(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     96659,       2763]*)
(*NotebookOutlinePosition[     98946,       2833]*)
(*  CellTagsIndexPosition[     98902,       2829]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Appendix A1. Power Series and Special Functions", "Section"],
  "\n",
  StyleBox["Series Solutions", "Subsection"],
  StyleBox[" ", "Subsection"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Series",
    FontWeight->"Bold"],
  " function can be used to obtain a series solution to a differential \
equation, provided ",
  StyleBox["DSolve",
    FontWeight->"Bold"],
  " can solve it in terms of special functions. ",
  StyleBox["SeriesCoefficient",
    FontWeight->"Bold"],
  " can generate the nth coefficient in a series expansion."
}], "Text"],

Cell[TextData[{
  StyleBox["Example",
    FontVariations->{"Underline"->True}],
  "  Obtain a series solution to the following differential equation (Ledder, \
A4, Exercise 2)."
}], "Text"],

Cell[TextData[{
  "y''",
  " + 2",
  StyleBox["x y'",
    FontSlant->"Italic"],
  " - ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = 0"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Then obtain the first 6 non-zero terms of the series solution satisfying \
",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 1, ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'(0) = 3. Plot the  approximate and the exact solutions. (Think of a mass \
spring system with a \"repelling\" spring moving in a  fluid that is \
thickening with time.) "
}], "Text"],

Cell["First enter and name the ode.", "Text"],

Cell[CellGroupData[{

Cell["DE = y''[x] + 2*x*y'[x] - y[x] == 0", "Input",
  CellLabel->"In[2]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-y[x]\), "+", 
        RowBox[{"2", " ", "x", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "+", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "\[Equal]", 
      "0"}]], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell[TextData[{
  "The general solution is in terms of special functions. Note that it is \
obtained using generic initial values, ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "0",
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'(0) = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "1. "
}], "Text"],

Cell[CellGroupData[{

Cell["gensoln = DSolve[ {DE, y[0]==y0, y'[0]==y1}, y[x], x ]", "Input",
  CellLabel->"In[11]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(\(1\/\(3\ Gamma[
                    5\/4]\)\)\((\[ExponentialE]\^\(-x\^2\)\ \((4\ \
\@\(2\/\[Pi]\)\ y1\ Gamma[5\/4]\ Gamma[7\/4]\ HermiteH[\(-\(3\/2\)\), x] - 
                    3\ y0\ Gamma[5\/4]\ Hypergeometric1F1[3\/4, 1\/2, x\^2] - 
                    2\ y1\ Gamma[7\/4]\ Hypergeometric1F1[3\/4, 1\/2, 
                        x\^2])\))\)\)\)}}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[TextData[{
  "The next entry applies ",
  StyleBox["Series",
    FontWeight->"Bold"],
  " to gensoln to generate the first 5 terms in the Taylor series \
representation for the general solution, expanded about ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 0",
  ". The syntax for the nth order Taylor series of an expression in x, \
expanded about x0, is shown below."
}], "Text"],

Cell[TextData[StyleBox["Series[ expression, {x, x0, n} ]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["sersoln = Series[ y[x]/.gensoln[[1]], {x,0,5} ]", "Input",
  CellLabel->"In[28]:=",
  FormatType->InputForm],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "y0", "+", \(\(4\ y1\ Gamma[7\/4]\ x\)\/\(3\ Gamma[3\/4]\)\), 
        "+", \(\(y0\ x\^2\)\/2\), 
        "-", \(\(2\ \((y1\ Gamma[7\/4])\)\ x\^3\)\/\(9\ Gamma[3\/4]\)\), 
        "-", \(\(y0\ x\^4\)\/8\), 
        "+", \(\(y1\ Gamma[7\/4]\ x\^5\)\/\(18\ Gamma[3\/4]\)\), "+", 
        InterpretationBox[\(O[x]\^6\),
          SeriesData[ x, 0, {}, 0, 6, 1],
          Editable->False]}],
      SeriesData[ x, 0, {y0, 
        Times[ 
          Rational[ 4, 3], y1, 
          Power[ 
            Gamma[ 
              Rational[ 3, 4]], -1], 
          Gamma[ 
            Rational[ 7, 4]]], 
        Times[ 
          Rational[ 1, 2], y0], 
        Times[ 
          Rational[ -2, 9], y1, 
          Power[ 
            Gamma[ 
              Rational[ 3, 4]], -1], 
          Gamma[ 
            Rational[ 7, 4]]], 
        Times[ 
          Rational[ -1, 8], y0], 
        Times[ 
          Rational[ 1, 18], y1, 
          Power[ 
            Gamma[ 
              Rational[ 3, 4]], -1], 
          Gamma[ 
            Rational[ 7, 4]]]}, 0, 6, 1],
      Editable->False]], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[TextData[{
  "The term O",
  Cell[BoxData[
      \(TraditionalForm\`\([x]\)\^6\)]],
  "representes the error in the approximation.\n If you would like to see a \
particular coefficient, for example the 20th,  first generate the 20th order \
series and then apply the function ",
  StyleBox["SeriesCoefficient",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Series[y[x]/.gensoln[[1]], {x,0,20}];
SeriesCoefficient[ %, 20]\
\>", "Input",
  CellLabel->"In[88]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\(-\(\(713\ y0\)\/39105331200\)\)\)], "Output",
  CellLabel->"Out[89]="]
}, Open  ]],

Cell[TextData[{
  "Apply the ",
  StyleBox["FullSimplify",
    FontWeight->"Bold"],
  " function to simplify all of the coefficients in sersoln displayed above."
}], "Text"],

Cell[CellGroupData[{

Cell["FullSimplify[sersoln]", "Input",
  CellLabel->"In[42]:=",
  FormatType->InputForm],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "y0", "+", \(y1\ x\), "+", \(\(y0\ x\^2\)\/2\), 
        "-", \(\(y1\ x\^3\)\/6\), "-", \(\(y0\ x\^4\)\/8\), 
        "+", \(\(y1\ x\^5\)\/24\), "+", 
        InterpretationBox[\(O[x]\^6\),
          SeriesData[ x, 0, {}, 0, 6, 1],
          Editable->False]}],
      SeriesData[ x, 0, {y0, y1, 
        Times[ 
          Rational[ 1, 2], y0], 
        Times[ 
          Rational[ -1, 6], y1], 
        Times[ 
          Rational[ -1, 8], y0], 
        Times[ 
          Rational[ 1, 24], y1]}, 0, 6, 1],
      Editable->False]], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Normal",
    FontWeight->"Bold"],
  " function can be used to convert the series solution into a polynomial \
approximation (i.e. eliminate the error term). When applied to the last \
output, ",
  StyleBox["Normal",
    FontWeight->"Bold"],
  " also collects the terms containing y0 and the ones containing y1."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Normal[",
  StyleBox["%", "Subsection"],
  "]"
}], "Input",
  CellLabel->"In[43]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(y0 + \(x\^2\ y0\)\/2 - \(x\^4\ y0\)\/8 + 
      x\ y1 - \(x\^3\ y1\)\/6 + \(x\^5\ y1\)\/24\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[TextData[{
  "If initial values are given, like ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 1 and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 3, ",
  "they can be used in ",
  StyleBox["DSolve",
    FontWeight->"Bold"],
  ". To obtain the first 6 Taylor series terms ask for the order 6 series."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
soln = DSolve[ {DE, y[0]==1, y'[0]==3}, y[x], x ];
Series[y[x]/.%[[1]], {x,0,6}];
approxsoln = Normal[FullSimplify[%]]\
\>", "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(1 + 3\ x + x\^2\/2 - x\^3\/2 - x\^4\/8 + 
      x\^5\/8 + \(7\ x\^6\)\/240\)], "Output",
  CellLabel->"Out[72]="]
}, Open  ]],

Cell["\<\
The following picture shows the exact and approximate solution \
curves. The approximation is the dashed curve. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ Plot[ y[x]/.soln, {x,0,3} ],
      Plot[ approxsoln, {x,0,3}, PlotStyle->Dashing[{0.02,0.02}]],
      PlotRange->{{0,3},{0,8}}]\
\>", "Input",
  CellLabel->"In[69]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.333333 0 0.0772542 [
[.16667 -0.0125 -9 -9 ]
[.16667 -0.0125 9 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -9 -9 ]
[.83333 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .07725 -6 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -6 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -6 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -6 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -6 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -6 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(0.5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(1)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(2)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2.5)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(1)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(2)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(3)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(4)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(5)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(7)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(8)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .07725 m
.04057 .10596 L
.08481 .13806 L
.12636 .16844 L
.16632 .19743 L
.20885 .22763 L
.2498 .25572 L
.29331 .28425 L
.33524 .3103 L
.37557 .33395 L
.41848 .35761 L
.4598 .379 L
.49953 .39837 L
.54183 .41783 L
.58254 .43555 L
.62583 .45343 L
.66752 .46984 L
.70762 .48498 L
.7503 .50047 L
.79139 .51485 L
.83505 .52964 L
.87712 .54345 L
.9176 .55637 L
.96065 .56976 L
1 .5817 L
s
[ .02 .02 ] 0 setdash
0 .07725 m
.04057 .10596 L
.08481 .13806 L
.12636 .16844 L
.16632 .19745 L
.20885 .22771 L
.2498 .25601 L
.29331 .28513 L
.33524 .31251 L
.37557 .33875 L
.41848 .36762 L
.4598 .39785 L
.49953 .43112 L
.54183 .47388 L
.58254 .52563 L
.62583 .59688 L
s
.62583 .59688 m
.6356 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[69]:=",
  ImageSize->{209.812, 129.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003A0000PB000`400?l00000o`00003odOooool0
02Oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Eooooo`?o00005_ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001Cooooo1Ol0000Cooooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00005_ooool3o`0000[ooooo000Vooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000001Cooooo00Co0000oooooooooooo0000
5?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000005?ooool01Ol0
003ooooooooooooooooo000000Wooooo000Vooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`07ooooo`009_ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Cooooo0_l0000:ooooo`009_ooool01?l0003oooooooooool00007
ooooo`Co00005_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo1?l0000D
ooooo`05o`000?ooooooooooooooool000004oooool01Ol0003ooooooooooooooooo000000Oooooo
1?l0000Iooooo`03o`000?oooooooooo00Oooooo000Vooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool05_ooool2o`0001Oooooo0_l00009ooooo`03o`000?oooooooooo01Gooooo
00Go0000ooooooooooooooooo`00000Cooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000002Oooool002Oooooo0_l00008oooo
o`Go00005Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo1Ol0000Doooo
o`?o00005Oooool3o`0000Sooooo1Ol0000Eooooo`?o00002_ooool00=7ooooo003Aooooo`00dOoo
ool000oooooo^?l0000:ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`003oooool00ol0003o
ooooooooo`2oooooo`003oooool2o`000<3ooooo000?ooooo`03o`000?oooooooooo0;oooooo000?
ooooo`03o`000?oooooooooo0;oooooo000?ooooo`;o0000`?ooool000oooooo00?o0000oooooooo
ool0_oooool000oooooo00?o0000ooooooooool0_oooool000oooooo0_l00030ooooo`003oooool0
0ol0003oooooooooo`2oooooo`003oooool2o`000<3ooooo0008ooooo`?o00001?ooool00ol0003o
ooooooooo`2oooooo`002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;oooooo
0009ooooo`03o`000?oooooooooo00?ooooo0_l00030ooooo`002Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo00000;oooooo0009ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo0000__ooool000Sooooo0_l00005ooooo`;o00000_ooool2o`000;cooooo0009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00
3oooool00ol0003oooooooooo`03ooooo`;o0000^_ooool000oooooo0_l00006ooooo`;o0000^?oo
ool000oooooo00?o0000ooooooooool01_ooool2o`000;Oooooo000?ooooo`03o`000?oooooooooo
00Sooooo0_l0002eooooo`003oooool2o`0000[ooooo0ol0002cooooo`003oooool00ol0003ooooo
ooooo`0;ooooo`;o0000/_ooool000oooooo00?o0000ooooooooool03?ooool3o`000;3ooooo0007
ooooo`Go00000oooool2o`00013ooooo00?o0000ooooooooool0[Oooool000Sooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`0?ooooo`;o0000[_ooool000Wooooo00?o0000oooo
ooooool00oooool2o`0001;ooooo00?o0000ooooooooool0Zoooool000[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:[ooooo0007ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0:Wo
oooo0007ooooo`05o`000?ooooooooooooooool000000oooool2o`0001Gooooo0_l0002Yooooo`00
2?ooool3o`0000Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Vooooo`003ooo
ool00ol0003oooooooooo`0Gooooo`;o0000Y_ooool000oooooo0_l0000Iooooo`?o0000Y?ooool0
00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Qooooo`003oooool00ol0003o
ooooooooo`0Kooooo`?o0000XOooool000oooooo0_l0000Nooooo`;o0000X?ooool000oooooo00?o
0000ooooooooool07_ooool2o`0009oooooo000?ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0W?ooool000Sooooo0ol00004ooooo`;o00008_ooool00ol0003oooooooooo`2Koooo
o`001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`2Jooooo`002oooool01?l0003oooooooooooooool2o`0002Cooooo0_l0002Joooo
o`002Oooool2o`0000Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2Gooooo`00
2oooool01Ol0003ooooooooooooooooo000002Sooooo0ol0002Fooooo`001oooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l0000Yooooo`;o0000UOooool000Sooooo0ol00004ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0T_ooool000oooooo00?o0000ooooooooool0:ooo
ool2o`0009;ooooo000?ooooo`;o0000;_ooool2o`00093ooooo000?ooooo`03o`000?oooooooooo
02kooooo0_l0002?ooooo`003oooool00ol0003oooooooooo`0`ooooo`;o0000SOooool000oooooo
0_l0000cooooo`03o`000?oooooooooo08[ooooo000?ooooo`03o`000?oooooooooo03?ooooo0_l0
002:ooooo`003oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo08Oooooo0009oooo
o`?o00000oooool2o`0003Oooooo0_l00027ooooo`002_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0Q?ooool000Oooooo1Ol00003ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0Poooool000Oooooo00Co0000oooooooooooo0000
1?ooool2o`0003_ooooo0_l00023ooooo`002?ooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo03cooooo0_l00021ooooo`002Oooool2o`0000Cooooo0_l0000oooooo`;o0000Ooooool0
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0oooooo`?o0000OOooool000oo
oooo00?o0000ooooooooool0@Oooool3o`0007_ooooo000?ooooo`;o0000@oooool01?l0003ooooo
o`000?l0001iooooo`003oooool00ol0003oooooooooo`16ooooo`;o0000Moooool000oooooo00?o
0000ooooooooool0AOooool2o`000003ooooool0003o000007Gooooo000?ooooo`;o0000B?ooool0
0ol0003oooooooooo`02o`0007?ooooo000?ooooo`03o`000?oooooooooo04Sooooo00Co0000oooo
oooooooooooo0_l0001aooooo`003oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
06kooooo0008ooooo`?o00001?ooool2o`0004cooooo00Co0000oooooooooooooooo0_l0001^oooo
o`001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`02ooooo`;o0000K?ooool000_ooooo00Go0000ooooooooooooooooo`00001?oooo
o`03o`000?oooooooooo00?ooooo0_l0001Zooooo`002oooool01?l0003oooooooooooooool2o`00
04oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`001oooool4o`0000Co
oooo00?o0000ooooooooool0E_ooool2o`0006Oooooo0007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0DOooool2o`0000Gooooo0_l0001Uooooo`001oooool5o`0000?ooooo0_l0
001Dooooo`03o`000?oooooooooo00Cooooo0ol0001Rooooo`003oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo00Kooooo0ol0001Oooooo`003oooool2o`00067ooooo0_l0001Moooo
o`003oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00
3oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00[ooooo0_l0001Iooooo`003ooo
ool2o`0005Wooooo00?o0000ooooooooool02oooool2o`0005Oooooo000?ooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool03?ooool2o`0005Gooooo000?ooooo`03o`000?oooooooooo
06[ooooo0ol0001Booooo`002?ooool3o`0000Cooooo0_l0001Mooooo`03o`000?oooooooooo00ko
oooo0ol0001?ooooo`001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`0@ooooo`;o0000COooool000Oooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool04Oooool3o`0004[o
oooo0007ooooo`Co00001?ooool2o`00063ooooo00?o0000ooooooooool04oooool2o`0004Sooooo
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Moooool2o`0004Kooooo0008
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0NOooool3o`0004?ooooo0009oooo
o`;o00001?ooool2o`0006;ooooo00?o0000ooooooooool06?ooool2o`00047ooooo000?ooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool06_ooool2o`0003oooooo000?ooooo`;o0000
Hoooool00ol0003oooooooooo`0Kooooo`?o0000??ooool000oooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0Mooooo`?o0000>Oooool000oooooo00?o0000ooooooooool0Q_ooool3
o`0003Kooooo000?ooooo`;o0000R_ooool4o`0003;ooooo000?ooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool09?ooool3o`0002oooooo000?ooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool09_ooool3o`0002cooooo0009ooooo`03o`000?oooooooooo00?ooooo0_l0
001Yooooo`03o`000?oooooooooo02Sooooo0ol0000Yooooo`002Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09Kooooo0ol0000Vooooo`002_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo09Wooooo0ol0000Sooooo`002_ooool00ol0003oooooooooo`02ooooo`;o
0000WOooool3o`00023ooooo000;ooooo`05o`000?ooooooooooooooool00000K?ooool00ol0003o
ooooooooo`0booooo`?o00007Oooool000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0=Oooool3o`0001[ooooo0007ooooo`Go0000
0oooool2o`0006cooooo00?o0000ooooooooool0=oooool3o`0001Oooooo000?ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0>Oooool4o`0001?ooooo000?ooooo`03o`000?oooooo
oooo0:cooooo1?l0000?ooooo`003oooool2o`000;7ooooo0ol0000<ooooo`003oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo04?ooooo0_l0000:ooooo`003oooool2o`0006kooooo
00?o0000ooooooooool0Coooool000oooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`1>ooooo`003oooool00ol0003oooooooooo`1_ooooo`;o0000C_ooool000Sooooo0ol00004oooo
o`;o0000LOooool00ol0003oooooooooo`1<ooooo`001oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1<ooooo`001oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1;oooo
o`002?ooool3o`0000Cooooo0_l0001booooo`03o`000?oooooooooo04_ooooo0007ooooo`05o`00
0?ooooooooooooooool00000aOooool000Oooooo00Go0000ooooooooooooooooo`000035ooooo`00
2?ooool3o`000<Kooooo003Aooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 286.688}, {609, 480.375}} -> {-1.53845, \
33.2565, 0.0164309, 0.0708954}}]
}, Open  ]],

Cell[TextData[StyleBox["Special Functions", "Subsubsection"]], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has, built-in, most of the special functions that are found in elementary \
differential  equations textbooks. For example, the Bessel functions of the \
first and second kind of order n are denoted  ",
  StyleBox["BesselJ[n,x]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["BesselY[n,x]",
    FontWeight->"Bold"],
  " respectively. Compare the plots below to the ones appearing in Chapter 3, \
 Figures 3.7.3 and 3.7.4 in Ledder. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ Plot[ BesselJ[0,x], {x,0,20} ],
      Plot[ BesselJ[1,x], {x,0,20}, PlotStyle->Dashing[{0.02,0.02}] ] ]\
\>", \
"Input",
  CellLabel->"In[76]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.183714 0.419605 [
[.2619 .17121 -3 -9 ]
[.2619 .17121 3 0 ]
[.5 .17121 -6 -9 ]
[.5 .17121 6 0 ]
[.7381 .17121 -6 -9 ]
[.7381 .17121 6 0 ]
[.97619 .17121 -6 -9 ]
[.97619 .17121 6 0 ]
[.01131 .01587 -24 -4.5 ]
[.01131 .01587 0 4.5 ]
[.01131 .09979 -24 -4.5 ]
[.01131 .09979 0 4.5 ]
[.01131 .26764 -18 -4.5 ]
[.01131 .26764 0 4.5 ]
[.01131 .35156 -18 -4.5 ]
[.01131 .35156 0 4.5 ]
[.01131 .43548 -18 -4.5 ]
[.01131 .43548 0 4.5 ]
[.01131 .5194 -18 -4.5 ]
[.01131 .5194 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .18371 m
.2619 .18996 L
s
[(5)] .2619 .17121 0 1 Mshowa
.5 .18371 m
.5 .18996 L
s
[(10)] .5 .17121 0 1 Mshowa
.7381 .18371 m
.7381 .18996 L
s
[(15)] .7381 .17121 0 1 Mshowa
.97619 .18371 m
.97619 .18996 L
s
[(20)] .97619 .17121 0 1 Mshowa
.125 Mabswid
.07143 .18371 m
.07143 .18746 L
s
.11905 .18371 m
.11905 .18746 L
s
.16667 .18371 m
.16667 .18746 L
s
.21429 .18371 m
.21429 .18746 L
s
.30952 .18371 m
.30952 .18746 L
s
.35714 .18371 m
.35714 .18746 L
s
.40476 .18371 m
.40476 .18746 L
s
.45238 .18371 m
.45238 .18746 L
s
.54762 .18371 m
.54762 .18746 L
s
.59524 .18371 m
.59524 .18746 L
s
.64286 .18371 m
.64286 .18746 L
s
.69048 .18371 m
.69048 .18746 L
s
.78571 .18371 m
.78571 .18746 L
s
.83333 .18371 m
.83333 .18746 L
s
.88095 .18371 m
.88095 .18746 L
s
.92857 .18371 m
.92857 .18746 L
s
.25 Mabswid
0 .18371 m
1 .18371 L
s
.02381 .01587 m
.03006 .01587 L
s
[(-0.4)] .01131 .01587 1 0 Mshowa
.02381 .09979 m
.03006 .09979 L
s
[(-0.2)] .01131 .09979 1 0 Mshowa
.02381 .26764 m
.03006 .26764 L
s
[(0.2)] .01131 .26764 1 0 Mshowa
.02381 .35156 m
.03006 .35156 L
s
[(0.4)] .01131 .35156 1 0 Mshowa
.02381 .43548 m
.03006 .43548 L
s
[(0.6)] .01131 .43548 1 0 Mshowa
.02381 .5194 m
.03006 .5194 L
s
[(0.8)] .01131 .5194 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03685 m
.02756 .03685 L
s
.02381 .05783 m
.02756 .05783 L
s
.02381 .07881 m
.02756 .07881 L
s
.02381 .12077 m
.02756 .12077 L
s
.02381 .14175 m
.02756 .14175 L
s
.02381 .16273 m
.02756 .16273 L
s
.02381 .20469 m
.02756 .20469 L
s
.02381 .22567 m
.02756 .22567 L
s
.02381 .24666 m
.02756 .24666 L
s
.02381 .28862 m
.02756 .28862 L
s
.02381 .3096 m
.02756 .3096 L
s
.02381 .33058 m
.02756 .33058 L
s
.02381 .37254 m
.02756 .37254 L
s
.02381 .39352 m
.02756 .39352 L
s
.02381 .4145 m
.02756 .4145 L
s
.02381 .45646 m
.02756 .45646 L
s
.02381 .47744 m
.02756 .47744 L
s
.02381 .49842 m
.02756 .49842 L
s
.02381 .54038 m
.02756 .54038 L
s
.02381 .56136 m
.02756 .56136 L
s
.02381 .58234 m
.02756 .58234 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60325 L
.02605 .60309 L
.02729 .60276 L
.02846 .60232 L
.03053 .60123 L
.03279 .5996 L
.03527 .59727 L
.0379 .59419 L
.04262 .58711 L
.05205 .56722 L
.06244 .53705 L
.0842 .45083 L
.10458 .35164 L
.14335 .16125 L
.15346 .11979 L
.16449 .08127 L
.1749 .05239 L
.18458 .0327 L
.18965 .02523 L
.19232 .02211 L
.19514 .01941 L
.19762 .01755 L
.19892 .01675 L
.20033 .01604 L
.20162 .01553 L
.2028 .01517 L
.20398 .01491 L
.2051 .01477 L
.20617 .01472 L
.20734 .01476 L
.20857 .01491 L
.20973 .01516 L
.2108 .01547 L
.21179 .01584 L
.21401 .01691 L
.21627 .01836 L
.21873 .02034 L
.22371 .02558 L
.22899 .03287 L
.23398 .04127 L
.24332 .0605 L
.26427 .11607 L
.30273 .22958 L
.32261 .27539 L
.33263 .29188 L
.33832 .29895 L
.34109 .30176 L
.34365 .30398 L
.34626 .30587 L
Mistroke
.34863 .30725 L
.35126 .30842 L
.3527 .3089 L
.35406 .30924 L
.35526 .30945 L
.35653 .30959 L
.35762 .30964 L
.35881 .30962 L
.36009 .30951 L
.36081 .30941 L
.36146 .30929 L
.36274 .30899 L
.36394 .30863 L
.36618 .30775 L
.36856 .30653 L
.37282 .30359 L
.37741 .2994 L
.38248 .2936 L
.3926 .27866 L
.40186 .26162 L
.42273 .2153 L
.4433 .16623 L
.46241 .12537 L
.47191 .10877 L
.48087 .09613 L
.48583 .09053 L
.4912 .08567 L
.49357 .08394 L
.49608 .08238 L
.49823 .08127 L
.50057 .08031 L
.50189 .07988 L
.50311 .07955 L
.50427 .0793 L
.50552 .07911 L
.50662 .079 L
.50766 .07895 L
.5088 .07894 L
.51003 .07901 L
.51126 .07914 L
.51196 .07925 L
.51261 .07937 L
.51403 .0797 L
.51532 .08008 L
.51767 .08096 L
.52018 .08218 L
.5247 .08505 L
.5296 .08914 L
.53851 .09897 L
.55836 .13011 L
Mistroke
.57939 .17156 L
.59917 .21136 L
.61725 .24268 L
.62721 .25621 L
.63667 .26597 L
.64185 .2699 L
.64666 .27261 L
.64943 .27376 L
.65194 .27453 L
.65333 .27484 L
.65406 .27498 L
.65483 .2751 L
.65551 .27518 L
.65625 .27526 L
.65756 .27533 L
.65886 .27533 L
.66007 .27527 L
.6607 .27522 L
.6614 .27514 L
.6628 .27493 L
.66404 .27467 L
.66537 .27433 L
.66777 .27353 L
.67014 .27253 L
.67263 .27124 L
.67708 .26835 L
.68707 .25932 L
.698 .24585 L
.73858 .17687 L
.75733 .14484 L
.7672 .1304 L
.77765 .11781 L
.78294 .11266 L
.78876 .10805 L
.79132 .1064 L
.79406 .10487 L
.79663 .10368 L
.79901 .10279 L
.8016 .10205 L
.80296 .10176 L
.80366 .10164 L
.80441 .10153 L
.80514 .10144 L
.8058 .10137 L
.80711 .1013 L
.80829 .10128 L
.80954 .10131 L
.81069 .1014 L
.81192 .10154 L
.81308 .10172 L
Mistroke
.81413 .10193 L
.81672 .10261 L
.81916 .10347 L
.82377 .10566 L
.82885 .1089 L
.83913 .11793 L
.84865 .12891 L
.85757 .14106 L
.89633 .2032 L
.91603 .23148 L
.92718 .24392 L
.93251 .24869 L
.93754 .25242 L
.94225 .2552 L
.94473 .25638 L
.94735 .25742 L
.94956 .25811 L
.95073 .25841 L
.95198 .25869 L
.95313 .25889 L
.95418 .25904 L
.95524 .25915 L
.95624 .25922 L
.95739 .25927 L
.95865 .25926 L
.95997 .2592 L
.9612 .25909 L
.96236 .25894 L
.96341 .25876 L
.9658 .25824 L
.96821 .25751 L
.97086 .2565 L
.97619 .2538 L
Mfstroke
[ .02 .02 ] 0 setdash
.02381 .18371 m
.04262 .26497 L
.06244 .34031 L
.07216 .37044 L
.08255 .39632 L
.08852 .40789 L
.09396 .41619 L
.09658 .41941 L
.09942 .42232 L
.1019 .42437 L
.10328 .4253 L
.10458 .42605 L
.1058 .42664 L
.10712 .42714 L
.10833 .42749 L
.10945 .42771 L
.11061 .42784 L
.11166 .42787 L
.11288 .42779 L
.11402 .42762 L
.11528 .42732 L
.11662 .42687 L
.11901 .42573 L
.12159 .42403 L
.12442 .4216 L
.12967 .41558 L
.13529 .40703 L
.14545 .38646 L
.16669 .32592 L
.18681 .2549 L
.22514 .12155 L
.23534 .0935 L
.24491 .07183 L
.2549 .0547 L
.2602 .04803 L
.26297 .04525 L
.26592 .0428 L
.26852 .0411 L
.27088 .03992 L
.27202 .03948 L
.27325 .03909 L
.27442 .03881 L
.27549 .03863 L
.27674 .03851 L
.27791 .03848 L
.2792 .03855 L
.27992 .03863 L
.28058 .03873 L
.2819 .03902 L
.28334 .03946 L
Mistroke
.28596 .04057 L
.28874 .04219 L
.29126 .04404 L
.29691 .04949 L
.30214 .05606 L
.30706 .06348 L
.32718 .10418 L
.34566 .15114 L
.36612 .20513 L
.3852 .24947 L
.39464 .26719 L
.40357 .28064 L
.4085 .28653 L
.41386 .29162 L
.41622 .29343 L
.41873 .29504 L
.42088 .29617 L
.42323 .29714 L
.42438 .29752 L
.42562 .29784 L
.42692 .29811 L
.42813 .29827 L
.42934 .29837 L
.43048 .29839 L
.43151 .29836 L
.43262 .29826 L
.43384 .29808 L
.43453 .29795 L
.43518 .2978 L
.43789 .29697 L
.44023 .29596 L
.44274 .29459 L
.44765 .29107 L
.4523 .28673 L
.46103 .27616 L
.48091 .24234 L
.49933 .20344 L
.51955 .15938 L
.53856 .12329 L
.54739 .10984 L
.5567 .09862 L
.56158 .09408 L
.56691 .09022 L
.56926 .0889 L
.57176 .08775 L
.57413 .0869 L
.57628 .08635 L
.57747 .08612 L
.57858 .08597 L
.5798 .08586 L
Mistroke
.58112 .08582 L
.58177 .08582 L
.58249 .08585 L
.58379 .08596 L
.58507 .08613 L
.58624 .08635 L
.58858 .08697 L
.5907 .08772 L
.59544 .09007 L
.60058 .09364 L
.60615 .09863 L
.61623 .11041 L
.63618 .14198 L
.65725 .18175 L
.67713 .21855 L
.69524 .24615 L
.70527 .25753 L
.70988 .26164 L
.71477 .26519 L
.71724 .26665 L
.71997 .268 L
.72249 .26899 L
.72479 .26969 L
.72611 .27 L
.7275 .27026 L
.72817 .27035 L
.72889 .27044 L
.72968 .27051 L
.73041 .27055 L
.73109 .27057 L
.73183 .27058 L
.73253 .27056 L
.73318 .27053 L
.7344 .27043 L
.73569 .27026 L
.7369 .27004 L
.73822 .26975 L
.74062 .26904 L
.74296 .26814 L
.74513 .26713 L
.75005 .26422 L
.75528 .26022 L
.76489 .25059 L
.77359 .23965 L
.81373 .17406 L
.83216 .14444 L
.84262 .13024 L
.85236 .11945 L
.86201 .11149 L
.86479 .10975 L
Mistroke
.86742 .10834 L
.86977 .10729 L
.87235 .10634 L
.8749 .10562 L
.87629 .10533 L
.8776 .10511 L
.87882 .10496 L
.87994 .10487 L
.88123 .10483 L
.88246 .10483 L
.88377 .1049 L
.88451 .10496 L
.88518 .10503 L
.88648 .10522 L
.8877 .10545 L
.89045 .10614 L
.89343 .10719 L
.89834 .10955 L
.90293 .11245 L
.91336 .12139 L
.92352 .13283 L
.93442 .1475 L
.97577 .21115 L
.97619 .21176 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[76]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`006oooool00ol0003oooooooooo`3oooooo`?ooooo0008ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`3oooooo`?ooooo0007ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooo`?o
oooo0005o`0000;ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo00?o0000oooooooo
ool0ooooool3ooooo`001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
00Gooooo0_l0000/ooooo`Go0000d_ooool000Oooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool2o`00
0=3ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`03o`000?oooooooooo
02Wooooo0_l00007ooooo`03o`000?oooooooooo0<gooooo0008ooooo`;o00002oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3=ooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0c?ooool001_ooooo0_l0000Yooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0c?ooool001_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Oooooo1_l0002nooooo`006oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`000;gooooo000Kooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0;_ooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`;o0000^oooool001_ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooooooo`;o0000a_ooool001_ooooo0_l0
000Vooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000037ooooo`006ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000b?oo
ool001_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
00000<Sooooo000Kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo0;Kooooo000Kooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;Ko
oooo000Kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;Gooooo000Kooooo`;o00008oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;_ooool6o`00087ooooo000K
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo02cooooo0_l00006ooooo`;o0000Ooooool001_ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000004?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool4
o`00073ooooo0008ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000??oo
ool2o`0000_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo06[ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3_ooool2o`0006[ooooo0005o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`04ooooo`;o00008_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Ioooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00oooooo0_l0000Vooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0^ooooo`So0000<?ooool000Oooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooool0
0000?_ooool3o`0000Oooooo00?o0000ooooooooool03?ooool4o`0001gooooo0007ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00Sooooo0_l00007ooooo`;o00001oooool2o`0001_ooooo0008ooooo`;o00002Oooool3o`0000Go
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03_o
oooo0_l0000=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool001_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000003_ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`006oooool2o`00023ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool04Oooool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`006oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo013ooooo0_l0000Aooooo`03o`000?oooooooooo01Gooooo000K
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04Oooool2o`0001;ooooo00?o0000
ooooooooool05?ooool001_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0@oooo
o`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool04oooool001_ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Cooooo`006oooool2o`0001oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`06ooooo`?o00000_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool3o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool3o`0000?ooooo0ol00002ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Cooooo1Ol00003ooooo`;o00001?ooool001_ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00Oo0000oooooooooooo
ooooo`000?oooooo0000017ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000003ooooo`;o00006_oo
ool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool001_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Looooo`04o`00
0?ooooooooooo`00017ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool2o`0001_ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000Koooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000A
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Hooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`01ooooo`006ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo1?l00003ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00Ko0000oooooooooooo0000ooooool0000=ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04oooool01?l0003oooooooooooooool5o`0001gooooo00?o0000oooo
ooooool04?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`01ooooo`006oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01_ooool2o`0000Cooooo00Co0000oooooooooooo00003ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`04o`000?oo
ooooooooo`0001;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
007ooooo000Kooooo`;o00007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oo
oooo1Ol00003ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`;o00004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;o
oooo00Co0000oooooooooooooooo1Ol0000Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04?ooool01?l0003oooooooooooooool3o`0000Cooooo0_l00004ooooo`006oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Oooooo`006oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Nooooo`006oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0N
ooooo`005?ooooooo`0000go0000000Kooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`;o00002oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooool000002oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00000;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00?o0000oooo
ooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo000Kooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`006oooool2o`0001co
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool02?ooool001_ooooo0_l0000Looooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`006oooool2o`0001cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01_ooool001_ooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool001_ooooo00?o0000oooo
ool000006_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06Oooool001_ooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool06?ooool001_ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
5oooool001_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool05oooool001_ooooo0_l0000Jooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01Kooooo000Kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05Oooool001_o
oooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool05Oooool001_ooooo00Co0000oooooooooooo00006?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01Cooooo000Kooooo`04o`000?ooooooooooo`0001Oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo0000017ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Cooooo`006oooool2o`000003ooooool0003ooooo
01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0>_ooool2o`0001?ooooo000Kooooo`05o`000?oooooooooooooo
ool000005_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo013ooooo000Kooooo`05
o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Co
oooo00Co0000oooooooooooooooo1Ol00004ooooo`05o`000?ooooooooooooooool000005_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09_ooool2
o`0000oooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo02kooooo1?l0
0002ooooo`?o00002?ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00004_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2o`0000[o
oooo00?o0000ooooooooool0<_ooool4o`0000[ooooo0007ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0@Oooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0
003oooooooooo`03ooooo`;o00006?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
017ooooo0_l00010ooooo`;o00001oooool2o`0000Wooooo0_l00004ooooo`?o0000A?ooool000Oo
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`02ooooo`;o0000F?ooool000Oooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`11ooooo`Co0000F_ooool000Sooooo0_l00009ooooo`?o00001Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2?ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2?ooooo`006oooool2o`0000Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool00ol0003o
ooooooooo`2@ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o0000Toooool001_ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo0_l0
0005ooooo`03o`000?oooooooooo09?ooooo000Kooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`2Hooooo`006oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Uoooo
o`006oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03[ooooo0_l00005ooooo`03
o`000?oooooooooo0:Kooooo000Kooooo`;o00005_ooool00ol0003oooooooooo`0looooo`Go0000
ZOooool001_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0>_ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0=cooooo000Kooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0=cooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo0=cooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0=cooooo
000Kooooo`;o00002?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0gOooool001_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo0=gooooo000Kooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0k?ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0k?ooool000Oooooo00Co0000oooooooooooo
00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0kOooool000Oooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo0_l00009ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0kOooool000Oooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=oooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3Ooooo
o`001oooool01?l0003oooooooooool00009ooooo`;o00001Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Poooo
o`002?ooool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3Pooooo`00
6oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3Pooooo`006oooool2o`0001;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`3Qooooo`006oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo0>kooooo000Kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0k_ooool001_o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3_ooooo`006oooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool00000lOooool001_ooooo0_l0000=ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`3Sooooo`006oooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`3Sooooo`00
6oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003o
ooooooooo`3Tooooo`006oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000_ooooo
00?o0000ooooooooool0i?ooool001_ooooo00?o0000ooooooooool03_ooool2o`0000[ooooo00?o
0000ooooooooool0iOooool001_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo0>Gooooo000Kooooo`;o00004?ooool00ol0003oooooooooo`3`oooo
o`006oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?3ooooo000Kooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooool00000l?ooool000Sooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooooooo
1Ol0003[ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?7ooooo0007ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0lOooool000Oooooo00Co0000oooooooooooo00001oooool4o`00
00Gooooo0_l0000?ooooo`03o`000?oooooooooo0?7ooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
0?7ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo0?;ooooo0008ooooo`;o00002_ooool2o`0000Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3booooo`006oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo0?;ooooo000Kooooo`;o00003_ooool00ol0003ooooooooo
o`3booooo`006oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?;ooooo000Koooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0loooool001_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`3cooooo`006oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo0??ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0looo
ool001_ooooo0_l0000<ooooo`03o`000?oooooooooo0?Cooooo000Kooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0m?ooool001_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`3dooooo`006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?Cooooo
000Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0mOooool001_ooooo0_l0000;
ooooo`03o`000?oooooooooo0?Gooooo000Kooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0mOooool001_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3fooooo`00
2?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?Ko
oooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooo
oooo00002?ooool3o`0000Gooooo0_l00009ooooo`03o`000?oooooooooo0?Oooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0moooool000Oooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`3gooooo`002?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0moooool001_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3hoooo
o`006oooool2o`0000Sooooo00?o0000ooooooooool0n?ooool001_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3hooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?Wooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0nOooool0
01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3iooooo`006oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?[ooooo000Kooooo`;o00001_ooool00ol0003ooooo
ooooo`3jooooo`006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?[ooooo000K
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0noooool001_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3kooooo`006oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0?cooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
o?ooool001_ooooo0_l00004ooooo`03o`000?oooooooooo0?cooooo000Kooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0oOooool001_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3mooooo`004oooool3o`0000Gooooo00Go0000ooooooooooooooooo`00003ooooo
o`7ooooo000Dooooo`03o`000?oooooooooo00Cooooo00Co0000ooooool0003o0000ooooool2oooo
o`005?ooool00ol0003oooooooooo`04ooooo`?o0000ooooool3ooooo`005?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo0oooool001Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooo`?ooooo000Cooooo`;o00001_ooool00ol0003oooooooooo`3o
ooooo`?ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool3oooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 364.875}, {271.812, 94.875}} -> {-8.30519, \
0.357394, 0.0789457, 0.00895918}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[ Plot[ BesselY[0,x], {x,0,20} ],
      Plot[ BesselY[1,x], {x,0,20}, PlotStyle->Dashing[{0.02,0.02}] ] ]\
\>", \
"Input",
  CellLabel->"In[77]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.419094 0.353743 [
[.2619 .40659 -3 -9 ]
[.2619 .40659 3 0 ]
[.5 .40659 -6 -9 ]
[.5 .40659 6 0 ]
[.7381 .40659 -6 -9 ]
[.7381 .40659 6 0 ]
[.97619 .40659 -6 -9 ]
[.97619 .40659 6 0 ]
[.01131 .06535 -12 -4.5 ]
[.01131 .06535 0 4.5 ]
[.01131 .15379 -30 -4.5 ]
[.01131 .15379 0 4.5 ]
[.01131 .24222 -24 -4.5 ]
[.01131 .24222 0 4.5 ]
[.01131 .33066 -30 -4.5 ]
[.01131 .33066 0 4.5 ]
[.01131 .50753 -24 -4.5 ]
[.01131 .50753 0 4.5 ]
[.01131 .59597 -18 -4.5 ]
[.01131 .59597 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .41909 m
.2619 .42534 L
s
[(5)] .2619 .40659 0 1 Mshowa
.5 .41909 m
.5 .42534 L
s
[(10)] .5 .40659 0 1 Mshowa
.7381 .41909 m
.7381 .42534 L
s
[(15)] .7381 .40659 0 1 Mshowa
.97619 .41909 m
.97619 .42534 L
s
[(20)] .97619 .40659 0 1 Mshowa
.125 Mabswid
.07143 .41909 m
.07143 .42284 L
s
.11905 .41909 m
.11905 .42284 L
s
.16667 .41909 m
.16667 .42284 L
s
.21429 .41909 m
.21429 .42284 L
s
.30952 .41909 m
.30952 .42284 L
s
.35714 .41909 m
.35714 .42284 L
s
.40476 .41909 m
.40476 .42284 L
s
.45238 .41909 m
.45238 .42284 L
s
.54762 .41909 m
.54762 .42284 L
s
.59524 .41909 m
.59524 .42284 L
s
.64286 .41909 m
.64286 .42284 L
s
.69048 .41909 m
.69048 .42284 L
s
.78571 .41909 m
.78571 .42284 L
s
.83333 .41909 m
.83333 .42284 L
s
.88095 .41909 m
.88095 .42284 L
s
.92857 .41909 m
.92857 .42284 L
s
.25 Mabswid
0 .41909 m
1 .41909 L
s
.02381 .06535 m
.03006 .06535 L
s
[(-1)] .01131 .06535 1 0 Mshowa
.02381 .15379 m
.03006 .15379 L
s
[(-0.75)] .01131 .15379 1 0 Mshowa
.02381 .24222 m
.03006 .24222 L
s
[(-0.5)] .01131 .24222 1 0 Mshowa
.02381 .33066 m
.03006 .33066 L
s
[(-0.25)] .01131 .33066 1 0 Mshowa
.02381 .50753 m
.03006 .50753 L
s
[(0.25)] .01131 .50753 1 0 Mshowa
.02381 .59597 m
.03006 .59597 L
s
[(0.5)] .01131 .59597 1 0 Mshowa
.125 Mabswid
.02381 .08304 m
.02756 .08304 L
s
.02381 .10073 m
.02756 .10073 L
s
.02381 .11841 m
.02756 .11841 L
s
.02381 .1361 m
.02756 .1361 L
s
.02381 .17147 m
.02756 .17147 L
s
.02381 .18916 m
.02756 .18916 L
s
.02381 .20685 m
.02756 .20685 L
s
.02381 .22454 m
.02756 .22454 L
s
.02381 .25991 m
.02756 .25991 L
s
.02381 .2776 m
.02756 .2776 L
s
.02381 .29528 m
.02756 .29528 L
s
.02381 .31297 m
.02756 .31297 L
s
.02381 .34835 m
.02756 .34835 L
s
.02381 .36603 m
.02756 .36603 L
s
.02381 .38372 m
.02756 .38372 L
s
.02381 .40141 m
.02756 .40141 L
s
.02381 .43678 m
.02756 .43678 L
s
.02381 .45447 m
.02756 .45447 L
s
.02381 .47216 m
.02756 .47216 L
s
.02381 .48984 m
.02756 .48984 L
s
.02381 .52522 m
.02756 .52522 L
s
.02381 .5429 m
.02756 .5429 L
s
.02381 .56059 m
.02756 .56059 L
s
.02381 .57828 m
.02756 .57828 L
s
.02381 .04766 m
.02756 .04766 L
s
.02381 .02998 m
.02756 .02998 L
s
.02381 .01229 m
.02756 .01229 L
s
.02381 .61365 m
.02756 .61365 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03202 0 m
.03279 .02276 L
.0379 .13014 L
.04262 .20153 L
.05224 .30866 L
.06244 .39229 L
.0728 .45813 L
.0825 .50676 L
.09313 .54771 L
.09911 .56548 L
.10458 .57861 L
.10935 .58768 L
.11196 .59175 L
.11442 .59501 L
.11673 .59755 L
.11922 .59977 L
.12148 .60131 L
.12357 .60234 L
.12476 .60277 L
.12605 .60309 L
.12726 .60326 L
.12837 .60332 L
.12967 .60326 L
.1304 .60316 L
.13108 .60304 L
.13232 .60271 L
.13364 .60224 L
.13625 .6009 L
.1387 .59918 L
.14429 .59366 L
.14898 .58739 L
.15412 .57897 L
.16447 .5576 L
.18298 .50841 L
.20423 .44356 L
.22354 .38668 L
.23317 .3617 L
.24362 .33851 L
.25349 .32105 L
.26258 .30923 L
.26726 .30484 L
.26983 .30293 L
.27228 .30144 L
.27454 .30035 L
.27574 .29988 L
.27702 .29947 L
.27819 .29917 L
.27926 .29897 L
.28034 .29882 L
.28135 .29874 L
Mistroke
.28255 .29871 L
.28386 .29877 L
.28452 .29883 L
.28524 .29893 L
.28652 .29916 L
.28779 .29949 L
.289 .29987 L
.29127 .30078 L
.29394 .30219 L
.2964 .30381 L
.30199 .30854 L
.31164 .31998 L
.32069 .33401 L
.3413 .37461 L
.38004 .45883 L
.39045 .4777 L
.40012 .49232 L
.41021 .50399 L
.41555 .50854 L
.41831 .51044 L
.42124 .51211 L
.42378 .51326 L
.42513 .51376 L
.42658 .51421 L
.42791 .51454 L
.42913 .51478 L
.43035 .51496 L
.4315 .51506 L
.43214 .5151 L
.43284 .51512 L
.43358 .51512 L
.43427 .51509 L
.4355 .515 L
.43619 .51493 L
.43683 .51484 L
.43817 .51459 L
.43965 .51423 L
.44262 .51324 L
.44526 .51206 L
.44767 .51074 L
.45306 .50697 L
.46279 .49752 L
.47275 .48471 L
.48195 .47061 L
.50273 .43371 L
.52307 .3965 L
.53301 .37992 L
.54211 .36649 L
.55083 .35561 L
.56035 .34636 L
Mistroke
.56556 .34256 L
.5681 .34105 L
.57041 .33988 L
.57263 .33893 L
.57503 .3381 L
.57635 .33774 L
.57757 .33746 L
.57872 .33724 L
.57996 .33706 L
.58123 .33694 L
.58242 .33688 L
.58359 .33686 L
.58467 .3369 L
.58583 .33698 L
.58711 .33713 L
.58845 .33734 L
.58971 .3376 L
.59199 .33822 L
.59408 .33895 L
.5988 .34115 L
.60361 .34415 L
.60887 .34827 L
.61947 .35901 L
.63909 .38563 L
.66005 .41909 L
.67998 .45 L
.69047 .46408 L
.70157 .47637 L
.71148 .48461 L
.71712 .48799 L
.71982 .48927 L
.72238 .49027 L
.7247 .49099 L
.72592 .4913 L
.72722 .49158 L
.72842 .49179 L
.72951 .49194 L
.73061 .49205 L
.73164 .49212 L
.73285 .49216 L
.73413 .49215 L
.73522 .49209 L
.73641 .49199 L
.7377 .49184 L
.73908 .49161 L
.74157 .49104 L
.74414 .49025 L
.74688 .48919 L
.75178 .48672 L
.75705 .48329 L
Mistroke
.76286 .47863 L
.783 .45652 L
.82328 .39953 L
.84181 .37643 L
.8523 .3662 L
.86204 .35908 L
.8674 .35625 L
.87226 .35438 L
.87496 .35364 L
.87647 .35331 L
.87787 .35307 L
.8791 .35291 L
.8798 .35284 L
.88044 .35278 L
.88112 .35274 L
.88185 .35271 L
.88316 .35269 L
.88441 .35271 L
.88573 .35279 L
.88685 .3529 L
.8881 .35306 L
.88943 .35329 L
.89087 .35358 L
.89348 .35427 L
.89857 .35618 L
.90325 .35854 L
.91305 .36531 L
.92216 .37358 L
.94286 .39759 L
.97619 .44125 L
Mfstroke
[ .02 .02 ] 0 setdash
.05472 0 m
.05752 .03272 L
.06244 .07759 L
.08414 .21671 L
.10458 .31754 L
.12296 .39737 L
.14313 .4716 L
.15275 .50066 L
.16307 .52639 L
.16877 .53801 L
.17396 .54692 L
.17889 .55385 L
.18413 .55956 L
.18885 .56324 L
.19153 .56472 L
.19276 .56525 L
.19405 .56571 L
.19515 .56601 L
.19635 .56627 L
.19744 .56642 L
.19846 .56649 L
.19967 .5665 L
.20076 .56644 L
.20203 .56627 L
.20322 .56602 L
.20442 .56569 L
.20574 .56524 L
.2084 .564 L
.21087 .56249 L
.21318 .56078 L
.21839 .55587 L
.22398 .54905 L
.23411 .53302 L
.24515 .51102 L
.26526 .46293 L
.28661 .40846 L
.30595 .36426 L
.31566 .34603 L
.32614 .33028 L
.33096 .32458 L
.33604 .31967 L
.34038 .3164 L
.34285 .31493 L
.34514 .31383 L
.34766 .31289 L
.34898 .31252 L
.35039 .31221 L
.35161 .31202 L
.35276 .31191 L
.35401 .31185 L
Mistroke
.35472 .31185 L
.35537 .31187 L
.35649 .31195 L
.35754 .31208 L
.35868 .31228 L
.35991 .31256 L
.36241 .31334 L
.36468 .31428 L
.36986 .31728 L
.37546 .3218 L
.38561 .33307 L
.3951 .34675 L
.40553 .36457 L
.42658 .4058 L
.4477 .4475 L
.46697 .47933 L
.47653 .49134 L
.48157 .49646 L
.48693 .5009 L
.4916 .50389 L
.49408 .50515 L
.49675 .50624 L
.49795 .50663 L
.4992 .50699 L
.50036 .50726 L
.50144 .50747 L
.50246 .50763 L
.50355 .50775 L
.50475 .50783 L
.50585 .50785 L
.50704 .50783 L
.50815 .50775 L
.50938 .50762 L
.51069 .50741 L
.51206 .50712 L
.51337 .50677 L
.51582 .50596 L
.52021 .50394 L
.52501 .50094 L
.5358 .49139 L
.5458 .47945 L
.58495 .41624 L
.60494 .38366 L
.61545 .36908 L
.62655 .35657 L
.63136 .35223 L
.63651 .34837 L
.63947 .34653 L
.64216 .34511 L
.6449 .34391 L
Mistroke
.64744 .34302 L
.64973 .34241 L
.65088 .34216 L
.65216 .34195 L
.65344 .34179 L
.65415 .34172 L
.65481 .34168 L
.65602 .34164 L
.6573 .34165 L
.65842 .3417 L
.65961 .3418 L
.66074 .34194 L
.66176 .34211 L
.66427 .34266 L
.66664 .34338 L
.67127 .3453 L
.67637 .3482 L
.68667 .35639 L
.69621 .36645 L
.70513 .37762 L
.74397 .43534 L
.76373 .46188 L
.77491 .47365 L
.78025 .47819 L
.78527 .48177 L
.79013 .48455 L
.79269 .48573 L
.79538 .48677 L
.79766 .48748 L
.79887 .48779 L
.80016 .48807 L
.80134 .48829 L
.80242 .48844 L
.80351 .48857 L
.80454 .48865 L
.80572 .48871 L
.80702 .48872 L
.80767 .48871 L
.80838 .48868 L
.80965 .48859 L
.81091 .48845 L
.81211 .48827 L
.81437 .48782 L
.81702 .4871 L
.81947 .48624 L
.82505 .48366 L
.83012 .48056 L
.83561 .47645 L
.84556 .46718 L
.86416 .445 L
Mistroke
.8837 .41814 L
.90515 .3897 L
.915 .37851 L
.92557 .36856 L
.93069 .36465 L
.93554 .36153 L
.93986 .35927 L
.94215 .35827 L
.94463 .35735 L
.94677 .35669 L
.94873 .3562 L
.9506 .35583 L
.95258 .35555 L
.95359 .35545 L
.95466 .35537 L
.95568 .35533 L
.95661 .35532 L
.9577 .35533 L
.95888 .35538 L
.95999 .35547 L
.96102 .35558 L
.96283 .35584 L
.96453 .35618 L
.96839 .35722 L
.97215 .35863 L
.97619 .36055 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008Oooool00ol0003oooooo`00003looooo`008Ooo
ool00ol0003oooooo`00003looooo`008Oooool00ol0003oooooo`00003looooo`008Oooool3o`00
0?cooooo000Qooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0m?ooool0027ooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`3dooooo`008Oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo0?Cooooo000Qooooo`?o00001_ooool00ol0003oooooooooo`3c
ooooo`008Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo0??ooooo000Qooooo`03
o`000?oooooo000000Kooooo00?o0000ooooooooool0loooool0027ooooo00?o0000ooooool00000
o?ooool0027ooooo00?o0000ooooool00000o?ooool0027ooooo0ol0003looooo`008Oooool00ol0
003oooooo`00003looooo`006Oooool3o`0000Gooooo00?o0000ooooool000001_ooool00ol0003o
ooooooooo`3cooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooooooool0loooool001;ooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooool000001_ooool00ol0003oooooooooo`3cooooo`006_ooool00ol0003oooooooooo`04
ooooo`?o00001_ooool00ol0003oooooooooo`3cooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool0l_ooool001Wooooo0_l00006ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool0l_ooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo0?;ooooo000Qooooo`;o000000?o
ooooo`000?ooool0n_ooool0027ooooo00Co0000oooooooooooo0000noooool0027ooooo00Co0000
oooooooooooo0000noooool0027ooooo00Co0000oooooooooooo0000noooool0027ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`3aooooo`008Oooool2o`000003ooooool0003o
oooo00Kooooo00?o0000ooooooooool0lOooool0027ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`3aooooo`008Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo0?7ooooo000Qooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0lOooool0
027ooooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo0?7ooooo000Qooooo`04
o`000?ooooooooooo`000?_ooooo000Qooooo`04o`000?ooooooooooo`000?_ooooo000Qooooo`04
o`000?ooooooooooo`000?_ooooo000Qooooo`04o`000?ooooooooooo`000?_ooooo000Qooooo`;o
000000?oooooo`000?ooool01oooool00ol0003oooooooooo`3`ooooo`008Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo0?3ooooo0008ooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool0l?ooool000Oooooo00Co0000oooooooooooo00002Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo0>oooooo0005o`0000;ooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0>oooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0>oooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooool000000ol00005ooooo`05o`000?ooooooooooooooool00000n_ooool000Oooooo00Co
0000oooooooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool01Ol0
003ooooooooooooooooo00000?[ooooo0008ooooo`;o00002?ooool5o`000003ooooool0003o0000
00?o00001?ooool01Ol0003ooooooooooooooooo00000?[ooooo000Qooooo`;o00000_ooool00ol0
003oooooooooo`3hooooo`008Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooo
ooooool0k_ooool0027ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo
0>kooooo000Qooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`3^oooo
o`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0k_ooool0027ooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
k_ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0>kooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0moooool0
027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3gooooo`008Oooool2o`0000?o
oooo00?o0000ooooooooool0moooool0027ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3gooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Oooooo000Q
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3]
ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0kOooool0027ooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0kOooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0>cooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0k?oo
ool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>cooooo
0006ooooo`Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003ooooooooo
ool0000;ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo0?Kooooo
000=ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0m_ooool000kooooo0_l0
0008ooooo`Go00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0joooool0027ooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0joooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0>_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`3Zooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0j_ooool0027ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0>[ooooo000Qooooo`;o00001?ooool0
0ol0003oooooooooo`3fooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0mOooool0027ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3eooooo`008Oooool2o`0000Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`3Yooooo`008Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool3o`000;[ooooo000Qoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Zoooo
o`?o000000Coooooo`000?l0003o0000^?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2eooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Co
oooo000Qooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`?o0000Z?ooool0027ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0/_ooool000Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000_oo
ool3o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool2o`000:?ooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:3o
oooo0005o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`2Ooooo
o`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool2o`0000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooool000003oooool00ol0003oooooooooo`2Noooo
o`001oooool01?l0003oooooooooool00007ooooo`06o`000?ooooooooooooooool0003ooooo1?l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo013ooooo0_l00010ooooo`Go0000Joooool000Oooooo00Co0000
oooooooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo03gooooo0ol00003ooooo`?o0000JOooool000Sooooo
0_l00009ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0kooooo`;o00002?ooool2o`0000Sooooo1_l0001Iooooo`008Oooool2o`0000Kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo0_l0
001Nooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02Oooool2o`0003;ooooo0ol0000Nooooo`008Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo02cooooo0ol00003ooooo`?o00003?ooool4o`0000_ooooo000Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Yoooo
o`;o00002Oooool2o`0000Sooooo0_l0000?ooooo`008Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01Kooooo000Qooooo`;o00001oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000jooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05Oooool0027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Ooo
ool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo00oooooo0ol0000Dooooo`008Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`04ooooo`?o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02;ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04oooool3o`0000?ooooo0ol0000Hooooo`03o`000?oo
oooooooo013ooooo0_l00007ooooo`Go00000oooool2o`0000Cooooo000Qooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool04?ooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0oooool0027ooooo0_l00008ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04?ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003
ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo007ooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Cooooo1?l0000Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000?ooooo1?l0000Eooooo`03o`00
0?oooooooooo01Sooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00Oooool0027ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
013ooooo0_l00003ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00Ooo
ool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Gooooo1Ol00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool04Oooool01?l0003oooooooooooooool5o`0001?ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`03o`0000Cooooo0_l00004ooooo`008Oooool2
o`0000Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`008Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo000Qooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0:ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02_ooool001_oooooool00006o`0000008Oooool00ol0003oooooooooo`08oooo
o`;o00003?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ool000002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool00007ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Sooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool0027o
oooo0_l00009ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool0027ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_ooool0027ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool08oooool0027ooooo0_l0000:ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
9Oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Wooooo`008Oooool2o`0000_ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000003_o
oooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02Kooooo0_l0000=ooooo`;o00000oooool2o`0000_ooooo
00?o0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool2o`0002gooooo000Q
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o0000;oooool0027ooooo0_l0000<oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo013ooooo0_l0000nooooo`Co00000_ooool3o`00013ooooo00?o0000oooo
ooooool0;oooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`04
o`000?ooooooooooo`00043ooooo0ol00015ooooo`002?ooool2o`0000Cooooo00Co0000oooooooo
oooooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00cooooo0_l00004ooooo`03o`000?oooooooooo08Gooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo0_l0
0008ooooo`03o`000?oooooooooo07[ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool09oooool2o`0000Wooooo00?o0000ooooooooool03Oooool3o`0007gooooo0007
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`;o00003Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo0_l0
001oooooo`001oooool01?l0003oooooooooool00007ooooo`06o`000?ooooooooooooooool0003o
oooo1?l00005ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo0ol000001?oooooo0000o`000?l0002Aoooo
o`001oooool01?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`00
0008ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02gooooo0ol0002Cooooo`002?ooool2o`0000Wooooo0ol00002
ooooo`Go00001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`34ooooo`008Oooool2o`0000kooooo00?o0000oooo
ooooool04Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool0a?ooool0
027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`04o`000?oooooooooo
o`000=Oooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool01?l0
003oooooooooool0003Gooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
017ooooo0_l0003Hooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017o
oooo0_l0000>ooooo`03o`000?oooooooooo0<Oooooo000Qooooo`;o00004?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0aoooool0027ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0b?ooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0bOooool0027ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0b_ooool0027ooooo0_l0000Aooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool2o`000=Cooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=7ooooo000Qooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`?o0000d?oo
ool0027ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo0=Wooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`3Iooooo`008Oooool2o`0001?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`3Jooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0foooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
0005ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3Looooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
g?ooool000gooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Mooooo`003Ooo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l0000Fooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0g_ooool000gooooo00Co0000oooooooooooo0000
1oooool4o`0000Gooooo00?o0000ooooooooool05_ooool5o`000>7ooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo0>7ooooo000>ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0o?oo
ool0027ooooo0_l0003mooooo`008Oooool00ol0003oooooooooo`3looooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 364.875}, {496.75, 319.812}} -> {-8.97768, \
2.20476, 0.0807888, 0.0108754}}]
}, Open  ]],

Cell[TextData[{
  "To see a list of the functions that are known to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " go the Help Browser and choose "
}], "Text"],

Cell[TextData[StyleBox["Built-in Functions/Mathematical \
Functions/(Alphabetical Listing)",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{703, 796},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 232, 7, 66, "Text"],
Cell[1989, 60, 444, 14, 48, "Text"],
Cell[2436, 76, 189, 5, 28, "Text"],
Cell[2628, 83, 200, 11, 28, "Text"],
Cell[2831, 96, 382, 11, 48, "Text"],
Cell[3216, 109, 45, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[3286, 113, 101, 2, 29, "Input"],
Cell[3390, 117, 407, 11, 27, "Output"]
}, Open  ]],
Cell[3812, 131, 364, 16, 48, "Text"],

Cell[CellGroupData[{
Cell[4201, 151, 121, 2, 29, "Input"],
Cell[4325, 155, 444, 8, 153, "Output"]
}, Open  ]],
Cell[4784, 166, 390, 11, 68, "Text"],
Cell[5177, 179, 139, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[5341, 186, 114, 2, 29, "Input"],
Cell[5458, 190, 1169, 38, 123, "Output"]
}, Open  ]],
Cell[6642, 231, 358, 10, 80, "Text"],

Cell[CellGroupData[{
Cell[7025, 245, 138, 5, 47, "Input"],
Cell[7166, 252, 92, 2, 45, "Output"]
}, Open  ]],
Cell[7273, 257, 173, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[7471, 266, 88, 2, 29, "Input"],
Cell[7562, 270, 622, 19, 48, "Output"]
}, Open  ]],
Cell[8199, 292, 361, 10, 48, "Text"],

Cell[CellGroupData[{
Cell[8585, 306, 128, 6, 32, "Input"],
Cell[8716, 314, 149, 3, 48, "Output"]
}, Open  ]],
Cell[8880, 320, 332, 12, 48, "Text"],

Cell[CellGroupData[{
Cell[9237, 336, 168, 5, 71, "Input"],
Cell[9408, 343, 133, 3, 48, "Output"]
}, Open  ]],
Cell[9556, 349, 136, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[9717, 356, 208, 6, 83, "Input"],
Cell[9928, 364, 14734, 481, 138, 4454, 349, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[24677, 848, 70, 0, 28, "Text"],
Cell[24750, 850, 519, 13, 68, "Text"],

Cell[CellGroupData[{
Cell[25294, 867, 186, 6, 65, "Input"],
Cell[25483, 875, 35728, 929, 186, 8935, 593, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61248, 1809, 161, 5, 71, "Input"],
Cell[61412, 1816, 34881, 931, 186, 9050, 607, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[96308, 2750, 171, 5, 28, "Text"],
Cell[96482, 2757, 173, 4, 28, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

