(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     33061,       1170]*)
(*NotebookOutlinePosition[     35348,       1240]*)
(*  CellTagsIndexPosition[     35304,       1236]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Appendix A2. Picard Iteration", "Section"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
The following first order initial value problem \
\>", "Text"],

Cell[TextData[{
  StyleBox["y'",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  " , ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") )  ,  ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 0"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["can be reformulated as the an integral equation ", "Text"],

Cell[TextData[{
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_0\%t\), 
          RowBox[{\(f(s, y(s))\), 
            StyleBox[
              RowBox[{
                StyleBox["d",
                  FontSlant->"Italic"], "s"}]]}]}], TraditionalForm]]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "See Ledder, Appendix A.2. \nAssume that ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ") and its ",
  StyleBox["y",
    FontSlant->"Italic"],
  " partial are continuous on a rectangle containing the point (0,0). Then \
starting with  an initial \"guess\" for a solution "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(y\_0\)(t) = g(t)\)]]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["the recursive relation ", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\(y\_n\)(t)\), "=", 
        RowBox[{\(\[Integral]\_0\%t\), 
          RowBox[{\(f(s, \(y\_\(n - 1\)\)(s))\), 
            StyleBox[
              RowBox[{
                StyleBox["d",
                  FontSlant->"Italic"], "s"}]]}]}]}], 
      TraditionalForm]]]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "generates a sequence of functions converging to the solution. These \
functions are called the Picard iterates generated by ",
  StyleBox["g",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "). \n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can generate some of these iterates, use an iteratively defined process.  \
\nThe following example is taken from Ledder, see Chapter A.2, Exercise 2.   \
\n",
  StyleBox["Example",
    FontVariations->{"Underline"->True}],
  "  Obtain the first three Picard iterates for the following IVP, generated \
by the function  ",
  StyleBox["g",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = 0.    "
}], "Text"],

Cell[TextData[{
  StyleBox["y'",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = ",
  StyleBox["t",
    FontSlant->"Italic"],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(t\^2\) \(y(t)\), \ y(0) = 0\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Sketch their graphs and the graph of the exact solution. \nStart with the \
definition of the function  ",
  StyleBox["f",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell["f[t_,y_] := t + t^2*y", "Input",
  CellLabel->"In[1]:="],

Cell["Use it to define the differential equation.", "Text"],

Cell[CellGroupData[{

Cell["DE = y'[t] == f[t,y[t]]", "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(t + t\^2\ y[t]\)}]], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
Define the expression Y[0,t] to be 0. Then define Y[n,t] \
recursively as shown below.\
\>", "Text"],

Cell["\<\
Y[0,t_] := 0
Y[n_,t_] := Integrate[f[s,Y[n-1,s]], {s,0,t}]\
\>", "Input",
  CellLabel->"In[3]:="],

Cell["Here are the first three Picard iterates.", "Text"],

Cell[CellGroupData[{

Cell["Table[Y[n,t], {n,1,3} ]", "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({t\^2\/2, t\^2\/2 + t\^5\/10, 
      t\^2\/2 + t\^5\/10 + t\^8\/80}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["The solution formula is obtained next. It is not pretty.  ", "Text"],

Cell[CellGroupData[{

Cell["soln = DSolve[ {DE, y[0]==0}, y[t], t ]", "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({{y[
            t] \[Rule] \(-\(1\/3\)\)\ \[ExponentialE]\^\(t\^3\/3\)\ \((t\^2\ \
ExpIntegralE[1\/3, t\^3\/3] - 3\^\(2/3\)\ Gamma[2\/3])\)}}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["\<\
The plot of the solution, red and thick, and the three iterates, \
blue, green, black: \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ Plot[ y[t]/.soln, {t,0,2}, 
            PlotStyle->{RGBColor[1,0,0],Thickness[0.02]} ],
      Plot[ Y[1,t], {t,0,2}, PlotStyle->{RGBColor[0,0,1]} ],
      Plot[ Y[2,t], {t,0,2}, PlotStyle->{RGBColor[0,1,0]} ],
      Plot[ Y[3,t], {t,0,2} ], PlotRange->{0,5} ]\
\>", "Input",
  CellLabel->"In[7]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.123607 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02 w
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 1e-05 L
.03053 1e-05 L
.03279 2e-05 L
.03527 4e-05 L
.0379 5e-05 L
.04262 .0001 L
.04749 .00015 L
.05205 .00022 L
.06244 .00041 L
.07305 .00066 L
.08274 .00095 L
.10458 .00178 L
.12357 .00272 L
.14429 .00397 L
.18493 .00713 L
.22406 .01109 L
.26565 .01636 L
.30571 .02258 L
.34426 .02976 L
.38527 .0389 L
.42475 .04946 L
.46273 .0616 L
.50315 .07719 L
.54206 .09551 L
.58342 .11962 L
.62326 .14881 L
.66159 .18433 L
.70238 .23302 L
.74164 .29459 L
.77939 .37286 L
.8196 .48558 L
s
.8196 .48558 m
.85376 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 1e-05 L
.03053 1e-05 L
.03279 2e-05 L
.03527 4e-05 L
.0379 5e-05 L
.04262 .0001 L
.04749 .00015 L
.05205 .00022 L
.06244 .00041 L
.07305 .00066 L
.08274 .00095 L
.10458 .00178 L
.12357 .00271 L
.14429 .00396 L
.18493 .00708 L
.22406 .01093 L
.26565 .01594 L
.30571 .02166 L
.34426 .02799 L
.38527 .03561 L
.42475 .04381 L
.46273 .05251 L
.50315 .06262 L
.54206 .0732 L
.58342 .08535 L
.62326 .09794 L
.66159 .11087 L
.70238 .1255 L
.74164 .14044 L
.77939 .1556 L
.8196 .1726 L
.85828 .18979 L
.89942 .20897 L
.93905 .22831 L
.97619 .24721 L
s
0 1 0 r
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 1e-05 L
.03053 1e-05 L
.03279 2e-05 L
.03527 4e-05 L
.0379 5e-05 L
.04262 .0001 L
.04749 .00015 L
.05205 .00022 L
.06244 .00041 L
.07305 .00066 L
.08274 .00095 L
.10458 .00178 L
.12357 .00272 L
.14429 .00397 L
.18493 .00713 L
.22406 .01109 L
.26565 .01636 L
.30571 .02256 L
.34426 .02969 L
.38527 .03872 L
.42475 .04905 L
.46273 .06073 L
.50315 .0754 L
.54206 .09208 L
.58342 .11306 L
.62326 .13702 L
.66159 .16414 L
.70238 .19813 L
.74164 .23666 L
.77939 .27993 L
.8196 .33371 L
.85828 .39406 L
.89942 .4688 L
.93905 .5525 L
s
.93905 .5525 m
.96602 .61803 L
s
0 g
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 1e-05 L
.03053 1e-05 L
.03279 2e-05 L
.03527 4e-05 L
.0379 5e-05 L
.04262 .0001 L
.04749 .00015 L
.05205 .00022 L
.06244 .00041 L
.07305 .00066 L
.08274 .00095 L
.10458 .00178 L
.12357 .00272 L
.14429 .00397 L
.18493 .00713 L
.22406 .01109 L
.26565 .01636 L
.30571 .02258 L
.34426 .02976 L
.38527 .03889 L
.42475 .04944 L
.46273 .06153 L
.50315 .07703 L
.54206 .09512 L
.58342 .11868 L
.62326 .14676 L
.66159 .18014 L
.70238 .22439 L
.74164 .27786 L
.77939 .34201 L
.8196 .4277 L
.85828 .53147 L
s
.85828 .53147 m
.88386 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{157.438, 97.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002M0000HB000`400?l00000o`00003oWOooool0
02[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`?o00005_ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001Gooooo1Ol0000=ooooo`00:Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`000?oo
ooooooooo`0000gooooo000Yooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0=ooooo`00:Oooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool03?ooool002Wooooo00Co0000oooooooooooo0000
1oooool4o`0001Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`Co0000
5Oooool01Ol0003ooooooooooooooooo000000gooooo000Yooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool05oooool2o`0001Oooooo0_l00009ooooo`03o`000?oooooooooo01Ko
oooo00Go0000ooooooooooooooooo`00000=ooooo`00:_ooool2o`0000Sooooo1Ol0000Fooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool5o`0001Gooooo0ol0000>ooooo`00
WOooool009gooooo002Mooooo`003_ooool2o`000003ool00?l0003o0000083o00002_ooool0013o
oooo5Ooo000;o`000003ooooool0003ooooo01gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooooooo013ooooo
3?oo0005o`0006Sooooo000Aooooo`;o00007?ooool6ool000Go0000Hoooool0017ooooo00?o0000
ooooooooool08?ooool6ool000Ko0000GOooool0017ooooo00?o0000ooooooooool09Oooool7ool0
00Go0000F?ooool0017ooooo0_l0000/ooooo`Koo`000ol00002o`00oe?ooooo000Aooooo`03o`00
0?oooooooooo033ooooo1?oo0003o`0000Co003oC_ooool0017ooooo00?o0000ooooooooool0<ooo
ool4ool000;o00000_ooool5o`00odWooooo000Aooooo`03o`000?oooooooooo03Kooooo0ooo0003
o`0000Cooooo1?l00?m5ooooo`004Oooool2o`0003Wooooo1?oo0002o`0000Kooooo0ol00?m2oooo
o`004Oooool00ol0003oooooooooo`0kooooo`?oo`000ol00006ooooo`;o003o@?ooool0017ooooo
00?o0000ooooooooool0?Oooool4ool000;o00001_ooool3o`00ocgooooo000Aooooo`;o0000@Ooo
ool3ool000;o00001oooool4o`00ocWooooo000;ooooo`?o00000oooool00ol0003oooooooooo`12
ooooo`?oo`000_l00009ooooo`Co003o=Oooool000cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`13ooooo`Coo`000_l0000;ooooo`?o003o<_ooool000cooooo00?o0000oooooooo
ool00_ooool2o`0004Kooooo1?oo00000ol0003o0?l0ooooo`0;ooooo`;o003o<?ooool000cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`16ooooo`Coo`0000?o0000o`3o0?ooool0
3?ooool3o`00obgooooo000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?oo
ool3ool00003o`000?l0o`3o0?l000kooooo0_l00?l[ooooo`002oooool2o`0000Cooooo0_l0001;
ooooo`;oo`0000Co0000ooooool0o`3o0?l03_ooool3o`00obSooooo000<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Boooool2ool00004o`000?ooooooooooo`3o013ooooo0_l0
0?lVooooo`004Oooool00ol0003oooooooooo`1<ooooo`;oo`0000?o0000ooooooooool00_l0o`0@
ooooo`;o003o9?ooool0017ooooo00?o0000ooooooooool0COooool2ool00005o`000?oooooooooo
ooooool0o`004Oooool00ol00?ooooooooooo`0Qooooo`004Oooool2o`0004oooooo0_oo00001Ol0
003ooooooooooooooooo0?l0017ooooo0_l00?lQooooo`004Oooool00ol0003oooooooooo`1?oooo
o`;oo`000_l00002ooooo`03o`3o0?oooooooooo013ooooo0ol00?lNooooo`004Oooool00ol0003o
ooooooooo`1@ooooo`?oo`0000Co0000oooooooooooo0?l05?ooool2o`00oacooooo000Aooooo`;o
0000D_ooool3ool00004o`000?ooooooooooo`3o01Gooooo0ol00?lIooooo`004Oooool00ol0003o
ooooooooo`1Booooo`?oo`0000Co0000oooooooooooo0?l05oooool2o`00oaOooooo000Aooooo`03
o`000?oooooooooo05?ooooo0ooo00001?l0003oooooooooool0o`0Hooooo`;o003o5Oooool0017o
oooo0_l0001Eooooo`?oo`0000Co0000oooooooooooo0?l06Oooool2o`00oa?ooooo000:ooooo`Go
00000_ooool00ol0003oooooooooo`1Eooooo`;oo`0000Go0000ooooooooooooooooo`3o000Joooo
o`;o003o4Oooool000_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`1Foooo
o`;oo`0000Go0000ooooooooooooooooo`3o000Kooooo`;o003o3oooool000cooooo00?o0000oooo
ooooool00_ooool2o`0005Oooooo0ooo00001?l0003oooooooooool0o`0Mooooo`03o`00oooooooo
oooo00cooooo000=ooooo`05o`000?ooooooooooooooool00000FOooool2ool00005ooooool0003o
ooooooooool0o`00:oooool000[ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo05Oooooo0ooo00001Ol0003ooooooooooooooooo0?l002[ooooo000:ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`1Hooooo`?oo`0000Go0000oooooooooooo
ooooo`3o000Yooooo`002oooool3o`0000?ooooo0_l0001Jooooo`;oo`0000?oooooo`000?ooool0
0_ooool00ol0o`3oooooooooo`0Vooooo`004Oooool00ol0003oooooooooo`1Iooooo`?oo`0000?o
0000ooooooooool00_ooool00ol0o`3oooooooooo`0Uooooo`004Oooool00ol0003oooooooooo`1J
ooooo`;oo`0000?oooooo`000?ooool00_ooool00ol0o`3oooooooooo`0Uooooo`004Oooool2o`00
05_ooooo0ooo00000ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo02Cooooo000Aooooo`03
o`000?oooooooooo05_ooooo0_oo00000ooooooo0000ooooo`03ooooo`03o`3o0?oooooooooo02?o
oooo000Aooooo`03o`000?oooooooooo05_ooooo0ooo00000ooooooo0000ooooo`03ooooo`03o`3o
0?oooooooooo02;ooooo000Aooooo`;o0000GOooool2ool00003ooooool0003ooooo00?ooooo00?o
0?l0ooooooooool08_ooool0017ooooo00?o0000ooooooooool0G?ooool3ool00003ooooool0003o
oooo00?ooooo00?o0?l0ooooooooool08Oooool0017ooooo00?o0000ooooooooool0GOooool2ool0
0003ooooool0003ooooo00Cooooo00?o0?l0ooooooooool08?ooool0017ooooo0_l0001Nooooo`?o
o`0000?oooooo`000?ooool00oooool00ol0o`3oooooooooo`0Pooooo`002oooool3o`0000?ooooo
00?o0000ooooooooool0G_ooool2ool00003ooooool0003ooooo00Cooooo00?o0?l0ooooooooool0
7oooool000[ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo05kooooo
0ooo00000ooooooo0000ooooo`04ooooo`03o`3o0?oooooooooo01kooooo000>ooooo`04o`000?oo
ooooooooo`00067ooooo0_oo00000ooooooo0000ooooo`04ooooo`03o`3o0?oooooooooo01kooooo
000<ooooo`;o00000oooool2o`00063ooooo0ooo00000ooooooo0000ooooo`04ooooo`03o`3o0?oo
oooooooo01gooooo000>ooooo`04o`000?ooooooooooo`0006;ooooo0_oo00000ooooooo0000oooo
o`04ooooo`03o`3o0?oooooooooo01gooooo000:ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`1Pooooo`?oo`0000?oooooo`000?ooool01?ooool00ol0o`3ooooooooo
o`0Looooo`002oooool3o`0000?ooooo0_l0001Rooooo`;oo`0000?oooooo`000?ooool01Oooool0
0ol0o`3oooooooooo`0Kooooo`004Oooool00ol0003oooooooooo`1Qooooo`;oo`0000?oooooo`00
0?ooool01Oooool00ol0o`3oooooooooo`0Kooooo`004Oooool00ol0003oooooooooo`1Qooooo`?o
o`0000?oooooo`000?ooool01Oooool00ol0o`3oooooooooo`0Jooooo`004Oooool2o`0006?ooooo
0_oo00000ooooooo0000ooooo`05ooooo`03o`3o0?oooooooooo01[ooooo000Aooooo`03o`000?oo
oooooooo06;ooooo0_oo0002ooooo`03o`000?oooooooooo00Cooooo00?o0?l0ooooooooool06Ooo
ool0017ooooo00?o0000ooooooooool0H_ooool3ool00003ooooool0003ooooo00Kooooo00?o0?l0
ooooooooool06?ooool0017ooooo0_l0001Tooooo`;oo`000_ooool00ol0003oooooooooo`04oooo
o`03o`3o0?oooooooooo01Sooooo000Aooooo`03o`000?oooooooooo06?ooooo0_oo0002ooooo`03
o`000?oooooooooo00Gooooo00?o0?l0ooooooooool05oooool0017ooooo00?o0000ooooooooool0
Hoooool3ool00003ooooool0003ooooo00Kooooo00?o0?l0ooooooooool05oooool0017ooooo00?o
0000ooooooooool0I?ooool2ool000;ooooo00?o0000ooooooooool01Oooool00ol0o`3ooooooooo
o`0Fooooo`003?ooool3o`0000;ooooo0_l0001Uooooo`;oo`000_ooool00ol0003oooooooooo`05
ooooo`03o`3o0?oooooooooo01Kooooo000=ooooo`05o`000?ooooooooooooooool00000I_ooool3
ool00003ooooool0003ooooo00Oooooo00?o0?l0ooooooooool05Oooool000[ooooo1Ol00002oooo
o`03o`000?oooooooooo06Gooooo0_oo0002ooooo`03o`000?oooooooooo00Gooooo00?o0?l0oooo
ooooool05Oooool000[ooooo00Co0000oooooooooooo00000oooool2o`0006Kooooo0_oo0002oooo
o`03o`000?oooooooooo00Kooooo00?o0?l0ooooooooool05?ooool000_ooooo00?o0000ooooool0
00000oooool00ol0003oooooooooo`1Uooooo`;oo`000_ooool00ol0003oooooooooo`06ooooo`03
o`3o0?oooooooooo01Cooooo000<ooooo`;o00000oooool00ol0003oooooooooo`1Uooooo`?oo`00
0_ooool00ol0003oooooooooo`06ooooo`03o`3o0?oooooooooo01?ooooo000=ooooo`04o`000?oo
ooooooooooooo`;o0000Ioooool2ool000;ooooo00?o0000ooooooooool01oooool00ol0o`3ooooo
ooooo`0Booooo`004Oooool00ol0003oooooooooo`1Vooooo`;oo`000_ooool00ol0003ooooooooo
o`07ooooo`03o`3o0?oooooooooo01;ooooo000Aooooo`03o`000?oooooooooo06Kooooo0_oo0003
ooooo`03o`000?oooooooooo00Oooooo00?o0?l0ooooooooool04Oooool0017ooooo0_l0001Woooo
o`?oo`000_ooool00ol0003oooooooooo`07ooooo`03o`3o0?oooooooooo017ooooo000Aooooo`03
o`000?oooooooooo06Oooooo0_oo0002ooooo`03o`000?oooooooooo00Sooooo00?o0?l0oooooooo
ool04?ooool0017ooooo00?o0000ooooooooool0Ioooool2ool000?ooooo00?o0000ooooooooool0
1oooool00ol0o`3oooooooooo`0@ooooo`004Oooool00ol0003oooooooooo`1Wooooo`;oo`000ooo
ool00ol0003oooooooooo`08ooooo`03o`3o0?oooooooooo00oooooo000Aooooo`;o0000J?ooool2
ool000?ooooo00?o0000ooooooooool02?ooool00ol0o`3oooooooooo`0?ooooo`004Oooool00ol0
003oooooooooo`1Wooooo`?oo`000oooool00ol0003oooooooooo`07ooooo`03o`3o0?oooooooooo
00oooooo000Aooooo`03o`000?oooooooooo06Sooooo0_oo0003ooooo`03o`000?oooooooooo00So
oooo00?o0?l0ooooooooool03_ooool000_ooooo0ol00003ooooo`;o0000JOooool2ool000?ooooo
00?o0000ooooooooool02?ooool00ol0o`3oooooooooo`0>ooooo`002_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool0J?ooool2ool000?ooooo00?o0000ooooooooool0
2?ooool00ol0o`3oooooooooo`0>ooooo`003_ooool01?l0003oooooooooool0001Zooooo`?oo`00
0oooool00ol0003oooooooooo`08ooooo`03o`3o0?oooooooooo00gooooo000>ooooo`03o`000?oo
oooooooo00;o0000J_ooool2ool000?ooooo00?o0000ooooooooool02?ooool00ol0o`3ooooooooo
o`0=ooooo`002_ooool4o`0008oooooo000:ooooo`03o`000?oooooooooo093ooooo000:ooooo`Go
0000S_ooool009gooooo0000\
\>"],
  ImageRangeCache->{{{0, 156.438}, {96.25, 0}} -> {-0.287749, -0.655959, \
0.0160015, 0.0616452}}]
}, Open  ]],

Cell[TextData[{
  "The next output reveals what appears to be a bug in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The Picard iterates are the partial sums for the Taylor series for the \
solution yet ",
  StyleBox["Series",
    FontWeight->"Bold"],
  " generates a series approximation to the solution that does not converge \
to the correct solution curve."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Series[ y[t]/.soln[[1]], {t,0,8} ];
Normal[%]\
\>", "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(t\^\(10/3\)\/\(2\ 3\^\(2/3\)\) + t\^\(19/3\)\/\(10\ 3\^\(2/3\)\) + 
      Gamma[2\/3]\/3\^\(1/3\) - 
      1\/3\ t\^\(4/3\)\ Gamma[
          2\/3] + \(t\^3\ Gamma[2\/3]\)\/\(3\ 3\^\(1/3\)\) - 
      1\/9\ t\^\(13/3\)\ Gamma[
          2\/3] + \(t\^6\ Gamma[2\/3]\)\/\(18\ 3\^\(1/3\)\) - 
      1\/54\ t\^\(22/3\)\ Gamma[2\/3]\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[ %, {t,0,2}, PlotRange->{0,5} ]", "Input",
  CellLabel->"In[23]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.123607 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11605 m
.02499 .11603 L
.02605 .11601 L
.02846 .11594 L
.03279 .11577 L
.04262 .11531 L
.06244 .11412 L
.10458 .11108 L
.14451 .10799 L
.18292 .10518 L
.22379 .10264 L
.24411 .10163 L
.26314 .10089 L
.27249 .1006 L
.28137 .10037 L
.28626 .10027 L
.29161 .10018 L
.29647 .10011 L
.30098 .10006 L
.30362 .10004 L
.30605 .10003 L
.30733 .10002 L
.30872 .10002 L
.30943 .10002 L
.31018 .10002 L
.31089 .10001 L
.31154 .10001 L
.31282 .10001 L
.31399 .10002 L
.31528 .10002 L
.31594 .10002 L
.31666 .10002 L
.31786 .10003 L
.31915 .10003 L
.3215 .10005 L
.32376 .10007 L
.32623 .10009 L
.33121 .10016 L
.33582 .10025 L
.34011 .10034 L
.35063 .10064 L
.36056 .10103 L
.37915 .10201 L
.39916 .10351 L
.41762 .10531 L
.43797 .10782 L
.45702 .1107 L
.49491 .11816 L
.53373 .12851 L
.57501 .14302 L
Mistroke
.61477 .16099 L
.65301 .18251 L
.69371 .2106 L
.73289 .24333 L
.77453 .2849 L
.81465 .33218 L
.85325 .38483 L
.89431 .44886 L
.93384 .51848 L
.97187 .59259 L
.97619 .60144 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{156, 96.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002L0000H2000`400?l00000o`00003oW?ooool0
02Wooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`?o00005_ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001Gooooo1Ol0000=ooooo`00:?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`000?oo
ooooooooo`0000gooooo000Xooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0=ooooo`00:?ooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool03?ooool002Sooooo00Co0000oooooooooooo0000
1oooool4o`0001Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`Co0000
5Oooool01Ol0003ooooooooooooooooo000000gooooo000Xooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool05oooool2o`0001Oooooo0_l00009ooooo`03o`000?oooooooooo01Ko
oooo00Go0000ooooooooooooooooo`00000=ooooo`00:Oooool2o`0000Sooooo1Ol0000Fooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool5o`0001Gooooo0ol0000>ooooo`00
W?ooool009cooooo002Looooo`003_oooon3o`0000_ooooo000Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool0R?ooool0017ooooo0_l0
0029ooooo`004Oooool00ol0003oooooooooo`28ooooo`004Oooool00ol0003oooooooooo`28oooo
o`004Oooool2o`0008Wooooo000Aooooo`03o`000?oooooooooo08Sooooo000Aooooo`03o`000?oo
oooooooo08Sooooo000Aooooo`;o0000ROooool0017ooooo00?o0000ooooooooool0R?ooool0017o
oooo00?o0000ooooooooool0R?ooool0017ooooo00?o0000ooooooooool0R?ooool000_ooooo0ol0
0003ooooo`;o00004OoooolSo`0005Gooooo000<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool;o`0002?ooooo1ol0001>ooooo`003?ooool00ol0003oooooooooo`02oooo
o`So0000=Oooool5o`0004Wooooo000<ooooo`03o`000?oooooooooo00;ooooo0_l00010ooooo`?o
0000A_ooool000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`?o0000
@oooool000_ooooo0_l00004ooooo`03o`000?oooooooooo04Gooooo0_l00011ooooo`003?ooool0
0ol0003oooooooooo`02ooooo`;o0000B?ooool2o`0003oooooo000Aooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0??ooool0017ooooo00?o0000ooooooooool0B_ooool2o`0003co
oooo000Aooooo`;o0000COooool3o`0003Wooooo000Aooooo`03o`000?oooooooooo04oooooo0_l0
000gooooo`004Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo03Cooooo000Aoooo
o`;o0000Doooool00ol0003oooooooooo`0cooooo`004Oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo03;ooooo000Aooooo`03o`000?oooooooooo05Cooooo0_l0000booooo`004Ooo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02oooooo000:ooooo`Go00000_ooool2
o`0005Sooooo0_l0000_ooooo`002oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool0;?ooool000cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo02_ooooo000=ooooo`04o`000?oooooooooooooo
o`;o0000Foooool00ol0003oooooooooo`0[ooooo`002_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Zooooo`002_ooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Yoooo
o`002oooool3o`0000?ooooo0_l0001Nooooo`03o`000?oooooooooo02Sooooo000Aooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool09oooool0017ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`0Vooooo`004Oooool2o`00063ooooo00?o0000ooooooooool09_ooool0
017ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Uooooo`004Oooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02Cooooo000Aooooo`;o0000Hoooool00ol0003ooooo
ooooo`0Sooooo`004Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02;ooooo000A
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool08Oooool0017ooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0Qooooo`002oooool3o`0000?ooooo0_l0001Vooooo`03
o`000?oooooooooo023ooooo000:ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo01oooooo000>ooooo`04o`000?ooooooooooo`0006Wo
oooo00?o0000ooooooooool07_ooool000cooooo0_l00003ooooo`;o0000J?ooool00ol0003ooooo
ooooo`0Nooooo`003_ooool01?l0003oooooooooool0001Zooooo`03o`000?oooooooooo01gooooo
000:ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01cooooo000;ooooo`?o00000oooool2o`0006[ooooo00?o0000ooooooooool07?oo
ool0017ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Kooooo`004Oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo01[ooooo000Aooooo`;o0000K?ooool00ol0003o
ooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Wooooo
000Aooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool06Oooool0017ooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Hooooo`004Oooool2o`0006oooooo00?o0000oooo
ooooool05oooool0017ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Gooooo`00
4Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01Kooooo000<ooooo`?o00000_oo
ool2o`00077ooooo00?o0000ooooooooool05Oooool000gooooo00Go0000ooooooooooooooooo`00
001booooo`03o`000?oooooooooo01Gooooo000:ooooo`Go00000_ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo01Cooooo000:ooooo`04o`000?ooooooooooo`0000?ooooo0_l0001c
ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`0Cooooo`003?ooool2o`0000?ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`0Booooo`003Oooool01?l0003oooooooooooooool2o`0007Go
oooo00?o0000ooooooooool04Oooool0017ooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`0Aooooo`004Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo013ooooo000A
ooooo`;o0000M_ooool00ol0003oooooooooo`0@ooooo`004Oooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo00oooooo000Aooooo`03o`000?oooooooooo07Kooooo00?o0000oooooooo
ool03oooool0017ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0>ooooo`004Ooo
ool2o`0007Sooooo00?o0000ooooooooool03_ooool0017ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`0=ooooo`004Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
00gooooo000;ooooo`?o00000oooool2o`0007[ooooo00?o0000ooooooooool03?ooool000[ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool03?ooool000kooooo00Co0000oooooooooooo0000R_ooool000kooooo00?o0000ooooooooool0
0_l00029ooooo`002_ooool4o`0008kooooo000:ooooo`03o`000?oooooooooo08oooooo000:oooo
o`Go0000SOooool009cooooo0000\
\>"],
  ImageRangeCache->{{{0, 155}, {95.375, 0}} -> {-0.290014, -0.661888, \
0.0161726, 0.062304}}]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{703, 796},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 123, 2, 33, "Text"],
Cell[1880, 55, 72, 2, 28, "Text"],
Cell[1955, 59, 438, 24, 28, "Text"],
Cell[2396, 85, 64, 0, 28, "Text"],
Cell[2463, 87, 429, 17, 30, "Text"],
Cell[2895, 106, 402, 15, 80, "Text"],
Cell[3300, 123, 132, 3, 24, "Text"],
Cell[3435, 128, 39, 0, 28, "Text"],
Cell[3477, 130, 381, 11, 28, "Text"],
Cell[3861, 143, 744, 24, 143, "Text"],
Cell[4608, 169, 304, 14, 28, "Text"],
Cell[4915, 185, 186, 6, 60, "Text"],
Cell[5104, 193, 62, 1, 31, "Input"],
Cell[5169, 196, 59, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[5253, 200, 64, 1, 31, "Input"],
Cell[5320, 203, 210, 6, 30, "Output"]
}, Open  ]],
Cell[5545, 212, 110, 3, 28, "Text"],
Cell[5658, 217, 107, 4, 51, "Input"],
Cell[5768, 223, 57, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[5850, 227, 64, 1, 23, "Input"],
Cell[5917, 230, 125, 3, 28, "Output"]
}, Open  ]],
Cell[6057, 236, 74, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[6156, 240, 80, 1, 23, "Input"],
Cell[6239, 243, 200, 4, 30, "Output"]
}, Open  ]],
Cell[6454, 250, 111, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[6590, 257, 314, 7, 73, "Input"],
Cell[6907, 266, 14673, 500, 108, 5220, 378, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[21595, 769, 387, 10, 50, "Text"],

Cell[CellGroupData[{
Cell[22007, 783, 95, 4, 36, "Input"],
Cell[22105, 789, 385, 8, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22527, 802, 78, 1, 23, "Input"],
Cell[22608, 805, 10437, 362, 107, 3821, 275, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

