(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1303651,      43798]*)
(*NotebookOutlinePosition[   1305938,      43868]*)
(*  CellTagsIndexPosition[   1305894,      43864]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Appendix A3. Partial Differential Equations", \
"Section"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["The wave equation", "Subsubsection"]], "Text"],

Cell[TextData[{
  " The following entries show how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can be used to plot approximations to solutions of the wave equation  on \
a finite domain: A string of length L with ends clamped at ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "= 0 and ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = ",
  StyleBox["L",
    FontSlant->"Italic"],
  ". Let ",
  StyleBox["u",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ",",
  StyleBox["t",
    FontSlant->"Italic"],
  ") denote the vertical  displacement of the string at point  ",
  StyleBox["x",
    FontSlant->"Italic"],
  " at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  ". For small vibrations ",
  StyleBox["u",
    FontSlant->"Italic"],
  " satisfies the wave equation "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`u\_\(t\ t\) = \(c\^2\) u\_\(x\ x\)\)]]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "The letter  ",
  StyleBox["c",
    FontSlant->"Italic"],
  " denotes a positive constant determined by the characteristics of the \
string. Separation of variables  leads to solutions of the following form "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(U\_N\)(x, 
          t) = \[Sum]\+\(n = 1\)\%N\((\(A\_n\) \(cos(\(c\ n\ \[Pi]\ t\)\/L)\) \
+ \(B\_n\) \(sin(\(c\ n\ \[Pi]\ t\)\/L)\))\)\ \(sin(\(n\ \[Pi]\ \
x\)\/L)\)\)]],
  " ,  ",
  StyleBox["N",
    FontSlant->"Italic"],
  " a positive integer. "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
See Ledder, Chapter 8, Section 3. \
\>", "Text"],

Cell[TextData[StyleBox["Set the string into motion", "Subsubsection"]], "Text"],

Cell[TextData[{
  " The string is set into motion at  ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "= 0 by giving it an initial shape  ",
  StyleBox["f",
    FontSlant->"Italic"],
  " (",
  StyleBox["x",
    FontSlant->"Italic"],
  ")  and an initial velocity distribution, ",
  StyleBox[" g",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ").  Thus the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  " should be chosen so that the function"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(U\_N\)(x, 
        0) = \[Sum]\+\(n = 1\)\%N A\_n\ \(sin(\(n\ \[Pi]\ x\)\/L)\)\)]]], \
"Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "approximates ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ") on [0 , ",
  StyleBox["L",
    FontSlant->"Italic"],
  " ] and the function "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[PartialD]\_t\ \(\(U\_N\)(x, 
          0)\) = \[Sum]\+\(n = 1\)\%N\( c\ n\ \[Pi]\ B\_n\)\/L\ \(sin(\(n\ \
\[Pi]\ x\)\/L)\)\)]]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "approximates ",
  StyleBox["g",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  "). Consequently, ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " is the Fourier sine series coefficient for ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ") and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\ n\ \[Pi]\ B\_n\)\/L\)]],
  " is the Fourier  sine series coefficient for ",
  StyleBox["g",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ").  \nThe following entries define the functions ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["g",
    FontSlant->"Italic"],
  ", calculate ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  ", then create various solution curves. We  assume that ",
  StyleBox["L",
    FontSlant->"Italic"],
  " = 1, ",
  StyleBox["c",
    FontSlant->"Italic"],
  " = 1 and the string is initially stretched \"tent like\" over the ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis  with the shape "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = 
        0.2\ x\  + \((0.2\ \((1 - x)\) - 0.2\ x)\) \(UnitStep(x - 0.5)\)\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
See the following definitions and plot.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
L = 1; c = 1;
f[x_] := 0.2*x + (0.2*(1-x)-0.2*x)*UnitStep[x-0.5];
Plot[ f[x], {x,0,1}, PlotRange->{0,0.125}, AspectRatio->1/3 ]\
\>", "Input",
  CellLabel->"In[35]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 2.66667 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .05333 -24 -4.5 ]
[.01131 .05333 0 4.5 ]
[.01131 .10667 -24 -4.5 ]
[.01131 .10667 0 4.5 ]
[.01131 .16 -24 -4.5 ]
[.01131 .16 0 4.5 ]
[.01131 .21333 -24 -4.5 ]
[.01131 .21333 0 4.5 ]
[.01131 .26667 -18 -4.5 ]
[.01131 .26667 0 4.5 ]
[.01131 .32 -24 -4.5 ]
[.01131 .32 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .05333 m
.03006 .05333 L
s
[(0.02)] .01131 .05333 1 0 Mshowa
.02381 .10667 m
.03006 .10667 L
s
[(0.04)] .01131 .10667 1 0 Mshowa
.02381 .16 m
.03006 .16 L
s
[(0.06)] .01131 .16 1 0 Mshowa
.02381 .21333 m
.03006 .21333 L
s
[(0.08)] .01131 .21333 1 0 Mshowa
.02381 .26667 m
.03006 .26667 L
s
[(0.1)] .01131 .26667 1 0 Mshowa
.02381 .32 m
.03006 .32 L
s
[(0.12)] .01131 .32 1 0 Mshowa
.125 Mabswid
.02381 .01333 m
.02756 .01333 L
s
.02381 .02667 m
.02756 .02667 L
s
.02381 .04 m
.02756 .04 L
s
.02381 .06667 m
.02756 .06667 L
s
.02381 .08 m
.02756 .08 L
s
.02381 .09333 m
.02756 .09333 L
s
.02381 .12 m
.02756 .12 L
s
.02381 .13333 m
.02756 .13333 L
s
.02381 .14667 m
.02756 .14667 L
s
.02381 .17333 m
.02756 .17333 L
s
.02381 .18667 m
.02756 .18667 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .22667 m
.02756 .22667 L
s
.02381 .24 m
.02756 .24 L
s
.02381 .25333 m
.02756 .25333 L
s
.02381 .28 m
.02756 .28 L
s
.02381 .29333 m
.02756 .29333 L
s
.02381 .30667 m
.02756 .30667 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .02164 L
.10458 .04523 L
.14415 .06739 L
.18221 .0887 L
.22272 .11139 L
.26171 .13322 L
.30316 .15643 L
.34309 .17879 L
.3815 .20031 L
.42237 .22319 L
.46172 .24523 L
.48147 .25629 L
.49012 .26113 L
.49468 .26369 L
.49719 .26509 L
.49842 .26578 L
.49955 .26642 L
.50085 .26619 L
.50154 .26581 L
.50226 .2654 L
.50471 .26403 L
.5095 .26135 L
.51896 .25605 L
.53984 .24436 L
.57781 .22309 L
.61824 .20045 L
.65714 .17867 L
.6985 .1555 L
.73835 .13319 L
.77668 .11173 L
.81746 .08889 L
.85673 .0669 L
.89448 .04576 L
.93468 .02324 L
.97337 .00158 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[35]:=",
  ImageSize->{259, 86.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000430000ER000`400?l00000o`00003oooooool4
ooooo`00Aoooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Jooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00006_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0001_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Pooooo`?o00004?ooool0
04Kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Iooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000006Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000008?ooool00ol0003oooooooooo`0?ooooo`00A_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00001oooool5o`0001Wooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001Wooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool03ooo
ool004Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Hooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00006_ooool01?l0003oooooooooool00007oooo
o`Co00006_ooool01?l0003oooooooooool00008ooooo`?o00008Oooool00ol0003oooooooooo`0?
ooooo`00A_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000006Ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000001[ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Pooooo`03o`000?oooooooooo00oooooo0016ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Iooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool06_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000007oooool2o`00017ooooo0017oooo
o`;o00002Oooool3o`0001_ooooo0_l0000;ooooo`03o`000?oooooooooo01Wooooo0_l0000:oooo
o`;o00006oooool2o`0000Wooooo0ol0000Qooooo`03o`000?oooooooooo00oooooo003oooooo`Co
oooo003oooooo`Cooooo003oooooo`Cooooo003oooooo`Cooooo000OooooomWo00002oooool002Go
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
013ooooo000Uooooo`03o`000?oooooooooo00;o0000`oooool2o`0001Cooooo000Uooooo`03o`00
0?oooooooooo00;ooooo0_l0002oooooo`;o00005_ooool002Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooo
oooo00Gooooo0_l0002iooooo`;o00006Oooool002Gooooo00?o0000ooooooooool01oooool2o`00
0;Gooooo0_l0000Kooooo`009Oooool00ol0003oooooooooo`09ooooo`;o0000/Oooool2o`0001go
oooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0[Oooool00ol0003ooooo
ooooo`0Mooooo`003?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0
0004ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`;o00008?ooool000_ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool03_ooool2o`000:Oooooo0_l0000Rooooo`002oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0@ooooo`;o0000Xoooool2o`0002Cooooo000;ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`;o00004oooool2
o`0009oooooo0_l0000Vooooo`002oooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0V_ooool2o`0002Sooooo000;ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05Oooool2o`0009Sooooo0_l0000Zooooo`003?ooool2o`0000[ooooo0_l00003ooooo`?o
00001Oooool00ol0003oooooooooo`0Gooooo`;o0000UOooool00ol0003oooooooooo`0Zooooo`00
9Oooool00ol0003oooooooooo`0Iooooo`;o0000TOooool2o`0002gooooo000Uooooo`03o`000?oo
oooooooo01_ooooo0_l0002=ooooo`;o0000;oooool002Gooooo00?o0000ooooooooool07Oooool2
o`0008[ooooo00?o0000ooooooooool0;oooool002Gooooo00?o0000ooooooooool07oooool2o`00
08Kooooo0_l0000booooo`009Oooool00ol0003oooooooooo`0Qooooo`;o0000P_ooool2o`0003Co
oooo000<ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`0000Cooooo
00?o0000ooooooooool08oooool2o`0007kooooo0_l0000fooooo`002oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool000_ooooo
00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Go00001?ooool2o`00
02Oooooo0_l0001hooooo`;o0000>Oooool000_ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Xooooo`;o0000M?ooool2o`0003_ooooo000;ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0kooooo`002oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l00005ooooo`03o`000?oooooooooo02_o
oooo0_l0001^ooooo`;o0000?_ooool000cooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02gooooo0_l0001Zooooo`;o0000@?ooool002Gooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo043ooooo000U
ooooo`03o`000?oooooooooo033ooooo0_l0001Tooooo`;o0000@oooool002Gooooo00?o0000oooo
ooooool0<_ooool2o`00063ooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`0dooooo`;o
0000G?ooool2o`0004Oooooo000<ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o0000
0oooool3o`0000Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo04Oooooo000;ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool2o`00
05Kooooo0_l0001:ooooo`002oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo0_l0
001Booooo`;o0000C?ooool000_ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
ool0003ooooo00Co00001Oooool2o`0003cooooo00?o0000ooooooooool0COooool2o`0004kooooo
000;ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008oooo
o`03o`000?oooooooooo03cooooo0_l0001;ooooo`;o0000D?ooool000_ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0?_ooool2o`0004Sooooo00?o0000ooooooooool0D?ooool000cooooo0_l0000:oooo
o`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`13oooo
o`;o0000Doooool002Gooooo00?o0000ooooooooool0@Oooool2o`00047ooooo0_l0001Eooooo`00
9Oooool00ol0003oooooooooo`13ooooo`;o0000?Oooool2o`0005Oooooo000Uooooo`03o`000?oo
oooooooo04Gooooo0ol0000hooooo`;o0000FOooool002Gooooo00?o0000ooooooooool0B?ooool2
o`0003Cooooo0_l0001Kooooo`003?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`00
00?ooooo0ol00005ooooo`03o`000?oooooooooo04[ooooo0_l0000`ooooo`;o0000GOooool000_o
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1<ooooo`;o0000;?ooool2o`0005oooooo000;
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0C_ooool2o`0002Sooooo0_l0001Qooooo`00
2oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol00005oooo
o`;o0000DOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo067ooooo000;ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0DOooool2o`0002;ooooo0_l0001Tooooo`002oooool0
1?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05?ooooo0_l0000Nooooo`;o0000I_ooool000cooooo
0_l0000:ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo06Kooooo000Uooooo`03o`000?oooooooooo05Kooooo0_l0
000Hooooo`;o0000JOooool002Gooooo00?o0000ooooooooool0F?ooool2o`0001Cooooo0_l0001[
ooooo`009Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0Joooool002Gooooo00?o0000ooooooooool0Foooool2o`0000kooooo0_l0001^ooooo`00
9Oooool00ol0003oooooooooo`1Mooooo`;o00002Oooool3o`00073ooooo000Booooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1Oooooo`;o00001Ooo
ool2o`0007?ooooo000Aooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Qooooo`05o`000?ooooooooooooooool00000MOooool0017ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000Hoooool3o`0007Kooooo
000Aooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3Kooooo`004Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0foooool0017ooooo00Co0000oooooooooooo00002?ooool2o`0000Kooooo
00?o0000ooooooooool0foooool001;ooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0foooool002Gooooo00?o0000ooooooooool0foooool002Gooooo00?o0000oooo
ooooool0foooool002Gooooo00?o0000ooooooooool0foooool002Gooooo00?o0000ooooooooool0
foooool000cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00001?oo
ool00ol0003oooooooooo`3Kooooo`002oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3Kooooo`002ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3Kooooo`002oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`000=cooooo000;ooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0foooool000_ooooo00Co0000oooooooooooo00002?ooool2o`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0=_ooooo000<ooooo`;o
00002_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3Kooooo`00
ooooool4ooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 335.875}, {191.062, 105.875}} -> {-0.560015, \
0.16381, 0.00487014, 0.00173934}}]
}, Open  ]],

Cell["\<\
Set the string into motion with a finger flick at a point one \
quarter of the way from the left endpoint \
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`g(x) = 0.1\ \(DirecDelta(x - 0.25)\)\)]]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["g[x_] := 0.1*DiracDelta[x - 0.25]", "Input",
  CellLabel->"In[34]:=",
  FormatType->InputForm],

Cell["\<\
You may, of course, change these to fit any situation that you \
would like to explore. \
\>", "Text"],

Cell["\<\
The next entries calculate the formulas for the coefficients An and \
Bn.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
An = 2/L*Integrate[f[x]*Sin[n*Pi*x/L], {x,0,L} ]
Bn = L/(c*n*Pi)*Integrate[g[x]*Sin[n*Pi*x/L], {x,0,L} ]\
\>", "Input",
  CellLabel->"In[39]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(2\ \((\(0.`\ Cos[1.5707963267948966`\ n]\)\/n + \(0.`\ Cos[n\ \
\[Pi]]\)\/n + \(0.04052847345693511`\ Sin[1.5707963267948966`\ n]\)\/n\^2 - \
\(0.020264236728467555`\ Sin[n\ \[Pi]]\)\/n\^2)\)\)], "Output",
  CellLabel->"Out[39]="],

Cell[BoxData[
    \(\(0.03183098861837907`\ Sin[0.7853981633974483`\ n]\)\/n\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[TextData[{
  "This is the definition of the function ",
  StyleBox["U",
    FontSlant->"Italic"],
  " as a function on ",
  StyleBox["N, x, t ",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell["\<\
U[N_,x_,t_] := Sum[ (An*Cos[c*n*Pi*t/L] + \
Bn*Sin[c*n*Pi*t/L])*Sin[n*Pi*x/L], {n,1,N}]\
\>", "Input",
  CellLabel->"In[43]:=",
  FormatType->InputForm],

Cell[TextData[{
  "The first plot checks that the coefficients are correct for the velocily \
function  g. (A check for the shape  function",
  StyleBox[" f",
    FontSlant->"Italic"],
  "  is made when we plot ",
  StyleBox["U",
    FontSlant->"Italic"],
  " at ",
  StyleBox["t",
    FontSlant->"Italic"],
  "  =0 below). "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ {g[x], Sum[ c*n*Pi*Bn/L*Sin[n*Pi*x/L], {n,1,30}]}, {x,0,L}, \
PlotRange->{-0.5,2}, PlotLabel->\"Initial Velocity\"]\
\>", "Input",
  CellLabel->"In[50]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.123607 0.247214 [
[.21429 .11111 -9 -9 ]
[.21429 .11111 9 0 ]
[.40476 .11111 -9 -9 ]
[.40476 .11111 9 0 ]
[.59524 .11111 -9 -9 ]
[.59524 .11111 9 0 ]
[.78571 .11111 -9 -9 ]
[.78571 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .12361 m
.21429 .12986 L
s
[(0.2)] .21429 .11111 0 1 Mshowa
.40476 .12361 m
.40476 .12986 L
s
[(0.4)] .40476 .11111 0 1 Mshowa
.59524 .12361 m
.59524 .12986 L
s
[(0.6)] .59524 .11111 0 1 Mshowa
.78571 .12361 m
.78571 .12986 L
s
[(0.8)] .78571 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.2619 .12361 m
.2619 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.7381 .12361 m
.7381 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.02381 0 m
.03006 0 L
s
[(-0.5)] .01131 0 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.5)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(1)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(1.5)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -119.25 -12.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 36.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
71.250 21.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
71.250 21.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Initial) show
119.250 21.250 moveto
(Velocity) show
167.250 21.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.02499 .12361 L
.02605 .12361 L
.02729 .12361 L
.02846 .12361 L
.02954 .12361 L
.03053 .12361 L
.03163 .12361 L
.03279 .12361 L
.03395 .12361 L
.0352 .12361 L
.03638 .12361 L
.03746 .12361 L
.03873 .12361 L
.03944 .12361 L
.04011 .12361 L
.04132 .12361 L
.04262 .12361 L
.04327 .12361 L
.04396 .12361 L
.04519 .12361 L
.04588 .12361 L
.04652 .12361 L
.04722 .12361 L
.04797 .12361 L
.04862 .12361 L
.04933 .12361 L
.05061 .12361 L
.05186 .12361 L
.05302 .12361 L
.05414 .12361 L
.05519 .12361 L
.05634 .12361 L
.05759 .12361 L
.05882 .12361 L
.06012 .12361 L
.06123 .12361 L
.06244 .12361 L
.06315 .12361 L
.06381 .12361 L
.06453 .12361 L
.06529 .12361 L
.06657 .12361 L
.06729 .12361 L
.06797 .12361 L
.06924 .12361 L
.0704 .12361 L
.07103 .12361 L
.07173 .12361 L
.073 .12361 L
Mistroke
.07376 .12361 L
.07448 .12361 L
.07513 .12361 L
.07583 .12361 L
.0766 .12361 L
.0774 .12361 L
.07809 .12361 L
.07885 .12361 L
.07956 .12361 L
.0802 .12361 L
.08095 .12361 L
.08166 .12361 L
.08291 .12361 L
.08362 .12361 L
.08427 .12361 L
.08544 .12361 L
.08669 .12361 L
.08787 .12361 L
.08896 .12361 L
.09016 .12361 L
.09148 .12361 L
.09214 .12361 L
.09285 .12361 L
.09413 .12361 L
.09483 .12361 L
.09548 .12361 L
.09619 .12361 L
.09695 .12361 L
.09821 .12361 L
.09893 .12361 L
.09961 .12361 L
.10086 .12361 L
.10201 .12361 L
.10333 .12361 L
.10458 .12361 L
.10572 .12361 L
.10694 .12361 L
.1081 .12361 L
.10916 .12361 L
.11033 .12361 L
.11162 .12361 L
.11227 .12361 L
.11297 .12361 L
.11422 .12361 L
.11491 .12361 L
.11554 .12361 L
.11624 .12361 L
.11698 .12361 L
.11822 .12361 L
.11892 .12361 L
Mistroke
.11958 .12361 L
.12081 .12361 L
.12194 .12361 L
.12323 .12361 L
.12446 .12361 L
.12562 .12361 L
.12668 .12361 L
.12789 .12361 L
.12903 .12361 L
.13009 .12361 L
.13107 .12361 L
.13214 .12361 L
.13327 .12361 L
.13441 .12361 L
.13564 .12361 L
.1368 .12361 L
.13785 .12361 L
.13909 .12361 L
.13979 .12361 L
.14043 .12361 L
.14162 .12361 L
.14288 .12361 L
.14402 .12361 L
.14526 .12361 L
.14656 .12361 L
.14777 .12361 L
.14891 .12361 L
.14994 .12361 L
.15113 .12361 L
.15226 .12361 L
.15348 .12361 L
.15478 .12361 L
.15589 .12361 L
.15711 .12361 L
.15842 .12361 L
.15915 .12361 L
.15982 .12361 L
.16113 .12361 L
.16236 .12361 L
.16352 .12361 L
.16456 .12361 L
.16577 .12361 L
.1669 .12361 L
.16796 .12361 L
.16893 .12361 L
.16999 .12361 L
.17111 .12361 L
.17225 .12361 L
.17347 .12361 L
.17462 .12361 L
Mistroke
.17566 .12361 L
.17689 .12361 L
.17758 .12361 L
.17823 .12361 L
.1794 .12361 L
.18065 .12361 L
.18185 .12361 L
.18316 .12361 L
.18441 .12361 L
.18556 .12361 L
.1867 .12361 L
.18773 .12361 L
.18893 .12361 L
.19005 .12361 L
.19128 .12361 L
.19258 .12361 L
.19369 .12361 L
.19491 .12361 L
.19623 .12361 L
.19696 .12361 L
.19763 .12361 L
.19894 .12361 L
.20017 .12361 L
.20122 .12361 L
.20238 .12361 L
.20359 .12361 L
.20472 .12361 L
.20578 .12361 L
.20675 .12361 L
.20781 .12361 L
.20894 .12361 L
.21008 .12361 L
.21129 .12361 L
.21244 .12361 L
.21349 .12361 L
.21472 .12361 L
.21541 .12361 L
.21605 .12361 L
.21723 .12361 L
.21847 .12361 L
.21968 .12361 L
.221 .12361 L
.22224 .12361 L
.2234 .12361 L
.22454 .12361 L
.22558 .12361 L
.22677 .12361 L
.2279 .12361 L
.22914 .12361 L
.23044 .12361 L
Mistroke
.23155 .12361 L
.23277 .12361 L
.23409 .12361 L
.23482 .12361 L
.2355 .12361 L
.2368 .12361 L
.23804 .12361 L
.23909 .12361 L
.24025 .12361 L
.24146 .12361 L
.2426 .12361 L
.24365 .12361 L
.24462 .12361 L
.24569 .12361 L
.24681 .12361 L
.24795 .12361 L
.24917 .12361 L
.25032 .12361 L
.25137 .12361 L
.2526 .12361 L
.25329 .12361 L
.25393 .12361 L
.2551 .12361 L
.25635 .12361 L
.25756 .12361 L
.25888 .12361 L
.26013 .12361 L
.26129 .12361 L
.26233 .12361 L
.26348 .12361 L
.26467 .12361 L
.2658 .12361 L
.26704 .12361 L
.26835 .12361 L
.26946 .12361 L
.27068 .12361 L
.272 .12361 L
.27274 .12361 L
.27341 .12361 L
.27472 .12361 L
.27595 .12361 L
.27701 .12361 L
.27817 .12361 L
.27938 .12361 L
.28052 .12361 L
.28158 .12361 L
.28255 .12361 L
.28367 .12361 L
.28474 .12361 L
.28588 .12361 L
Mistroke
.2871 .12361 L
.28825 .12361 L
.2893 .12361 L
.29053 .12361 L
.29122 .12361 L
.29186 .12361 L
.29303 .12361 L
.29427 .12361 L
.29549 .12361 L
.29618 .12361 L
.29682 .12361 L
.29799 .12361 L
.29923 .12361 L
.30034 .12361 L
.30138 .12361 L
.30252 .12361 L
.30375 .12361 L
.30499 .12361 L
.30569 .12361 L
.30634 .12361 L
.30765 .12361 L
.30839 .12361 L
.30906 .12361 L
.31026 .12361 L
.31156 .12361 L
.31278 .12361 L
.31392 .12361 L
.31497 .12361 L
.31611 .12361 L
.31718 .12361 L
.31816 .12361 L
.3193 .12361 L
.32055 .12361 L
.32173 .12361 L
.32282 .12361 L
.32406 .12361 L
.32522 .12361 L
.32626 .12361 L
.32739 .12361 L
.32862 .12361 L
.32992 .12361 L
.33103 .12361 L
.33225 .12361 L
.33356 .12361 L
.33477 .12361 L
.33541 .12361 L
.3361 .12361 L
.33683 .12361 L
.33751 .12361 L
.33876 .12361 L
Mistroke
.33991 .12361 L
.34123 .12361 L
.34249 .12361 L
.3436 .12361 L
.3448 .12361 L
.34592 .12361 L
.34694 .12361 L
.34814 .12361 L
.34945 .12361 L
.35067 .12361 L
.35181 .12361 L
.35302 .12361 L
.35431 .12361 L
.35554 .12361 L
.35665 .12361 L
.35796 .12361 L
.3587 .12361 L
.35939 .12361 L
.36064 .12361 L
.36128 .12361 L
.36198 .12361 L
.36266 .12361 L
.36337 .12361 L
.36465 .12361 L
.36536 .12361 L
.36602 .12361 L
.36675 .12361 L
.36753 .12361 L
.3682 .12361 L
.36893 .12361 L
.36962 .12361 L
.37026 .12361 L
.37146 .12361 L
.37274 .12361 L
.37394 .12361 L
.37526 .12361 L
.37651 .12361 L
.37766 .12361 L
.3788 .12361 L
.37984 .12361 L
.38103 .12361 L
.38216 .12361 L
.38339 .12361 L
.3847 .12361 L
.38581 .12361 L
.38703 .12361 L
.38834 .12361 L
.38908 .12361 L
.38975 .12361 L
.39106 .12361 L
Mistroke
.39229 .12361 L
.39334 .12361 L
.3945 .12361 L
.39571 .12361 L
.39685 .12361 L
.39791 .12361 L
.39888 .12361 L
.39994 .12361 L
.40106 .12361 L
.40221 .12361 L
.40342 .12361 L
.40457 .12361 L
.40562 .12361 L
.40685 .12361 L
.40754 .12361 L
.40818 .12361 L
.40936 .12361 L
.4106 .12361 L
.41181 .12361 L
.41313 .12361 L
.41438 .12361 L
.41554 .12361 L
.41669 .12361 L
.41772 .12361 L
.41892 .12361 L
.42005 .12361 L
.42129 .12361 L
.42259 .12361 L
.42371 .12361 L
.42493 .12361 L
.42624 .12361 L
.42698 .12361 L
.42765 .12361 L
.42896 .12361 L
.43019 .12361 L
.43125 .12361 L
.43241 .12361 L
.43362 .12361 L
.43476 .12361 L
.43582 .12361 L
.43679 .12361 L
.43791 .12361 L
.43898 .12361 L
.44012 .12361 L
.44134 .12361 L
.44249 .12361 L
.44354 .12361 L
.44477 .12361 L
.44546 .12361 L
.4461 .12361 L
Mistroke
.44727 .12361 L
.44851 .12361 L
.44973 .12361 L
.45042 .12361 L
.45106 .12361 L
.45223 .12361 L
.45347 .12361 L
.45458 .12361 L
.45562 .12361 L
.45676 .12361 L
.45799 .12361 L
.45922 .12361 L
.45992 .12361 L
.46057 .12361 L
.46188 .12361 L
.46262 .12361 L
.46329 .12361 L
.46449 .12361 L
.46579 .12361 L
.46702 .12361 L
.46815 .12361 L
.4692 .12361 L
.47034 .12361 L
.47141 .12361 L
.47239 .12361 L
.47353 .12361 L
.47478 .12361 L
.47596 .12361 L
.47705 .12361 L
.47829 .12361 L
.47945 .12361 L
.48049 .12361 L
.48162 .12361 L
.48285 .12361 L
.48415 .12361 L
.48526 .12361 L
.48648 .12361 L
.48779 .12361 L
.489 .12361 L
.48963 .12361 L
.49033 .12361 L
.49105 .12361 L
.49174 .12361 L
.49299 .12361 L
.49413 .12361 L
.49539 .12361 L
.49671 .12361 L
.49783 .12361 L
.49902 .12361 L
.50014 .12361 L
Mistroke
.50116 .12361 L
.50236 .12361 L
.50366 .12361 L
.50489 .12361 L
.50603 .12361 L
.50723 .12361 L
.50853 .12361 L
.50975 .12361 L
.51087 .12361 L
.51218 .12361 L
.51292 .12361 L
.51361 .12361 L
.51486 .12361 L
.5155 .12361 L
.5162 .12361 L
.51687 .12361 L
.51759 .12361 L
.51886 .12361 L
.51958 .12361 L
.52024 .12361 L
.52096 .12361 L
.52174 .12361 L
.52241 .12361 L
.52314 .12361 L
.52383 .12361 L
.52447 .12361 L
.52568 .12361 L
.52695 .12361 L
.52816 .12361 L
.52947 .12361 L
.53072 .12361 L
.53187 .12361 L
.53301 .12361 L
.53405 .12361 L
.53525 .12361 L
.53637 .12361 L
.5376 .12361 L
.53891 .12361 L
.54002 .12361 L
.54124 .12361 L
.54255 .12361 L
.54329 .12361 L
.54396 .12361 L
.54526 .12361 L
.5465 .12361 L
.54755 .12361 L
.54871 .12361 L
.54992 .12361 L
.55105 .12361 L
.55211 .12361 L
Mistroke
.55308 .12361 L
.55415 .12361 L
.55527 .12361 L
.55641 .12361 L
.55763 .12361 L
.55878 .12361 L
.55982 .12361 L
.56105 .12361 L
.56175 .12361 L
.56238 .12361 L
.56356 .12361 L
.5648 .12361 L
.56601 .12361 L
.56734 .12361 L
.56858 .12361 L
.56974 .12361 L
.57088 .12361 L
.57192 .12361 L
.57312 .12361 L
.57425 .12361 L
.57548 .12361 L
.57679 .12361 L
.5779 .12361 L
.57912 .12361 L
.58044 .12361 L
.58118 .12361 L
.58185 .12361 L
.58315 .12361 L
.58439 .12361 L
.58544 .12361 L
.5866 .12361 L
.58782 .12361 L
.58895 .12361 L
.59001 .12361 L
.59098 .12361 L
.5921 .12361 L
.59317 .12361 L
.59431 .12361 L
.59553 .12361 L
.59668 .12361 L
.59773 .12361 L
.59896 .12361 L
.59965 .12361 L
.60029 .12361 L
.60146 .12361 L
.60271 .12361 L
.60392 .12361 L
.60461 .12361 L
.60525 .12361 L
.60642 .12361 L
Mistroke
.60766 .12361 L
.60876 .12361 L
.6098 .12361 L
.61094 .12361 L
.61217 .12361 L
.61341 .12361 L
.6141 .12361 L
.61475 .12361 L
.61607 .12361 L
.6168 .12361 L
.61747 .12361 L
.61867 .12361 L
.61997 .12361 L
.6212 .12361 L
.62233 .12361 L
.62339 .12361 L
.62452 .12361 L
.62559 .12361 L
.62657 .12361 L
.62771 .12361 L
.62896 .12361 L
.63014 .12361 L
.63123 .12361 L
.63247 .12361 L
.63363 .12361 L
.63467 .12361 L
.6358 .12361 L
.63703 .12361 L
.63833 .12361 L
.63944 .12361 L
.64066 .12361 L
.64197 .12361 L
.64318 .12361 L
.64381 .12361 L
.6445 .12361 L
.64523 .12361 L
.64591 .12361 L
.64716 .12361 L
.64831 .12361 L
.64956 .12361 L
.65088 .12361 L
.652 .12361 L
.65319 .12361 L
.65431 .12361 L
.65533 .12361 L
.65653 .12361 L
.65784 .12361 L
.65906 .12361 L
.6602 .12361 L
.6614 .12361 L
Mistroke
.6627 .12361 L
.66392 .12361 L
.66504 .12361 L
.66635 .12361 L
.66709 .12361 L
.66777 .12361 L
.66903 .12361 L
.66966 .12361 L
.67036 .12361 L
.67104 .12361 L
.67175 .12361 L
.67303 .12361 L
.67374 .12361 L
.6744 .12361 L
.67513 .12361 L
.67591 .12361 L
.67658 .12361 L
.67731 .12361 L
.678 .12361 L
.67864 .12361 L
.67984 .12361 L
.68112 .12361 L
.68232 .12361 L
.68364 .12361 L
.68488 .12361 L
.68603 .12361 L
.68718 .12361 L
.68821 .12361 L
.68941 .12361 L
.69053 .12361 L
.69176 .12361 L
.69307 .12361 L
.69418 .12361 L
.6954 .12361 L
.69671 .12361 L
.69745 .12361 L
.69812 .12361 L
.69942 .12361 L
.70066 .12361 L
.70171 .12361 L
.70286 .12361 L
.70407 .12361 L
.70521 .12361 L
.70627 .12361 L
.70724 .12361 L
.7083 .12361 L
.70942 .12361 L
.71056 .12361 L
.71178 .12361 L
.71293 .12361 L
Mistroke
.71398 .12361 L
.71521 .12361 L
.7159 .12361 L
.71654 .12361 L
.71771 .12361 L
.71896 .12361 L
.72017 .12361 L
.72149 .12361 L
.72273 .12361 L
.72389 .12361 L
.72503 .12361 L
.72607 .12361 L
.72727 .12361 L
.7284 .12361 L
.72963 .12361 L
.73094 .12361 L
.73205 .12361 L
.73327 .12361 L
.73458 .12361 L
.73532 .12361 L
.73599 .12361 L
.7373 .12361 L
.73853 .12361 L
.73959 .12361 L
.74075 .12361 L
.74196 .12361 L
.7431 .12361 L
.74416 .12361 L
.74513 .12361 L
.74619 .12361 L
.74731 .12361 L
.74846 .12361 L
.74967 .12361 L
.75083 .12361 L
.75187 .12361 L
.7531 .12361 L
.75379 .12361 L
.75443 .12361 L
.75561 .12361 L
.75685 .12361 L
.75806 .12361 L
.75875 .12361 L
.75939 .12361 L
.76056 .12361 L
.7618 .12361 L
.7629 .12361 L
.76394 .12361 L
.76508 .12361 L
.76631 .12361 L
.76754 .12361 L
Mistroke
.76824 .12361 L
.76889 .12361 L
.7702 .12361 L
.77094 .12361 L
.77161 .12361 L
.7728 .12361 L
.7741 .12361 L
.77533 .12361 L
.77646 .12361 L
.77752 .12361 L
.77865 .12361 L
.77972 .12361 L
.7807 .12361 L
.78184 .12361 L
.78309 .12361 L
.78427 .12361 L
.78536 .12361 L
.7866 .12361 L
.78776 .12361 L
.7888 .12361 L
.78993 .12361 L
.79116 .12361 L
.79246 .12361 L
.79357 .12361 L
.79479 .12361 L
.7961 .12361 L
.7973 .12361 L
.79793 .12361 L
.79863 .12361 L
.79936 .12361 L
.80004 .12361 L
.80129 .12361 L
.80243 .12361 L
.80369 .12361 L
.80501 .12361 L
.80612 .12361 L
.80731 .12361 L
.80843 .12361 L
.80945 .12361 L
.81066 .12361 L
.81196 .12361 L
.81318 .12361 L
.81432 .12361 L
.81552 .12361 L
.81682 .12361 L
.81804 .12361 L
.81916 .12361 L
.82047 .12361 L
.8212 .12361 L
.82189 .12361 L
Mistroke
.82315 .12361 L
.82385 .12361 L
.82448 .12361 L
.82516 .12361 L
.82587 .12361 L
.82715 .12361 L
.82786 .12361 L
.82852 .12361 L
.82925 .12361 L
.83002 .12361 L
.8307 .12361 L
.83143 .12361 L
.83212 .12361 L
.83275 .12361 L
.83396 .12361 L
.83524 .12361 L
.83644 .12361 L
.83775 .12361 L
.839 .12361 L
.84015 .12361 L
.84129 .12361 L
.84232 .12361 L
.84352 .12361 L
.84464 .12361 L
.84587 .12361 L
.84718 .12361 L
.84829 .12361 L
.8495 .12361 L
.85082 .12361 L
.85155 .12361 L
.85222 .12361 L
.85353 .12361 L
.85476 .12361 L
.85581 .12361 L
.85697 .12361 L
.85818 .12361 L
.85932 .12361 L
.86037 .12361 L
.86134 .12361 L
.86241 .12361 L
.86353 .12361 L
.86467 .12361 L
.86589 .12361 L
.86704 .12361 L
.86808 .12361 L
.86931 .12361 L
.87 .12361 L
.87064 .12361 L
.87182 .12361 L
.87306 .12361 L
Mistroke
.87427 .12361 L
.87559 .12361 L
.87684 .12361 L
.87799 .12361 L
.87914 .12361 L
.88017 .12361 L
.88137 .12361 L
.88249 .12361 L
.88373 .12361 L
.88503 .12361 L
.88615 .12361 L
.88737 .12361 L
.88868 .12361 L
.88942 .12361 L
.89009 .12361 L
.89139 .12361 L
.89263 .12361 L
.89368 .12361 L
.89484 .12361 L
.89605 .12361 L
.89719 .12361 L
.89825 .12361 L
.89922 .12361 L
.90029 .12361 L
.90141 .12361 L
.90255 .12361 L
.90377 .12361 L
.90492 .12361 L
.90596 .12361 L
.90719 .12361 L
.90789 .12361 L
.90852 .12361 L
.9097 .12361 L
.91094 .12361 L
.91216 .12361 L
.91284 .12361 L
.91348 .12361 L
.91464 .12361 L
.91589 .12361 L
.91699 .12361 L
.91803 .12361 L
.91917 .12361 L
.9204 .12361 L
.92163 .12361 L
.92233 .12361 L
.92297 .12361 L
.92429 .12361 L
.92502 .12361 L
.92569 .12361 L
.92689 .12361 L
Mistroke
.92819 .12361 L
.92941 .12361 L
.93055 .12361 L
.9316 .12361 L
.93273 .12361 L
.9338 .12361 L
.93478 .12361 L
.93592 .12361 L
.93717 .12361 L
.93835 .12361 L
.93944 .12361 L
.94068 .12361 L
.94184 .12361 L
.94288 .12361 L
.94401 .12361 L
.94524 .12361 L
.94654 .12361 L
.94765 .12361 L
.94887 .12361 L
.94975 .12361 L
.95057 .12361 L
.95146 .12361 L
.95241 .12361 L
.95324 .12361 L
.95401 .12361 L
.95486 .12361 L
.95577 .12361 L
.95653 .12361 L
.95737 .12361 L
.95824 .12361 L
.95905 .12361 L
.95981 .12361 L
.9605 .12361 L
.9613 .12361 L
.96206 .12361 L
.96287 .12361 L
.96377 .12361 L
.96471 .12361 L
.96559 .12361 L
.96641 .12361 L
.96716 .12361 L
.96802 .12361 L
.96884 .12361 L
.96972 .12361 L
.97067 .12361 L
.97155 .12361 L
.97236 .12361 L
.97331 .12361 L
.97433 .12361 L
.9753 .12361 L
Mistroke
.97619 .12361 L
Mfstroke
.02381 .12361 m
.02846 .11754 L
.03068 .11509 L
.03279 .11323 L
.03398 .11241 L
.03527 .11173 L
.03645 .11132 L
.03754 .11112 L
.03871 .1111 L
.04 .11132 L
.04065 .11153 L
.04135 .11182 L
.04262 .11252 L
.04393 .11348 L
.04516 .11456 L
.04793 .1176 L
.05297 .12446 L
.05752 .13069 L
.05992 .13344 L
.06244 .13568 L
.06381 .13654 L
.06459 .1369 L
.06531 .13716 L
.06659 .13741 L
.0673 .13743 L
.06795 .13739 L
.06923 .13709 L
.06995 .13681 L
.07062 .13647 L
.07184 .13567 L
.07314 .13458 L
.07552 .132 L
.07775 .129 L
.08284 .121 L
.08794 .11326 L
.0905 .11022 L
.09195 .1089 L
.0933 .10796 L
.09407 .10757 L
.09479 .1073 L
.09544 .10713 L
.09615 .10704 L
.09691 .10705 L
.09773 .10718 L
.09842 .10739 L
.09919 .10773 L
.09989 .10814 L
.10053 .1086 L
.10197 .10989 L
.10458 .11312 L
Mistroke
.11379 .13006 L
.11622 .13465 L
.11885 .13897 L
.12005 .14064 L
.12133 .14214 L
.12243 .14318 L
.1236 .14403 L
.12433 .1444 L
.125 .14464 L
.1263 .14481 L
.12702 .14473 L
.12781 .1445 L
.12856 .14414 L
.12925 .14369 L
.13043 .14267 L
.13173 .14117 L
.13436 .13702 L
.13951 .12557 L
.14434 .11309 L
.14905 .10231 L
.15034 .09998 L
.15172 .09791 L
.15302 .09639 L
.1542 .09542 L
.15485 .09505 L
.15553 .09481 L
.15676 .09473 L
.15808 .09519 L
.15883 .0957 L
.15953 .09634 L
.1608 .0979 L
.16196 .09976 L
.16456 .1054 L
.16911 .11919 L
.17407 .1372 L
.1784 .1521 L
.18068 .15846 L
.18192 .16129 L
.18308 .16344 L
.18428 .16514 L
.1856 .16631 L
.18672 .16671 L
.18792 .16649 L
.18914 .16556 L
.1903 .16402 L
.19134 .16208 L
.19246 .15939 L
.19508 .15088 L
.19786 .13874 L
.20283 .11122 L
Mistroke
.20765 .08247 L
.2103 .06824 L
.21283 .05719 L
.21425 .05243 L
.215 .05042 L
.21579 .04868 L
.21653 .04748 L
.2172 .04675 L
.21851 .04633 L
.21983 .04735 L
.22057 .04859 L
.22125 .05017 L
.2225 .05421 L
.22383 .06009 L
.22638 .07615 L
.22879 .09706 L
.23332 .15004 L
.24348 .31108 L
.24774 .38009 L
.25227 .44266 L
.25463 .46831 L
.25588 .47954 L
.25723 .48961 L
.25847 .49688 L
.2596 .50185 L
.26068 .50505 L
.26182 .50673 L
.26306 .5066 L
.26376 .50563 L
.2644 .50416 L
.26558 .50003 L
.26683 .49369 L
.26899 .47806 L
.27138 .45459 L
.27665 .38336 L
.28158 .30154 L
.29037 .15564 L
.29278 .12222 L
.29534 .09184 L
.29756 .0705 L
.29995 .05297 L
.30142 .04511 L
.30206 .04237 L
.30277 .03986 L
.30406 .03655 L
.30476 .03544 L
.30542 .03484 L
.30667 .0348 L
.30781 .03598 L
.30912 .0387 L
Mistroke
.31037 .04251 L
.31283 .05313 L
.31511 .06588 L
.32025 .10072 L
.3249 .13278 L
.32925 .15755 L
.33144 .16678 L
.33256 .17055 L
.33379 .17385 L
.33449 .17533 L
.33513 .17645 L
.3364 .17796 L
.33756 .17852 L
.33879 .17827 L
.34003 .17718 L
.34074 .1762 L
.3414 .17506 L
.34272 .17212 L
.34415 .1681 L
.34907 .14887 L
.35478 .12189 L
.35759 .10932 L
.3602 .09924 L
.36264 .09166 L
.36388 .08867 L
.36525 .08607 L
.36591 .08508 L
.36661 .08424 L
.36738 .08355 L
.36808 .08314 L
.36935 .08293 L
.37007 .08312 L
.37074 .08348 L
.372 .08463 L
.37318 .08627 L
.37424 .08817 L
.37539 .09066 L
.38036 .1054 L
.38531 .12341 L
.38804 .13312 L
.39063 .14137 L
.39303 .14772 L
.39429 .15045 L
.39564 .15282 L
.39689 .1545 L
.39802 .15557 L
.39916 .15622 L
.40023 .15642 L
.40145 .15619 L
.40274 .15541 L
Mistroke
.40384 .15433 L
.40505 .15272 L
.40774 .14772 L
.41025 .14159 L
.41553 .1261 L
.41832 .11772 L
.42127 .1096 L
.42386 .10368 L
.42523 .10113 L
.42671 .0989 L
.42737 .09809 L
.42807 .09736 L
.42931 .09641 L
.43047 .09591 L
.43174 .09581 L
.43305 .09618 L
.43423 .09692 L
.43488 .09749 L
.43559 .09824 L
.43688 .09991 L
.43936 .10417 L
.44165 .1091 L
.45061 .13187 L
.45319 .13769 L
.45563 .14222 L
.45783 .14527 L
.45907 .14651 L
.46022 .14732 L
.46137 .14781 L
.46246 .14797 L
.46364 .14781 L
.46493 .14724 L
.4662 .1463 L
.46754 .14491 L
.46993 .14151 L
.47427 .13307 L
.47901 .12217 L
.48418 .11115 L
.48567 .10855 L
.48707 .10643 L
.48835 .10481 L
.4897 .10346 L
.49089 .10259 L
.49219 .10199 L
.49337 .10178 L
.49448 .10186 L
.49578 .1023 L
.49698 .10302 L
.49763 .10355 L
.49835 .10422 L
Mistroke
.49966 .10569 L
.50222 .10941 L
.50498 .1144 L
.50998 .12474 L
.51444 .13354 L
.51681 .13741 L
.51934 .14063 L
.52078 .14196 L
.52209 .14282 L
.52341 .14335 L
.52465 .14352 L
.52533 .14348 L
.52605 .14334 L
.52734 .14282 L
.52806 .1424 L
.52873 .14191 L
.53027 .14049 L
.53279 .13733 L
.5351 .13369 L
.54031 .12399 L
.54506 .11523 L
.54766 .11119 L
.54894 .10952 L
.55012 .10819 L
.55121 .10717 L
.55242 .10628 L
.55362 .10565 L
.5549 .10528 L
.55598 .1052 L
.55715 .10536 L
.55824 .10574 L
.55924 .10628 L
.56052 .10722 L
.56188 .10851 L
.56433 .1115 L
.56987 .12051 L
.57477 .12918 L
.57745 .1334 L
.57995 .13666 L
.58129 .13806 L
.58251 .13911 L
.58387 .13999 L
.58462 .14034 L
.58532 .14058 L
.58655 .1408 L
.58769 .14076 L
.58894 .14047 L
.58957 .14021 L
.59026 .13986 L
.59171 .13887 L
Mistroke
.59303 .13768 L
.59601 .13416 L
.6014 .12576 L
.60635 .11761 L
.60896 .11383 L
.6104 .11204 L
.61175 .11059 L
.61303 .10944 L
.61371 .10893 L
.61442 .10846 L
.61569 .10784 L
.61685 .1075 L
.61802 .10738 L
.61911 .10747 L
.62031 .10779 L
.62159 .10839 L
.63118 .11948 L
.63644 .12778 L
.64138 .13445 L
.64394 .13691 L
.64538 .1379 L
.6467 .13855 L
.6474 .13878 L
.64806 .13893 L
.64878 .13902 L
.64956 .13902 L
.65037 .13893 L
.65113 .13874 L
.65182 .13849 L
.65257 .13815 L
.65381 .13739 L
.65518 .13631 L
.65796 .13343 L
.66293 .12659 L
.66801 .11896 L
.67051 .11556 L
.67284 .11289 L
.67423 .11156 L
.6755 .11056 L
.67691 .10971 L
.67768 .10937 L
.6784 .10912 L
.67968 .10887 L
.68085 .10886 L
.68213 .10909 L
.68278 .10929 L
.68349 .10959 L
.68478 .11031 L
.68601 .1112 L
.6883 .11335 L
Mistroke
.69345 .1199 L
.69825 .12684 L
.70275 .13264 L
.70496 .13486 L
.7061 .13578 L
.70734 .13661 L
.70863 .13725 L
.70934 .1375 L
.70999 .13767 L
.71116 .13781 L
.71241 .13775 L
.7131 .13763 L
.71374 .13745 L
.71444 .13718 L
.71518 .13683 L
.71642 .13608 L
.71779 .13503 L
.72268 .12971 L
.7272 .1235 L
.73213 .11688 L
.73439 .11433 L
.73563 .11313 L
.73679 .11215 L
.73788 .11138 L
.73905 .11072 L
.74012 .11027 L
.7411 .11 L
.74233 .10985 L
.74347 .1099 L
.74472 .11016 L
.74542 .1104 L
.74606 .11068 L
.74734 .11139 L
.74874 .1124 L
.75128 .11478 L
.76057 .12675 L
.76584 .13295 L
.76851 .13516 L
.76923 .13563 L
.77002 .13606 L
.77075 .13639 L
.77144 .13663 L
.77272 .13692 L
.7734 .13698 L
.77412 .13698 L
.77481 .13691 L
.77546 .13679 L
.77668 .1364 L
.77788 .13584 L
.77898 .13516 L
Mistroke
.78147 .13313 L
.79055 .12205 L
.79295 .11896 L
.79555 .11593 L
.79785 .11369 L
.79911 .11269 L
.80029 .11191 L
.80167 .11121 L
.8024 .11094 L
.80319 .11072 L
.80388 .1106 L
.8046 .11054 L
.80588 .1106 L
.80714 .11087 L
.80831 .11131 L
.8096 .11198 L
.81098 .11292 L
.81366 .11532 L
.8162 .11814 L
.82095 .12419 L
.82597 .13037 L
.82843 .13284 L
.83067 .13461 L
.83188 .13533 L
.83303 .13586 L
.83425 .13623 L
.83494 .13636 L
.83557 .13642 L
.83628 .13643 L
.83694 .13638 L
.83818 .13613 L
.83888 .13591 L
.83952 .13565 L
.84096 .13488 L
.84318 .13324 L
.84525 .13129 L
.84994 .12578 L
.85486 .11955 L
.85941 .11465 L
.86185 .11275 L
.86308 .11203 L
.86444 .11144 L
.86514 .11123 L
.86579 .11109 L
.8665 .11099 L
.86725 .11097 L
.86851 .11108 L
.86923 .11124 L
.86989 .11144 L
.87118 .11199 L
Mistroke
.8724 .11269 L
.87469 .11442 L
.8798 .11989 L
.88407 .12524 L
.88865 .13061 L
.89128 .13308 L
.89368 .13476 L
.89483 .13534 L
.89609 .13579 L
.89727 .13604 L
.89837 .13611 L
.89953 .13602 L
.90061 .13578 L
.90181 .13534 L
.90309 .13469 L
.90571 .13279 L
.90812 .13049 L
.91303 .12471 L
.91842 .11815 L
.92067 .11577 L
.92308 .11369 L
.92424 .11288 L
.92535 .11225 L
.92634 .11181 L
.92741 .11146 L
.92855 .11125 L
.9298 .1112 L
.93111 .11137 L
.93234 .11171 L
.93348 .1122 L
.93453 .11278 L
.93688 .11451 L
.9416 .11938 L
.94663 .12557 L
.95098 .13057 L
.95327 .13273 L
.95568 .13447 L
.95706 .13518 L
.95784 .13549 L
.95857 .13571 L
.95985 .13594 L
.96057 .13597 L
.96122 .13595 L
.96251 .13575 L
.96323 .13555 L
.9639 .1353 L
.96513 .13471 L
.96644 .1339 L
.96883 .13197 L
.97108 .12971 L
Mistroke
.97619 .12361 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{216, 133.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QB000`400?l00000o`00003of?ooool0
0=Sooooo000<ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000__ooool000_ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo00000;gooooo0004ooooo`Go
00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo0;_ooooo000;ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2o`000;Oooooo000;ooooo`04
o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo0;Kooooo000;ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2foooo
o`003?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo0;Kooooo000Oooooo`03o`00
0?oooooooooo0;Kooooo000Oooooo`03o`000?oooooooooo0;Kooooo000Oooooo`03o`000?oooooo
oooo033ooooo0_l00024ooooo`007oooool00ol0003oooooooooo`0`ooooo`;o0000Q?ooool001oo
oooo00?o0000ooooooooool08?ooool2o`0000gooooo00?o0000ooooool00000Q?ooool001oooooo
00?o0000ooooooooool07oooool3o`0000gooooo00Co0000oooooooooooo0000Poooool001oooooo
00?o0000ooooooooool07oooool00ol0003oooooo`00000=ooooo`04o`000?ooooooooooo`0008?o
oooo000Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000003Oooool01?l0003ooooo
ooooool00023ooooo`007oooool00ol0003oooooooooo`0Hooooo`;o00001?ooool2o`000003oooo
ool0003o000000Co00002?ooool01?l0003oooooooooool00008ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`?o00005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001Go
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Jooooo`?o00002_ooool001oooooo
00?o0000ooooooooool05oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o
00000_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`00000Cooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`00000Jooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo01Oo
oooo00Co0000oooooooooooo00000oooool01ol0003ooooooooooooooooo0000ooooool000002_oo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo1Ol0000Cooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Cooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Wooooo
000Oooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00007oooo
o`Co00001oooool01?l0003oooooooooool0000Dooooo`04o`000?ooooooooooo`0000Oooooo1?l0
000Dooooo`04o`000?ooooooooooo`0000Sooooo0ol0000Kooooo`03o`000?oooooooooo00Wooooo
000Oooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo0_l000000ooooooo0000ooooo`07ooooo`03o`000?oooooo000001Co
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Eooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Wooooo000O
ooooo`03o`000?oooooooooo01Cooooo0_l000001Ooooooo0000oooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?ooool02?ooool2o`0001Cooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Iooooo`;o00002oooool001oooooo00?o0000oooo
ooooool05?ooool01?l0003oooooo`000?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool4
o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`?o000000?ooooo
o`000?ooool01_ooool3o`0000[ooooo00?o0000ooooooooool02?ooool2o`0000[ooooo0_l0000E
ooooo`;o00002Oooool3o`0001_ooooo00?o0000ooooooooool02Oooool001oooooo00?o0000oooo
ooooool02Oooool2o`0000Wooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`?o00002?oo
ool3o`0000Wooooo0_l0001;ooooo`007oooool4o`0000Oooooo1?l00007ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo0000
o`0000Oooooo0ol00009ooooo`?o00002?ooool4o`0000Sooooo0ol00008ooooo`?o00002Oooool3
o`00017ooooo000Oooooo`;o000000?oooooo`000?l000001_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool2o`00
00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00001oooool2o`0000;ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00007ooooo`;o000000?oooooo`000?ooool04?ooool001[ooooo^Ol00005ooooo`007oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001Oooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`06o`000?ooooooooooo`000?oo
oooo00001Oooool2o`0000Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Cooooo00?o
0000ooooool000001?ooool01_l0003oooooooooool0003oooooo`0000Gooooo0_l00003ooooo`03
o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooo
oooooooo0_l00005ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool2o`00
00Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo000Oooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003oooooo`00
00Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool00_l00007ooooo`04o`000?ooooooooooo`0000Oooooo0_l000000ooooooo0000
o`000007ooooo`04o`000?ooooooooooo`0000Oooooo0_l000000ooooooo0000ooooo`06ooooo`;o
000000?oooooo`000?l000001oooool5o`0000[ooooo000Oooooo`03o`000?oooooooooo00Cooooo
0_l00008ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00008ooooo`?o00002?ooool3o`0000Wooooo0ol00008ooooo`?o
00002Oooool2o`0000Wooooo0ol00009ooooo`;o00003?ooool001oooooo00?o0000ooooooooool0
3_ooool3o`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`000009ooooo`;o00002_ooool00ol0003oooooooooo`1?
ooooo`007oooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo0_l0
00000ooooooo0000ooooo`07ooooo`?o0000Ioooool001oooooo00?o0000ooooooooool06Oooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00008ooooo`?o0000L_ooool001oooooo00?o0000ooooooooool06Ooo
ool3o`0000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0007gooooo000Oooooo`03o`000?oooooooooo01[ooooo0_l00007ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00001nooooo`007oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`00001nooooo`007oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool3o`0007kooooo000Oooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`26ooooo`007oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Q_ooool001oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Kooooo000O
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`26
ooooo`007oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Q_ooool001oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo08Kooooo000Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`26ooooo`007oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Q_ooool001oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Kooooo000Oooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`27ooooo`003?ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo08Oooooo000;ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`27ooooo`002oooool01?l0003oooooooooool0000;oooo
o`03o`000?oooooooooo00;ooooo0_l0000Uooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Qoooool000_ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`27oooo
o`002oooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Qoooool000_ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`27ooooo`003?ooool2o`0000Sooooo1Ol00004ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`27ooooo`00
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Qoooool001oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo08Oooooo000Oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`27ooooo`007oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Qoooool001oooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo08Oooooo000Oooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`007oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Qoooool001oooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo000Ooooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27oooo
o`007oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Qoooool001oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo08Oooooo000Oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`27ooooo`007oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Qoooool001oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo000Oooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`28ooooo`005oooool3o`0000Gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Sooooo
000Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo08Sooooo000Hooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Sooooo000Hoooo
o`03o`000?oooooooooo00Cooooo0_l0000Wooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0R?ooool001Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool001Oooooo0_l00006ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`28ooooo`006?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`28ooooo`007oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0R?ooool001oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08Sooooo000Oooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`28ooooo`007oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool001oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Sooooo000O
ooooo`03o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00002;ooooo`007oooool0
0ol0003oooooooooo`0Vooooo`05o`000?ooooooooooooooool00000Roooool001oooooo00?o0000
ooooooooool09_ooool01Ol0003ooooooooooooooooo000008_ooooo000Oooooo`03o`000?oooooo
oooo02Kooooo00Go0000ooooooooooooooooo`00002;ooooo`007oooool00ol0003oooooooooo`0V
ooooo`05o`000?ooooooooooooooool00000Roooool001oooooo00?o0000ooooooooool09_ooool0
1Ol0003ooooooooooooooooo000008_ooooo000Oooooo`03o`000?oooooooooo02Kooooo00Go0000
ooooooooooooooooo`00002;ooooo`007oooool00ol0003oooooooooo`0Wooooo`04o`000?oooooo
ooooo`0008_ooooo000Oooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000Rooo
ool001oooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0002;ooooo`007oooool0
0ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0008_ooooo000;ooooo`?o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0Wooooo`04o`000?oooooo
ooooo`0008_ooooo000<ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooool00000S?ooool000cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`02ooooo`;o0000:?ooool00ol0003oooooo`00002<
ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0:?ooool2o`0008cooooo000<ooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03
o`000?oooooooooo02Sooooo0_l0002<ooooo`002oooool2o`0000Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Xooooo`;o0000S?ooool000cooooo00?o0000ooooooooool01ooo
ool5o`0000Cooooo00?o0000ooooooooool0]_ooool001oooooo00?o0000ooooooooool0]_ooool0
01oooooo00?o0000ooooooooool0]_ooool001oooooo00?o0000ooooooooool0]_ooool001oooooo
00?o0000ooooooooool0]_ooool001oooooo00?o0000ooooooooool0]_ooool001oooooo00?o0000
ooooooooool0]_ooool001oooooo00?o0000ooooooooool0]_ooool001oooooo00?o0000oooooooo
ool0]_ooool001oooooo00?o0000ooooooooool0]_ooool001oooooo00?o0000ooooooooool0]_oo
ool001oooooo00?o0000ooooooooool0]_ooool001oooooo00?o0000ooooooooool0]_ooool001oo
oooo00?o0000ooooooooool0]_ooool001oooooo00?o0000ooooooooool0]_ooool001oooooo00?o
0000ooooooooool0]_ooool001oooooo00?o0000ooooooooool0]_ooool001Kooooo1Ol00004oooo
o`03o`000?oooooooooo0;Kooooo000Gooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0]_ooool001Sooooo00?o0000ooooooooool01?ooool2o`000;Oooooo000Iooooo`03o`00
0?oooooooooo0;cooooo000Fooooo`05o`000?ooooooooooooooool00000_Oooool001Kooooo00Go
0000ooooooooooooooooo`00002mooooo`005oooool3o`0008Kooooo0ol0000eooooo`00XOooool0
0ol0003oooooooooo`0dooooo`00A_ooool5o`000005ooooool0003o0000o`000?ooool01ol00003
ooooo`;o00000_ooool5o`0000;ooooo1?l000000ooooooo0000o`000003o`0000Wooooo00?o0000
ooooooooool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00000oooool3o`0000;ooooo1Ol00003
ooooo`;o00001?ooool00ol0003oooooooooo`0cooooo`00B?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo03?ooooo0018ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooooooool5o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000003Cooooo0018ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooo`00000dooooo`00B?ooool01?l0003ooooooooo
ooooool4o`0000;ooooo0ol00003ooooo`Co00000_ooool3o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooool000000oooool3o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0000?ooooo0ol00002ooooo`?o00000oooool4o`0000;ooooo0_l000000ooooooo0000
o`00000cooooo`00B?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0>_ooool004Kooooo1Ol00009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`?o00002Oooool5o`0000Oooooo0ol0000A
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>_ooool00=Sooooo003Hooooo`00
\
\>"],
  ImageRangeCache->{{{77.875, 292.875}, {655.125, 522.812}} -> {-0.622392, \
10.9149, 0.00571668, 0.0220233}}]
}, Open  ]],

Cell[TextData[{
  "This curve is a typical approximation to a Dirac delta. The area under the \
curve is approximately 1/10. \nThe fjollowing plot of ",
  StyleBox["U",
    FontSlant->"Italic"],
  "(20,",
  StyleBox["x",
    FontSlant->"Italic"],
  ",0) shows that the An coefficients are also correct. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ U[20,x,0], {x,0,L}, PlotRange->{0,0.12}, PlotLabel->\"Initial \
Waveform\", AspectRatio->1/3]\
\>", "Input",
  CellLabel->"In[54]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 2.77778 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .05556 -24 -4.5 ]
[.01131 .05556 0 4.5 ]
[.01131 .11111 -24 -4.5 ]
[.01131 .11111 0 4.5 ]
[.01131 .16667 -24 -4.5 ]
[.01131 .16667 0 4.5 ]
[.01131 .22222 -24 -4.5 ]
[.01131 .22222 0 4.5 ]
[.01131 .27778 -18 -4.5 ]
[.01131 .27778 0 4.5 ]
[.01131 .33333 -24 -4.5 ]
[.01131 .33333 0 4.5 ]
[.5 .34583 -50.0625 0 ]
[.5 .34583 50.0625 12 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .05556 m
.03006 .05556 L
s
[(0.02)] .01131 .05556 1 0 Mshowa
.02381 .11111 m
.03006 .11111 L
s
[(0.04)] .01131 .11111 1 0 Mshowa
.02381 .16667 m
.03006 .16667 L
s
[(0.06)] .01131 .16667 1 0 Mshowa
.02381 .22222 m
.03006 .22222 L
s
[(0.08)] .01131 .22222 1 0 Mshowa
.02381 .27778 m
.03006 .27778 L
s
[(0.1)] .01131 .27778 1 0 Mshowa
.02381 .33333 m
.03006 .33333 L
s
[(0.12)] .01131 .33333 1 0 Mshowa
.125 Mabswid
.02381 .01389 m
.02756 .01389 L
s
.02381 .02778 m
.02756 .02778 L
s
.02381 .04167 m
.02756 .04167 L
s
.02381 .06944 m
.02756 .06944 L
s
.02381 .08333 m
.02756 .08333 L
s
.02381 .09722 m
.02756 .09722 L
s
.02381 .125 m
.02756 .125 L
s
.02381 .13889 m
.02756 .13889 L
s
.02381 .15278 m
.02756 .15278 L
s
.02381 .18056 m
.02756 .18056 L
s
.02381 .19444 m
.02756 .19444 L
s
.02381 .20833 m
.02756 .20833 L
s
.02381 .23611 m
.02756 .23611 L
s
.02381 .25 m
.02756 .25 L
s
.02381 .26389 m
.02756 .26389 L
s
.02381 .29167 m
.02756 .29167 L
s
.02381 .30556 m
.02756 .30556 L
s
.02381 .31944 m
.02756 .31944 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
gsave
.5 .34583 -119.312 -12.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 36.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
71.250 21.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
71.250 21.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Initial) show
119.250 21.250 moveto
(Waveform) show
167.375 21.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .02238 L
.10458 .04735 L
.14415 .0699 L
.18221 .09268 L
.22272 .11582 L
.26171 .13881 L
.30316 .16308 L
.34309 .18586 L
.3815 .20933 L
.42237 .23149 L
.44268 .24405 L
.46172 .257 L
.47106 .26286 L
.47994 .26746 L
.48484 .26941 L
.48743 .27025 L
.49018 .27099 L
.49273 .27151 L
.49504 .27185 L
.49616 .27197 L
.49736 .27207 L
.4985 .27213 L
.49955 .27215 L
.50081 .27215 L
.50201 .2721 L
.50308 .27204 L
.50425 .27193 L
.50552 .27178 L
.50687 .27158 L
.50929 .27111 L
.51361 .26994 L
.51838 .26818 L
.52903 .2628 L
.53904 .2565 L
.57773 .23144 L
.61887 .20912 L
.65849 .18491 L
.6966 .16322 L
.73716 .1395 L
.77621 .11643 L
.8177 .09274 L
.85768 .06883 L
.89615 .04693 L
.93707 .02267 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[54]:=",
  ImageSize->{269, 89.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004=0000FB000`400?l00000o`00003oooooool>
ooooo`00E?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Eooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0001Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Kooooo`?o00008_ooool0
05?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Dooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000005?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000006oooool00ol0003oooooooooo`0Qooooo`00Doooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00001oooool5o`0001?ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001Cooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool08Ooo
ool005?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Cooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00005?ooool01?l0003oooooooooool00007oooo
o`Co00005Oooool01?l0003oooooooooool00008ooooo`?o00007?ooool00ol0003oooooooooo`0Q
ooooo`00Doooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000005?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000001Cooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Kooooo`03o`000?oooooooooo027ooooo001Cooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Dooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Dooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool05Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000006_ooool2o`0002?ooooo001Doooo
o`;o00002Oooool3o`0001Kooooo0_l0000;ooooo`03o`000?oooooooooo01?ooooo0_l0000:oooo
o`;o00005_ooool2o`0000Wooooo0ol0000Looooo`03o`000?oooooooooo027ooooo003oooooo`ko
oooo003oooooo`kooooo003oooooo`kooooo000boooookko00007Oooool003Oooooo00?o0000oooo
ool000001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000002;ooooo000gooooo`03
o`000?oooooooooo00;o00007oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Mooooo`;o00000_ooool00ol0003o
ooooooooo`0Pooooo`00=oooool2o`0000?ooooo00?o0000ooooooooool0Y_ooool00ol0003ooooo
ooooo`0Uooooo`00=oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:Cooooo00?o
0000ooooooooool09_ooool003Oooooo00?o0000ooooooooool01?ooool2o`000:;ooooo0_l0000Y
ooooo`00=oooool2o`0000Oooooo0_l0002Nooooo`;o0000:oooool003Oooooo00?o0000oooooooo
ool02?ooool2o`0009[ooooo0_l0000]ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool2o`0000;ooooo1Ol00004ooooo`;o00002oooool2o`0009Kooooo0_l0000_ooooo`007Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0<ooooo`;o0000T_ooool2o`00037ooooo000Mooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0SOooool2o`0003?ooooo000Moooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`03ooooo`;o00004?ooool2o`0008cooooo00?o0000ooooooooool0<oooool001gooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08Oooooo0_l0000fooooo`00
7Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`02ooooo`;o00004oooool00ol0003oooooooooo`24ooooo`;o0000>?ooool0
01kooooo0_l0000:ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool04oooool2o`00
08?ooooo00?o0000ooooooooool0>?ooool003Oooooo00?o0000ooooooooool05Oooool2o`0007oo
oooo0_l0000kooooo`00=oooool2o`0001Sooooo0_l0001kooooo`;o0000?Oooool003Oooooo00?o
0000ooooooooool06Oooool2o`0007Sooooo00?o0000ooooooooool0?Oooool003Oooooo00?o0000
ooooooooool06oooool2o`0007Cooooo0_l00010ooooo`007_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0ol00004ooooo`;o00007_ooool2o`00073ooooo0_l00012oooo
o`007Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06_ooooo0_l00014
ooooo`007Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01Ol0
0004ooooo`;o00008Oooool2o`0006Wooooo0_l00016ooooo`007Oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02;ooooo0_l0001Uooooo`;o0000B?ooool001gooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo04Sooooo000Mooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool2o`0000Gooooo0_l0000V
ooooo`;o0000Goooool2o`0004_ooooo000Nooooo`;o00002_ooool2o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Wooooo`;o0000G?ooool00ol0003oooooooooo`1;oooo
o`00=oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool0C?ooool003Oooooo0_l0000[ooooo`;o0000E_ooool2o`0004oooooo000gooooo`03o`000?oo
oooooooo02cooooo0_l0001Booooo`;o0000DOooool001kooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00003ooooo`?o00001Oooool2o`0002oooooo00?o0000ooooooooool0COooool2
o`0005?ooooo000Mooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;oooool2o`0004_ooooo
0_l0001Eooooo`007Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo037ooooo0_l00017oooo
o`;o0000Eoooool001gooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003o
oooo00Co00001Oooool2o`0003Cooooo0_l00013ooooo`;o0000FOooool001gooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0
=Oooool2o`00043ooooo00?o0000ooooooooool0FOooool001gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo0_l0000hooooo`;o
0000??ooool2o`0005cooooo000Nooooo`;o00002_ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03Wooooo0_l0000hooooo`;o0000G_ooool003Oooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo05kooooo000gooooo`;o0000?Oooool2
o`0003;ooooo0_l0001Qooooo`00=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0HOooool003Oooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo06;ooooo000Nooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`;o00000oooool3o`0000Gooooo0_l00011ooooo`;o0000:_ooool2o`0006Gooooo
000Mooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@_ooool2o`0002Kooooo0_l0001Woooo
o`007Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`02ooooo`;o0000AOooool2o`0002;ooooo0_l0001Yooooo`007Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol00005ooooo`03o`00
0?oooooooooo04Kooooo0_l0000Nooooo`;o0000Joooool001gooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`18ooooo`;o00006_ooool2o`0006gooooo000Mooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo0_l0
001;ooooo`;o00005oooool00ol0003oooooooooo`1]ooooo`007_ooool2o`0000[ooooo0_l00003
ooooo`?o00001Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01;ooooo0_l0001`
ooooo`00=oooool2o`0004kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1`oooo
o`00=oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0LOooool003Oooooo00?o0000ooooooooool0Coooool2o`0000cooooo0_l0001dooooo`009?oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo0_l0001Booooo`;o00002?oo
ool2o`0007Kooooo000Sooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Cooooo`?o00000_ooool3o`0007Sooooo000Sooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`Co0000N_oo
ool002?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000e?oo
ool002?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0=?ooooo000Sooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`;o0000e?oo
ool002Cooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0doooool0
03Oooooo00?o0000ooooooooool0doooool003Oooooo0_l0003Dooooo`00=oooool00ol0003ooooo
ooooo`3Cooooo`00=oooool00ol0003oooooooooo`3Cooooo`007_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000;ooooo1Ol00004ooooo`;o0000e?ooool001gooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0doooool001gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo0_l0003Dooooo`007Oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0fOooool001gooooo00Co0000
oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
f?ooool001gooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`00003Jooooo`007_ooool2o`0000[ooooo00?o0000ooooooooool00_ooool3o`000=_ooooo
003oooooo`kooooo001Pooooo`Go000000Goooooo`000?l0003o0000ooooo`07o`0000?ooooo0_l0
0002ooooo`Go00000_ooool4o`000003ooooool0003o000000?o00002?ooool00ol0003oooooo`00
0003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol0
0002ooooo`?o00000oooool01Ol0003oooooo`000?oooooo000004kooooo001Rooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000002ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00004ooooo`05o`000?oooooo0000ooooool00000C_ooool006;o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oooooo0000
00;ooooo1Ol00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0004ooooo`05o`000?oooooo0000ooooool00000C_ooool006;ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo
ooooooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oooooo0000
ooooool00000C_ooool006;ooooo00Co0000oooooooooooooooo1?l00002ooooo`?o00000oooool4
o`0000;ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`05o`000?oooooo
0000ooooool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00000ooo
ool4o`0000;ooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
ooooo`1>ooooo`00H_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01oooool01Ol0003oooooo`000?oooooo000001Gooooo00?o0000ooooooooool0
H?ooool0063ooooo1Ol00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`?o00002Oooool6o`0001Gooooo0_l0001Pooooo`00ooooool>
ooooo`00ooooool>ooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 345.875}, {183.312, 94.875}} -> {-0.743115, \
0.159768, 0.00557924, 0.00191288}}]
}, Open  ]],

Cell[TextData[{
  "A snapshot of the waveform at ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0.2."
}], "Text"],

Cell[CellGroupData[{

Cell["Plot[ U[50,x,0.2], {x,0,L}, AspectRatio->1/3]", "Input",
  CellLabel->"In[77]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.00793651 3.63708 [
[.21429 -0.00456 -9 -9 ]
[.21429 -0.00456 9 0 ]
[.40476 -0.00456 -9 -9 ]
[.40476 -0.00456 9 0 ]
[.59524 -0.00456 -9 -9 ]
[.59524 -0.00456 9 0 ]
[.78571 -0.00456 -9 -9 ]
[.78571 -0.00456 9 0 ]
[.97619 -0.00456 -3 -9 ]
[.97619 -0.00456 3 0 ]
[.01131 .08068 -24 -4.5 ]
[.01131 .08068 0 4.5 ]
[.01131 .15342 -24 -4.5 ]
[.01131 .15342 0 4.5 ]
[.01131 .22616 -24 -4.5 ]
[.01131 .22616 0 4.5 ]
[.01131 .2989 -24 -4.5 ]
[.01131 .2989 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .00794 m
.21429 .01419 L
s
[(0.2)] .21429 -0.00456 0 1 Mshowa
.40476 .00794 m
.40476 .01419 L
s
[(0.4)] .40476 -0.00456 0 1 Mshowa
.59524 .00794 m
.59524 .01419 L
s
[(0.6)] .59524 -0.00456 0 1 Mshowa
.78571 .00794 m
.78571 .01419 L
s
[(0.8)] .78571 -0.00456 0 1 Mshowa
.97619 .00794 m
.97619 .01419 L
s
[(1)] .97619 -0.00456 0 1 Mshowa
.125 Mabswid
.07143 .00794 m
.07143 .01169 L
s
.11905 .00794 m
.11905 .01169 L
s
.16667 .00794 m
.16667 .01169 L
s
.2619 .00794 m
.2619 .01169 L
s
.30952 .00794 m
.30952 .01169 L
s
.35714 .00794 m
.35714 .01169 L
s
.45238 .00794 m
.45238 .01169 L
s
.5 .00794 m
.5 .01169 L
s
.54762 .00794 m
.54762 .01169 L
s
.64286 .00794 m
.64286 .01169 L
s
.69048 .00794 m
.69048 .01169 L
s
.7381 .00794 m
.7381 .01169 L
s
.83333 .00794 m
.83333 .01169 L
s
.88095 .00794 m
.88095 .01169 L
s
.92857 .00794 m
.92857 .01169 L
s
.25 Mabswid
0 .00794 m
1 .00794 L
s
.02381 .08068 m
.03006 .08068 L
s
[(0.02)] .01131 .08068 1 0 Mshowa
.02381 .15342 m
.03006 .15342 L
s
[(0.04)] .01131 .15342 1 0 Mshowa
.02381 .22616 m
.03006 .22616 L
s
[(0.06)] .01131 .22616 1 0 Mshowa
.02381 .2989 m
.03006 .2989 L
s
[(0.08)] .01131 .2989 1 0 Mshowa
.125 Mabswid
.02381 .02612 m
.02756 .02612 L
s
.02381 .04431 m
.02756 .04431 L
s
.02381 .06249 m
.02756 .06249 L
s
.02381 .09886 m
.02756 .09886 L
s
.02381 .11705 m
.02756 .11705 L
s
.02381 .13523 m
.02756 .13523 L
s
.02381 .17161 m
.02756 .17161 L
s
.02381 .18979 m
.02756 .18979 L
s
.02381 .20798 m
.02756 .20798 L
s
.02381 .24435 m
.02756 .24435 L
s
.02381 .26253 m
.02756 .26253 L
s
.02381 .28072 m
.02756 .28072 L
s
.02381 .31709 m
.02756 .31709 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.02381 .00794 m
.02605 .0121 L
.02846 .01618 L
.03053 .01915 L
.03163 .02044 L
.03279 .02157 L
.03344 .0221 L
.03416 .02258 L
.03543 .0232 L
.03672 .02351 L
.03793 .02353 L
.03911 .02332 L
.04019 .02297 L
.04143 .02241 L
.04262 .02177 L
.045 .02037 L
.0463 .01969 L
.04753 .0192 L
.04868 .01894 L
.04993 .01892 L
.05106 .01921 L
.0521 .01976 L
.05334 .02084 L
.0545 .02228 L
.05577 .02439 L
.05713 .02729 L
.05991 .03528 L
.06244 .04491 L
.07223 .0954 L
.07759 .12293 L
.08022 .13407 L
.08263 .14244 L
.08523 .14939 L
.0866 .15215 L
.08805 .15445 L
.08876 .15537 L
.08953 .1562 L
.0909 .15734 L
.09175 .15783 L
.09254 .15816 L
.09326 .15837 L
.09403 .15852 L
.0953 .15859 L
.09602 .15857 L
.0967 .15852 L
.09741 .15843 L
.09806 .15834 L
.09952 .15814 L
.10076 .15799 L
.10146 .15794 L
Mistroke
.10212 .15792 L
.10331 .15797 L
.10458 .15817 L
.10589 .15854 L
.10655 .1588 L
.10728 .15914 L
.10976 .16076 L
.11116 .16196 L
.11265 .16345 L
.11535 .16655 L
.12056 .17314 L
.12549 .17871 L
.1278 .18079 L
.13024 .18258 L
.13292 .18412 L
.1354 .18525 L
.1398 .18703 L
.14443 .18933 L
.14677 .19087 L
.14933 .19288 L
.15382 .19713 L
.15871 .20225 L
.16394 .20733 L
.17342 .21387 L
.18223 .21868 L
.22378 .25037 L
.26381 .28107 L
.28217 .2973 L
.29259 .30396 L
.30233 .31052 L
.30726 .31414 L
.31194 .31705 L
.31452 .3182 L
.31523 .31844 L
.31598 .31866 L
.31663 .31881 L
.31733 .31895 L
.31853 .3191 L
.31966 .31915 L
.32032 .31914 L
.32101 .3191 L
.32225 .31896 L
.32748 .31758 L
.33005 .3167 L
.33242 .31595 L
.33372 .31561 L
.33515 .31532 L
.3359 .31521 L
.33659 .31513 L
.33733 .31508 L
Mistroke
.33812 .31506 L
.33878 .31506 L
.33951 .3151 L
.34083 .31524 L
.34211 .31547 L
.3433 .31574 L
.34822 .31733 L
.35063 .31814 L
.35285 .31876 L
.35409 .31902 L
.35541 .31921 L
.35673 .3193 L
.35748 .3193 L
.35818 .31928 L
.3594 .31916 L
.36052 .31897 L
.3618 .31868 L
.36302 .31832 L
.36728 .31674 L
.36962 .31584 L
.37181 .31514 L
.37295 .31486 L
.37418 .31464 L
.37484 .31456 L
.37554 .31451 L
.37678 .3145 L
.37792 .3146 L
.37898 .31477 L
.38014 .31504 L
.38138 .31542 L
.38636 .31761 L
.38908 .31887 L
.39041 .31941 L
.39163 .31981 L
.39227 .31998 L
.39296 .32014 L
.39369 .32026 L
.39438 .32034 L
.39515 .32037 L
.39596 .32035 L
.39672 .32027 L
.39741 .32015 L
.39873 .31981 L
.39947 .31955 L
.40016 .31928 L
.40274 .31794 L
.40519 .31639 L
.40782 .31471 L
.40909 .31398 L
.41029 .31339 L
Mistroke
.41138 .31296 L
.41255 .31263 L
.4138 .31245 L
.41512 .31248 L
.41624 .31269 L
.41749 .31313 L
.41819 .31347 L
.41883 .31384 L
.42028 .31485 L
.4229 .31722 L
.42766 .32219 L
.42903 .32343 L
.43032 .32439 L
.43148 .32502 L
.43273 .32538 L
.43384 .3254 L
.43505 .32503 L
.43631 .32419 L
.43749 .32294 L
.4386 .32135 L
.43961 .31954 L
.44187 .31418 L
.44452 .30579 L
.44697 .29625 L
.45251 .27083 L
.45736 .2486 L
.45991 .23856 L
.46259 .22995 L
.46499 .22423 L
.46635 .22185 L
.46761 .22019 L
.46878 .21912 L
.46983 .21851 L
.47106 .2182 L
.47221 .21825 L
.47331 .21858 L
.47447 .21919 L
.47546 .21987 L
.47655 .22077 L
.48125 .22537 L
.48388 .22773 L
.48517 .22868 L
.48638 .22939 L
.4871 .22973 L
.48775 .22998 L
.48848 .2302 L
.48926 .23036 L
.48991 .23043 L
.49061 .23045 L
.49189 .23033 L
Mistroke
.49309 .23005 L
.49441 .22959 L
.49708 .22829 L
.50185 .22554 L
.50436 .22434 L
.50579 .22383 L
.5071 .2235 L
.50825 .22333 L
.50951 .22326 L
.51083 .22333 L
.51207 .22352 L
.51321 .22377 L
.51441 .22413 L
.51656 .22491 L
.52138 .22688 L
.52389 .22769 L
.52461 .22788 L
.52529 .22802 L
.52657 .22822 L
.52777 .22833 L
.52888 .22834 L
.5301 .22828 L
.53138 .22812 L
.53268 .22787 L
.53407 .22753 L
.53659 .22678 L
.53936 .22589 L
.54088 .22543 L
.54231 .22506 L
.54362 .22479 L
.54481 .22459 L
.54546 .22452 L
.54614 .22446 L
.54683 .22442 L
.54758 .2244 L
.5488 .22444 L
.55011 .22455 L
.55134 .22472 L
.55246 .22493 L
.55776 .22624 L
.56056 .22692 L
.56208 .22723 L
.56283 .22735 L
.56352 .22744 L
.56475 .22757 L
.56543 .22761 L
.56607 .22763 L
.56677 .22764 L
.56742 .22763 L
.56813 .22759 L
Mistroke
.56889 .22754 L
.56954 .22748 L
.57023 .22739 L
.57149 .2272 L
.57385 .22674 L
.57629 .22619 L
.57891 .22563 L
.58018 .22539 L
.58138 .2252 L
.58245 .22506 L
.58363 .22495 L
.58477 .22489 L
.58602 .22488 L
.58733 .22492 L
.58857 .22502 L
.58971 .22515 L
.59077 .22529 L
.59314 .22571 L
.59812 .22668 L
.59949 .2269 L
.60094 .22709 L
.60165 .22716 L
.60232 .22722 L
.60357 .22729 L
.60482 .22731 L
.60613 .22728 L
.60726 .22721 L
.6085 .2271 L
.60983 .22693 L
.61125 .22672 L
.61383 .22626 L
.61673 .22575 L
.61816 .22553 L
.61948 .22536 L
.62068 .22524 L
.62195 .22515 L
.62267 .22512 L
.62336 .2251 L
.62464 .22511 L
.62581 .22516 L
.62706 .22526 L
.62824 .22538 L
.62931 .22552 L
.63443 .22635 L
.63698 .22674 L
.63832 .22691 L
.63905 .22699 L
.63974 .22705 L
.64098 .22713 L
.64164 .22716 L
Mistroke
.64235 .22717 L
.64361 .22716 L
.64476 .22712 L
.6459 .22704 L
.64711 .22692 L
.64929 .22663 L
.65424 .22582 L
.6554 .22564 L
.65667 .22546 L
.65778 .22534 L
.65896 .22523 L
.66002 .22517 L
.66119 .22514 L
.66226 .22514 L
.66325 .22517 L
.66451 .22526 L
.66514 .22532 L
.66584 .22539 L
.66825 .22574 L
.67086 .22621 L
.67369 .22673 L
.67498 .22694 L
.67635 .22713 L
.67751 .22725 L
.67879 .22734 L
.67999 .22736 L
.68127 .22731 L
.68248 .2272 L
.68358 .22704 L
.68474 .22681 L
.68596 .22649 L
.68816 .22574 L
.69052 .22468 L
.69312 .22327 L
.70213 .21716 L
.74245 .18618 L
.78125 .15655 L
.8225 .12524 L
.86223 .095 L
.90045 .06581 L
.94113 .0349 L
.97619 .00794 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{229.938, 76.625},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003U0000C2000`400?l00000o`00003oiOooool0
03kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00005_ooool2o`0000Cooooo00?o0000
ooooooooool00oooool3o`0001Oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000G
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00007Oooool3o`0000Wooooo000moooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00005Oooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000001Gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000001gooooo00?o0000ooooooooool02?ooool003gooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Oooooo1Ol0000Fooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo00Sooooo000m
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0001Oooooo00Co0000oooooooooooo00001oooool4o`00
01Kooooo00Co0000oooooooooooo00002?ooool3o`0001kooooo00?o0000ooooooooool02?ooool0
03gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001Gooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00000Gooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool05oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000007Oooool00ol0003oooooooooo`08ooooo`00?Oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000005Oooool01?l0003oooooooooool00009ooooo`;o0000
5oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000001cooooo0_l0000:ooooo`00?_ooool2o`00
00Wooooo0ol0000Gooooo`;o00002oooool00ol0003oooooooooo`0Fooooo`;o00002_ooool2o`00
01Oooooo0_l00009ooooo`?o00007_ooool00ol0003oooooooooo`08ooooo`00iOooool00>Gooooo
000Oooooo`03o`000?oooooooooo0<?ooooo000JooooolKo00001Oooool001oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Wooooo000Oooooo`;o
00009?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000Wooooo000Oooooo`Oo
0000/Oooool00ol0003oooooooooo`0;ooooo`007oooool2o`0000Cooooo0_l0002_ooooo`03o`00
0?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0:[ooooo0_l0000@ooooo`007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0:Wooooo00?o0000ooooooooool04?ooool001oooooo0_l00006ooooo`03o`000?oooooooooo0:Oo
oooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Uooooo`;o00005?ooool001oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo01Cooooo000Oooooo`;o00001oooool00ol0003oooooooooo`2R
ooooo`03o`000?oooooooooo01Gooooo0006ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool5o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Poooo
o`;o00006?ooool000Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2Oooooo`03o`000?oooooooooo01Sooooo0005ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0Iooooo`001Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool2o`0000Oo
oooo00?o0000ooooooooool0W?ooool2o`0001cooooo0005ooooo`04o`000?ooooooooooo`0000So
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo01cooooo0005oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Iooooo`03o`00
0?oooooooooo01gooooo0006ooooo`;o00002_ooool2o`0000?ooooo0ol00005ooooo`;o00002?oo
ool00ol0003oooooooooo`2Gooooo`;o00008?ooool001oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo023ooooo000Oooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0U?ooool2o`0002?ooooo000Oooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0TOooool2o`0002Gooooo000Oooooo`;o00002Oooool00ol0003ooooo
ooooo`2@ooooo`03o`000?oooooooooo02Gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0S_ooool2o`0002Sooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0SOooool00ol0003oooooooooo`0Xooooo`007oooool2o`0000Wooooo00?o0000oooo
ooooool0S?ooool00ol0003oooooooooo`0Yooooo`007oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo08_ooooo00?o0000ooooooooool0:_ooool000Kooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`?o00001?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo08Wooooo00?o0000ooooooooool0:oooool000Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02cooooo0005ooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`0000Cooooo0_l0000:oooo
o`;o0000R?ooool00ol0003oooooooooo`0]ooooo`001Oooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00[ooooo1Ol00022ooooo`;o0000<?ooool000Gooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo033ooooo0005ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool2o`0000Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1looooo`;o0000<oooool000Kooooo0_l0000:ooooo`;o0000
1Oooool00ol0003oooooooooo`03ooooo`;o00004Oooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo03?ooooo000Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`0dooooo`007oooool00ol0003oooooooooo`0Booooo`;o0000M_ooool2
o`0003Oooooo000Oooooo`;o00005Oooool2o`0007?ooooo00?o0000ooooooooool0=oooool001oo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo03So
oooo000Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0iooooo`007oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool0>_ooool001oooooo0_l0000Jooooo`03o`000?oooooooooo06Wooooo00?o0000
ooooooooool0>oooool000Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`?o00001Oooool00ol0003oooooooooo`0Jooooo`;o0000J?ooool00ol0003oooooooooo`0loooo
o`001Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo0_l0000fooooo`?o0000:ooo
ool2o`0003oooooo0005ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00;ooooo0_l0000Oooooo`03o`000?oooooooooo03?o
oooo00Co0000oooooooooooo00000oooool4o`0000?ooooo1Ol00002ooooo`Ko00000_ooool6o`00
0003ooooool0003o000000Co000000Coooooo`000?l0003o0000@Oooool000Gooooo00Co0000oooo
oooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo1?l0
0004ooooo`?o00001?ooool4o`0000Cooooo0ol00004ooooo`?o0000@oooool000Gooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000oooooooo
ool08?ooool2o`00037ooooo00?o0000ooooooooool0KOooool000Gooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06gooooo0006ooooo`;o
00002_ooool2o`0000Cooooo0_l00005ooooo`;o00009?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo06gooooo000Oooooo`03o`000?oooooooooo02Cooooo0_l0000/ooooo`03o`00
0?oooooooooo06kooooo000Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1^ooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0K_ooool001oooooo0_l0000Yooooo`;o00009oooool00ol0
003oooooooooo`1_ooooo`007oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0Koooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo06oooooo000Oooooo`;o0000;Oooool2o`0002?ooooo00?o
0000ooooooooool0Koooool000Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003
ooooo`?o00001Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0L?ooool000Gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0L?ooool000Gooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0L?ooool000Go
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00001Oooool2
o`0003;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1`ooooo`001Oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03;ooooo0_l0000Looooo`03o`000?oooooooooo073ooooo
0005ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Boooo
o`;o00001Oooool00ol0003oooooooooo`1`ooooo`001_ooool2o`0000[ooooo0_l00003ooooo`?o
00001Oooool2o`0003Kooooo0_l00002ooooo`Go00000oooool4o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`03o`000?oooooooooo077ooooo000Oooooo`03o`000?oooooooooo03Kooooo
0ol00004ooooo`Co00001?ooool3o`0000Gooooo00?o0000ooooool00000Loooool001oooooo00?o
0000ooooooooool0COooool2o`0007Cooooo000Oooooo`03o`000?oooooooooo0<?ooooo0000\
\>"],
  ImageRangeCache->{{{78.875, 307.812}, {315.938, 240.312}} -> {-0.587548, \
0.319107, 0.00532515, 0.00139441}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[77]="]
}, Open  ]],

Cell["Five snapshots, one every 0.2 seconds: ", "Text"],

Cell[CellGroupData[{

Cell["Plot[ Evaluate[Table[U[50,x,t], {t,0,1,0.2}]], {x,0,L}]", "Input",
  CellLabel->"In[59]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 2.96713 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .0123 -24 -4.5 ]
[.01131 .0123 0 4.5 ]
[.01131 .16066 -30 -4.5 ]
[.01131 .16066 0 4.5 ]
[.01131 .45737 -24 -4.5 ]
[.01131 .45737 0 4.5 ]
[.01131 .60573 -18 -4.5 ]
[.01131 .60573 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .0123 m
.03006 .0123 L
s
[(-0.1)] .01131 .0123 1 0 Mshowa
.02381 .16066 m
.03006 .16066 L
s
[(-0.05)] .01131 .16066 1 0 Mshowa
.02381 .45737 m
.03006 .45737 L
s
[(0.05)] .01131 .45737 1 0 Mshowa
.02381 .60573 m
.03006 .60573 L
s
[(0.1)] .01131 .60573 1 0 Mshowa
.125 Mabswid
.02381 .04198 m
.02756 .04198 L
s
.02381 .07165 m
.02756 .07165 L
s
.02381 .10132 m
.02756 .10132 L
s
.02381 .13099 m
.02756 .13099 L
s
.02381 .19033 m
.02756 .19033 L
s
.02381 .22 m
.02756 .22 L
s
.02381 .24967 m
.02756 .24967 L
s
.02381 .27935 m
.02756 .27935 L
s
.02381 .33869 m
.02756 .33869 L
s
.02381 .36836 m
.02756 .36836 L
s
.02381 .39803 m
.02756 .39803 L
s
.02381 .4277 m
.02756 .4277 L
s
.02381 .48704 m
.02756 .48704 L
s
.02381 .51672 m
.02756 .51672 L
s
.02381 .54639 m
.02756 .54639 L
s
.02381 .57606 m
.02756 .57606 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .3331 L
.10458 .35938 L
.14415 .38405 L
.18221 .40776 L
.22272 .43302 L
.26171 .45732 L
.30316 .48314 L
.34309 .50802 L
.3815 .53196 L
.42237 .55737 L
.46172 .58179 L
.48147 .59453 L
.48566 .59753 L
.49012 .60035 L
.49268 .60164 L
.49501 .60253 L
.49613 .60284 L
.49735 .6031 L
.4985 .60325 L
.49955 .60332 L
.50074 .60331 L
.50186 .60321 L
.50308 .60302 L
.50439 .6027 L
.50576 .60227 L
.50706 .60175 L
.5095 .60056 L
.51896 .59421 L
.53984 .58091 L
.57817 .55706 L
.61895 .53169 L
.65822 .50722 L
.69597 .48368 L
.73617 .45864 L
.77486 .43453 L
.816 .40889 L
.85562 .38419 L
.89373 .36044 L
.93429 .33515 L
.97334 .31082 L
.97619 .30902 L
s
.02381 .30902 m
.02605 .31241 L
.02846 .31574 L
.03053 .31816 L
.03163 .31922 L
.03279 .32014 L
.03344 .32057 L
.03416 .32097 L
.03543 .32147 L
.03672 .32172 L
.03793 .32174 L
.03911 .32157 L
.04019 .32128 L
.04143 .32082 L
.04262 .3203 L
.045 .31916 L
.0463 .31861 L
.04753 .31821 L
.04868 .31799 L
.04993 .31798 L
.05106 .31821 L
.0521 .31867 L
.05334 .31954 L
.0545 .32072 L
.05577 .32244 L
.05713 .3248 L
.05991 .33132 L
.06244 .33918 L
.07223 .38037 L
.07759 .40283 L
.08022 .41191 L
.08263 .41875 L
.08523 .42441 L
.0866 .42667 L
.08805 .42854 L
.08876 .42929 L
.08953 .42997 L
.0909 .4309 L
.09175 .4313 L
.09254 .43157 L
.09326 .43174 L
.09403 .43186 L
.0953 .43192 L
.09602 .4319 L
.0967 .43186 L
.09741 .43179 L
.09806 .43172 L
.09952 .43155 L
.10076 .43143 L
.10146 .43139 L
Mistroke
.10212 .43138 L
.10331 .43142 L
.10458 .43157 L
.10589 .43188 L
.10655 .43209 L
.10728 .43237 L
.10976 .43369 L
.11116 .43467 L
.11265 .43589 L
.11535 .43842 L
.12056 .44379 L
.12549 .44833 L
.1278 .45003 L
.13024 .45149 L
.13292 .45275 L
.1354 .45367 L
.1398 .45512 L
.14443 .457 L
.14677 .45825 L
.14933 .45989 L
.15382 .46336 L
.15871 .46754 L
.16394 .47168 L
.17342 .47702 L
.18223 .48094 L
.22378 .5068 L
.26381 .53184 L
.28217 .54508 L
.29259 .55051 L
.30233 .55586 L
.30726 .55882 L
.31194 .56119 L
.31452 .56213 L
.31523 .56232 L
.31598 .5625 L
.31663 .56263 L
.31733 .56274 L
.31853 .56287 L
.31966 .56291 L
.32032 .5629 L
.32101 .56287 L
.32225 .56275 L
.32748 .56162 L
.33005 .5609 L
.33242 .5603 L
.33372 .56002 L
.33515 .55978 L
.3359 .55969 L
.33659 .55963 L
.33733 .55959 L
Mistroke
.33812 .55957 L
.33878 .55957 L
.33951 .5596 L
.34083 .55972 L
.34211 .5599 L
.3433 .56013 L
.34822 .56142 L
.35063 .56208 L
.35285 .56259 L
.35409 .5628 L
.35541 .56295 L
.35673 .56303 L
.35748 .56303 L
.35818 .56301 L
.3594 .56291 L
.36052 .56276 L
.3618 .56252 L
.36302 .56223 L
.36728 .56094 L
.36962 .56021 L
.37181 .55963 L
.37295 .5594 L
.37418 .55922 L
.37484 .55916 L
.37554 .55912 L
.37678 .55911 L
.37792 .55919 L
.37898 .55933 L
.38014 .55955 L
.38138 .55986 L
.38636 .56164 L
.38908 .56268 L
.39041 .56311 L
.39163 .56344 L
.39227 .56358 L
.39296 .56371 L
.39369 .56381 L
.39438 .56387 L
.39515 .5639 L
.39596 .56388 L
.39672 .56382 L
.39741 .56372 L
.39873 .56345 L
.39947 .56323 L
.40016 .56301 L
.40274 .56192 L
.40519 .56066 L
.40782 .55929 L
.40909 .55869 L
.41029 .55821 L
Mistroke
.41138 .55786 L
.41255 .55759 L
.4138 .55744 L
.41512 .55746 L
.41624 .55764 L
.41749 .55799 L
.41819 .55827 L
.41883 .55857 L
.42028 .5594 L
.4229 .56133 L
.42766 .56539 L
.42903 .5664 L
.43032 .56718 L
.43148 .56769 L
.43273 .56799 L
.43384 .568 L
.43505 .5677 L
.43631 .56702 L
.43749 .566 L
.4386 .5647 L
.43961 .56322 L
.44187 .55885 L
.44452 .552 L
.44697 .54422 L
.45251 .52349 L
.45736 .50535 L
.45991 .49716 L
.46259 .49013 L
.46499 .48547 L
.46635 .48353 L
.46761 .48217 L
.46878 .4813 L
.46983 .4808 L
.47106 .48055 L
.47221 .48059 L
.47331 .48086 L
.47447 .48135 L
.47546 .48191 L
.47655 .48264 L
.48125 .4864 L
.48388 .48833 L
.48517 .4891 L
.48638 .48968 L
.4871 .48996 L
.48775 .49016 L
.48848 .49034 L
.48926 .49047 L
.48991 .49053 L
.49061 .49054 L
.49189 .49044 L
Mistroke
.49309 .49022 L
.49441 .48985 L
.49708 .48878 L
.50185 .48654 L
.50436 .48556 L
.50579 .48515 L
.5071 .48488 L
.50825 .48474 L
.50951 .48468 L
.51083 .48474 L
.51207 .48489 L
.51321 .4851 L
.51441 .48539 L
.51656 .48602 L
.52138 .48763 L
.52389 .4883 L
.52461 .48844 L
.52529 .48856 L
.52657 .48873 L
.52777 .48881 L
.52888 .48882 L
.5301 .48877 L
.53138 .48864 L
.53268 .48844 L
.53407 .48816 L
.53659 .48755 L
.53936 .48682 L
.54088 .48645 L
.54231 .48615 L
.54362 .48592 L
.54481 .48577 L
.54546 .4857 L
.54614 .48565 L
.54683 .48562 L
.54758 .48561 L
.5488 .48564 L
.55011 .48573 L
.55134 .48587 L
.55246 .48604 L
.55776 .48711 L
.56056 .48767 L
.56208 .48791 L
.56283 .48801 L
.56352 .48809 L
.56475 .48819 L
.56543 .48823 L
.56607 .48824 L
.56677 .48825 L
.56742 .48824 L
.56813 .48821 L
Mistroke
.56889 .48817 L
.56954 .48812 L
.57023 .48805 L
.57149 .48789 L
.57385 .48752 L
.57629 .48707 L
.57891 .48661 L
.58018 .48641 L
.58138 .48626 L
.58245 .48615 L
.58363 .48606 L
.58477 .48601 L
.58602 .486 L
.58733 .48604 L
.58857 .48611 L
.58971 .48622 L
.59077 .48634 L
.59314 .48668 L
.59812 .48747 L
.59949 .48765 L
.60094 .4878 L
.60165 .48786 L
.60232 .48791 L
.60357 .48797 L
.60482 .48798 L
.60613 .48796 L
.60726 .4879 L
.6085 .48781 L
.60983 .48767 L
.61125 .4875 L
.61383 .48713 L
.61673 .48671 L
.61816 .48653 L
.61948 .48639 L
.62068 .48629 L
.62195 .48622 L
.62267 .48619 L
.62336 .48618 L
.62464 .48619 L
.62581 .48623 L
.62706 .48631 L
.62824 .48641 L
.62931 .48652 L
.63443 .4872 L
.63698 .48752 L
.63832 .48766 L
.63905 .48772 L
.63974 .48777 L
.64098 .48784 L
.64164 .48786 L
Mistroke
.64235 .48787 L
.64361 .48786 L
.64476 .48782 L
.6459 .48776 L
.64711 .48766 L
.64929 .48743 L
.65424 .48676 L
.6554 .48662 L
.65667 .48648 L
.65778 .48637 L
.65896 .48629 L
.66002 .48624 L
.66119 .48621 L
.66226 .48621 L
.66325 .48624 L
.66451 .48631 L
.66514 .48635 L
.66584 .48642 L
.66825 .4867 L
.67086 .48708 L
.67369 .48751 L
.67498 .48768 L
.67635 .48784 L
.67751 .48794 L
.67879 .488 L
.67999 .48802 L
.68127 .48798 L
.68248 .48789 L
.68358 .48776 L
.68474 .48757 L
.68596 .48731 L
.68816 .4867 L
.69052 .48584 L
.69312 .48468 L
.70213 .4797 L
.74245 .45442 L
.78125 .43026 L
.8225 .40471 L
.86223 .38004 L
.90045 .35623 L
.94113 .33101 L
.97619 .30902 L
Mfstroke
.02381 .30902 m
.06244 .33286 L
.08255 .3463 L
.08518 .34887 L
.08802 .35135 L
.09053 .35313 L
.0932 .35455 L
.09467 .35515 L
.0963 .35566 L
.09916 .3563 L
.10199 .35683 L
.10458 .35742 L
.10583 .35781 L
.10719 .35833 L
.10968 .3596 L
.11252 .36156 L
.11516 .36382 L
.12035 .36871 L
.12281 .37074 L
.12388 .37148 L
.12507 .37216 L
.12618 .37265 L
.12735 .37299 L
.12863 .37315 L
.12982 .37308 L
.13095 .37282 L
.13199 .37243 L
.13318 .3718 L
.1343 .37104 L
.13898 .36671 L
.14147 .36422 L
.14278 .36304 L
.14415 .362 L
.14539 .36129 L
.1461 .36101 L
.14675 .36083 L
.1479 .36075 L
.14913 .361 L
.15039 .36168 L
.15158 .36272 L
.15265 .364 L
.15381 .36577 L
.1564 .37114 L
.15914 .37878 L
.16406 .3962 L
.169 .41528 L
.17369 .43121 L
.17572 .43673 L
.17789 .44145 L
.17914 .44359 L
Mistroke
.18027 .44517 L
.18141 .44642 L
.18248 .44729 L
.18363 .44793 L
.18485 .44828 L
.18588 .44835 L
.18702 .4482 L
.18824 .44783 L
.18955 .44722 L
.19192 .44575 L
.19441 .44399 L
.19713 .44217 L
.19837 .44145 L
.19969 .44081 L
.20081 .44038 L
.20206 .44003 L
.2033 .43981 L
.20444 .43972 L
.20569 .43975 L
.207 .43991 L
.20815 .44014 L
.20922 .44042 L
.21164 .44122 L
.21618 .44287 L
.21818 .44347 L
.21924 .44373 L
.22037 .44395 L
.22164 .44412 L
.22283 .44421 L
.22353 .44423 L
.22419 .44423 L
.22543 .44417 L
.2261 .44412 L
.2268 .44404 L
.22806 .44385 L
.23092 .44327 L
.23339 .4427 L
.23605 .44213 L
.23727 .4419 L
.23856 .44171 L
.23966 .44158 L
.24087 .44148 L
.24202 .44143 L
.24308 .44142 L
.24429 .44145 L
.24544 .44152 L
.24651 .44161 L
.24749 .44172 L
.2497 .44202 L
.25441 .44273 L
Mistroke
.25576 .44291 L
.25705 .44305 L
.25821 .44316 L
.25947 .44324 L
.26074 .44329 L
.2619 .4433 L
.26254 .4433 L
.26323 .44329 L
.26449 .44324 L
.26567 .44317 L
.26691 .44307 L
.26914 .44285 L
.27352 .4424 L
.27478 .44228 L
.27597 .44219 L
.27706 .44212 L
.27821 .44206 L
.27947 .44202 L
.28064 .44201 L
.2819 .44202 L
.28262 .44203 L
.2833 .44205 L
.28449 .44209 L
.28558 .44215 L
.28804 .44231 L
.29326 .44267 L
.29477 .44276 L
.29618 .44282 L
.29746 .44286 L
.29818 .44288 L
.29884 .44289 L
.30001 .44289 L
.30111 .44289 L
.30231 .44287 L
.3036 .44283 L
.30496 .44279 L
.30624 .44273 L
.30865 .44262 L
.31093 .44251 L
.31307 .44243 L
.31426 .44239 L
.31554 .44236 L
.31671 .44233 L
.31778 .44232 L
.31897 .44232 L
.32028 .44232 L
.32094 .44233 L
.32164 .44234 L
.32292 .44236 L
.32541 .44242 L
Mistroke
.32768 .44248 L
.33034 .44255 L
.33175 .44258 L
.33323 .44261 L
.33453 .44263 L
.33527 .44264 L
.33596 .44264 L
.33718 .44265 L
.33848 .44265 L
.33917 .44265 L
.33981 .44264 L
.34101 .44264 L
.34231 .44263 L
.34372 .44261 L
.34858 .44256 L
.35002 .44255 L
.35137 .44254 L
.35278 .44253 L
.35352 .44253 L
.35432 .44252 L
.355 .44252 L
.35574 .44252 L
.35644 .44252 L
.35709 .44252 L
.35831 .44252 L
.35961 .44252 L
.36084 .44252 L
.36197 .44252 L
.36322 .44252 L
.36453 .44252 L
.36567 .44252 L
.36674 .44251 L
.36915 .4425 L
.37177 .44248 L
.37306 .44248 L
.37425 .44247 L
.37491 .44247 L
.37562 .44247 L
.37632 .44247 L
.3771 .44247 L
.37775 .44247 L
.37844 .44247 L
.37969 .44248 L
.3846 .44254 L
.38982 .44264 L
.39137 .44266 L
.39213 .44267 L
.39282 .44268 L
.39413 .44268 L
.39482 .44269 L
Mistroke
.39555 .44269 L
.39686 .44268 L
.39808 .44267 L
.39878 .44266 L
.39942 .44265 L
.40086 .44262 L
.40581 .44248 L
.40842 .4424 L
.40984 .44237 L
.41118 .44234 L
.41235 .44232 L
.4136 .44231 L
.41428 .44231 L
.41499 .44231 L
.41626 .44232 L
.41743 .44234 L
.41851 .44237 L
.42096 .44244 L
.42602 .44266 L
.42868 .44276 L
.43003 .4428 L
.43079 .44282 L
.4315 .44283 L
.43281 .44285 L
.434 .44285 L
.43466 .44284 L
.43537 .44283 L
.43668 .4428 L
.43788 .44276 L
.43915 .44271 L
.44145 .44259 L
.44569 .44235 L
.44686 .44229 L
.44809 .44223 L
.44915 .44219 L
.45028 .44216 L
.45152 .44214 L
.45268 .44214 L
.45339 .44214 L
.45406 .44215 L
.45531 .44219 L
.45649 .44223 L
.45758 .44228 L
.46004 .44244 L
.4647 .44277 L
.46604 .44286 L
.46732 .44293 L
.46846 .44298 L
.46971 .44302 L
.47091 .44303 L
Mistroke
.47199 .44303 L
.47324 .44301 L
.47441 .44298 L
.4755 .44292 L
.47651 .44286 L
.47877 .44269 L
.48128 .44247 L
.48396 .44223 L
.48526 .44213 L
.4865 .44205 L
.4876 .44199 L
.4888 .44195 L
.49008 .44192 L
.49072 .44192 L
.49143 .44193 L
.49268 .44196 L
.49386 .44202 L
.49453 .44206 L
.49525 .44211 L
.49652 .44222 L
.4994 .44252 L
.50176 .44278 L
.50431 .44304 L
.50548 .44314 L
.50673 .44322 L
.50778 .44327 L
.50895 .44329 L
.50964 .4433 L
.51028 .44329 L
.51101 .44327 L
.51171 .44325 L
.51295 .44318 L
.51365 .44312 L
.51429 .44306 L
.51915 .44247 L
.52135 .44216 L
.52373 .44187 L
.52483 .44177 L
.52598 .44168 L
.52697 .44163 L
.52805 .4416 L
.52929 .4416 L
.52998 .44162 L
.53062 .44165 L
.53185 .44173 L
.53302 .44185 L
.53517 .44213 L
.53752 .44252 L
.54206 .44328 L
.54337 .44346 L
Mistroke
.54461 .44359 L
.54573 .44368 L
.54694 .44373 L
.54765 .44373 L
.54829 .44373 L
.54903 .4437 L
.54973 .44366 L
.55097 .44355 L
.55166 .44347 L
.55231 .44338 L
.55475 .44294 L
.55734 .44238 L
.55983 .44182 L
.56121 .44154 L
.56252 .44132 L
.56373 .44115 L
.56505 .44103 L
.56624 .44098 L
.56735 .44098 L
.56866 .44106 L
.56989 .4412 L
.57059 .44131 L
.57124 .44142 L
.57269 .44174 L
.57836 .44339 L
.58079 .44405 L
.58199 .44432 L
.58309 .44451 L
.58436 .44465 L
.58503 .44469 L
.58574 .4447 L
.58689 .44466 L
.58815 .44452 L
.58933 .4443 L
.59042 .44403 L
.59286 .4432 L
.59726 .44127 L
.59972 .44026 L
.60107 .4398 L
.60234 .43948 L
.60306 .43935 L
.60385 .43926 L
.60456 .43922 L
.60521 .43923 L
.60651 .43937 L
.60716 .4395 L
.60788 .4397 L
.60919 .44019 L
.6104 .44078 L
.61309 .44252 L
Mistroke
.61541 .44431 L
.61796 .44631 L
.61915 .44715 L
.62044 .44792 L
.62166 .44847 L
.62277 .44879 L
.62396 .44889 L
.62526 .44867 L
.62592 .44842 L
.62662 .44804 L
.62789 .44704 L
.62907 .44572 L
.63036 .44386 L
.6327 .43931 L
.63497 .4335 L
.63706 .42707 L
.64224 .40814 L
.6478 .38711 L
.65049 .37831 L
.65304 .37147 L
.65533 .3668 L
.65663 .36482 L
.65783 .3634 L
.65902 .36239 L
.66029 .36172 L
.6615 .36145 L
.66261 .36148 L
.66361 .36172 L
.66471 .36218 L
.66586 .36285 L
.66693 .36361 L
.67191 .36789 L
.67436 .36983 L
.67543 .37054 L
.67661 .37119 L
.67783 .37171 L
.67912 .37207 L
.67979 .37219 L
.68052 .37225 L
.68184 .37222 L
.68311 .37201 L
.68432 .37168 L
.6854 .37128 L
.68659 .37076 L
.69208 .36786 L
.6934 .36722 L
.69478 .36664 L
.69606 .3662 L
.69726 .36589 L
.6984 .3657 L
Mistroke
.69962 .36561 L
.70032 .36561 L
.70098 .36564 L
.70222 .36578 L
.70286 .3659 L
.70355 .36605 L
.70478 .3664 L
.70758 .36739 L
.71208 .36916 L
.71331 .36958 L
.71461 .36995 L
.71572 .3702 L
.71693 .37039 L
.71822 .37051 L
.71894 .37053 L
.71959 .37052 L
.72087 .37043 L
.72207 .37026 L
.72328 .37003 L
.72439 .36976 L
.7269 .36901 L
.72962 .36813 L
.7322 .36737 L
.73363 .36703 L
.73438 .36689 L
.73518 .36676 L
.73592 .36667 L
.73659 .36661 L
.7379 .36655 L
.73915 .36658 L
.7403 .36667 L
.74156 .36684 L
.7429 .36708 L
.74759 .36828 L
.74984 .36889 L
.75197 .36938 L
.75315 .3696 L
.75443 .36978 L
.75559 .36988 L
.75666 .36993 L
.75784 .36993 L
.75913 .36985 L
.75979 .36979 L
.76049 .3697 L
.76176 .36951 L
.76424 .369 L
.76651 .36845 L
.76923 .3678 L
.77177 .36731 L
.77305 .36713 L
Mistroke
.77376 .36706 L
.77441 .367 L
.77513 .36697 L
.7759 .36695 L
.77663 .36695 L
.7773 .36697 L
.77856 .36705 L
.77975 .36718 L
.78082 .36734 L
.78199 .36754 L
.78702 .36862 L
.7893 .36908 L
.79056 .36929 L
.79173 .36945 L
.79273 .36955 L
.79381 .36963 L
.795 .36966 L
.7961 .36965 L
.7973 .36959 L
.79858 .36947 L
.7998 .36931 L
.8009 .36914 L
.80615 .36809 L
.80877 .36761 L
.81024 .36739 L
.81094 .36731 L
.8116 .36725 L
.81279 .36717 L
.8141 .36713 L
.81538 .36715 L
.8161 .36719 L
.81675 .36724 L
.81804 .36736 L
.81925 .36753 L
.82152 .36791 L
.82417 .36843 L
.8266 .3689 L
.82874 .36923 L
.82982 .36936 L
.831 .36947 L
.83218 .36953 L
.83345 .36955 L
.83465 .36952 L
.83575 .36945 L
.83703 .36932 L
.8384 .36914 L
.84085 .36872 L
.84371 .36816 L
.84639 .36767 L
.84752 .3675 L
Mistroke
.8487 .36735 L
.85 .36724 L
.85119 .36717 L
.8525 .36716 L
.85371 .3672 L
.85441 .36724 L
.85505 .3673 L
.85648 .36746 L
.86129 .36835 L
.86365 .36885 L
.8658 .36926 L
.86689 .36942 L
.86807 .36957 L
.86932 .36966 L
.8705 .3697 L
.8718 .36966 L
.87253 .36961 L
.87318 .36954 L
.87447 .36934 L
.87567 .36908 L
.87699 .36871 L
.87838 .36824 L
.88088 .36721 L
.8865 .36423 L
.89647 .35851 L
.93451 .3346 L
.975 .30961 L
.97619 .30902 L
Mfstroke
.02381 .30902 m
.06244 .28482 L
.08255 .27276 L
.0932 .26682 L
.09916 .26211 L
.10458 .25765 L
.10963 .25418 L
.11248 .25273 L
.11384 .25219 L
.11511 .25176 L
.11741 .25117 L
.11863 .25095 L
.11994 .25077 L
.1206 .2507 L
.12132 .25063 L
.12262 .25054 L
.12389 .25048 L
.12507 .25043 L
.12756 .25035 L
.12879 .25031 L
.12991 .25026 L
.13202 .25013 L
.1343 .24993 L
.13906 .24941 L
.14167 .24913 L
.14296 .24901 L
.14415 .24893 L
.14533 .24887 L
.14659 .24883 L
.14785 .24883 L
.14857 .24884 L
.14924 .24887 L
.15041 .24893 L
.15148 .24902 L
.15389 .24928 L
.1586 .24995 L
.16089 .25027 L
.16189 .25038 L
.16298 .25049 L
.16417 .25058 L
.1653 .25063 L
.16659 .25065 L
.16778 .25063 L
.169 .25057 L
.16969 .25052 L
.17034 .25046 L
.17304 .25013 L
.17811 .24931 L
.18079 .24892 L
.18156 .24883 L
Mistroke
.18228 .24875 L
.18294 .2487 L
.18364 .24865 L
.18428 .24862 L
.18499 .2486 L
.18624 .2486 L
.18694 .24862 L
.18769 .24865 L
.18839 .2487 L
.18904 .24876 L
.19027 .24889 L
.19161 .24908 L
.19405 .2495 L
.19884 .25036 L
.20001 .25053 L
.20126 .25068 L
.20198 .25075 L
.20264 .2508 L
.20393 .25086 L
.20509 .25087 L
.20617 .25084 L
.20736 .25076 L
.20862 .25063 L
.20996 .25045 L
.21121 .25024 L
.21356 .24978 L
.21578 .24932 L
.21816 .24886 L
.21932 .24868 L
.22041 .24854 L
.22139 .24844 L
.22246 .24837 L
.22363 .24834 L
.22488 .24836 L
.22594 .24842 L
.22711 .24854 L
.22837 .24871 L
.22974 .24895 L
.23221 .24947 L
.23723 .2506 L
.23845 .25081 L
.23975 .251 L
.2405 .25108 L
.24118 .25113 L
.24187 .25117 L
.24252 .25118 L
.24368 .25117 L
.24492 .2511 L
.24597 .25099 L
.24714 .25082 L
Mistroke
.24972 .25028 L
.25215 .24966 L
.25436 .24907 L
.25673 .2485 L
.25788 .24828 L
.25896 .24812 L
.25993 .24801 L
.26098 .24794 L
.26224 .24792 L
.26287 .24794 L
.26357 .24798 L
.2648 .24812 L
.26595 .24831 L
.26732 .2486 L
.26857 .24892 L
.27137 .24977 L
.2738 .25054 L
.27508 .25091 L
.27644 .25125 L
.27763 .25149 L
.27894 .25168 L
.28013 .25178 L
.28124 .2518 L
.28233 .25174 L
.28351 .25161 L
.28475 .25138 L
.2859 .2511 L
.29016 .24961 L
.29259 .24865 L
.29516 .24775 L
.29622 .24745 L
.29736 .2472 L
.29861 .24702 L
.29977 .24695 L
.30042 .24696 L
.30113 .247 L
.30242 .24718 L
.30367 .24746 L
.30483 .24783 L
.30748 .24897 L
.31031 .25045 L
.313 .25186 L
.31431 .25246 L
.31552 .25292 L
.31663 .25324 L
.31779 .25346 L
.31896 .25355 L
.32025 .25347 L
.3215 .25321 L
.32268 .2528 L
Mistroke
.32374 .2523 L
.3249 .25163 L
.32987 .24764 L
.33213 .24568 L
.33337 .24471 L
.33453 .24394 L
.33552 .2434 L
.33658 .243 L
.33776 .24278 L
.33884 .24283 L
.34012 .24323 L
.34134 .24399 L
.34242 .245 L
.3436 .24647 L
.34489 .24851 L
.34624 .25118 L
.34868 .25721 L
.35303 .27137 L
.35782 .28965 L
.36299 .30853 L
.36583 .31701 L
.36723 .32046 L
.36853 .3232 L
.36972 .32531 L
.37104 .32718 L
.37236 .32859 L
.37308 .32917 L
.37376 .32959 L
.37496 .33006 L
.37606 .33022 L
.37726 .33011 L
.37854 .32973 L
.37977 .32913 L
.38111 .3283 L
.38353 .32648 L
.38807 .32302 L
.3894 .3222 L
.39065 .32156 L
.39195 .32106 L
.39264 .32086 L
.39338 .32069 L
.39469 .32054 L
.39593 .32055 L
.39705 .32067 L
.39827 .32093 L
.40281 .32262 L
.4052 .3237 L
.40773 .32474 L
.40994 .32545 L
.4112 .32573 L
Mistroke
.41237 .32591 L
.41344 .32601 L
.41443 .32603 L
.41556 .32598 L
.41663 .32587 L
.41788 .32567 L
.41921 .32538 L
.42159 .32472 L
.42436 .32387 L
.42697 .32314 L
.42911 .32267 L
.43032 .32248 L
.43142 .32236 L
.43257 .32229 L
.43382 .32229 L
.43512 .32235 L
.43633 .32247 L
.44152 .32343 L
.44425 .32405 L
.44574 .32436 L
.44713 .32461 L
.44845 .3248 L
.44966 .32493 L
.45035 .32498 L
.451 .32502 L
.45168 .32505 L
.45243 .32505 L
.45366 .32503 L
.45497 .32495 L
.45608 .32484 L
.45732 .32469 L
.4624 .32385 L
.46506 .32341 L
.46652 .32321 L
.46788 .32307 L
.46907 .32298 L
.47035 .32292 L
.47108 .32291 L
.47176 .32291 L
.47305 .32294 L
.47424 .323 L
.47533 .32309 L
.4778 .32336 L
.48247 .324 L
.48475 .32428 L
.48574 .32438 L
.48683 .32447 L
.48796 .32455 L
.48903 .32459 L
.49025 .32461 L
Mistroke
.49139 .3246 L
.49266 .32456 L
.49381 .3245 L
.49515 .3244 L
.4964 .32429 L
.50145 .32374 L
.50392 .32349 L
.505 .32341 L
.50617 .32333 L
.50739 .32328 L
.50854 .32325 L
.50986 .32324 L
.51109 .32326 L
.51233 .3233 L
.51304 .32334 L
.51371 .32337 L
.51649 .32358 L
.52082 .32397 L
.52318 .32416 L
.52433 .32423 L
.52538 .32428 L
.52653 .32432 L
.52776 .32434 L
.52841 .32435 L
.52911 .32435 L
.53038 .32433 L
.53154 .32429 L
.53276 .32424 L
.53496 .32411 L
.5398 .32376 L
.54219 .32361 L
.54335 .32356 L
.5444 .32351 L
.54563 .32348 L
.54694 .32346 L
.54762 .32346 L
.54836 .32346 L
.54906 .32347 L
.5497 .32348 L
.55082 .32351 L
.55205 .32356 L
.55454 .32368 L
.55912 .32393 L
.56044 .324 L
.56168 .32405 L
.56282 .32409 L
.56402 .32413 L
.56507 .32414 L
.56622 .32415 L
.56727 .32415 L
Mistroke
.56825 .32415 L
.56941 .32413 L
.57047 .3241 L
.57285 .32402 L
.57761 .32382 L
.57887 .32377 L
.58023 .32372 L
.5814 .32369 L
.58269 .32366 L
.5839 .32364 L
.58518 .32364 L
.58637 .32364 L
.58748 .32364 L
.58857 .32366 L
.58957 .32367 L
.59182 .32373 L
.59691 .32387 L
.59831 .32391 L
.59979 .32394 L
.60106 .32396 L
.60178 .32397 L
.60246 .32398 L
.60369 .32399 L
.60499 .32399 L
.60609 .32399 L
.60731 .32398 L
.60862 .32396 L
.61002 .32395 L
.61254 .32391 L
.61512 .32387 L
.61654 .32385 L
.61786 .32383 L
.61908 .32382 L
.6202 .32381 L
.62144 .3238 L
.62212 .3238 L
.62277 .3238 L
.62347 .3238 L
.6241 .3238 L
.62483 .3238 L
.62552 .3238 L
.62675 .3238 L
.62808 .32381 L
.63084 .32382 L
.63159 .32382 L
.6324 .32382 L
.63317 .32382 L
.63387 .32382 L
.63512 .32383 L
.63583 .32383 L
Mistroke
.63649 .32382 L
.63769 .32382 L
.63897 .32382 L
.64021 .32382 L
.64085 .32382 L
.64153 .32382 L
.6423 .32382 L
.64299 .32382 L
.64365 .32382 L
.64436 .32382 L
.64563 .32382 L
.64678 .32383 L
.64742 .32383 L
.64811 .32384 L
.64936 .32385 L
.65178 .32388 L
.65401 .32391 L
.65641 .32394 L
.6576 .32396 L
.65869 .32397 L
.65995 .32398 L
.66061 .32398 L
.66132 .32399 L
.66258 .32399 L
.66372 .32398 L
.66489 .32397 L
.66597 .32395 L
.66715 .32393 L
.6684 .3239 L
.6728 .32377 L
.67526 .3237 L
.67661 .32366 L
.6779 .32363 L
.67909 .32361 L
.68038 .3236 L
.68156 .3236 L
.68265 .32361 L
.68394 .32364 L
.68514 .32367 L
.68646 .32371 L
.68789 .32377 L
.69058 .3239 L
.69344 .32405 L
.69486 .32412 L
.69619 .32417 L
.69739 .32421 L
.69868 .32423 L
.69991 .32424 L
.70121 .32423 L
.70233 .32421 L
Mistroke
.70354 .32417 L
.70428 .32414 L
.70498 .32411 L
.7063 .32403 L
.70925 .32382 L
.71183 .32361 L
.71324 .32351 L
.71457 .32342 L
.71581 .32336 L
.71695 .32332 L
.71821 .32329 L
.71887 .32328 L
.71957 .32328 L
.72071 .3233 L
.72178 .32334 L
.72295 .3234 L
.72419 .32349 L
.72702 .32376 L
.72968 .32406 L
.73225 .32434 L
.73351 .32446 L
.73466 .32455 L
.73581 .32461 L
.73689 .32465 L
.73804 .32467 L
.73929 .32465 L
.74057 .3246 L
.74128 .32455 L
.74193 .3245 L
.74438 .32423 L
.74933 .32345 L
.75193 .32306 L
.75335 .32289 L
.75404 .32282 L
.75467 .32276 L
.75581 .3227 L
.75704 .32267 L
.75767 .32268 L
.75837 .3227 L
.75963 .32277 L
.76077 .32289 L
.76199 .32306 L
.76418 .32347 L
.76854 .3245 L
.77092 .32503 L
.77207 .32525 L
.77312 .32541 L
.77426 .32554 L
.77547 .32562 L
.77678 .32562 L
Mistroke
.77803 .32554 L
.77915 .32541 L
.78018 .32522 L
.78132 .32496 L
.78252 .32462 L
.78775 .32271 L
.7903 .3218 L
.79142 .32147 L
.79263 .32119 L
.79375 .32102 L
.79479 .32094 L
.79578 .32094 L
.79683 .32104 L
.79794 .32125 L
.79898 .32155 L
.80012 .32198 L
.80135 .32258 L
.8063 .32587 L
.80872 .3276 L
.81092 .32891 L
.81206 .3294 L
.8133 .32973 L
.81446 .32981 L
.81554 .32966 L
.81668 .32923 L
.81794 .32841 L
.81925 .32713 L
.82048 .32553 L
.82311 .32071 L
.82552 .31471 L
.83093 .29663 L
.83623 .27623 L
.83914 .26569 L
.84187 .2571 L
.84443 .2507 L
.84578 .24805 L
.8472 .24581 L
.8484 .24438 L
.84971 .24327 L
.85091 .24267 L
.85202 .24242 L
.85321 .24247 L
.85449 .24285 L
.8557 .24345 L
.85682 .2442 L
.86119 .24801 L
.86365 .25019 L
.86596 .2519 L
.86712 .25258 L
.86837 .25314 L
Mistroke
.86904 .25337 L
.86975 .25356 L
.87102 .25376 L
.87232 .25378 L
.8735 .25365 L
.87416 .25353 L
.87486 .25336 L
.87615 .25298 L
.87842 .25215 L
.88092 .25122 L
.88234 .2508 L
.88302 .25064 L
.88366 .25052 L
.88439 .25043 L
.88506 .25039 L
.88577 .25039 L
.88656 .25046 L
.88786 .25072 L
.88859 .25095 L
.88925 .25122 L
.89054 .25188 L
.89175 .25268 L
.93037 .27789 L
.93983 .28702 L
.94233 .2895 L
.94504 .29188 L
.94743 .29359 L
.94996 .29499 L
.9514 .2956 L
.95299 .29615 L
.95578 .29688 L
.95855 .29749 L
.96108 .29815 L
.96365 .29909 L
.96507 .29976 L
.96643 .30052 L
.97144 .30435 L
.97619 .30902 L
Mfstroke
.02381 .30902 m
.06244 .2849 L
.10458 .25838 L
.14415 .23364 L
.18221 .2099 L
.22272 .18453 L
.26171 .16012 L
.28158 .14915 L
.29205 .14149 L
.29779 .13734 L
.30059 .13562 L
.30316 .13431 L
.30543 .13337 L
.30791 .13259 L
.30928 .13226 L
.31054 .13201 L
.31174 .13181 L
.31304 .13164 L
.31446 .1315 L
.3158 .1314 L
.3171 .13132 L
.3183 .13127 L
.32392 .13105 L
.32874 .13082 L
.33109 .1307 L
.33324 .13061 L
.3344 .13057 L
.3355 .13054 L
.33667 .13053 L
.33793 .13052 L
.33923 .13054 L
.33989 .13056 L
.34061 .13058 L
.34189 .13064 L
.34309 .13071 L
.34818 .13111 L
.35066 .13131 L
.35292 .13146 L
.35415 .13153 L
.35531 .13156 L
.35653 .13158 L
.35722 .13159 L
.35786 .13158 L
.35911 .13155 L
.35982 .13152 L
.36049 .13149 L
.36183 .1314 L
.36327 .13128 L
.36823 .13077 L
.37067 .13054 L
Mistroke
.37186 .13044 L
.37294 .13037 L
.37399 .13032 L
.37498 .13029 L
.37603 .13028 L
.37716 .13029 L
.37833 .13033 L
.37957 .13039 L
.38062 .13047 L
.38177 .13058 L
.38703 .1312 L
.38962 .1315 L
.39075 .13161 L
.392 .13171 L
.39312 .13177 L
.39417 .13181 L
.39528 .13182 L
.39647 .1318 L
.3977 .13175 L
.399 .13166 L
.40011 .13155 L
.40132 .13142 L
.40657 .13067 L
.40795 .13048 L
.40945 .1303 L
.41087 .13017 L
.41217 .13008 L
.41339 .13003 L
.41409 .13002 L
.41474 .13002 L
.41605 .13006 L
.41678 .1301 L
.41745 .13015 L
.41863 .13027 L
.41992 .13043 L
.42225 .13078 L
.42676 .13155 L
.428 .13174 L
.4293 .1319 L
.43041 .13201 L
.43163 .13209 L
.43233 .13212 L
.43297 .13214 L
.43371 .13214 L
.4344 .13212 L
.43564 .13205 L
.43633 .132 L
.43698 .13193 L
.43942 .13158 L
.442 .13109 L
Mistroke
.44447 .13057 L
.44682 .13012 L
.44811 .12992 L
.44879 .12982 L
.44952 .12974 L
.4508 .12964 L
.45199 .1296 L
.45273 .1296 L
.45353 .12962 L
.45428 .12966 L
.45498 .12972 L
.45629 .12989 L
.45768 .13012 L
.463 .13139 L
.46555 .13202 L
.4668 .13228 L
.46796 .13248 L
.46901 .13261 L
.47013 .13271 L
.47125 .13275 L
.47249 .13272 L
.4738 .13261 L
.47501 .13244 L
.47634 .13217 L
.47773 .13181 L
.48265 .13023 L
.48485 .12954 L
.48605 .12921 L
.48719 .12896 L
.48825 .12879 L
.4894 .12867 L
.49045 .12863 L
.49141 .12866 L
.49256 .12878 L
.49363 .12896 L
.4948 .12925 L
.49607 .12966 L
.50099 .13182 L
.50336 .13293 L
.50461 .13345 L
.50593 .13391 L
.50708 .13421 L
.50834 .13443 L
.50949 .13449 L
.51057 .13444 L
.51126 .13434 L
.51192 .1342 L
.51315 .13381 L
.51447 .13323 L
.51591 .1324 L
Mistroke
.52075 .12869 L
.52357 .12648 L
.52512 .1255 L
.52587 .12511 L
.52656 .12483 L
.52779 .12451 L
.52847 .12446 L
.52912 .12449 L
.52981 .12462 L
.53046 .12484 L
.53117 .1252 L
.53193 .12572 L
.53327 .12701 L
.53473 .12895 L
.5361 .13133 L
.53736 .13398 L
.54229 .14812 L
.54711 .166 L
.55229 .18559 L
.5548 .1939 L
.55717 .20052 L
.55931 .20522 L
.5605 .2073 L
.56163 .2089 L
.56279 .21018 L
.56408 .21116 L
.56534 .21172 L
.56604 .21187 L
.56669 .21192 L
.56778 .21179 L
.56897 .21141 L
.57021 .21079 L
.57137 .21003 L
.5765 .2058 L
.57921 .20373 L
.58068 .20283 L
.58141 .20246 L
.58207 .20218 L
.58332 .20176 L
.58402 .20161 L
.58467 .20151 L
.58538 .20146 L
.58604 .20146 L
.58677 .20151 L
.58754 .20162 L
.58819 .20176 L
.5889 .20194 L
.59019 .20238 L
.59258 .20345 L
.59742 .20588 L
Mistroke
.59985 .20687 L
.60051 .20708 L
.60123 .20728 L
.60252 .20755 L
.60376 .2077 L
.60447 .20773 L
.60512 .20773 L
.60631 .20765 L
.60758 .20747 L
.60872 .20722 L
.60978 .20694 L
.6122 .20614 L
.61443 .20531 L
.61681 .20447 L
.61797 .20411 L
.61906 .20381 L
.62005 .20359 L
.6211 .20341 L
.62228 .20327 L
.62336 .20321 L
.62453 .20322 L
.62581 .20331 L
.62709 .20348 L
.62781 .2036 L
.62847 .20373 L
.63095 .20435 L
.63591 .20575 L
.63727 .20608 L
.63872 .20637 L
.63995 .20656 L
.64065 .20663 L
.64131 .20669 L
.64247 .20674 L
.6437 .20673 L
.64474 .20668 L
.64588 .20657 L
.64712 .2064 L
.64844 .20616 L
.65082 .20565 L
.65519 .20466 L
.6574 .20426 L
.65865 .20409 L
.65983 .20397 L
.66051 .20393 L
.66117 .2039 L
.66239 .20388 L
.66371 .20392 L
.66445 .20397 L
.66514 .20403 L
.66639 .20417 L
Mistroke
.66752 .20432 L
.67005 .20473 L
.67264 .20519 L
.67538 .20563 L
.67681 .20581 L
.67838 .20597 L
.67907 .20603 L
.67981 .20608 L
.68114 .20614 L
.68179 .20616 L
.68247 .20618 L
.68323 .20619 L
.68393 .2062 L
.68458 .2062 L
.68529 .2062 L
.68657 .20621 L
.68779 .20624 L
.68892 .20629 L
.69018 .20638 L
.69082 .20644 L
.69151 .20652 L
.69279 .20673 L
.69396 .20699 L
.6953 .20737 L
.69657 .20782 L
.69883 .20884 L
.70128 .21027 L
.74221 .2364 L
.78162 .2612 L
.81951 .28472 L
.85986 .31022 L
.87844 .32303 L
.88087 .32353 L
.8835 .32402 L
.8847 .32427 L
.88597 .32461 L
.88825 .32542 L
.8896 .32609 L
.89087 .32684 L
.89373 .32912 L
.89613 .33162 L
.89869 .33479 L
.90445 .34259 L
.90696 .34553 L
.90828 .34678 L
.909 .34734 L
.90968 .34779 L
.91098 .34839 L
.91167 .34856 L
.91241 .34863 L
Mistroke
.91372 .34842 L
.91492 .34785 L
.91613 .34688 L
.91682 .34616 L
.91746 .34538 L
.91987 .34143 L
.9225 .33551 L
.92497 .32865 L
.9296 .31392 L
.93455 .29855 L
.93717 .29188 L
.93861 .28888 L
.93998 .28654 L
.94116 .28494 L
.94245 .28367 L
.94363 .28294 L
.94472 .28262 L
.94573 .28262 L
.94686 .28294 L
.94804 .28363 L
.94914 .28456 L
.95157 .28744 L
.9538 .29082 L
.95883 .29927 L
.96287 .30505 L
.96397 .30628 L
.96516 .3074 L
.96626 .30825 L
.96729 .30887 L
.96844 .30938 L
.96968 .30972 L
.97078 .30986 L
.97195 .30985 L
.97299 .30974 L
.97397 .30956 L
.97619 .30902 L
Mfstroke
.02381 .30902 m
.06244 .28494 L
.10458 .25865 L
.14415 .23399 L
.18221 .21027 L
.22272 .18502 L
.26171 .16071 L
.30316 .13489 L
.34309 .11002 L
.3815 .08607 L
.42237 .06066 L
.46172 .03624 L
.48147 .02351 L
.48566 .0205 L
.49012 .01768 L
.49268 .01639 L
.49501 .01551 L
.49613 .01519 L
.49735 .01494 L
.4985 .01478 L
.49955 .01472 L
.50074 .01473 L
.50186 .01482 L
.50308 .01502 L
.50439 .01533 L
.50576 .01577 L
.50706 .01628 L
.5095 .01747 L
.51896 .02383 L
.53984 .03712 L
.57817 .06098 L
.61895 .08634 L
.65822 .11081 L
.69597 .13435 L
.73617 .1594 L
.77486 .18351 L
.816 .20915 L
.85562 .23385 L
.89373 .25759 L
.93429 .28288 L
.97334 .30722 L
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[59]:=",
  ImageSize->{222.688, 137.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003N0000RB000`400?l00000o`00003og_ooool0
0=kooooo003Nooooo`00g_ooool00=kooooo003Nooooo`00g_ooool00=kooooo000>ooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`2kooooo`003Ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
^oooool000Kooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2kooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00?ooooo0_l0001Iooooo`Co0000Goooool000gooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo0_l00003ooooo`;o0000
G_ooool000gooooo00Co0000oooooooooooo00002?ooool2o`0000Gooooo00?o0000ooooooooool0
EOooool2o`0000Kooooo0_l0001Looooo`003_ooool2o`0000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Cooooo`;o00002_ooool2o`0005[ooooo000Pooooo`03o`000?oooooo
oooo057ooooo0_l0000>ooooo`;o0000F?ooool0023ooooo0_l0001Aooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0EOooool0023ooooo00?o0000ooooooooool0C_ooool2o`0001Co
oooo0_l0001Eooooo`008?ooool00ol0003oooooooooo`1<ooooo`;o00006?ooool00ol0003ooooo
ooooo`1Booooo`008?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0DOooool0023ooooo00?o0000ooooooooool0BOooool2o`0001gooooo0_l0001A
ooooo`008?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0C_ooool0023ooooo0_l00017ooooo`;o00008oooool2o`0004kooooo000Pooooo`03o`00
0?oooooooooo04Cooooo0_l0000Wooooo`;o0000C?ooool0023ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04Wooooo000Pooooo`03o`000?oooooo
oooo047ooooo0_l0000]ooooo`;o0000BOooool0023ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo04Kooooo000Pooooo`03o`000?oooooooooo03ko
oooo0_l0000cooooo`;o0000A_ooool0023ooooo0_l0000nooooo`03o`000?oooooooooo03Gooooo
0_l00014ooooo`008?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0@Oooool0023ooooo00?o0000ooooooooool0>_ooool2o`0003cooooo0_l00011
ooooo`008?ooool00ol0003oooooooooo`0hooooo`;o0000@?ooool2o`0003oooooo000Pooooo`03
o`000?oooooooooo03Kooooo0_l0000Vooooo`;o00007?ooool00ol0003oooooooooo`0looooo`00
8?ooool00ol0003oooooooooo`0dooooo`;o00004_ooool2o`0000Gooooo0ol00004ooooo`?o0000
1?ooool4o`0001cooooo0_l0000looooo`008?ooool2o`0003?ooooo7_l000000ooooooo0000o`00
0004o`0000;ooooo1?l00003ooooo`03o`000?oooooooooo01cooooo0_l0000jooooo`008?ooool0
0ol0003oooooooooo`0aooooo`?o0000;?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03Oooooo000Pooooo`03o`000?oooooooooo02oooooo0ol0000_ooooo`03o`000?oooooooooo
01kooooo0_l0000gooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?o
oooo0ol00004ooooo`03o`000?oooooooooo02gooooo0ol0000aooooo`03o`000?oooooooooo023o
oooo0_l0000eooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool01Ol0003ooooooooooooooooo000002kooooo0_l0000cooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0<_ooool000Go00000_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooooooo0_l0000[ooooo`;o
0000=_ooool00ol0003oooooooooo`0Rooooo`;o0000<_ooool000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool00000:oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0;oooool0
00Oooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00001?oo
ool00ol0003oooooooooo`0Wooooo`;o0000>Oooool00ol0003oooooooooo`0Uooooo`;o0000;ooo
ool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Oo
oooo00?o0000ooooooooool09Oooool2o`0003_ooooo00?o0000ooooooooool09oooool2o`0002go
oooo0008ooooo`;o00002_ooool2o`0000;ooooo1Ol00003ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02[ooooo
000Pooooo`03o`000?oooooooooo02;ooooo0_l0000oooooo`03o`000?oooooooooo02Wooooo0_l0
000Zooooo`008?ooool2o`0002;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02Oooooo000Pooooo`03o`000?oooooooooo01oooooo0_l00013oooo
o`03o`000?oooooooooo02_ooooo0_l0000Wooooo`008?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool00_ooool2o`0002Wooooo0_l0000Uooooo`00
8?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
0_l000000ooooooo0000o`00000Co`0001Kooooo00?o0000ooooooooool08_ooool0023ooooo00?o
0000ooooooooool06oooool2o`0004Sooooo0ol00005ooooo`;o00004?ooool3o`0001Gooooo0_l0
000Rooooo`008?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Oooooo`008?ooool2o`0001Wooooo0_l0001Yoooo
o`;o00005Oooool2o`0001oooooo000Pooooo`03o`000?oooooooooo01Kooooo0_l0001]ooooo`;o
00005Oooool00ol0003oooooooooo`0Looooo`008?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`008?oo
ool00ol0003oooooooooo`0Cooooo`;o0000Loooool2o`0001Cooooo0_l0000Kooooo`008?ooool0
0ol0003oooooooooo`0Aooooo`;o00009_ooool2o`0004oooooo00?o0000ooooooooool04?ooool2
o`000003ooooool0003o000001Wooooo000Pooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02Oooool2o`0000Gooooo0ol00004ooooo`?o00001?ooool3o`0000Cooooo1?l0001?oooo
o`;o00003oooool4o`0000;ooooo0_l0000Gooooo`008?ooool2o`0000oooooo5_l000000ooooooo
0000o`000004o`000003ooooool0003o000000Co00000_ooool4o`0000?ooooo00?o0000oooooooo
ool0Coooool2o`0000gooooo00Co0000oooooooooooooooo1ol0000Dooooo`008?ooool00ol0003o
ooooooooo`0<ooooo`?o00003?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Boooo
o`04o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00005_ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l00003ooooo`;o00001?ooool3
o`0000Cooooo00?o0000ooooooooool01oooool2o`0000cooooo0ol00004ooooo`008?ooool00ol0
003oooooooooo`0;ooooo`;o00003Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0001;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
01Gooooo00Co0000oooooooooooo00000oooool2o`0000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo000P
ooooo`03o`000?oooooooooo00Wooooo0_l0000?ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool04oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo1Ol0
000Eooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04
o`000?ooooooooooo`0000Gooooo0ol00003ooooo`04o`000?ooooooooooo`0000gooooo0ol00009
ooooo`03o`000?oooooooooo00?ooooo000Pooooo`03o`000?oooooooooo00Oooooo0_l0000Aoooo
o`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool04_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00005_ooool01?l0003ooooooooo
ool00007ooooo`Co00005_ooool01?l0003oooooooooool00007ooooo`Co00000oooool00ol0003o
ooooooooo`0=ooooo`;o00002?ooool00ol0003oooooooooo`03ooooo`008?ooool2o`0000Kooooo
0ol0000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Coooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000Foooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
0007ooooo`?o000000Coooooo`000?oooooo00004Oooool2o`0000Oooooo00?o0000ooooooooool0
0oooool0023ooooo00?o0000ooooooooool00oooool3o`0001Cooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000001Cooooo0_l00002ooooo`03o`000?oooooooooo00Oo
oooo0_l0000Fooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool05_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool04Oooool4
o`0000?ooooo0_l00005ooooo`008?ooool00ol0003oooooooooo`02ooooo`?o00005_ooool2o`00
00Wooooo0ol0000Eooooo`04o`000?oooooo0000o`0000_ooooo00?o0000ooooooooool05Oooool2
o`0000[ooooo0_l0000Gooooo`;o00002Oooool3o`000003ooooool0003o000001?ooooo0_l00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00?ooooo000Pooooo`03o`000?oooooooooo
00?o0000>oooool00ol0003oooooooooo`1Hooooo`?o00004_ooool01?l0003oooooo`000?l00009
ooooo`008?ooool01?l0003oooooo`000?l0000mooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool00_l0000?ooooo`04o`000?ooooooooooooooo`?o00001oooool0023ooooo0ol0000o
ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`006oooooo3o`0000008?ooool3o`0000Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000002?ooool2o`0000Go
oooo1?l00004ooooo`008?ooool7o`0003_ooooo0_l00003ooooo`?o0000Boooool2o`0000Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooooooo`?o
00001oooool0023ooooo00Go0000ooooool0003o0000ooooo`02o`0003cooooo00Ko0000oooooooo
ooooooooo`000?oooom@o`000003ooooool0003ooooo00[ooooo0ol00006ooooo`03o`000?oooooo
oooo00?o00002Oooool0023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0joooo
o`Co0000DOooool3o`0000gooooo0_l00005ooooo`04o`000?oooooo0000o`0000_ooooo000Poooo
o`03o`000?oooooooooo00Cooooo0_l0002Pooooo`;o00000oooool3o`0000gooooo000Pooooo`;o
00001Oooool01?l0003oooooo`000?l0002Oooooo`04o`000?ooooooooooooooo`;o00003_ooool0
023ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0009kooooo0ol0000@
ooooo`008?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0002Moooo
o`?o00004?ooool0023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`?o
0000VOooool2o`0001?ooooo000Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Gooooo0_l0001Rooooo`;o0000:oooool2o`0001Cooooo000Pooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool2o`000003oooo
ool0003ooooo05oooooo1?l00004ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`;o0000
1Oooool2o`0000Cooooo0_l0000Fooooo`008?ooool2o`0000Kooooo00?o0000ooooooooool02?oo
ool3o`0000Cooooo00?o0000ooooooooool0GOooool01?l0003oooooooooooooool4o`0000;ooooo
1_l00002ooooo`Go00000_ooool6o`000003ooooool0003o000000_o00005oooool0023ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`;o00001?ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo02Kooooo0_l0000Iooooo`008?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00001Nooooo`03o`000?oo
oooooooo02Gooooo0_l0000Kooooo`008?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo0_l000000ooooooo0000ooooo`1Mooooo`03o`000?oooooooooo02Cooooo0_l0000L
ooooo`008?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo0ol0001Moooo
o`03o`000?oooooooooo02;ooooo0_l0000Nooooo`008?ooool2o`0000Sooooo00?o0000oooooooo
ool03_ooool2o`0005cooooo00?o0000ooooooooool08Oooool2o`0001oooooo000Pooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03_ooool01?l0003oooooo`000?l0001Iooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool0023ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooooooo`;o0000Eoooool00ol0003o
ooooooooo`0Oooooo`;o00008_ooool0023ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`0Nooooo`;o00008oooool0023ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo0_l0001Dooooo`03o`000?oooooooooo01cooooo0_l0
000Uooooo`008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01_ooooo0ol0000V
ooooo`008?ooool2o`0000[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool06_ooool2o`0002Sooooo000Pooooo`03
o`000?oooooooooo00[ooooo1Ol0000;ooooo`03o`000?oooooooooo00Kooooo0_l0001>ooooo`03
o`000?oooooooooo01Wooooo0_l0000Zooooo`008?ooool00ol0003oooooooooo`0>ooooo`;o0000
2_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Gooooo0_l00004ooooo`03o`00
0?oooooooooo01Oooooo0ol0000[ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Co`0000;ooooo00?o0000ooooooooool05Oooool3o`0002gooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`05
o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`07ooooo`Co00002Oooool2o`00
04Kooooo0ol0000Fooooo`?o0000;oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00005ooooo`05o`000?ooooooooooooooool000004oooool3o`0001Kooooo00?o
0000ooooooooool0F_ooool3o`00037ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooooooool2o`0001Cooooo0ol0000Eooooo`;o
0000FOooool2o`0003?ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
oooo0000ooooo`04o`0000Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo05Cooooo0_l0000eooooo`001oooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Cooooo0_l0001Booooo`?o0000=_ooool000Sooooo0_l0000:ooooo`;o00000_ooool5
o`0000?ooooo00?o0000ooooooooool06?ooool2o`0001Kooooo0_l0001?ooooo`;o0000>?ooool0
023ooooo00?o0000ooooooooool06_ooool2o`0001Kooooo00?o0000ooooooooool07_ooool2o`00
02_ooooo00?o0000ooooooooool0>?ooool0023ooooo00?o0000ooooooooool07?ooool2o`0001Go
oooo0_l0000Mooooo`Co00001?ooool3o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo017o
oooo0_l0000kooooo`008?ooool2o`0001oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Jooooo`04o`000?ooooooooooooooo`Go000000?oooooo`000?l000001?l000000ooooooo
0000o`00000Jo`0003cooooo000Pooooo`03o`000?oooooooooo01oooooo0_l0000Eooooo`;o0000
6_ooool00ol0003oooooooooo`0Vooooo`;o0000?_ooool0023ooooo00?o0000ooooooooool08Ooo
ool2o`0001Gooooo0_l0000Gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0?_oo
ool0023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0oooooo`008?ooool00ol0
003oooooooooo`0Tooooo`;o00005Oooool2o`0001Cooooo00?o0000ooooooooool08oooool2o`00
04;ooooo000Pooooo`;o00009oooool2o`0001Gooooo0_l0000Booooo`03o`000?oooooooooo027o
oooo0_l00014ooooo`008?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`;o0000A_ooool0023ooooo00?o
0000ooooooooool0:Oooool2o`0001Gooooo0_l0000>ooooo`03o`000?oooooooooo01kooooo0_l0
0018ooooo`008?ooool00ol0003oooooooooo`0[ooooo`;o00005Oooool2o`0000cooooo00?o0000
ooooooooool07?ooool2o`0004[ooooo000Pooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0B_ooool0023ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`;o
00002?ooool00ol0003oooooooooo`0Jooooo`;o0000COooool0023ooooo0_l0000`ooooo`;o0000
5_ooool2o`0000Kooooo00?o0000ooooooooool06?ooool2o`0004oooooo000Pooooo`03o`000?oo
oooooooo037ooooo0_l0000Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`1?ooooo`008?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo01;ooooo1?l00002ooooo`03o`000?oooooooooo01Kooooo0_l0001Booooo`008?ooool00ol0
003oooooooooo`0doooooa7o000000?oooooo`000?l000000ol000001?oooooo0000ooooool0000G
ooooo`03o`000?oooooooooo05;ooooo000Pooooo`03o`000?oooooooooo04Cooooo0ol00004oooo
o`Co00005Oooool2o`0005Gooooo000Pooooo`03o`000?oooooooooo04oooooo0_l0000Booooo`03
o`000?oooooooooo05Gooooo000Pooooo`;o0000D_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo05Kooooo000Pooooo`03o`000?oooooooooo05;ooooo0_l0000<ooooo`;o0000FOoo
ool0023ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`;o0000Foooool0
00kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`003Oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo000=ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Gooooo`Go0000Goooool000go
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`;o0000_?ooool000go
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo0_l00005ooooo`03o`000?oooooooooo
0;_ooooo000>ooooo`;o00002_ooool00ol0003oooooooooo`31ooooo`00g_ooool00=kooooo003N
ooooo`00g_ooool00=kooooo003Nooooo`00g_ooool00001\
\>"],
  ImageRangeCache->{{{77.875, 299.562}, {527.562, 390.938}} -> {-0.597356, \
0.56083, 0.00541577, 0.00173834}}]
}, Open  ]],

Cell[TextData[{
  "A movie (see the Help Browser: A Practical Introduction to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "/Graphics and Sound/Special Topic: Animated Graphics)."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
<<Graphics`Animation`
Animate[Plot[U[50,x,t], {x,0,L}, PlotRange->{-0.1,0.1}], {t,0,2,0.05}]\
\>", \
"Input",
  CellLabel->"In[68]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33409 L
.10458 .36147 L
.14415 .38716 L
.18221 .41186 L
.22272 .43816 L
.26171 .46347 L
.30316 .49036 L
.34309 .51627 L
.3815 .54121 L
.42237 .56767 L
.46172 .5931 L
.48147 .60636 L
.48566 .6095 L
.49012 .61244 L
.49268 .61378 L
.49501 .6147 L
.49613 .61503 L
.49735 .61529 L
.4985 .61545 L
.49955 .61552 L
.50074 .61551 L
.50186 .61541 L
.50308 .61521 L
.50439 .61488 L
.50576 .61443 L
.50706 .61389 L
.5095 .61265 L
.51896 .60603 L
.53984 .59219 L
.57817 .56734 L
.61895 .54092 L
.65822 .51544 L
.69597 .49093 L
.73617 .46484 L
.77486 .43973 L
.816 .41303 L
.85562 .38731 L
.89373 .36257 L
.93429 .33624 L
.97334 .31089 L
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{225, 139},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Q0000Rb000`400?l00000o`00003ohOooool0
0>7ooooo003Qooooo`00hOooool00>7ooooo003Qooooo`00hOooool00>7ooooo000Dooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o0000_oooool001?ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`2nooooo`003?ooool5o`0000;ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`2nooooo`004oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00?ooooo0_l0002iooooo`004oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0^?ooool001?ooooo00Co0000oooooooooooo0000
2?ooool2o`0000Gooooo00?o0000ooooooooool0^?ooool001Cooooo0_l0000:ooooo`03o`000?oo
oooooooo00?ooooo0_l0002iooooo`009_ooool00ol0003oooooooooo`2hooooo`009_ooool00ol0
003oooooooooo`2hooooo`009_ooool2o`000;Wooooo000Vooooo`03o`000?oooooooooo0;Sooooo
000Vooooo`03o`000?oooooooooo0;Sooooo000Vooooo`;o0000^Oooool002Kooooo00?o0000oooo
ooooool0^?ooool002Kooooo0_l0002iooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0
^?ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000;[ooooo0005o`00
00;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooooooo0_l0002iooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo00000;[ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooo`000003o`0000Cooooo00?o0000ooooooooool0^?ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooool000001oooool2o`000;Wooooo0008ooooo`;o00002_ooool2o`0000;ooooo1Ol0
00000ooooooo0000o`000003o`0000?ooooo00?o0000ooooooooool0^?ooool002Kooooo00?o0000
ooooooooool0^?ooool002Kooooo0_l0002iooooo`009_ooool00ol0003oooooooooo`2hooooo`00
9_ooool00ol0003oooooooooo`2hooooo`009_ooool2o`000;Wooooo000Vooooo`03o`000?oooooo
oooo0;Sooooo000Vooooo`03o`000?oooooooooo0;Sooooo000Vooooo`;o0000^Oooool000kooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001?ooool00ol0003ooooo
ooooo`2hooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool01Ol0003ooooooooooooooooo00000;[ooooo0006ooooo`Go00000_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooooooo
0_l0002iooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00Go0000ooooooooooooooooo`00002jooooo`003Oooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooo`000?ooool01?l00004ooooo`03o`000?oooooooooo0;Sooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00007ooooo`;o0000
^Oooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000?ooooo00?o0000ooooooooool0^?oo
ool002Kooooo00?o0000ooooooooool0^?ooool002Kooooo0_l0002iooooo`009_ooool00ol0003o
ooooooooo`2hooooo`009_ooool00ol0003oooooooooo`2hooooo`009_ooool2o`000;Wooooo000V
ooooo`03o`000?oooooooooo0;Sooooo000Vooooo`03o`000?oooooooooo0;Sooooo0008ooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol00004ooooo`;o
0000^Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo00000;[ooooo
0005o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00002jooooo`001oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooooooool2o`000;Wooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001?ooool00ol0003o
ooooooooo`2hooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo0;Sooooo0008oooo
o`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00000oooool2o`000;Wooooo000Vooooo`03
o`000?oooooooooo01[ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00005Oooool2o`00
00Cooooo00?o0000ooooooooool00oooool3o`0001Kooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol0000Fooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00006oooool3o`00
00Gooooo000Vooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool0000Dooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool05?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000005?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`04
ooooo`009_ooool2o`0001[ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0D
ooooo`04o`000?ooooooooooo`0000Oooooo1Ol0000Eooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Dooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Kooooo`03o`000?oooooooooo00Cooooo000Vooooo`03o`000?oooooooooo
01Wooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Cooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00005_ooool01?l0003oooooooooool00007ooooo`Co
00005Oooool01?l0003oooooooooool00008ooooo`?o00007?ooool00ol0003oooooooooo`04oooo
o`009_ooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Dooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000005_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool01?ooool002Ko
oooo0_l0000Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000D
ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000Fooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool05Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000006_ooool2o`0000Kooooo000Vooooo`03o`000?oooooooooo01[ooooo0_l00009ooooo`?o
00005_ooool2o`0000_ooooo00?o0000ooooooooool05Oooool2o`0000[ooooo0_l0000Fooooo`;o
00002Oooool3o`0001cooooo00?o0000ooooooooool01?ooool002Kooooo00?o0000ooooooooool0
^?ooool002Kooooo0_l0002iooooo`009_ooool00ol0003oooooooooo`2hooooo`008Oooooo0o`00
00009_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo0ol00005ooooo`00
9_ooool00ol0003oooooooooo`02o`0001oooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07_ooool01?l0003ooooo
ooooool00005ooooo`009_ooool2o`0000?ooooo00?o0000ooooooooool0Z?ooool2o`0000Wooooo
000Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Y_ooool00ol0003ooooooooo
o`09ooooo`009_ooool00ol0003oooooooooo`04ooooo`;o0000YOooool00ol0003oooooooooo`0:
ooooo`009_ooool2o`0000Oooooo00?o0000ooooooooool0X?ooool2o`0000gooooo000Vooooo`03
o`000?oooooooooo00Oooooo0_l0002Oooooo`03o`000?oooooooooo00gooooo000Vooooo`03o`00
0?oooooooooo00Wooooo0_l0002Kooooo`;o00004?ooool002Kooooo0_l0000<ooooo`03o`000?oo
oooooooo09Kooooo0_l0000Booooo`009_ooool00ol0003oooooooooo`0<ooooo`;o0000UOooool0
0ol0003oooooooooo`0Booooo`009_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
093ooooo0_l0000Eooooo`009_ooool2o`00013ooooo0_l0002>ooooo`;o00005oooool000Sooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Cooooo
00?o0000ooooooooool04Oooool2o`0008_ooooo00?o0000ooooooooool05oooool000Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool0Q_oo
ool2o`0001[ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o00005Oooool2o`0008Co
oooo0_l0000Looooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000001Sooooo00?o0000
ooooooooool0P?ooool00ol0003oooooooooo`0Looooo`001oooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003o`0000Cooooo
00?o0000ooooooooool05oooool2o`0007kooooo0_l0000Oooooo`001oooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000007oooo
o`;o00006_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo01oooooo0008ooooo`;o
00002_ooool2o`0000?ooooo0ol00002ooooo`Go00000oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool08?ooool002Kooooo00?o0000ooooooooool0
6oooool2o`0007Kooooo0_l0000Sooooo`009_ooool2o`0001kooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`0Sooooo`009_ooool00ol0003oooooooooo`0Nooooo`;o0000L?ooool2
o`0002Kooooo000Vooooo`03o`000?oooooooooo023ooooo0_l0001/ooooo`;o0000:?ooool002Ko
oooo0_l0000Sooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0:?ooool002Kooooo
00?o0000ooooooooool08oooool2o`0006Kooooo0_l0000[ooooo`009_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0:oooool000kooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001?ooool2o`0002Oooooo0_l0001P
ooooo`;o0000;_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00Go0000ooooooooooooooooo`00000Zooooo`03o`000?oooooooooo05_o
oooo0_l0000`ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Gooooo00Go0000ooooooooooooooooo`00000[ooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool0<?ooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooooooo`;o0000:oooool2o`0005Oooooo0_l0000cooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00004ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0cooooo`00
3Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00001oooool0
0ol0003oooooooooo`0]ooooo`;o0000DOooool2o`0003Kooooo000>ooooo`;o00002_ooool2o`00
00;ooooo1Ol00003ooooo`;o0000<?ooool2o`0004kooooo00?o0000ooooooooool0=_ooool002Ko
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03Oo
oooo000Vooooo`03o`000?oooooooooo03;ooooo0_l00018ooooo`;o0000>_ooool002Kooooo0_l0
000eooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0>_ooool002Kooooo00?o0000
ooooooooool0=Oooool2o`0004;ooooo0_l0000mooooo`009_ooool00ol0003oooooooooo`0goooo
o`;o0000?oooool00ol0003oooooooooo`0mooooo`009_ooool2o`0003[ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0nooooo`009_ooool00ol0003oooooooooo`0jooooo`;o0000
>Oooool2o`00047ooooo000Vooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`11ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000nooooo`;o0000<oooool2
o`0004Cooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000011ooooo`03
o`000?oooooooooo02kooooo0_l00016ooooo`001oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000004;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`16ooooo`001oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooooooool2o`0004;ooooo0_l0000Zooooo`;o0000BOooool000Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o
00001?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0BOooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`14ooooo`;o00009?ooool2
o`0004cooooo0008ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`00
00?ooooo0_l00017ooooo`;o00008?ooool2o`0004kooooo000Vooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1>ooooo`009_ooool2o`0004[ooooo
0_l0000Jooooo`;o0000DOooool002Kooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0Eooooo`;o0000Doooool002Kooooo00?o0000ooooooooool0C?ooool2o`0001Cooooo00?o0000
ooooooooool0Doooool002Kooooo0_l0001?ooooo`03o`000?oooooooooo00oooooo0_l0001Foooo
o`009_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00cooooo0_l0001Hooooo`00
9_ooool00ol0003oooooooooo`1@ooooo`;o00002oooool00ol0003oooooooooo`1Hooooo`009_oo
ool2o`0005?ooooo0_l00008ooooo`03o`000?oooooooooo05Wooooo000Dooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo00?ooooo0_l0001Looooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0EOooool2o`0000;ooooo00?o0000ooooooooool0G?ooool0
01?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`;o0000Eoooool4
o`0005kooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0__ooool0
01?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`2nooooo`004oooool01?l0
003oooooooooool00008ooooo`;o0000`?ooool001Cooooo0_l0000:ooooo`03o`000?oooooooooo
0;kooooo003Qooooo`00hOooool00>7ooooo003Qooooo`00hOooool00>7ooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 301.875}, {199.875, 61.875}} -> {-0.641947, \
-0.0121264, 0.00552199, 0.00170186}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33466 L
.10458 .36288 L
.14415 .38895 L
.14906 .39044 L
.15165 .39098 L
.15307 .3913 L
.1544 .39167 L
.15679 .39258 L
.15806 .39323 L
.15943 .39408 L
.16186 .39599 L
.16408 .39818 L
.17275 .40868 L
.17512 .41115 L
.17642 .41227 L
.17765 .41314 L
.1788 .41377 L
.18004 .41426 L
.18117 .41452 L
.18221 .41461 L
.18341 .41456 L
.18453 .41438 L
.18577 .41405 L
.18709 .41361 L
.18836 .41315 L
.18973 .41267 L
.19104 .41231 L
.19224 .41214 L
.19339 .41215 L
.19466 .41244 L
.1953 .41272 L
.19599 .41312 L
.19723 .41415 L
.19839 .4155 L
.1996 .41735 L
.20178 .42183 L
.20428 .4289 L
.20696 .43856 L
.21178 .46004 L
.21747 .48735 L
.21997 .49822 L
.22272 .50849 L
.22529 .51615 L
.22769 .52148 L
.22902 .52369 L
.23023 .52528 L
.2309 .526 L
.23163 .52666 L
.23296 .52757 L
Mistroke
.23371 .52794 L
.23442 .5282 L
.23506 .52837 L
.23575 .5285 L
.2365 .52858 L
.2373 .52862 L
.23798 .52863 L
.23872 .52861 L
.24006 .52856 L
.2408 .52853 L
.24149 .52852 L
.24212 .52853 L
.24281 .52856 L
.24406 .5287 L
.24531 .52896 L
.24648 .52932 L
.24776 .52985 L
.24914 .53059 L
.25196 .53256 L
.25454 .53474 L
.26421 .54257 L
.28318 .5558 L
.28837 .56188 L
.28987 .56335 L
.29128 .56447 L
.29254 .56519 L
.29326 .56546 L
.29391 .5656 L
.29511 .56559 L
.29622 .56525 L
.29745 .56448 L
.29876 .56315 L
.30014 .56121 L
.30144 .55884 L
.30389 .5531 L
.31353 .52074 L
.31587 .5131 L
.3184 .50615 L
.31984 .50296 L
.32117 .50061 L
.32244 .49891 L
.32308 .49827 L
.32378 .49772 L
.32502 .49715 L
.32619 .49708 L
.32724 .49738 L
.32838 .49807 L
.32963 .49922 L
.33095 .50081 L
.33331 .50441 L
Mistroke
.33786 .51254 L
.34219 .5194 L
.34454 .52211 L
.34587 .52325 L
.34711 .52407 L
.34825 .52461 L
.34929 .52495 L
.35048 .52518 L
.35161 .52526 L
.35284 .52524 L
.35414 .52512 L
.35648 .52484 L
.35777 .52473 L
.35899 .5247 L
.35968 .52472 L
.36031 .52478 L
.36105 .5249 L
.36174 .52506 L
.36279 .52539 L
.36395 .5259 L
.36516 .5266 L
.36629 .52741 L
.37051 .5315 L
.37545 .53752 L
.38004 .54271 L
.38232 .54474 L
.38474 .54639 L
.38613 .5471 L
.38744 .54763 L
.38861 .548 L
.38988 .54832 L
.39492 .54918 L
.39614 .54943 L
.39745 .54977 L
.39889 .55025 L
.40024 .55082 L
.40282 .55229 L
.40528 .55415 L
.40987 .55858 L
.41445 .5634 L
.41875 .56739 L
.42118 .56917 L
.4238 .57067 L
.42618 .57171 L
.42837 .57246 L
.43326 .57399 L
.43603 .57508 L
.43861 .57641 L
.44294 .57936 L
.44757 .58315 L
Mistroke
.45215 .58666 L
.45447 .58801 L
.45578 .58859 L
.45702 .58901 L
.4577 .58918 L
.45835 .58931 L
.45957 .58945 L
.46089 .58946 L
.46163 .58941 L
.46232 .58932 L
.46357 .58908 L
.4647 .58879 L
.46723 .58793 L
.46981 .58693 L
.47255 .58596 L
.47398 .58556 L
.47474 .58538 L
.47555 .58523 L
.4763 .58512 L
.47698 .58505 L
.47766 .58501 L
.47831 .585 L
.47956 .58505 L
.48019 .58511 L
.48089 .5852 L
.48212 .58543 L
.48328 .58571 L
.48868 .58746 L
.49097 .58819 L
.49222 .58852 L
.49338 .58877 L
.49464 .58898 L
.49531 .58905 L
.49602 .5891 L
.49729 .58912 L
.49845 .58906 L
.49964 .58893 L
.50076 .58873 L
.50198 .58846 L
.50329 .58811 L
.50842 .58649 L
.5096 .58614 L
.51089 .58581 L
.51202 .58557 L
.51323 .58537 L
.51443 .58525 L
.51551 .5852 L
.5166 .58522 L
.51762 .58529 L
.51883 .58545 L
Mistroke
.51952 .58557 L
.52016 .5857 L
.52283 .5864 L
.52762 .58793 L
.52902 .58834 L
.53035 .58866 L
.53154 .5889 L
.53283 .58907 L
.5335 .58913 L
.53424 .58916 L
.53501 .58916 L
.53574 .58913 L
.53703 .589 L
.53775 .58888 L
.53842 .58875 L
.54091 .58803 L
.54317 .58714 L
.54824 .58461 L
.55737 .58006 L
.57808 .56787 L
.6181 .54146 L
.65661 .51631 L
.69757 .48916 L
.73701 .46336 L
.77494 .43875 L
.81532 .4124 L
.85418 .38719 L
.8955 .36061 L
.9353 .33505 L
.97359 .3103 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo000Woooo
o`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:Oooool2o`0000;ooooo00?o0000
ooooooooool01Oooool002Oooooo00Co0000oooooooooooooooo0_l0003Vooooo`03o`000?oooooo
oooo00[ooooo000Wooooo`;o00001?ooool00ol0003oooooooooo`3Rooooo`03o`000?oooooooooo
00_ooooo000Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0goooool2o`0000ko
oooo000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0gOooool00ol0003ooooo
ooooo`0>ooooo`009oooool00ol0003oooooooooo`06ooooo`;o0000foooool2o`00017ooooo000W
ooooo`;o00002Oooool00ol0003oooooooooo`3Fooooo`;o00004oooool002Oooooo00?o0000oooo
ooooool02Oooool2o`000=Gooooo00?o0000ooooooooool04oooool002Oooooo00?o0000oooooooo
ool02oooool2o`000=7ooooo0_l0000Fooooo`009oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo0<cooooo0_l0000Hooooo`009oooool2o`0000oooooo0_l0003;ooooo`03o`000?oo
oooooooo01Sooooo000Wooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0a_ooool2
o`0001_ooooo000Wooooo`03o`000?oooooooooo017ooooo0_l00035ooooo`03o`000?oooooooooo
01_ooooo000Wooooo`03o`000?oooooooooo01?ooooo0_l00031ooooo`;o00007_ooool002Oooooo
0_l0000Fooooo`03o`000?oooooooooo0;cooooo0_l0000Pooooo`002?ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003ooooooooo
o`0Fooooo`;o0000^oooool00ol0003oooooooooo`0Pooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool2o`000;Oooooo0_l0000Soooo
o`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0/oooool00ol0003oooooooooo`0Sooooo`001oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`;o00007?ooool00ol0003oooooooooo`2`ooooo`;o00009_ooool000Oooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool0
00000ol00005ooooo`03o`000?oooooooooo01cooooo1?l0002]ooooo`03o`000?oooooooooo02Ko
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool07oooool2o`000:[ooooo0_l0000Y
ooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo02Wooooo000Wooooo`;o
00008_ooool00ol0003oooooooooo`2Tooooo`;o0000;?ooool002Oooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo02cooooo000Wooooo`03o`000?oo
oooooooo02?ooooo0_l000001?oooooo0000o`000?l0002Looooo`;o0000;oooool002Oooooo0_l0
000Uooooo`?o00000_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo02oooooo000W
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0U_ooool2o`0003;ooooo000Woooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Toooool2o`0003Cooooo000Wooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0dooooo`00
9oooool2o`0002_ooooo00?o0000ooooooooool0T?ooool2o`0003Oooooo000Wooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0gooooo`009oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08cooooo0_l0000jooooo`009oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0>_ooool002Oo
oooo0_l0000/ooooo`03o`000?oooooooooo08Wooooo0_l0000mooooo`009oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0?Oooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo08Gooooo0_l00010ooooo`003Oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`10ooooo`00
3Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool2o`0002gooooo00?o0000ooooooooool0P_ooool2o`0004?ooooo000=ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`13
ooooo`003Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l0
0005ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0O_ooool2o`0004Kooooo000=
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`16ooooo`00
3_ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool2o`0002kooooo00?o0000ooooooooool0
O?ooool00ol0003oooooooooo`17ooooo`009oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo07Wooooo0_l0001:ooooo`009oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool0B_ooool002Oooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1fooooo`;o0000COooool002Oooooo0_l0000_ooooo`03o`000?oooooooooo07Go
oooo00?o0000ooooooooool0COooool002Oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Gooooo`?o0000FOooool2o`00053ooooo000Wooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool05oooool01?l0003oooooooooool0001Fooooo`;o0000D_ooool002Oooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool00000
EOooool00ol0003oooooooooo`1Booooo`009oooool2o`00033ooooo00?o0000ooooooooool05Ooo
ool01Ol0003ooooooooooooooooo000005?ooooo0_l0001Eooooo`009oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool2o`00053ooooo00?o
0000ooooooooool0EOooool002Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool2o`0005Sooooo000Woooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0F?ooool002Oooooo0_l0000booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool6o`0004Cooooo0_l0001Kooooo`00
2?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0000Gooooo00?o0000ooooooooool0<_ooool5o`0000oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo05_ooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`;o00003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03kooooo0_l0001Nooooo`001oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0G_ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0003_ooooo0_l00009ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0>Oooool2o`00067ooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo
0_l0000hooooo`03o`000?oooooooooo067ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0000coooo
o`;o0000I?ooool000Sooooo0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o
00001?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05_ooool2o`0002oooooo0_l0001Vooooo`009oooool2o`00043ooooo00Go0000oooooooooooo
ooooo`00000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0I_ooool002Oooooo
00?o0000ooooooooool0@?ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo02Wo
oooo0_l0001Yooooo`009oooool00ol0003oooooooooo`10ooooo`?o00007Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo06Wooooo000Wooooo`03o`000?oooooooooo067ooooo0_l0
000Uooooo`;o0000K?ooool002Oooooo0_l0001Tooooo`?o00008?ooool2o`0006kooooo000Woooo
o`03o`000?oooooooooo06Gooooo0_l0000Nooooo`03o`000?oooooooooo06kooooo000Wooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool06Oooool2o`00077ooooo000Wooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool01?ooool4o`0000Cooooo1_l00005ooooo`03o`00
0?oooooooooo077ooooo000Wooooo`;o0000J_ooool6o`0000Cooooo1?l00006ooooo`Go0000M?oo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`005?ooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo000C
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`000?Oooooo000C
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool0
0008ooooo`;o0000ooooool001Cooooo0_l0000:ooooo`03o`000?oooooooooo0?gooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33391 L
.10458 .35979 L
.10702 .36085 L
.10967 .36237 L
.11448 .3663 L
.12002 .37226 L
.12242 .37494 L
.12507 .37764 L
.12739 .37964 L
.12867 .38054 L
.12988 .38124 L
.13054 .38156 L
.13126 .38185 L
.13252 .38224 L
.1338 .38247 L
.13499 .38254 L
.13619 .38251 L
.13732 .3824 L
.13833 .38225 L
.13942 .38206 L
.14062 .38185 L
.14189 .38167 L
.14297 .38159 L
.14415 .38162 L
.14537 .38182 L
.14606 .38204 L
.1467 .3823 L
.14788 .38299 L
.14912 .38403 L
.15023 .38526 L
.15127 .3867 L
.15365 .39109 L
.15621 .39759 L
.15855 .40515 L
.16383 .42675 L
.17272 .46726 L
.17528 .47712 L
.17769 .48493 L
.17986 .49051 L
.18221 .49499 L
.18339 .49664 L
.18469 .49802 L
.18534 .49855 L
.18604 .49901 L
.18731 .49957 L
.18857 .49983 L
.18977 .49984 L
.19084 .4997 L
.19201 .49943 L
Mistroke
.19448 .49865 L
.19569 .49827 L
.1968 .49796 L
.19781 .49775 L
.19888 .49763 L
.19995 .49761 L
.20113 .49775 L
.20243 .4981 L
.20316 .49838 L
.20382 .49871 L
.20633 .50043 L
.2077 .50167 L
.20918 .50323 L
.21187 .50646 L
.21701 .51298 L
.21953 .51582 L
.22183 .51798 L
.22404 .5196 L
.22637 .52081 L
.22758 .52127 L
.22871 .5216 L
.22994 .52187 L
.23126 .5221 L
.23406 .52247 L
.23544 .52267 L
.2367 .52291 L
.23786 .52319 L
.23908 .52358 L
.2403 .52407 L
.24165 .52473 L
.24439 .52655 L
.24689 .5287 L
.25251 .53471 L
.26267 .54409 L
.30248 .57022 L
.31123 .57138 L
.31247 .57141 L
.31363 .57151 L
.31484 .57169 L
.31616 .57203 L
.3173 .57246 L
.31834 .57298 L
.32068 .57463 L
.322 .57589 L
.32323 .57724 L
.326 .58094 L
.33104 .58893 L
.33348 .59268 L
.33577 .59562 L
.33692 .59679 L
Mistroke
.33815 .59774 L
.33885 .59813 L
.33952 .59839 L
.34078 .59857 L
.34202 .59831 L
.34315 .59769 L
.34445 .5965 L
.34568 .59493 L
.34786 .59104 L
.35022 .58542 L
.36053 .55226 L
.36328 .54415 L
.36585 .53798 L
.36725 .53531 L
.36853 .53335 L
.36995 .53172 L
.37073 .53107 L
.37147 .53061 L
.37268 .53019 L
.37397 .53017 L
.37507 .53048 L
.37629 .53115 L
.37759 .53219 L
.37899 .53365 L
.38153 .53691 L
.38655 .54434 L
.38931 .54812 L
.39192 .55106 L
.39435 .55314 L
.39572 .554 L
.39698 .55461 L
.39805 .55499 L
.39922 .55528 L
.40044 .55546 L
.40158 .55552 L
.40289 .5555 L
.40412 .5554 L
.40523 .55527 L
.40644 .55511 L
.40786 .55491 L
.40918 .55473 L
.41038 .55461 L
.41166 .55451 L
.41237 .55448 L
.41311 .55447 L
.41374 .55448 L
.41444 .5545 L
.41517 .55454 L
.41596 .55461 L
.41671 .5547 L
Mistroke
.41738 .5548 L
.42011 .55531 L
.42269 .55592 L
.4251 .55651 L
.42642 .5568 L
.42769 .55705 L
.42886 .55724 L
.43014 .5574 L
.4313 .5575 L
.43238 .55755 L
.43362 .55756 L
.43474 .55751 L
.43604 .55741 L
.43726 .55727 L
.43985 .55686 L
.44265 .55633 L
.44506 .55587 L
.44732 .55551 L
.44845 .55538 L
.44967 .55526 L
.45036 .55522 L
.45102 .55519 L
.45225 .55517 L
.45332 .55518 L
.45445 .55523 L
.45542 .5553 L
.45648 .55541 L
.45886 .55571 L
.46109 .55606 L
.46336 .55642 L
.46578 .55675 L
.46717 .55691 L
.46844 .55701 L
.46971 .55708 L
.47091 .55711 L
.47217 .55711 L
.4728 .55709 L
.4735 .55706 L
.47473 .55698 L
.47588 .55688 L
.47847 .55659 L
.48126 .55622 L
.48363 .55591 L
.48489 .55577 L
.48622 .55565 L
.4875 .55556 L
.48866 .5555 L
.48983 .55548 L
.49093 .55548 L
.492 .5555 L
Mistroke
.49314 .55555 L
.49411 .55561 L
.49517 .55569 L
.49976 .55619 L
.50228 .55647 L
.50361 .55661 L
.50502 .55673 L
.50625 .55681 L
.50694 .55685 L
.5076 .55687 L
.50875 .5569 L
.50999 .5569 L
.51112 .55688 L
.51236 .55683 L
.51365 .55675 L
.51485 .55666 L
.5193 .55621 L
.52203 .55593 L
.52337 .55582 L
.52461 .55573 L
.52573 .55567 L
.52692 .55563 L
.52811 .55561 L
.52942 .55562 L
.53015 .55564 L
.53083 .55566 L
.53212 .55572 L
.5335 .55581 L
.53501 .55594 L
.54023 .55645 L
.54255 .55664 L
.54386 .55673 L
.54506 .55678 L
.54612 .55681 L
.54727 .55683 L
.54848 .55682 L
.54961 .55679 L
.55025 .55676 L
.55095 .55673 L
.55223 .55664 L
.55461 .55644 L
.55716 .55619 L
.55997 .55592 L
.56129 .55581 L
.56271 .55571 L
.56339 .55568 L
.56404 .55565 L
.56527 .55561 L
.56594 .55561 L
.56666 .55561 L
Mistroke
.56796 .55563 L
.56875 .55566 L
.56949 .5557 L
.57089 .5558 L
.57341 .55604 L
.57573 .55631 L
.57847 .55663 L
.57966 .55676 L
.58097 .55687 L
.58222 .55696 L
.58338 .557 L
.58449 .55701 L
.58567 .55699 L
.5869 .55691 L
.58806 .5568 L
.58933 .55662 L
.5907 .55635 L
.59301 .55575 L
.59545 .55491 L
.5998 .55293 L
.62046 .53997 L
.65858 .51526 L
.69914 .48896 L
.7382 .46361 L
.7797 .43665 L
.81969 .41066 L
.85817 .38569 L
.89909 .35907 L
.9385 .33346 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo000Woooo
o`03o`000?oooooooooo00;o0000:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>Co
oooo00?o0000ooooooooool02_ooool002Oooooo0_l00004ooooo`;o0000h_ooool2o`0000gooooo
000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0g_ooool00ol0003ooooooooo
o`0=ooooo`009oooool00ol0003oooooooooo`06ooooo`;o0000g?ooool2o`00013ooooo000Woooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`0@oooo
o`009oooool2o`0000[ooooo0_l0003Fooooo`;o00004oooool002Oooooo00?o0000ooooooooool0
2oooool2o`000=?ooooo00?o0000ooooooooool04oooool002Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`3?ooooo`03o`000?oooooooooo01Cooooo000Wooooo`03o`000?oooooo
oooo00kooooo0_l0003=ooooo`;o00005oooool002Oooooo0_l0000Aooooo`03o`000?oooooooooo
0<Wooooo00?o0000ooooooooool05oooool002Oooooo00?o0000ooooooooool04Oooool2o`000<Oo
oooo0_l0000Jooooo`009oooool00ol0003oooooooooo`0Booooo`;o0000a?ooool2o`0001cooooo
000Wooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0_oooool2o`0001kooooo000W
ooooo`;o00005_ooool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo01kooooo0008oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol00005oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0^_ooool2o`00027ooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`;o0000
0_ooool00ol0003oooooooooo`2cooooo`;o00008oooool000Oooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Hooooo`?o000000?oooooo`000?l00000/Oooool2o`0002Go
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0000Nooooo`03o`000?oooooooooo
0:kooooo00?o0000ooooooooool09Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0Vooooo`001oooool0
1?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooo`000008ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Z_ooool2o`0002Wo
oooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0:Oooool002Oooooo0_l0
000Pooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0:_ooool002Oooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo02_ooooo000Woooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Y?ooool2o`0002kooooo000Wooooo`;o
00008?ooool00ol0003oooooooooo`2Rooooo`;o0000<?ooool002Oooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo033ooooo000Wooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0W_ooool2o`0003?ooooo000Wooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0W?ooool2o`0003Gooooo000Wooooo`;o00008Oooool00ol0
003oooooooooo`2Kooooo`03o`000?oooooooooo03Gooooo000Wooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0VOooool2o`0003Sooooo000Wooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0hooooo`009oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo09Gooooo0_l0000kooooo`009oooool2o`0002;ooooo00?o0000
ooooooooool0Toooool2o`0003gooooo000Wooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0T_ooool00ol0003oooooooooo`0mooooo`003_ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0T?ooool2o`00043ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`2>ooooo`03o`000?oooooooooo043ooooo000=ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o00008ooo
ool00ol0003oooooooooo`2<ooooo`;o0000@oooool000gooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo04?ooooo000=ooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`29ooooo`;o0000A_ooool000gooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`27ooooo`03o`000?oooooooooo04Kooooo000>ooooo`;o00002_ooool2o`00
00;ooooo1Ol00004ooooo`;o00009?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo
04Oooooo000Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Q?ooool2o`0004[o
oooo000Wooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`1:ooooo`009oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo083ooooo0_l0
001=ooooo`009oooool2o`0002Kooooo00?o0000ooooooooool0OOooool2o`0004oooooo000Woooo
o`03o`000?oooooooooo02Gooooo1_l0001iooooo`03o`000?oooooooooo04oooooo000Wooooo`03
o`000?oooooooooo02_ooooo0_l0001eooooo`;o0000D_ooool002Oooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`1aooooo`;o0000E?ooool002Oooooo0_l0000^ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool0E?ooool002Oooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1/ooooo`;o0000Eoooool002Oooooo00?o0000ooooooooool0;_ooool3o`00
06_ooooo00?o0000ooooooooool0Eoooool002Oooooo00?o0000ooooooooool0<?ooool4o`0006Ko
oooo0_l0001Jooooo`009oooool2o`0003Cooooo0ol0001Sooooo`03o`000?oooooooooo05[ooooo
0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`0eooooo`;o00007_ooool2o`00047ooooo00?o
0000ooooooooool0Foooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool06_ooool4o`0003kooooo0_l0001Nooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool06_ooool01?l0003oooooooooool0000mooooo`03o`000?oooooooooo05kooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0000iooooo`03o`000?oooooooooo01Wooooo00Go
0000ooooooooooooooooo`00000jooooo`;o0000HOooool000Oooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o00001Oooool00ol0003o
ooooooooo`0iooooo`;o00006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Go
oooo0_l0001Sooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo03_ooooo0_l0000F
ooooo`03o`000?oooooooooo00?ooooo0_l0000eooooo`03o`000?oooooooooo06?ooooo0008oooo
o`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo0_l000000ooo
oooo0000o`000002o`0002cooooo0_l0001Vooooo`009oooool2o`0003oooooo0_l0000Booooo`03
o`000?oooooooooo00Oooooo0ol00002ooooobgo0000J?ooool002Oooooo00?o0000ooooooooool0
@?ooool2o`00013ooooo00?o0000ooooooooool0XOooool002Oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:;ooooo000Wooooo`03o`000?oooooo
oooo04?ooooo0ol0000;ooooo`03o`000?oooooooooo0:;ooooo000Wooooo`;o0000Aoooool3o`00
00Sooooo00?o0000ooooooooool0X_ooool002Oooooo00?o0000ooooooooool0B?ooool2o`0000Oo
oooo00?o0000ooooooooool0X_ooool002Oooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0:?ooooo000Wooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2Sooooo`009oooool2o`0004cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`2Sooooo`009oooool00ol0003oooooooooo`1;oooo
o`05o`000?ooooooooooooooool00000Y_ooool002Oooooo00?o0000ooooooooool0C?ooool3o`00
0:Oooooo000Wooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0Y_ooool002Oooooo
0_l0003gooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o
0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01?ooool2o`000?Oooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`3mooooo`004oooool01?l0003oooooooooool00008ooooo`;o0000ooooool001Cooooo0_l0000:
ooooo`03o`000?oooooooooo0?gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33246 L
.07216 .34012 L
.0775 .34582 L
.08013 .34834 L
.08255 .35022 L
.08394 .35104 L
.08542 .3517 L
.08618 .35195 L
.0869 .35212 L
.08768 .35225 L
.08852 .35233 L
.08922 .35235 L
.08998 .35232 L
.0907 .35227 L
.09136 .35219 L
.09396 .35176 L
.09462 .35166 L
.09535 .35157 L
.09665 .35149 L
.09793 .35157 L
.0991 .35184 L
.10037 .35239 L
.10109 .35285 L
.10176 .35339 L
.10312 .3548 L
.10458 .35687 L
.10586 .3592 L
.10722 .36222 L
.10967 .36909 L
.11521 .39074 L
.1204 .41553 L
.12528 .43789 L
.1296 .4535 L
.13202 .45983 L
.13425 .46397 L
.13544 .46557 L
.13655 .46669 L
.13777 .46755 L
.13907 .4681 L
.13973 .46824 L
.14044 .46831 L
.14173 .46825 L
.14299 .46801 L
.14415 .46768 L
.14655 .46691 L
.14773 .46657 L
.14883 .46633 L
.15008 .46618 L
.15074 .46616 L
Mistroke
.15145 .4662 L
.15271 .46641 L
.15385 .46678 L
.15502 .46734 L
.15609 .46801 L
.15852 .47001 L
.16292 .47493 L
.16811 .48123 L
.17065 .48388 L
.17296 .48584 L
.1754 .48743 L
.17674 .48809 L
.17801 .48861 L
.18067 .48941 L
.18355 .49007 L
.1859 .49064 L
.18842 .49147 L
.1908 .49258 L
.19298 .4939 L
.19804 .49804 L
.20337 .5032 L
.20823 .50749 L
.21341 .51085 L
.2164 .51225 L
.2191 .51332 L
.22439 .51547 L
.22925 .5182 L
.2344 .5221 L
.24361 .52987 L
.25353 .53581 L
.26442 .54143 L
.30482 .56828 L
.32343 .58072 L
.34369 .59488 L
.34644 .59735 L
.34903 .59931 L
.35044 .60018 L
.35173 .60082 L
.35316 .60137 L
.35391 .60158 L
.35471 .60175 L
.35593 .60189 L
.35723 .60192 L
.35846 .60183 L
.35958 .60167 L
.36089 .60142 L
.36232 .60109 L
.36365 .60077 L
.36491 .60049 L
.36607 .60029 L
Mistroke
.36732 .60014 L
.36804 .6001 L
.36871 .60009 L
.36999 .60019 L
.37063 .60029 L
.37132 .60044 L
.37256 .60082 L
.37403 .60145 L
.37537 .60218 L
.37997 .60538 L
.38123 .60628 L
.38258 .60714 L
.38386 .6078 L
.38502 .60822 L
.38622 .60842 L
.38753 .60832 L
.38876 .60788 L
.3899 .60712 L
.39109 .60595 L
.3924 .60418 L
.39377 .60178 L
.39505 .59901 L
.3995 .5858 L
.40428 .56697 L
.40958 .54511 L
.41246 .53477 L
.41515 .52706 L
.41745 .52221 L
.41874 .52025 L
.41991 .51894 L
.42119 .51799 L
.42191 .51767 L
.42258 .51751 L
.42381 .51752 L
.42511 .51792 L
.42632 .5186 L
.42764 .5196 L
.43004 .52191 L
.43455 .52653 L
.43587 .52765 L
.4371 .52853 L
.43779 .52894 L
.43853 .5293 L
.43982 .52976 L
.44106 .52997 L
.44236 .52996 L
.44347 .52978 L
.4447 .5294 L
.44921 .52688 L
.45159 .52526 L
Mistroke
.45411 .52369 L
.45517 .52314 L
.45631 .52264 L
.45757 .52224 L
.45874 .52199 L
.45988 .52189 L
.46097 .52191 L
.46195 .52202 L
.46301 .52225 L
.46371 .52245 L
.46436 .52267 L
.46558 .52316 L
.46832 .52449 L
.47089 .52583 L
.47326 .52692 L
.47438 .52735 L
.47543 .52767 L
.47653 .52792 L
.47773 .52809 L
.47896 .52814 L
.48007 .52808 L
.48136 .52789 L
.48258 .52761 L
.48781 .52562 L
.49037 .52452 L
.49273 .52368 L
.49393 .52335 L
.49519 .5231 L
.49646 .52296 L
.49718 .52292 L
.49785 .52292 L
.49859 .52296 L
.49928 .52302 L
.50059 .52323 L
.50132 .52339 L
.50199 .52356 L
.50351 .52402 L
.5085 .52586 L
.51094 .52667 L
.51201 .52695 L
.51318 .52719 L
.51438 .52737 L
.51552 .52746 L
.51683 .52746 L
.51805 .52737 L
.51875 .52728 L
.51941 .52717 L
.52065 .52691 L
.52341 .52612 L
.52772 .52468 L
Mistroke
.52885 .52433 L
.53007 .52401 L
.5312 .52376 L
.53226 .52357 L
.53351 .52343 L
.53464 .52338 L
.53589 .5234 L
.53659 .52345 L
.53725 .52352 L
.5383 .52367 L
.53947 .5239 L
.54183 .52452 L
.54676 .52603 L
.54923 .52665 L
.54991 .52678 L
.55064 .5269 L
.55194 .52706 L
.55314 .52713 L
.55444 .52713 L
.55567 .52704 L
.5568 .52691 L
.55782 .52673 L
.55894 .5265 L
.5612 .52591 L
.56641 .52444 L
.5679 .5241 L
.56864 .52397 L
.56933 .52386 L
.5706 .52371 L
.57127 .52366 L
.57199 .52363 L
.57318 .52363 L
.57446 .52371 L
.57567 .52385 L
.57678 .52404 L
.57936 .52461 L
.58207 .52535 L
.58463 .52604 L
.58589 .52634 L
.58706 .52657 L
.58811 .52674 L
.58923 .52687 L
.59036 .52695 L
.59159 .52697 L
.59227 .52695 L
.59292 .52692 L
.59413 .5268 L
.59543 .52661 L
.59685 .52633 L
.60178 .52506 L
Mistroke
.60415 .52446 L
.60532 .52421 L
.60639 .52402 L
.60762 .52385 L
.60828 .52378 L
.60896 .52373 L
.61008 .5237 L
.6113 .52372 L
.61245 .52381 L
.6135 .52393 L
.61472 .52413 L
.61587 .52436 L
.62013 .52547 L
.62234 .52607 L
.62473 .52662 L
.62539 .52674 L
.62609 .52686 L
.62734 .52701 L
.62851 .52708 L
.62979 .52709 L
.63048 .52706 L
.63114 .52701 L
.63236 .52686 L
.63368 .52661 L
.63511 .52625 L
.63768 .52539 L
.64005 .52441 L
.65847 .51588 L
.69788 .49035 L
.73578 .46575 L
.77612 .43981 L
.81496 .41465 L
.85624 .38778 L
.89601 .36177 L
.93426 .33687 L
.97497 .31001 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo000Woooo
o`03o`000?oooooooooo00;o0000:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>Co
oooo00?o0000ooooooooool02_ooool002Oooooo0_l00004ooooo`;o0000hoooool00ol0003ooooo
ooooo`0;ooooo`009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=kooooo0_l0
000>ooooo`009oooool00ol0003oooooooooo`06ooooo`;o0000gOooool00ol0003oooooooooo`0>
ooooo`009oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Sooooo0_l0000Aoooo
o`009oooool2o`0000[ooooo00?o0000ooooooooool0eOooool2o`0001?ooooo000Wooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0doooool00ol0003oooooooooo`0Cooooo`009ooo
ool00ol0003oooooooooo`0;ooooo`;o0000dOooool2o`0001Kooooo000Wooooo`03o`000?oooooo
oooo00cooooo1Ol0003;ooooo`;o00006?ooool002Oooooo0_l0000Booooo`03o`000?oooooooooo
0<Oooooo00?o0000ooooooooool06?ooool002Oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`34ooooo`;o00006oooool002Oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`33ooooo`03o`000?oooooooooo01_ooooo000Wooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0`Oooool2o`0001kooooo000Wooooo`;o00004oooool00ol0003oooooooooo`30
ooooo`03o`000?oooooooooo01kooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0__ooool00ol0003oooooooooo`0Oooooo`001oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2looooo`;o0000
8_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo0;_ooooo00?o0000ooooooooool08_ooool000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool2o`0001Gooooo00?o0000ooooooooool0^?ooool2o`0002Gooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooo000000?o00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0;Oooooo00?o
0000ooooooooool09Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo0;Gooooo0_l0000Xooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2dooooo`03o`00
0?oooooooooo02Sooooo000Wooooo`;o00005Oooool00ol0003oooooooooo`2cooooo`03o`000?oo
oooooooo02Wooooo000Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0/?ooool2
o`0002cooooo000Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0[oooool00ol0
003oooooooooo`0/ooooo`009oooool2o`0001Kooooo00?o0000ooooooooool0[Oooool2o`0002oo
oooo000Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Zoooool2o`00037ooooo
000Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Z_ooool00ol0003ooooooooo
o`0aooooo`009oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0:Sooooo0_l0000d
ooooo`009oooool2o`0001Oooooo00?o0000ooooooooool0YOooool2o`0003Kooooo000Wooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0fooooo`00
9oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0:;ooooo0_l0000iooooo`009ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0>Ooo
ool002Oooooo0_l0000Hooooo`03o`000?oooooooooo09kooooo0_l0000looooo`009oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo09cooooo0_l0000nooooo`003_ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0nooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0V?ooool2o`00047ooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`02ooooo`;o00006_ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo047ooooo000=
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Wooooo1_l0002Aooooo`;o0000A?ooool000gooooo00Co
0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0A?ooool000gooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`2:ooooo`;o0000Aoooool000kooooo0_l0000:oooo
o`;o00000_ooool5o`0000Cooooo0_l0000Qooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0Aoooool002Oooooo00?o0000ooooooooool08Oooool2o`0008Oooooo0_l0001:ooooo`00
9oooool00ol0003oooooooooo`0Sooooo`;o0000Q?ooool00ol0003oooooooooo`1:ooooo`009ooo
ool00ol0003oooooooooo`0Tooooo`?o0000P?ooool2o`0004gooooo000Wooooo`;o0000:?ooool2
o`0007gooooo00?o0000ooooooooool0COooool002Oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`1hooooo`;o0000D?ooool002Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooooooo053ooooo000Wooooo`03o`000?oooooooooo02_ooooo
0_l0001eooooo`03o`000?oooooooooo057ooooo000Wooooo`;o0000;_ooool00ol0003ooooooooo
o`1`ooooo`;o0000E?ooool002Oooooo00?o0000ooooooooool0;_ooool3o`0006kooooo00?o0000
ooooooooool0E?ooool002Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]oooo
o`?o0000>Oooool2o`0005Oooooo000Wooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0;?ooool01?l0003oooooooooool00005ooooo`Co00001_ooool3o`0000Oooooo0_l0000Joooo
o`?o0000FOooool002Oooooo0_l0000dooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooooooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`00
0?l000001_l000000ooooooo0000o`00000Io`0005cooooo0008ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`0dooooo`;o0000:_ooool00ol0003oooooooooo`02ooooo`Co00001_ooool3o`0008Co
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0U?ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`?o00009Oooool00ol0003ooooooooo
o`2Dooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000>oooool2o`0002?ooooo
00?o0000ooooooooool0U?ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0U?ooool000Oooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool0
0ol0003oooooooooo`0mooooo`;o00008?ooool00ol0003oooooooooo`2Dooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Eooooo`009oooool2o`00047o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Eooooo`009oooool00ol0003ooooo
ooooo`11ooooo`;o00006oooool00ol0003oooooooooo`2Eooooo`009oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0U_ooool002Oooooo00?o0000
ooooooooool0A?ooool2o`0001Oooooo00?o0000ooooooooool0U_ooool002Oooooo0_l00017oooo
o`;o00005Oooool00ol0003oooooooooo`2Fooooo`009oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0U_ooool002Oooooo00?o0000ooooooooool0
BOooool2o`00017ooooo00?o0000ooooooooool0Uoooool002Oooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09Oooooo000Wooooo`;o0000COooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo09Oooooo000Wooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Gooooo`009oooool00ol0003o
ooooooooo`1>ooooo`;o00002oooool00ol0003oooooooooo`2Hooooo`009oooool00ol0003ooooo
ooooo`1?ooooo`So00001?ooool00ol0003oooooooooo`2Hooooo`009oooool2o`0005Sooooo00Co
0000oooooooooooo0000Voooool001Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
0005ooooo`03o`000?oooooooooo05Sooooo0ol0002Kooooo`004oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0
003oooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02605 .31255 L
.02846 .31602 L
.03053 .31854 L
.03163 .31964 L
.03279 .3206 L
.03344 .32105 L
.03416 .32146 L
.03543 .32198 L
.03672 .32224 L
.03793 .32226 L
.03911 .32209 L
.04019 .32179 L
.04143 .32131 L
.04262 .32077 L
.045 .31959 L
.0463 .31901 L
.04753 .31859 L
.04868 .31836 L
.04993 .31835 L
.05106 .31859 L
.0521 .31907 L
.05334 .31998 L
.0545 .32121 L
.05577 .323 L
.05713 .32546 L
.05991 .33225 L
.06244 .34043 L
.07223 .38333 L
.07759 .40672 L
.08022 .41618 L
.08263 .4233 L
.08523 .4292 L
.0866 .43155 L
.08805 .4335 L
.08876 .43428 L
.08953 .43498 L
.0909 .43595 L
.09175 .43637 L
.09254 .43665 L
.09326 .43683 L
.09403 .43695 L
.0953 .43702 L
.09602 .437 L
.0967 .43695 L
.09741 .43688 L
.09806 .43681 L
.09952 .43663 L
.10076 .43651 L
.10146 .43647 L
Mistroke
.10212 .43645 L
.10331 .43649 L
.10458 .43666 L
.10589 .43697 L
.10655 .43719 L
.10728 .43748 L
.10976 .43886 L
.11116 .43988 L
.11265 .44115 L
.11535 .44378 L
.12056 .44938 L
.12549 .45411 L
.1278 .45588 L
.13024 .4574 L
.13292 .45871 L
.1354 .45967 L
.1398 .46118 L
.14443 .46313 L
.14677 .46444 L
.14933 .46615 L
.15382 .46976 L
.15871 .47411 L
.16394 .47843 L
.17342 .48398 L
.18223 .48807 L
.22378 .515 L
.26381 .54108 L
.28217 .55487 L
.29259 .56052 L
.30233 .5661 L
.30726 .56917 L
.31194 .57165 L
.31452 .57262 L
.31523 .57283 L
.31598 .57301 L
.31663 .57315 L
.31733 .57326 L
.31853 .57339 L
.31966 .57344 L
.32032 .57343 L
.32101 .57339 L
.32225 .57327 L
.32748 .5721 L
.33005 .57135 L
.33242 .57072 L
.33372 .57043 L
.33515 .57018 L
.3359 .57009 L
.33659 .57002 L
.33733 .56998 L
Mistroke
.33812 .56996 L
.33878 .56996 L
.33951 .56999 L
.34083 .57011 L
.34211 .5703 L
.3433 .57054 L
.34822 .57188 L
.35063 .57257 L
.35285 .5731 L
.35409 .57332 L
.35541 .57348 L
.35673 .57356 L
.35748 .57356 L
.35818 .57354 L
.3594 .57344 L
.36052 .57328 L
.3618 .57303 L
.36302 .57273 L
.36728 .57139 L
.36962 .57062 L
.37181 .57002 L
.37295 .56979 L
.37418 .5696 L
.37484 .56953 L
.37554 .56949 L
.37678 .56949 L
.37792 .56956 L
.37898 .56971 L
.38014 .56994 L
.38138 .57027 L
.38636 .57212 L
.38908 .5732 L
.39041 .57365 L
.39163 .57399 L
.39227 .57414 L
.39296 .57427 L
.39369 .57438 L
.39438 .57444 L
.39515 .57447 L
.39596 .57445 L
.39672 .57438 L
.39741 .57429 L
.39873 .574 L
.39947 .57378 L
.40016 .57354 L
.40274 .5724 L
.40519 .57109 L
.40782 .56966 L
.40909 .56904 L
.41029 .56854 L
Mistroke
.41138 .56817 L
.41255 .56789 L
.4138 .56774 L
.41512 .56777 L
.41624 .56795 L
.41749 .56832 L
.41819 .56861 L
.41883 .56892 L
.42028 .56978 L
.4229 .57179 L
.42766 .57602 L
.42903 .57707 L
.43032 .57789 L
.43148 .57842 L
.43273 .57873 L
.43384 .57874 L
.43505 .57843 L
.43631 .57771 L
.43749 .57665 L
.4386 .5753 L
.43961 .57376 L
.44187 .56921 L
.44452 .56208 L
.44697 .55397 L
.45251 .53238 L
.45736 .51349 L
.45991 .50497 L
.46259 .49764 L
.46499 .49278 L
.46635 .49076 L
.46761 .48935 L
.46878 .48844 L
.46983 .48792 L
.47106 .48766 L
.47221 .48771 L
.47331 .48799 L
.47447 .4885 L
.47546 .48908 L
.47655 .48984 L
.48125 .49376 L
.48388 .49576 L
.48517 .49656 L
.48638 .49717 L
.4871 .49746 L
.48775 .49767 L
.48848 .49786 L
.48926 .49799 L
.48991 .49805 L
.49061 .49807 L
.49189 .49797 L
Mistroke
.49309 .49773 L
.49441 .49734 L
.49708 .49624 L
.50185 .4939 L
.50436 .49288 L
.50579 .49245 L
.5071 .49217 L
.50825 .49202 L
.50951 .49197 L
.51083 .49202 L
.51207 .49218 L
.51321 .4924 L
.51441 .4927 L
.51656 .49336 L
.52138 .49503 L
.52389 .49573 L
.52461 .49588 L
.52529 .49601 L
.52657 .49618 L
.52777 .49627 L
.52888 .49628 L
.5301 .49622 L
.53138 .49609 L
.53268 .49588 L
.53407 .49559 L
.53659 .49495 L
.53936 .4942 L
.54088 .49381 L
.54231 .49349 L
.54362 .49326 L
.54481 .49309 L
.54546 .49303 L
.54614 .49298 L
.54683 .49295 L
.54758 .49293 L
.5488 .49296 L
.55011 .49306 L
.55134 .4932 L
.55246 .49338 L
.55776 .49449 L
.56056 .49508 L
.56208 .49533 L
.56283 .49543 L
.56352 .49551 L
.56475 .49562 L
.56543 .49566 L
.56607 .49568 L
.56677 .49568 L
.56742 .49567 L
.56813 .49564 L
Mistroke
.56889 .4956 L
.56954 .49554 L
.57023 .49547 L
.57149 .49531 L
.57385 .49492 L
.57629 .49446 L
.57891 .49397 L
.58018 .49377 L
.58138 .49361 L
.58245 .49349 L
.58363 .4934 L
.58477 .49335 L
.58602 .49334 L
.58733 .49338 L
.58857 .49346 L
.58971 .49356 L
.59077 .49369 L
.59314 .49404 L
.59812 .49486 L
.59949 .49505 L
.60094 .49522 L
.60165 .49528 L
.60232 .49533 L
.60357 .49539 L
.60482 .4954 L
.60613 .49538 L
.60726 .49532 L
.6085 .49522 L
.60983 .49508 L
.61125 .4949 L
.61383 .49451 L
.61673 .49408 L
.61816 .49389 L
.61948 .49374 L
.62068 .49364 L
.62195 .49357 L
.62267 .49354 L
.62336 .49353 L
.62464 .49354 L
.62581 .49358 L
.62706 .49366 L
.62824 .49376 L
.62931 .49388 L
.63443 .49459 L
.63698 .49492 L
.63832 .49507 L
.63905 .49513 L
.63974 .49518 L
.64098 .49525 L
.64164 .49527 L
Mistroke
.64235 .49529 L
.64361 .49528 L
.64476 .49524 L
.6459 .49517 L
.64711 .49507 L
.64929 .49482 L
.65424 .49413 L
.6554 .49398 L
.65667 .49383 L
.65778 .49373 L
.65896 .49364 L
.66002 .49358 L
.66119 .49356 L
.66226 .49356 L
.66325 .49359 L
.66451 .49366 L
.66514 .49371 L
.66584 .49377 L
.66825 .49407 L
.67086 .49447 L
.67369 .49491 L
.67498 .49509 L
.67635 .49525 L
.67751 .49535 L
.67879 .49542 L
.67999 .49544 L
.68127 .4954 L
.68248 .49531 L
.68358 .49517 L
.68474 .49498 L
.68596 .49471 L
.68816 .49407 L
.69052 .49317 L
.69312 .49197 L
.70213 .48678 L
.74245 .46045 L
.78125 .43529 L
.8225 .40868 L
.86223 .38299 L
.90045 .35819 L
.94113 .33192 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo000Woooo
o`;o00001?ooool2o`0002Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00007
ooooo`009oooool00ol0003oooooo`000003o`000003ooooool0003ooooo0>?ooooo0_l0000;oooo
o`009oooool2o`0000Kooooo00?o0000ooooooooool0h?ooool00ol0003oooooooooo`0;ooooo`00
9oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=oooooo00?o0000ooooooooool0
3?ooool002Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Looooo`;o00003ooo
ool002Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Kooooo`03o`000?oooooo
oooo00oooooo000Wooooo`;o00001oooool00ol0003oooooooooo`3Iooooo`;o00004_ooool002Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Gooooo`;o00005?ooool002Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Fooooo`03o`000?oooooooooo01Cooooo
000Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0doooool2o`0001Oooooo000W
ooooo`;o00002?ooool00ol0003oooooooooo`3Booooo`03o`000?oooooooooo01Oooooo000Woooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0d?ooool2o`0001[ooooo000Wooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0c_ooool00ol0003oooooooooo`0Jooooo`00
9oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<cooooo0_l0000Mooooo`009ooo
ool2o`0000Wooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Mooooo`002?ooool2
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<Wooooo0_l0000Pooooo`001oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`37ooooo`03o`000?oooooooooo023ooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`35ooooo`;o00008oooool000Oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool2o`0000[ooooo00?o0000ooooooooool0`oooool2
o`0002Gooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0<7ooooo0_l0000Wooooo`001oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`0Wooooo`002?ooool2o`0000[o
oooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`2mooooo`;o0000:_ooool002Oooooo0_l0000;ooooo`03o`000?oooooooooo0;_ooooo
0_l0000/ooooo`009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0;Wooooo0_l0
000^ooooo`009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0;Sooooo00?o0000
ooooooooool0;_ooool002Oooooo0_l0000<ooooo`03o`000?oooooooooo0;Gooooo0_l0000aoooo
o`009oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;Cooooo00?o0000oooooooo
ool0<Oooool002Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo03;ooooo000Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0/?oo
ool2o`0003Gooooo000Wooooo`;o00003Oooool2o`000;3ooooo00?o0000ooooooooool0=Oooool0
02Oooooo00?o0000ooooooooool03Oooool5o`000:[ooooo0_l0000hooooo`009oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00;o0000Y_ooool2o`0003[ooooo000Wooooo`03o`00
0?oooooooooo01?ooooo0_l0002Tooooo`03o`000?oooooooooo03[ooooo000Wooooo`;o00005Ooo
ool00ol0003oooooooooo`2Pooooo`;o0000?Oooool002Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`2Mooooo`;o0000?oooool000kooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`0Fooooo`;o0000W?ooool00ol0
003oooooooooo`0oooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo0_l0
002Hooooo`;o0000@_ooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`?o0000U?ooool00ol0003ooooo
ooooo`12ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo08oo
oooo0_l00015ooooo`003Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`00
0?ooool01?l00005ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0SOooool00ol0
003oooooooooo`15ooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00002?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo08_ooooo00?o
0000ooooooooool0A_ooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0000Q
ooooo`?o0000R?ooool2o`0004Wooooo000Wooooo`03o`000?oooooooooo02?ooooo0_l00025oooo
o`03o`000?oooooooooo04Wooooo000Wooooo`03o`000?oooooooooo02Gooooo0_l00017ooooo`;o
0000>?ooool2o`0004cooooo000Wooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
@oooool4o`0000Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1<ooooo`009ooo
ool2o`0002Wooooo0_l00013ooooo`05o`000?ooooooooooooooool000001?ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000009ol0001?ooooo`009oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool4o`0000Kooooo0ol0
001gooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0Qoooool002Oooooo00?o0000ooooooooool0;?ooool2o`0003gooooo00?o0000oooo
ooooool0R?ooool002Oooooo0_l0000_ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0R?ooool002Oooooo00?o0000ooooooooool0;oooool2o`0003[ooooo00?o0000ooooooooool0
R?ooool002Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo08Sooooo000Wooooo`03o`000?oooooooooo03;ooooo0_l0000gooooo`03o`000?oooooo
oooo08Sooooo000Wooooo`;o0000=Oooool2o`0003Cooooo00?o0000ooooooooool0ROooool000So
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol00005ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`29ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0=oooool2o`00037ooooo00?o0000ooooooooool0ROooool000Oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0ROooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0003_ooooo
0_l0000]ooooo`03o`000?oooooooooo08[ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08[ooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
000000Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo08[ooooo0008ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`00
00Cooooo00?o0000ooooooooool0?_ooool2o`0002Sooooo00?o0000ooooooooool0Roooool002Oo
oooo0_l00011ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Roooool002Oooooo
00?o0000ooooooooool0@Oooool2o`0002Cooooo00?o0000ooooooooool0S?ooool002Oooooo00?o
0000ooooooooool0@oooool2o`0002;ooooo00?o0000ooooooooool0S?ooool002Oooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`03ooooo`Co00001Oooool5o`0000Gooooo1?l00005
ooooo`03o`000?oooooooooo08cooooo000Wooooo`;o0000Aoooool5o`0000Cooooo1_l00004oooo
o`Go00001?ooool01Ol0003ooooooooooooooooo000008oooooo000Wooooo`03o`000?oooooooooo
06?ooooo1?l0002?ooooo`009oooool00ol0003oooooooooo`1Tooooo`;o0000T?ooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool2o`000?Oooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Ooo
ool00ol0003oooooooooo`3fooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooo`005?ooool2
o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .3492 L
.03279 .38032 L
.03527 .39375 L
.03754 .40276 L
.03879 .40643 L
.03945 .408 L
.04015 .40939 L
.04143 .41127 L
.04262 .41229 L
.04384 .4127 L
.04496 .41258 L
.04626 .41196 L
.04749 .411 L
.05205 .40604 L
.0533 .40476 L
.05463 .4036 L
.05588 .40277 L
.05702 .4023 L
.05772 .40214 L
.05836 .4021 L
.05907 .40216 L
.05981 .40235 L
.06107 .40296 L
.06178 .40347 L
.06244 .40403 L
.10458 .43663 L
.14349 .4632 L
.18485 .49145 L
.22469 .51762 L
.24291 .52767 L
.25329 .53489 L
.25837 .53853 L
.26059 .53982 L
.26177 .5404 L
.26302 .54091 L
.26428 .54133 L
.26543 .54162 L
.26657 .54182 L
.26766 .54193 L
.26888 .54197 L
.27 .54194 L
.27123 .54183 L
.27254 .54165 L
.27784 .54057 L
.27917 .5403 L
.28043 .54008 L
.28166 .53989 L
.2828 .53977 L
.28392 .53969 L
Mistroke
.28511 .53965 L
.28643 .53967 L
.28762 .53974 L
.2889 .53987 L
.29029 .54005 L
.2928 .54048 L
.29559 .54101 L
.29712 .54128 L
.29854 .54149 L
.29975 .54164 L
.30105 .54175 L
.30179 .54179 L
.30249 .54181 L
.30381 .54181 L
.30495 .54176 L
.30618 .54167 L
.30735 .54155 L
.30841 .54141 L
.31349 .54056 L
.31474 .54036 L
.31608 .54017 L
.31732 .54002 L
.31849 .53991 L
.31981 .53984 L
.32101 .53981 L
.32233 .53984 L
.32307 .53987 L
.32376 .53992 L
.32832 .54048 L
.33265 .54118 L
.33381 .54134 L
.33504 .54149 L
.33568 .54155 L
.33639 .54161 L
.33764 .54168 L
.33877 .5417 L
.33998 .54169 L
.34113 .54164 L
.34219 .54156 L
.34336 .54144 L
.34445 .54131 L
.34692 .54094 L
.34953 .54053 L
.35191 .54019 L
.35299 .54007 L
.35416 .53997 L
.35527 .5399 L
.3563 .53987 L
.35738 .53987 L
.35858 .53991 L
Mistroke
.35982 .54 L
.36099 .54011 L
.36366 .54046 L
.36619 .54087 L
.36849 .54123 L
.36975 .5414 L
.37094 .54153 L
.37161 .54159 L
.37233 .54165 L
.3736 .54171 L
.37488 .54172 L
.37606 .54169 L
.37736 .5416 L
.37809 .54154 L
.37878 .54146 L
.38164 .54105 L
.38666 .54021 L
.38803 .54002 L
.38878 .53994 L
.38949 .53987 L
.39073 .53979 L
.39139 .53976 L
.39211 .53975 L
.39331 .53977 L
.39462 .53985 L
.39529 .5399 L
.396 .53998 L
.39727 .54015 L
.40201 .54102 L
.40441 .54146 L
.40568 .54166 L
.40637 .54175 L
.40702 .54183 L
.40819 .54192 L
.40947 .54198 L
.41057 .54197 L
.41174 .54192 L
.41287 .54181 L
.41411 .54165 L
.41636 .54124 L
.42057 .54026 L
.42314 .53971 L
.42384 .53959 L
.42458 .53948 L
.42522 .53941 L
.42591 .53934 L
.42715 .53927 L
.4283 .53927 L
.42901 .53931 L
.42968 .53936 L
Mistroke
.43093 .53952 L
.43206 .53972 L
.43326 .53999 L
.43542 .54059 L
.4403 .54207 L
.44157 .54239 L
.44278 .54262 L
.44345 .54272 L
.44418 .5428 L
.44545 .54286 L
.44667 .54283 L
.44796 .54267 L
.44918 .54243 L
.45029 .54213 L
.45301 .54112 L
.45595 .53978 L
.45853 .53866 L
.45995 .53815 L
.46064 .53795 L
.46129 .53779 L
.46252 .53759 L
.46317 .53755 L
.46386 .53754 L
.46497 .53764 L
.4662 .5379 L
.46734 .53829 L
.46857 .53887 L
.47079 .54026 L
.47577 .54427 L
.47713 .5453 L
.47859 .54622 L
.4793 .54657 L
.47997 .54684 L
.48122 .54712 L
.48187 .54715 L
.48255 .54708 L
.48379 .54666 L
.48447 .54626 L
.48511 .54577 L
.48657 .54421 L
.48799 .54207 L
.48929 .53958 L
.4922 .5321 L
.49737 .51362 L
.50228 .49314 L
.50466 .48359 L
.50723 .47435 L
.50949 .46755 L
.51189 .46202 L
.51322 .45973 L
Mistroke
.51393 .45875 L
.51468 .45787 L
.51538 .45722 L
.51601 .45676 L
.51725 .45619 L
.51845 .45603 L
.51975 .45626 L
.52098 .45679 L
.52212 .45752 L
.52643 .46147 L
.52879 .46378 L
.53097 .46563 L
.53222 .46647 L
.53335 .46707 L
.53461 .46755 L
.5353 .46772 L
.53595 .46782 L
.53709 .46787 L
.53814 .46776 L
.53929 .46749 L
.54051 .46705 L
.54289 .46585 L
.54511 .46449 L
.54775 .46284 L
.5489 .46219 L
.55016 .46157 L
.55132 .4611 L
.5524 .46076 L
.55343 .46053 L
.55452 .4604 L
.55567 .46037 L
.55675 .46046 L
.55793 .46067 L
.55921 .46102 L
.5617 .46198 L
.56444 .46327 L
.5671 .46449 L
.56857 .46507 L
.56995 .46551 L
.57124 .46582 L
.57196 .46594 L
.57263 .46601 L
.57381 .46607 L
.57506 .46602 L
.57623 .46587 L
.57733 .46565 L
.57853 .46534 L
.57982 .46492 L
.58471 .46304 L
.586 .46257 L
Mistroke
.5874 .46212 L
.58863 .4618 L
.58993 .46155 L
.59067 .46145 L
.59149 .46138 L
.59223 .46135 L
.59293 .46136 L
.59424 .46145 L
.59498 .46154 L
.59565 .46166 L
.59696 .46194 L
.59838 .46232 L
.60096 .46316 L
.60357 .46405 L
.60602 .46477 L
.60725 .46505 L
.60788 .46517 L
.60858 .46528 L
.60929 .46536 L
.61005 .46542 L
.61075 .46545 L
.6114 .46545 L
.61266 .46539 L
.61384 .46525 L
.61491 .46507 L
.61607 .46483 L
.62105 .46339 L
.62341 .46271 L
.62471 .46239 L
.62594 .46213 L
.62709 .46195 L
.62834 .46183 L
.62947 .46178 L
.63052 .46179 L
.63118 .46182 L
.63188 .46188 L
.63317 .46205 L
.63442 .46227 L
.63556 .46253 L
.64093 .46398 L
.64329 .46456 L
.64462 .46481 L
.64582 .46499 L
.6465 .46506 L
.64724 .46511 L
.64794 .46514 L
.64859 .46515 L
.64984 .46511 L
.65048 .46506 L
.65117 .46499 L
Mistroke
.65258 .46479 L
.65386 .46454 L
.65675 .46385 L
.65949 .46313 L
.66069 .46284 L
.66198 .46256 L
.66325 .46232 L
.66443 .46216 L
.66555 .46205 L
.66674 .46199 L
.66799 .462 L
.66915 .46207 L
.67044 .4622 L
.67115 .4623 L
.67181 .46241 L
.67655 .46348 L
.67864 .464 L
.68095 .4645 L
.68222 .46471 L
.68341 .46486 L
.68468 .46497 L
.68539 .465 L
.68604 .46501 L
.68733 .46497 L
.68806 .46493 L
.68874 .46486 L
.69011 .46468 L
.69158 .46442 L
.69648 .46329 L
.69915 .46268 L
.70046 .46244 L
.70166 .46227 L
.70288 .46214 L
.70419 .46206 L
.70488 .46205 L
.70562 .46206 L
.70633 .46209 L
.70698 .46213 L
.70823 .46226 L
.70936 .46243 L
.71189 .46293 L
.71722 .46424 L
.71869 .46456 L
.72023 .46483 L
.72154 .465 L
.72229 .46507 L
.72299 .46512 L
.72363 .46514 L
.72434 .46514 L
.72561 .46509 L
Mistroke
.72685 .46497 L
.728 .46479 L
.72924 .46454 L
.7306 .46418 L
.73337 .46327 L
.74313 .45905 L
.7625 .44865 L
.78337 .4334 L
.82453 .40722 L
.86418 .38183 L
.90232 .35717 L
.94291 .33126 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo000Woooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00007
ooooo`009oooool00ol0003oooooooooo`3Yooooo`;o00002oooool002Oooooo0_l0003Yooooo`03
o`000?oooooooooo00_ooooo000Wooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool0
3?ooool002Oooooo0_l0003Vooooo`;o00003oooool002Oooooo0_l0003Tooooo`;o00004Oooool0
02Oooooo0_l0003Sooooo`03o`000?oooooooooo017ooooo000Wooooo`;o0000hOooool2o`0001Co
oooo000Wooooo`;o0000goooool2o`0001Kooooo000Wooooo`;o0000g_ooool00ol0003ooooooooo
o`0Fooooo`009oooool2o`000=cooooo0_l0000Iooooo`009oooool2o`000=_ooooo00?o0000oooo
ooooool06Oooool002Oooooo0_l0003Iooooo`;o00007?ooool002Oooooo00?o0000ooooool00000
eoooool00ol0003oooooooooo`0Looooo`009oooool3o`000=Kooooo00?o0000ooooooooool07Ooo
ool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3
o`0000Gooooo00?o0000ooooool00000e?ooool2o`00023ooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`00003Cooooo`03o`000?oooooooooo023o
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000dOooool2o`00
02?ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol0003?ooooo`;o00009Oooool0
00Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooool000000ol00005ooooo`04o`000?ooooooooooo`000<gooooo00?o0000oooooooo
ool09Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003;ooooo`;o0000:?oo
ool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`04o`000?oooooo
ooooo`000<Wooooo0_l0000Zooooo`009oooool2o`000003ooooool0003ooooo00;ooooo1?l00031
ooooo`03o`000?oooooooooo02[ooooo000Wooooo`03o`000?oooooooooo00;o00000_ooool01Ol0
003ooooooooooooooooo00000;kooooo0_l0000]ooooo`009oooool01?l0003oooooooooooooool3
o`0000Gooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0]ooooo`009oooool2o`00
00_ooooo0_l0002hooooo`;o0000<?ooool002Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`2dooooo`03o`000?oooooooooo033ooooo000Wooooo`03o`000?oooooooooo00gooooo
0_l0002cooooo`03o`000?oooooooooo037ooooo000Wooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0[_ooool2o`0003Cooooo000Wooooo`;o00004Oooool00ol0003oooooooooo`2/
ooooo`03o`000?oooooooooo03Cooooo000Wooooo`03o`000?oooooooooo017ooooo0_l0002Zoooo
o`;o0000=oooool002Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Uooooo`;o
0000>Oooool002Oooooo00?o0000ooooooooool05?ooool2o`000:?ooooo0_l0000kooooo`009ooo
ool2o`0001Oooooo00?o0000ooooooooool0W_ooool2o`0003gooooo000Wooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0Voooool2o`0003oooooo000>ooooo`;o00001?ooool00ol0
003oooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool06?ooool2o`00
063ooooo0_l0000hooooo`03o`000?oooooooooo03oooooo000=ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`1Looooo`?o00001oooool2o`0002gooooo0_l0
0012ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00_ooool2o`0001cooooo0_l0001Looooo`03o`000?oooooooooo00;o0000
0oooool7o`0000?ooooo1_l00003ooooo`Ko00000oooool7o`0000;ooooo2?l00002ooooo`;o0000
A?ooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo00;ooooo1?l00006ooooo`Co00001Oooool4o`0000Kooooo1?l00006ooooo`?o
00001_ooool4o`0004Gooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
oooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool07_ooool2o`0005Sooooo00?o0000oooo
ooooool0Noooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000Sooooo00?o0000ooooooooool08?ooool2o`0005Gooooo00?o0000ooooooooool0O?oo
ool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0000Sooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool0O?ooool002Oooooo00?o0000ooooooooool08oooool2o`00
05;ooooo00?o0000ooooooooool0O?ooool002Oooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo07cooooo000Wooooo`03o`000?oooooooooo02Kooooo
0_l0001>ooooo`03o`000?oooooooooo07gooooo000Wooooo`;o0000:Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo07gooooo000Wooooo`03o`000?oooooooooo02Wooooo0_l0001;
ooooo`03o`000?oooooooooo07gooooo000Wooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`1mooooo`009oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0O_ooool002Oooooo0_l0000^ooooo`;o0000
A_ooool00ol0003oooooooooo`1nooooo`009oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0O_ooool002Oooooo00?o0000ooooooooool0<?ooool2
o`0004?ooooo00?o0000ooooooooool0O_ooool002Oooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo07kooooo000Wooooo`;o0000=?ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo07oooooo0008ooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooo
ooooo`0dooooo`?o0000?Oooool00ol0003oooooooooo`1oooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo07oooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0Xooooo`;o00001_ooool4o`0000Gooooo00?o0000
ooooooooool0Ooooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0003[ooooo<_l0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0P?ooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o0000
1Oooool00ol0003oooooooooo`1_ooooo`Co0000Poooool000Oooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`000?l0
00000ol00004ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool001Cooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3foooo
o`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0003goooo
o`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooooooo
oooo00002?ooool2o`000?oooooo000Dooooo`;o00002_ooool00ol0003oooooooooo`3mooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02605 .31286 L
.02846 .31661 L
.03053 .3193 L
.03163 .32045 L
.03279 .32145 L
.03344 .3219 L
.03416 .3223 L
.03543 .32278 L
.03672 .32296 L
.03793 .32288 L
.03911 .32258 L
.04019 .32215 L
.04262 .3208 L
.04497 .31931 L
.04626 .31857 L
.04748 .31802 L
.04817 .31779 L
.04892 .31762 L
.05023 .31759 L
.05088 .31771 L
.05156 .31795 L
.05278 .31867 L
.05393 .31974 L
.05516 .32132 L
.05633 .32326 L
.05739 .32541 L
.05999 .3322 L
.06244 .3405 L
.07223 .38417 L
.07759 .40717 L
.08022 .41629 L
.08263 .42306 L
.08523 .42864 L
.0866 .43086 L
.08805 .43271 L
.08953 .43413 L
.0909 .43509 L
.0917 .4355 L
.09242 .4358 L
.09325 .43606 L
.09403 .43624 L
.09531 .43642 L
.09595 .43647 L
.09666 .4365 L
.09792 .43653 L
.09909 .43655 L
.0998 .43657 L
.10047 .4366 L
.10174 .4367 L
Mistroke
.10244 .43679 L
.1031 .4369 L
.10458 .43725 L
.10587 .43768 L
.10723 .43827 L
.10967 .43967 L
.11517 .44412 L
.12033 .44896 L
.12514 .45308 L
.13402 .45861 L
.14376 .46351 L
.18272 .48905 L
.20257 .50272 L
.20801 .50595 L
.21099 .50739 L
.21378 .50849 L
.21615 .50922 L
.21871 .50981 L
.22009 .51003 L
.22084 .51013 L
.22154 .51021 L
.22278 .51032 L
.22344 .51035 L
.22414 .51038 L
.22544 .51041 L
.2261 .51041 L
.22683 .51039 L
.22811 .51035 L
.22931 .51029 L
.23201 .5101 L
.2349 .50987 L
.23763 .50967 L
.23897 .50959 L
.24021 .50953 L
.24133 .50949 L
.24253 .50947 L
.24373 .50947 L
.24441 .50947 L
.24505 .50948 L
.24616 .50951 L
.24737 .50955 L
.24864 .50961 L
.24981 .50968 L
.25418 .50997 L
.25663 .51013 L
.25783 .51019 L
.25894 .51023 L
.26022 .51027 L
.2609 .51028 L
.26161 .51029 L
Mistroke
.26276 .51029 L
.26403 .51027 L
.26532 .51023 L
.26652 .51018 L
.26924 .51003 L
.27418 .50969 L
.27529 .50962 L
.27649 .50956 L
.27755 .50951 L
.27867 .50947 L
.27998 .50944 L
.28118 .50943 L
.28227 .50944 L
.28346 .50947 L
.28413 .50949 L
.28486 .50952 L
.28619 .50959 L
.28867 .50975 L
.29138 .50995 L
.29426 .51016 L
.29546 .51023 L
.29675 .5103 L
.29749 .51032 L
.29817 .51034 L
.29882 .51036 L
.2995 .51036 L
.3007 .51036 L
.30181 .51035 L
.30303 .51031 L
.30434 .51025 L
.30693 .51008 L
.30968 .50985 L
.31205 .50966 L
.31459 .50948 L
.31533 .50944 L
.31602 .5094 L
.31733 .50936 L
.31855 .50934 L
.31924 .50934 L
.31988 .50934 L
.32065 .50935 L
.32136 .50937 L
.32201 .5094 L
.3227 .50943 L
.32427 .50953 L
.3257 .50964 L
.33078 .5101 L
.33205 .51021 L
.33326 .5103 L
.33443 .51038 L
Mistroke
.33551 .51043 L
.33666 .51047 L
.3379 .51048 L
.33914 .51048 L
.34045 .51044 L
.34109 .51041 L
.34178 .51037 L
.34302 .51029 L
.34586 .51004 L
.35075 .50954 L
.35215 .50941 L
.35348 .50932 L
.35467 .50925 L
.35596 .50921 L
.35665 .5092 L
.3574 .5092 L
.3582 .50921 L
.35893 .50923 L
.36026 .50929 L
.361 .50933 L
.36167 .50938 L
.3644 .50964 L
.36698 .50994 L
.36941 .51022 L
.37073 .51036 L
.37198 .51047 L
.37304 .51055 L
.37418 .5106 L
.37544 .51064 L
.3766 .51064 L
.37786 .51062 L
.37904 .51056 L
.38033 .51047 L
.3817 .51034 L
.38707 .50966 L
.38966 .50934 L
.39107 .5092 L
.39176 .50914 L
.3924 .50909 L
.39352 .50904 L
.39473 .509 L
.39605 .50901 L
.39731 .50905 L
.39801 .50909 L
.39864 .50914 L
.40006 .50927 L
.40262 .5096 L
.40563 .51006 L
.40841 .51046 L
.40966 .51062 L
Mistroke
.41083 .51074 L
.41206 .51083 L
.4127 .51086 L
.4134 .51088 L
.41409 .51089 L
.41485 .51089 L
.41556 .51087 L
.41622 .51084 L
.41746 .51076 L
.41809 .5107 L
.41879 .51062 L
.42121 .51028 L
.42383 .50982 L
.42631 .50937 L
.42856 .50902 L
.42979 .50887 L
.43096 .50877 L
.43219 .5087 L
.43289 .50868 L
.43353 .50868 L
.4346 .5087 L
.43577 .50878 L
.437 .5089 L
.43815 .50905 L
.44079 .50952 L
.4432 .51003 L
.44602 .51063 L
.44726 .51086 L
.44863 .51107 L
.44992 .51122 L
.45114 .5113 L
.45243 .51133 L
.45315 .51132 L
.45381 .51129 L
.45513 .51118 L
.45587 .51109 L
.45656 .51099 L
.45946 .51039 L
.46205 .50972 L
.4648 .50899 L
.46715 .50847 L
.46779 .50836 L
.46849 .50825 L
.46974 .50812 L
.47038 .50807 L
.47108 .50805 L
.47237 .50807 L
.47361 .50817 L
.47477 .50833 L
.47549 .50846 L
Mistroke
.47616 .5086 L
.47742 .50893 L
.48024 .50982 L
.48275 .5107 L
.4854 .51155 L
.4865 .51184 L
.48767 .51208 L
.48896 .51226 L
.49016 .51233 L
.49131 .51231 L
.49256 .51218 L
.49374 .51196 L
.49483 .51168 L
.49689 .51095 L
.49908 .50996 L
.50154 .50874 L
.50412 .50752 L
.50519 .5071 L
.50632 .50672 L
.50757 .50642 L
.50874 .50626 L
.50995 .50624 L
.51126 .50639 L
.5125 .50671 L
.51365 .50714 L
.51468 .50766 L
.51582 .50834 L
.51811 .51003 L
.52298 .51412 L
.52438 .51514 L
.52507 .51557 L
.52572 .51592 L
.52691 .51641 L
.52821 .51667 L
.52945 .5166 L
.53061 .51621 L
.53166 .51558 L
.53279 .51457 L
.53402 .51306 L
.53533 .51098 L
.53766 .50605 L
.54187 .49349 L
.54649 .47591 L
.55175 .45499 L
.55434 .44583 L
.55673 .43864 L
.5589 .4334 L
.5612 .42933 L
.56239 .42782 L
.5635 .42678 L
Mistroke
.56473 .42602 L
.56605 .42563 L
.56672 .42559 L
.56744 .42565 L
.56873 .42602 L
.56951 .42638 L
.57026 .4268 L
.57165 .42777 L
.57698 .43238 L
.57931 .4342 L
.58059 .43501 L
.58178 .43562 L
.58307 .43611 L
.58375 .43629 L
.58449 .43642 L
.58579 .4365 L
.58698 .43642 L
.58815 .43619 L
.58926 .43587 L
.59047 .43541 L
.59178 .43481 L
.59688 .43213 L
.59921 .43108 L
.60038 .43066 L
.60166 .4303 L
.60276 .43009 L
.60393 .42996 L
.60504 .42994 L
.60605 .43 L
.60734 .43017 L
.60799 .4303 L
.60871 .43047 L
.61116 .43124 L
.61384 .43226 L
.61672 .43334 L
.61811 .4338 L
.61944 .43416 L
.62063 .43441 L
.62192 .4346 L
.62315 .43469 L
.62445 .43469 L
.62568 .4346 L
.6268 .43445 L
.63165 .43326 L
.63617 .4319 L
.63845 .43137 L
.63973 .43115 L
.64089 .43101 L
.64216 .43093 L
.64288 .43092 L
Mistroke
.64355 .43093 L
.64477 .43101 L
.64607 .43115 L
.64735 .43136 L
.64873 .43164 L
.65123 .43225 L
.654 .43296 L
.65551 .43332 L
.65692 .4336 L
.65812 .4338 L
.6594 .43396 L
.66014 .43402 L
.66083 .43406 L
.66212 .43408 L
.66331 .43404 L
.66441 .43396 L
.66562 .43382 L
.66689 .43362 L
.67174 .4326 L
.67413 .43209 L
.67634 .43169 L
.67757 .43153 L
.67888 .43141 L
.67963 .43136 L
.68033 .43134 L
.68165 .43134 L
.68286 .4314 L
.68397 .43149 L
.6852 .43164 L
.68649 .43183 L
.69071 .43264 L
.69303 .43309 L
.69523 .43345 L
.69648 .4336 L
.69713 .43367 L
.69783 .43372 L
.69905 .43378 L
.70019 .43379 L
.70132 .43377 L
.70239 .4337 L
.70355 .4336 L
.70481 .43344 L
.7097 .43261 L
.71238 .43213 L
.7137 .43193 L
.71491 .43177 L
.7156 .4317 L
.71635 .43164 L
.71711 .43159 L
.71791 .43155 L
Mistroke
.71859 .43153 L
.71932 .43153 L
.72063 .43157 L
.72131 .43161 L
.72206 .43167 L
.72341 .43181 L
.72594 .43217 L
.731 .43304 L
.73355 .4334 L
.73425 .43348 L
.73501 .43355 L
.73572 .4336 L
.73637 .43363 L
.73754 .43367 L
.73862 .43367 L
.73981 .43363 L
.74108 .43354 L
.74172 .43348 L
.74241 .4334 L
.74367 .43324 L
.74603 .43287 L
.75059 .4321 L
.7519 .43191 L
.75315 .43177 L
.75427 .43167 L
.75549 .43159 L
.7562 .43157 L
.75684 .43157 L
.75758 .43157 L
.75828 .43159 L
.75952 .43167 L
.76022 .43173 L
.76087 .4318 L
.76332 .43214 L
.7659 .43261 L
.76841 .43308 L
.76979 .43332 L
.77109 .43352 L
.77231 .43366 L
.77363 .43377 L
.77483 .43382 L
.77594 .43381 L
.77725 .43373 L
.77848 .43359 L
.77918 .43348 L
.77983 .43335 L
.78128 .43301 L
.78404 .43209 L
.78694 .43081 L
.8251 .40692 L
Mistroke
.86571 .38039 L
.9048 .35496 L
.94634 .32787 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo000Woooo
o`;o00000oooool3o`0002Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:Oooool2o`0000;ooooo00?o0000oooo
ooooool01Oooool002Oooooo0ol000001?oooooo0000o`000?ooool2o`000>?ooooo00?o0000oooo
ooooool02_ooool002Oooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo0>3o
oooo00?o0000ooooooooool02oooool002Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3Nooooo`;o00003_ooool002Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3Looooo`03o`000?oooooooooo00kooooo000Wooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0f_ooool2o`00017ooooo000Wooooo`;o00001oooool00ol0003oooooooooo`3Hoooo
o`;o00004oooool002Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Gooooo`03
o`000?oooooooooo01?ooooo000Wooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
eOooool2o`0001Kooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0dooo
ool00ol0003oooooooooo`0Fooooo`009oooool2o`0000Sooooo00?o0000ooooooooool0dOooool2
o`0001Wooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0coooool2o`00
01_ooooo000Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0cOooool00ol0003o
ooooooooo`0Kooooo`009oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<_ooooo
0_l0000Nooooo`009oooool2o`0000Wooooo00?o0000ooooooooool0bOooool2o`00023ooooo0008
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol00005
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`0P
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`35ooooo`;o00008oooool000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0<Cooooo00?o0000oooo
ooooool08oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0000[ooooo00?o0000
ooooooooool0`_ooool2o`0002Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool09_ooool000Oooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0<3ooooo00?o0000oooo
ooooool09oooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0_Oooool2o`0002[ooooo000Wooooo`;o0000
2oooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo02[ooooo000Wooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0^_ooool2o`0002gooooo000Wooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0^?ooool2o`0002oooooo000Wooooo`;o00003?ooool00ol0
003oooooooooo`2fooooo`03o`000?oooooooooo02oooooo000Wooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0]?ooool2o`0003;ooooo000Wooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0/Oooool2o`0003Cooooo000Wooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0M_ooool4o`0003Kooooo00?o0000ooooooooool0=?ooool002Oooooo0_l0000>
ooooo`03o`000?oooooooooo07Gooooo00Go0000ooooooooooooooooo`000004ooooo`Go00001Ooo
ool6o`0000?ooooo1_l00004ooooo`Go00001?ooool6o`0000Cooooo00?o0000ooooooooool0=Ooo
ool002Oooooo00?o0000ooooooooool03Oooool5o`0007?ooooo00?o0000ooooooooool00_ooool4
o`0000Gooooo1Ol00005ooooo`Co00001_ooool4o`0000Gooooo1?l00006ooooo`Co0000>?ooool0
02Oooooo00?o0000ooooooooool04Oooool3o`00073ooooo00?o0000ooooooooool0Koooool002Oo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06oo
oooo000Wooooo`;o00005Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo073ooooo
000Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`1`ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005
ooooo`03o`000?oooooooooo01Kooooo0ol0001Zooooo`03o`000?oooooooooo073ooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06Oooool2o`0006Sooooo00?o0000ooooooooool0
L?ooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00;ooooo0_l0000Looooo`;o0000IOooool00ol0003oooooooooo`1aooooo`00
3Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool0LOooool000gooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003o
oooo00Co00001Oooool00ol0003oooooooooo`0Nooooo`;o0000H_ooool00ol0003oooooooooo`1a
ooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
2?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
L_ooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0000Rooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool0L_ooool002Oooooo00?o0000ooooooooool08_ooool2
o`0005gooooo00?o0000ooooooooool0L_ooool002Oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo07?ooooo000Wooooo`03o`000?oooooooooo02Go
oooo0_l0001Iooooo`03o`000?oooooooooo07?ooooo000Wooooo`;o0000:?ooool2o`0005Oooooo
00?o0000ooooooooool0Loooool002Oooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo07?ooooo000Wooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`1dooooo`009oooool00ol0003oooooooooo`0[oooo
o`;o0000B_ooool3o`0000Gooooo00?o0000ooooooooool0M?ooool002Oooooo0_l0000^ooooodKo
000000Coooooo`000?l0003o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
07Cooooo000Wooooo`03o`000?oooooooooo07;ooooo0ol00006ooooo`;o000000?oooooo`000?oo
ool0M_ooool002Oooooo00?o0000ooooooooool0O?ooool2o`0007Sooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo
0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005oooo
o`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0m_oo
ool000Sooooo0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?ooool0
0ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Dooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`004oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0
003oooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33248 L
.07216 .34012 L
.0775 .3458 L
.08013 .34832 L
.08255 .35019 L
.08394 .35102 L
.08542 .35168 L
.08618 .35192 L
.0869 .3521 L
.08768 .35224 L
.08852 .35232 L
.08922 .35234 L
.08998 .35231 L
.0907 .35226 L
.09136 .35218 L
.09396 .35177 L
.09462 .35167 L
.09535 .35158 L
.09665 .3515 L
.09793 .35159 L
.0991 .35186 L
.10037 .35242 L
.10109 .35288 L
.10176 .35341 L
.10312 .35483 L
.10458 .3569 L
.10586 .35922 L
.10722 .36224 L
.10967 .3691 L
.11521 .39074 L
.1204 .41551 L
.12528 .43786 L
.1296 .45346 L
.13202 .45978 L
.13425 .46392 L
.13544 .46552 L
.13655 .46665 L
.13777 .46752 L
.13907 .46808 L
.13973 .46823 L
.14044 .46831 L
.14173 .46826 L
.14299 .46804 L
.14415 .46774 L
.14655 .46702 L
.14773 .46671 L
.14883 .46649 L
.15008 .46637 L
.15074 .46636 L
Mistroke
.15145 .46641 L
.15271 .46664 L
.15385 .46702 L
.15502 .46756 L
.15609 .46821 L
.15852 .47011 L
.16292 .47453 L
.16543 .47713 L
.16811 .47955 L
.16942 .4805 L
.17065 .48123 L
.17176 .48174 L
.17296 .48213 L
.17423 .48235 L
.17488 .48238 L
.17559 .48237 L
.17684 .48222 L
.17801 .48194 L
.17869 .48172 L
.17941 .48145 L
.18068 .48091 L
.18355 .47946 L
.18614 .47816 L
.1874 .4776 L
.18857 .47715 L
.18961 .47683 L
.19076 .47657 L
.19191 .4764 L
.19313 .47634 L
.19381 .47636 L
.19446 .47641 L
.19567 .47658 L
.19698 .47688 L
.1984 .4773 L
.20334 .47922 L
.20572 .4801 L
.20689 .48046 L
.20796 .48072 L
.20909 .48094 L
.2103 .48108 L
.21155 .48114 L
.21219 .48113 L
.21288 .48109 L
.21404 .48095 L
.21509 .48077 L
.21631 .48049 L
.21745 .48018 L
.22172 .47878 L
.22394 .47808 L
.22517 .47776 L
Mistroke
.22634 .4775 L
.22699 .47739 L
.22771 .47728 L
.22896 .47717 L
.23024 .47713 L
.23142 .47718 L
.23207 .47723 L
.23277 .47732 L
.23403 .47752 L
.2364 .47807 L
.23893 .47878 L
.2417 .47957 L
.24287 .47987 L
.24412 .48014 L
.2453 .48034 L
.24638 .48048 L
.24759 .48057 L
.24891 .48059 L
.25016 .48054 L
.25131 .48043 L
.25236 .48028 L
.25335 .4801 L
.2556 .47961 L
.26015 .47845 L
.26133 .47819 L
.26259 .47794 L
.26377 .47776 L
.26485 .47763 L
.26612 .47755 L
.26684 .47753 L
.2675 .47753 L
.26871 .47758 L
.26999 .4777 L
.27122 .47786 L
.27254 .47809 L
.27492 .4786 L
.27752 .47921 L
.27889 .47951 L
.28035 .47979 L
.2817 .48001 L
.28292 .48016 L
.28415 .48025 L
.28531 .48029 L
.28649 .48028 L
.28758 .48022 L
.28877 .48011 L
.29002 .47994 L
.2922 .47956 L
.29424 .47914 L
.29648 .47866 L
Mistroke
.29886 .47822 L
.3001 .47803 L
.30076 .47795 L
.30147 .47788 L
.30272 .4778 L
.30389 .47777 L
.30458 .47777 L
.30535 .47779 L
.30607 .47784 L
.30674 .47789 L
.308 .47803 L
.30935 .47822 L
.31445 .47918 L
.31696 .47963 L
.31806 .47979 L
.31926 .47993 L
.32044 .48003 L
.32154 .48009 L
.3227 .4801 L
.32394 .48007 L
.32459 .48003 L
.3253 .47998 L
.32659 .47984 L
.329 .47949 L
.33325 .47871 L
.33549 .47835 L
.3367 .47818 L
.33784 .47806 L
.33904 .47797 L
.34036 .47792 L
.34148 .47792 L
.34268 .47797 L
.34391 .47805 L
.34506 .47817 L
.34723 .47847 L
.34985 .47892 L
.35263 .47939 L
.355 .47972 L
.35564 .47979 L
.35634 .47986 L
.3576 .47994 L
.35889 .47998 L
.35963 .47998 L
.3603 .47997 L
.36155 .47991 L
.36287 .4798 L
.36417 .47965 L
.36539 .47948 L
.36768 .47912 L
.37024 .47869 L
Mistroke
.37293 .4783 L
.37434 .47816 L
.37514 .47809 L
.37589 .47805 L
.3772 .47801 L
.37794 .47801 L
.37861 .47802 L
.37979 .47808 L
.3809 .47816 L
.38212 .47829 L
.38343 .47845 L
.38854 .47926 L
.39088 .47959 L
.39205 .47972 L
.39333 .47983 L
.39443 .47989 L
.39561 .47992 L
.39672 .47991 L
.39772 .47987 L
.39902 .47978 L
.39967 .47972 L
.40039 .47964 L
.40285 .47931 L
.40553 .47888 L
.40841 .47845 L
.40981 .47828 L
.4105 .47821 L
.41114 .47816 L
.41233 .47808 L
.41362 .47804 L
.41474 .47805 L
.41598 .47809 L
.41728 .47818 L
.41849 .4783 L
.42092 .47863 L
.42317 .47899 L
.42586 .47941 L
.42713 .47958 L
.4283 .47972 L
.42953 .47983 L
.43018 .47987 L
.43087 .4799 L
.43203 .47993 L
.4333 .47991 L
.43399 .47988 L
.43463 .47984 L
.43536 .47979 L
.43606 .47972 L
.43864 .47939 L
.44292 .47869 L
Mistroke
.44527 .47834 L
.44642 .4782 L
.44748 .4781 L
.44875 .47802 L
.44941 .478 L
.45011 .47799 L
.45124 .478 L
.45249 .47806 L
.45365 .47815 L
.45489 .47829 L
.45714 .47862 L
.46207 .47947 L
.46327 .47966 L
.46456 .47982 L
.4653 .47989 L
.46598 .47995 L
.46663 .47999 L
.46731 .48002 L
.468 .48004 L
.46874 .48004 L
.46943 .48002 L
.47006 .47999 L
.4708 .47994 L
.4716 .47987 L
.47306 .47969 L
.47583 .47923 L
.47838 .47874 L
.48063 .47833 L
.48186 .47813 L
.48304 .47798 L
.4837 .47792 L
.48442 .47786 L
.48568 .4778 L
.48697 .4778 L
.48816 .47785 L
.48881 .4779 L
.48951 .47797 L
.49079 .47813 L
.49317 .47856 L
.49575 .47912 L
.4985 .47971 L
.49983 .47995 L
.50109 .48014 L
.50221 .48027 L
.50344 .48034 L
.5046 .48036 L
.50583 .48032 L
.50688 .48024 L
.50804 .48009 L
.50939 .47985 L
Mistroke
.51064 .47959 L
.51343 .47887 L
.51588 .47822 L
.51722 .4779 L
.51849 .47764 L
.51916 .47753 L
.51989 .47742 L
.52116 .4773 L
.52246 .47726 L
.52365 .47729 L
.52496 .47742 L
.5257 .47753 L
.52639 .47766 L
.52929 .47842 L
.53188 .47928 L
.53463 .48021 L
.53576 .48055 L
.53697 .48085 L
.53767 .481 L
.53831 .4811 L
.53957 .48124 L
.54073 .48128 L
.542 .4812 L
.54264 .48112 L
.54333 .48101 L
.54457 .48071 L
.54603 .48023 L
.54741 .47967 L
.55001 .47844 L
.55231 .47731 L
.55475 .47628 L
.55603 .47588 L
.55675 .47572 L
.55743 .4756 L
.55862 .47552 L
.5599 .47559 L
.56113 .47584 L
.56228 .47622 L
.56353 .47681 L
.56487 .47761 L
.56959 .4814 L
.57199 .48338 L
.57316 .48421 L
.57424 .48484 L
.57522 .48526 L
.57626 .48551 L
.57731 .48555 L
.57845 .4853 L
.57976 .48461 L
.58097 .48354 L
Mistroke
.5816 .48281 L
.58229 .48186 L
.5837 .47949 L
.58626 .4736 L
.58867 .46634 L
.59798 .42924 L
.60289 .41111 L
.60536 .40415 L
.60677 .40099 L
.60805 .39867 L
.60947 .39671 L
.61025 .3959 L
.61099 .39531 L
.6123 .39464 L
.61303 .39447 L
.61371 .39443 L
.61492 .39464 L
.61624 .39519 L
.6169 .39559 L
.61761 .39608 L
.6189 .39712 L
.62382 .40178 L
.62511 .4029 L
.62651 .40396 L
.62775 .40472 L
.62905 .40532 L
.6298 .40557 L
.63062 .40575 L
.63136 .40585 L
.63206 .40587 L
.63338 .40576 L
.63411 .4056 L
.63478 .40541 L
.63609 .40492 L
.63752 .40424 L
.6401 .40275 L
.64272 .40119 L
.64517 .39995 L
.64641 .39946 L
.64704 .39926 L
.64773 .39907 L
.64849 .39892 L
.64921 .39881 L
.6499 .39876 L
.65055 .39875 L
.65182 .39883 L
.653 .39903 L
.65407 .39929 L
.65523 .39966 L
.66021 .40177 L
Mistroke
.66258 .40277 L
.66388 .40324 L
.66512 .40359 L
.66627 .40385 L
.66752 .40402 L
.66866 .40409 L
.66971 .40407 L
.67095 .40395 L
.67211 .40376 L
.67339 .40346 L
.67477 .40305 L
.67733 .40215 L
.68014 .40113 L
.68148 .4007 L
.68291 .4003 L
.68361 .40014 L
.68427 .40001 L
.68549 .39983 L
.68618 .39976 L
.6869 .39973 L
.6882 .39973 L
.68892 .39978 L
.68959 .39984 L
.69033 .39995 L
.69113 .40008 L
.69383 .40074 L
.69639 .40153 L
.69871 .40225 L
.70121 .40292 L
.70256 .40319 L
.7038 .40336 L
.70499 .40346 L
.70625 .40349 L
.70738 .40344 L
.70843 .40335 L
.70958 .40319 L
.71082 .40295 L
.71607 .40157 L
.71866 .40089 L
.71979 .40064 L
.72105 .40041 L
.7222 .40026 L
.72329 .40016 L
.72443 .40012 L
.72566 .40014 L
.72694 .40024 L
.72758 .40031 L
.72828 .40041 L
.73068 .40087 L
.73489 .40192 L
Mistroke
.7371 .40245 L
.73831 .4027 L
.73945 .4029 L
.74076 .40307 L
.74146 .40313 L
.74221 .40318 L
.74289 .4032 L
.74353 .4032 L
.74475 .40316 L
.74599 .40306 L
.74714 .40291 L
.7484 .4027 L
.74974 .40243 L
.75424 .40137 L
.7566 .40087 L
.75789 .40065 L
.75909 .40049 L
.76037 .40037 L
.76105 .40034 L
.76177 .40032 L
.76306 .40034 L
.76423 .40042 L
.76542 .40054 L
.76671 .40073 L
.76905 .40118 L
.77179 .4018 L
.77473 .40244 L
.77616 .40269 L
.77686 .40279 L
.77751 .40288 L
.77873 .403 L
.77937 .40304 L
.78005 .40306 L
.78128 .40307 L
.78197 .40305 L
.78261 .40301 L
.78378 .40291 L
.78501 .40275 L
.78715 .40238 L
.7895 .40188 L
.7921 .4013 L
.79353 .40101 L
.79488 .40077 L
.79614 .4006 L
.7968 .40052 L
.79751 .40046 L
.79875 .40039 L
.7999 .40037 L
.8012 .40042 L
.80239 .40051 L
Mistroke
.80369 .40067 L
.80506 .40088 L
.8099 .40193 L
.81245 .40249 L
.81385 .40275 L
.81517 .40295 L
.81592 .40305 L
.81674 .40312 L
.81748 .40317 L
.81816 .4032 L
.8188 .40321 L
.81951 .4032 L
.82025 .40317 L
.82094 .40312 L
.82219 .40297 L
.82289 .40286 L
.82352 .40275 L
.82592 .40218 L
.82872 .4013 L
.83135 .40031 L
.84123 .39615 L
.85978 .38511 L
.89839 .35993 L
.93946 .33272 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo000Woooo
o`03o`000?oooooooooo00;o0000:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>Co
oooo00?o0000ooooooooool02_ooool002Oooooo0_l00004ooooo`;o0000h_ooool2o`0000gooooo
000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0g_ooool00ol0003ooooooooo
o`0=ooooo`009oooool00ol0003oooooooooo`06ooooo`;o0000g?ooool2o`00013ooooo000Woooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`0@oooo
o`009oooool2o`0000[ooooo00?o0000ooooooooool0eOooool2o`0001?ooooo000Wooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0doooool00ol0003oooooooooo`0Cooooo`009ooo
ool00ol0003oooooooooo`0;ooooo`;o0000d_ooool00ol0003oooooooooo`0Dooooo`009oooool0
0ol0003oooooooooo`0<ooooo`Go0000c?ooool2o`0001Oooooo000Wooooo`;o00004_ooool00ol0
003oooooooooo`38ooooo`03o`000?oooooooooo01Oooooo000Wooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0aOooool2o`0001[ooooo000Wooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0`oooool2o`0001cooooo000Wooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0`_ooool00ol0003oooooooooo`0Looooo`009oooool2o`0001?ooooo00?o0000
ooooooooool0`?ooool2o`0001oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0_Oooool2o`00027ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool0
8Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo0;[ooooo0_l0000Tooooo`001oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`;o00005Oooool00ol0003oooooooooo`2gooooo`;o00009_ooool000Oooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol0
0005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0]_ooool00ol0003ooooooooo
o`0Vooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0N_ooool4o`0003Kooooo0_l0000Yooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1jooooo`04o`00
0?ooooooooooo`0000Gooooo1?l00005ooooo`Go00001Oooool4o`0000Gooooo1Ol00005ooooo`Co
00001Oooool2o`0002_ooooo000Wooooo`;o00005Oooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo00;ooooo0_l000000ooooooo0000o`000004ooooo`Ko00000oooool6o`0000Cooooo
1Ol00005ooooo`Go00001?ooool5o`0002gooooo000Wooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`04ooooo`;o0000GOooool002Oooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo06?ooooo000Woooo
o`;o00005_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo06?ooooo000Wooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`1Tooooo`00
9oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0
I?ooool002Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1gooooo`03o`000?oo
oooooooo06Cooooo000Wooooo`;o00005oooool00ol0003oooooooooo`1eooooo`03o`000?oooooo
oooo06Gooooo000Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0MOooool00ol0
003oooooooooo`1Uooooo`009oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo07Go
oooo00?o0000ooooooooool0IOooool002Oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1dooooo`03o`000?oooooooooo06Kooooo000Wooooo`;o00006?ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo06Kooooo000Wooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`1Vooooo`003_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1Vooooo`003Oooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1Vooooo`003Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
0_ooool2o`0001[ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1Wooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Iooooo`Ko0000KOooool00ol0003oooooooooo`1Wooooo`00
3Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1Woooo
o`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo063ooooo0ol00005ooooo`03o`000?oo
oooooooo06Sooooo000>ooooo`;o00002_ooool2o`0000;ooooo1Ol00004ooooo`;o00008_ooool0
1?l0003oooooooooooooool7o`0000;ooooo2?l000000ooooooo0000o`000006o`000003ooooool0
003o000003go00000_ooool3o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Xooooo`009oooool00ol0003oooooooooo`0Rooooo`Co00001Oooool4o`0000Kooooo0ol00007
ooooo`03o`000?oooooooooo03Cooooo0_l00007ooooo`?o00001Oooool2o`000003ooooool0003o
oooo06[ooooo000Wooooo`03o`000?oooooooooo08Sooooo0ol0001[ooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Go
oooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool0
0ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`00
0?l000000ol00004ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2
o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool001Cooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000Coooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3f
ooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0003g
ooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000Coooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooo
oooooooo00002?ooool2o`000?oooooo000Dooooo`;o00002_ooool00ol0003oooooooooo`3moooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33385 L
.08255 .34785 L
.08518 .35052 L
.08802 .3531 L
.09053 .35496 L
.0932 .35644 L
.09467 .35706 L
.0963 .35759 L
.09916 .35826 L
.10199 .35881 L
.10458 .35943 L
.10583 .35983 L
.10719 .36038 L
.10968 .36169 L
.11252 .36374 L
.11516 .36609 L
.12035 .37118 L
.12281 .37329 L
.12388 .37407 L
.12507 .37477 L
.12618 .37528 L
.12735 .37564 L
.12863 .37581 L
.12982 .37574 L
.13095 .37547 L
.13199 .37506 L
.13318 .3744 L
.1343 .37361 L
.13898 .36911 L
.14147 .36651 L
.14278 .36528 L
.14415 .3642 L
.14539 .36346 L
.1461 .36316 L
.14675 .36298 L
.1479 .36289 L
.14913 .36316 L
.15039 .36386 L
.15158 .36495 L
.15265 .36628 L
.15381 .36812 L
.1564 .37371 L
.15914 .38168 L
.16406 .39982 L
.169 .41969 L
.17369 .43627 L
.17572 .44202 L
.17789 .44694 L
.17914 .44917 L
Mistroke
.18027 .45082 L
.18141 .45212 L
.18248 .45303 L
.18363 .45369 L
.18485 .45406 L
.18588 .45413 L
.18702 .45397 L
.18824 .45358 L
.18955 .45295 L
.19192 .45142 L
.19441 .44958 L
.19713 .44769 L
.19837 .44694 L
.19969 .44628 L
.20081 .44583 L
.20206 .44546 L
.2033 .44523 L
.20444 .44514 L
.20569 .44518 L
.207 .44534 L
.20815 .44558 L
.20922 .44587 L
.21164 .4467 L
.21618 .44842 L
.21818 .44904 L
.21924 .44931 L
.22037 .44954 L
.22164 .44972 L
.22283 .44982 L
.22353 .44984 L
.22419 .44984 L
.22543 .44978 L
.2261 .44972 L
.2268 .44963 L
.22806 .44944 L
.23092 .44884 L
.23339 .44825 L
.23605 .44765 L
.23727 .44741 L
.23856 .44721 L
.23966 .44708 L
.24087 .44697 L
.24202 .44692 L
.24308 .44691 L
.24429 .44694 L
.24544 .44701 L
.24651 .44711 L
.24749 .44722 L
.2497 .44753 L
.25441 .44828 L
Mistroke
.25576 .44846 L
.25705 .44861 L
.25821 .44872 L
.25947 .44881 L
.26074 .44886 L
.2619 .44887 L
.26254 .44887 L
.26323 .44885 L
.26449 .4488 L
.26567 .44873 L
.26691 .44863 L
.26914 .4484 L
.27352 .44793 L
.27478 .44781 L
.27597 .44771 L
.27706 .44764 L
.27821 .44758 L
.27947 .44754 L
.28064 .44752 L
.2819 .44753 L
.28262 .44754 L
.2833 .44756 L
.28449 .44761 L
.28558 .44767 L
.28804 .44783 L
.29326 .44822 L
.29477 .4483 L
.29618 .44837 L
.29746 .44841 L
.29818 .44843 L
.29884 .44844 L
.30001 .44844 L
.30111 .44844 L
.30231 .44842 L
.3036 .44838 L
.30496 .44833 L
.30624 .44828 L
.30865 .44816 L
.31093 .44805 L
.31307 .44796 L
.31426 .44792 L
.31554 .44788 L
.31671 .44786 L
.31778 .44785 L
.31897 .44784 L
.32028 .44785 L
.32094 .44786 L
.32164 .44786 L
.32292 .44789 L
.32541 .44795 L
Mistroke
.32768 .44801 L
.33034 .44809 L
.33175 .44812 L
.33323 .44815 L
.33453 .44817 L
.33527 .44818 L
.33596 .44818 L
.33718 .44819 L
.33848 .44819 L
.33917 .44819 L
.33981 .44819 L
.34101 .44818 L
.34231 .44817 L
.34372 .44815 L
.34858 .4481 L
.35002 .44808 L
.35137 .44807 L
.35278 .44806 L
.35352 .44806 L
.35432 .44806 L
.355 .44806 L
.35574 .44806 L
.35644 .44806 L
.35709 .44806 L
.35831 .44806 L
.35961 .44806 L
.36084 .44806 L
.36197 .44806 L
.36322 .44806 L
.36453 .44805 L
.36567 .44805 L
.36674 .44805 L
.36915 .44803 L
.37177 .44802 L
.37306 .44801 L
.37425 .44801 L
.37491 .448 L
.37562 .448 L
.37632 .448 L
.3771 .448 L
.37775 .44801 L
.37844 .44801 L
.37969 .44802 L
.3846 .44808 L
.38982 .44818 L
.39137 .4482 L
.39213 .44821 L
.39282 .44822 L
.39413 .44823 L
.39482 .44823 L
Mistroke
.39555 .44823 L
.39686 .44822 L
.39808 .44821 L
.39878 .4482 L
.39942 .44819 L
.40086 .44816 L
.40581 .44801 L
.40842 .44793 L
.40984 .44789 L
.41118 .44787 L
.41235 .44785 L
.4136 .44784 L
.41428 .44784 L
.41499 .44784 L
.41626 .44785 L
.41743 .44787 L
.41851 .44789 L
.42096 .44798 L
.42602 .4482 L
.42868 .44831 L
.43003 .44835 L
.43079 .44837 L
.4315 .44838 L
.43281 .4484 L
.434 .4484 L
.43466 .44839 L
.43537 .44838 L
.43668 .44835 L
.43788 .44831 L
.43915 .44825 L
.44145 .44813 L
.44569 .44788 L
.44686 .44781 L
.44809 .44776 L
.44915 .44772 L
.45028 .44768 L
.45152 .44766 L
.45268 .44766 L
.45339 .44766 L
.45406 .44768 L
.45531 .44771 L
.45649 .44775 L
.45758 .44781 L
.46004 .44797 L
.4647 .44832 L
.46604 .44841 L
.46732 .44848 L
.46846 .44853 L
.46971 .44857 L
.47091 .44859 L
Mistroke
.47199 .44859 L
.47324 .44857 L
.47441 .44853 L
.4755 .44848 L
.47651 .44842 L
.47877 .44824 L
.48128 .44801 L
.48396 .44776 L
.48526 .44765 L
.4865 .44756 L
.4876 .4475 L
.4888 .44746 L
.49008 .44744 L
.49072 .44743 L
.49143 .44744 L
.49268 .44748 L
.49386 .44753 L
.49453 .44758 L
.49525 .44763 L
.49652 .44774 L
.4994 .44805 L
.50176 .44833 L
.50431 .4486 L
.50548 .4487 L
.50673 .44878 L
.50778 .44883 L
.50895 .44886 L
.50964 .44886 L
.51028 .44886 L
.51101 .44884 L
.51171 .44881 L
.51295 .44874 L
.51365 .44868 L
.51429 .44862 L
.51915 .448 L
.52135 .44768 L
.52373 .44738 L
.52483 .44727 L
.52598 .44718 L
.52697 .44713 L
.52805 .4471 L
.52929 .4471 L
.52998 .44712 L
.53062 .44715 L
.53185 .44724 L
.53302 .44736 L
.53517 .44765 L
.53752 .44805 L
.54206 .44885 L
.54337 .44903 L
Mistroke
.54461 .44917 L
.54573 .44926 L
.54694 .44931 L
.54765 .44932 L
.54829 .44931 L
.54903 .44929 L
.54973 .44924 L
.55097 .44913 L
.55166 .44904 L
.55231 .44895 L
.55475 .4485 L
.55734 .44791 L
.55983 .44733 L
.56121 .44704 L
.56252 .4468 L
.56373 .44663 L
.56505 .4465 L
.56624 .44645 L
.56735 .44646 L
.56866 .44654 L
.56989 .44668 L
.57059 .44679 L
.57124 .44691 L
.57269 .44724 L
.57836 .44896 L
.58079 .44965 L
.58199 .44993 L
.58309 .45012 L
.58436 .45027 L
.58503 .45032 L
.58574 .45033 L
.58689 .45029 L
.58815 .45014 L
.58933 .44991 L
.59042 .44963 L
.59286 .44876 L
.59726 .44676 L
.59972 .4457 L
.60107 .44523 L
.60234 .44489 L
.60306 .44476 L
.60385 .44466 L
.60456 .44462 L
.60521 .44463 L
.60651 .44477 L
.60716 .44491 L
.60788 .44512 L
.60919 .44563 L
.6104 .44624 L
.61309 .44806 L
Mistroke
.61541 .44992 L
.61796 .452 L
.61915 .45288 L
.62044 .45368 L
.62166 .45425 L
.62277 .45458 L
.62396 .45469 L
.62526 .45446 L
.62592 .4542 L
.62662 .4538 L
.62789 .45276 L
.62907 .45139 L
.63036 .44945 L
.6327 .44472 L
.63497 .43866 L
.63706 .43196 L
.64224 .41225 L
.6478 .39034 L
.65049 .38119 L
.65304 .37406 L
.65533 .3692 L
.65663 .36713 L
.65783 .36566 L
.65902 .36461 L
.66029 .3639 L
.6615 .36362 L
.66261 .36366 L
.66361 .36391 L
.66471 .36439 L
.66586 .36508 L
.66693 .36587 L
.67191 .37033 L
.67436 .37235 L
.67543 .37309 L
.67661 .37377 L
.67783 .37431 L
.67912 .37469 L
.67979 .3748 L
.68052 .37487 L
.68184 .37484 L
.68311 .37463 L
.68432 .37428 L
.6854 .37387 L
.68659 .37332 L
.69208 .3703 L
.6934 .36963 L
.69478 .36902 L
.69606 .36857 L
.69726 .36825 L
.6984 .36805 L
Mistroke
.69962 .36795 L
.70032 .36795 L
.70098 .36799 L
.70222 .36814 L
.70286 .36826 L
.70355 .36842 L
.70478 .36877 L
.70758 .36981 L
.71208 .37166 L
.71331 .37209 L
.71461 .37247 L
.71572 .37273 L
.71693 .37294 L
.71822 .37306 L
.71894 .37308 L
.71959 .37307 L
.72087 .37298 L
.72207 .3728 L
.72328 .37256 L
.72439 .37228 L
.7269 .3715 L
.72962 .37058 L
.7322 .36979 L
.73363 .36944 L
.73438 .36929 L
.73518 .36915 L
.73592 .36906 L
.73659 .36899 L
.7379 .36894 L
.73915 .36896 L
.7403 .36906 L
.74156 .36923 L
.7429 .36949 L
.74759 .37074 L
.74984 .37137 L
.75197 .37189 L
.75315 .37211 L
.75443 .3723 L
.75559 .37241 L
.75666 .37246 L
.75784 .37245 L
.75913 .37237 L
.75979 .37231 L
.76049 .37222 L
.76176 .37201 L
.76424 .37148 L
.76651 .37091 L
.76923 .37024 L
.77177 .36973 L
.77305 .36954 L
Mistroke
.77376 .36946 L
.77441 .36941 L
.77513 .36937 L
.7759 .36935 L
.77663 .36935 L
.7773 .36937 L
.77856 .36946 L
.77975 .36959 L
.78082 .36975 L
.78199 .36996 L
.78702 .37109 L
.7893 .37157 L
.79056 .37179 L
.79173 .37196 L
.79273 .37206 L
.79381 .37214 L
.795 .37218 L
.7961 .37216 L
.7973 .3721 L
.79858 .37197 L
.7998 .37181 L
.8009 .37163 L
.80615 .37054 L
.80877 .37004 L
.81024 .36981 L
.81094 .36973 L
.8116 .36966 L
.81279 .36958 L
.8141 .36954 L
.81538 .36956 L
.8161 .3696 L
.81675 .36965 L
.81804 .36978 L
.81925 .36995 L
.82152 .37035 L
.82417 .37089 L
.8266 .37138 L
.82874 .37173 L
.82982 .37186 L
.831 .37197 L
.83218 .37204 L
.83345 .37206 L
.83465 .37203 L
.83575 .37195 L
.83703 .37182 L
.8384 .37163 L
.84085 .3712 L
.84371 .37061 L
.84639 .3701 L
.84752 .36993 L
Mistroke
.8487 .36977 L
.85 .36965 L
.85119 .36958 L
.8525 .36957 L
.85371 .36961 L
.85441 .36966 L
.85505 .36971 L
.85648 .36989 L
.86129 .37081 L
.86365 .37133 L
.8658 .37176 L
.86689 .37193 L
.86807 .37208 L
.86932 .37218 L
.8705 .37221 L
.8718 .37218 L
.87253 .37212 L
.87318 .37205 L
.87447 .37184 L
.87567 .37157 L
.87699 .37119 L
.87838 .3707 L
.88088 .36962 L
.8865 .36651 L
.89647 .36056 L
.93451 .33567 L
.975 .30964 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo000Woooo
o`03o`000?oooooooooo00;o0000:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>Co
oooo00?o0000ooooooooool02_ooool002Oooooo0_l00004ooooo`;o0000hoooool00ol0003ooooo
ooooo`0;ooooo`009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=kooooo0_l0
000>ooooo`009oooool00ol0003oooooooooo`06ooooo`;o0000gOooool00ol0003oooooooooo`0>
ooooo`009oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Sooooo0_l0000Aoooo
o`009oooool2o`0000[ooooo0_l0003Fooooo`;o00004oooool002Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3Booooo`03o`000?oooooooooo01?ooooo000Wooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0coooool2o`0001Kooooo000Wooooo`03o`000?oooooo
oooo00cooooo0_l0003>ooooo`;o00006?ooool002Oooooo0_l0000?ooooo`;o0000boooool00ol0
003oooooooooo`0Hooooo`009oooool00ol0003oooooooooo`0@ooooo`?o0000aoooool00ol0003o
ooooooooo`0Iooooo`009oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo
0ol00020ooooo`?o0000>?ooool00ol0003oooooooooo`0Jooooo`009oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000o`00001nooooo`04o`000?oo
ooooooooo`0000Kooooo1?l00006ooooo`?o00001oooool3o`0000Kooooo1?l00006ooooo`?o0000
1Oooool3o`0001gooooo000Wooooo`;o00005_ooool2o`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1looooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Cooooo
1_l00003ooooo`Oo00000_ooool8o`0000;ooooo2?l00002ooooo`Ko00007oooool000Sooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Gooooo00?o
0000ooooooooool05_ooool3o`0000Gooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`04ooooo`;o0000DOooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`1Goooo
o`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`1Gooooo`001oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`;o00008?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo05Sooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07So
oooo00?o0000ooooooooool0F?ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0F?ooool000Sooooo0_l0000:oooo
o`;o00000oooool3o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`1Hooooo`009oooool2o`00027ooooo00?o0000oooooooo
ool0Moooool00ol0003oooooooooo`1Iooooo`009oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool0FOooool002Oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo05Wooooo000Wooooo`;o00008_ooool0
0ol0003oooooooooo`1fooooo`03o`000?oooooooooo05Wooooo000Wooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1Jooooo`009oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0F_ooool002Oooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo05[ooooo
000Wooooo`;o00009?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo05_ooooo000W
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1K
ooooo`009oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Foooool002Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Zooooo`;o
00001Oooool00ol0003oooooooooo`1Looooo`009oooool2o`0002Gooooo00?o0000ooooooooool0
0_ooool6o`0000?ooooo1ol000000ooooooo0000o`00000lo`000003ooooool0003o000000Go0000
0oooool6o`0000Gooooo1Ol00004ooooo`03o`000?oooooooooo05cooooo000Wooooo`03o`000?oo
oooooooo02Cooooo0_l000000ooooooo0000o`000005ooooo`Co00001oooool2o`0003cooooo0ol0
0006ooooo`Co00001Oooool5o`0000Gooooo0_l000000ooooooo0000o`00001Nooooo`003_ooool2
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooo
oooo02Gooooo0ol0001/ooooo`?o0000Goooool000gooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04
o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0
000:ooooo`;o00000_ooool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_oo
ool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Go
oooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3f
ooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004oooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`;o0000moooool001Cooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3fooooo`004oooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0003gooooo`004oooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo00002?ooool2
o`000?oooooo000Dooooo`;o00002_ooool00ol0003oooooooooo`3mooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .32096 L
.0522 .32666 L
.06244 .33483 L
.06525 .33678 L
.0679 .33826 L
.07027 .33923 L
.07162 .33962 L
.07286 .33988 L
.07401 .34004 L
.0751 .34012 L
.07628 .34015 L
.07756 .34011 L
.0782 .34007 L
.0789 .34002 L
.08017 .33989 L
.08255 .3396 L
.08405 .33942 L
.08545 .33928 L
.08672 .33919 L
.08743 .33916 L
.08808 .33914 L
.08879 .33913 L
.08945 .33913 L
.09017 .33915 L
.09095 .33919 L
.09176 .33925 L
.09253 .33933 L
.09398 .3395 L
.09902 .34032 L
.10169 .34071 L
.10243 .34079 L
.1032 .34087 L
.10386 .34091 L
.10458 .34095 L
.10583 .34098 L
.10652 .34097 L
.10716 .34095 L
.10839 .34087 L
.10956 .34074 L
.11073 .34058 L
.1118 .3404 L
.11423 .33991 L
.11681 .33937 L
.11922 .33894 L
.12043 .33877 L
.12173 .33865 L
.12247 .33861 L
.12317 .33859 L
.12449 .3386 L
Mistroke
.12565 .33868 L
.1267 .33879 L
.12792 .33898 L
.12906 .3392 L
.1333 .34026 L
.13555 .34084 L
.13678 .34111 L
.13792 .34133 L
.13916 .3415 L
.13982 .34157 L
.14052 .34162 L
.14177 .34164 L
.14291 .34158 L
.14409 .34146 L
.1452 .34127 L
.14642 .341 L
.14773 .34064 L
.15285 .33891 L
.15519 .3382 L
.15636 .33792 L
.15764 .3377 L
.15874 .3376 L
.15992 .33758 L
.16103 .33765 L
.16203 .3378 L
.16729 .33962 L
.17016 .34106 L
.17285 .34232 L
.17402 .34277 L
.17514 .34311 L
.17642 .34336 L
.17759 .34346 L
.17889 .34338 L
.18009 .34314 L
.18141 .34269 L
.18207 .34238 L
.18281 .34199 L
.18757 .33837 L
.19008 .33619 L
.19145 .33512 L
.19272 .33427 L
.19384 .3337 L
.19504 .33332 L
.19572 .33323 L
.19637 .33324 L
.19757 .33352 L
.19869 .33412 L
.19971 .33497 L
.20084 .33628 L
.20203 .33808 L
Mistroke
.2045 .34321 L
.20715 .35075 L
.21194 .36852 L
.21759 .39206 L
.22035 .4025 L
.22284 .41055 L
.22405 .41384 L
.22536 .41691 L
.2265 .41913 L
.22774 .42109 L
.22906 .42265 L
.22978 .42327 L
.23046 .42372 L
.23166 .4242 L
.23296 .4243 L
.23369 .42418 L
.23438 .42397 L
.23513 .42364 L
.23592 .42319 L
.23873 .42098 L
.24126 .4186 L
.24399 .41617 L
.24524 .41523 L
.24656 .41441 L
.24769 .41387 L
.24892 .41346 L
.25008 .41324 L
.25132 .4132 L
.25248 .41332 L
.25354 .41357 L
.2542 .41377 L
.2549 .41403 L
.25615 .41459 L
.25897 .41611 L
.26159 .4176 L
.26289 .41827 L
.26409 .41881 L
.26533 .41928 L
.26645 .4196 L
.2677 .41984 L
.26838 .41992 L
.26902 .41996 L
.27015 .41994 L
.27119 .41983 L
.27233 .41962 L
.27353 .4193 L
.27878 .41727 L
.28134 .41626 L
.28246 .41588 L
.28367 .41553 L
Mistroke
.2848 .41528 L
.28584 .41512 L
.28684 .41503 L
.2879 .415 L
.28901 .41505 L
.29005 .41517 L
.29119 .41536 L
.29242 .41564 L
.29705 .41708 L
.29959 .4179 L
.30084 .41825 L
.30199 .41852 L
.30331 .41875 L
.30401 .41884 L
.30474 .41891 L
.30593 .41897 L
.30723 .41894 L
.30844 .41883 L
.30974 .41865 L
.31097 .41841 L
.31209 .41815 L
.31737 .4167 L
.31882 .41634 L
.32036 .41602 L
.32167 .41582 L
.32242 .41573 L
.32312 .41568 L
.32438 .41563 L
.32501 .41563 L
.32571 .41566 L
.32694 .41575 L
.32808 .41589 L
.32944 .41612 L
.33067 .41637 L
.33343 .41703 L
.33584 .41762 L
.33711 .41789 L
.33846 .41814 L
.33963 .41832 L
.34093 .41846 L
.3421 .41853 L
.3432 .41854 L
.34445 .4185 L
.34515 .41845 L
.34579 .41839 L
.34702 .41823 L
.34818 .41805 L
.35361 .4169 L
.35592 .41645 L
.35718 .41625 L
Mistroke
.35835 .4161 L
.35963 .41599 L
.3603 .41596 L
.36103 .41594 L
.36231 .41595 L
.36348 .41601 L
.36463 .41612 L
.36585 .41627 L
.36805 .41664 L
.373 .41762 L
.37507 .41796 L
.37623 .41811 L
.37729 .41821 L
.37848 .41829 L
.37973 .41832 L
.38082 .4183 L
.38202 .41823 L
.38266 .41818 L
.38334 .41811 L
.38456 .41796 L
.38731 .41751 L
.3899 .41702 L
.39231 .4166 L
.39341 .41644 L
.39446 .41631 L
.39566 .4162 L
.39676 .41613 L
.39798 .4161 L
.39911 .41612 L
.40034 .41618 L
.40166 .41629 L
.40656 .41701 L
.40924 .41749 L
.41174 .41786 L
.41305 .41801 L
.41378 .41808 L
.41445 .41812 L
.41518 .41816 L
.41597 .41818 L
.41672 .41819 L
.41741 .41818 L
.41861 .41813 L
.4193 .41808 L
.41994 .41802 L
.42123 .41788 L
.42262 .41769 L
.42782 .41683 L
.42906 .41665 L
.43039 .41647 L
.43164 .41634 L
Mistroke
.43277 .41626 L
.43387 .41621 L
.43506 .4162 L
.43618 .41622 L
.43721 .41627 L
.43833 .41636 L
.43957 .41649 L
.44205 .41684 L
.44662 .41757 L
.44793 .41776 L
.44917 .4179 L
.45029 .41801 L
.4515 .41809 L
.45256 .41812 L
.45373 .41812 L
.45494 .41809 L
.45609 .41801 L
.45715 .41792 L
.45812 .41781 L
.46032 .4175 L
.46507 .41675 L
.46643 .41657 L
.46772 .41642 L
.46888 .41633 L
.47013 .41626 L
.47123 .41623 L
.47244 .41624 L
.4737 .41629 L
.47488 .41638 L
.47598 .41649 L
.47699 .41661 L
.47925 .41694 L
.48171 .41734 L
.48433 .41773 L
.48584 .41791 L
.48721 .41803 L
.48787 .41807 L
.48858 .4181 L
.48987 .41812 L
.49109 .4181 L
.49179 .41807 L
.49243 .41803 L
.49373 .41791 L
.49513 .41775 L
.49996 .417 L
.50253 .41661 L
.50394 .41644 L
.50526 .41632 L
.50638 .41625 L
.50759 .41621 L
Mistroke
.50828 .41621 L
.50893 .41622 L
.51016 .41627 L
.51086 .41631 L
.51149 .41637 L
.5129 .41652 L
.51546 .41689 L
.51847 .4174 L
.51979 .41761 L
.52124 .41782 L
.52241 .41796 L
.52366 .41808 L
.52498 .41815 L
.52622 .41818 L
.52691 .41818 L
.52766 .41815 L
.52838 .41812 L
.52904 .41807 L
.53028 .41795 L
.53161 .41779 L
.5367 .41693 L
.53893 .41656 L
.54011 .4164 L
.54138 .41626 L
.54261 .41616 L
.54374 .41611 L
.54487 .4161 L
.54593 .41613 L
.54713 .41621 L
.54824 .41631 L
.54945 .41647 L
.55073 .41666 L
.55595 .41763 L
.55726 .41786 L
.5585 .41804 L
.55961 .41817 L
.56083 .41828 L
.56188 .41833 L
.563 .41834 L
.56406 .41831 L
.56502 .41825 L
.56614 .41815 L
.56734 .41799 L
.56953 .41761 L
.57192 .41712 L
.57448 .41659 L
.57572 .41636 L
.5769 .41617 L
.57795 .41603 L
.5791 .41593 L
Mistroke
.58024 .41587 L
.5815 .41586 L
.58281 .41592 L
.58405 .41604 L
.5852 .4162 L
.58625 .41638 L
.58862 .41689 L
.59361 .41806 L
.59498 .41832 L
.59573 .41844 L
.59643 .41854 L
.5971 .41861 L
.59781 .41866 L
.59906 .41871 L
.6003 .41868 L
.601 .41863 L
.60166 .41857 L
.60235 .41848 L
.60298 .41838 L
.60441 .4181 L
.60933 .41677 L
.61198 .41604 L
.61338 .41572 L
.61415 .41558 L
.61487 .41547 L
.61556 .41539 L
.61631 .41533 L
.6176 .41529 L
.61892 .41536 L
.62013 .4155 L
.6214 .41574 L
.62261 .41604 L
.62486 .41675 L
.62748 .41771 L
.62991 .41858 L
.63203 .41919 L
.6331 .41941 L
.63427 .41957 L
.63545 .41964 L
.63672 .4196 L
.63792 .41945 L
.63902 .41922 L
.64421 .41711 L
.64706 .41563 L
.64845 .41495 L
.64974 .4144 L
.65096 .41399 L
.65225 .41368 L
.65354 .41354 L
.65428 .41354 L
Mistroke
.65496 .4136 L
.65616 .41383 L
.65725 .41419 L
.65851 .41477 L
.6597 .41548 L
.66411 .41904 L
.66652 .42116 L
.66879 .42282 L
.66997 .42344 L
.67123 .42385 L
.67192 .42394 L
.67264 .42392 L
.67393 .42357 L
.6751 .42287 L
.6762 .42187 L
.6774 .42035 L
.67868 .41823 L
.68136 .41216 L
.68427 .40324 L
.68954 .38266 L
.69464 .36162 L
.69713 .35252 L
.6994 .34547 L
.70174 .33978 L
.70282 .33774 L
.70397 .33596 L
.70518 .33453 L
.70631 .3336 L
.707 .33322 L
.70765 .33297 L
.70887 .33281 L
.71014 .33301 L
.71077 .33323 L
.71147 .33356 L
.71271 .33434 L
.71387 .33523 L
.71665 .33775 L
.71928 .34017 L
.72183 .34212 L
.72326 .34294 L
.72395 .34325 L
.72459 .34348 L
.72571 .34376 L
.72694 .34389 L
.72815 .34383 L
.72944 .34359 L
.73012 .3434 L
.73076 .34318 L
.73221 .34256 L
.73512 .34099 L
Mistroke
.73782 .33946 L
.73901 .33884 L
.74032 .33825 L
.74151 .3378 L
.74278 .33744 L
.74348 .3373 L
.74413 .33721 L
.74538 .33712 L
.74608 .33713 L
.74673 .33718 L
.74744 .33726 L
.7482 .3374 L
.74947 .33771 L
.75087 .33816 L
.75565 .34011 L
.75816 .34107 L
.75953 .34149 L
.76081 .34179 L
.76197 .34199 L
.7632 .3421 L
.7639 .34212 L
.76457 .34211 L
.76581 .34201 L
.76696 .34184 L
.76801 .34163 L
.7704 .34097 L
.77511 .33939 L
.77716 .33879 L
.77825 .33854 L
.77941 .33832 L
.78065 .33816 L
.7818 .33809 L
.78299 .33809 L
.78407 .33815 L
.78531 .33829 L
.78601 .33841 L
.78666 .33853 L
.78909 .33911 L
.79377 .34045 L
.79495 .34075 L
.79606 .341 L
.79715 .3412 L
.79815 .34135 L
.79925 .34146 L
.80046 .34152 L
.80166 .34151 L
.80293 .34143 L
.80422 .34128 L
.80543 .34108 L
.80818 .34048 L
Mistroke
.81324 .33921 L
.81463 .33893 L
.81539 .3388 L
.81611 .3387 L
.81678 .33862 L
.81751 .33855 L
.81878 .33848 L
.81996 .33848 L
.82126 .33854 L
.82192 .3386 L
.82262 .33868 L
.8239 .33886 L
.82636 .33935 L
.82862 .33986 L
.83116 .34044 L
.8325 .34071 L
.83393 .34095 L
.83464 .34105 L
.8353 .34112 L
.83655 .34122 L
.83771 .34125 L
.83897 .34124 L
.84013 .34117 L
.84121 .34106 L
.8424 .3409 L
.84367 .34069 L
.84862 .33965 L
.851 .33918 L
.85217 .33899 L
.85326 .33885 L
.85424 .33876 L
.85528 .33869 L
.85633 .33866 L
.85748 .33867 L
.85877 .33874 L
.85996 .33886 L
.86127 .33903 L
.86267 .33926 L
.86761 .34025 L
.86881 .34048 L
.87011 .3407 L
.87126 .34087 L
.87247 .341 L
.87356 .34109 L
.87476 .34113 L
.87586 .34113 L
.87688 .34109 L
.87817 .34099 L
.8789 .34092 L
.87958 .34083 L
Mistroke
.88214 .34041 L
.88695 .33947 L
.88944 .33905 L
.89012 .33896 L
.89085 .33887 L
.89154 .33881 L
.89218 .33876 L
.89286 .33873 L
.8936 .33871 L
.89432 .3387 L
.89509 .33872 L
.8958 .33875 L
.89648 .3388 L
.89775 .33892 L
.90277 .33977 L
.90746 .34071 L
.90867 .34091 L
.90982 .34106 L
.91046 .34113 L
.91115 .34119 L
.91236 .34125 L
.91307 .34127 L
.91371 .34127 L
.91446 .34124 L
.91516 .34121 L
.9164 .34109 L
.91711 .341 L
.91775 .34091 L
.91997 .34047 L
.92203 .33993 L
.92673 .33839 L
.9362 .33468 L
.94122 .33239 L
.94667 .32929 L
.95658 .32182 L
.97514 .30952 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool01_ooool0
02Oooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`05o`000?oooooo
ooooooooool000001oooool002Oooooo00Co0000oooooooooooooooo0_l0003Vooooo`03o`000?oo
oooooooo00[ooooo000Wooooo`;o00001?ooool00ol0003oooooooooo`3Rooooo`03o`000?oooooo
oooo00_ooooo000Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0h?ooool00ol0
003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023o
oooo0_l00020ooooo`?o0000>?ooool2o`0000oooooo000Wooooo`03o`000?oooooooooo00Kooooo
0ol0000Eooooo`?o00001Oooool2o`000003ooooool0003o000007kooooo0_l000000ooooooo0000
o`000005ooooo`?o00001_ooool3o`0002?ooooo0ol0000Aooooo`009oooool2o`0000Wooooo5_l0
0003ooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`1looooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000?ooooo1ol000000ooooooo0000o`00000Ro`0001Cooooo
000Wooooo`03o`000?oooooooooo02?ooooo0ol00005ooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool00oooool4o`0004Cooooo000Wooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`1;ooooo`009oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0Boooool002Oooooo0_l0000/ooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool0Boooool002Oooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo04cooooo000Wooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1<ooooo`009oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0C?ooool0
02Oooooo0_l0000]ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0C?ooool000So
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo04go
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0COooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool0COooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0002oo
oooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`1=ooooo`001oooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003
o`0000Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo04kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1dooooo`03o`000?oooooooooo04kooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol0
0002ooooo`Go00001?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool0C_ooool002Oooooo0_l0000`ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0Coooool002Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo04oooooo000Wooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo04oooooo000Wooooo`;o0000
<Oooool00ol0003oooooooooo`02ooooo`Co00001Oooool5o`0000Cooooo1Ol00004ooooo`Go0000
1Oooool5o`0000Cooooo1Ol00004ooooo`Go00001?ooool5o`0000Gooooo1Ol00004ooooo`Go0000
1?ooool5o`0000Cooooo1Ol00005ooooo`03o`000?oooooooooo04oooooo000Wooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool00_l00004ooooo`Go00001Oooool4o`0000Gooooo1?l0
0005ooooo`Go00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool5o`0000Gooooo1?l0
0005ooooo`Co00001Oooool4o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo053ooooo000W
ooooo`03o`000?oooooooooo037ooooo0ol0001/ooooo`?o0000Doooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000oooo
ooooool0m_ooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0003gooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`00
0?Oooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?o
ooooo`000?l000000ol00004ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool001Cooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo
000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3fooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo
0_l0003gooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo
000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co
0000oooooooooooo00002?ooool2o`000?oooooo000Dooooo`;o00002_ooool00ol0003ooooooooo
o`3mooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02605 .30952 L
.02729 .30977 L
.02846 .30998 L
.02954 .31015 L
.03072 .31028 L
.0318 .31036 L
.03279 .3104 L
.03396 .3104 L
.03506 .31035 L
.03626 .31025 L
.03756 .31008 L
.0402 .30961 L
.04262 .30907 L
.04497 .30853 L
.04748 .30804 L
.04822 .30793 L
.04892 .30783 L
.05023 .3077 L
.05146 .30763 L
.05215 .30761 L
.05278 .30761 L
.05394 .30766 L
.05502 .30774 L
.05621 .30788 L
.05748 .30808 L
.06244 .30915 L
.06507 .30974 L
.06651 .31001 L
.06787 .31022 L
.06857 .3103 L
.06932 .31037 L
.07016 .31043 L
.07093 .31045 L
.07159 .31046 L
.07231 .31044 L
.07306 .31041 L
.07376 .31035 L
.07443 .31029 L
.07516 .31019 L
.07648 .30998 L
.07895 .30948 L
.08158 .30885 L
.08448 .30819 L
.08575 .30795 L
.08711 .30774 L
.08839 .30761 L
.08956 .30754 L
.09088 .30752 L
.09163 .30755 L
Mistroke
.09232 .30759 L
.09359 .30771 L
.0943 .30781 L
.09494 .30791 L
.09991 .30902 L
.10233 .30962 L
.10458 .3101 L
.10576 .3103 L
.10684 .31044 L
.10808 .31055 L
.10925 .31059 L
.11053 .31057 L
.1117 .31049 L
.113 .31034 L
.11437 .31011 L
.1197 .3088 L
.12231 .30814 L
.12345 .30789 L
.1247 .30765 L
.12577 .3075 L
.12676 .3074 L
.12781 .30734 L
.12893 .30733 L
.13016 .30738 L
.13132 .3075 L
.13236 .30765 L
.13349 .30786 L
.1385 .30919 L
.14095 .30988 L
.14318 .3104 L
.14431 .31061 L
.14553 .31077 L
.14669 .31085 L
.14776 .31087 L
.14889 .31083 L
.15014 .31071 L
.15145 .31051 L
.15267 .31025 L
.15811 .30863 L
.16049 .30789 L
.16175 .30756 L
.1631 .30727 L
.16379 .30715 L
.16443 .30706 L
.16565 .30695 L
.16679 .30692 L
.16803 .30697 L
.16934 .30713 L
.17 .30724 L
.17073 .30739 L
Mistroke
.17323 .30808 L
.17591 .30903 L
.17883 .3101 L
.18017 .31054 L
.18159 .31094 L
.18228 .3111 L
.18294 .31123 L
.18415 .3114 L
.18539 .31148 L
.18669 .31145 L
.18781 .31133 L
.18903 .31111 L
.19034 .31077 L
.19176 .3103 L
.1943 .30925 L
.19874 .30729 L
.19996 .30683 L
.20126 .30644 L
.20236 .30618 L
.20358 .306 L
.2043 .30595 L
.20497 .30595 L
.2057 .30598 L
.20647 .30607 L
.20777 .30633 L
.20851 .30654 L
.20919 .30678 L
.21176 .30794 L
.2145 .30951 L
.21719 .3111 L
.21851 .31181 L
.21972 .31237 L
.22083 .31278 L
.222 .31309 L
.22317 .31325 L
.22446 .31325 L
.22576 .31304 L
.22696 .31266 L
.22828 .31204 L
.22968 .31117 L
.23463 .30685 L
.23715 .30451 L
.23838 .30351 L
.23951 .30272 L
.24054 .30216 L
.24163 .30177 L
.24273 .30161 L
.24392 .30174 L
.2446 .30197 L
.24533 .30235 L
Mistroke
.24602 .30284 L
.24666 .30342 L
.24787 .30484 L
.24915 .30681 L
.25181 .31246 L
.25474 .32093 L
.26482 .35976 L
.2673 .36891 L
.27001 .37755 L
.27257 .38404 L
.2738 .3865 L
.27495 .38843 L
.27608 .38995 L
.2773 .3912 L
.27841 .392 L
.27944 .39246 L
.28055 .39268 L
.28176 .39263 L
.28303 .3923 L
.28422 .39177 L
.28935 .38808 L
.29206 .38601 L
.29355 .38502 L
.29494 .38425 L
.29615 .38373 L
.29745 .38332 L
.29815 .38317 L
.29889 .38306 L
.29952 .38301 L
.30021 .383 L
.30144 .3831 L
.30274 .38333 L
.30398 .38366 L
.3051 .38404 L
.31012 .38616 L
.31276 .3872 L
.31421 .38765 L
.31556 .38798 L
.31674 .38819 L
.31801 .38831 L
.31873 .38834 L
.31941 .38834 L
.3207 .38827 L
.32187 .38812 L
.32297 .38794 L
.32544 .38736 L
.33007 .38604 L
.33234 .38548 L
.33333 .38528 L
.33442 .3851 L
Mistroke
.3356 .38495 L
.33684 .38486 L
.33749 .38483 L
.33819 .38482 L
.33944 .38486 L
.34067 .38495 L
.34182 .38508 L
.34399 .38543 L
.34898 .38643 L
.35143 .38686 L
.3525 .38702 L
.35367 .38716 L
.35481 .38725 L
.35602 .38732 L
.35733 .38733 L
.35855 .38731 L
.35925 .38727 L
.35991 .38723 L
.36115 .38712 L
.36393 .38677 L
.36823 .38612 L
.37058 .38581 L
.37173 .38569 L
.37278 .3856 L
.37393 .38553 L
.37516 .38548 L
.3758 .38547 L
.3765 .38547 L
.37777 .3855 L
.37892 .38555 L
.38015 .38563 L
.38236 .38583 L
.38691 .38635 L
.3894 .3866 L
.39061 .3867 L
.39171 .38677 L
.39292 .38683 L
.39422 .38687 L
.3949 .38688 L
.39563 .38688 L
.39633 .38687 L
.39697 .38685 L
.39809 .38681 L
.39931 .38675 L
.4018 .38657 L
.40634 .38618 L
.40754 .38609 L
.40885 .386 L
.4101 .38592 L
.41123 .38587 L
Mistroke
.41239 .38584 L
.41363 .38582 L
.41477 .38582 L
.41585 .38583 L
.4169 .38586 L
.41787 .38589 L
.42007 .386 L
.42477 .38629 L
.42736 .38644 L
.42863 .3865 L
.42981 .38655 L
.43091 .38658 L
.43209 .3866 L
.43326 .3866 L
.43456 .3866 L
.43564 .38658 L
.4368 .38655 L
.43789 .38652 L
.4389 .38648 L
.44411 .38625 L
.44666 .38615 L
.44776 .38611 L
.44897 .38608 L
.45022 .38606 L
.45141 .38605 L
.45207 .38604 L
.45277 .38604 L
.45403 .38605 L
.45468 .38606 L
.45539 .38607 L
.45666 .38609 L
.45956 .38617 L
.46447 .38631 L
.46589 .38635 L
.46721 .38637 L
.46841 .38639 L
.4697 .3864 L
.47039 .3864 L
.47115 .3864 L
.47195 .3864 L
.47269 .3864 L
.47338 .3864 L
.47401 .38639 L
.47543 .38638 L
.47816 .38634 L
.48074 .3863 L
.48317 .38627 L
.48451 .38626 L
.48575 .38624 L
.48681 .38624 L
Mistroke
.48795 .38623 L
.48922 .38623 L
.49038 .38623 L
.49102 .38623 L
.49171 .38623 L
.49294 .38623 L
.49441 .38623 L
.49574 .38624 L
.49701 .38624 L
.49767 .38624 L
.49837 .38624 L
.49966 .38624 L
.50085 .38624 L
.50206 .38624 L
.50275 .38624 L
.50339 .38624 L
.5058 .38623 L
.50693 .38623 L
.50799 .38623 L
.50909 .38623 L
.51031 .38623 L
.51155 .38623 L
.51286 .38624 L
.51398 .38624 L
.5152 .38625 L
.51793 .38628 L
.52047 .38632 L
.52285 .38636 L
.52402 .38637 L
.52511 .38638 L
.52609 .38639 L
.52713 .3864 L
.52817 .3864 L
.52933 .3864 L
.53056 .3864 L
.53168 .38639 L
.53298 .38637 L
.53422 .38634 L
.53879 .38622 L
.54139 .38614 L
.54266 .38611 L
.54383 .38608 L
.5449 .38607 L
.54602 .38605 L
.54715 .38604 L
.54839 .38605 L
.54908 .38605 L
.54973 .38606 L
.55095 .38608 L
.55226 .38611 L
Mistroke
.55368 .38616 L
.55862 .38637 L
.56101 .38648 L
.56218 .38652 L
.56326 .38656 L
.56438 .38658 L
.5656 .3866 L
.56685 .3866 L
.56749 .3866 L
.56818 .38659 L
.56934 .38657 L
.57039 .38654 L
.57161 .38649 L
.57276 .38644 L
.57701 .38618 L
.57925 .38604 L
.58165 .38591 L
.58236 .38588 L
.58303 .38586 L
.58429 .38583 L
.58547 .38581 L
.58675 .38582 L
.58745 .38583 L
.58811 .38585 L
.58934 .3859 L
.59067 .38597 L
.5921 .38606 L
.59705 .38648 L
.59947 .38667 L
.60066 .38675 L
.60173 .38681 L
.60287 .38685 L
.60409 .38687 L
.60473 .38688 L
.60542 .38687 L
.60667 .38685 L
.60773 .3868 L
.6089 .38674 L
.61127 .38654 L
.61551 .38607 L
.61799 .3858 L
.6193 .38567 L
.62002 .38562 L
.6207 .38557 L
.62135 .38554 L
.62205 .3855 L
.62326 .38547 L
.6245 .38548 L
.62564 .38551 L
.62675 .38557 L
Mistroke
.62779 .38565 L
.63015 .3859 L
.63491 .3866 L
.63762 .38698 L
.63895 .38713 L
.64018 .38723 L
.6413 .3873 L
.64249 .38733 L
.64368 .38732 L
.64499 .38727 L
.64567 .38722 L
.64639 .38715 L
.64767 .387 L
.65056 .38651 L
.65325 .38597 L
.65579 .38546 L
.65696 .38526 L
.65819 .38508 L
.65883 .385 L
.65954 .38493 L
.66079 .38485 L
.66192 .38482 L
.66314 .38486 L
.66429 .38494 L
.66533 .38506 L
.66663 .38527 L
.66784 .38552 L
.67056 .38622 L
.67312 .38696 L
.67553 .38761 L
.67662 .38785 L
.67777 .38807 L
.67904 .38824 L
.6802 .38833 L
.68124 .38834 L
.68221 .3883 L
.68328 .38818 L
.68442 .38799 L
.68565 .38769 L
.68697 .38729 L
.68938 .38637 L
.6939 .38443 L
.69504 .38399 L
.69626 .38359 L
.69741 .3833 L
.69845 .38311 L
.69963 .38301 L
.70074 .38303 L
.70195 .38318 L
.70325 .38352 L
Mistroke
.70388 .38374 L
.70458 .38403 L
.70598 .38475 L
.7085 .38642 L
.71332 .39018 L
.71473 .39116 L
.71607 .39192 L
.71681 .39224 L
.71762 .3925 L
.71835 .39265 L
.71903 .3927 L
.72026 .39255 L
.72096 .39231 L
.72161 .39198 L
.7223 .39152 L
.72294 .39099 L
.72436 .3894 L
.72561 .38754 L
.72677 .38541 L
.72941 .37917 L
.73472 .3615 L
.73941 .34281 L
.74449 .32349 L
.74682 .31614 L
.74929 .30987 L
.7514 .3059 L
.7526 .30424 L
.75372 .30306 L
.75438 .30254 L
.7551 .30211 L
.7564 .30167 L
.75767 .30164 L
.75885 .30192 L
.75957 .30222 L
.76025 .30258 L
.76152 .30343 L
.76436 .30589 L
.76678 .3082 L
.76937 .31046 L
.77062 .31138 L
.77181 .31209 L
.77288 .3126 L
.77404 .31299 L
.77521 .31322 L
.77646 .31327 L
.77752 .31317 L
.7787 .31292 L
.77997 .31249 L
.78133 .31189 L
.78381 .31053 L
Mistroke
.78884 .30763 L
.79006 .30707 L
.79136 .30658 L
.79212 .30636 L
.7928 .3062 L
.79348 .30608 L
.79413 .306 L
.7953 .30594 L
.79654 .30601 L
.79759 .30617 L
.79876 .30644 L
.8 .30682 L
.80135 .30732 L
.80377 .30837 L
.80805 .31022 L
.80928 .31065 L
.81044 .31098 L
.81148 .31121 L
.8126 .31138 L
.81324 .31144 L
.81394 .31147 L
.81467 .31147 L
.81535 .31144 L
.81656 .31131 L
.81787 .31107 L
.81918 .31074 L
.82042 .31036 L
.82274 .30953 L
.82531 .30858 L
.82804 .3077 L
.82946 .30734 L
.83027 .30719 L
.83103 .30707 L
.83172 .307 L
.83236 .30695 L
.83309 .30692 L
.83379 .30693 L
.83506 .307 L
.8362 .30715 L
.83684 .30726 L
.83753 .3074 L
.83877 .30769 L
.8434 .30912 L
.84606 .30993 L
.84751 .31029 L
.84887 .31057 L
.85002 .31073 L
.85126 .31084 L
.85197 .31087 L
.85264 .31087 L
Mistroke
.8539 .31082 L
.85503 .3107 L
.85626 .31051 L
.85848 .31003 L
.86354 .3086 L
.86615 .30794 L
.86746 .30768 L
.86821 .30756 L
.86889 .30747 L
.87012 .30736 L
.87143 .30732 L
.87264 .30736 L
.87379 .30745 L
.87486 .30758 L
.87602 .30778 L
.87839 .30831 L
.88263 .30943 L
.88501 .30999 L
.88633 .31024 L
.88758 .31042 L
.88873 .31053 L
.89 .31059 L
.89114 .31059 L
.89221 .31053 L
.8935 .3104 L
.89415 .31032 L
.89486 .3102 L
.8973 .30971 L
.89995 .30905 L
.90279 .30836 L
.90418 .30807 L
.90549 .30784 L
.90667 .30768 L
.90795 .30757 L
.90916 .30752 L
.91045 .30754 L
.91155 .3076 L
.91276 .30773 L
.92183 .30965 L
.92404 .31007 L
.92527 .31025 L
.92639 .31037 L
.92703 .31041 L
.92772 .31045 L
.92897 .31046 L
.93022 .31041 L
.93137 .31031 L
.93258 .31016 L
.93371 .30997 L
.93629 .30945 L
Mistroke
.939 .30882 L
.94148 .30827 L
.94258 .30807 L
.94378 .30788 L
.94491 .30775 L
.94595 .30766 L
.94706 .30762 L
.94828 .30762 L
.94955 .30768 L
.95075 .30779 L
.95604 .30876 L
.95893 .30942 L
.96034 .30972 L
.96163 .30995 L
.96273 .31012 L
.96393 .31027 L
.96519 .31037 L
.96639 .31041 L
.96771 .31039 L
.96837 .31035 L
.96911 .3103 L
.9704 .31015 L
.97161 .30997 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0<oooool3o`00083ooooo0ol0000mooooo`009oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Gooooo1?l00005ooooo`;o000000?oooooo`000?l00000O_ooool2o`000003oooo
ool0003o000000Kooooo0ol00007ooooo`03o`000?oooooooooo02Wooooo000Qoooooooo0000000W
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00005ooooo`Go00001Ooo
ool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Cooooo1Ol00005ooooo`?o0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo03oooooo000Wooooo`;o0000>?ooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo03oooooo000Wooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0oooooo`009oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0@?ooool002Oooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo043ooooo000W
ooooo`;o0000>Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo043ooooo000Woooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`11oooo
o`009oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo07Kooooo00?o0000oooooooo
ool0@Oooool002Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo047ooooo000Wooooo`;o0000>oooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo04;ooooo000Wooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`12ooooo`009oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool0@_ooool002Oooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo04;ooooo000Wooooo`;o0000>oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo04?ooooo0008ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`13ooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo04?ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`02ooooo`Co00001_ooool4o`0000Kooooo0ol0000l
ooooo`?o00001_ooool4o`0000Kooooo1?l00004ooooo`03o`000?oooooooooo04Cooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0000mooooo`04o`000?ooooooooooooooo`;o0000
0oooool6o`0000Cooooo1ol00002ooooocgo00000_ooool6o`0000Cooooo1_l00003ooooo`;o0000
0oooool00ol0003oooooooooo`14ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooo
ooooool0?Oooool3o`0006cooooo0ol00017ooooo`001oooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oo
oooooooo0?Kooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool0
0ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oo
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
oooooooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000oooooooo
ool0m_ooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0003gooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`00
00Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oo
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?ooooo
o`000?l000000ol00004ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool001Cooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000C
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3fooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0
003gooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000C
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000
oooooooooooo00002?ooool2o`000?oooooo000Dooooo`;o00002_ooool00ol0003oooooooooo`3m
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .29698 L
.06244 .28339 L
.06503 .28155 L
.06747 .28008 L
.06883 .27941 L
.07029 .2788 L
.07162 .27837 L
.07286 .27806 L
.07401 .27785 L
.0751 .27773 L
.07628 .27766 L
.07756 .27766 L
.0782 .27769 L
.0789 .27773 L
.08017 .27784 L
.08255 .27814 L
.0854 .27853 L
.0868 .27869 L
.08808 .2788 L
.0888 .27885 L
.08957 .27889 L
.09033 .27891 L
.09117 .27892 L
.09187 .27891 L
.09262 .27888 L
.09333 .27884 L
.09398 .27879 L
.09533 .27866 L
.09658 .27851 L
.09942 .2781 L
.10211 .2777 L
.10329 .27754 L
.10458 .2774 L
.10575 .2773 L
.10684 .27724 L
.10799 .27721 L
.10921 .27722 L
.10986 .27724 L
.11056 .27727 L
.11183 .27737 L
.11307 .2775 L
.11421 .27765 L
.11888 .27839 L
.12116 .27873 L
.12216 .27885 L
.12324 .27896 L
.12442 .27904 L
.12554 .27909 L
.12682 .2791 L
Mistroke
.12801 .27906 L
.1287 .27902 L
.12934 .27897 L
.13055 .27885 L
.13325 .27847 L
.13831 .27761 L
.13969 .27741 L
.14045 .27731 L
.14117 .27723 L
.14184 .27717 L
.14257 .27712 L
.14385 .27706 L
.14502 .27706 L
.14631 .2771 L
.14697 .27714 L
.14767 .2772 L
.14893 .27734 L
.15139 .27771 L
.15364 .27813 L
.15625 .27861 L
.15867 .27899 L
.15989 .27912 L
.1612 .27922 L
.16195 .27926 L
.16265 .27927 L
.16396 .27925 L
.16503 .27919 L
.16621 .27908 L
.16744 .27893 L
.16858 .27875 L
.17284 .27791 L
.17522 .27744 L
.17639 .27724 L
.17748 .27708 L
.17872 .27695 L
.17938 .2769 L
.18008 .27686 L
.1812 .27684 L
.18245 .27687 L
.18366 .27695 L
.18479 .27708 L
.18603 .27726 L
.18736 .27751 L
.19253 .27867 L
.19372 .27892 L
.19502 .27916 L
.19616 .27933 L
.19737 .27946 L
.19846 .27954 L
.19966 .27956 L
Mistroke
.20075 .27953 L
.20177 .27945 L
.20306 .2793 L
.20446 .27906 L
.20702 .27848 L
.21182 .27723 L
.21322 .27693 L
.21453 .27669 L
.21526 .27659 L
.21605 .27651 L
.21676 .27646 L
.21742 .27643 L
.21863 .27644 L
.21931 .27648 L
.21995 .27654 L
.22124 .27671 L
.22196 .27684 L
.22262 .27698 L
.22743 .27836 L
.23007 .27917 L
.23136 .27952 L
.23254 .27978 L
.23357 .27996 L
.23464 .28009 L
.23572 .28016 L
.23691 .28015 L
.23811 .28005 L
.2394 .27985 L
.24062 .27958 L
.24172 .27927 L
.24685 .27734 L
.24955 .27634 L
.25091 .27595 L
.25169 .27577 L
.2524 .27564 L
.25371 .27549 L
.25443 .27546 L
.25511 .27547 L
.25633 .27559 L
.25765 .27585 L
.25887 .27621 L
.26016 .2767 L
.26249 .27781 L
.26492 .27915 L
.26753 .28052 L
.2688 .28107 L
.26999 .28149 L
.27107 .28176 L
.27223 .28192 L
.27347 .28193 L
Mistroke
.27478 .28173 L
.2759 .28139 L
.27714 .28085 L
.27848 .28006 L
.27991 .27902 L
.28251 .27677 L
.28553 .27402 L
.28702 .27284 L
.28774 .27234 L
.2884 .27195 L
.28965 .27141 L
.29033 .27123 L
.29097 .27115 L
.29168 .27117 L
.29233 .27129 L
.29304 .27155 L
.29379 .27198 L
.29502 .27303 L
.29634 .27467 L
.29758 .27671 L
.29872 .27901 L
.3015 .28628 L
.30414 .29511 L
.31346 .33296 L
.31817 .34904 L
.31945 .35244 L
.32085 .35555 L
.32215 .35792 L
.32336 .35964 L
.32468 .361 L
.32538 .36151 L
.32612 .3619 L
.3269 .36216 L
.32764 .36226 L
.32831 .36223 L
.32903 .3621 L
.33034 .36161 L
.331 .36125 L
.33173 .36078 L
.33422 .35879 L
.33903 .35456 L
.34035 .3536 L
.34175 .35277 L
.34244 .35244 L
.34308 .35218 L
.34428 .35182 L
.34558 .35164 L
.34678 .35164 L
.3481 .35183 L
.34876 .35199 L
Mistroke
.34949 .35221 L
.35205 .35329 L
.35443 .35454 L
.35674 .35577 L
.35892 .35677 L
.36012 .35722 L
.36143 .35759 L
.36262 .35781 L
.36372 .35792 L
.36491 .35794 L
.3662 .35783 L
.36742 .35762 L
.36854 .35735 L
.37113 .3565 L
.37385 .35545 L
.37634 .35455 L
.3777 .35413 L
.37899 .35381 L
.37972 .35366 L
.38052 .35354 L
.38124 .35346 L
.3819 .35341 L
.38322 .3534 L
.38388 .35343 L
.38461 .3535 L
.3859 .35368 L
.38711 .35391 L
.38983 .35463 L
.39219 .35535 L
.39479 .3561 L
.3959 .35638 L
.39711 .35662 L
.39825 .3568 L
.39929 .35692 L
.40041 .35698 L
.40162 .35698 L
.4029 .35691 L
.40408 .35677 L
.40924 .35568 L
.41195 .35499 L
.41344 .35465 L
.41483 .35438 L
.41604 .3542 L
.41734 .35406 L
.41808 .35401 L
.41879 .35399 L
.42011 .35399 L
.42132 .35406 L
.42244 .35418 L
.42367 .35435 L
Mistroke
.42499 .35458 L
.42764 .35514 L
.4305 .35577 L
.43182 .35603 L
.43321 .35626 L
.43439 .35642 L
.4357 .35654 L
.43697 .35659 L
.43812 .3566 L
.43876 .35658 L
.43946 .35654 L
.44072 .35643 L
.4419 .35628 L
.44316 .35609 L
.44541 .35567 L
.44966 .35484 L
.45082 .35465 L
.45205 .35448 L
.4531 .35437 L
.45424 .35429 L
.4555 .35425 L
.4562 .35425 L
.45684 .35426 L
.45809 .35433 L
.45927 .35443 L
.46045 .35457 L
.46153 .35473 L
.46399 .35515 L
.46638 .3556 L
.46866 .35598 L
.46992 .35615 L
.47058 .35622 L
.47129 .35629 L
.47253 .35638 L
.47368 .35641 L
.47486 .35641 L
.47614 .35636 L
.47734 .35627 L
.47844 .35615 L
.48054 .35586 L
.48275 .35548 L
.48522 .35506 L
.48657 .35485 L
.48785 .35467 L
.48904 .35454 L
.49034 .35444 L
.49152 .35439 L
.4926 .35437 L
.49389 .3544 L
.49509 .35447 L
Mistroke
.49642 .35459 L
.49784 .35477 L
.5034 .35565 L
.50593 .35602 L
.50666 .3561 L
.50734 .35617 L
.50863 .35627 L
.50984 .35632 L
.51096 .35633 L
.51219 .3563 L
.51349 .35623 L
.5148 .35611 L
.5162 .35594 L
.51874 .35557 L
.5215 .35512 L
.52296 .3549 L
.52451 .3547 L
.52584 .35456 L
.5266 .35451 L
.52731 .35447 L
.52856 .35443 L
.52926 .35442 L
.5299 .35443 L
.53109 .35448 L
.53239 .35457 L
.53305 .35463 L
.53375 .35471 L
.53501 .35487 L
.53967 .3556 L
.54221 .35597 L
.54346 .35611 L
.5446 .35621 L
.54582 .35628 L
.54713 .35631 L
.54781 .35631 L
.54856 .3563 L
.54926 .35627 L
.54992 .35623 L
.55116 .35612 L
.55229 .356 L
.55483 .35564 L
.55742 .35522 L
.56016 .35481 L
.56159 .35464 L
.56235 .35457 L
.56316 .3545 L
.56391 .35446 L
.56459 .35443 L
.56528 .35441 L
.56592 .35441 L
Mistroke
.56718 .35444 L
.56781 .35447 L
.56851 .35452 L
.56974 .35463 L
.5709 .35477 L
.5763 .35561 L
.57859 .35596 L
.57984 .35611 L
.581 .35622 L
.58227 .35631 L
.58293 .35634 L
.58365 .35635 L
.58492 .35634 L
.58607 .35629 L
.58727 .3562 L
.58838 .35609 L
.59093 .35573 L
.59361 .35528 L
.59606 .35488 L
.59716 .35472 L
.59834 .35458 L
.59947 .35447 L
.60051 .3544 L
.60172 .35435 L
.60282 .35435 L
.60408 .35439 L
.60527 .35447 L
.61052 .35521 L
.61307 .35567 L
.6154 .35604 L
.61658 .3562 L
.61786 .35633 L
.61857 .35638 L
.61922 .35642 L
.6205 .35645 L
.62179 .35644 L
.62252 .3564 L
.62321 .35636 L
.62393 .35629 L
.62459 .35622 L
.62608 .35602 L
.63101 .35512 L
.63362 .35466 L
.63508 .35445 L
.6364 .35432 L
.63766 .35423 L
.63837 .35421 L
.63902 .3542 L
.64022 .35422 L
.64149 .3543 L
Mistroke
.64266 .35442 L
.64375 .35457 L
.64622 .355 L
.64841 .35545 L
.6508 .35594 L
.65291 .3563 L
.65397 .35645 L
.65514 .35656 L
.65579 .35661 L
.65648 .35664 L
.65774 .35665 L
.659 .35661 L
.66015 .35651 L
.66121 .35638 L
.66237 .3562 L
.66471 .35574 L
.66724 .35515 L
.66999 .35455 L
.67125 .35432 L
.67259 .35412 L
.67373 .354 L
.67498 .35393 L
.6762 .35392 L
.67731 .35397 L
.67859 .35409 L
.6798 .35427 L
.68196 .3547 L
.68432 .35529 L
.68703 .35601 L
.68958 .35659 L
.69099 .35683 L
.69179 .35693 L
.69252 .357 L
.69382 .35706 L
.69447 .35705 L
.69519 .35703 L
.6965 .35691 L
.69771 .35673 L
.69909 .35645 L
.7004 .35611 L
.70527 .35461 L
.70748 .35399 L
.70865 .35372 L
.70987 .35351 L
.71052 .35342 L
.71124 .35336 L
.71249 .35332 L
.71376 .35338 L
.71494 .35352 L
.71559 .35363 L
Mistroke
.71628 .35377 L
.71755 .35411 L
.71991 .35491 L
.72244 .35591 L
.72521 .35696 L
.72637 .35734 L
.72762 .35766 L
.7288 .35788 L
.72987 .358 L
.73109 .35802 L
.73241 .35791 L
.73365 .35768 L
.73481 .35736 L
.73684 .35657 L
.73909 .35545 L
.74364 .35301 L
.74495 .35243 L
.74619 .35199 L
.74688 .3518 L
.74762 .35165 L
.74892 .35154 L
.75016 .35161 L
.75148 .35189 L
.7526 .35229 L
.75384 .35291 L
.75649 .35477 L
.75897 .35696 L
.76185 .35957 L
.76327 .36069 L
.76459 .36153 L
.76571 .36203 L
.7669 .36232 L
.76758 .36234 L
.76822 .36226 L
.76943 .36184 L
.77053 .36109 L
.77155 .36008 L
.77267 .35861 L
.77385 .35664 L
.77631 .35112 L
.7786 .34437 L
.78381 .32469 L
.7884 .30551 L
.79082 .29607 L
.79339 .2873 L
.79563 .28107 L
.79682 .27836 L
.79811 .27595 L
.79928 .27419 L
.80036 .27295 L
Mistroke
.80138 .27209 L
.80247 .27152 L
.80372 .27123 L
.80442 .27124 L
.80506 .27134 L
.80629 .27176 L
.80746 .2724 L
.81008 .27441 L
.81293 .27698 L
.81534 .27902 L
.81665 .27996 L
.81789 .2807 L
.81894 .28119 L
.82006 .28157 L
.82132 .28182 L
.82246 .28187 L
.82375 .28176 L
.82497 .2815 L
.82606 .28114 L
.82725 .28066 L
.83234 .27801 L
.83466 .27689 L
.83593 .27638 L
.83711 .27601 L
.83812 .27577 L
.8392 .2756 L
.8404 .27553 L
.84149 .27555 L
.84278 .2757 L
.84343 .27582 L
.84415 .27597 L
.8466 .27672 L
.84928 .27774 L
.85215 .27883 L
.85355 .27928 L
.85487 .27963 L
.85606 .27987 L
.85736 .28005 L
.85858 .28012 L
.85989 .2801 L
.86112 .27998 L
.86224 .27981 L
.86707 .27854 L
.87159 .2772 L
.87275 .27693 L
.87386 .27672 L
.87513 .27655 L
.8763 .27646 L
.87758 .27644 L
.87877 .27649 L
Mistroke
.88008 .27663 L
.88074 .27672 L
.88147 .27685 L
.88706 .27822 L
.8898 .27891 L
.891 .27916 L
.89231 .27938 L
.89352 .27952 L
.89465 .2796 L
.89584 .27962 L
.89711 .27958 L
.89778 .27953 L
.8985 .27946 L
.89982 .27927 L
.90228 .27878 L
.90684 .27764 L
.90804 .27736 L
.90936 .27709 L
.91051 .27689 L
.91174 .27672 L
.91251 .27665 L
.9132 .27661 L
.91389 .27658 L
.91455 .27658 L
.91578 .27662 L
.91648 .27668 L
.91712 .27675 L
.91828 .27692 L
.91956 .27717 L
.92215 .27787 L
.9274 .27981 L
.93303 .28218 L
.94319 .2868 L
.95131 .29196 L
.96014 .29903 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000;ooooo`;o00004oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo0000023ooooo00Co0000oooooooooooo00001oooool01Ol0003oooooo`000?oooooo000002Oo
oooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00[ooooo1?l0000Booooo`04o`000?ooooooooooo`00
00Oooooo1Ol0000Qooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
000Pooooo`04o`000?ooooooooooo`0000Oooooo1Ol0000Wooooo`03o`000?oooooooooo00Kooooo
000Wooooo`;o00002OoooolQo`000003ooooool0003o000000Ko000000?oooooo`000?l000001_l0
0003ooooo`05o`000?ooooooooooooooool000004_ooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0002;ooooo00Co0000oooooooooooo00001oooool4o`00027ooooo00Co0000
oooooooooooo00001oooool6o`0000?ooooo1_l00003ooooo`Oo000000?oooooo`000?l000001Ol0
000;ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Oooooo0_l0000L
ooooo`03o`000?oooooooooo00?o00001Oooool5o`0000Kooooo0ol00004ooooo`03o`000?oooooo
oooo013ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000Rooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooooooo`Go00001_ooool3o`0000Kooooo0ol00006ooooo`Co00001oooool00ol0
003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`05ooooo`;o00007_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000Rooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000008?ooool00ol0003oooooooooo`03ooooo`;o00002?ooool002Oooooo00?o0000oooooooo
ool00oooool2o`00027ooooo0_l00009ooooo`?o00003oooool00ol0003oooooooooo`0@ooooo`;o
00002oooool00ol0003oooooooooo`0Qooooo`;o00002_ooool2o`0002;ooooo0_l00007ooooo`03
o`000?oooooo000000;o00008_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo000Wooooo`;o00000oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool09Oooool2o`0000cooooo000Wooooo`03o`000?oooooooooo00;o0000@_oo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`009oooool0
0ol0003oooooo`000014ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`07ooooo`009oooool2o`0004Kooooo00?o0000ooooooooool0Moooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo000Qoooooooo0000000Wooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00Gooooo000Wooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0eooooo`009oooool2o`0004Oooooo00?o0000ooooooooool0MOooool00ol0
003oooooooooo`0eooooo`009oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07Go
oooo00?o0000ooooooooool0=Oooool002Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`1dooooo`03o`000?oooooooooo03Kooooo000Wooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0M?ooool00ol0003oooooooooo`0fooooo`009oooool2o`0004Oooooo00?o0000
ooooooooool0M?ooool00ol0003oooooooooo`0fooooo`009oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0=oooool002Oooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo03Oooooo000Wooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool00_ooool4o`0000Kooooo0ol00007ooooo`;o0000
?_ooool3o`0000Kooooo1?l00005ooooo`Co00001Oooool00ol0003oooooooooo`0gooooo`009ooo
ool2o`0004Wooooo00Co0000oooooooooooooooo0_l00003ooooo`Ko00000oooool7o`000003oooo
ool0003o000003ko000000?oooooo`000?l000001_l00002ooooo`Ko00001?ooool01Ol0003ooooo
oooooooooooo000003[ooooo000Wooooo`03o`000?oooooooooo04Wooooo0ol0001/ooooo`Co0000
>_ooool002Oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1/ooooo`;o0000>ooo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000moooool000Oooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooool000000ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooooooool0m_ooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo1Ol0
0004ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool000kooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000moooool0
00gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?oo
ool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`3fooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0
003oooooooooo`3fooooo`003_ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool2o`000?Oo
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo0008
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`;o0000moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo0?Kooooo0008ooooo`;o00002_ooool2o`0000;ooooo1Ol0
00000ooooooo0000o`000003o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003g
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`00
5?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0
m_ooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?Kooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1?ooool2o`000?Oooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
oOooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004ooo
ool01?l0003oooooooooool00008ooooo`;o0000ooooool001Cooooo0_l0000:ooooo`03o`000?oo
oooooooo0?gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28382 L
.08255 .27126 L
.0932 .26507 L
.09916 .26016 L
.10458 .25552 L
.10963 .25191 L
.11248 .2504 L
.11384 .24983 L
.11511 .24938 L
.11741 .24877 L
.11863 .24854 L
.11994 .24835 L
.1206 .24828 L
.12132 .24821 L
.12262 .24811 L
.12389 .24805 L
.12507 .248 L
.12756 .24792 L
.12879 .24787 L
.12991 .24782 L
.13202 .24768 L
.1343 .24748 L
.13906 .24694 L
.14167 .24665 L
.14296 .24653 L
.14415 .24644 L
.14533 .24637 L
.14659 .24634 L
.14785 .24633 L
.14857 .24635 L
.14924 .24637 L
.15041 .24644 L
.15148 .24653 L
.15389 .2468 L
.1586 .24751 L
.16089 .24783 L
.16189 .24795 L
.16298 .24806 L
.16417 .24815 L
.1653 .24821 L
.16659 .24823 L
.16778 .24821 L
.169 .24815 L
.16969 .24809 L
.17034 .24804 L
.17304 .24769 L
.17811 .24683 L
.18079 .24643 L
.18156 .24633 L
Mistroke
.18228 .24626 L
.18294 .2462 L
.18364 .24615 L
.18428 .24612 L
.18499 .24609 L
.18624 .24609 L
.18694 .24611 L
.18769 .24615 L
.18839 .2462 L
.18904 .24626 L
.19027 .2464 L
.19161 .2466 L
.19405 .24703 L
.19884 .24793 L
.20001 .24811 L
.20126 .24826 L
.20198 .24833 L
.20264 .24839 L
.20393 .24845 L
.20509 .24846 L
.20617 .24842 L
.20736 .24834 L
.20862 .24821 L
.20996 .24802 L
.21121 .2478 L
.21356 .24732 L
.21578 .24684 L
.21816 .24637 L
.21932 .24618 L
.22041 .24603 L
.22139 .24593 L
.22246 .24586 L
.22363 .24582 L
.22488 .24585 L
.22594 .24591 L
.22711 .24603 L
.22837 .24621 L
.22974 .24646 L
.23221 .247 L
.23723 .24817 L
.23845 .2484 L
.23975 .24859 L
.2405 .24867 L
.24118 .24873 L
.24187 .24877 L
.24252 .24879 L
.24368 .24877 L
.24492 .2487 L
.24597 .24858 L
.24714 .2484 L
Mistroke
.24972 .24785 L
.25215 .2472 L
.25436 .24658 L
.25673 .24599 L
.25788 .24576 L
.25896 .24559 L
.25993 .24548 L
.26098 .2454 L
.26224 .24538 L
.26287 .24541 L
.26357 .24545 L
.2648 .24559 L
.26595 .24579 L
.26732 .24609 L
.26857 .24643 L
.27137 .24732 L
.2738 .24811 L
.27508 .2485 L
.27644 .24886 L
.27763 .24911 L
.27894 .24931 L
.28013 .24941 L
.28124 .24942 L
.28233 .24937 L
.28351 .24923 L
.28475 .24899 L
.2859 .24869 L
.29016 .24715 L
.29259 .24614 L
.29516 .24521 L
.29622 .2449 L
.29736 .24464 L
.29861 .24445 L
.29977 .24438 L
.30042 .24439 L
.30113 .24443 L
.30242 .24461 L
.30367 .24491 L
.30483 .24529 L
.30748 .24648 L
.31031 .24803 L
.313 .24949 L
.31431 .25012 L
.31552 .2506 L
.31663 .25093 L
.31779 .25116 L
.31896 .25125 L
.32025 .25116 L
.3215 .25089 L
.32268 .25047 L
Mistroke
.32374 .24995 L
.3249 .24925 L
.32987 .24509 L
.33213 .24305 L
.33337 .24205 L
.33453 .24124 L
.33552 .24068 L
.33658 .24026 L
.33776 .24003 L
.33884 .24008 L
.34012 .2405 L
.34134 .24129 L
.34242 .24235 L
.3436 .24387 L
.34489 .246 L
.34624 .24878 L
.34868 .25507 L
.35303 .26981 L
.35782 .28884 L
.36299 .30851 L
.36583 .31734 L
.36723 .32094 L
.36853 .32379 L
.36972 .32598 L
.37104 .32793 L
.37236 .3294 L
.37308 .33 L
.37376 .33044 L
.37496 .33094 L
.37606 .3311 L
.37726 .33098 L
.37854 .33058 L
.37977 .32997 L
.38111 .3291 L
.38353 .3272 L
.38807 .3236 L
.3894 .32275 L
.39065 .32208 L
.39195 .32156 L
.39264 .32135 L
.39338 .32118 L
.39469 .32102 L
.39593 .32102 L
.39705 .32116 L
.39827 .32142 L
.40281 .32318 L
.4052 .3243 L
.40773 .32539 L
.40994 .32613 L
.4112 .32643 L
Mistroke
.41237 .32662 L
.41344 .32671 L
.41443 .32673 L
.41556 .32668 L
.41663 .32657 L
.41788 .32636 L
.41921 .32606 L
.42159 .32538 L
.42436 .32449 L
.42697 .32372 L
.42911 .32323 L
.43032 .32304 L
.43142 .32291 L
.43257 .32284 L
.43382 .32284 L
.43512 .3229 L
.43633 .32302 L
.44152 .32403 L
.44425 .32467 L
.44574 .32499 L
.44713 .32525 L
.44845 .32545 L
.44966 .32559 L
.45035 .32565 L
.451 .32568 L
.45168 .32571 L
.45243 .32572 L
.45366 .32569 L
.45497 .32561 L
.45608 .3255 L
.45732 .32534 L
.4624 .32446 L
.46506 .32401 L
.46652 .3238 L
.46788 .32365 L
.46907 .32356 L
.47035 .3235 L
.47108 .32348 L
.47176 .32348 L
.47305 .32352 L
.47424 .32358 L
.47533 .32367 L
.4778 .32396 L
.48247 .32462 L
.48475 .32491 L
.48574 .32502 L
.48683 .32512 L
.48796 .32519 L
.48903 .32524 L
.49025 .32526 L
Mistroke
.49139 .32525 L
.49266 .32521 L
.49381 .32514 L
.49515 .32504 L
.4964 .32492 L
.50145 .32435 L
.50392 .32409 L
.505 .32401 L
.50617 .32393 L
.50739 .32387 L
.50854 .32384 L
.50986 .32383 L
.51109 .32385 L
.51233 .32389 L
.51304 .32393 L
.51371 .32397 L
.51649 .32419 L
.52082 .32459 L
.52318 .32478 L
.52433 .32486 L
.52538 .32491 L
.52653 .32495 L
.52776 .32498 L
.52841 .32498 L
.52911 .32498 L
.53038 .32496 L
.53154 .32492 L
.53276 .32487 L
.53496 .32473 L
.5398 .32437 L
.54219 .32422 L
.54335 .32416 L
.5444 .32412 L
.54563 .32408 L
.54694 .32406 L
.54762 .32406 L
.54836 .32406 L
.54906 .32407 L
.5497 .32408 L
.55082 .32411 L
.55205 .32416 L
.55454 .32428 L
.55912 .32455 L
.56044 .32462 L
.56168 .32468 L
.56282 .32472 L
.56402 .32475 L
.56507 .32477 L
.56622 .32478 L
.56727 .32478 L
Mistroke
.56825 .32477 L
.56941 .32475 L
.57047 .32473 L
.57285 .32464 L
.57761 .32443 L
.57887 .32438 L
.58023 .32433 L
.5814 .3243 L
.58269 .32427 L
.5839 .32425 L
.58518 .32424 L
.58637 .32424 L
.58748 .32425 L
.58857 .32426 L
.58957 .32428 L
.59182 .32434 L
.59691 .32449 L
.59831 .32453 L
.59979 .32456 L
.60106 .32458 L
.60178 .32459 L
.60246 .3246 L
.60369 .32461 L
.60499 .32461 L
.60609 .32461 L
.60731 .3246 L
.60862 .32458 L
.61002 .32457 L
.61254 .32453 L
.61512 .32448 L
.61654 .32446 L
.61786 .32445 L
.61908 .32443 L
.6202 .32442 L
.62144 .32442 L
.62212 .32442 L
.62277 .32441 L
.62347 .32441 L
.6241 .32441 L
.62483 .32441 L
.62552 .32441 L
.62675 .32442 L
.62808 .32442 L
.63084 .32443 L
.63159 .32443 L
.6324 .32444 L
.63317 .32444 L
.63387 .32444 L
.63512 .32444 L
.63583 .32444 L
Mistroke
.63649 .32444 L
.63769 .32444 L
.63897 .32444 L
.64021 .32443 L
.64085 .32443 L
.64153 .32443 L
.6423 .32443 L
.64299 .32443 L
.64365 .32443 L
.64436 .32443 L
.64563 .32444 L
.64678 .32444 L
.64742 .32445 L
.64811 .32445 L
.64936 .32446 L
.65178 .32449 L
.65401 .32453 L
.65641 .32456 L
.6576 .32458 L
.65869 .32459 L
.65995 .3246 L
.66061 .3246 L
.66132 .32461 L
.66258 .32461 L
.66372 .3246 L
.66489 .32459 L
.66597 .32457 L
.66715 .32455 L
.6684 .32452 L
.6728 .32438 L
.67526 .3243 L
.67661 .32427 L
.6779 .32424 L
.67909 .32422 L
.68038 .32421 L
.68156 .32421 L
.68265 .32422 L
.68394 .32424 L
.68514 .32427 L
.68646 .32432 L
.68789 .32438 L
.69058 .32452 L
.69344 .32468 L
.69486 .32475 L
.69619 .3248 L
.69739 .32484 L
.69868 .32486 L
.69991 .32487 L
.70121 .32487 L
.70233 .32484 L
Mistroke
.70354 .3248 L
.70428 .32477 L
.70498 .32473 L
.7063 .32465 L
.70925 .32443 L
.71183 .32422 L
.71324 .32411 L
.71457 .32402 L
.71581 .32395 L
.71695 .32391 L
.71821 .32388 L
.71887 .32387 L
.71957 .32388 L
.72071 .3239 L
.72178 .32394 L
.72295 .324 L
.72419 .32409 L
.72702 .32437 L
.72968 .32468 L
.73225 .32498 L
.73351 .3251 L
.73466 .32519 L
.73581 .32526 L
.73689 .3253 L
.73804 .32532 L
.73929 .3253 L
.74057 .32525 L
.74128 .3252 L
.74193 .32514 L
.74438 .32486 L
.74933 .32405 L
.75193 .32364 L
.75335 .32346 L
.75404 .32339 L
.75467 .32334 L
.75581 .32327 L
.75704 .32324 L
.75767 .32324 L
.75837 .32326 L
.75963 .32335 L
.76077 .32347 L
.76199 .32364 L
.76418 .32407 L
.76854 .32514 L
.77092 .3257 L
.77207 .32593 L
.77312 .32609 L
.77426 .32623 L
.77547 .32631 L
.77678 .32631 L
Mistroke
.77803 .32623 L
.77915 .32608 L
.78018 .32589 L
.78132 .32562 L
.78252 .32527 L
.78775 .32328 L
.7903 .32233 L
.79142 .32199 L
.79263 .3217 L
.79375 .32151 L
.79479 .32143 L
.79578 .32143 L
.79683 .32154 L
.79794 .32176 L
.79898 .32207 L
.80012 .32252 L
.80135 .32314 L
.8063 .32657 L
.80872 .32837 L
.81092 .32973 L
.81206 .33024 L
.8133 .33059 L
.81446 .33067 L
.81554 .33051 L
.81668 .33007 L
.81794 .32921 L
.81925 .32788 L
.82048 .32621 L
.82311 .3212 L
.82552 .31494 L
.83093 .29612 L
.83623 .27487 L
.83914 .26389 L
.84187 .25495 L
.84443 .24828 L
.84578 .24552 L
.8472 .24319 L
.8484 .2417 L
.84971 .24055 L
.85091 .23992 L
.85202 .23966 L
.85321 .23972 L
.85449 .2401 L
.8557 .24074 L
.85682 .24151 L
.86119 .24548 L
.86365 .24775 L
.86596 .24954 L
.86712 .25024 L
.86837 .25082 L
Mistroke
.86904 .25107 L
.86975 .25126 L
.87102 .25146 L
.87232 .25148 L
.8735 .25135 L
.87416 .25123 L
.87486 .25105 L
.87615 .25065 L
.87842 .24979 L
.88092 .24883 L
.88234 .24839 L
.88302 .24822 L
.88366 .2481 L
.88439 .248 L
.88506 .24795 L
.88577 .24796 L
.88656 .24803 L
.88786 .2483 L
.88859 .24855 L
.88925 .24882 L
.89054 .24952 L
.89175 .25035 L
.93037 .2766 L
.93983 .28611 L
.94233 .28869 L
.94504 .29117 L
.94743 .29295 L
.94996 .29441 L
.9514 .29505 L
.95299 .29562 L
.95578 .29637 L
.95855 .29701 L
.96108 .2977 L
.96365 .29868 L
.96507 .29938 L
.96643 .30017 L
.97144 .30416 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`0T
ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo04_ooooo1?l0001oooooo`03o`00
0?oooooo000002Gooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?oo
ool2o`0001Wooooo2?l00003ooooo`Ko00000oooool7o`0000Cooooo1_l00003ooooo`Ko00001?oo
ool01Ol0003ooooooooooooooooo000007kooooo00Co0000oooooooooooooooo0_l0000Sooooo`00
9oooool00ol0003oooooooooo`0Cooooo`Go00002?ooool3o`0000Kooooo1?l00006ooooo`Co0000
1Oooool4o`0000Gooooo1Ol00005ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0
0_ooool9o`0001_ooooo000Wooooo`03o`000?oooooooooo017ooooo0_l0000looooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`009oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0=ooooo`;o00006?ooool002Oooooo0_l0000@ooooo`;o0000?_ooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool002Oo
oooo00?o0000ooooooooool03Oooool2o`0001Oooooo0_l00004ooooo`04o`000?oooooooooooooo
o`Go00006oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`?o00008_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0002;ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02_ooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo00_ooooo0_l0000Hooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool08?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`;o00002oooool0
0ol0003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001oooool5o`00027ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o00002Oooool2o`0001_ooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0000Rooooo`04o`000?ooooooooooo`0000Oo
oooo1?l0000Qooooo`04o`000?ooooooooooo`0000Sooooo0ol00006ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`009oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000001cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooool000008_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo02;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo000Wooooo`03o`000?oooooooooo00Gooooo0_l0000Nooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Looooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`07ooooo`;o00008_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo027ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`;o00002?ooool002Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`;o00002Oooool3o`0001go
oooo00?o0000ooooooooool00_ooool2o`0000_ooooo00?o0000ooooooooool08Oooool2o`0000[o
oooo0_l0000Rooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool06Oooool2o`0000Go
oooo00?o0000ooooooooool01_ooool002Oooooo0_l00003ooooo`;o0000COooool00ol0003ooooo
ooooo`1fooooo`03o`000?oooooooooo01[ooooo0_l0000=ooooo`009oooool01Ol0003ooooooooo
oooooooo0000053ooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0Looooo`?o0000
2_ooool002Oooooo00Co0000ooooool0003o0000DOooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01oooool002Oooooo0_l0001Cooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`008Ooooooo
o`0000009oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l0000;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`009oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool00oooool3o`0006;ooooo1?l00005ooooo`03o`00
0?oooooooooo02_ooooo000Wooooo`;o0000EOooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooooooof?o00000_ooool2o`0000?ooooo00?o0000ooooooooool0;?ooool002Oooooo00?o
0000ooooooooool0EOooool4o`0000Oooooo00?o0000ooooooooool0HOooool4o`0002kooooo000W
ooooo`03o`000?oooooooooo05Kooooo0_l0001]ooooo`03o`000?oooooooooo02kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo0008oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol00005oooo
o`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0003goooo
o`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oo
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`003_ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo0?Ko
oooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l0
003gooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003ooooooooo
ool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03o`000?oooooooooo0?Ko
oooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008
ooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00002_ooool2o`0000;ooooo1Ol00004oooo
o`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000
moooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo0?Kooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool0m_ooool000Sooooo0_l0000:ooooo`;o0000
0_ooool5o`000003ooooool0003o000000?o00001?ooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`04ooooo`;o0000moooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`3mooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?go
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooo`005?ooool2o`0000[ooooo
00?o0000ooooooooool0oOooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28418 L
.10458 .2575 L
.12507 .24228 L
.14415 .23198 L
.15353 .22461 L
.15848 .22067 L
.16118 .2189 L
.16371 .21761 L
.16485 .21716 L
.16592 .21681 L
.16716 .21649 L
.16829 .21629 L
.16954 .21614 L
.1707 .21608 L
.17197 .21608 L
.17269 .21611 L
.17333 .21615 L
.17447 .21624 L
.17553 .21636 L
.1779 .21665 L
.17998 .21689 L
.18112 .217 L
.18221 .21707 L
.18349 .21713 L
.18466 .21714 L
.18575 .21712 L
.18694 .21706 L
.18825 .21695 L
.18964 .21679 L
.19214 .21642 L
.19474 .216 L
.19611 .2158 L
.19755 .2156 L
.19881 .21547 L
.19953 .21541 L
.2002 .21536 L
.20137 .21532 L
.20263 .21531 L
.20377 .21535 L
.205 .21543 L
.20617 .21555 L
.20725 .21568 L
.21145 .21639 L
.2139 .21681 L
.21619 .21715 L
.21734 .21727 L
.21858 .21736 L
.21928 .2174 L
.21995 .21741 L
Mistroke
.2212 .21741 L
.22245 .21735 L
.22315 .2173 L
.2238 .21723 L
.22625 .2169 L
.23081 .21604 L
.23339 .21558 L
.23465 .2154 L
.23579 .21527 L
.237 .21517 L
.2383 .21512 L
.23898 .21511 L
.23971 .21512 L
.2404 .21515 L
.24105 .2152 L
.2421 .2153 L
.24324 .21544 L
.24529 .21578 L
.24997 .21675 L
.25238 .2172 L
.2536 .21737 L
.25429 .21746 L
.25492 .21752 L
.25605 .21759 L
.25727 .21762 L
.25839 .2176 L
.25945 .21753 L
.2606 .21742 L
.26185 .21724 L
.26409 .21682 L
.26919 .21567 L
.27052 .2154 L
.27196 .21516 L
.27262 .21507 L
.27332 .21499 L
.27458 .2149 L
.27579 .21487 L
.27692 .2149 L
.27816 .21499 L
.27886 .21507 L
.2795 .21515 L
.28409 .21613 L
.28842 .21721 L
.28959 .21745 L
.29082 .21766 L
.29146 .21775 L
.29217 .21783 L
.29342 .21791 L
.29455 .21793 L
.29577 .21788 L
Mistroke
.29691 .21777 L
.29796 .21761 L
.29921 .21738 L
.30036 .21711 L
.30298 .21639 L
.30548 .21566 L
.30775 .21507 L
.30884 .21484 L
.31002 .21464 L
.31114 .21452 L
.31216 .21446 L
.31325 .21445 L
.31445 .21453 L
.3157 .21468 L
.31686 .2149 L
.31815 .21521 L
.31955 .21561 L
.32209 .21647 L
.32436 .21724 L
.32685 .21797 L
.32752 .21813 L
.32825 .21827 L
.32955 .21846 L
.33028 .21852 L
.33105 .21854 L
.3317 .21854 L
.33241 .2185 L
.3337 .21834 L
.33442 .21821 L
.33508 .21806 L
.33756 .21729 L
.34241 .21527 L
.34369 .21476 L
.34507 .21427 L
.34634 .2139 L
.34755 .21365 L
.34865 .21351 L
.34984 .21347 L
.35093 .21354 L
.35193 .21369 L
.35316 .21399 L
.35427 .21437 L
.35676 .2155 L
.36191 .21843 L
.36332 .21913 L
.36481 .21974 L
.36608 .22011 L
.3668 .22024 L
.36748 .22031 L
.36879 .2203 L
Mistroke
.37003 .22009 L
.37114 .21974 L
.37235 .21917 L
.37366 .21837 L
.37506 .21733 L
.37756 .2151 L
.37986 .21291 L
.38108 .21182 L
.38238 .21078 L
.38363 .20998 L
.38476 .20946 L
.38589 .20918 L
.38696 .20918 L
.38829 .20958 L
.3895 .21038 L
.39014 .21096 L
.39084 .21175 L
.39225 .21381 L
.39345 .21608 L
.39475 .21901 L
.39708 .22558 L
.40659 .26281 L
.41077 .27895 L
.41299 .28607 L
.41538 .29222 L
.41671 .29487 L
.41792 .29683 L
.41909 .29826 L
.42031 .29934 L
.42161 .30002 L
.42281 .30027 L
.4235 .30025 L
.42413 .30015 L
.42486 .29993 L
.42555 .29964 L
.42689 .29887 L
.42831 .29783 L
.43086 .29565 L
.43363 .29328 L
.43516 .29215 L
.43661 .29126 L
.43785 .29068 L
.43855 .29043 L
.4392 .29025 L
.44034 .29005 L
.44156 .29 L
.44281 .29011 L
.44399 .29036 L
.44505 .29069 L
.44619 .29113 L
Mistroke
.45164 .29382 L
.45301 .29445 L
.45431 .29497 L
.45557 .29539 L
.45673 .29568 L
.4578 .29586 L
.45893 .29596 L
.46007 .29596 L
.46133 .29586 L
.46255 .29566 L
.46387 .29535 L
.46625 .2946 L
.47124 .29285 L
.47261 .29245 L
.47336 .29227 L
.47407 .29211 L
.47473 .29199 L
.47545 .29189 L
.4767 .29178 L
.47734 .29175 L
.47805 .29175 L
.4788 .29178 L
.47949 .29183 L
.48073 .29199 L
.48142 .2921 L
.48206 .29223 L
.4877 .29371 L
.49017 .29435 L
.49148 .29462 L
.4922 .29474 L
.49287 .29484 L
.49408 .29497 L
.49472 .29501 L
.49541 .29504 L
.49664 .29503 L
.49777 .29496 L
.49905 .29482 L
.50025 .29464 L
.5025 .2942 L
.50513 .29359 L
.50755 .29304 L
.50968 .29265 L
.51074 .29251 L
.51192 .29239 L
.5131 .29232 L
.51437 .29231 L
.51557 .29235 L
.51666 .29244 L
.52186 .29327 L
.52471 .29385 L
Mistroke
.52611 .29411 L
.52739 .29432 L
.52861 .29448 L
.5299 .2946 L
.5312 .29467 L
.53193 .29469 L
.53262 .29468 L
.53381 .29464 L
.5349 .29456 L
.53616 .29443 L
.53735 .29427 L
.54176 .29349 L
.54418 .29307 L
.54536 .29289 L
.54645 .29276 L
.54763 .29264 L
.54889 .29256 L
.55021 .29253 L
.55087 .29254 L
.55159 .29256 L
.55278 .29263 L
.55405 .29274 L
.55525 .29289 L
.55634 .29304 L
.56146 .2939 L
.56286 .29412 L
.56435 .29431 L
.56561 .29443 L
.56633 .29448 L
.56701 .29451 L
.56831 .29454 L
.56954 .29453 L
.57065 .29448 L
.57186 .29438 L
.57317 .29424 L
.57456 .29405 L
.57707 .29365 L
.57969 .29323 L
.58111 .29302 L
.58245 .29286 L
.58358 .29275 L
.5848 .29266 L
.5855 .29263 L
.58615 .29262 L
.58738 .29262 L
.58803 .29264 L
.58873 .29268 L
.58947 .29273 L
.59016 .29278 L
.59273 .29309 L
Mistroke
.5957 .29355 L
.59853 .294 L
.5997 .29416 L
.60095 .2943 L
.60167 .29437 L
.60233 .29442 L
.6036 .29449 L
.60475 .29451 L
.60599 .29449 L
.60717 .29444 L
.60825 .29435 L
.6095 .29423 L
.61067 .29408 L
.61333 .29367 L
.61613 .29323 L
.61735 .29305 L
.61871 .29288 L
.61996 .29276 L
.62113 .29267 L
.62237 .29263 L
.62307 .29262 L
.62371 .29262 L
.62497 .29266 L
.62569 .29271 L
.62636 .29276 L
.62771 .29289 L
.62915 .29308 L
.63424 .29389 L
.63545 .29407 L
.63674 .29424 L
.63793 .29437 L
.63904 .29446 L
.64011 .29451 L
.64126 .29454 L
.64254 .29452 L
.6437 .29447 L
.64494 .29437 L
.6463 .29422 L
.64876 .29387 L
.65301 .29316 L
.65417 .29299 L
.6554 .29283 L
.65646 .29272 L
.65759 .29263 L
.65891 .29257 L
.66013 .29256 L
.66088 .29258 L
.66159 .2926 L
.66223 .29264 L
.66292 .2927 L
Mistroke
.66418 .29283 L
.66552 .29301 L
.66793 .29339 L
.67243 .29416 L
.67367 .29433 L
.67497 .29447 L
.67608 .29456 L
.67729 .29461 L
.67858 .29462 L
.6793 .29461 L
.67996 .29458 L
.68123 .29448 L
.68244 .29436 L
.68475 .29402 L
.68726 .29357 L
.69005 .29307 L
.69157 .29283 L
.69299 .29265 L
.6942 .29254 L
.6955 .29246 L
.69625 .29244 L
.69695 .29244 L
.69827 .29249 L
.69952 .29258 L
.70023 .29265 L
.70087 .29273 L
.70332 .29311 L
.70789 .294 L
.70914 .29422 L
.71047 .29443 L
.71173 .29459 L
.71288 .29469 L
.71417 .29476 L
.71539 .29477 L
.7167 .29473 L
.71745 .29467 L
.71813 .29461 L
.727 .29297 L
.72822 .29274 L
.72955 .29254 L
.73081 .29239 L
.73198 .2923 L
.73314 .29225 L
.73419 .29226 L
.7354 .29232 L
.73654 .29242 L
.73772 .29258 L
.73896 .29279 L
.74118 .29325 L
.74378 .29385 L
Mistroke
.74621 .29438 L
.74829 .29474 L
.74946 .29489 L
.75052 .29497 L
.75169 .29502 L
.75296 .295 L
.75415 .29492 L
.75526 .2948 L
.76038 .29373 L
.76307 .29304 L
.76454 .29269 L
.7659 .2924 L
.7671 .2922 L
.76839 .29204 L
.76912 .29198 L
.76981 .29195 L
.77111 .29194 L
.7723 .29201 L
.7734 .29213 L
.77461 .29233 L
.77589 .29259 L
.78017 .29376 L
.78253 .29444 L
.78477 .29498 L
.78603 .29521 L
.78675 .2953 L
.78741 .29537 L
.78858 .29543 L
.78982 .29542 L
.7911 .29532 L
.7923 .29515 L
.79338 .29494 L
.79455 .29465 L
.79977 .29296 L
.80115 .29251 L
.80262 .29207 L
.80399 .29175 L
.80528 .29152 L
.80646 .29139 L
.80775 .29135 L
.80891 .2914 L
.80999 .29152 L
.81118 .29174 L
.81249 .29207 L
.81515 .29298 L
.81772 .29401 L
.82046 .29509 L
.82179 .29554 L
.82304 .29589 L
.82417 .29613 L
Mistroke
.82539 .29631 L
.82669 .29639 L
.82735 .29639 L
.82807 .29636 L
.82934 .29624 L
.83054 .29605 L
.83325 .29543 L
.83476 .29505 L
.83616 .29474 L
.83736 .29453 L
.83863 .29442 L
.83991 .29444 L
.84064 .29453 L
.84132 .29466 L
.84255 .29506 L
.84368 .2956 L
.84491 .29641 L
.84622 .29751 L
.84849 .30001 L
.8506 .30294 L
.8554 .31085 L
.85782 .31477 L
.85909 .31662 L
.86044 .31831 L
.86162 .3195 L
.86292 .32045 L
.8641 .32093 L
.8652 .32103 L
.86635 .32073 L
.86745 .32007 L
.86843 .31914 L
.8695 .31777 L
.87066 .31587 L
.87189 .31338 L
.87412 .30783 L
.87919 .29139 L
.88454 .27271 L
.88675 .26601 L
.88912 .26006 L
.89047 .25734 L
.89171 .25534 L
.89296 .2538 L
.89413 .25279 L
.89538 .25216 L
.8967 .25199 L
.89782 .25221 L
.89906 .25281 L
.89976 .25329 L
.9004 .25382 L
.90183 .25526 L
Mistroke
.90443 .25854 L
.90974 .26609 L
.91255 .26959 L
.9141 .2712 L
.91556 .2725 L
.91684 .27347 L
.91823 .27433 L
.92065 .27544 L
.92185 .27584 L
.92311 .27619 L
.92539 .27673 L
.92776 .27731 L
.93031 .27813 L
.93178 .27874 L
.93311 .27941 L
.93573 .28103 L
.97551 .30846 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0Eooo
ool4o`0009_ooooo000Wooooo`;o00008_ooool3o`0000Cooooo1?l00005ooooo`Go00001Oooool5
o`0000Cooooo1Ol00004ooooo`Ko00000oooool2o`0000;ooooo0_l0002Jooooo`009oooool00ol0
003oooooooooo`0Pooooo`;o000000?oooooo`000?l000000ol00004ooooo`Go00001Oooool5o`00
00Gooooo1Ol00003ooooo`Go00001_ooool4o`0000Cooooo00?o0000ooooooooool0V?ooool000So
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Go
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0V?ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01gooooo0_l0000looooo`03o`000?oooooooooo09Sooooo0005
o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0001_ooooo0ol0000nooooo`03o`00
0?oooooooooo09Sooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06?ooool2o`0004;ooooo00?o0000ooooooooool0Uoooool000Oooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol00005
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`2G
ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo01Gooooo0_l00015ooooo`03o`00
0?oooooooooo09Oooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?oo
ool2o`0001Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2Fooooo`009oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0U_ooool0
02Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
07Wooooo1?l0000Iooooo`009oooool00ol0003oooooooooo`0@ooooo`;o0000C?ooool00ol0003o
ooooooooo`1hooooo`04o`000?ooooooooooo`0001Wooooo000Wooooo`;o00004?ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Fooooo`009oooool00ol0003oooooooooo`0=ooooo`;o00005oooool2o`0000Cooooo
00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool00ol0003oooooo`000003ooooo`?o
00008_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0002;ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo00_ooooo0_l0000Hooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`03ooooo`;o00003Oooool00ol0
003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01So
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Pooooo`04o`000?oooooooooo
o`0000Kooooo1_l0000Qooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000Pooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Aoooo
o`03o`000?oooooooooo00Gooooo0_l0000<ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o
00002Oooool2o`0001_ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Ooooo
o`04o`000?ooooooooooo`0000Kooooo0_l00002ooooo`03o`000?oooooooooo023ooooo00Co0000
oooooooooooo00001oooool4o`00027ooooo00Co0000oooooooooooo00002?ooool3o`0001;ooooo
00?o0000ooooooooool01_ooool4o`0000Wooooo00?o0000ooooooooool01_ooool002Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Kooooo00Go0000oooo
ool0003oooooo`00000Rooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool08_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003o
ooooooooo`0:ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`009oooool00ol0003ooooo
ooooo`05ooooo`;o00007_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000008?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00;o00008_ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`;o00002?ooool002Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Oooooo`;o00002Oooool3o`0002;ooooo0_l00007ooooo`05o`000?ooooooooooooooool0
00000_ooool3o`0001kooooo0_l0000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Aooooo`03
o`000?oooooooooo00kooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o0000
0oooool2o`0005cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000;o
ooooD_l000000ooooooo0000o`000006o`0000?ooooo0ol00008ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool02_ooool002Oooooo00Go0000ooooooooooooooooo`00001Oooooo`04
o`000?oooooo0000o`0000Gooooo0ol0001Aooooo`?o00001_ooool4o`0000;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo000Wooooo`04
o`000?oooooo0000o`00063ooooo0ol0001Zooooo`;o00001_ooool00ol0003oooooooooo`0Boooo
o`;o00002Oooool002Oooooo0_l0003@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`06ooooo`008Oooooooo`0000009oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool01ol0003ooooooooo
oooooooo0000ooooool000002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool01?l0003ooooo
o`000?l0000Iooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooooooo0=7ooooo
0ol0000Rooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000
moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool2o`000?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000
ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?oo
ool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003o
ooooooooo`3fooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo
0ol00005ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`003Oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool0
1?l00005ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o
00002_ooool2o`0000;ooooo1Ol00004ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooo
oooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Ko
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005
ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
m_ooool000Sooooo0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?oo
ool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Dooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`004oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003oooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28401 L
.10458 .25712 L
.14415 .23161 L
.18221 .20707 L
.19311 .19938 L
.19847 .19494 L
.20342 .19126 L
.20791 .18872 L
.21018 .18779 L
.21267 .18703 L
.21398 .18674 L
.21517 .18652 L
.21655 .18633 L
.21786 .18619 L
.21906 .18609 L
.22018 .18602 L
.22272 .1859 L
.23243 .18532 L
.23475 .18513 L
.2372 .18494 L
.23821 .18488 L
.23929 .18482 L
.24048 .18477 L
.24159 .18475 L
.24224 .18474 L
.24295 .18475 L
.24424 .18477 L
.2455 .18483 L
.24666 .1849 L
.24792 .185 L
.24932 .18513 L
.25214 .18545 L
.25452 .18573 L
.25576 .18587 L
.25708 .186 L
.25823 .18609 L
.25949 .18616 L
.26064 .1862 L
.26171 .18621 L
.26299 .1862 L
.26363 .18618 L
.26434 .18614 L
.26559 .18606 L
.26676 .18595 L
.2694 .18564 L
.27223 .18525 L
.2749 .18489 L
.27621 .18474 L
.27742 .18463 L
Mistroke
.27852 .18456 L
.27969 .18451 L
.28099 .18449 L
.28217 .18451 L
.28333 .18456 L
.28457 .18466 L
.28562 .18476 L
.28677 .1849 L
.29174 .18566 L
.294 .186 L
.29524 .18616 L
.29641 .18628 L
.2975 .18637 L
.29868 .18643 L
.29976 .18646 L
.30075 .18645 L
.30194 .1864 L
.30318 .18631 L
.30424 .1862 L
.3054 .18605 L
.31041 .1852 L
.31268 .1848 L
.31392 .18461 L
.3151 .18445 L
.3162 .18434 L
.31738 .18426 L
.31846 .18422 L
.31946 .18422 L
.32065 .18426 L
.32193 .18435 L
.32313 .18448 L
.32423 .18464 L
.32948 .18567 L
.33208 .18619 L
.33346 .18642 L
.33421 .18653 L
.33492 .18661 L
.33619 .18673 L
.33687 .18677 L
.33759 .18679 L
.33889 .18678 L
.34007 .18672 L
.34135 .18659 L
.34255 .18642 L
.3448 .18599 L
.34986 .18477 L
.35198 .18431 L
.35314 .1841 L
.35423 .18395 L
.35541 .18383 L
Mistroke
.3567 .18377 L
.35779 .18378 L
.35897 .18384 L
.35964 .18391 L
.36035 .184 L
.36162 .18421 L
.36452 .1849 L
.36723 .1857 L
.36978 .18645 L
.37099 .18676 L
.37227 .18704 L
.37294 .18716 L
.37368 .18727 L
.37497 .1874 L
.37614 .18744 L
.3774 .1874 L
.37858 .18728 L
.37967 .1871 L
.38893 .18401 L
.39118 .18332 L
.39245 .18303 L
.39361 .18285 L
.3949 .18276 L
.39555 .18276 L
.39627 .1828 L
.39756 .18296 L
.39876 .18322 L
.40017 .18366 L
.4015 .18418 L
.40398 .18537 L
.40688 .18691 L
.40815 .18755 L
.40955 .18819 L
.41068 .18861 L
.41188 .18896 L
.41315 .18919 L
.41434 .18926 L
.41501 .18923 L
.41573 .18914 L
.41705 .18883 L
.41834 .18833 L
.41953 .18771 L
.42219 .18585 L
.42463 .18376 L
.42726 .18144 L
.42865 .18034 L
.43014 .17937 L
.43145 .17875 L
.43265 .17845 L
.43385 .17843 L
Mistroke
.43499 .17871 L
.43627 .17941 L
.43744 .18045 L
.43874 .18204 L
.44011 .18425 L
.44231 .18895 L
.44468 .19551 L
.44897 .21053 L
.45369 .22945 L
.45873 .24833 L
.46148 .25663 L
.46397 .26245 L
.46517 .26462 L
.46647 .26651 L
.4677 .26784 L
.46883 .26871 L
.47015 .2693 L
.47139 .26948 L
.47209 .26943 L
.47274 .26931 L
.47349 .26907 L
.47419 .26876 L
.4756 .26794 L
.47691 .267 L
.47986 .26453 L
.48208 .26266 L
.48449 .26093 L
.48586 .26016 L
.48712 .25962 L
.48833 .25926 L
.4896 .25905 L
.49083 .25902 L
.49216 .25915 L
.4934 .25943 L
.49454 .25978 L
.49732 .26096 L
.49994 .26227 L
.50217 .26333 L
.50457 .26427 L
.50594 .26467 L
.5072 .26493 L
.50846 .26508 L
.50966 .26512 L
.5109 .26505 L
.51221 .26488 L
.51346 .26463 L
.51458 .26434 L
.51995 .26255 L
.52217 .26184 L
.52338 .26151 L
Mistroke
.52452 .26125 L
.52574 .26104 L
.52639 .26096 L
.52709 .2609 L
.52833 .26084 L
.52945 .26086 L
.5306 .26094 L
.53166 .26107 L
.53282 .26126 L
.53405 .26151 L
.5384 .26262 L
.54079 .26323 L
.54209 .26352 L
.5433 .26374 L
.54434 .26389 L
.54544 .26401 L
.54667 .26409 L
.54779 .2641 L
.54909 .26406 L
.55029 .26397 L
.5516 .26381 L
.55299 .26359 L
.5579 .26259 L
.56007 .26215 L
.56127 .26194 L
.5624 .26178 L
.56346 .26165 L
.5646 .26155 L
.56565 .2615 L
.56661 .26149 L
.56775 .2615 L
.56882 .26156 L
.56999 .26165 L
.57125 .2618 L
.57383 .26219 L
.57619 .2626 L
.57862 .26302 L
.58092 .26335 L
.58218 .26349 L
.58285 .26354 L
.58356 .26359 L
.58481 .26364 L
.58597 .26365 L
.58705 .26363 L
.58821 .26357 L
.5893 .26349 L
.59031 .26339 L
.59508 .26274 L
.59754 .26238 L
.60015 .26206 L
Mistroke
.60093 .26199 L
.60166 .26193 L
.60237 .26189 L
.60302 .26186 L
.6043 .26183 L
.60498 .26182 L
.60569 .26183 L
.60689 .26187 L
.60817 .26195 L
.60939 .26205 L
.61049 .26216 L
.61577 .26281 L
.61825 .26309 L
.61946 .2632 L
.62058 .26328 L
.62175 .26334 L
.62301 .26338 L
.62431 .26338 L
.62497 .26337 L
.62569 .26335 L
.62689 .2633 L
.62798 .26323 L
.63044 .26301 L
.63486 .26253 L
.63735 .26229 L
.6386 .2622 L
.63998 .26211 L
.6407 .26208 L
.64148 .26206 L
.64221 .26205 L
.64288 .26204 L
.64353 .26205 L
.64424 .26206 L
.64554 .2621 L
.64623 .26213 L
.64687 .26217 L
.64807 .26225 L
.65077 .26248 L
.65328 .26272 L
.65562 .26292 L
.65678 .26301 L
.65788 .26308 L
.65914 .26314 L
.66029 .26318 L
.66157 .26319 L
.66275 .26319 L
.66404 .26316 L
.6647 .26314 L
.66541 .26311 L
.66798 .26296 L
Mistroke
.67075 .26275 L
.67314 .26256 L
.6744 .26247 L
.67575 .26238 L
.67709 .26231 L
.67831 .26226 L
.67954 .26223 L
.68069 .26222 L
.68187 .26222 L
.68295 .26224 L
.68414 .26227 L
.6854 .26233 L
.68757 .26244 L
.68961 .26257 L
.69185 .26272 L
.69423 .26286 L
.69547 .26292 L
.69612 .26295 L
.69683 .26298 L
.69807 .26301 L
.69923 .26302 L
.69989 .26303 L
.70061 .26303 L
.70137 .26302 L
.70207 .26301 L
.70333 .26298 L
.70467 .26293 L
.70976 .26269 L
.71226 .26256 L
.71336 .26252 L
.71457 .26247 L
.71573 .26244 L
.71683 .26241 L
.71798 .2624 L
.71923 .26239 L
.71987 .26239 L
.72058 .2624 L
.72187 .26241 L
.72312 .26244 L
.72428 .26247 L
.72888 .26263 L
.7309 .2627 L
.73312 .26276 L
.7344 .26279 L
.73559 .26281 L
.73685 .26282 L
.73756 .26283 L
.7382 .26283 L
.7389 .26283 L
.73955 .26283 L
Mistroke
.74027 .26283 L
.74102 .26282 L
.7423 .26281 L
.7437 .2628 L
.75366 .26267 L
.75593 .26266 L
.75836 .26264 L
.75954 .26263 L
.76065 .26261 L
.76273 .26258 L
.76492 .26253 L
.76729 .26247 L
.76966 .26241 L
.77031 .2624 L
.77101 .26239 L
.77227 .26237 L
.77296 .26237 L
.77361 .26237 L
.77483 .26238 L
.77612 .26242 L
.77686 .26245 L
.77753 .26249 L
.77877 .26259 L
.77988 .26272 L
.78117 .2629 L
.78238 .26311 L
.7847 .26366 L
.78683 .26432 L
.79164 .26639 L
.79649 .26918 L
.8018 .27275 L
.8125 .28015 L
.85301 .30585 L
.86208 .31242 L
.8717 .3195 L
.87672 .32231 L
.88225 .32464 L
.88486 .32567 L
.88734 .32677 L
.892 .3296 L
.89453 .33171 L
.89729 .33453 L
.90299 .34143 L
.90558 .34451 L
.907 .34601 L
.90834 .34723 L
.90959 .34815 L
.91024 .34854 L
.91094 .34886 L
.91217 .34919 L
Mistroke
.9133 .34921 L
.91455 .34888 L
.91569 .34824 L
.91701 .34707 L
.91826 .34553 L
.92048 .34175 L
.9229 .33622 L
.92833 .31961 L
.93344 .30227 L
.93564 .2955 L
.93796 .28941 L
.93917 .28678 L
.9405 .28438 L
.94171 .28268 L
.94283 .28152 L
.94348 .28104 L
.94419 .28067 L
.94546 .28042 L
.9467 .28066 L
.94785 .28129 L
.94909 .28238 L
.95045 .284 L
.95321 .28837 L
.95844 .29843 L
.96132 .30353 L
.96274 .30564 L
.96406 .3073 L
.96539 .30866 L
.9666 .30959 L
.96729 .31001 L
.96794 .31031 L
.96862 .31055 L
.96937 .31072 L
.9706 .31079 L
.97189 .31064 L
.973 .31034 L
.97421 .3099 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`1Sooooo`Co0000Soooool002Oo
oooo00?o0000ooooooooool0=?ooool2o`0000Oooooo0ol00006ooooo`Co00001Oooool4o`0000Go
oooo1_l00004ooooo`;o00000_ooool00ol0003oooooooooo`2=ooooo`009oooool2o`0002cooooo
2Ol000000ooooooo0000o`000006o`0000;ooooo1ol00004ooooo`Go00001?ooool5o`0000Gooooo
0ol000000ooooooo0000o`000003ooooo`03o`000?oooooooooo08gooooo000Wooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0<_ooool3o`0000Gooooo00?o0000ooooooooool0S?oo
ool002Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo08_ooooo000Wooooo`03o`000?oooooooooo02Oooooo0_l0000oooooo`03o`000?oooooooooo
08_ooooo000Wooooo`;o00009oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08_o
oooo000Wooooo`03o`000?oooooooooo02Cooooo0_l00013ooooo`03o`000?oooooooooo08[ooooo
000Wooooo`03o`000?oooooooooo02;ooooo0_l00015ooooo`03o`000?oooooooooo08[ooooo000W
ooooo`;o00008_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo08[ooooo000Woooo
o`03o`000?oooooooooo01oooooo0_l00018ooooo`03o`000?oooooooooo08[ooooo0008ooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03
o`000?oooooooooo01gooooo0_l0001;ooooo`03o`000?oooooooooo08Wooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0ROooool000Go00000_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`;o00006oooool2o`0004kooooo00?o0000ooooooooool0ROooool000Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool0ROooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooo
oooo01Oooooo0_l0001Aooooo`03o`000?oooooooooo08Wooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo08Sooooo
0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool2o`0001Kooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`28ooooo`009oooool00ol0003oooooooooo`0C
ooooo`;o0000E_ooool00ol0003oooooooooo`28ooooo`009oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0R?ooool002Oooooo00?o0000oooooooo
ool04?ooool2o`0005[ooooo00?o0000ooooooooool00oooool3o`00087ooooo000Wooooo`;o0000
4?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000
o`000?l00003ooooo`Oo00000_oooolko`0003Sooooo000Wooooo`03o`000?oooooooooo00gooooo
0_l0000Gooooo`;o00001?ooool01?l0003oooooooooooooool5o`00027ooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo0ol00008ooooo`04o`000?ooooooooooo`0000Kooooo0ol00007oooo
o`?o00000oooool2o`0000;ooooo0ol00004ooooo`?o00008_ooool2o`0000Cooooo1?l000001?oo
oooo0000o`000?l0000Wooooo`?o00001oooool002Oooooo00?o0000ooooooooool02oooool2o`00
01Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool01oooool3o`0001Kooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007
ooooo`?o000000?oooooo`000?ooool09_ooool00ol0003oooooooooo`06ooooo`009oooool2o`00
00Wooooo0_l0000Kooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool07oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002;ooooo00Co0000oooooooooooo
00001oooool4o`00027ooooo00Co0000oooooooooooo00002?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool002Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool000008_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo02;ooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooooooool2o`00
01oooooo0ol00004ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Go
oooo0_l0000Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000P
ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000Rooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`06o`000?oooooooooooooo
ool0003ooooo0_l0000Looooo`04o`000?ooooooooooo`0000?ooooo0_l00008ooooo`009oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo0_l00009ooooo`?o00008_ooool2
o`0000_ooooo00?o0000ooooooooool08Oooool2o`0000[ooooo0_l0000Rooooo`;o00002Oooool3
o`0000Cooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01_ooool002Oooooo0_l00003ooooo`;o0000a_ooool2o`0001Wooooo00Go0000
ooooooooooooooooo`00000<ooooo`009oooool01Ol0003ooooooooooooooooo00000<[ooooo0_l0
000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool002Oooooo00Co0000
ooooool0003o0000cOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool002Oooooo0_l0003@ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`008Oooooooo`0000009oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000?o
oooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool01Oooool002Oooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`009oooool00ol0003ooooooooo
o`3Dooooo`?o00002oooool00ol0003oooooooooo`0Aooooo`009oooool2o`000=Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`009oooool00ol0003oooooooooo`3Hoooo
o`;o00002?ooool00ol0003oooooooooo`0Aooooo`009oooool00ol0003oooooooooo`3Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool002Oooooo00?o0000ooooooooool0
f_ooool2o`0000Gooooo00?o0000ooooooooool04_ooool002Oooooo0_l0003Mooooo`05o`000?oo
ooooooooooooool000005Oooool002Oooooo00?o0000ooooooooool0gOooool01?l0003ooooooooo
ool0000Eooooo`009oooool00ol0003oooooooooo`3Mooooo`?o00005_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2
o`000?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`00
00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_oo
ool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo
0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0
003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03
o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool0
00gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00;ooooo0_l0003gooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03
o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00008ooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00002_ooool2o`00
00;ooooo1Ol00004ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003g
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005ooooo`03o`000?oo
oooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0m_ooool000Sooooo
0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?ooool00ol0003ooooo
ooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000
moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool2o`000?Oooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`3fooooo`004oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooo`00
5?ooool2o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28376 L
.10458 .25578 L
.14415 .22993 L
.18221 .20517 L
.22272 .17892 L
.24141 .16881 L
.25127 .16055 L
.25366 .15871 L
.25624 .15705 L
.25771 .15626 L
.25906 .15567 L
.26034 .15521 L
.26171 .15485 L
.26245 .1547 L
.26312 .15459 L
.26443 .15445 L
.26516 .15441 L
.26595 .1544 L
.2667 .15441 L
.26739 .15444 L
.26864 .15452 L
.27001 .15466 L
.27279 .15499 L
.2741 .15514 L
.27534 .15525 L
.27603 .1553 L
.27677 .15535 L
.27808 .15539 L
.27932 .15539 L
.28064 .15534 L
.28177 .15525 L
.28302 .15513 L
.28562 .15475 L
.28801 .15434 L
.29059 .15391 L
.29195 .15372 L
.2927 .15363 L
.2934 .15356 L
.29469 .15346 L
.29586 .15342 L
.29696 .15342 L
.29815 .15346 L
.29942 .15355 L
.30005 .15361 L
.30076 .1537 L
.30316 .15407 L
.30565 .15454 L
.30837 .15507 L
.30961 .15528 L
Mistroke
.31094 .15546 L
.31219 .1556 L
.31332 .15568 L
.31452 .15572 L
.31562 .15572 L
.31683 .15566 L
.3181 .15555 L
.31921 .15541 L
.32025 .15525 L
.3226 .1548 L
.32509 .15427 L
.32779 .15373 L
.32902 .15353 L
.33034 .15336 L
.33146 .15326 L
.33269 .15319 L
.33343 .15318 L
.3341 .15319 L
.33484 .15322 L
.33561 .15328 L
.33692 .15341 L
.33766 .15352 L
.33835 .15363 L
.3435 .15473 L
.34596 .15527 L
.3473 .15553 L
.34856 .15572 L
.34927 .1558 L
.34992 .15586 L
.35064 .15591 L
.35142 .15594 L
.35206 .15595 L
.35277 .15594 L
.35405 .15586 L
.35523 .15574 L
.35655 .15554 L
.35921 .15498 L
.3617 .15436 L
.36399 .15379 L
.36624 .15333 L
.36737 .15315 L
.36861 .15301 L
.36985 .15294 L
.37055 .15292 L
.37118 .15293 L
.37242 .153 L
.37358 .15313 L
.37467 .15329 L
.37583 .15352 L
.3779 .15402 L
Mistroke
.38259 .15532 L
.3838 .15561 L
.38512 .15588 L
.38636 .15608 L
.38751 .15621 L
.38866 .15627 L
.38969 .15627 L
.39089 .1562 L
.39201 .15607 L
.39325 .15586 L
.39455 .15557 L
.39688 .15492 L
.39942 .15412 L
.40214 .1533 L
.40336 .15301 L
.4045 .15278 L
.40554 .15262 L
.40666 .15252 L
.40772 .15249 L
.40885 .15252 L
.40981 .15261 L
.41087 .15277 L
.41211 .15303 L
.41325 .15334 L
.41581 .15419 L
.42045 .15586 L
.42173 .15625 L
.42293 .15654 L
.42402 .15674 L
.42519 .15687 L
.42647 .15691 L
.42712 .15688 L
.42783 .15682 L
.42909 .15663 L
.43026 .15636 L
.43144 .156 L
.43256 .15559 L
.43466 .15471 L
.43939 .15263 L
.44067 .15218 L
.44188 .15185 L
.44255 .1517 L
.44327 .15159 L
.44453 .1515 L
.44574 .15153 L
.44701 .15172 L
.4481 .15199 L
.4493 .1524 L
.45199 .15369 L
.45488 .15541 L
Mistroke
.45736 .15687 L
.45877 .15759 L
.46009 .15813 L
.46133 .15849 L
.46203 .15862 L
.46267 .15869 L
.46334 .15871 L
.46407 .15867 L
.46476 .15856 L
.4654 .15841 L
.46664 .15796 L
.46777 .15737 L
.4703 .15555 L
.47563 .15051 L
.47708 .14923 L
.47788 .14863 L
.47863 .14814 L
.47994 .14749 L
.48064 .14728 L
.48139 .14717 L
.48208 .14718 L
.48272 .1473 L
.48342 .14756 L
.48417 .14799 L
.48543 .14907 L
.48614 .14991 L
.48681 .15084 L
.48919 .1553 L
.49176 .16208 L
.49685 .18043 L
.50152 .19995 L
.50626 .21813 L
.50886 .22609 L
.51014 .22931 L
.51132 .23184 L
.51241 .23379 L
.51361 .23551 L
.51482 .2368 L
.5161 .23771 L
.51718 .23814 L
.51834 .23828 L
.51944 .23814 L
.52044 .23781 L
.52564 .23416 L
.52849 .23178 L
.52989 .23074 L
.53118 .22993 L
.5324 .2293 L
.53369 .22881 L
.53498 .2285 L
Mistroke
.53572 .22841 L
.5364 .22838 L
.5376 .22845 L
.53869 .22863 L
.53995 .22896 L
.54114 .22938 L
.54556 .23142 L
.54798 .23252 L
.55025 .23333 L
.55143 .23364 L
.5527 .23386 L
.55338 .23393 L
.5541 .23398 L
.55539 .23396 L
.55657 .23385 L
.55767 .23368 L
.55887 .23341 L
.56015 .23306 L
.56284 .2322 L
.56574 .23125 L
.56708 .23088 L
.56849 .23055 L
.5697 .23034 L
.57038 .23025 L
.57102 .23018 L
.5723 .23012 L
.57351 .23014 L
.57459 .23022 L
.57578 .23036 L
.57706 .23058 L
.57843 .23087 L
.58089 .23148 L
.58326 .23208 L
.58455 .23238 L
.58576 .23262 L
.58688 .23281 L
.5879 .23293 L
.58903 .23303 L
.59023 .23308 L
.59153 .23306 L
.59272 .23299 L
.59403 .23285 L
.59542 .23264 L
.60032 .23165 L
.60249 .23123 L
.60368 .23102 L
.60481 .23087 L
.60586 .23076 L
.60701 .23067 L
.60805 .23064 L
Mistroke
.60902 .23064 L
.61027 .23069 L
.61145 .23078 L
.61251 .2309 L
.61365 .23106 L
.61859 .23194 L
.62097 .23234 L
.62227 .23252 L
.62351 .23265 L
.62466 .23273 L
.62591 .23278 L
.62705 .23277 L
.6281 .23274 L
.62934 .23265 L
.63051 .23253 L
.63316 .23216 L
.63578 .23171 L
.63854 .23127 L
.63976 .2311 L
.64106 .23096 L
.64181 .2309 L
.64249 .23085 L
.64318 .23082 L
.64383 .23081 L
.64504 .23081 L
.64615 .23085 L
.64738 .23093 L
.64867 .23106 L
.65439 .23192 L
.65688 .2323 L
.6582 .23246 L
.65892 .23254 L
.6596 .23259 L
.66092 .23267 L
.66212 .23271 L
.66324 .2327 L
.66445 .23265 L
.66561 .23257 L
.66684 .23245 L
.66904 .23216 L
.67158 .23175 L
.67429 .23132 L
.67561 .23115 L
.67685 .231 L
.67797 .23091 L
.67918 .23084 L
.68023 .23081 L
.68139 .23081 L
.68259 .23086 L
.68372 .23094 L
Mistroke
.68478 .23104 L
.68574 .23115 L
.68792 .23146 L
.6905 .23188 L
.69294 .23227 L
.69513 .23254 L
.69636 .23265 L
.6975 .23272 L
.6986 .23275 L
.69981 .23275 L
.70107 .2327 L
.70225 .23262 L
.70354 .23249 L
.7047 .23234 L
.70733 .23193 L
.70963 .23154 L
.71207 .23115 L
.71416 .23089 L
.71535 .23078 L
.71646 .23071 L
.71774 .23068 L
.71891 .23068 L
.7202 .23073 L
.72085 .23078 L
.72156 .23083 L
.72294 .23099 L
.72443 .2312 L
.7271 .23166 L
.73718 .23375 L
.74215 .2349 L
.74465 .23565 L
.74741 .2367 L
.75039 .2382 L
.75318 .23997 L
.75851 .24423 L
.77865 .25849 L
.81745 .28325 L
.85871 .30845 L
.89844 .33245 L
.89969 .33294 L
.90086 .33354 L
.90207 .33433 L
.90341 .33537 L
.9062 .33819 L
.90877 .3414 L
.91386 .34843 L
.91608 .35124 L
.91725 .35253 L
.91849 .35374 L
.91961 .35464 L
Mistroke
.92084 .35543 L
.92195 .35595 L
.923 .35627 L
.92407 .35643 L
.92505 .35643 L
.92613 .35631 L
.92727 .35604 L
.92962 .3552 L
.93091 .35467 L
.93213 .35419 L
.93327 .35383 L
.93451 .35357 L
.93563 .3535 L
.93666 .35362 L
.93776 .35395 L
.93878 .35449 L
.9399 .35534 L
.94111 .35658 L
.94356 .36015 L
.94581 .3645 L
.95099 .37678 L
.95352 .38239 L
.95462 .38444 L
.9558 .38626 L
.95705 .38763 L
.95823 .38833 L
.95888 .38843 L
.95957 .38831 L
.96081 .38746 L
.96146 .38667 L
.96216 .38554 L
.96341 .38279 L
.96491 .37827 L
.96626 .373 L
.96871 .36086 L
.97137 .34437 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo073ooooo0ol00023ooooo`00
1_ooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Boooool2o`0000Oooooo0ol00006oooo
o`?o00001_ooool4o`0000Gooooo00Co0000oooooooooooo0000Poooool000gooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l0
000ioooooa?o000000?oooooo`000?l000001ol000000ooooooo0000o`000005o`0000?ooooo1_l0
0003ooooo`?o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo083ooooo000=
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo
00?o0000ooooooooool0=_ooool2o`0003?ooooo0ol00005ooooo`03o`000?oooooooooo083ooooo
000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`20oooo
o`003_ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`0cooooo`;o
0000?_ooool00ol0003oooooooooo`20ooooo`009oooool2o`0003;ooooo0_l00011ooooo`03o`00
0?oooooooooo07oooooo000Wooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`1oooooo`009oooool00ol0003oooooooooo`0^ooooo`;o0000AOooool0
0ol0003oooooooooo`1nooooo`009oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0O_ooool002Oooooo0_l0000/ooooo`;o0000B?ooool00ol0003o
ooooooooo`1nooooo`009oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0OOooool002Oooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo07gooooo000Wooooo`03o`000?oooooooooo02Oooooo0_l0001=
ooooo`03o`000?oooooooooo07gooooo000Wooooo`;o00009oooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo07gooooo000Wooooo`03o`000?oooooooooo02Cooooo0_l0001@ooooo`03
o`000?oooooooooo07gooooo000Wooooo`03o`000?oooooooooo02;ooooo0_l0001Cooooo`03o`00
0?oooooooooo07cooooo000Wooooo`;o00008_ooool00ol0003oooooooooo`1Cooooo`03o`000?oo
oooooooo07cooooo000Wooooo`03o`000?oooooooooo01oooooo0_l0001Fooooo`03o`000?oooooo
oooo07cooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`00
00;ooooo0ol00005ooooo`03o`000?oooooooooo01gooooo0_l0001Hooooo`03o`000?oooooooooo
07cooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0Noooool000Go00000_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`;o00006oooool2o`0005cooooo00?o0000oooooooo
ool00_ooool5o`0000Cooooo1_l00003ooooo`Ko00000oooool6o`0000?ooooo1_l00003ooooo`So
0000A?ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo05gooooo00Co0000oooooooooooo00001Oooool5o`0000Cooooo1?l00005
ooooo`Co00001Oooool4o`0000Kooooo1?l00007ooooo`?o0000@Oooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
0ol00005ooooo`03o`000?oooooooooo01Oooooo0_l0001Pooooo`?o0000>?ooool2o`00043ooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Moooo
o`03o`000?oooooooooo03gooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go
00001?ooool2o`0001Kooooo00?o0000ooooooooool0Woooool2o`0003gooooo000Wooooo`03o`00
0?oooooooooo01?ooooo0_l0002Tooooo`;o0000>oooool002Oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo03Sooooo000Wooooo`03o`000?oooooo
oooo013ooooo0_l0002Zooooo`;o0000>?ooool002Oooooo0_l0000@ooooo`03o`000?oooooooooo
0:cooooo0_l0000fooooo`009oooool00ol0003oooooooooo`0=ooooo`;o00005oooool2o`0000Co
oooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`?o00008_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0002;ooooo0_l00004oooo
o`05o`000?ooooooooooo`000?ooool00ol0000Wooooo`?o00001oooool002Oooooo00?o0000oooo
ooooool02oooool2o`0001Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool08?ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007
ooooo`;o00000_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo000Woooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00027ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooo`000002o`0002Oooooo00?o0000ooooooooool01_ooool002Oo
oooo0_l00009ooooo`;o00006oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo
01oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0000Rooooo`04o`000?oo
ooooooooo`0000Oooooo1?l0000Qooooo`04o`000?ooooooooooo`0000Sooooo1?l0000Wooooo`03
o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo000002;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo
oooo0ol0000Uooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Gooooo
0_l0000Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Poooo
o`04o`000?ooooooooooo`0000Wooooo0_l0000Rooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Qooooo`;o00002?ooool002Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Oooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`00
0?oooooooooo027ooooo0_l0000:ooooo`;o00008_ooool2o`0000Wooooo0ol00004ooooo`;o0000
8_ooool00ol0003oooooooooo`06ooooo`009oooool2o`0000?ooooo0_l00037ooooo`;o0000:Ooo
ool002Oooooo00Go0000ooooooooooooooooo`00003;ooooo`03o`000?oooooooooo02Kooooo000W
ooooo`04o`000?oooooo0000o`000<gooooo0_l0000Vooooo`009oooool2o`000=7ooooo00?o0000
ooooooooool08oooool0027oooooool0000002Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
1Oooool002Oooooo00?o0000ooooooooool0e_ooool2o`0001Kooooo00?o0000ooooooooool01Ooo
ool002Oooooo0_l0003Iooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`009oooool00ol0
003oooooooooo`3Jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool002Oo
oooo00?o0000ooooooooool0foooool2o`00013ooooo00?o0000ooooooooool01_ooool002Oooooo
00?o0000ooooooooool0g?ooool2o`0000oooooo00?o0000ooooooooool01_ooool002Oooooo0_l0
003Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000
ooooooooool0g_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo000Woooo
o`03o`000?oooooooooo0=oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06oooo
o`009oooool00ol0003oooooooooo`3Oooooo`;o00000_ooool3o`0000Oooooo00?o0000oooooooo
ool01_ooool002Oooooo0_l0003Qooooo`Co000000?oooooo`000?l000001_ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`3Vooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo0>Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`009oooool2o`000>Wooooo00Go0000oooooooo
ooooooooo`000009ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;o
oooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`3Xooooo`05o`000?oooooooooooooo
ool000002Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0>Sooooo00Go0000ooooooooooooooooo`000009ooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0>Wooooo00?o0000ooooool000002_ooool000Oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool2o`000>[ooooo0ol0000:ooooo`001oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
o`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Co
oooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooooooo
o`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0
003gooooo`009oooool00ol0003oooooooooo`3fooooo`003_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooo`000?ooool01?l00005ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oo
oooooooo0?Kooooo000>ooooo`;o00002_ooool2o`0000;ooooo1Ol00004ooooo`;o0000moooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000Sooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0
003gooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool0m_ooool000Sooooo0_l0000:ooooo`;o00000_ooool5o`000003
ooooool0003o000000?o00001?ooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Doooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3foooo
o`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0m_ooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04oooo
o`;o0000moooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3moooo
o`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003oooooo`005?ooool2o`0000[ooooo00?o0000oooooooo
ool0oOooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .2839 L
.10458 .25628 L
.14415 .23051 L
.18221 .20579 L
.22272 .17937 L
.26171 .15394 L
.28158 .14252 L
.29205 .13454 L
.29779 .13022 L
.30059 .12843 L
.30316 .12707 L
.30543 .12609 L
.30791 .12527 L
.30928 .12493 L
.31054 .12467 L
.31174 .12446 L
.31304 .12429 L
.31446 .12414 L
.3158 .12404 L
.3171 .12396 L
.3183 .1239 L
.32392 .12367 L
.32874 .12343 L
.33109 .12331 L
.33324 .12321 L
.3344 .12317 L
.3355 .12314 L
.33667 .12313 L
.33793 .12312 L
.33923 .12314 L
.33989 .12316 L
.34061 .12318 L
.34189 .12324 L
.34309 .12331 L
.34818 .12373 L
.35066 .12394 L
.35292 .1241 L
.35415 .12417 L
.35531 .12421 L
.35653 .12423 L
.35722 .12423 L
.35786 .12422 L
.35911 .12419 L
.35982 .12416 L
.36049 .12413 L
.36183 .12404 L
.36327 .12391 L
.36823 .12338 L
.37067 .12314 L
Mistroke
.37186 .12304 L
.37294 .12296 L
.37399 .12291 L
.37498 .12288 L
.37603 .12287 L
.37716 .12288 L
.37833 .12292 L
.37957 .12299 L
.38062 .12307 L
.38177 .12318 L
.38703 .12383 L
.38962 .12414 L
.39075 .12425 L
.392 .12436 L
.39312 .12442 L
.39417 .12446 L
.39528 .12447 L
.39647 .12445 L
.3977 .1244 L
.399 .1243 L
.40011 .12419 L
.40132 .12405 L
.40657 .12328 L
.40795 .12308 L
.40945 .12289 L
.41087 .12275 L
.41217 .12266 L
.41339 .12261 L
.41409 .1226 L
.41474 .1226 L
.41605 .12264 L
.41678 .12269 L
.41745 .12274 L
.41863 .12286 L
.41992 .12302 L
.42225 .12339 L
.42676 .12419 L
.428 .12438 L
.4293 .12456 L
.43041 .12467 L
.43163 .12476 L
.43233 .12479 L
.43297 .1248 L
.43371 .1248 L
.4344 .12478 L
.43564 .12472 L
.43633 .12465 L
.43698 .12459 L
.43942 .12422 L
.442 .12371 L
Mistroke
.44447 .12317 L
.44682 .1227 L
.44811 .12249 L
.44879 .12239 L
.44952 .12231 L
.4508 .1222 L
.45199 .12216 L
.45273 .12216 L
.45353 .12218 L
.45428 .12223 L
.45498 .12229 L
.45629 .12246 L
.45768 .1227 L
.463 .12403 L
.46555 .12468 L
.4668 .12495 L
.46796 .12516 L
.46901 .1253 L
.47013 .1254 L
.47125 .12544 L
.47249 .12541 L
.4738 .1253 L
.47501 .12511 L
.47634 .12484 L
.47773 .12447 L
.48265 .12281 L
.48485 .12209 L
.48605 .12176 L
.48719 .1215 L
.48825 .12131 L
.4894 .12119 L
.49045 .12115 L
.49141 .12118 L
.49256 .1213 L
.49363 .1215 L
.4948 .1218 L
.49607 .12222 L
.50099 .12447 L
.50336 .12563 L
.50461 .12617 L
.50593 .12664 L
.50708 .12696 L
.50834 .12719 L
.50949 .12726 L
.51057 .1272 L
.51126 .12709 L
.51192 .12695 L
.51315 .12655 L
.51447 .12594 L
.51591 .12508 L
Mistroke
.52075 .12122 L
.52357 .11891 L
.52512 .11789 L
.52587 .11749 L
.52656 .11719 L
.52779 .11686 L
.52847 .1168 L
.52912 .11683 L
.52981 .11697 L
.53046 .1172 L
.53117 .11757 L
.53193 .11812 L
.53327 .11946 L
.53473 .12149 L
.5361 .12396 L
.53736 .12672 L
.54229 .14145 L
.54711 .16007 L
.55229 .18048 L
.5548 .18913 L
.55717 .19602 L
.55931 .20091 L
.5605 .20309 L
.56163 .20474 L
.56279 .20608 L
.56408 .20711 L
.56534 .20769 L
.56604 .20785 L
.56669 .20789 L
.56778 .20776 L
.56897 .20737 L
.57021 .20671 L
.57137 .20593 L
.5765 .20152 L
.57921 .19936 L
.58068 .19843 L
.58141 .19805 L
.58207 .19775 L
.58332 .19731 L
.58402 .19715 L
.58467 .19705 L
.58538 .197 L
.58604 .197 L
.58677 .19705 L
.58754 .19716 L
.58819 .19731 L
.5889 .1975 L
.59019 .19796 L
.59258 .19907 L
.59742 .20161 L
Mistroke
.59985 .20263 L
.60051 .20286 L
.60123 .20306 L
.60252 .20334 L
.60376 .2035 L
.60447 .20353 L
.60512 .20353 L
.60631 .20345 L
.60758 .20326 L
.60872 .203 L
.60978 .2027 L
.6122 .20187 L
.61443 .20101 L
.61681 .20013 L
.61797 .19976 L
.61906 .19945 L
.62005 .19922 L
.6211 .19903 L
.62228 .19889 L
.62336 .19882 L
.62453 .19883 L
.62581 .19892 L
.62709 .1991 L
.62781 .19923 L
.62847 .19937 L
.63095 .20001 L
.63591 .20147 L
.63727 .20181 L
.63872 .20211 L
.63995 .20231 L
.64065 .20239 L
.64131 .20245 L
.64247 .2025 L
.6437 .20249 L
.64474 .20243 L
.64588 .20232 L
.64712 .20214 L
.64844 .2019 L
.65082 .20137 L
.65519 .20033 L
.6574 .19991 L
.65865 .19974 L
.65983 .19962 L
.66051 .19957 L
.66117 .19954 L
.66239 .19953 L
.66371 .19957 L
.66445 .19962 L
.66514 .19968 L
.66639 .19982 L
Mistroke
.66752 .19998 L
.67005 .20041 L
.67264 .20089 L
.67538 .20134 L
.67681 .20153 L
.67838 .2017 L
.67907 .20176 L
.67981 .20181 L
.68114 .20187 L
.68179 .2019 L
.68247 .20191 L
.68323 .20192 L
.68393 .20193 L
.68458 .20194 L
.68529 .20194 L
.68657 .20195 L
.68779 .20198 L
.68892 .20203 L
.69018 .20212 L
.69082 .20218 L
.69151 .20227 L
.69279 .20249 L
.69396 .20276 L
.6953 .20315 L
.69657 .20362 L
.69883 .20469 L
.70128 .20618 L
.74221 .23339 L
.78162 .25921 L
.81951 .28371 L
.85986 .31027 L
.87844 .32361 L
.88087 .32413 L
.8835 .32464 L
.8847 .32491 L
.88597 .32525 L
.88825 .3261 L
.8896 .32679 L
.89087 .32758 L
.89373 .32996 L
.89613 .33255 L
.89869 .33586 L
.90445 .34399 L
.90696 .34705 L
.90828 .34834 L
.909 .34893 L
.90968 .3494 L
.91098 .35002 L
.91167 .3502 L
.91241 .35027 L
Mistroke
.91372 .35006 L
.91492 .34946 L
.91613 .34845 L
.91682 .3477 L
.91746 .34688 L
.91987 .34277 L
.9225 .33661 L
.92497 .32947 L
.9296 .31412 L
.93455 .29812 L
.93717 .29117 L
.93861 .28804 L
.93998 .28561 L
.94116 .28395 L
.94245 .28262 L
.94363 .28186 L
.94472 .28152 L
.94573 .28152 L
.94686 .28186 L
.94804 .28258 L
.94914 .28355 L
.95157 .28655 L
.9538 .29006 L
.95883 .29886 L
.96287 .30488 L
.96397 .30617 L
.96516 .30733 L
.96626 .30822 L
.96729 .30887 L
.96844 .3094 L
.96968 .30975 L
.97078 .30989 L
.97195 .30989 L
.97299 .30977 L
.97397 .30959 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`1looooo`;o0000N?ooool002Oooooo00?o0000ooooooooool0
L_ooool3o`0000Kooooo0_l000000ooooooo0000ooooo`1fooooo`009oooool2o`0004Kooooo;_l0
00001?oooooo0000o`000?l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
M?ooool002Oooooo00?o0000ooooooooool0@oooool2o`0003;ooooo0ol00005ooooo`03o`000?oo
oooooooo07Cooooo000Wooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`1dooooo`009oooool00ol0003oooooooooo`10ooooo`;o0000?_ooool00ol0
003oooooooooo`1cooooo`009oooool2o`00043ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`1cooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo
0ol00005ooooo`03o`000?oooooooooo03gooooo0_l00011ooooo`03o`000?oooooooooo07?ooooo
000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool2o`0004Cooooo00?o0000oooo
ooooool0L_ooool000Kooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`1booooo`003Oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`0003Wooooo0_l0
0017ooooo`03o`000?oooooooooo07;ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool0=_ooool2o`0004[ooooo
00?o0000ooooooooool0LOooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo077ooooo000>ooooo`;o00002_ooool2o`0000;ooooo1Ol00004ooooo`03
o`000?oooooooooo03?ooooo0_l0001=ooooo`03o`000?oooooooooo077ooooo000Wooooo`;o0000
<_ooool2o`00053ooooo00?o0000ooooooooool0L?ooool002Oooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo073ooooo000Wooooo`03o`000?oooooo
oooo02kooooo0_l0001Cooooo`03o`000?oooooooooo073ooooo000Wooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1`ooooo`009oooool2o`0002co
oooo0_l0001Fooooo`03o`000?oooooooooo073ooooo000Wooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1`ooooo`009oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Koooool002Oooooo00?o0000
ooooooooool09oooool2o`0005_ooooo00?o0000ooooooooool00oooool4o`0000Gooooo1Ol00005
ooooo`Go0000E?ooool002Oooooo0_l0000Wooooo`03o`000?oooooooooo05cooooo00Go0000oooo
ooooooooooooo`000004ooooo`Ko00001?ooool5o`0000Cooooo1ol0001>ooooo`009oooool00ol0
003oooooooooo`0Tooooo`;o0000Goooool4o`0001oooooo0ol0001;ooooo`009oooool00ol0003o
ooooooooo`0Rooooo`;o0000Qoooool00ol0003oooooooooo`18ooooo`009oooool2o`0002;ooooo
00?o0000ooooooooool0R?ooool2o`0004Sooooo000Wooooo`03o`000?oooooooooo01oooooo0_l0
002=ooooo`03o`000?oooooooooo04Gooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01gooooo0_l0002@
ooooo`03o`000?oooooooooo04Cooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo097ooooo0_l00014ooooo`00
1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o0000U_ooool00ol0
003oooooooooo`11ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0Uoooool2o`00047ooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o0000
1Oooool00ol0003oooooooooo`0Gooooo`;o0000W?ooool2o`0003oooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo
03cooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool2o`0001Ko
oooo00?o0000ooooooooool0X?ooool2o`0003cooooo000Wooooo`03o`000?oooooooooo01?ooooo
0_l0002Uooooo`;o0000>_ooool002Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`2Wooooo`03o`000?oooooooooo03Oooooo000Wooooo`03o`000?oooooooooo013ooooo0_l0002[
ooooo`;o0000=oooool002Oooooo0_l0000@ooooo`03o`000?oooooooooo0:gooooo00?o0000oooo
ooooool0=?ooool002Oooooo00?o0000ooooooooool03Oooool2o`0001Oooooo0_l00004ooooo`04
o`000?ooooooooooooooo`Go00008Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`00
02;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0
003oooooooooo`05o`0002Oooooo0ol00007ooooo`009oooool00ol0003oooooooooo`0;ooooo`;o
00006?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00023ooooo00Co0000
oooooooooooo00002_ooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Oooooo0_l00002oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05
o`000?oooooo0000ooooool000009oooool00ol0003oooooooooo`06ooooo`009oooool2o`0000Wo
oooo0_l0000Kooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0002;ooooo00Co0000oooooooooooo0000
1oooool4o`00027ooooo00Co0000oooooooooooo00002?ooool4o`0002Oooooo00?o0000oooooooo
ool01_ooool002Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo02;ooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooooooool2o`0001oo
oooo0_l00005ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Gooooo
0_l0000Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Poooo
o`04o`000?ooooooooooo`0000Wooooo0_l0000Rooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`06o`000?ooooooooooooooool0
003ooooo0_l0000Looooo`;o000000?oooooo`000?ooool00_ooool2o`0000Sooooo000Wooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool2o`0000Wooooo0ol0000Rooooo`;o
00002oooool00ol0003oooooooooo`0Qooooo`;o00002_ooool2o`0002;ooooo0_l00009ooooo`?o
00001?ooool2o`0001[ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Kooooo000Wooooo`;o00000oooool2o`000<Oooooo00?o0000ooooooooool05oooool01Ol0003o
oooooooooooooooo000000cooooo000Wooooo`05o`000?ooooooooooooooool00000b_ooool2o`00
01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`009oooool01?l0003o
ooooo`000?l0003=ooooo`;o00005?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo000Wooooo`;o0000dOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool0027oooooool0000002Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000
2oooool2o`0000[ooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`3Eooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04Oooool002Oooooo0_l0003Gooooo`?o00002Oooool00ol0
003oooooooooo`0Aooooo`009oooool00ol0003oooooooooo`3Hooooo`?o00001_ooool00ol0003o
ooooooooo`0Booooo`009oooool00ol0003oooooooooo`3Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04_ooool002Oooooo00?o0000ooooooooool0foooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01;ooooo000Wooooo`;o0000g?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01;ooooo000Wooooo`03o`000?oooooooooo0=cooooo00Go0000oooo
ooooooooooooo`00000Eooooo`009oooool00ol0003oooooooooo`3Mooooo`Co00005Oooool002Oo
oooo00?o0000ooooooooool0g_ooool00ol0003oooooooooo`0Eooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool0
m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_oo
ool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo0000
00?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oo
oooooooo0?Kooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool0
0ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oo
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
oooooooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000oooooooo
ool0m_ooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0003gooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`00
00Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oo
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?ooooo
o`000?l000000ol00004ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool001Cooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000C
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3fooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0
003gooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000C
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000
oooooooooooo00002?ooool2o`000?oooooo000Dooooo`;o00002_ooool00ol0003oooooooooo`3m
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28412 L
.10458 .2574 L
.14415 .23188 L
.18221 .20723 L
.22272 .18097 L
.26171 .15561 L
.30316 .12816 L
.32392 .11431 L
.34309 .1015 L
.34772 .0976 L
.35028 .0958 L
.35271 .09445 L
.35496 .09355 L
.35624 .09319 L
.35742 .09295 L
.35852 .0928 L
.35951 .09273 L
.36065 .0927 L
.36173 .09273 L
.36288 .0928 L
.36409 .09291 L
.36625 .09316 L
.36861 .09343 L
.36993 .09355 L
.37114 .09363 L
.37245 .09367 L
.37369 .09367 L
.37483 .09362 L
.37608 .09353 L
.37673 .09346 L
.37744 .09337 L
.37889 .09316 L
.3815 .0927 L
.38405 .09222 L
.38642 .09184 L
.38761 .09169 L
.38889 .09157 L
.38962 .09153 L
.3903 .0915 L
.39159 .0915 L
.39271 .09155 L
.3939 .09164 L
.39492 .09176 L
.39603 .09192 L
.40085 .09288 L
.40351 .09343 L
.40482 .09366 L
.40604 .09383 L
.40677 .09391 L
Mistroke
.40744 .09397 L
.40817 .09402 L
.40896 .09404 L
.40962 .09405 L
.41033 .09404 L
.41162 .09396 L
.41284 .09384 L
.41418 .09364 L
.41687 .09311 L
.4217 .092 L
.42292 .09176 L
.42422 .09154 L
.4249 .09145 L
.42565 .09136 L
.42696 .09127 L
.4282 .09124 L
.42889 .09125 L
.42953 .09128 L
.4307 .09138 L
.43193 .09154 L
.43305 .09173 L
.43424 .09197 L
.43639 .09248 L
.43892 .09313 L
.44125 .09367 L
.44254 .09392 L
.44396 .09413 L
.4447 .09421 L
.44539 .09426 L
.44612 .09429 L
.4469 .0943 L
.44758 .09429 L
.44833 .09424 L
.44903 .09418 L
.44968 .09411 L
.45091 .09392 L
.45222 .09366 L
.45741 .09229 L
.45969 .0917 L
.46089 .09143 L
.46218 .09121 L
.46341 .09105 L
.46454 .09097 L
.46567 .09096 L
.46673 .091 L
.46793 .09111 L
.46904 .09127 L
.47025 .09151 L
.47153 .09182 L
.47675 .09338 L
Mistroke
.47805 .09375 L
.47929 .09406 L
.4805 .09431 L
.48163 .09449 L
.4826 .09459 L
.48363 .09465 L
.48478 .09464 L
.48582 .09457 L
.48693 .09443 L
.48814 .0942 L
.49032 .09364 L
.49528 .09197 L
.49769 .09122 L
.49884 .09094 L
.4999 .09074 L
.50103 .09058 L
.50226 .0905 L
.50334 .09051 L
.50449 .09059 L
.5057 .09077 L
.50683 .09102 L
.50941 .09181 L
.51207 .09285 L
.51486 .09395 L
.51724 .09472 L
.5179 .09489 L
.51859 .09504 L
.51985 .09523 L
.52116 .0953 L
.5219 .09529 L
.52259 .09525 L
.52384 .09507 L
.52447 .09494 L
.52517 .09476 L
.52766 .09388 L
.52999 .09281 L
.5327 .0915 L
.53526 .0904 L
.53668 .08994 L
.53748 .08974 L
.53822 .08961 L
.53953 .08948 L
.54026 .08948 L
.54092 .08953 L
.54213 .08971 L
.54326 .09001 L
.54449 .09047 L
.54582 .09108 L
.55098 .09424 L
.55347 .0957 L
Mistroke
.55469 .09628 L
.55582 .0967 L
.55684 .09697 L
.55793 .09711 L
.55902 .0971 L
.56022 .09691 L
.56088 .09672 L
.56161 .09644 L
.56293 .09575 L
.56421 .09488 L
.5654 .09392 L
.56833 .09111 L
.57098 .08846 L
.57218 .08738 L
.57349 .08638 L
.57472 .08567 L
.57586 .08526 L
.57706 .08514 L
.57775 .08523 L
.57839 .08543 L
.57968 .08618 L
.5804 .08683 L
.58106 .08755 L
.58224 .08919 L
.58334 .09114 L
.58586 .09704 L
.58832 .10458 L
.59097 .11431 L
.60013 .15165 L
.60287 .16083 L
.60541 .16759 L
.6068 .17047 L
.60806 .17257 L
.60946 .17433 L
.61023 .17505 L
.61096 .17558 L
.61217 .17613 L
.61344 .17632 L
.61453 .17621 L
.61573 .17582 L
.61701 .17515 L
.61839 .17422 L
.62089 .17219 L
.62344 .17007 L
.62483 .16902 L
.62614 .16817 L
.62737 .16751 L
.62802 .16723 L
.6287 .16698 L
.62991 .16668 L
Mistroke
.63102 .16655 L
.63233 .16658 L
.63307 .16668 L
.63374 .16682 L
.63505 .16722 L
.63628 .16774 L
.63905 .16927 L
.64206 .17125 L
.66216 .18154 L
.70298 .2082 L
.74228 .23422 L
.78007 .25913 L
.82032 .28687 L
.82253 .28901 L
.82492 .29096 L
.82602 .29171 L
.82719 .29238 L
.82819 .29287 L
.82927 .29329 L
.8305 .29367 L
.83166 .29392 L
.83236 .29403 L
.83303 .29411 L
.83428 .29422 L
.83648 .29434 L
.83759 .29441 L
.83882 .29454 L
.83947 .29464 L
.84017 .29478 L
.84143 .29513 L
.84269 .29563 L
.84384 .29625 L
.84511 .29712 L
.8465 .2983 L
.8493 .30146 L
.8544 .30916 L
.85905 .3163 L
.86028 .31783 L
.86163 .31919 L
.8629 .32011 L
.86407 .32061 L
.86531 .32072 L
.86601 .32059 L
.86667 .32032 L
.86737 .31989 L
.868 .31937 L
.86944 .31771 L
.87067 .31575 L
.87181 .31353 L
.8744 .30711 L
Mistroke
.87912 .29185 L
.88438 .27344 L
.88696 .26557 L
.88933 .25966 L
.89064 .25707 L
.89208 .25482 L
.89277 .25396 L
.89352 .25321 L
.89431 .25259 L
.89505 .25219 L
.89571 .25197 L
.89644 .25187 L
.89776 .25205 L
.89904 .25264 L
.90022 .25352 L
.9395 .28393 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0ROooool2o`0006_ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0Ooooool3
o`0000Kooooo00?o0000ooooool00000Joooool000Sooooo0_l0000:ooooo`;o00000_ooool5o`00
0003ooooool0003o000000?o00001?ooool2o`0005;ooooo8?l00002ooooo`Oo00000oooool3o`00
0003ooooool0003o000000?ooooo0_l00003ooooo`03o`000?oooooooooo06Sooooo000Wooooo`03
o`000?oooooooooo04oooooo0_l0000Gooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`?o
00001_ooool4o`0000Cooooo00?o0000ooooooooool0J?ooool002Oooooo00?o0000ooooooooool0
COooool2o`0003cooooo00?o0000ooooooooool0J?ooool002Oooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo06Oooooo000Wooooo`;o0000C?ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Oooooo000Wooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Vooooo`009oooool00ol0003o
ooooooooo`18ooooo`;o0000@oooool00ol0003oooooooooo`1Vooooo`009oooool00ol0003ooooo
ooooo`16ooooo`;o0000AOooool00ol0003oooooooooo`1Vooooo`009oooool2o`0004Kooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`1Vooooo`009oooool00ol0003oooooooooo`13
ooooo`;o0000BOooool00ol0003oooooooooo`1Uooooo`009oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0IOooool002Oooooo00?o0000oooooooo
ool0@?ooool2o`0004cooooo00?o0000ooooooooool0IOooool002Oooooo0_l0000oooooo`;o0000
C_ooool00ol0003oooooooooo`1Uooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`1Uooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_o
oooo0_l0001Booooo`03o`000?oooooooooo06Cooooo0006ooooo`Go00000_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0I?ooool000go
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo00;ooooo0_l0000iooooo`;o0000EOooool00ol0003oooooooooo`1Tooooo`003Oooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Sooooo`003Oooool0
1?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003o
ooooooooo`0eooooo`;o0000FOooool00ol0003oooooooooo`1Sooooo`003_ooool2o`0000[ooooo
0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool00_ooool4o`0005gooooo000Wooooo`;o0000=?ooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo00;o00000oooool3o`0005[ooooo000Wooooo`03o`000?oooooo
oooo037ooooo0_l0001Nooooo`Co00001oooool2o`0005Sooooo000Wooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1Eooooo`009oooool00ol0003o
ooooooooo`0^ooooo`;o0000Koooool2o`0005Gooooo000Wooooo`;o0000;Oooool2o`0007?ooooo
0_l0001Cooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07Gooooo00?o
0000ooooooooool0D?ooool002Oooooo00?o0000ooooooooool0:Oooool2o`0007Wooooo0_l0001@
ooooo`009oooool00ol0003oooooooooo`0Wooooo`;o0000OOooool2o`0004kooooo000Wooooo`;o
00009oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo04_ooooo000Wooooo`03o`00
0?oooooooooo02Cooooo0_l00023ooooo`;o0000Boooool002Oooooo00?o0000ooooooooool08_oo
ool2o`0008Oooooo00?o0000ooooooooool0B?ooool002Oooooo0_l0000Rooooo`03o`000?oooooo
oooo08Sooooo0_l00018ooooo`009oooool00ol0003oooooooooo`0Oooooo`;o0000SOooool00ol0
003oooooooooo`15ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;o
oooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`0Mooooo`;o0000T?ooool00ol0003o
ooooooooo`14ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`2Aooooo`;o0000A?ooool000Go00000_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`;o00006oooool2o`0009Kooooo00?o0000ooooooooool0
@Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo09Oooooo0_l00011ooooo`001oooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000
ooooooooool05oooool2o`0009cooooo0_l0000oooooo`001oooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0looooo`002?oo
ool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo0_l0000Fooooo`03o`000?oo
oooooooo0:3ooooo0_l0000looooo`009oooool00ol0003oooooooooo`0Cooooo`;o0000YOooool2
o`0003[ooooo000Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Yoooool00ol0
003oooooooooo`0Jooooo`Co00006Oooool002Oooooo00?o0000ooooooooool04?ooool2o`000:_o
oooo0_l0000Iooooo`;o00000oooool00ol0003oooooooooo`0Fooooo`009oooool2o`00013ooooo
00?o0000ooooooooool0[Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool03Oooool2o`0001Oooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`Go00008Oooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Rooooo`;o0000
1?ooool00ol0003oooooooooo`05o`0001?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`?o00001oooool002Oooooo00?o0000ooooooooool02oooool2o`0001Sooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000008?ooool01?l0003oooooooooool00007ooooo`;o00000_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Gooooo0_l0000;ooooo`03o`000?oooooooooo00Kooooo
000Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00027o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000
oooooooooooo00001oooool01Ol0003oooooo`000?oooooo0000017ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o00002Ooo
ool2o`0001_ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool00007
ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`Co00004Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
00008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooooooool2o`00013ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooo
oooo00Gooooo0_l0000Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000Pooooo`04o`000?ooooooooooo`0000Wooooo0_l0000Rooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`07o`000?oooooo
ooooooooool0003oooooo`00000>ooooo`03o`000?oooooooooo00cooooo0_l00005ooooo`;o0000
2?ooool002Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`;o00002Ooo
ool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0000:ooooo`;o00008_oo
ool2o`0000Wooooo0ol00002ooooo`;o00003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01_ooool002Oooooo0_l00003ooooo`;o0000a?ooool5
o`0000Wooooo00?o0000ooooooooool03oooool2o`0000cooooo000Wooooo`05o`000?oooooooooo
ooooool00000b_ooool3o`0000Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09
ooooo`009oooool01?l0003oooooo`000?l0003=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool04_ooool2o`0000Wooooo000Wooooo`;o0000d?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool0027oooooool0000002Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013o
oooo00Co0000ooooool0003o00006Oooool00ol0003oooooooooo`05ooooo`009oooool00ol0003o
ooooooooo`3Aooooo`?o00008_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooooooo
o`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`3foooo
o`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000moooool000Oooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol0
0005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000oooooooo
ool0m_ooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool0
02Oooooo00?o0000ooooooooool0m_ooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000moooool000gooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
ooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`3f
ooooo`003_ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool2o`000?Oooooo000Wooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0
003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo0008ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Ooo
ool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000moooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooo000000?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo0?Kooooo0008ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000
o`000003o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`005?ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0m_ooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`000?Oo
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003ooooo
ooooool00008ooooo`;o0000ooooool001Cooooo0_l0000:ooooo`03o`000?oooooooooo0?gooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28397 L
.10458 .25677 L
.14415 .23114 L
.18221 .20645 L
.22272 .18022 L
.26171 .15496 L
.30316 .12805 L
.34309 .10211 L
.3815 .07722 L
.39174 .06948 L
.39675 .0663 L
.40134 .06415 L
.40381 .06333 L
.40616 .06275 L
.40744 .06251 L
.40864 .06232 L
.40995 .06216 L
.41134 .06203 L
.41277 .06194 L
.41432 .06186 L
.41578 .06181 L
.41712 .06177 L
.42237 .06167 L
.42706 .06158 L
.42842 .06155 L
.4297 .06154 L
.43085 .06153 L
.4321 .06152 L
.43319 .06153 L
.43439 .06154 L
.43564 .06156 L
.43682 .0616 L
.43892 .06167 L
.44119 .06178 L
.44644 .06207 L
.44772 .06212 L
.44908 .06217 L
.44987 .06219 L
.45058 .0622 L
.45129 .06221 L
.45197 .06221 L
.45317 .06221 L
.45444 .06218 L
.45552 .06215 L
.45671 .0621 L
.45937 .06194 L
.46185 .06176 L
.46426 .06157 L
.46683 .06141 L
Mistroke
.46759 .06137 L
.46831 .06134 L
.46901 .06132 L
.46965 .0613 L
.4709 .06128 L
.47156 .06128 L
.47226 .06129 L
.47344 .06131 L
.4747 .06136 L
.47589 .06143 L
.47697 .0615 L
.48214 .06197 L
.48436 .06217 L
.48557 .06226 L
.48671 .06233 L
.48793 .0624 L
.48858 .06242 L
.48928 .06244 L
.49053 .06245 L
.49167 .06243 L
.49275 .0624 L
.49377 .06235 L
.49487 .06227 L
.49606 .06217 L
.50068 .06167 L
.50328 .06138 L
.5047 .06124 L
.50602 .06114 L
.50716 .06107 L
.50837 .06103 L
.50906 .06102 L
.50972 .06102 L
.51095 .06104 L
.51158 .06106 L
.51229 .0611 L
.51371 .06121 L
.51503 .06134 L
.51627 .06149 L
.51909 .06188 L
.52206 .0623 L
.52448 .06258 L
.52514 .06264 L
.52585 .06269 L
.52712 .06276 L
.52837 .06278 L
.52955 .06277 L
.53061 .06272 L
.53176 .06264 L
.53302 .06251 L
.53441 .06233 L
Mistroke
.53721 .06186 L
.53981 .06139 L
.54223 .06099 L
.54353 .06081 L
.54472 .06068 L
.54603 .06059 L
.54675 .06056 L
.54743 .06055 L
.54867 .06058 L
.54981 .06064 L
.55105 .06077 L
.55237 .06096 L
.55466 .06139 L
.5568 .06188 L
.55912 .06244 L
.56165 .06299 L
.56306 .06322 L
.56436 .06338 L
.5656 .06346 L
.56693 .06348 L
.5681 .06342 L
.56921 .0633 L
.57042 .06311 L
.57173 .06283 L
.57733 .06108 L
.58006 .06019 L
.58125 .05987 L
.58253 .0596 L
.58378 .05943 L
.58492 .05936 L
.58601 .05938 L
.58717 .05951 L
.58839 .05977 L
.58952 .06012 L
.59077 .06064 L
.59212 .06133 L
.59759 .06528 L
.60259 .06932 L
.6051 .07099 L
.60648 .07172 L
.60777 .07227 L
.60851 .07253 L
.60931 .07275 L
.61004 .07291 L
.6107 .07301 L
.61203 .07313 L
.61269 .07315 L
.61342 .07315 L
.61411 .07312 L
.61476 .07308 L
Mistroke
.61599 .07298 L
.61731 .07288 L
.61805 .07285 L
.61874 .07284 L
.61988 .0729 L
.62114 .07311 L
.62246 .07354 L
.62369 .07419 L
.62494 .07513 L
.62627 .0765 L
.62752 .07817 L
.62865 .08004 L
.63144 .08611 L
.63407 .09382 L
.63881 .11205 L
.64393 .13557 L
.64862 .15683 L
.65118 .167 L
.65358 .17505 L
.65579 .18105 L
.65781 .18523 L
.65896 .18707 L
.66005 .18846 L
.6612 .18957 L
.66245 .19041 L
.70322 .21225 L
.74248 .23685 L
.78022 .26184 L
.78153 .26213 L
.78277 .26228 L
.78346 .26233 L
.7842 .26235 L
.7855 .26235 L
.78675 .26233 L
.78807 .26232 L
.78919 .26236 L
.79043 .26248 L
.79171 .26273 L
.79242 .26293 L
.79308 .26316 L
.79435 .26375 L
.79556 .26449 L
.79825 .26682 L
.80118 .27041 L
.80638 .27857 L
.80893 .28264 L
.81127 .2859 L
.81237 .28717 L
.81341 .28815 L
.81448 .28893 L
Mistroke
.81566 .28947 L
.81686 .28965 L
.81795 .28947 L
.81921 .28883 L
.82041 .28779 L
.82158 .28635 L
.82283 .28437 L
.82506 .27974 L
.83012 .26517 L
.83546 .24719 L
.83808 .239 L
.84047 .23252 L
.84255 .22796 L
.84473 .2244 L
.84587 .22308 L
.84693 .22218 L
.84809 .22156 L
.84932 .22129 L
.85059 .22142 L
.8513 .22166 L
.85196 .22198 L
.85316 .22281 L
.85444 .22397 L
.85908 .22986 L
.86394 .23679 L
.86632 .23978 L
.86854 .2421 L
.87108 .24416 L
.87242 .24499 L
.87384 .2457 L
.87614 .24652 L
.87745 .24686 L
.87869 .24712 L
.88298 .24798 L
.88514 .24857 L
.8875 .24949 L
.89007 .25088 L
.89246 .25255 L
.89701 .25651 L
.93601 .28244 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000GooooolOo`000003ooooool0003o
000000Ko00000oooool5o`0006Sooooo000Wooooo`03o`000?oooooooooo05_ooooo1?l0000Moooo
o`;o00001oooool4o`0000Gooooo0_l0001Vooooo`002?ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool0FOooool2o`0003Gooooo00?o0000ooooooooool0Hoooool000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0=Oooool6
o`00063ooooo0005o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0005Oooooo0_l0
000mooooo`;o0000Goooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0GOooool000Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o
00001Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0G?ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`1Booooo`;o0000@oooool0
0ol0003oooooooooo`1Looooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`00
0?l000000ol00004ooooo`;o0000D_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
05_ooooo000Wooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`1Kooooo`009oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0Foooool002Oooooo00?o0000ooooooooool0COooool2o`0004[ooooo00?o
0000ooooooooool0F_ooool002Oooooo0_l0001<ooooo`;o0000C?ooool00ol0003oooooooooo`1J
ooooo`009oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0F_ooool002Oooooo00?o0000ooooooooool0B?ooool2o`0004oooooo00?o0000oooooooo
ool0F_ooool002Oooooo00?o0000ooooooooool0A_ooool2o`00057ooooo00?o0000ooooooooool0
F_ooool002Oooooo0_l00016ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0F_oo
ool002Oooooo00?o0000ooooooooool0@oooool2o`0005Gooooo00?o0000ooooooooool0FOooool0
02Oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
05Wooooo000Wooooo`03o`000?oooooooooo043ooooo0_l0001Hooooo`03o`000?oooooooooo05Wo
oooo000Wooooo`;o0000?oooool2o`0005[ooooo00?o0000ooooooooool0FOooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0FOooool000gooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0kooooo`;o0000G_ooool00ol0003oooooooooo`1Hooooo`00
1_ooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo05Sooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000>Oooool2o`00067ooooo00?o0000
ooooooooool0F?ooool000gooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0
003ooooo00Co00001Oooool00ol0003oooooooooo`0fooooo`;o0000Hoooool00ol0003ooooooooo
o`1Hooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00002?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0Eoooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo00?o0000ooooooooool0
<oooool2o`0006Oooooo00?o0000ooooooooool0Eoooool002Oooooo0_l0000booooo`;o0000JOoo
ool00ol0003oooooooooo`1Gooooo`009oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool0E_ooool002Oooooo00?o0000ooooooooool0;_ooool2o`00
06gooooo00?o0000ooooooooool0E_ooool002Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo05Kooooo000Wooooo`;o0000;?ooool2o`00077ooooo
00?o0000ooooooooool0EOooool002Oooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`1aooooo`?o0000EOooool002Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1e
ooooo`;o0000Doooool002Oooooo00?o0000ooooooooool09oooool2o`0007[ooooo0_l0001Aoooo
o`009oooool2o`0002Oooooo00?o0000ooooooooool0O?ooool2o`0004oooooo000Wooooo`03o`00
0?oooooooooo02Cooooo0_l00021ooooo`;o0000COooool002Oooooo00?o0000ooooooooool08_oo
ool2o`0008Gooooo0_l0001;ooooo`009oooool2o`0002;ooooo00?o0000ooooooooool0Qoooool0
0ol0003oooooooooo`18ooooo`009oooool00ol0003oooooooooo`0Oooooo`;o0000Roooool2o`00
04Sooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;o
oooo0ol00005ooooo`03o`000?oooooooooo01gooooo0_l0002?ooooo`03o`000?oooooooooo01co
oooo1?l0000Uooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01_ooooo00Co
0000oooooooooooo00009Oooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o
00006oooool2o`0009Cooooo0_l0000Kooooo`05o`000?ooooooooooooooool000009?ooool000Oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo09Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02;ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`0Gooooo`;o0000
V_ooool2o`0001Kooooo00?o0000ooooooooool01?ooool2o`0002;ooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Looooo`;o00005?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo0008ooooo`;o00002_ooool2o`0000?o
oooo0ol00002ooooo`Go00001?ooool2o`0001Kooooo00?o0000ooooooooool0Woooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo0ol0000Oooooo`009oooool00ol0003ooooo
ooooo`0Cooooo`;o0000Xoooool2o`00017ooooo00?o0000ooooooooool02Oooool3o`0001cooooo
000Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0YOooool2o`0000kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`009oooool00ol0003oooooooooo`0@
ooooo`;o0000Z_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo0_l0000J
ooooo`009oooool2o`00013ooooo00?o0000ooooooooool0Zoooool4o`0000Wooooo00?o0000oooo
ooooool03oooool2o`0001Sooooo000Wooooo`03o`000?oooooooooo00gooooo0_l0000Gooooo`;o
00001?ooool01?l0003oooooooooooooool5o`00027ooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00008_ooool2o`00
00Cooooo00?o0000ooooooooool01Ol00004ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo00_ooooo0_l0000Hooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool0
000:ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo0000023ooooo00Co0000oooooooooooo00001oooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`00000Eooooo`;o00003?ooool00ol0003oooooooooo`06ooooo`009oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000Oooooo1Ol0000Qooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`00
00Oooooo0_l00002ooooo`05o`000?ooooooooooooooool000005oooool2o`0000[ooooo00?o0000
ooooooooool01_ooool002Oooooo0_l00009ooooo`;o00006oooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool0000Rooooo`04o`000?ooooooooooo`0000Oooooo1?l0000Qooooo`04o`000?ooooooooooo`00
00Sooooo0ol00003ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00000Rooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool08_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;o
00000_ooool00ol0003oooooooooo`0Iooooo`;o00001oooool00ol0003oooooooooo`06ooooo`00
9oooool00ol0003oooooooooo`05ooooo`;o00007_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000
1oooool01_l0003ooooooooooooooooo0000ooooo`;o00007Oooool00ol0003oooooooooo`03oooo
o`;o00002?ooool002Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`;o
00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0000:ooooo`;o
00008_ooool2o`0000Wooooo1_l0000Oooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0000?ooooo0_l0003Uooooo`03o`000?oooooooooo00[ooooo000Wooooo`05o`000?oo
ooooooooooooool00000j?ooool00ol0003oooooooooo`09ooooo`009oooool01?l0003oooooo`00
0?l0003Zooooo`;o00002Oooool002Oooooo0_l0003^ooooo`03o`000?oooooooooo00Kooooo000Q
oooooooo0000000Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0
003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003goooo
o`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o
00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o
0000moooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo0?Kooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool0m_ooool000Sooooo0_l0000:ooooo`;o00000ooo
ool3o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool000kooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooo
ooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02
ooooo`;o0000moooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000
oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003ooooo
ooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00002?ooool00ol0003oooooooooo`3fooooo`003_ooool2o`0000[ooooo0_l00002ooooo`Go
00001?ooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`;o0000moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`3f
ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0?Kooooo0008ooooo`;o00002_oo
ool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oo
oooo0_l0003gooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo
00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool01?ooool2o`000?Oooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`3mooooo`004oooool01?l0003oooooooooool00008ooooo`;o0000ooooool001Cooooo0_l0
000:ooooo`03o`000?oooooooooo0?gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28378 L
.10458 .25582 L
.14415 .22998 L
.18221 .20524 L
.22272 .17891 L
.26171 .15365 L
.30316 .12721 L
.34309 .10173 L
.3815 .07699 L
.42237 .0513 L
.43215 .04509 L
.43755 .04025 L
.44268 .03579 L
.44498 .03414 L
.44744 .03274 L
.44885 .03213 L
.45013 .03169 L
.45141 .03136 L
.45262 .03116 L
.45373 .03105 L
.4549 .031 L
.4559 .03101 L
.45699 .03107 L
.45817 .03118 L
.45943 .03132 L
.46172 .0316 L
.46294 .03175 L
.46425 .03187 L
.46536 .03195 L
.46658 .032 L
.4679 .032 L
.46864 .03197 L
.46932 .03193 L
.47056 .03182 L
.47188 .03166 L
.47426 .03125 L
.47648 .03079 L
.47906 .03025 L
.48034 .03002 L
.48151 .02984 L
.48257 .0297 L
.4837 .0296 L
.48483 .02954 L
.48608 .02954 L
.48711 .02958 L
.48822 .02967 L
.48927 .0298 L
.49023 .02994 L
.49501 .03098 L
Mistroke
.49719 .03149 L
.49955 .03197 L
.50091 .03218 L
.50215 .03232 L
.50334 .03239 L
.5046 .03241 L
.50572 .03237 L
.50677 .03228 L
.50793 .03214 L
.50916 .03193 L
.51442 .03068 L
.51701 .03005 L
.51814 .02981 L
.5194 .02959 L
.52055 .02943 L
.52164 .02933 L
.52278 .02928 L
.52401 .02928 L
.52529 .02936 L
.52593 .02942 L
.52663 .02951 L
.52787 .02971 L
.52903 .02994 L
.53359 .03109 L
.5378 .03212 L
.54026 .03256 L
.5415 .03273 L
.54286 .03286 L
.54358 .03291 L
.54423 .03294 L
.5457 .03301 L
.54707 .03305 L
.54835 .03308 L
.54953 .03314 L
.55079 .03323 L
.55206 .03337 L
.55278 .03348 L
.55345 .0336 L
.55467 .03389 L
.55578 .03424 L
.55829 .03535 L
.56053 .03673 L
.56262 .03835 L
.56735 .04295 L
.57231 .04824 L
.57689 .05241 L
.57934 .05408 L
.58193 .05537 L
.58328 .05587 L
.58454 .05625 L
Mistroke
.5874 .05689 L
.58985 .05737 L
.59218 .05794 L
.59347 .05836 L
.59487 .05894 L
.59733 .06029 L
.59977 .06212 L
.60199 .06417 L
.60696 .06968 L
.61123 .07447 L
.61349 .07664 L
.61591 .07852 L
.61723 .07932 L
.61843 .0799 L
.61964 .08036 L
.62079 .08067 L
.62207 .08092 L
.62326 .08106 L
.62456 .08115 L
.62522 .08117 L
.62594 .0812 L
.62714 .08125 L
.62823 .08132 L
.62944 .08146 L
.6307 .0817 L
.63181 .08201 L
.63284 .0824 L
.63396 .08296 L
.63517 .08371 L
.63786 .086 L
.64078 .08935 L
.64608 .09673 L
.64859 .10012 L
.65124 .10312 L
.65233 .10409 L
.6535 .10495 L
.65479 .10564 L
.65599 .10605 L
.65668 .10618 L
.65733 .10623 L
.65854 .10617 L
.65985 .10588 L
.66058 .10563 L
.66126 .10536 L
.66378 .1041 L
.66613 .10292 L
.66737 .10245 L
.66807 .10227 L
.6687 .10217 L
.66939 .10214 L
Mistroke
.67015 .10221 L
.67086 .10239 L
.67151 .10267 L
.67282 .10357 L
.67357 .10431 L
.67426 .10515 L
.67567 .10732 L
.67718 .11041 L
.67976 .11744 L
.68256 .12752 L
.68768 .15056 L
.6923 .17295 L
.69729 .19412 L
.70005 .20313 L
.7026 .20942 L
.70503 .21366 L
.70626 .21521 L
.7076 .2165 L
.70882 .21736 L
.70994 .21793 L
.71122 .21838 L
.71244 .21865 L
.71356 .21882 L
.7146 .21893 L
.71583 .21905 L
.71695 .21917 L
.71815 .21936 L
.71945 .21965 L
.72059 .21999 L
.72179 .22045 L
.72433 .22179 L
.72712 .22373 L
.73792 .2319 L
.74276 .23419 L
.74531 .2352 L
.748 .23641 L
.75036 .23778 L
.75296 .23979 L
.75752 .24474 L
.76026 .24832 L
.76319 .25218 L
.76461 .25386 L
.76596 .25524 L
.76718 .25624 L
.7685 .25701 L
.76981 .25739 L
.771 .25736 L
.77166 .25718 L
.77238 .25684 L
.77367 .25584 L
Mistroke
.77489 .25443 L
.77617 .25245 L
.77847 .24768 L
.78797 .21695 L
.79047 .20846 L
.79319 .20044 L
.79444 .19736 L
.79576 .19458 L
.79691 .1926 L
.79814 .19095 L
.79937 .18979 L
.8005 .18916 L
.80157 .18893 L
.80271 .18906 L
.80395 .18963 L
.80511 .1905 L
.80638 .1918 L
.80774 .19352 L
.81199 .20016 L
.81648 .20727 L
.81903 .2105 L
.82038 .21189 L
.82183 .21309 L
.82316 .21396 L
.82437 .21456 L
.82559 .21499 L
.82675 .21528 L
.82738 .21539 L
.82808 .21548 L
.82882 .21554 L
.82951 .21559 L
.83074 .21564 L
.83143 .21566 L
.83207 .21568 L
.83277 .21572 L
.83354 .21577 L
.83429 .21585 L
.83509 .21597 L
.83583 .21611 L
.83654 .21629 L
.83786 .21671 L
.83902 .21721 L
.8403 .2179 L
.84289 .21973 L
.84753 .22418 L
.85291 .22995 L
.85556 .2325 L
.85802 .2345 L
.86056 .23615 L
.86287 .2373 L
Mistroke
.86543 .23828 L
.86816 .23915 L
.87051 .23989 L
.87299 .24083 L
.87744 .24317 L
.8799 .24491 L
.8826 .24713 L
.88819 .25222 L
.89832 .25979 L
.93875 .2851 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0001[ooooo`;o00001?ooool5o`0000Cooooo1_l0001gooooo`00
9oooool00ol0003oooooooooo`1Xooooo`;o000000?oooooo`000?l000000ol00005ooooo`Co0000
1_ooool6o`00077ooooo000Wooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool06_oo
ool3o`0006oooooo000Wooooo`03o`000?oooooooooo06Gooooo0_l0000Pooooo`03o`000?oooooo
oooo06cooooo000Wooooo`;o0000IOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
06cooooo000Wooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`1[ooooo`009oooool00ol0003oooooooooo`1Qooooo`;o00009_ooool2o`0006_ooooo
000Wooooo`03o`000?oooooooooo05oooooo0_l0000Yooooo`Co0000J?ooool002Oooooo0_l0001N
ooooo`;o0000;oooool2o`0006Kooooo000Wooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool0<?ooool2o`0006Gooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1Jooooo`;o
0000=Oooool00ol0003oooooooooo`1Rooooo`001oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0F?ooool2o`0003Sooooo00?o0000ooooooooool0HOooool0
00Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000Eoooool2o`0003[ooooo00?o
0000ooooooooool0HOooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo03_ooooo1Ol0001Nooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005ooooo`03
o`000?oooooooooo05?ooooo0_l00013ooooo`;o0000G?ooool000Oooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0F_ooool0
00Sooooo0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?ooool2o`00
057ooooo0_l00018ooooo`03o`000?oooooooooo05Wooooo000Wooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Hooooo`009oooool00ol0003ooooo
ooooo`1=ooooo`;o0000C?ooool00ol0003oooooooooo`1Hooooo`009oooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo04gooooo1ol0001Cooooo`009oooool2o`0004_ooooo0_l0001A
ooooo`;o00000oooool00ol0003oooooooooo`1Aooooo`009oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0D?ooool002Oooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo053ooooo000Wooooo`03o`00
0?oooooooooo04Kooooo0_l0001Kooooo`03o`000?oooooooooo053ooooo000Wooooo`;o0000A_oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo04oooooo000Wooooo`03o`000?oooooo
oooo04?ooooo0_l0001Oooooo`03o`000?oooooooooo04oooooo000Wooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1?ooooo`009oooool00ol0003o
ooooooooo`10ooooo`;o0000H_ooool00ol0003oooooooooo`1?ooooo`009oooool2o`0003oooooo
0_l0001Tooooo`03o`000?oooooooooo04oooooo000>ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo04kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0>oooool2o`0006Sooooo00?o0000ooooooooool0C_ooool000Kooooo1Ol00002ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1>oooo
o`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool00_ooool2o`0003Wooooo0_l0001[ooooo`03o`000?oooooooooo04kooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0=_ooool2o`0006gooooo00?o0000ooooooooool0C_ooool000gooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo04gooooo000>ooooo`;o0000
2_ooool2o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo03?ooooo0_l0001aooooo`03o`00
0?oooooooooo04gooooo000Wooooo`;o0000<_ooool2o`0007?ooooo00?o0000ooooooooool0COoo
ool002Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo04gooooo000Wooooo`03o`000?oooooooooo02kooooo0_l0001gooooo`03o`000?oooooooooo
04cooooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Moooool00ol0003o
ooooooooo`1<ooooo`009oooool2o`0002cooooo0_l0001jooooo`03o`000?oooooooooo04cooooo
000Wooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`0Fooooo`?o0000<_ooool002Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000<Oooool002Oooooo00?o0000
ooooooooool09oooool2o`0007oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02kooooo000Wooooo`;o00009oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^oooo
o`009oooool00ol0003oooooooooo`0Tooooo`;o0000P_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool002Oooooo00?o0000ooooooooool0
8_ooool2o`0008Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02cooooo000Wooooo`;o00008_ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool5o`0002[ooooo000Wooooo`03o`000?oooooo
oooo01oooooo0_l00029ooooo`Go00004?ooool00ol0003oooooooooo`09ooooo`?o0000:?ooool0
00Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`00
00Gooooo00?o0000ooooooooool07Oooool2o`0008oooooo0ol0000>ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool09Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0T_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool000Go00000_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`;o00006oooool2o`0009Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Cooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Goooo
o`;o00002?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02?ooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooo000000?o00001Oooool00ol0003oooooooooo`0Gooooo`;o0000W?ooool2o`0000Kooooo00?o
0000ooooooooool04Oooool4o`00027ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool05?ooool2o`00023ooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go0000
1?ooool2o`0001Kooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Oooooo0_l0000Nooooo`009oooool00ol0003oooooooooo`0Cooooo`;o0000Xooo
ool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool07?ooool002Oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`2Sooooo`;o000000?oooooo`000?l000006ooo
ool2o`0001cooooo000Wooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`?o00007_ooool0
0ol0003oooooooooo`0Iooooo`009oooool2o`00013ooooo00?o0000ooooooooool0bOooool2o`00
01Wooooo000Wooooo`03o`000?oooooooooo00gooooo0_l0000Gooooo`;o00001?ooool01?l0003o
ooooooooooooool5o`00027ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol0000Roooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00008_ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0001Sooooo0_l0000=ooooo`?o00001oooool002Oooooo00?o0000oooooooo
ool02oooool2o`0001Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000P
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool08?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo000Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001ooo
ool5o`00027ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001[ooooo0_l0000;
ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o00002Oooool2o`0001_ooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00008_ooool01?l0003oooooooooool00007ooooo`Co00008Oooool01?l0003o
ooooooooool00008ooooo`?o00007Oooool2o`0000Wooooo00?o0000ooooooooool01_ooool002Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`05ooooo`;o
00007_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool0
1?l0003oooooooooool00009ooooo`;o00008_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo027ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
01oooooo0_l00005ooooo`;o00002?ooool002Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Oooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027o
oooo0_l0000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Rooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool002Oooooo0_l00003ooooo`;o0000i?ooool2o`0000cooooo
000Wooooo`05o`000?ooooooooooooooool00000j?ooool00ol0003oooooooooo`09ooooo`009ooo
ool01?l0003oooooo`000?l0003Zooooo`;o00002Oooool002Oooooo0_l0003^ooooo`03o`000?oo
oooooooo00Kooooo000Qoooooooo0000000Wooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo0_l0003gooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;o
oooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`;o0000moooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooo
oooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0m_ooool000Sooooo0_l0
000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oo
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooooooo
ool0m_ooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000
1Oooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`02ooooo`;o0000moooool000gooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_oo
ool000gooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co0000
1Oooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`3fooooo`003_ooool2o`0000[o
oooo0_l00002ooooo`Go00001?ooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool2o`000?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3f
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000moooool000Oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o00001Oooool0
0ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0?Kooooo
0008ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0000Gooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`000?Oooooo000Cooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00008ooooo`;o0000
ooooool001Cooooo0_l0000:ooooo`03o`000?oooooooooo0?gooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28394 L
.10458 .25657 L
.14415 .23088 L
.18221 .20618 L
.22272 .17988 L
.26171 .15456 L
.30316 .12767 L
.34309 .10176 L
.3815 .07683 L
.42237 .05036 L
.46172 .02493 L
.48147 .01167 L
.48566 .00854 L
.49012 .0056 L
.49268 .00426 L
.49501 .00334 L
.49613 .00301 L
.49735 .00274 L
.4985 .00258 L
.49955 .00251 L
.50074 .00252 L
.50186 .00262 L
.50308 .00283 L
.50439 .00315 L
.50576 .00361 L
.50706 .00414 L
.5095 .00538 L
.51896 .012 L
.53984 .02585 L
.57817 .05069 L
.61895 .07711 L
.65822 .10259 L
.69597 .12711 L
.73617 .15319 L
.77486 .1783 L
.816 .20501 L
.85562 .23073 L
.89373 .25546 L
.93429 .2818 L
.97334 .30714 L
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000MOooool4o`0007ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1cooooo`;o00000_ooool2o`0007gooooo000Cooooo`04o`000?ooooooooooo`0000So
oooo0_l00006ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1jooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1`ooooo`;o00002?ooool2o`0007[ooooo000Wooooo`;o0000Koooool2o`0000cooooo0_l0
001hooooo`009oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00kooooo0_l0001f
ooooo`009oooool00ol0003oooooooooo`1[ooooo`;o00004oooool2o`0007Cooooo000Wooooo`;o
0000J_ooool2o`0001Oooooo00?o0000ooooooooool0LOooool002Oooooo00?o0000ooooooooool0
J?ooool00ol0003oooooooooo`0Hooooo`;o0000LOooool002Oooooo00?o0000ooooooooool0I_oo
ool2o`0001gooooo00?o0000ooooooooool0K_ooool002Oooooo00?o0000ooooooooool0I?ooool2
o`00023ooooo0_l0001^ooooo`009oooool2o`0006Cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`1[ooooo`009oooool00ol0003oooooooooo`1Qooooo`;o00009_ooool2o`0006_o
oooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1Xooooo`009oooool00ol0003oooooooooo`1Nooooo`;o0000;?ooool2o`0006Sooooo000W
ooooo`;o0000GOooool2o`00033ooooo0_l0001Vooooo`009oooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Hoooool000Sooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo05Wooooo0_l0000fooooo`;o0000Hoooool000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`1Pooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0
001Gooooo`;o0000??ooool2o`00063ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo05gooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooo`000003o`0000Gooooo00?o0000ooooooooool0Doooool2o`0004;ooooo0_l0001Mooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000008ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`1Jooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`00
0?l000000ol00004ooooo`;o0000DOooool2o`0004Sooooo00?o0000ooooooooool0FOooool002Oo
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`19ooooo`;o0000FOooool002Oooooo
00?o0000ooooooooool0COooool2o`0004kooooo00?o0000ooooooooool0E_ooool002Oooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`1?ooooo`;o0000E_ooool002Oooooo0_l0001;
ooooo`;o0000E?ooool00ol0003oooooooooo`1Cooooo`009oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo05Gooooo0_l0001Cooooo`009oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool0D?ooool002Oooooo00?o0000ooooooooool0
A_ooool2o`0005cooooo0_l0001@ooooo`009oooool2o`0004Kooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`1=ooooo`009oooool00ol0003oooooooooo`13ooooo`;o0000H_ooool2
o`0004gooooo000Wooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0I?ooool2o`00
04_ooooo000Wooooo`03o`000?oooooooooo043ooooo0_l0001Yooooo`;o0000BOooool002Oooooo
0_l0000oooooo`;o0000KOooool00ol0003oooooooooo`16ooooo`003_ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0K_ooool2o`0004Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0>oooool2o`0007?ooooo0_l00014ooooo`001_ooool5o`0000;ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`1eooooo`;o0000@_ooool000gooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l0000i
ooooo`;o0000N_ooool00ol0003oooooooooo`0oooooo`003Oooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03o`000?oooooooooo03Kooooo0_l0
001mooooo`03o`000?oooooooooo03kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0O_ooool2o`0003kooooo000>ooooo`;o00002_ooool2o`0000;ooooo1Ol00004ooooo`03o`00
0?oooooooooo03?ooooo0_l00023ooooo`03o`000?oooooooooo03_ooooo000Wooooo`;o0000<_oo
ool2o`0008Kooooo00?o0000ooooooooool0>_ooool002Oooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`27ooooo`03o`000?oooooooooo03Wooooo000Wooooo`03o`000?oooooooooo
02kooooo0_l0002;ooooo`;o0000>Oooool002Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`2=ooooo`03o`000?oooooooooo03Kooooo000Wooooo`;o0000;?ooool2o`00097ooooo
0_l0000fooooo`009oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo09?ooooo0_l0
000dooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09Kooooo00?o0000
ooooooooool0<Oooool002Oooooo00?o0000ooooooooool09oooool2o`0009[ooooo0_l0000aoooo
o`009oooool2o`0002Oooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0^ooooo`00
9oooool00ol0003oooooooooo`0Tooooo`;o0000X?ooool2o`0002kooooo000Wooooo`03o`000?oo
oooooooo02;ooooo0_l0002Tooooo`;o0000;?ooool002Oooooo0_l0000Rooooo`03o`000?oooooo
oooo0:Kooooo00?o0000ooooooooool0:Oooool002Oooooo00?o0000ooooooooool07oooool2o`00
0:[ooooo0_l0000Yooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;o
oooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`0Mooooo`;o0000[_ooool2o`0002Oo
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool09?ooool000Go00000_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`;o00006oooool2o`000;Cooooo0_l0000Tooooo`001ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0]_ooool2o`0002;ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`0G
ooooo`;o0000^oooool00ol0003oooooooooo`0Oooooo`001oooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0_?ooool2o`0001oooooo0008ooooo`;o00002_oo
ool2o`0000?ooooo0ol00002ooooo`Go00001?ooool2o`0001Kooooo00?o0000ooooooooool0_ooo
ool2o`0001gooooo000Wooooo`03o`000?oooooooooo01?ooooo0_l00034ooooo`03o`000?oooooo
oooo01[ooooo000Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0aOooool2o`00
01[ooooo000Wooooo`03o`000?oooooooooo013ooooo0_l0003:ooooo`03o`000?oooooooooo01Oo
oooo000Wooooo`;o00004?ooool00ol0003oooooooooo`3;ooooo`;o00005oooool002Oooooo00?o
0000ooooooooool03Oooool2o`0001Oooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
6_ooool00ol0003oooooooooo`0:ooooo`?o00001oooool002Oooooo00?o0000ooooooooool02ooo
ool2o`0001Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Ko
oooo000Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00
027ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001_ooooo0_l0000:ooooo`03
o`000?oooooooooo00Kooooo000Wooooo`;o00002Oooool2o`0001_ooooo00Co0000oooooooooooo
00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00008_ooool01?l0003oooooooooool00007ooooo`Co00008Oooool01?l0003ooooooooo
ool00008ooooo`?o00007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
000Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo000002;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0R
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Nooooo`;o0000
1oooool00ol0003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`05ooooo`;o00007_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003o
ooooooooool00009ooooo`;o00008_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo027ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo
00?o0000ooooooooool00oooool2o`0000Sooooo000Wooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool07oooool2o`0000Wooooo0ol0000Rooooo`;o00002oooool00ol0003ooooooooo
o`0Qooooo`;o00002_ooool2o`0002;ooooo0_l00009ooooo`?o00008_ooool2o`0000Cooooo00?o
0000ooooooooool01_ooool002Oooooo0_l00003ooooo`;o0000iOooool00ol0003oooooooooo`0:
ooooo`009oooool01Ol0003ooooooooooooooooo00000>Sooooo00?o0000ooooooooool02Oooool0
02Oooooo00Co0000ooooool0003o0000j_ooool2o`0000Wooooo000Wooooo`;o0000k_ooool00ol0
003oooooooooo`06ooooo`008Oooooooo`0000009oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003g
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0002ooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool2o`000?Oooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0?Kooooo0008oooo
o`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`3foooo
o`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0
003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3
o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04
o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0
000:ooooo`;o00000_ooool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_oo
ool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Go
oooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3f
ooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004oooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`;o0000moooool001Cooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3fooooo`004oooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0003gooooo`004oooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo00002?ooool2
o`000?oooooo000Dooooo`;o00002_ooool00ol0003oooooooooo`3mooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .2841 L
.10458 .25738 L
.14415 .23187 L
.18221 .20721 L
.22272 .18097 L
.26171 .15562 L
.30316 .12829 L
.34309 .10198 L
.3815 .07691 L
.42237 .04979 L
.44268 .03795 L
.45262 .03297 L
.45491 .0318 L
.45734 .03068 L
.45959 .02983 L
.4607 .0295 L
.46172 .02925 L
.46284 .02905 L
.46406 .02891 L
.46509 .02887 L
.46618 .02889 L
.46739 .02899 L
.46851 .02915 L
.46974 .02939 L
.47106 .02972 L
.47532 .03105 L
.47756 .03175 L
.47994 .03236 L
.48124 .0326 L
.48198 .0327 L
.48268 .03277 L
.4839 .03283 L
.48521 .03281 L
.48648 .0327 L
.48712 .03261 L
.48781 .0325 L
.4902 .03195 L
.49469 .03055 L
.49705 .02983 L
.49834 .02949 L
.49955 .02924 L
.50086 .02904 L
.50156 .02897 L
.5023 .02893 L
.50298 .02891 L
.50363 .02892 L
.50484 .029 L
.50608 .02916 L
.50722 .02938 L
Mistroke
.50983 .03008 L
.51464 .03171 L
.51578 .03206 L
.517 .0324 L
.51812 .03266 L
.51916 .03284 L
.52038 .03298 L
.52103 .03302 L
.52172 .03304 L
.52247 .03302 L
.52317 .03297 L
.52449 .0328 L
.52569 .03256 L
.5268 .03227 L
.52931 .03143 L
.53185 .03046 L
.53451 .02949 L
.53591 .02908 L
.53665 .0289 L
.53744 .02875 L
.53816 .02865 L
.53882 .02859 L
.54011 .02857 L
.54135 .02868 L
.5425 .0289 L
.54375 .02927 L
.54508 .02981 L
.54731 .03103 L
.54976 .03274 L
.55881 .03997 L
.56145 .04167 L
.56396 .04295 L
.56684 .04408 L
.56947 .04491 L
.5742 .04648 L
.5769 .04772 L
.57943 .04927 L
.58407 .05315 L
.58907 .05834 L
.59406 .06331 L
.59657 .06532 L
.59801 .06627 L
.59932 .067 L
.60172 .06801 L
.60304 .0684 L
.60429 .0687 L
.6067 .06912 L
.60892 .06948 L
.61097 .06992 L
.612 .07022 L
Mistroke
.61314 .07063 L
.61551 .07179 L
.61773 .07333 L
.62671 .0832 L
.62908 .08606 L
.63164 .08882 L
.63406 .09089 L
.63521 .09166 L
.63628 .09224 L
.63756 .09277 L
.63823 .09297 L
.63896 .09314 L
.63972 .09325 L
.64044 .09332 L
.64109 .09334 L
.64179 .09333 L
.64305 .09324 L
.64368 .09318 L
.64438 .09309 L
.64555 .09295 L
.64678 .09282 L
.64804 .09277 L
.6492 .09282 L
.65044 .09301 L
.65115 .09321 L
.6518 .09344 L
.653 .09403 L
.65409 .09475 L
.65652 .09704 L
.66174 .10479 L
.66449 .10975 L
.6674 .11479 L
.66995 .11834 L
.67064 .1191 L
.67139 .11978 L
.6721 .1203 L
.67275 .12065 L
.67395 .12097 L
.67527 .1208 L
.67652 .12011 L
.67767 .119 L
.67894 .11726 L
.6803 .11478 L
.68278 .10884 L
.68741 .09404 L
.69277 .07508 L
.69538 .06694 L
.69776 .06087 L
.6989 .05852 L
.70013 .05639 L
Mistroke
.7013 .05481 L
.70237 .05371 L
.70351 .05291 L
.70477 .05246 L
.70608 .05243 L
.7073 .05278 L
.70795 .05309 L
.70865 .05351 L
.70993 .05451 L
.71234 .05693 L
.71776 .06332 L
.72048 .06621 L
.72305 .06845 L
.72601 .07045 L
.72869 .07186 L
.73884 .07758 L
.74389 .08188 L
.7486 .08591 L
.75097 .08751 L
.7523 .08821 L
.75351 .08871 L
.75484 .08911 L
.75559 .08927 L
.75628 .08938 L
.75756 .08949 L
.7582 .08951 L
.75891 .08951 L
.76007 .08947 L
.7613 .08942 L
.76235 .0894 L
.76349 .08945 L
.76473 .08962 L
.76605 .09 L
.7673 .09061 L
.76843 .09143 L
.76958 .09254 L
.77064 .09386 L
.77303 .09798 L
.77514 .10303 L
.77738 .10986 L
.78753 .15465 L
.79253 .17741 L
.79496 .18662 L
.79717 .19347 L
.79933 .19867 L
.80136 .20219 L
.80247 .20358 L
.8035 .20454 L
.80463 .20528 L
.80582 .20574 L
Mistroke
.80694 .20591 L
.80815 .20586 L
.80928 .20565 L
.81032 .20535 L
.81288 .20444 L
.81401 .20405 L
.81525 .2037 L
.81645 .20349 L
.81758 .20342 L
.81876 .2035 L
.82004 .2038 L
.82067 .20403 L
.82136 .20434 L
.82275 .20516 L
.82524 .20722 L
.83014 .21286 L
.83469 .21848 L
.83742 .22138 L
.83999 .22355 L
.8423 .225 L
.8436 .22563 L
.8448 .2261 L
.84729 .22682 L
.85004 .22741 L
.85269 .22802 L
.85419 .22846 L
.85558 .22897 L
.85811 .23021 L
.86081 .23199 L
.86576 .23632 L
.87023 .24071 L
.87506 .24499 L
.87773 .24688 L
.88018 .2483 L
.88499 .2504 L
.89029 .25245 L
.89596 .25551 L
.90108 .25939 L
.90574 .26344 L
.91485 .27042 L
.93554 .28179 L
.97548 .30844 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0001/ooooo`Go00001?ooool5o`0000Gooooo1Ol0001cooooo`00
9oooool00ol0003oooooooooo`1Yooooo`;o00001Oooool4o`0000Gooooo1Ol00004ooooo`03o`00
0?oooooooooo077ooooo000Wooooo`03o`000?oooooooooo06Kooooo0ol0000Jooooo`03o`000?oo
oooooooo073ooooo000Wooooo`03o`000?oooooooooo06Cooooo0_l0000Nooooo`?o0000Koooool0
02Oooooo0_l0001Tooooo`03o`000?oooooooooo027ooooo0_l0001]ooooo`009oooool00ol0003o
ooooooooo`1Qooooo`;o00009_ooool2o`0006_ooooo000Wooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`?o0000B_ooool002Oooooo00?o
0000ooooooooool0G_ooool2o`0002cooooo00?o0000ooooooooool06Oooool01?l0003ooooooooo
ool0001:ooooo`009oooool2o`0005gooooo0_l0000^ooooo`03o`000?oooooooooo01Wooooo00Go
0000ooooooooooooooooo`000019ooooo`009oooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo02oooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo0_l00017ooooo`002?ooool2
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0FOooool2o`0003Cooooo1?l0000Dooooo`03o`000?oooooo
oooo00Cooooo0_l00016ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0gooooo`;o00004oooool00ol0003ooooo
ooooo`06ooooo`;o0000A?ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o
0000Eoooool2o`0003cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo047ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02Oooool2o`00047ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0Doooool2
o`00047ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool5o`0003cooooo
0008ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo0_l0
001Aooooo`;o0000A_ooool5o`0000Sooooo00?o0000ooooooooool04Oooool2o`0003_ooooo000W
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>?ooool002Oooooo00?o0000oooo
ooooool0COooool2o`0004oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo03Sooooo000Wooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0>?ooool002Oooooo0_l0001;ooooo`;o0000Doooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0=oooool002Oooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0gooooo`009oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo05Gooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`0gooooo`009oooool0
0ol0003oooooooooo`16ooooo`;o0000FOooool3o`0001Wooooo00?o0000ooooooooool0=_ooool0
02Oooooo0_l00016ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0=_ooool002Oo
oooo00?o0000ooooooooool0@oooool2o`0007Sooooo00?o0000ooooooooool0=_ooool002Oooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo03Kooooo
000Wooooo`03o`000?oooooooooo043ooooo0_l0001looooo`03o`000?oooooooooo03Gooooo000W
ooooo`;o0000?oooool2o`0007kooooo00?o0000ooooooooool0=Oooool000kooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool0=Oooool000gooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0kooooo`;o0000POooool00ol0003oooooooooo`0eooooo`001_ooool5
o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo03Cooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`02ooooo`;o0000>Oooool2o`0008Gooooo00?o0000oooooooo
ool0=?ooool000gooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo
00Co00001Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool0=?ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000Sooooo00?o0000ooooooooool0=Oooool2o`0008Sooooo00?o0000ooooooooool0=?oo
ool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo03Cooooo000Wooooo`;o0000=?ooool00ol0
003oooooooooo`2:ooooo`03o`000?oooooooooo03?ooooo000Wooooo`03o`000?oooooooooo037o
oooo0_l0002=ooooo`03o`000?oooooooooo03?ooooo000Wooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0SOooool00ol0003oooooooooo`0cooooo`009oooool00ol0003ooooooooo
o`0^ooooo`;o0000T?ooool00ol0003oooooooooo`0cooooo`009oooool2o`0002gooooo0_l0002B
ooooo`03o`000?oooooooooo03?ooooo000Wooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0T_ooool00ol0003oooooooooo`0cooooo`009oooool00ol0003oooooooooo`0Yooooo`;o
0000U_ooool00ol0003oooooooooo`0booooo`009oooool00ol0003oooooooooo`0Wooooo`;o0000
VOooool00ol0003oooooooooo`0aooooo`009oooool2o`0002Oooooo00?o0000ooooooooool0VOoo
ool00ol0003oooooooooo`03o`0002kooooo000Wooooo`03o`000?oooooooooo02Cooooo0_l0002M
ooooo`;o00000oooool00ol0003oooooooooo`0[ooooo`009oooool00ol0003oooooooooo`0Roooo
o`;o0000Y?ooool00ol0003oooooooooo`0[ooooo`009oooool2o`0002;ooooo00?o0000oooooooo
ool0YOooool2o`0002_ooooo000Wooooo`03o`000?oooooooooo01oooooo0_l0002Zooooo`03o`00
0?oooooooooo02Sooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_oo
ool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01gooooo0_l0002/ooooo`;o0000:Ooo
ool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0[Oooool4o`0002Kooooo0005o`0000;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool2o`0001_ooooo0_l0002cooooo`?o00009?ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;Gooooo00?o
0000ooooooooool08_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo01Oo
oooo0_l0002iooooo`;o00008_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooooooool07oooool000Sooooo0_l0000:oooo
o`;o00000oooool3o`0000;ooooo1Ol00004ooooo`;o00005_ooool00ol0003oooooooooo`2moooo
o`03o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo01?ooooo0_l00031ooooo`?o
00007Oooool002Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`34ooooo`;o0000
6oooool002Oooooo00?o0000ooooooooool04?ooool2o`000<Wooooo0_l0000Iooooo`009oooool2
o`00013ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Fooooo`009oooool00ol0
003oooooooooo`0=ooooo`;o00005oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Q
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00008_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000I
ooooo`03o`000?oooooooooo00_ooooo0ol00007ooooo`009oooool00ol0003oooooooooo`0;oooo
o`;o00006?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00023ooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`;o00003?ooool00ol0003oooooooooo`06ooooo`009oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000Oooooo1Ol0000Qooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Kooooo`;o00002_ooool00ol0003ooooooooo
o`06ooooo`009oooool2o`0000Wooooo0_l0000Kooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002;o
oooo00Co0000oooooooooooo00001oooool4o`00027ooooo00Co0000oooooooooooo00002?ooool3
o`0001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`009oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00000Rooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool08_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000007_ooool2o`0000Oooooo00?o0000
ooooooooool01_ooool002Oooooo00?o0000ooooooooool01Oooool2o`0001kooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooooooo0000
2Oooool2o`0002;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0Qooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooo
oooo00?ooooo0_l00008ooooo`009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01oooooo0_l00009ooooo`?o00008_ooool2o`0000_ooooo00?o0000ooooooooool08Oooool2o`00
00[ooooo0_l0000Rooooo`;o00002Oooool3o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo
00Kooooo000Wooooo`;o00000oooool2o`000>Gooooo00?o0000ooooooooool02_ooool002Oooooo
00Go0000ooooooooooooooooo`00003Xooooo`03o`000?oooooooooo00Wooooo000Wooooo`04o`00
0?oooooo0000o`000>[ooooo0_l00009ooooo`009oooool2o`000>kooooo00?o0000ooooooooool0
1_ooool0027oooooool0000002Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2
o`000?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`00
00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_oo
ool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo
0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0
003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03
o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool0
00gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00;ooooo0_l0003gooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03
o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00008ooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00002_ooool2o`00
00;ooooo1Ol00004ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003g
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005ooooo`03o`000?oo
oooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0m_ooool000Sooooo
0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?ooool00ol0003ooooo
ooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000
moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool2o`000?Oooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`3fooooo`004oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooo`00
5?ooool2o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28393 L
.10458 .25651 L
.14415 .23081 L
.18221 .20611 L
.22272 .17979 L
.26171 .15448 L
.30316 .1276 L
.34309 .10171 L
.3815 .07679 L
.39174 .07011 L
.40134 .06454 L
.40381 .06343 L
.40616 .06255 L
.40745 .06215 L
.40887 .06178 L
.41014 .06151 L
.41134 .06131 L
.41204 .06122 L
.41279 .06115 L
.41411 .06106 L
.41486 .06103 L
.41565 .06102 L
.41632 .06103 L
.41706 .06105 L
.41775 .06108 L
.41838 .06111 L
.4198 .06123 L
.42237 .0615 L
.42717 .06206 L
.42834 .06217 L
.4296 .06227 L
.43032 .06232 L
.43098 .06236 L
.43228 .06241 L
.43338 .06243 L
.43441 .06242 L
.43554 .0624 L
.43675 .06235 L
.43801 .06228 L
.43921 .06219 L
.44145 .06198 L
.44629 .06151 L
.44747 .06141 L
.44873 .06133 L
.44945 .06129 L
.45012 .06126 L
.45141 .06122 L
.45213 .06121 L
.45279 .06121 L
Mistroke
.45352 .06121 L
.45429 .06123 L
.45503 .06126 L
.45573 .06129 L
.45703 .06136 L
.45952 .06156 L
.46221 .06183 L
.46459 .06206 L
.4659 .06217 L
.46714 .06227 L
.4683 .06233 L
.46955 .06239 L
.47069 .06242 L
.47174 .06242 L
.47299 .0624 L
.47415 .06237 L
.47543 .0623 L
.47681 .0622 L
.48219 .06167 L
.48497 .06139 L
.48632 .06129 L
.48755 .06121 L
.48886 .06116 L
.48957 .06114 L
.49025 .06113 L
.49098 .06113 L
.49166 .06114 L
.4924 .06116 L
.49319 .06119 L
.49439 .06126 L
.49567 .06136 L
.49799 .06159 L
.50055 .06189 L
.50327 .06219 L
.50447 .06231 L
.50577 .06242 L
.50652 .06247 L
.5072 .0625 L
.50785 .06253 L
.50854 .06255 L
.50975 .06256 L
.51087 .06255 L
.5121 .0625 L
.51342 .06241 L
.51485 .06229 L
.5164 .06212 L
.51921 .06175 L
.52172 .06142 L
.52305 .06126 L
.52448 .06112 L
Mistroke
.52518 .06106 L
.52585 .06101 L
.5271 .06095 L
.52828 .06092 L
.52956 .06093 L
.53027 .06095 L
.53091 .06098 L
.53165 .06103 L
.53235 .06108 L
.53494 .06137 L
.53994 .06214 L
.54237 .06249 L
.54344 .06262 L
.5446 .06273 L
.54575 .06281 L
.54685 .06286 L
.5481 .06287 L
.54926 .06283 L
.55043 .06276 L
.55174 .06264 L
.55309 .06246 L
.55437 .06226 L
.55975 .06124 L
.56211 .06085 L
.56345 .06067 L
.56469 .06056 L
.56579 .06049 L
.56678 .06047 L
.56794 .06049 L
.56902 .06055 L
.57016 .06066 L
.57121 .0608 L
.57358 .06124 L
.57859 .06242 L
.58078 .06291 L
.58194 .06313 L
.58317 .06332 L
.58441 .06346 L
.58557 .06353 L
.58676 .06356 L
.58785 .06355 L
.58909 .06347 L
.58979 .06341 L
.59043 .06335 L
.59287 .06302 L
.59397 .06287 L
.59516 .06271 L
.59627 .0626 L
.59729 .06253 L
.59843 .06251 L
Mistroke
.59951 .06257 L
.60068 .06273 L
.60194 .06304 L
.60322 .06351 L
.60442 .06411 L
.60574 .06496 L
.60715 .0661 L
.61004 .06912 L
.61268 .07259 L
.61747 .07969 L
.61993 .08308 L
.62131 .08473 L
.62259 .086 L
.62388 .08699 L
.62453 .08737 L
.62525 .08767 L
.62654 .08791 L
.62775 .08774 L
.62893 .0872 L
.63001 .08636 L
.63125 .08498 L
.63243 .08326 L
.6347 .07887 L
.6368 .07366 L
.64157 .05891 L
.64675 .04154 L
.64928 .03395 L
.65161 .02813 L
.65405 .02352 L
.65533 .02178 L
.65604 .02102 L
.65668 .02047 L
.65735 .02002 L
.65807 .01969 L
.65936 .01947 L
.66008 .01954 L
.66086 .01978 L
.6616 .02014 L
.66229 .02059 L
.70168 .05035 L
.73955 .07544 L
.77988 .10162 L
.78887 .11251 L
.79146 .1155 L
.79389 .11779 L
.79496 .11859 L
.79608 .11928 L
.79731 .11985 L
.79844 .1202 L
.7997 .1204 L
Mistroke
.8004 .12043 L
.80104 .12041 L
.80228 .12026 L
.80345 .12001 L
.80631 .11912 L
.80756 .11873 L
.80823 .11854 L
.80895 .11838 L
.81012 .1182 L
.81121 .11819 L
.81247 .1184 L
.81362 .11884 L
.8148 .11958 L
.81609 .12078 L
.81744 .1225 L
.81869 .12456 L
.82145 .13073 L
.82406 .13859 L
.82893 .15782 L
.83462 .18416 L
.83986 .20695 L
.84454 .22255 L
.84691 .22812 L
.84824 .23056 L
.8495 .23243 L
.85087 .23399 L
.85211 .23504 L
.8528 .23548 L
.85345 .2358 L
.85415 .23607 L
.85491 .23627 L
.85614 .23644 L
.8573 .23643 L
.85858 .23631 L
.8593 .2362 L
.85995 .23609 L
.86112 .23588 L
.86238 .23568 L
.86358 .23554 L
.86468 .23549 L
.86597 .23554 L
.86661 .23563 L
.86733 .23576 L
.86857 .23612 L
.86974 .23661 L
.87091 .23724 L
.87203 .23797 L
.87412 .23965 L
.87885 .2445 L
.89953 .2596 L
Mistroke
.93773 .2842 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0WOooool4o`0005Gooooo000Woooo
o`03o`000?oooooooooo09gooooo00Go0000ooooooooooooooooo`00001Dooooo`009oooool2o`00
09gooooo00?o0000ooooooooool00oooool2o`0005;ooooo000Wooooo`03o`000?oooooooooo09_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?ooooo`009oooool00ol0003ooooo
ooooo`2Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C_ooool002Oooooo00?o
0000ooooooooool0Voooool00ol0003oooooooooo`08ooooo`;o0000C_ooool002Oooooo0_l0002L
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Boooool002Oooooo00?o0000oooo
ooooool0Voooool00ol0003oooooooooo`0;ooooo`;o0000Boooool002Oooooo00?o0000oooooooo
ool0V_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Sooooo000Wooooo`03o`00
0?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`17ooooo`009ooo
ool2o`0005oooooo9?l000000ooooooo0000o`000006o`0000?ooooo0_l0000:ooooo`03o`000?oo
oooooooo013ooooo0_l00017ooooo`009oooool00ol0003oooooooooo`1Looooo`;o00008oooool2
o`0000Oooooo2?l00008ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0A?ooool0
00Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00005ooooo`03o`000?oooooooooo05Wooooo0ol0000fooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`13ooooo`001oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`12ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0001Gooooo`;o0000
>_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo0_l00012ooooo`001ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Gooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo0_l00010ooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ool000000ol00005ooooo`03o`000?oooooooooo05?ooooo0_l0000oooooo`;o000000?oooooo`00
0?ooool07Oooool2o`0003kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`10ooooo`?o00008?ooool00ol0003oooooooooo`0kooooo`002?ooool2
o`0000[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000DOooool2
o`0006Oooooo0_l0000kooooo`009oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
06Wooooo0_l0000iooooo`009oooool00ol0003oooooooooo`1=ooooo`;o0000K_ooool00ol0003o
ooooooooo`0fooooo`009oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool0=_ooool002Oooooo0_l0001;ooooo`;o0000L_ooool00ol0003ooooooooo
o`0eooooo`009oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool0=?ooool002Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo03?ooooo000Wooooo`03o`000?oooooooooo04Kooooo0_l0001hooooo`Oo
0000;oooool002Oooooo0_l00016ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
;Oooool002Oooooo00?o0000ooooooooool0@oooool2o`00087ooooo00?o0000ooooooooool0;Ooo
ool002Oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo02cooooo000Wooooo`03o`000?oooooooooo043ooooo0_l00025ooooo`03o`000?oooooooooo
02cooooo000Wooooo`;o0000?oooool2o`0008Sooooo00?o0000ooooooooool0:oooool000kooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0:oooool000gooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0kooooo`;o0000Roooool00ol0003oooooooooo`0[oooo
o`001_ooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2<
ooooo`03o`000?oooooooooo02[ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000>Oooool2o`0008oooooo00?o
0000ooooooooool0:_ooool000gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
ool0003ooooo00Co00001Oooool00ol0003oooooooooo`0fooooo`;o0000TOooool00ol0003ooooo
ooooo`0Zooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00002?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo097ooooo00?o0000oooo
ooooool0:_ooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo00?o0000oooooooo
ool0<oooool2o`0009Gooooo00?o0000ooooooooool0:Oooool002Oooooo0_l0000booooo`;o0000
Uoooool00ol0003oooooooooo`0Yooooo`009oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo09Oooooo00?o0000ooooooooool0:Oooool002Oooooo00?o0000ooooooooool0;_ooool2
o`0009_ooooo00?o0000ooooooooool0:?ooool002Oooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`2Kooooo`03o`000?oooooooooo02Sooooo000Wooooo`;o0000;?ooool2o`0009ko
oooo00?o0000ooooooooool0:?ooool002Oooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`2Nooooo`03o`000?oooooooooo02Sooooo000Wooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0Xooooo`009oooool00ol0003oooooooooo`0W
ooooo`;o0000Xoooool00ol0003oooooooooo`0Wooooo`009oooool2o`0002Oooooo00?o0000oooo
ooooool0Xoooool00ol0003oooooooooo`0Wooooo`009oooool00ol0003oooooooooo`0Tooooo`;o
0000Y_ooool00ol0003oooooooooo`0Wooooo`009oooool00ol0003oooooooooo`0Rooooo`;o0000
Z?ooool00ol0003oooooooooo`0Wooooo`009oooool2o`0002;ooooo00?o0000ooooooooool0Z?oo
ool00ol0003oooooooooo`0Wooooo`009oooool00ol0003oooooooooo`0Oooooo`;o0000[?ooool0
0ol0003oooooooooo`0Vooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`00
00;ooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`0Mooooo`;o0000[_ooool00ol0
003oooooooooo`0Vooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo02Gooooo
0005o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0001_ooooo0_l0002booooo`03
o`000?oooooooooo02Gooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`2booooo`;o000000Coooooo`000?l0003o00008_ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo01Oooooo0_l0002fooooo`?o0000
00Coooooo`000?l0003o00008?ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool07_ooool000Sooooo0_l0000:oooo
o`;o00000oooool3o`0000;ooooo1Ol00004ooooo`;o00005_ooool00ol0003oooooooooo`2noooo
o`;o00007_ooool002Oooooo00?o0000ooooooooool04oooool2o`000<?ooooo0_l0000Looooo`00
9oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool0
6Oooool002Oooooo00?o0000ooooooooool04?ooool2o`000<Wooooo0_l0000Iooooo`009oooool2
o`00013ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Fooooo`009oooool00ol0
003oooooooooo`0=ooooo`;o00005oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Q
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00008_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000I
ooooo`;o00003?ooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo00_ooooo0_l0000Hoooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00008?ooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo0000023ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000001[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`009oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000Oooooo1Ol0000Qooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01_ooool002Oooooo0_l00009ooooo`;o00006oooool01?l0003oooooooooool0
000:ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool0000Rooooo`04o`000?ooooooooooo`0000Oooooo1?l0000Qooooo`04o`000?oooooooooo
o`0000Sooooo0ol0000Mooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`009oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00000Rooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool08_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Gooooo0_l0000Noooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?oo
ooooooooo`0000Wooooo0_l0000Rooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool08Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000007oooool2
o`0000Gooooo0_l00008ooooo`009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01oooooo0_l00009ooooo`?o00008_ooool2o`0000_ooooo00?o0000ooooooooool08Oooool2o`00
00[ooooo0_l0000Rooooo`;o00002Oooool3o`0002;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`009oooool2o`0000?ooooo0_l0003Tooooo`;o00003?ooool002Oooooo
00Go0000ooooooooooooooooo`00003Xooooo`03o`000?oooooooooo00Wooooo000Wooooo`04o`00
0?oooooo0000o`000>[ooooo0_l00009ooooo`009oooool2o`000>kooooo00?o0000ooooooooool0
1_ooool0027oooooool0000002Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2
o`000?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`00
00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_oo
ool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo
0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0
003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03
o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool0
00gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00;ooooo0_l0003gooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03
o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00008ooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00002_ooool2o`00
00;ooooo1Ol00004ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003g
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005ooooo`03o`000?oo
oooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0m_ooool000Sooooo
0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?ooool00ol0003ooooo
ooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000
moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool2o`000?Oooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`3fooooo`004oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooo`00
5?ooool2o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28378 L
.10458 .25582 L
.14415 .22997 L
.18221 .20524 L
.22272 .17891 L
.26171 .15364 L
.30316 .12717 L
.32392 .11456 L
.33304 .10721 L
.34309 .10141 L
.35207 .09734 L
.35702 .09497 L
.36173 .09287 L
.36428 .09197 L
.36572 .09157 L
.36706 .09128 L
.3683 .09109 L
.36942 .09098 L
.37072 .09094 L
.37194 .09097 L
.3731 .09107 L
.37433 .09124 L
.37538 .09143 L
.37653 .09168 L
.3815 .09301 L
.38401 .09364 L
.38533 .09391 L
.38606 .09404 L
.38674 .09414 L
.38797 .09427 L
.38862 .09431 L
.38932 .09433 L
.39056 .09432 L
.3917 .09425 L
.39283 .09413 L
.39387 .09397 L
.39624 .09348 L
.40101 .09222 L
.40232 .09189 L
.40373 .09158 L
.40498 .09136 L
.40567 .09126 L
.40631 .09119 L
.4075 .09109 L
.40881 .09106 L
.40992 .0911 L
.41112 .0912 L
.41184 .09129 L
.41251 .09139 L
Mistroke
.41402 .09168 L
.41677 .09236 L
.41945 .09311 L
.42192 .09373 L
.42321 .094 L
.4244 .09419 L
.42565 .09433 L
.42631 .09438 L
.42702 .09441 L
.42773 .09441 L
.4285 .09439 L
.42922 .09434 L
.4299 .09428 L
.43117 .0941 L
.43252 .09384 L
.43766 .09245 L
.44018 .09175 L
.44128 .09149 L
.44249 .09125 L
.44356 .09108 L
.44456 .09097 L
.44562 .0909 L
.44675 .0909 L
.44799 .09097 L
.44916 .0911 L
.45021 .09127 L
.45134 .09151 L
.45639 .09297 L
.45886 .09371 L
.46111 .09425 L
.46223 .09444 L
.46346 .09459 L
.46461 .09465 L
.46568 .09465 L
.46681 .09457 L
.46806 .09441 L
.46937 .09416 L
.4706 .09386 L
.47603 .0921 L
.47841 .09136 L
.47967 .09105 L
.48037 .0909 L
.48102 .09079 L
.48166 .0907 L
.48236 .09062 L
.48357 .09056 L
.48481 .09059 L
.48595 .0907 L
.48715 .0909 L
.48848 .09121 L
Mistroke
.49115 .09205 L
.49383 .09305 L
.49675 .0941 L
.49809 .0945 L
.49882 .09468 L
.49951 .09482 L
.50016 .09494 L
.50086 .09503 L
.50208 .09511 L
.5033 .09509 L
.504 .09504 L
.50465 .09496 L
.50596 .09471 L
.50669 .09452 L
.50736 .09433 L
.51222 .0924 L
.51451 .09143 L
.51571 .09097 L
.51699 .09055 L
.5181 .09026 L
.51933 .09003 L
.52045 .08992 L
.5215 .0899 L
.52272 .09 L
.52341 .0901 L
.52406 .09024 L
.52536 .0906 L
.52675 .09111 L
.53155 .09348 L
.53295 .09419 L
.53447 .0949 L
.53581 .09542 L
.53654 .09566 L
.53723 .09584 L
.53851 .09608 L
.53918 .09614 L
.53991 .09615 L
.5412 .09605 L
.54238 .09581 L
.54368 .09539 L
.5449 .09486 L
.54717 .09358 L
.54983 .09181 L
.55226 .09019 L
.55441 .08902 L
.55549 .08857 L
.55667 .08822 L
.55786 .08805 L
.55913 .08808 L
.56033 .08831 L
Mistroke
.56142 .08871 L
.56666 .09266 L
.56952 .09566 L
.57221 .0983 L
.57338 .09923 L
.57449 .09992 L
.57577 .10042 L
.57694 .10056 L
.57824 .10031 L
.57944 .09964 L
.58076 .0984 L
.5815 .09747 L
.58216 .09647 L
.58463 .09152 L
.5869 .08529 L
.59202 .06657 L
.59682 .04649 L
.6013 .02948 L
.60382 .02185 L
.60612 .01647 L
.60743 .01412 L
.60867 .01237 L
.60998 .01101 L
.61072 .01046 L
.61141 .01008 L
.61267 .00967 L
.61387 .00962 L
.61517 .00987 L
.61591 .01014 L
.61658 .01044 L
.61926 .0121 L
.62208 .01415 L
.62465 .01586 L
.62591 .01655 L
.62708 .01708 L
.62814 .01744 L
.62926 .01772 L
.63038 .01789 L
.63162 .01794 L
.6323 .01792 L
.63295 .01787 L
.63416 .01771 L
.63546 .01746 L
.63689 .01714 L
.63822 .01682 L
.63947 .01654 L
.6406 .01633 L
.64181 .01617 L
.64298 .01611 L
.64422 .01615 L
Mistroke
.64527 .01629 L
.64643 .01654 L
.64766 .01695 L
.64897 .01754 L
.65134 .01898 L
.65597 .02283 L
.66018 .02684 L
.665 .031 L
.67011 .03432 L
.67929 .03855 L
.68917 .04487 L
.70006 .05341 L
.74031 .07931 L
.77903 .10401 L
.82021 .12886 L
.82267 .12969 L
.82406 .13032 L
.82533 .13103 L
.82768 .13269 L
.83016 .13495 L
.83572 .14141 L
.83816 .1444 L
.84077 .14732 L
.84203 .14853 L
.84323 .14954 L
.8444 .15035 L
.84548 .15095 L
.8465 .15138 L
.84758 .15169 L
.84867 .15185 L
.84987 .15186 L
.85117 .15171 L
.85235 .15144 L
.85503 .15061 L
.85625 .15023 L
.85739 .14994 L
.85858 .14975 L
.85988 .14974 L
.86112 .14999 L
.86226 .1505 L
.86351 .1514 L
.86414 .15201 L
.86484 .15281 L
.86601 .15446 L
.86726 .15671 L
.86953 .16204 L
.87188 .16928 L
.87412 .17766 L
.87831 .19632 L
.88364 .22197 L
Mistroke
.88865 .24321 L
.89084 .25054 L
.89316 .25671 L
.89436 .25928 L
.89569 .2616 L
.8969 .26326 L
.89803 .26446 L
.89927 .26542 L
.90045 .26603 L
.9015 .26636 L
.90265 .26653 L
.9039 .26653 L
.90454 .26648 L
.90523 .2664 L
.90762 .266 L
.90885 .26582 L
.91015 .2657 L
.91083 .26569 L
.91158 .26571 L
.91289 .26587 L
.91413 .26618 L
.91482 .26643 L
.91545 .26669 L
.91784 .26808 L
.9202 .26999 L
.92238 .27209 L
.9273 .27735 L
.93623 .28485 L
.97564 .30875 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo097o
oooo0ol0001Rooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2Aooooo`03o`000?oooooooooo00;o0000H?ooool002Oooooo0_l0002Booooo`04o`000?oo
ooooooooooooo`So0000FOooool002Oooooo00?o0000ooooooooool0T?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo05Kooooo000Wooooo`03o`000?oooooooooo093ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`009oooool2o`00093ooooo00?o0000oooo
ooooool03Oooool2o`0005Gooooo000Wooooo`03o`000?oooooooooo08oooooo00?o0000oooooooo
ool03oooool2o`0005?ooooo000Wooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0
4Oooool2o`00057ooooo000Wooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1>ooooo`009oooool2o`0008oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1=ooooo`009oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0C?ooool002Oooooo00?o0000ooooooooool0S_ooool00ol0003o
ooooooooo`0Gooooo`;o0000C?ooool002Oooooo00?o0000ooooooooool0SOooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo04Wooooo000Wooooo`;o0000S_ooool00ol0003ooooooooo
o`0Kooooo`;o0000BOooool002Oooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0M
ooooo`;o0000Aoooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08gooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`14ooooo`001oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Pooooo`;o0000A?oo
ool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000SOooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo047ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`0Tooooo`;o0000@Oooool000Oooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo0000
00?o00001Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0?_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`1jooooo`?o00001_oo
ool3o`0000Kooooo00?o0000ooooooooool09oooool2o`0003kooooo0008ooooo`;o00002_ooool2
o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo0_l0001Coooooa7o000000?ooooo
o`000?l000001_l00002ooooo`So00000_ooool3o`000004ooooool0003o0000o`0000?ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
>oooool002Oooooo00?o0000ooooooooool0Coooool3o`0000Oooooo0_l00008ooooo`;o00001ooo
ool2o`0000Oooooo0ol00006ooooo`Co00001Oooool01?l0003oooooooooool0000^ooooo`;o0000
>oooool002Oooooo00?o0000ooooooooool0COooool2o`0003Wooooo0ol0000`ooooo`03o`000?oo
oooooooo03Sooooo000Wooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0KOooool2
o`0003Sooooo000Wooooo`;o0000C?ooool00ol0003oooooooooo`1`ooooo`;o0000=_ooool002Oo
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1cooooo`;o0000=?ooool002Oooooo
00?o0000ooooooooool0B?ooool2o`0007Sooooo00?o0000ooooooooool0<Oooool002Oooooo00?o
0000ooooooooool0A_ooool2o`0007_ooooo0_l0000aooooo`009oooool2o`0004Kooooo00?o0000
ooooooooool0OOooool2o`0002oooooo000Wooooo`03o`000?oooooooooo04?ooooo0_l00022oooo
o`03o`000?oooooooooo02cooooo000Wooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0P_ooool3o`0002cooooo000Wooooo`03o`000?oooooooooo043ooooo0_l00027ooooo`;o0000
:oooool002Oooooo0_l0000oooooo`;o0000Roooool00ol0003oooooooooo`0Xooooo`003_ooool2
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Xooooo`003Oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03_ooooo0_l0002?ooooo`03o`000?oooooooooo02Oooooo
0006ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo093o
oooo1_l0000Sooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool00_ooool2o`0003Wooooo0_l0002Hooooo`;o00008_ooool000go
oooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool0
0ol0003oooooooooo`0fooooo`;o0000Voooool00ol0003oooooooooo`0Pooooo`003Oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool08?ooool000kooooo0_l0
000:ooooo`;o00000_ooool5o`0000Cooooo00?o0000ooooooooool0<oooool2o`0009kooooo00?o
0000ooooooooool08?ooool002Oooooo0_l0000booooo`;o0000XOooool00ol0003oooooooooo`0O
ooooo`009oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0:7ooooo00?o0000oooo
ooooool07oooool002Oooooo00?o0000ooooooooool0;_ooool2o`000:Gooooo00?o0000oooooooo
ool07_ooool002Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Uooooo`03o`00
0?oooooooooo01kooooo000Wooooo`;o0000;?ooool2o`000:Sooooo00?o0000ooooooooool07_oo
ool002Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo01gooooo000Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Z_ooool00ol0
003oooooooooo`0Mooooo`009oooool00ol0003oooooooooo`0Wooooo`;o0000[Oooool00ol0003o
ooooooooo`0Mooooo`009oooool2o`0002Oooooo00?o0000ooooooooool0[Oooool00ol0003ooooo
ooooo`0Mooooo`009oooool00ol0003oooooooooo`0Tooooo`;o0000/?ooool00ol0003ooooooooo
o`0Mooooo`009oooool00ol0003oooooooooo`0Rooooo`;o0000/oooool00ol0003oooooooooo`0L
ooooo`009oooool2o`0002;ooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0Loooo
o`009oooool00ol0003oooooooooo`0Oooooo`;o0000]_ooool00ol0003oooooooooo`0Looooo`00
2?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o0000
1Oooool00ol0003oooooooooo`0Mooooo`;o0000^?ooool00ol0003oooooooooo`0Looooo`001ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`2hooooo`03o`000?oooooooooo01cooooo0005o`0000;ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool2o`0001_ooooo0_l0002kooooo`03o`000?oooooooooo01cooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`2looooo`03o`000?oooooooooo01_ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0
003oooooooooo`0Gooooo`;o0000_oooool00ol0003oooooooooo`0Kooooo`001oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00
0008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0_oooool00ol0003ooooooooo
o`0Kooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo0_l0000F
ooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool06oooool002Oooooo00?o0000oooo
ooooool04oooool2o`000<Cooooo00?o0000ooooooooool06_ooool002Oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo01[ooooo000Wooooo`03o`00
0?oooooooooo013ooooo0_l00037ooooo`;o00006oooool002Oooooo0_l0000@ooooo`03o`000?oo
oooooooo0<Sooooo00?o0000ooooooooool06Oooool002Oooooo00?o0000ooooooooool03Oooool2
o`0001Oooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00008Oooool2o`0000Cooooo00?o
0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00005_ooool5o`0000cooooo0ol0
0007ooooo`009oooool00ol0003oooooooooo`0;ooooo`;o00006?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`00023ooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`0Pooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000P
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
8?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000006oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo
000Wooooo`;o00002Oooool2o`0001_ooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`0Oooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0
003oooooooooool00007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o00007Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000008?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Rooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool01Oooool2o`0001kooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooooooo
00002Oooool2o`0002;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0Qoooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Nooooo`;o00001_oo
ool2o`0000Sooooo000Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool2
o`0000Wooooo0ol0000Rooooo`;o00002oooool00ol0003oooooooooo`0Qooooo`;o00002_ooool2
o`0002;ooooo0_l00009ooooo`?o00008Oooool2o`0000Gooooo00?o0000ooooooooool01_ooool0
02Oooooo0_l00003ooooo`;o0000i?ooool00ol0003oooooooooo`0;ooooo`009oooool01Ol0003o
oooooooooooooooo00000>Oooooo0_l0000;ooooo`009oooool01?l0003oooooo`000?l0003Zoooo
o`;o00002Oooool002Oooooo0_l0003^ooooo`03o`000?oooooooooo00Kooooo000Qoooooooo0000
000Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`05ooooo`009oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool01Oooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool0
0ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000moooool0
00Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool0m_ooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000;o
oooo1Ol00004ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003goooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool000kooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`3foooo
o`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo
00002?ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`3foooo
o`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?oo
ool00ol0003oooooooooo`3fooooo`003_ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool2
o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oo
oooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`;o0000moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`3fooooo`001ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooo`000008ooooo`03o`000?oooooooooo0?Kooooo0008ooooo`;o00002_ooool2o`0000;o
oooo1Ol000000ooooooo0000o`000003o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo
0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003g
ooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooo
ooooool0m_ooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01?ooool2o`000?Oooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool0oOooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3moooo
o`004oooool01?l0003oooooooooool00008ooooo`;o0000ooooool001Cooooo0_l0000:ooooo`03
o`000?oooooooooo0?gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28397 L
.10458 .25683 L
.14415 .23121 L
.18221 .20652 L
.22272 .18029 L
.26171 .15498 L
.28158 .14144 L
.29205 .13486 L
.30316 .12808 L
.30791 .12556 L
.31054 .12444 L
.31304 .1236 L
.31444 .12323 L
.31518 .12307 L
.31597 .12293 L
.3167 .12282 L
.31736 .12274 L
.31865 .12263 L
.31996 .12259 L
.32069 .1226 L
.32136 .12262 L
.32261 .12269 L
.32392 .12281 L
.32907 .12356 L
.3316 .12395 L
.33271 .1241 L
.33394 .12424 L
.33497 .12433 L
.33607 .12441 L
.33723 .12446 L
.33832 .12448 L
.33953 .12446 L
.34081 .12441 L
.34189 .12433 L
.34309 .12423 L
.34767 .12363 L
.35019 .12328 L
.35256 .123 L
.35389 .12288 L
.35463 .12283 L
.35532 .12279 L
.35654 .12275 L
.35783 .12275 L
.35903 .12278 L
.36016 .12284 L
.36139 .12294 L
.36272 .12308 L
.36764 .12375 L
.37006 .12408 L
Mistroke
.37124 .12422 L
.3723 .12432 L
.37335 .12441 L
.37433 .12446 L
.37537 .1245 L
.37649 .12451 L
.37765 .12448 L
.37887 .12442 L
.37991 .12435 L
.38106 .12423 L
.38631 .1235 L
.3889 .12312 L
.39004 .12297 L
.39129 .12283 L
.39241 .12274 L
.39346 .12267 L
.39456 .12264 L
.39575 .12263 L
.39699 .12267 L
.39829 .12275 L
.39939 .12285 L
.40061 .12299 L
.40585 .12382 L
.40874 .12428 L
.41015 .12445 L
.41145 .12458 L
.41269 .12466 L
.41399 .1247 L
.4153 .12468 L
.41604 .12465 L
.41674 .12461 L
.41795 .1245 L
.41905 .12437 L
.42153 .12398 L
.42633 .12308 L
.42875 .12269 L
.42942 .1226 L
.43013 .12252 L
.43143 .12241 L
.43254 .12236 L
.43376 .12235 L
.43503 .1224 L
.43621 .12249 L
.43732 .12262 L
.43833 .12277 L
.44059 .12318 L
.44571 .12431 L
.44711 .12458 L
.4486 .12482 L
.44987 .12497 L
Mistroke
.45059 .12503 L
.45126 .12507 L
.45257 .1251 L
.4538 .12506 L
.45491 .12497 L
.45612 .12482 L
.45743 .12459 L
.45883 .12429 L
.46135 .12365 L
.46394 .12294 L
.46635 .12235 L
.46767 .12209 L
.46888 .12191 L
.46956 .12184 L
.47021 .12179 L
.4709 .12176 L
.47164 .12175 L
.47234 .12177 L
.4731 .12182 L
.4739 .12191 L
.47465 .12202 L
.476 .12228 L
.47744 .12265 L
.48277 .12444 L
.48543 .12529 L
.48673 .12562 L
.4879 .12585 L
.48915 .12601 L
.48984 .12605 L
.49048 .12607 L
.49119 .12605 L
.49183 .12601 L
.49255 .12592 L
.4933 .12579 L
.49445 .12552 L
.49568 .12514 L
.4979 .12425 L
.50295 .12179 L
.50532 .12078 L
.50597 .12056 L
.50666 .12036 L
.50788 .1201 L
.50903 .11998 L
.5101 .11998 L
.51127 .12013 L
.51252 .12045 L
.51321 .12069 L
.51396 .12102 L
.51532 .12176 L
.51787 .12356 L
Mistroke
.52271 .12762 L
.52417 .1287 L
.52553 .12953 L
.52622 .12986 L
.52695 .13013 L
.52777 .13032 L
.52852 .13039 L
.52984 .13022 L
.53058 .12994 L
.53127 .12956 L
.53254 .12854 L
.53325 .12778 L
.53389 .12696 L
.53645 .12253 L
.53789 .11921 L
.53922 .11565 L
.54425 .09856 L
.54907 .07925 L
.55425 .05989 L
.55675 .0523 L
.55913 .04663 L
.56126 .04292 L
.56247 .04142 L
.56359 .0404 L
.56474 .03969 L
.56583 .03934 L
.56702 .03928 L
.56831 .03954 L
.56958 .0401 L
.57023 .04047 L
.57093 .04093 L
.57333 .04286 L
.57597 .04524 L
.57883 .04763 L
.58014 .04853 L
.58153 .0493 L
.58272 .04979 L
.58403 .05014 L
.58471 .05025 L
.58536 .0503 L
.58658 .05026 L
.5879 .05005 L
.58864 .04985 L
.58933 .04963 L
.59173 .0486 L
.59429 .04723 L
.59648 .04603 L
.59878 .04492 L
.59998 .04444 L
.60131 .04403 L
Mistroke
.60251 .04376 L
.60363 .04361 L
.60436 .04357 L
.60506 .04357 L
.60636 .04366 L
.60709 .04377 L
.60776 .0439 L
.60929 .04429 L
.61187 .0452 L
.61462 .04632 L
.6169 .0472 L
.61935 .04797 L
.62004 .04813 L
.62076 .04828 L
.62205 .04847 L
.62326 .04855 L
.62457 .04854 L
.62522 .0485 L
.6259 .04843 L
.62712 .04824 L
.62843 .04795 L
.62987 .04756 L
.63487 .04593 L
.6372 .04525 L
.63848 .04494 L
.6397 .04472 L
.64083 .04457 L
.64206 .04448 L
.64318 .04447 L
.64421 .04452 L
.64541 .04464 L
.6467 .04485 L
.64792 .0451 L
.64904 .04537 L
.65158 .04609 L
.65437 .04691 L
.65569 .04726 L
.6571 .04758 L
.65842 .04782 L
.65963 .04797 L
.66034 .04803 L
.661 .04807 L
.66172 .04808 L
.66248 .04807 L
.66376 .04798 L
.66449 .0479 L
.66518 .0478 L
.67014 .04663 L
.67276 .04587 L
.6742 .04548 L
Mistroke
.67556 .04515 L
.67685 .0449 L
.67753 .04479 L
.67824 .04471 L
.67951 .04461 L
.68068 .0446 L
.68185 .04467 L
.68294 .04481 L
.68414 .04505 L
.68543 .04539 L
.68781 .04627 L
.69041 .04753 L
.69512 .05033 L
.70395 .05567 L
.74474 .082 L
.78402 .10733 L
.82178 .13192 L
.86199 .15747 L
.88047 .16976 L
.88553 .17516 L
.88832 .17773 L
.88968 .17879 L
.89094 .17962 L
.89211 .18026 L
.89339 .18082 L
.89468 .18122 L
.89539 .18137 L
.89605 .18148 L
.89721 .18157 L
.89828 .18158 L
.89951 .1815 L
.90068 .18138 L
.90192 .18123 L
.90309 .1811 L
.90374 .18105 L
.90444 .18102 L
.90566 .18105 L
.90683 .18122 L
.90807 .18159 L
.90912 .1821 L
.91027 .18289 L
.91164 .18418 L
.91289 .18574 L
.91569 .1907 L
.91828 .19722 L
.92073 .20507 L
.93097 .24974 L
.93657 .27398 L
.93932 .28349 L
.94183 .29031 L
Mistroke
.94283 .2925 L
.94393 .29453 L
.94497 .29614 L
.94592 .29731 L
.94703 .29836 L
.94821 .29913 L
.9493 .29955 L
.95033 .2997 L
.95146 .29965 L
.95267 .29939 L
.9537 .29903 L
.95482 .29853 L
.95737 .29727 L
.95848 .29676 L
.95969 .29628 L
.96079 .29597 L
.9618 .29579 L
.96277 .29576 L
.96381 .29587 L
.96489 .29616 L
.9659 .29661 L
.96702 .29729 L
.96822 .29826 L
.97025 .30037 L
.97238 .30316 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`25ooooo`Co0000KOooool0
02Oooooo0_l00026ooooo`05o`000?ooooooooooooooool000001?ooool6o`0000Cooooo1_l00003
ooooo`Go0000D?ooool002Oooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`02oooo
o`Go00001?ooool5o`0000Gooooo1?l00005ooooo`;o0000C_ooool002Oooooo00?o0000oooooooo
ool0Q?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04_ooooo000Wooooo`03o`00
0?oooooooooo08Cooooo00?o0000ooooooooool08_ooool2o`0004_ooooo000Wooooo`;o0000Q?oo
ool00ol0003oooooooooo`0Uooooo`;o0000BOooool002Oooooo00?o0000ooooooooool0Poooool0
0ol0003oooooooooo`0Wooooo`;o0000Aoooool000Sooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo
08?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`14ooooo`001oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`0[ooooo`;o0000A?ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000
Poooool00ol0003oooooooooo`0]ooooo`;o0000@_ooool000Oooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo02oooooo0_l00010ooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ool000000ol00005ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0mooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0<_ooool2o`0003gooooo0008ooooo`;o00002_ooool2o`0000;ooooo1Ol00000
0ooooooo0000o`000003o`0000Cooooo0_l00022ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0>_ooool002Oooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo03Wooooo000Wooooo`03o`000?oooooooooo087ooooo00?o0000oooooooo
ool0=oooool2o`0003Wooooo000Wooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0fooooo`009oooool2o`0008;ooooo00?o0000ooooooooool0>_oo
ool2o`0003Kooooo000Wooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0cooooo`009oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo
03kooooo0_l0000cooooo`009oooool00ol0003oooooooooo`1^ooooo`;o00001_ooool4o`0000Go
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0`ooooo`009oooool2o`0004Kooooo
;_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
@_ooool2o`00033ooooo000Wooooo`03o`000?oooooooooo04?ooooo0_l0000]ooooo`?o00001_oo
ool2o`000003ooooool0003ooooo04Kooooo00?o0000ooooooooool0;Oooool002Oooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0gooooo`;o0000BOooool2o`0002gooooo000Woooo
o`03o`000?oooooooooo043ooooo0_l00027ooooo`03o`000?oooooooooo02[ooooo000Wooooo`;o
0000?_ooool3o`0008[ooooo0_l0000Zooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
SOooool00ol0003oooooooooo`0Wooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0Vooooo`001_ooool5o`0000;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2Aooooo`;o00009_ooool0
00gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00;ooooo0_l0000iooooo`;o0000U_ooool00ol0003oooooooooo`0Sooooo`003Oooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03o`00
0?oooooooooo03Kooooo0_l0002Iooooo`;o00008oooool000gooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`2Kooooo`;o00008Oooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Co
oooo00?o0000ooooooooool0<oooool2o`000:3ooooo00?o0000ooooooooool07_ooool002Oooooo
0_l0000booooo`;o0000Xoooool00ol0003oooooooooo`0Mooooo`009oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool07?ooool002Oooooo00?o0000
ooooooooool0;_ooool2o`000:Sooooo0_l0000Looooo`009oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo0:[ooooo1Ol0000Gooooo`009oooool2o`0002cooooo0_l0002aooooo`03
o`000?oooooooooo01Gooooo000Wooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0Dooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo0;?ooooo00?o0000ooooooooool05?ooool002Oooooo00?o0000ooooooooool09oooool2
o`000;Oooooo00?o0000ooooooooool04oooool002Oooooo0_l0000Wooooo`03o`000?oooooooooo
0;Oooooo00?o0000ooooooooool04oooool002Oooooo00?o0000ooooooooool09?ooool2o`000;[o
oooo00?o0000ooooooooool04oooool002Oooooo00?o0000ooooooooool08_ooool2o`000;cooooo
00?o0000ooooooooool04oooool002Oooooo0_l0000Rooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool04oooool002Oooooo00?o0000ooooooooool07oooool2o`000<3ooooo00?o0000
ooooooooool04_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002oooo
o`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool07Oooool2o`000<;ooooo00?o0000oooo
ooooool04_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`0Booooo`001Ol0
0002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o0000a_ooool00ol0003o
ooooooooo`0Aooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0Aooooo`001oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00
0003o`0000Gooooo00?o0000ooooooooool05oooool2o`000<Wooooo00?o0000ooooooooool04Ooo
ool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0<Wo
oooo00?o0000ooooooooool04Oooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo
1Ol00004ooooo`;o00005_ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo013ooooo
000Wooooo`03o`000?oooooooooo01?ooooo0_l0003>ooooo`03o`000?oooooooooo013ooooo000W
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0c_ooool00ol0003oooooooooo`0@
ooooo`009oooool00ol0003oooooooooo`0@ooooo`;o0000dOooool00ol0003oooooooooo`0@oooo
o`009oooool2o`00013ooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`0@ooooo`00
9oooool00ol0003oooooooooo`0=ooooo`;o00005oooool2o`0000Cooooo00Co0000oooooooooooo
oooo1Ol0000Qooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00008_ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol0000Oooooo`03o`000?oooooooooo00Gooooo0ol00007ooooo`009oooool00ol0003ooooo
ooooo`0;ooooo`;o00006?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
023ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Pooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool002Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007
ooooo`Go00008Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
8?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000007_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o00002Oooool2o`0001_o
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool00007ooooo`Co0000
8Oooool01?l0003oooooooooool00008ooooo`?o00007oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo000002;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00000Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool002Oooooo
00?o0000ooooooooool01Oooool2o`0001kooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo0000023ooooo00Co0000oooooooooooo00002Oooool2o`0002;ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`00
9oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo0_l00009ooooo`?o0000
8_ooool2o`0000_ooooo00?o0000ooooooooool08Oooool2o`0000[ooooo0_l0000Rooooo`;o0000
2Oooool3o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`009ooo
ool2o`0000?ooooo0_l0003Rooooo`03o`000?oooooooooo00gooooo000Wooooo`05o`000?oooooo
ooooooooool00000iOooool00ol0003oooooo`000003o`0000Wooooo000Wooooo`04o`000?oooooo
0000o`000>Kooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o0000k_ooool0
0ol0003oooooooooo`06ooooo`008Oooooooo`0000009oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0
003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0_l00002ooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool2o`000?Oooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0
003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0?Kooooo0008
ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`3f
ooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000ooo
ool3o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000oooo
o`04o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo
0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003ooooooooo
o`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooo
ooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`00
00Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003ooooooooo
o`3fooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool001Cooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3fooooo`004oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0003gooooo`004oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo00002?oo
ool2o`000?oooooo000Dooooo`;o00002_ooool00ol0003oooooooooo`3mooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28412 L
.10458 .2574 L
.14415 .23189 L
.18221 .20724 L
.22272 .18101 L
.23179 .17393 L
.24141 .16666 L
.24644 .16378 L
.25197 .16116 L
.26171 .15681 L
.26701 .15462 L
.26854 .15411 L
.26999 .15369 L
.2713 .15338 L
.27203 .15324 L
.27271 .15313 L
.27335 .15304 L
.27405 .15297 L
.27527 .1529 L
.2765 .1529 L
.27764 .15296 L
.27888 .15308 L
.27959 .15318 L
.28025 .15328 L
.28302 .15385 L
.28541 .15444 L
.28801 .15508 L
.2892 .15534 L
.29046 .15558 L
.29154 .15574 L
.29274 .15588 L
.29344 .15593 L
.29409 .15597 L
.2948 .15598 L
.29555 .15598 L
.29681 .15592 L
.29752 .15586 L
.29819 .15579 L
.29944 .15561 L
.30059 .1554 L
.30316 .15483 L
.308 .15369 L
.30918 .15347 L
.31045 .15327 L
.31117 .15318 L
.31184 .15312 L
.31314 .15304 L
.31431 .15303 L
.3154 .15307 L
Mistroke
.31659 .15317 L
.31786 .15333 L
.31907 .15354 L
.32021 .15377 L
.32234 .15427 L
.32486 .1549 L
.3272 .15544 L
.32849 .15567 L
.32965 .15584 L
.33095 .15598 L
.33166 .15602 L
.33234 .15604 L
.33302 .15604 L
.33374 .15602 L
.33504 .15593 L
.33575 .15585 L
.33643 .15576 L
.33797 .15549 L
.34314 .15421 L
.34542 .15365 L
.34667 .15338 L
.34785 .15318 L
.34852 .15308 L
.34925 .153 L
.35052 .15291 L
.35181 .15289 L
.35299 .15293 L
.35424 .15305 L
.3554 .15322 L
.35667 .15347 L
.35803 .15378 L
.36058 .15447 L
.36336 .15524 L
.36461 .15555 L
.36594 .15583 L
.36708 .15602 L
.36833 .15617 L
.3695 .15625 L
.37076 .15625 L
.37195 .15618 L
.37304 .15606 L
.37411 .15589 L
.3751 .15569 L
.37734 .15512 L
.38188 .15375 L
.38315 .1534 L
.3845 .15308 L
.38565 .15286 L
.38692 .15269 L
.38763 .15263 L
Mistroke
.38828 .15259 L
.38903 .15258 L
.38974 .1526 L
.391 .15271 L
.39172 .1528 L
.39238 .15291 L
.3949 .15351 L
.39719 .15424 L
.39986 .15515 L
.40231 .15591 L
.40347 .1562 L
.40455 .15641 L
.40567 .15658 L
.40691 .15667 L
.40816 .15667 L
.40931 .15658 L
.41063 .15638 L
.41188 .15611 L
.41412 .15542 L
.4162 .15465 L
.41865 .15368 L
.42089 .15288 L
.42206 .15253 L
.42315 .15228 L
.42429 .15209 L
.42553 .15198 L
.4268 .15198 L
.42795 .15208 L
.42858 .15218 L
.42927 .15232 L
.43053 .15266 L
.43281 .1535 L
.43523 .15461 L
.4375 .15569 L
.43957 .15658 L
.44074 .157 L
.44201 .15735 L
.44271 .15749 L
.44336 .15759 L
.44464 .15767 L
.44585 .15761 L
.44694 .15743 L
.4482 .1571 L
.44938 .15666 L
.45209 .15529 L
.45457 .15375 L
.45751 .15196 L
.45879 .1513 L
.45946 .151 L
.46018 .15072 L
Mistroke
.46144 .15036 L
.4626 .15019 L
.46369 .15018 L
.4649 .15035 L
.46615 .15075 L
.46686 .15106 L
.4675 .1514 L
.46995 .15314 L
.47467 .15767 L
.47697 .1598 L
.47797 .16058 L
.47905 .16126 L
.48032 .1618 L
.48151 .162 L
.48217 .16197 L
.48287 .16181 L
.48412 .16119 L
.48478 .16068 L
.48548 .15999 L
.48676 .15834 L
.48827 .1557 L
.48965 .15265 L
.49213 .14574 L
.49483 .13639 L
.49974 .11643 L
.50426 .09802 L
.50663 .08959 L
.50913 .08221 L
.51046 .07901 L
.51192 .07612 L
.51324 .07407 L
.51448 .07264 L
.51575 .07163 L
.51691 .07109 L
.51755 .07094 L
.51824 .07088 L
.5195 .07104 L
.52081 .07151 L
.52203 .07218 L
.52481 .07423 L
.52774 .07665 L
.52903 .07764 L
.53043 .07859 L
.53172 .07932 L
.53292 .07984 L
.53407 .0802 L
.53529 .08043 L
.53596 .08049 L
.5367 .08049 L
.53739 .08045 L
Mistroke
.53802 .08037 L
.53923 .08012 L
.54051 .07973 L
.54539 .07763 L
.54778 .07659 L
.55 .07582 L
.55124 .07551 L
.55255 .07529 L
.55387 .07518 L
.55462 .07517 L
.55533 .07519 L
.55654 .07531 L
.55766 .07549 L
.55889 .07575 L
.56017 .07609 L
.56441 .07739 L
.56674 .07804 L
.56789 .0783 L
.56894 .0785 L
.57019 .07866 L
.57085 .07872 L
.57154 .07875 L
.57267 .07877 L
.5739 .07871 L
.57505 .0786 L
.57629 .07842 L
.57852 .07798 L
.58344 .07684 L
.58463 .0766 L
.58592 .07638 L
.58666 .07628 L
.58734 .0762 L
.58799 .07614 L
.58867 .07609 L
.58935 .07606 L
.59009 .07605 L
.59141 .07609 L
.59221 .07614 L
.59298 .07621 L
.59441 .07638 L
.59696 .07682 L
.59972 .07736 L
.60234 .07782 L
.60363 .07801 L
.6048 .07814 L
.60603 .07823 L
.60671 .07826 L
.60736 .07828 L
.60806 .07828 L
.60871 .07827 L
Mistroke
.60942 .07824 L
.61018 .07819 L
.61143 .07807 L
.61279 .0779 L
.61524 .07752 L
.61983 .07675 L
.62105 .07659 L
.62221 .07647 L
.62285 .07641 L
.62354 .07637 L
.62475 .07632 L
.62591 .07632 L
.62714 .07636 L
.62819 .07642 L
.62934 .07653 L
.63193 .07687 L
.63473 .07731 L
.63734 .07772 L
.63862 .07788 L
.63978 .078 L
.64101 .0781 L
.64234 .07815 L
.64303 .07816 L
.64377 .07816 L
.64448 .07814 L
.64513 .07811 L
.64644 .07802 L
.64718 .07795 L
.64787 .07787 L
.65077 .07746 L
.6533 .07705 L
.65469 .07684 L
.656 .07667 L
.65722 .07653 L
.65854 .07642 L
.65974 .07635 L
.66084 .07633 L
.662 .07635 L
.66327 .0764 L
.66391 .07645 L
.66459 .07651 L
.66583 .07665 L
.67126 .07748 L
.67253 .07768 L
.67391 .07788 L
.67513 .07802 L
.67643 .07813 L
.67759 .0782 L
.67888 .07822 L
.68004 .0782 L
Mistroke
.68114 .07815 L
.68228 .07806 L
.68353 .07792 L
.6858 .07759 L
.69007 .07686 L
.69248 .07651 L
.69317 .07643 L
.69382 .07636 L
.69505 .07627 L
.69621 .07622 L
.69727 .07622 L
.69844 .07626 L
.69968 .07634 L
.70454 .07705 L
.70914 .07789 L
.71037 .07808 L
.71168 .07823 L
.71237 .07829 L
.71312 .07834 L
.71381 .07837 L
.71445 .07838 L
.71567 .07836 L
.71678 .0783 L
.71801 .07818 L
.7193 .078 L
.72352 .07717 L
.72585 .07667 L
.72699 .07646 L
.72805 .07629 L
.72929 .07615 L
.72995 .0761 L
.73064 .07607 L
.73177 .07607 L
.73301 .07616 L
.73416 .07633 L
.73539 .07661 L
.73656 .07697 L
.73762 .07737 L
.74013 .0786 L
.7424 .08 L
.74748 .08374 L
.75663 .0901 L
.77736 .10205 L
.81745 .12872 L
.85603 .15434 L
.89706 .18324 L
.89949 .1856 L
.90077 .18662 L
.90213 .18751 L
.90332 .18812 L
Mistroke
.90463 .18862 L
.90582 .18891 L
.90693 .18907 L
.90761 .18911 L
.90832 .18912 L
.9096 .18907 L
.91031 .18902 L
.91097 .18896 L
.91174 .18888 L
.91246 .18881 L
.91374 .18872 L
.9149 .18871 L
.91615 .18881 L
.91686 .18894 L
.91751 .1891 L
.91861 .18949 L
.91979 .19009 L
.9209 .19084 L
.92192 .19169 L
.92441 .19441 L
.92677 .19774 L
.93658 .213 L
.93773 .21416 L
.93895 .21508 L
.93958 .21543 L
.94028 .21571 L
.9415 .21593 L
.94266 .21582 L
.9439 .21537 L
.94507 .21466 L
.94613 .2138 L
.94888 .21095 L
.95147 .20805 L
.9526 .20696 L
.95379 .20604 L
.9551 .20544 L
.9563 .20535 L
.95743 .20577 L
.95846 .20665 L
.95966 .20831 L
.96079 .21058 L
.96183 .21331 L
.9628 .21642 L
.965 .22557 L
.96743 .23904 L
.96963 .25405 L
.97458 .29467 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1iooooo`Co0000NOooool0
00Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000N_ooool01Ol0003ooooooooo
oooooooo000000?ooooo1ol000000ooooooo0000o`00000Xo`0004?ooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`02ooooo`Co
00001_ooool3o`0002Wooooo00?o0000ooooooooool0@?ooool000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o00001Oooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo03Wooooo0ol0000oooooo`001oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00
0008ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0?Oooool2o`0003gooooo0008
ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo0_l0001h
ooooo`03o`000?oooooooooo03oooooo0_l0000kooooo`009oooool00ol0003oooooooooo`1goooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool0>?ooool002Oooooo00?o0000oooooooo
ool0Moooool00ol0003oooooooooo`12ooooo`;o0000>?ooool002Oooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo03Gooooo000Wooooo`;o0000Mooo
ool00ol0003oooooooooo`16ooooo`;o0000=Oooool002Oooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo03;ooooo000Wooooo`03o`000?oooooooooo
07Kooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0aooooo`009oooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooooooo04[ooooo0_l0000aooooo`009oooool2o`0007Kooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0^ooooo`009oooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo04kooooo0_l0000^ooooo`009oooool00ol0003oooooooooo`1e
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0:oooool002Oooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`1Booooo`;o0000:oooool002Oooooo0_l0001eooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool0:?ooool000kooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1dooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool09oooool000gooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1dooooo`03o`000?oooooooooo05Kooooo0_l0000Wooooo`001_ooool5o`0000;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0??ooool3o`0000Kooooo0ol00007ooooo`?o00001_ooool3
o`0000Kooooo1?l00006ooooo`Co00001?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo02Cooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`02ooooo`;o0000>Oooool5o`000003ooooool0003o000000Ko000000?o
ooooo`000?l000001ol000000ooooooo0000o`000006o`0000;ooooo1ol00003ooooo`Ko00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo0_l0000Tooooo`003Oooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03o`00
0?oooooooooo03Kooooo0_l0000_ooooo`;o00001_ooool2o`000003ooooool0003ooooo05kooooo
00?o0000ooooooooool08Oooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0hoooo
o`?o0000H?ooool2o`00027ooooo000>ooooo`;o00002_ooool2o`0000;ooooo1Ol00004ooooo`03
o`000?oooooooooo03?ooooo0_l0002Pooooo`03o`000?oooooooooo01kooooo000Wooooo`;o0000
<oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo01gooooo000Wooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0Xoooool2o`0001gooooo000Wooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0Jooooo`009oooool00ol0
003oooooooooo`0^ooooo`;o0000Z_ooool00ol0003oooooooooo`0Iooooo`009oooool2o`0002go
oooo0_l0002]ooooo`;o00000_ooool00ol0003oooooooooo`0Dooooo`009oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo0:oooooo1Ol0000Dooooo`009oooool00ol0003ooooooooo
o`0Yooooo`;o0000]_ooool00ol0003oooooooooo`0Booooo`009oooool00ol0003oooooooooo`0W
ooooo`;o0000^Oooool00ol0003oooooooooo`0Aooooo`009oooool2o`0002Oooooo00?o0000oooo
ooooool0^Oooool00ol0003oooooooooo`0Aooooo`009oooool00ol0003oooooooooo`0Tooooo`;o
0000_Oooool00ol0003oooooooooo`02ooooo`?o00002oooool002Oooooo00?o0000ooooooooool0
8_ooool2o`000;oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000:ooooo`00
9oooool2o`0002;ooooo00?o0000ooooooooool0`?ooool4o`0000?ooooo00?o0000ooooooooool0
2?ooool002Oooooo00?o0000ooooooooool07oooool2o`000<[ooooo00?o0000ooooooooool02?oo
ool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3
o`0000Gooooo00?o0000ooooooooool07Oooool2o`000<cooooo00?o0000ooooooooool02?ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0cOooool00ol0003oooooooooo`07ooooo`001Ol00002ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o0000d?ooool00ol0003oooooooooo`07oooo
o`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0d?ooool00ol0003oooooooooo`07ooooo`001oooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo
00?o0000ooooooooool05oooool2o`000=?ooooo00?o0000ooooooooool01oooool000Oooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0=?ooooo00?o0000oooo
ooooool01oooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`;o
00005_ooool00ol0003oooooooooo`3Dooooo`03o`000?oooooooooo00Oooooo000Wooooo`03o`00
0?oooooooooo01?ooooo0_l0003Hooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`06ooooo`009oooool0
0ol0003oooooooooo`0@ooooo`;o0000foooool00ol0003oooooooooo`06ooooo`009oooool2o`00
013ooooo00?o0000ooooooooool0foooool00ol0003oooooooooo`06ooooo`009oooool00ol0003o
ooooooooo`0=ooooo`;o00005oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qoooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00008_ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Woooo
o`?o00001oooool002Oooooo00?o0000ooooooooool02oooool2o`0001Sooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00008?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool0
0ol0003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Pooooo`04o`000?oooooo
ooooo`0000Oooooo1Ol0000Qooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00000Pooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000W
ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o00002Oooool2o`0001_ooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00008_ooool01?l0003oooooooooool00007ooooo`Co00008Oooool01?l0003o
ooooooooool00008ooooo`?o0000:?ooool2o`0000Oooooo000Wooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000008?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002;ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`00000Wooooo`;o00001oooool002Oooooo00?o0000oooooooo
ool01Oooool2o`0001kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
0000023ooooo00Co0000oooooooooooo00002Oooool2o`0002;ooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`00000Vooooo`?o00001oooool002Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Oooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027o
oooo0_l0000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`;o00001oooool002Oooooo
0_l00003ooooo`;o0000j_ooool00ol0003oooooooooo`05ooooo`009oooool01Ol0003ooooooooo
oooooooo00000>cooooo00?o0000ooooooooool01Oooool002Oooooo00Co0000ooooool0003o0000
kOooool00ol0003oooooooooo`05ooooo`009oooool2o`000>oooooo00?o0000ooooooooool01Ooo
ool0027oooooool0000002Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;o
oooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo0_l0003gooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l0
0003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003g
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`00
3_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`00
0?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000go
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo00;ooooo0_l0003gooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03o`00
0?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00008ooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00002_ooool2o`0000;o
oooo1Ol00004ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003goooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooo
oooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0m_ooool000Sooooo0_l0
000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?ooool00ol0003ooooooooo
o`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000mooo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooooooo
o`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool2o`000?Oooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`3fooooo`004oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooo`005?oo
ool2o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .2839 L
.10458 .25623 L
.14415 .23047 L
.18221 .20584 L
.20342 .19275 L
.20829 .18982 L
.21345 .18703 L
.21558 .1861 L
.21786 .18528 L
.21917 .18491 L
.22037 .18464 L
.22157 .18444 L
.22272 .1843 L
.22387 .18423 L
.2251 .18422 L
.22626 .18426 L
.22731 .18433 L
.22855 .18447 L
.2299 .18466 L
.23233 .18509 L
.23495 .18559 L
.2374 .18601 L
.23874 .18619 L
.23996 .18632 L
.24065 .18638 L
.24131 .18642 L
.24201 .18645 L
.24276 .18647 L
.24394 .18646 L
.24525 .1864 L
.2459 .18636 L
.24661 .18629 L
.24789 .18615 L
.25263 .1854 L
.25489 .18501 L
.25702 .1847 L
.2582 .18456 L
.25948 .18445 L
.26064 .18439 L
.26171 .18436 L
.26286 .18437 L
.26412 .18443 L
.26544 .18453 L
.26667 .18466 L
.26889 .18498 L
.27128 .18538 L
.27409 .18587 L
.27547 .18608 L
.27675 .18624 L
Mistroke
.27791 .18636 L
.27914 .18645 L
.27985 .18648 L
.28051 .1865 L
.28175 .18649 L
.28298 .18644 L
.28367 .1864 L
.28432 .18634 L
.28563 .18619 L
.28704 .186 L
.29189 .18513 L
.29331 .18488 L
.29484 .18464 L
.29619 .18446 L
.29693 .18439 L
.29763 .18433 L
.29892 .18426 L
.2996 .18424 L
.30034 .18424 L
.30165 .18428 L
.30285 .18436 L
.30413 .1845 L
.30534 .18467 L
.30761 .18506 L
.31025 .18559 L
.31268 .18606 L
.31481 .1864 L
.31588 .18653 L
.31706 .18663 L
.31825 .18669 L
.31952 .1867 L
.32072 .18665 L
.32181 .18657 L
.32702 .18571 L
.32988 .18506 L
.33257 .18451 L
.33368 .18432 L
.33484 .18416 L
.33612 .18403 L
.3373 .18396 L
.33859 .18396 L
.33979 .18401 L
.34111 .18413 L
.34185 .18423 L
.34253 .18433 L
.34697 .18532 L
.35167 .18648 L
.35285 .18671 L
.35412 .18691 L
.35485 .18699 L
Mistroke
.35552 .18705 L
.35683 .18711 L
.35799 .1871 L
.35927 .18701 L
.36047 .18686 L
.36159 .18666 L
.3643 .186 L
.36675 .18527 L
.3694 .18446 L
.37079 .18409 L
.37226 .18375 L
.37355 .18353 L
.37428 .18344 L
.37496 .18338 L
.37616 .18334 L
.37745 .18338 L
.37876 .18353 L
.38001 .18375 L
.38112 .18402 L
.38234 .18438 L
.38687 .18605 L
.38925 .18694 L
.39054 .18735 L
.39175 .18767 L
.39245 .18782 L
.39308 .18793 L
.39379 .18802 L
.39454 .18808 L
.39586 .18808 L
.3971 .18797 L
.39836 .18773 L
.39952 .18741 L
.40078 .18696 L
.40213 .18638 L
.40695 .18387 L
.40823 .18322 L
.40961 .18259 L
.41084 .18213 L
.41214 .18177 L
.41295 .18163 L
.41368 .18155 L
.41442 .18153 L
.41511 .18157 L
.41641 .18179 L
.41715 .182 L
.41782 .18224 L
.41906 .18282 L
.42041 .18364 L
.42314 .18575 L
.42566 .18799 L
Mistroke
.42841 .19031 L
.42966 .19118 L
.43035 .19158 L
.43099 .1919 L
.43213 .19229 L
.43338 .19244 L
.43458 .19227 L
.43573 .19178 L
.43675 .19105 L
.43787 .18992 L
.43909 .18829 L
.44038 .18608 L
.4427 .18089 L
.44542 .17299 L
.44836 .16263 L
.45368 .14141 L
.45883 .12216 L
.46134 .11455 L
.46364 .10905 L
.46476 .10689 L
.46599 .10496 L
.46715 .10353 L
.46822 .10254 L
.46935 .10183 L
.4706 .10142 L
.47191 .10138 L
.47314 .10164 L
.47441 .10218 L
.47575 .10299 L
.47816 .10484 L
.48077 .10708 L
.48357 .10928 L
.48497 .11018 L
.4863 .11086 L
.48749 .11133 L
.48878 .11165 L
.49 .11179 L
.4913 .11177 L
.49241 .11162 L
.49362 .11133 L
.49506 .11085 L
.49636 .1103 L
.49931 .10887 L
.5021 .10752 L
.50332 .107 L
.50463 .10652 L
.50591 .10615 L
.50709 .10591 L
.50822 .10576 L
.50941 .1057 L
Mistroke
.51066 .10575 L
.51183 .10588 L
.51312 .10611 L
.51449 .10645 L
.51888 .1079 L
.52119 .10869 L
.52364 .10938 L
.52502 .10967 L
.5258 .1098 L
.52654 .10988 L
.52783 .10998 L
.52855 .10999 L
.52922 .10998 L
.53045 .1099 L
.53114 .10983 L
.53179 .10974 L
.5331 .10951 L
.53449 .10921 L
.5393 .10795 L
.54192 .10733 L
.54321 .10708 L
.54438 .10691 L
.5456 .10678 L
.54692 .10671 L
.54761 .1067 L
.54836 .10671 L
.54906 .10674 L
.54972 .10679 L
.55085 .1069 L
.5521 .10707 L
.55464 .10754 L
.55999 .10867 L
.56145 .10892 L
.56225 .10904 L
.56299 .10914 L
.56431 .10927 L
.56501 .10931 L
.56575 .10934 L
.56645 .10936 L
.5671 .10935 L
.5678 .10934 L
.56855 .1093 L
.56981 .1092 L
.57053 .10912 L
.5712 .10904 L
.57615 .10822 L
.57856 .1078 L
.58085 .10746 L
.58212 .10732 L
.58278 .10726 L
Mistroke
.5835 .10721 L
.58475 .10715 L
.58591 .10714 L
.58716 .10717 L
.58786 .1072 L
.58852 .10725 L
.58985 .10736 L
.59127 .10753 L
.5962 .10826 L
.59764 .10847 L
.59919 .10868 L
.60057 .10883 L
.60132 .10889 L
.60203 .10894 L
.60334 .10901 L
.60403 .10903 L
.60478 .10903 L
.60543 .10903 L
.60611 .10901 L
.60733 .10896 L
.6086 .10887 L
.60975 .10876 L
.61232 .10845 L
.61697 .10784 L
.61823 .1077 L
.61957 .10757 L
.62027 .10752 L
.62104 .10747 L
.62173 .10743 L
.62239 .10741 L
.62368 .10739 L
.62485 .1074 L
.62551 .10742 L
.62621 .10745 L
.6275 .10752 L
.63239 .10802 L
.63496 .10832 L
.63636 .10847 L
.63766 .1086 L
.63891 .1087 L
.64004 .10876 L
.6413 .10881 L
.64199 .10883 L
.64265 .10884 L
.64379 .10883 L
.64484 .1088 L
.646 .10875 L
.64722 .10867 L
.64993 .10843 L
.65246 .10817 L
Mistroke
.65548 .10787 L
.6568 .10776 L
.65824 .10766 L
.65951 .1076 L
.6607 .10756 L
.66183 .10755 L
.66304 .10756 L
.66371 .10758 L
.66444 .1076 L
.66575 .10767 L
.66703 .10775 L
.66821 .10785 L
.6729 .10828 L
.67548 .10849 L
.67676 .10857 L
.67793 .10863 L
.67904 .10867 L
.68021 .10869 L
.68138 .1087 L
.68268 .10868 L
.68376 .10864 L
.68492 .10859 L
.68702 .10845 L
.69226 .10802 L
.69365 .10791 L
.69512 .10782 L
.69584 .10778 L
.69652 .10774 L
.69779 .1077 L
.69897 .10767 L
.70005 .10767 L
.70124 .10768 L
.70251 .10771 L
.70378 .10776 L
.70497 .10783 L
.70767 .10801 L
.71264 .10838 L
.71401 .10846 L
.71475 .1085 L
.71546 .10853 L
.71612 .10855 L
.71683 .10857 L
.71807 .10859 L
.71926 .1086 L
.72057 .10858 L
.72123 .10857 L
.72194 .10855 L
.72321 .10849 L
.72569 .10835 L
.72794 .1082 L
Mistroke
.73015 .10804 L
.7325 .1079 L
.73373 .10784 L
.73438 .10781 L
.73508 .10779 L
.73631 .10776 L
.73746 .10774 L
.73856 .10775 L
.73975 .10777 L
.741 .1078 L
.74216 .10785 L
.74425 .10796 L
.74647 .1081 L
.74889 .10827 L
.75022 .10835 L
.75148 .10843 L
.75265 .10848 L
.75392 .10853 L
.75508 .10856 L
.75616 .10857 L
.7574 .10856 L
.75852 .10854 L
.75982 .1085 L
.76104 .10844 L
.76362 .10828 L
.7664 .10806 L
.76926 .10784 L
.77081 .10774 L
.77157 .1077 L
.77226 .10767 L
.7735 .10763 L
.77419 .10763 L
.77483 .10763 L
.77553 .10764 L
.77618 .10766 L
.77689 .1077 L
.77764 .10775 L
.77887 .10787 L
.78019 .10804 L
.78143 .10825 L
.78257 .10849 L
.78535 .10926 L
.788 .11022 L
.7928 .11252 L
.79792 .11563 L
.80713 .12212 L
.82801 .13529 L
.86958 .16137 L
.87973 .16914 L
.88527 .17432 L
Mistroke
.88798 .17665 L
.89045 .17844 L
.89272 .17974 L
.89376 .18021 L
.89486 .18062 L
.89604 .18095 L
.89713 .18118 L
.89831 .18134 L
.8996 .18144 L
.9009 .18148 L
.90209 .1815 L
.9034 .18153 L
.90406 .18157 L
.90478 .18163 L
.906 .1818 L
.9073 .18214 L
.90853 .18264 L
.90965 .18329 L
.91079 .18417 L
.91205 .18544 L
.91336 .18713 L
.9146 .18909 L
.9168 .19358 L
.91916 .19985 L
.92455 .21947 L
.92947 .24187 L
.93407 .26322 L
.93649 .27345 L
.93907 .28286 L
.94156 .29012 L
.94381 .29501 L
.94489 .29679 L
.94607 .29829 L
.94717 .29933 L
.94819 .29997 L
.94909 .30031 L
.94994 .30046 L
.9507 .30046 L
.95153 .30032 L
.95243 .30005 L
.95339 .29964 L
.9551 .29868 L
.95821 .29673 L
.95906 .29625 L
.95995 .29582 L
.96072 .29551 L
.96155 .29526 L
.96244 .2951 L
.96327 .29507 L
.96425 .29518 L
Mistroke
.96514 .29543 L
.96597 .2958 L
.96688 .29634 L
.96851 .29771 L
.97046 .29993 L
.97251 .30287 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0K_ooool2o`0008Kooooo
000Wooooo`03o`000?oooooooooo06gooooo00Co0000ooooool0003o00001_ooool3o`0007cooooo
000Wooooo`;o0000KOooool2o`0000?ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000
o`000014o`0003Oooooo000Wooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool00ooo
ool4o`0000Oooooo00?o0000ooooooooool0?oooool2o`0003Gooooo000Wooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool0D_ooool2o`0003?ooooo000Wooooo`03o`000?oooooooooo
06cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0`ooooo`009oooool2o`0006co
oooo00?o0000ooooooooool0E_ooool2o`00033ooooo000Wooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool0F?ooool2o`0002kooooo000Wooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`0[ooooo`009oooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo05cooooo0_l0000[ooooo`009oooool2o`0006_ooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`0Xooooo`003_ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo06[ooooo00?o0000oooooooo
ool0Goooool2o`0002Sooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02Gooooo0006ooooo`Go00000_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool09?oo
ool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo00;ooooo0_l0001Zooooo`03o`000?oooooooooo06Cooooo0_l0000Tooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Qooooo`00
3Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Sooooo0_l0000Qooooo`003_ooool2o`00
00[ooooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool07_ooool002Oooooo0_l0001Yooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool07Oooool002Oooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`1/ooooo`;o00007Oooool002Oooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`1_ooooo`;o00006oooool002Oooooo00?o0000ooooooooool0;oooool3o`0000Kooooo0ol00006
ooooo`Co00001_ooool4o`0000Gooooo1Ol00005ooooo`Co00001Oooool00ol0003oooooooooo`1`
ooooo`Go00005oooool002Oooooo0_l0000^ooooo`;o00000oooool6o`0000?ooooo1ol00003oooo
o`Ko00001?ooool6o`0000Cooooo1Ol00004ooooo`;o00000_ooool00ol0003oooooooooo`1eoooo
o`;o00005_ooool002Oooooo00?o0000ooooooooool0:oooool2o`0003Kooooo1?l0001hooooo`03
o`000?oooooooooo01Cooooo000Wooooo`03o`000?oooooooooo02Wooooo0_l0002dooooo`03o`00
0?oooooooooo01Cooooo000Wooooo`03o`000?oooooooooo02Oooooo0_l0002gooooo`03o`000?oo
oooooooo01?ooooo000Wooooo`;o00009oooool00ol0003oooooooooo`2gooooo`03o`000?oooooo
oooo01?ooooo000Wooooo`03o`000?oooooooooo02Cooooo0_l0002jooooo`03o`000?oooooooooo
01?ooooo000Wooooo`03o`000?oooooooooo02;ooooo0_l0002mooooo`03o`000?oooooooooo01;o
oooo000Wooooo`;o00008_ooool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo01;ooooo
000Wooooo`03o`000?oooooooooo01oooooo0_l00030ooooo`03o`000?oooooooooo01;ooooo0008
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol00005
ooooo`03o`000?oooooooooo01gooooo0_l00032ooooo`03o`000?oooooooooo01;ooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo0<?ooooo00?o0000ooooooooool04Oooool000Go00000_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`;o00006oooool2o`000<Kooooo00?o0000ooooooooool04Oooool000Oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo0<Kooooo00?o0000ooooooooool04Oooool000Oooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`00
0?oooooooooo01Oooooo0_l0003:ooooo`03o`000?oooooooooo013ooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo
013ooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool2o`0001Ko
oooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0@ooooo`009oooool00ol0003ooooo
ooooo`0Cooooo`;o0000c_ooool00ol0003oooooooooo`0@ooooo`009oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo0<oooooo00?o0000ooooooooool03oooool002Oooooo00?o0000
ooooooooool04?ooool2o`000=;ooooo00?o0000ooooooooool03oooool002Oooooo0_l0000@oooo
o`03o`000?oooooooooo0=;ooooo00?o0000ooooooooool03oooool002Oooooo00?o0000oooooooo
ool03Oooool2o`0001Oooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00008Oooool2o`00
00Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00007oooool00ol0
003oooooooooo`05ooooo`?o00001oooool002Oooooo00?o0000ooooooooool02oooool2o`0001So
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000Woooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00027ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`009oooool2o`0000Wooooo0_l0000Kooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0002;ooooo00Co0000oooooooooooo00001oooool4o`00027ooooo00Co0000oooooooo
oooo00002?ooool3o`0001oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`009oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00000Rooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
8_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000007oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Go
oooo0_l0000Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000P
ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000Rooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000007oooool00ol0003oooooooooo`04ooooo`;o00002?ooool002Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Oooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03
o`000?oooooooooo027ooooo0_l0000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Qooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool002Oooooo0_l00003ooooo`;o0000
h_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo000Wooooo`05o`000?oo
ooooooooooooool00000iOooool00ol0003oooooo`000004o`0000Sooooo000Wooooo`04o`000?oo
oooo0000o`000>Kooooo0ol00003ooooo`;o00001oooool002Oooooo0_l0003_ooooo`03o`000?oo
oooooooo00Gooooo000Qoooooooo0000000Wooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo0_l0003gooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;o
oooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`;o0000moooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooo
oooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0m_ooool000Sooooo0_l0
000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oo
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooooooo
ool0m_ooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000
1Oooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`02ooooo`;o0000moooool000gooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_oo
ool000gooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co0000
1Oooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`3fooooo`003_ooool2o`0000[o
oooo0_l00002ooooo`Go00001?ooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool2o`000?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3f
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000moooool000Oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o00001Oooool0
0ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0?Kooooo
0008ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0000Gooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`000?Oooooo000Cooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00008ooooo`;o0000
ooooool001Cooooo0_l0000:ooooo`03o`000?oooooooooo0?gooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28376 L
.10458 .25579 L
.12507 .24426 L
.13506 .23714 L
.14415 .22992 L
.1536 .22424 L
.16254 .22026 L
.16712 .21834 L
.17197 .2165 L
.1745 .21574 L
.17585 .21541 L
.17729 .21514 L
.17797 .21504 L
.17862 .21496 L
.17983 .21486 L
.18097 .21483 L
.18221 .21485 L
.18285 .21488 L
.18354 .21493 L
.18476 .21507 L
.18608 .21527 L
.18752 .21554 L
.19253 .21666 L
.19486 .21714 L
.19615 .21734 L
.19736 .2175 L
.1985 .2176 L
.19973 .21765 L
.20085 .21766 L
.20188 .21762 L
.20308 .21752 L
.20437 .21737 L
.20671 .21697 L
.21205 .21582 L
.2148 .21531 L
.21618 .21513 L
.21696 .21506 L
.21769 .21501 L
.21899 .21496 L
.22018 .21498 L
.22084 .21501 L
.22156 .21506 L
.22285 .2152 L
.2278 .21614 L
.23053 .21676 L
.23188 .21704 L
.23312 .21727 L
.23438 .21746 L
.23552 .21759 L
Mistroke
.23679 .21768 L
.23749 .21771 L
.23814 .21771 L
.23929 .21768 L
.24035 .2176 L
.24151 .21747 L
.24273 .21729 L
.24791 .21615 L
.25045 .21557 L
.25155 .21534 L
.25275 .21514 L
.25405 .21497 L
.25529 .21487 L
.25597 .21484 L
.2567 .21483 L
.25801 .21487 L
.25869 .21491 L
.25942 .21498 L
.26075 .21517 L
.26233 .21546 L
.26377 .21578 L
.26853 .21698 L
.2699 .21729 L
.27119 .21754 L
.27235 .21771 L
.2736 .21784 L
.2747 .2179 L
.27591 .21791 L
.27718 .21784 L
.27836 .21771 L
.27946 .21754 L
.28047 .21734 L
.28273 .21679 L
.28782 .21539 L
.28922 .21507 L
.28998 .21492 L
.2907 .2148 L
.29197 .21464 L
.29264 .21459 L
.29337 .21455 L
.29459 .21456 L
.29528 .21459 L
.29593 .21464 L
.29723 .21481 L
.29796 .21494 L
.29862 .21508 L
.30345 .21645 L
.30595 .21723 L
.30829 .21783 L
.30946 .21806 L
Mistroke
.31073 .21822 L
.31145 .21828 L
.31213 .21831 L
.31341 .21829 L
.31452 .2182 L
.3157 .21803 L
.31681 .2178 L
.31781 .21754 L
.32261 .2159 L
.32511 .21502 L
.32648 .21461 L
.32775 .2143 L
.32842 .21418 L
.32914 .21407 L
.32993 .21399 L
.33065 .21395 L
.33131 .21395 L
.33202 .21397 L
.33332 .21412 L
.33452 .21435 L
.33586 .21472 L
.33855 .21572 L
.3434 .21786 L
.34454 .21829 L
.34575 .21869 L
.34645 .21888 L
.34708 .21903 L
.34832 .21922 L
.3496 .21929 L
.35032 .21926 L
.35099 .2192 L
.35221 .21898 L
.3535 .21861 L
.3546 .21819 L
.35578 .21764 L
.35791 .21648 L
.36276 .21366 L
.36406 .21305 L
.36544 .21255 L
.36623 .21235 L
.36695 .21223 L
.36767 .21217 L
.36835 .21217 L
.369 .21222 L
.36969 .21234 L
.37091 .2127 L
.37222 .2133 L
.37366 .2142 L
.37844 .21841 L
.38095 .22078 L
Mistroke
.38233 .22191 L
.38362 .22276 L
.38492 .22335 L
.38561 .22353 L
.38636 .2236 L
.38768 .2234 L
.38889 .22281 L
.39011 .22179 L
.3908 .22101 L
.39144 .22015 L
.39386 .21571 L
.39623 .20961 L
.39837 .20273 L
.40318 .18397 L
.40836 .16253 L
.41108 .15252 L
.41396 .14384 L
.41648 .1382 L
.41791 .13588 L
.4186 .13499 L
.41925 .13427 L
.42048 .13327 L
.4216 .13271 L
.42281 .13247 L
.42412 .13259 L
.43344 .13919 L
.43599 .14096 L
.43728 .14163 L
.43802 .14193 L
.43868 .14215 L
.43989 .14241 L
.44118 .14252 L
.44237 .14246 L
.44349 .14227 L
.44413 .14211 L
.44483 .1419 L
.44625 .14137 L
.44879 .14019 L
.45155 .13883 L
.45308 .13815 L
.45453 .13761 L
.45586 .13721 L
.45662 .13704 L
.45732 .13691 L
.45856 .13678 L
.45988 .13676 L
.46053 .1368 L
.46123 .13687 L
.46251 .13707 L
.46375 .13735 L
Mistroke
.46489 .13767 L
.46929 .13915 L
.47171 .13991 L
.4729 .14022 L
.474 .14045 L
.47529 .14065 L
.47598 .14071 L
.4767 .14076 L
.47787 .14078 L
.47917 .14071 L
.48036 .14058 L
.48165 .14036 L
.48399 .13984 L
.48911 .13851 L
.49036 .13823 L
.49169 .13799 L
.49245 .13788 L
.49315 .1378 L
.49385 .13773 L
.49451 .13769 L
.49568 .13767 L
.49691 .13771 L
.49797 .13779 L
.49913 .13792 L
.50038 .13811 L
.50172 .13837 L
.50414 .13889 L
.5067 .13945 L
.5081 .13972 L
.50941 .13993 L
.51053 .14007 L
.51173 .14018 L
.51238 .14022 L
.51307 .14024 L
.51429 .14024 L
.51561 .14017 L
.51635 .14011 L
.51702 .14004 L
.51957 .13968 L
.52257 .13911 L
.52535 .13859 L
.52659 .13839 L
.52775 .13824 L
.52897 .13811 L
.52961 .13806 L
.53031 .13803 L
.53099 .138 L
.53175 .138 L
.53246 .13801 L
.53312 .13803 L
Mistroke
.53436 .13811 L
.53506 .13817 L
.53569 .13824 L
.5381 .13859 L
.54072 .13904 L
.5432 .13947 L
.54546 .13978 L
.54668 .13991 L
.54783 .13999 L
.54905 .14004 L
.54974 .14005 L
.55038 .14004 L
.55143 .14 L
.5526 .13992 L
.55382 .13981 L
.55497 .13966 L
.56041 .1388 L
.5628 .13845 L
.56415 .13829 L
.5654 .13819 L
.56665 .13813 L
.56779 .13811 L
.5691 .13813 L
.57034 .1382 L
.57164 .13831 L
.57284 .13845 L
.57554 .13884 L
.57824 .13928 L
.58081 .13965 L
.58223 .13981 L
.58297 .13987 L
.58377 .13993 L
.5845 .13996 L
.58517 .13999 L
.58647 .13999 L
.58772 .13995 L
.58887 .13988 L
.59013 .13976 L
.59147 .1396 L
.59617 .13887 L
.59826 .13856 L
.59941 .13841 L
.60049 .1383 L
.60178 .13819 L
.60295 .13813 L
.60405 .13811 L
.60524 .13813 L
.60652 .13819 L
.60771 .13829 L
.60903 .13843 L
Mistroke
.61044 .13862 L
.61328 .13906 L
.61597 .13949 L
.61716 .13966 L
.61844 .13981 L
.61918 .13988 L
.61984 .13993 L
.62114 .14 L
.62231 .14003 L
.62358 .14001 L
.62478 .13995 L
.62588 .13986 L
.63054 .13922 L
.63495 .1385 L
.63613 .13835 L
.63739 .13821 L
.63804 .13816 L
.63877 .13811 L
.64004 .13806 L
.64119 .13805 L
.64244 .13809 L
.64361 .13817 L
.64469 .13828 L
.64717 .13861 L
.64989 .13907 L
.65254 .13952 L
.65399 .13974 L
.65537 .13991 L
.65666 .14003 L
.6574 .14007 L
.65807 .1401 L
.65927 .14012 L
.66053 .14008 L
.66172 .14001 L
.66282 .13991 L
.66404 .13976 L
.66534 .13956 L
.67024 .13868 L
.67153 .13846 L
.67293 .13825 L
.67425 .1381 L
.67546 .138 L
.67616 .13796 L
.67692 .13794 L
.67772 .13793 L
.67846 .13795 L
.67978 .13802 L
.68052 .13808 L
.68119 .13815 L
.68391 .13855 L
Mistroke
.6865 .13904 L
.68892 .13952 L
.69025 .13975 L
.6915 .13994 L
.69265 .14008 L
.6937 .14018 L
.69487 .14025 L
.69613 .14027 L
.69739 .14023 L
.69856 .14015 L
.69985 .14001 L
.70123 .1398 L
.70659 .13872 L
.70919 .13822 L
.7105 .13802 L
.71125 .13793 L
.71193 .13786 L
.71316 .13777 L
.71447 .13774 L
.71569 .13777 L
.71685 .13785 L
.71755 .13793 L
.71819 .13801 L
.71961 .13823 L
.72217 .13876 L
.72519 .13946 L
.72651 .13975 L
.72796 .14003 L
.72914 .14022 L
.73039 .14038 L
.73109 .14044 L
.73172 .14048 L
.73296 .14051 L
.73365 .14049 L
.73429 .14047 L
.73499 .14042 L
.73573 .14034 L
.73698 .14017 L
.73835 .13991 L
.74302 .13878 L
.74549 .13817 L
.74684 .13789 L
.74812 .13768 L
.7488 .13759 L
.74953 .13752 L
.75081 .13745 L
.75212 .13745 L
.75331 .13752 L
.75446 .13766 L
.75572 .13786 L
Mistroke
.75825 .13845 L
.7631 .13983 L
.76522 .14036 L
.76642 .14059 L
.76753 .14075 L
.76882 .14087 L
.76948 .1409 L
.7702 .1409 L
.77151 .14083 L
.77274 .14069 L
.77342 .14058 L
.77414 .14043 L
.77542 .14013 L
.77832 .13924 L
.78104 .13833 L
.78237 .13791 L
.7836 .13756 L
.7847 .13731 L
.78591 .13709 L
.78712 .13695 L
.7884 .1369 L
.78964 .13695 L
.79078 .13708 L
.79209 .13732 L
.79333 .13764 L
.79794 .13933 L
.80031 .14027 L
.8016 .14073 L
.80282 .14111 L
.80352 .14128 L
.80427 .14144 L
.80558 .14163 L
.80623 .14168 L
.80692 .14169 L
.80814 .14162 L
.80929 .14146 L
.81033 .14122 L
.81153 .14084 L
.81267 .14041 L
.8169 .13834 L
.81913 .13721 L
.82036 .13667 L
.8215 .13625 L
.82274 .1359 L
.8234 .13578 L
.8241 .13569 L
.82536 .13566 L
.82651 .13579 L
.82779 .13613 L
.829 .13663 L
Mistroke
.83008 .13722 L
.83126 .13801 L
.83633 .14271 L
.84068 .14719 L
.84299 .14917 L
.84426 .15005 L
.84546 .15072 L
.84614 .15101 L
.84688 .15128 L
.84817 .15157 L
.84949 .15168 L
.85071 .15161 L
.85198 .15139 L
.85271 .15122 L
.85339 .15103 L
.85478 .15062 L
.85625 .15018 L
.85744 .1499 L
.85874 .14973 L
.85992 .14976 L
.86102 .14999 L
.86233 .15057 L
.86351 .15144 L
.86417 .15208 L
.86488 .15291 L
.86618 .15479 L
.86853 .15953 L
.87106 .16659 L
.87562 .18403 L
.88603 .23273 L
.88872 .24345 L
.89166 .25289 L
.893 .25634 L
.89444 .2594 L
.89578 .2617 L
.89701 .26337 L
.89832 .26469 L
.899 .26522 L
.89973 .26567 L
.90095 .26619 L
.90164 .26637 L
.90228 .26647 L
.90349 .26653 L
.90459 .26646 L
.90586 .26629 L
.90706 .2661 L
.9082 .26591 L
.90943 .26576 L
.91059 .2657 L
.91165 .26573 L
Mistroke
.91283 .26588 L
.91412 .2662 L
.91477 .26643 L
.91547 .26672 L
.91672 .26738 L
.91949 .26939 L
.9221 .27183 L
.92698 .27701 L
.93128 .28123 L
.93582 .28459 L
.9382 .28587 L
.94081 .28702 L
.9454 .2888 L
.94939 .29065 L
.95316 .29296 L
.96025 .29855 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
067ooooo0ol0002Booooo`009oooool00ol0003oooooooooo`1Qooooo`04o`000?ooooooooooo`00
00Gooooo0ol00018ooooo`;o00001oooool3o`0000Kooooo0ol0000/ooooo`009oooool2o`00067o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03o`0000;oooooD_l000000ooooooo
0000o`000005o`0000?ooooo00?o0000ooooooooool0:Oooool000kooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00?ooooo0ol0001Jooooo`;o00001_ooool00ol0003oooooooooo`0Xooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0JOooool2o`00
02Sooooo0006ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo06_ooooo1_l0000Sooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`00063ooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`0Pooooo`003Oooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooo`000?ooool01?l00005ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`0Pooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool08?ooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Co
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo01oo
oooo000Wooooo`;o0000Goooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo01oooooo
000Wooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`0Oooooo`009oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo07Gooooo00?o0000
ooooooooool07_ooool002Oooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01kooooo000Wooooo`;o0000G_ooool00ol0003oooooooooo`1eooooo`03
o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`0Nooooo`009oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo07Oooooo00?o0000ooooooooool07Oooool002Oooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo01gooooo000Wooooo`;o0000GOooool00ol0
003oooooooooo`1gooooo`03o`000?oooooooooo01gooooo000Wooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0Mooooo`009oooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0NOooool00ol0003ooooo
ooooo`0Looooo`009oooool2o`0002Cooooo1Ol00004ooooo`Go00001?ooool6o`0000Cooooo1Ol0
0004ooooo`Ko00001?ooool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0Looooo`009oooool00ol0003oooooooooo`0Pooooo`?o00001Oooool4
o`0000Gooooo1?l00006ooooo`Co00001Oooool4o`0000Kooooo1?l00005ooooo`04o`000?oooooo
ooooo`0007cooooo00?o0000ooooooooool07?ooool000Sooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0eooooo`Co0000O?ooool00ol0003oooooooooo`0Looooo`001oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool2o`000;So
oooo00?o0000ooooooooool07?ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`;o00007?ooool2o`000;_ooooo00?o0000ooooooooool06oooool000Oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool06oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo01Sooooo
0_l0002nooooo`03o`000?oooooooooo01_ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo01_ooooo0008ooooo`;o
00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool2o`0001Kooooo0_l00031ooooo`03
o`000?oooooooooo01_ooooo000Wooooo`03o`000?oooooooooo01?ooooo0_l00034ooooo`03o`00
0?oooooooooo01[ooooo000Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0a?oo
ool00ol0003oooooooooo`0Jooooo`009oooool00ol0003oooooooooo`0@ooooo`;o0000aoooool2
o`0001_ooooo000Wooooo`;o00004?ooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo
01Wooooo000Wooooo`03o`000?oooooooooo00gooooo0_l0000Gooooo`;o00001?ooool01?l0003o
ooooooooooooool5o`00027ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol0000Roooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00008_ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0001Kooooo1Ol0000<ooooo`?o00001oooool002Oooooo00?o0000oooooooo
ool02oooool2o`0001Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000P
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool08?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Kooooo000Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001ooo
ool5o`00027ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`009oooool2o`0000Wooooo0_l0000Koooo
o`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`0002;ooooo00Co0000oooooooooooo00001oooool4o`00027o
oooo00Co0000oooooooooooo00002?ooool3o`0001gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00000Rooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool08_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03
o`000?oooooooooo00Gooooo0_l0000Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo0_l0000Rooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000007_ooool3o`0000Gooooo0_l00008ooooo`009oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01oooooo0_l00009ooooo`?o00008_ooool2o`0000_o
oooo00?o0000ooooooooool08Oooool2o`0000[ooooo0_l0000Rooooo`;o00002Oooool3o`0002;o
oooo0_l00004ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o00000oooool2o`000>Gooooo
00?o0000ooooooooool02_ooool002Oooooo00Go0000ooooooooooooooooo`00003Xooooo`;o0000
2_ooool002Oooooo00Co0000ooooool0003o0000joooool00ol0003oooooooooo`07ooooo`009ooo
ool2o`000>kooooo00?o0000ooooooooool01_ooool0027oooooool0000002Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000Wooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`05ooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo0008ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo0?Ko
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003
o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003ooooo
ooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003goooo
o`009oooool00ol0003oooooooooo`3fooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`003Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooo`000?ooool01?l00005ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo
0?Kooooo000>ooooo`;o00002_ooool2o`0000;ooooo1Ol00004ooooo`;o0000moooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2
o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000Sooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005
ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0003goooo
o`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooool000000ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooooooool0m_ooool000Sooooo0_l0000:ooooo`;o00000_ooool5o`000003ooooool0
003o000000?o00001?ooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Dooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`004ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
m_ooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000
moooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?oo
ooooooooo`0000Sooooo0_l0003oooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool0oOoo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .284 L
.08255 .27075 L
.10458 .25687 L
.11448 .25094 L
.11709 .24946 L
.11992 .24804 L
.12122 .24749 L
.1226 .24698 L
.12379 .24661 L
.12507 .24629 L
.12635 .24605 L
.12752 .24591 L
.1287 .24583 L
.12982 .24583 L
.13112 .24588 L
.13233 .246 L
.13302 .24609 L
.13365 .24619 L
.13506 .24644 L
.13939 .24737 L
.14169 .24784 L
.14295 .24806 L
.14415 .24823 L
.14547 .24837 L
.14667 .24844 L
.1478 .24847 L
.14903 .24844 L
.15032 .24836 L
.15098 .2483 L
.1517 .24821 L
.15418 .24783 L
.15899 .24687 L
.16109 .24648 L
.16221 .24631 L
.1634 .24616 L
.1647 .24605 L
.16592 .24599 L
.16663 .24597 L
.1673 .24598 L
.16857 .24603 L
.16924 .24608 L
.16996 .24615 L
.17124 .2463 L
.17414 .2468 L
.17684 .24735 L
.1794 .24785 L
.18171 .24822 L
.18301 .24836 L
.18422 .24845 L
Mistroke
.18545 .24849 L
.18662 .24848 L
.18766 .24843 L
.18879 .24833 L
.19002 .24819 L
.19132 .24798 L
.19365 .24754 L
.19619 .24699 L
.1989 .24644 L
.20022 .24622 L
.20146 .24605 L
.20258 .24595 L
.20379 .24587 L
.20484 .24586 L
.206 .24588 L
.2072 .24596 L
.20833 .24609 L
.20939 .24623 L
.21035 .2464 L
.21253 .24684 L
.21511 .24744 L
.21755 .24798 L
.21974 .24837 L
.22097 .24853 L
.22211 .24863 L
.22321 .24868 L
.22442 .24868 L
.22568 .24862 L
.22686 .2485 L
.22814 .24832 L
.22931 .24811 L
.23193 .24752 L
.23423 .24693 L
.23668 .24634 L
.23876 .24593 L
.23995 .24576 L
.24107 .24564 L
.24234 .24558 L
.24352 .24558 L
.2448 .24566 L
.24545 .24572 L
.24616 .24581 L
.24755 .24605 L
.24903 .24637 L
.2517 .24709 L
.25423 .24782 L
.2566 .24843 L
.25788 .2487 L
.25906 .2489 L
.26037 .24904 L
Mistroke
.2611 .24908 L
.26178 .2491 L
.2631 .24906 L
.26433 .24895 L
.26503 .24885 L
.26567 .24874 L
.2671 .24843 L
.27201 .2469 L
.27475 .246 L
.2762 .2456 L
.27699 .24542 L
.27772 .24527 L
.27842 .24515 L
.27906 .24507 L
.27977 .245 L
.28053 .24496 L
.28116 .24496 L
.28185 .24498 L
.2831 .2451 L
.28435 .24531 L
.28552 .24559 L
.28818 .24647 L
.29099 .24762 L
.29357 .24868 L
.29584 .24945 L
.29698 .24974 L
.29823 .24996 L
.29949 .25007 L
.30019 .25008 L
.30083 .25006 L
.30207 .24991 L
.30325 .24966 L
.31298 .24493 L
.31419 .24434 L
.31534 .24387 L
.31598 .24366 L
.31667 .24346 L
.31788 .24323 L
.31858 .24316 L
.31933 .24316 L
.32003 .24321 L
.32067 .24331 L
.32132 .24345 L
.32201 .24367 L
.32328 .24421 L
.32789 .24752 L
.33043 .24986 L
.33283 .25197 L
.33391 .2528 L
.33506 .25353 L
Mistroke
.33633 .25411 L
.33749 .25439 L
.33853 .25441 L
.33951 .2542 L
.34058 .2537 L
.34173 .25281 L
.34295 .25146 L
.34429 .24949 L
.34671 .24456 L
.34908 .23818 L
.35127 .23102 L
.35675 .20986 L
.36173 .19036 L
.36425 .18176 L
.36698 .1741 L
.36823 .17125 L
.36956 .16873 L
.3708 .16682 L
.37193 .16546 L
.37322 .16434 L
.37394 .16391 L
.37461 .16362 L
.37581 .16336 L
.37711 .16343 L
.3778 .16359 L
.37855 .16386 L
.37933 .16423 L
.38007 .16465 L
.38281 .16664 L
.38527 .16867 L
.3879 .1707 L
.38917 .17154 L
.39038 .1722 L
.39146 .17268 L
.39263 .17307 L
.39388 .17332 L
.3952 .17341 L
.39633 .17336 L
.39758 .17316 L
.39828 .17299 L
.39892 .17281 L
.40037 .1723 L
.40298 .17116 L
.40752 .16912 L
.40877 .16866 L
.41009 .16827 L
.41134 .16798 L
.41247 .16781 L
.41363 .16772 L
.4147 .16771 L
Mistroke
.41588 .16778 L
.41711 .16794 L
.41819 .16814 L
.4192 .16838 L
.42148 .16903 L
.4265 .17058 L
.42788 .17093 L
.42934 .17123 L
.43058 .17142 L
.43129 .17149 L
.43196 .17155 L
.43317 .17159 L
.43445 .17156 L
.43554 .17148 L
.43673 .17135 L
.43802 .17114 L
.43939 .17087 L
.44187 .17031 L
.44427 .16975 L
.44554 .16948 L
.44688 .16922 L
.44805 .16903 L
.44933 .16887 L
.4505 .16878 L
.4516 .16872 L
.45274 .16872 L
.45383 .16875 L
.4548 .16881 L
.45586 .16891 L
.45701 .16905 L
.45823 .16923 L
.46043 .16961 L
.46498 .17041 L
.46609 .17057 L
.46727 .17071 L
.46857 .17083 L
.46978 .17091 L
.47046 .17093 L
.4712 .17094 L
.47189 .17094 L
.47254 .17093 L
.47375 .17087 L
.47504 .17078 L
.47623 .17066 L
.47734 .17053 L
.47987 .17018 L
.48203 .16986 L
.48438 .16955 L
.48546 .16944 L
.48661 .16933 L
Mistroke
.48769 .16925 L
.48867 .1692 L
.4899 .16917 L
.49058 .16917 L
.49122 .16918 L
.49238 .16921 L
.49362 .16927 L
.49473 .16935 L
.49577 .16944 L
.49814 .16969 L
.50315 .17026 L
.50452 .17039 L
.50598 .17049 L
.50722 .17055 L
.50793 .17058 L
.50859 .17059 L
.50981 .1706 L
.51108 .17058 L
.51217 .17054 L
.51336 .17048 L
.51465 .17039 L
.51602 .17028 L
.5185 .17005 L
.5209 .16983 L
.52216 .16972 L
.5235 .16962 L
.52467 .16955 L
.52596 .16949 L
.52713 .16946 L
.52822 .16944 L
.52936 .16944 L
.53045 .16946 L
.53142 .1695 L
.53248 .16954 L
.53485 .16968 L
.53705 .16985 L
.53953 .17004 L
.54215 .17021 L
.54352 .17028 L
.54424 .17031 L
.54502 .17034 L
.54573 .17035 L
.54638 .17037 L
.54765 .17037 L
.54893 .17037 L
.55011 .17034 L
.5514 .1703 L
.55278 .17024 L
.55762 .16996 L
.55983 .16983 L
Mistroke
.56104 .16977 L
.5622 .16972 L
.56326 .16969 L
.56443 .16966 L
.56549 .16964 L
.56648 .16964 L
.56776 .16964 L
.56896 .16966 L
.57004 .16968 L
.57121 .16972 L
.57624 .16994 L
.57861 .17004 L
.57992 .17009 L
.58115 .17013 L
.5823 .17016 L
.58355 .17018 L
.58469 .17019 L
.58574 .1702 L
.58698 .17019 L
.58814 .17018 L
.58942 .17016 L
.59079 .17012 L
.59616 .16996 L
.5975 .16992 L
.59893 .16988 L
.60026 .16985 L
.60151 .16983 L
.60219 .16982 L
.60292 .16981 L
.6042 .1698 L
.60495 .1698 L
.60573 .16981 L
.60641 .16981 L
.60715 .16982 L
.60846 .16983 L
.60965 .16985 L
.61235 .1699 L
.61491 .16994 L
.61722 .16998 L
.6184 .17 L
.61968 .17001 L
.62089 .17002 L
.622 .17003 L
.62318 .17003 L
.62447 .17003 L
.62512 .17003 L
.62582 .17003 L
.62708 .17002 L
.63623 .16998 L
.65696 .16988 L
Mistroke
.65812 .16986 L
.65935 .16985 L
.65999 .16985 L
.66069 .16985 L
.66192 .16984 L
.66309 .16985 L
.66433 .16985 L
.66551 .16987 L
.66658 .16988 L
.66908 .16993 L
.67143 .17 L
.67404 .17007 L
.67679 .17014 L
.67812 .17017 L
.67888 .17018 L
.67959 .17018 L
.68083 .17019 L
.68153 .17019 L
.68217 .17019 L
.68291 .17018 L
.6836 .17017 L
.68435 .17015 L
.68516 .17013 L
.68664 .17008 L
.68799 .17003 L
.69339 .16977 L
.69576 .16967 L
.6964 .16965 L
.6971 .16963 L
.69835 .1696 L
.69964 .16959 L
.70087 .16959 L
.70197 .16961 L
.70316 .16964 L
.70444 .16969 L
.7058 .16976 L
.70823 .16992 L
.71088 .17012 L
.71374 .17032 L
.71512 .1704 L
.71643 .17046 L
.71761 .17049 L
.7189 .17051 L
.72011 .1705 L
.72121 .17047 L
.72247 .17042 L
.72367 .17035 L
.72579 .17017 L
.72809 .16994 L
.73062 .16966 L
Mistroke
.73201 .16951 L
.73333 .16939 L
.73456 .16929 L
.7352 .16925 L
.73589 .16921 L
.7371 .16917 L
.73822 .16916 L
.73934 .16918 L
.74055 .16923 L
.74169 .1693 L
.74274 .1694 L
.74517 .1697 L
.74772 .17009 L
.75013 .17048 L
.75271 .17084 L
.75347 .17092 L
.75418 .17099 L
.75488 .17104 L
.75553 .17108 L
.75679 .17112 L
.75745 .17112 L
.75816 .17111 L
.75946 .17104 L
.76065 .17092 L
.76131 .17084 L
.76203 .17074 L
.76334 .17051 L
.76819 .16941 L
.77096 .16878 L
.77251 .1685 L
.77324 .1684 L
.77391 .16832 L
.77522 .16822 L
.77592 .16819 L
.77665 .1682 L
.77787 .16826 L
.77857 .16833 L
.77922 .16842 L
.78424 .16976 L
.78689 .17077 L
.7897 .17181 L
.79088 .17219 L
.79215 .17252 L
.79287 .17267 L
.79354 .17278 L
.79485 .17289 L
.79596 .17287 L
.79717 .17273 L
.79843 .17245 L
.79961 .17205 L
Mistroke
.80852 .1663 L
.80978 .16547 L
.81096 .16481 L
.8122 .16429 L
.81285 .16409 L
.81355 .16396 L
.81479 .16393 L
.81597 .16419 L
.81702 .16468 L
.81817 .16553 L
.81944 .16685 L
.82083 .16882 L
.82365 .17446 L
.82627 .18162 L
.82872 .1898 L
.83391 .21001 L
.83867 .22875 L
.84302 .24281 L
.84522 .24804 L
.84645 .25035 L
.84761 .25211 L
.84888 .25356 L
.85003 .25446 L
.85127 .255 L
.85197 .25513 L
.85261 .25514 L
.85369 .25494 L
.85487 .25444 L
.85611 .25365 L
.85727 .25271 L
.86224 .24763 L
.86486 .24511 L
.8663 .24398 L
.86701 .24352 L
.86766 .24315 L
.86895 .2426 L
.86962 .2424 L
.87034 .24228 L
.8715 .24223 L
.87278 .24242 L
.87396 .2428 L
.87523 .24342 L
.87753 .245 L
.89605 .25878 L
.93743 .28415 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0EOooool3o`0006gooooo0_l0000_ooooo`00
3_ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`1Dooooo`;o0000
0_ooool00ol0003oooooooooo`03ooooo`Go00001Oooool4o`0004kooooo1?l00005ooooo`;o0000
00?oooooo`000?l00000;_ooool002Oooooo0_l0001Eooooo`03o`000?oooooooooo00;ooooo0_l0
00001?oooooo0000o`000?l00004ooooo`Ko00000_oooom@o`0000?ooooo1Ol00004ooooo`03o`00
0?oooooooooo02cooooo000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool00ooo
ool3o`0006_ooooo00?o0000ooooooooool0:oooool002Oooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo02_ooooo000Wooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0[ooooo`009oooool2o`0005Co
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0[ooooo`009oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0:_ooool002Oooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo02[ooooo000W
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0Z
ooooo`009oooool2o`0005;ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Yoooo
o`009oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo07Kooooo00?o0000oooooooo
ool0:Oooool002Oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo02Wooooo000Wooooo`;o0000D_ooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo02Wooooo000Wooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Moooool0
0ol0003oooooooooo`0Xooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`00
00;ooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool0:?ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`0Xooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0001Aooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool09oooool000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool09oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`0Vooooo`001oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo04Oooooo0_l00006ooooo`03o`000?oooooooooo07_ooooo00?o0000oooooooo
ool00oooool3o`00023ooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go0000
1?ooool2o`0001Kooooo1ol00002ooooo`Oo00000oooool6o`0000Cooooo1_l00003ooooo`Oo0000
0oooool2o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0
0_ooool2o`000003ooooool0003o000001oooooo000Wooooo`03o`000?oooooooooo01?ooooo0ol0
0005ooooo`?o00001_ooool4o`0000Kooooo1?l00006ooooo`?o00001_ooool4o`0000Kooooo00Co
0000oooooooooooo0000O_ooool2o`0000;ooooo00?o0000ooooooooool00oooool2o`0001gooooo
000Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=_ooool3o`00083ooooo0ol0
0008ooooo`03o`000?oooooooooo01[ooooo000Wooooo`03o`000?oooooooooo013ooooo0_l00038
ooooo`;o00006_ooool002Oooooo0_l0000?ooooo`;o0000c?ooool00ol0003oooooooooo`0Goooo
o`009oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`04
o`000?ooooooooooooooo`Go00008Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`00
02;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00006?ooool2o`0000gooooo0ol00007ooooo`009oooool00ol0003o
ooooooooo`0;ooooo`;o00006?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`00023ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Pooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Iooooo`;o00003?ooool00ol0003oooooooooo`06
ooooo`009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000Oooooo1Ol0
000Qooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01_ooool002Oooooo0_l00009ooooo`;o00006oooool01?l0
003oooooooooool0000:ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool0000Rooooo`04o`000?ooooooooooo`0000Oooooo1?l0000Qooooo`04
o`000?ooooooooooo`0000Sooooo0ol0000Mooooo`;o00002Oooool00ol0003oooooooooo`06oooo
o`009oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00000Rooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
8_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000007_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Go
oooo0_l0000Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000P
ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000Rooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000007oooool2o`0000Gooooo0_l00008ooooo`009oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01oooooo0_l00009ooooo`?o00008_ooool2o`0000_ooooo00?o0000oooooooo
ool08Oooool2o`0000[ooooo0_l0000Rooooo`;o00002Oooool3o`0002;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`009oooool2o`0000?ooooo0_l0003Tooooo`;o0000
3?ooool002Oooooo00Go0000ooooooooooooooooo`00003Xooooo`03o`000?oooooooooo00Wooooo
000Wooooo`04o`000?oooooo0000o`000>[ooooo0_l00009ooooo`009oooool2o`000>kooooo00?o
0000ooooooooool01_ooool0027oooooool0000002Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`05ooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000
moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool2o`000?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000
ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?oo
ool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003o
ooooooooo`3fooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo
0ol00005ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`003Oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool0
1?l00005ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o
00002_ooool2o`0000;ooooo1Ol00004ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooo
oooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Ko
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005
ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
m_ooool000Sooooo0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?oo
ool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Dooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`004oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003oooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .29687 L
.0522 .28948 L
.05756 .28627 L
.06244 .28394 L
.07286 .2798 L
.0753 .27894 L
.0779 .27812 L
.0803 .2775 L
.08148 .27726 L
.08255 .27708 L
.0838 .27692 L
.08448 .27685 L
.08514 .27681 L
.08584 .27678 L
.0865 .27677 L
.08722 .27677 L
.08798 .2768 L
.08875 .27684 L
.08957 .27691 L
.09107 .27709 L
.09388 .27757 L
.09655 .27812 L
.09941 .27869 L
.1008 .27892 L
.10212 .2791 L
.1033 .27922 L
.10458 .2793 L
.10572 .27933 L
.10697 .27931 L
.10829 .27924 L
.10952 .27912 L
.11066 .27897 L
.11172 .27881 L
.11409 .27837 L
.11649 .27788 L
.11907 .27741 L
.12055 .27719 L
.12189 .27703 L
.12254 .27698 L
.12324 .27694 L
.12452 .2769 L
.12575 .27692 L
.12646 .27695 L
.12711 .27699 L
.1278 .27706 L
.12844 .27713 L
.12986 .27732 L
.13478 .27827 L
.13743 .27879 L
Mistroke
.13883 .27902 L
.1396 .27913 L
.14032 .27921 L
.14101 .27927 L
.14175 .27933 L
.14305 .27937 L
.14437 .27936 L
.14558 .27929 L
.14685 .27917 L
.14805 .27901 L
.1503 .27861 L
.15534 .27753 L
.15746 .27715 L
.15853 .277 L
.15971 .27688 L
.16098 .2768 L
.16217 .27678 L
.16327 .27681 L
.16445 .27689 L
.16575 .27704 L
.16696 .27723 L
.16971 .27778 L
.17261 .27846 L
.17524 .27902 L
.17642 .27922 L
.1777 .2794 L
.17891 .27951 L
.18002 .27956 L
.1812 .27956 L
.1825 .27949 L
.18315 .27943 L
.18386 .27934 L
.18512 .27915 L
.18768 .27861 L
.1904 .27792 L
.19275 .27734 L
.19398 .27707 L
.19528 .27683 L
.19595 .27673 L
.19669 .27664 L
.19799 .27654 L
.19931 .27651 L
.20053 .27656 L
.20129 .27662 L
.202 .2767 L
.20334 .27692 L
.20478 .27722 L
.20634 .27762 L
.21142 .27906 L
.21265 .27936 L
Mistroke
.21398 .27963 L
.21474 .27975 L
.21543 .27984 L
.21613 .2799 L
.2168 .27994 L
.21796 .27995 L
.21919 .27989 L
.22036 .27975 L
.22142 .27957 L
.22266 .27928 L
.22401 .27891 L
.22645 .27812 L
.22881 .27732 L
.23104 .27664 L
.23228 .27634 L
.23293 .27621 L
.23362 .2761 L
.23484 .27596 L
.23597 .27592 L
.2366 .27593 L
.23729 .27597 L
.23853 .27612 L
.23925 .27625 L
.24001 .27643 L
.24137 .27681 L
.24641 .2788 L
.24893 .2798 L
.25031 .28026 L
.25162 .2806 L
.25284 .28081 L
.25416 .28091 L
.25536 .28088 L
.25647 .28074 L
.25779 .28045 L
.25902 .28005 L
.26182 .27877 L
.26747 .27563 L
.26856 .27513 L
.26971 .27469 L
.27096 .27435 L
.27212 .27417 L
.27319 .27415 L
.2742 .27426 L
.2753 .27452 L
.27648 .27497 L
.27783 .2757 L
.27911 .27656 L
.28151 .27857 L
.28606 .28275 L
.28734 .28373 L
Mistroke
.28803 .28419 L
.28868 .28455 L
.28984 .28502 L
.2911 .28522 L
.29181 .28518 L
.29248 .28502 L
.29374 .2844 L
.29444 .28385 L
.2951 .28322 L
.29658 .28128 L
.29785 .27907 L
.29905 .27651 L
.30129 .27056 L
.30632 .25264 L
.31127 .23201 L
.3165 .21224 L
.31923 .20435 L
.32068 .20105 L
.32223 .19824 L
.32296 .19718 L
.32366 .19632 L
.32496 .19511 L
.32618 .19441 L
.32687 .1942 L
.32751 .1941 L
.32866 .19417 L
.3299 .19454 L
.33107 .19513 L
.33214 .19584 L
.33726 .2002 L
.33987 .20226 L
.34114 .20307 L
.3423 .20366 L
.34353 .20412 L
.34484 .20441 L
.34552 .20448 L
.34627 .2045 L
.34697 .20446 L
.34762 .20437 L
.34887 .2041 L
.35006 .20371 L
.35228 .20274 L
.35489 .2014 L
.3573 .20018 L
.3594 .19931 L
.36058 .19893 L
.36164 .19867 L
.36281 .19848 L
.36408 .19839 L
.36527 .19842 L
Mistroke
.36637 .19854 L
.36757 .19875 L
.36885 .19907 L
.37116 .19982 L
.37641 .20171 L
.37778 .2021 L
.37849 .20227 L
.37926 .20243 L
.37993 .20254 L
.38066 .20264 L
.38196 .20273 L
.38321 .20273 L
.38392 .20269 L
.38456 .20263 L
.38575 .20247 L
.38701 .20223 L
.39193 .2009 L
.39434 .20023 L
.39657 .19973 L
.39782 .19953 L
.39914 .19939 L
.39982 .19935 L
.40046 .19933 L
.40117 .19933 L
.40192 .19936 L
.40322 .19946 L
.40446 .19962 L
.40557 .19981 L
.40678 .20005 L
.4114 .20115 L
.41262 .20143 L
.41394 .20169 L
.4151 .20188 L
.41632 .20203 L
.41736 .20212 L
.41851 .20217 L
.41955 .20217 L
.42052 .20213 L
.42169 .20204 L
.42276 .20191 L
.42515 .20152 L
.42999 .20051 L
.43243 .20008 L
.4331 .19998 L
.43381 .19989 L
.43511 .19977 L
.43629 .19971 L
.43758 .19969 L
.43879 .19974 L
.43991 .19982 L
Mistroke
.44103 .19993 L
.44204 .20007 L
.44431 .20045 L
.44945 .2014 L
.45086 .20161 L
.45163 .20171 L
.45235 .20178 L
.45362 .20188 L
.45429 .20191 L
.45501 .20193 L
.45631 .20192 L
.45704 .20189 L
.45772 .20185 L
.45896 .20174 L
.46028 .20158 L
.46509 .20078 L
.46747 .20038 L
.46877 .20019 L
.46998 .20005 L
.47102 .19996 L
.47212 .19989 L
.47335 .19986 L
.47447 .19986 L
.47576 .19992 L
.47696 .20001 L
.47827 .20015 L
.47966 .20034 L
.48457 .20115 L
.48674 .20147 L
.48793 .20161 L
.48907 .20171 L
.49012 .20178 L
.49127 .20182 L
.49231 .20183 L
.49327 .2018 L
.49453 .20173 L
.49571 .20163 L
.49791 .20136 L
.50285 .20057 L
.50511 .20025 L
.50637 .20011 L
.50752 .20001 L
.50818 .19997 L
.50888 .19994 L
.51017 .19991 L
.51146 .19994 L
.51264 .2 L
.51387 .2001 L
.51503 .20022 L
.51766 .20059 L
Mistroke
.52038 .20103 L
.52297 .20141 L
.52405 .20155 L
.5252 .20166 L
.52645 .20175 L
.52762 .20179 L
.52877 .2018 L
.52985 .20178 L
.53082 .20173 L
.53188 .20165 L
.53303 .20153 L
.5343 .20137 L
.53687 .20098 L
.53925 .2006 L
.54146 .20028 L
.54265 .20014 L
.54397 .20002 L
.54529 .19994 L
.54601 .19992 L
.54669 .19991 L
.54794 .19993 L
.54908 .19998 L
.55033 .20008 L
.55165 .20022 L
.55615 .2009 L
.55862 .2013 L
.56095 .2016 L
.56225 .20172 L
.56298 .20177 L
.56366 .20181 L
.56486 .20184 L
.56612 .20182 L
.5673 .20177 L
.56841 .20169 L
.56963 .20156 L
.57093 .20139 L
.57368 .20095 L
.5766 .20046 L
.57802 .20025 L
.57936 .20008 L
.58056 .19997 L
.58186 .19988 L
.58308 .19985 L
.58378 .19985 L
.58442 .19986 L
.58573 .19992 L
.58646 .19998 L
.58713 .20004 L
.58962 .20037 L
.59198 .20076 L
Mistroke
.59454 .20121 L
.59727 .20162 L
.59869 .20178 L
.5995 .20185 L
.60025 .20189 L
.60095 .20192 L
.60158 .20193 L
.60228 .20193 L
.60302 .20191 L
.60428 .20184 L
.60542 .20173 L
.60674 .20157 L
.60799 .20138 L
.61262 .20054 L
.61506 .20013 L
.6163 .19996 L
.61765 .19983 L
.61836 .19978 L
.61912 .19974 L
.61984 .19972 L
.6205 .19972 L
.62114 .19973 L
.62184 .19976 L
.62311 .19986 L
.628 .20061 L
.63057 .20113 L
.63328 .20163 L
.63443 .2018 L
.63566 .20195 L
.63637 .20201 L
.63701 .20205 L
.63827 .2021 L
.6394 .20209 L
.64062 .20203 L
.64178 .20192 L
.64284 .20178 L
.64539 .20134 L
.64819 .20074 L
.65093 .20015 L
.65243 .19988 L
.65318 .19977 L
.65386 .19968 L
.65515 .19956 L
.65583 .19952 L
.65655 .1995 L
.65784 .19951 L
.65901 .19957 L
.66021 .19969 L
.6615 .19988 L
.66384 .20035 L
Mistroke
.66842 .20146 L
.66963 .20173 L
.67095 .20198 L
.67219 .20218 L
.67334 .20231 L
.67399 .20236 L
.67471 .20239 L
.67546 .20241 L
.67616 .20239 L
.6774 .20232 L
.6781 .20224 L
.67874 .20216 L
.67991 .20196 L
.68119 .20169 L
.68377 .20102 L
.68649 .20026 L
.68905 .19962 L
.69046 .19935 L
.69126 .19924 L
.692 .19915 L
.6933 .19907 L
.69396 .19907 L
.69468 .19909 L
.696 .19919 L
.69721 .19937 L
.69788 .19949 L
.69861 .19965 L
.69993 .19999 L
.70484 .20158 L
.7074 .20235 L
.70884 .20268 L
.70952 .2028 L
.71016 .2029 L
.71133 .203 L
.7126 .20303 L
.71385 .20295 L
.71454 .20286 L
.71518 .20275 L
.71638 .20249 L
.71748 .20217 L
.71999 .20127 L
.72454 .19939 L
.72575 .19896 L
.72704 .19857 L
.72827 .1983 L
.72939 .19814 L
.73063 .19807 L
.73133 .19809 L
.73199 .19815 L
.73268 .19825 L
Mistroke
.73331 .19837 L
.73473 .19877 L
.73612 .1993 L
.7374 .1999 L
.74029 .20149 L
.74303 .20303 L
.74422 .20362 L
.74553 .20417 L
.74678 .20455 L
.74793 .20477 L
.74904 .20484 L
.75022 .20475 L
.75145 .20447 L
.75261 .20404 L
.75388 .20337 L
.75525 .20245 L
.75958 .19863 L
.76187 .19652 L
.76313 .1955 L
.76433 .1947 L
.76501 .19433 L
.76575 .19402 L
.76704 .19374 L
.76836 .19384 L
.76957 .19433 L
.77085 .1953 L
.77157 .19606 L
.77225 .19693 L
.77362 .19912 L
.7751 .20214 L
.77774 .20922 L
.78026 .2177 L
.78498 .23661 L
.78992 .25689 L
.79457 .2724 L
.79715 .27846 L
.7986 .28096 L
.79994 .28269 L
.80106 .28373 L
.8023 .28446 L
.80359 .28479 L
.8048 .28474 L
.80594 .28442 L
.80718 .28382 L
.80836 .28306 L
.80944 .28223 L
.81367 .27859 L
.81605 .27676 L
.81722 .27603 L
.81829 .27548 L
Mistroke
.81941 .27504 L
.82062 .27473 L
.82187 .27459 L
.82319 .27462 L
.82442 .27482 L
.82512 .275 L
.82576 .27519 L
.82819 .27617 L
.83274 .27843 L
.83397 .27898 L
.8353 .27951 L
.83653 .2799 L
.8377 .28018 L
.839 .28038 L
.84019 .28046 L
.84151 .28042 L
.84225 .28034 L
.84294 .28024 L
.84724 .2791 L
.85177 .27755 L
.85415 .2769 L
.8548 .27676 L
.85549 .27664 L
.85674 .27648 L
.85797 .2764 L
.85914 .2764 L
.86018 .27647 L
.86131 .27659 L
.86258 .2768 L
.86399 .27709 L
.86682 .27781 L
.86948 .2785 L
.87191 .27902 L
.87318 .27922 L
.87439 .27936 L
.87567 .27944 L
.87639 .27945 L
.87706 .27944 L
.87829 .27939 L
.8794 .27928 L
.88068 .27911 L
.88189 .27891 L
.88623 .27802 L
.88861 .27757 L
.88977 .27738 L
.89083 .27725 L
.89199 .27714 L
.89323 .27707 L
.89388 .27706 L
.89459 .27706 L
Mistroke
.89587 .2771 L
.89704 .27719 L
.89828 .27732 L
.90051 .27764 L
.90291 .27805 L
.90547 .27846 L
.90672 .27862 L
.90789 .27875 L
.90895 .27883 L
.91009 .27889 L
.91131 .27891 L
.9126 .27888 L
.9137 .27882 L
.91491 .27872 L
.91767 .27841 L
.91887 .27826 L
.92019 .27811 L
.92138 .27799 L
.92249 .27792 L
.92355 .27789 L
.92468 .2779 L
.92599 .27799 L
.92722 .27817 L
.92832 .2784 L
.92951 .27873 L
.93173 .27959 L
.93406 .28083 L
.93824 .28373 L
.9565 .29663 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo04Wooooo0ol0001/ooooo`Co0000>_ooool002Oooooo00?o0000oooo
ooooool0B?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool5o`0000Gooooo1?l00005oooo
o`Go00001?ooool5o`0000Cooooo1?l00006ooooo`Co00001Oooool4o`0000Gooooo1?l00006oooo
o`Co00001Oooool5o`0000Cooooo1Ol00004ooooo`05o`000?ooooooooooooooool00000>_ooool0
02Oooooo0_l00019ooooo`03o`000?oooooooooo00;ooooo1Ol00004ooooo`Go00001?ooool5o`00
00Gooooo1Ol00004ooooo`Co00001?ooool7o`0000?ooooo1Ol00004ooooo`Go00001?ooool6o`00
00Cooooo1Ol00005ooooo`Co00001Oooool4o`0000Cooooo00?o0000ooooooooool0>?ooool002Oo
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Yooooo`;o00001Oooool00ol0003o
ooooooooo`0hooooo`009oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0=oooool002Oooooo0_l00018ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0=oooool002Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo03Kooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`0fooooo`001oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1dooooo`03o`00
0?oooooooooo03Kooooo0005o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0004Oo
oooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0eooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0MOooool00ol0
003oooooooooo`0eooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo03Gooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo03Go
oooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool2o`0004Kooooo
00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0eooooo`009oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0=?ooool002Oooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo03Cooooo000Woooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0doooo
o`009oooool2o`0004Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0dooooo`00
9oooool00ol0003oooooooooo`0Vooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000ko
oooo00?o0000ooooooooool04?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;o
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003o
ooooo`000002ooooo`?o00009oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Pooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Ko
oooo0_l00003ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool002Oooooo
00?o0000ooooooooool09Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Ko
oooo0ol00005ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00001oooool5o`00
027ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co
0000oooooooooooo00001_ooool2o`0000?ooooo00Co0000ooooool0003o00009?ooool00ol0003o
ooooooooo`06ooooo`009oooool2o`0000_ooooo6_l000000ooooooo0000o`000006o`0000;ooooo
1ol00003ooooo`?o000000?oooooo`000?l000000oooool2o`00017ooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool0000Rooooo`04o`000?ooooooooooo`0000Oooooo1?l0000Q
ooooo`04o`000?ooooooooooo`0000Oooooo1_l00002ooooo`;o00000oooool7o`000003ooooool0
003o000000co00002Oooool00ol0003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`08
ooooo`;o00004Oooool00ol0003oooooooooo`06ooooo`;o00000_ooool00ol0003oooooooooo`02
ooooo`Co00000oooool00ol0003oooooo`000002o`0000Kooooo00Co0000oooooooooooo00004_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo0_l000000ooo
oooo0000o`000005ooooo`?o00001oooool2o`0000cooooo0_l00008ooooo`03o`000?oooooooooo
00Kooooo000Wooooo`03o`000?oooooooooo00Gooooo0ol0000Mooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`;o00004oooool01?l0003oooooooooool0
0009ooooo`;o00008_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo00001oooool5o`0001oooooo0_l00005ooooo`;o00002?ooool002Oooooo
00?o0000ooooooooool00oooool2o`00027ooooo0_l00009ooooo`?o00008_ooool2o`0000_ooooo
00?o0000ooooooooool08Oooool2o`0000[ooooo0_l0000Rooooo`;o00002Oooool3o`0002;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`009oooool2o`0000?ooooo00?o
0000ooooooooool0hoooool00ol0003oooooooooo`0;ooooo`009oooool00ol0003oooooooooo`02
o`000>Oooooo0_l0000;ooooo`009oooool00ol0003oooooo`00003[ooooo`;o00002Oooool002Oo
oooo0_l0003^ooooo`03o`000?oooooooooo00Kooooo000Qoooooooo0000000Wooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`009oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01Oooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`0000Cooooo00?o0000
ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`3f
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3foooo
o`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000moooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooooooo
o`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000mooo
ool002Oooooo00?o0000ooooooooool0m_ooool000kooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000moooool000gooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01Ol0003o
ooooooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003ooooooooo
o`3fooooo`003_ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool2o`000?Oooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo0008ooooo`;o0000
1?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000mooo
ool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooo000000?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo0?Kooooo0008ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo
0000o`000003o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`005?ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0m_ooool001?o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?Kooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`00
0?Oooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003o
ooooooooool00008ooooo`;o0000ooooool001Cooooo0_l0000:ooooo`03o`000?oooooooooo0?go
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02605 .30851 L
.02729 .30826 L
.02846 .30805 L
.02954 .30789 L
.03072 .30775 L
.0318 .30767 L
.03279 .30763 L
.03396 .30763 L
.03506 .30768 L
.03626 .30779 L
.03756 .30795 L
.0402 .30843 L
.04262 .30897 L
.04497 .3095 L
.04748 .30999 L
.04822 .31011 L
.04892 .3102 L
.05023 .31034 L
.05146 .31041 L
.05215 .31042 L
.05278 .31042 L
.05394 .31038 L
.05502 .31029 L
.05621 .31015 L
.05748 .30995 L
.06244 .30888 L
.06507 .30829 L
.06651 .30802 L
.06787 .30782 L
.06857 .30773 L
.06932 .30766 L
.07016 .30761 L
.07093 .30758 L
.07159 .30757 L
.07231 .30759 L
.07306 .30763 L
.07376 .30768 L
.07443 .30775 L
.07516 .30784 L
.07648 .30805 L
.07895 .30856 L
.08158 .30919 L
.08448 .30985 L
.08575 .31008 L
.08711 .31029 L
.08839 .31043 L
.08956 .3105 L
.09088 .31051 L
.09163 .31049 L
Mistroke
.09232 .31045 L
.09359 .31032 L
.0943 .31022 L
.09494 .31012 L
.09991 .30901 L
.10233 .30841 L
.10458 .30793 L
.10576 .30773 L
.10684 .30759 L
.10808 .30748 L
.10925 .30744 L
.11053 .30746 L
.1117 .30754 L
.113 .30769 L
.11437 .30792 L
.1197 .30923 L
.12231 .3099 L
.12345 .31015 L
.1247 .31038 L
.12577 .31053 L
.12676 .31064 L
.12781 .3107 L
.12893 .31071 L
.13016 .31065 L
.13132 .31054 L
.13236 .31039 L
.13349 .31017 L
.1385 .30885 L
.14095 .30815 L
.14318 .30763 L
.14431 .30743 L
.14553 .30727 L
.14669 .30718 L
.14776 .30716 L
.14889 .3072 L
.15014 .30732 L
.15145 .30752 L
.15267 .30778 L
.15811 .30941 L
.16049 .31014 L
.16175 .31047 L
.1631 .31076 L
.16379 .31088 L
.16443 .31097 L
.16565 .31108 L
.16679 .31111 L
.16803 .31106 L
.16934 .31091 L
.17 .3108 L
.17073 .31065 L
Mistroke
.17323 .30996 L
.17591 .30901 L
.17883 .30793 L
.18017 .30749 L
.18159 .30709 L
.18228 .30693 L
.18294 .30681 L
.18415 .30664 L
.18539 .30656 L
.18669 .30659 L
.18781 .3067 L
.18903 .30693 L
.19034 .30727 L
.19176 .30774 L
.1943 .30878 L
.19874 .31075 L
.19996 .3112 L
.20126 .3116 L
.20236 .31185 L
.20358 .31203 L
.2043 .31208 L
.20497 .31209 L
.2057 .31205 L
.20647 .31196 L
.20777 .3117 L
.20851 .31149 L
.20919 .31126 L
.21176 .31009 L
.2145 .30852 L
.21719 .30693 L
.21851 .30623 L
.21972 .30567 L
.22083 .30526 L
.222 .30495 L
.22317 .30478 L
.22446 .30478 L
.22576 .30499 L
.22696 .30537 L
.22828 .30599 L
.22968 .30687 L
.23463 .31118 L
.23715 .31352 L
.23838 .31453 L
.23951 .31531 L
.24054 .31587 L
.24163 .31627 L
.24273 .31643 L
.24392 .3163 L
.2446 .31607 L
.24533 .31568 L
Mistroke
.24602 .31519 L
.24666 .31461 L
.24787 .3132 L
.24915 .31123 L
.25181 .30558 L
.25474 .2971 L
.26482 .25828 L
.2673 .24913 L
.27001 .24049 L
.27257 .234 L
.2738 .23154 L
.27495 .22961 L
.27608 .22808 L
.2773 .22683 L
.27841 .22604 L
.27944 .22558 L
.28055 .22535 L
.28176 .2254 L
.28303 .22573 L
.28422 .22627 L
.28935 .22995 L
.29206 .23203 L
.29355 .23301 L
.29494 .23378 L
.29615 .23431 L
.29745 .23472 L
.29815 .23487 L
.29889 .23497 L
.29952 .23502 L
.30021 .23503 L
.30144 .23494 L
.30274 .2347 L
.30398 .23437 L
.3051 .23399 L
.31012 .23187 L
.31276 .23084 L
.31421 .23038 L
.31556 .23005 L
.31674 .22985 L
.31801 .22972 L
.31873 .22969 L
.31941 .22969 L
.3207 .22977 L
.32187 .22991 L
.32297 .2301 L
.32544 .23068 L
.33007 .23199 L
.33234 .23255 L
.33333 .23275 L
.33442 .23294 L
Mistroke
.3356 .23308 L
.33684 .23318 L
.33749 .2332 L
.33819 .23321 L
.33944 .23317 L
.34067 .23308 L
.34182 .23295 L
.34399 .23261 L
.34898 .23161 L
.35143 .23117 L
.3525 .23102 L
.35367 .23088 L
.35481 .23078 L
.35602 .23072 L
.35733 .2307 L
.35855 .23073 L
.35925 .23076 L
.35991 .23081 L
.36115 .23092 L
.36393 .23127 L
.36823 .23191 L
.37058 .23222 L
.37173 .23235 L
.37278 .23243 L
.37393 .23251 L
.37516 .23255 L
.3758 .23256 L
.3765 .23256 L
.37777 .23254 L
.37892 .23248 L
.38015 .2324 L
.38236 .2322 L
.38691 .23169 L
.3894 .23143 L
.39061 .23133 L
.39171 .23126 L
.39292 .2312 L
.39422 .23116 L
.3949 .23116 L
.39563 .23116 L
.39633 .23117 L
.39697 .23118 L
.39809 .23122 L
.39931 .23128 L
.4018 .23146 L
.40634 .23185 L
.40754 .23195 L
.40885 .23204 L
.4101 .23211 L
.41123 .23216 L
Mistroke
.41239 .2322 L
.41363 .23222 L
.41477 .23222 L
.41585 .2322 L
.4169 .23218 L
.41787 .23214 L
.42007 .23204 L
.42477 .23174 L
.42736 .23159 L
.42863 .23153 L
.42981 .23149 L
.43091 .23146 L
.43209 .23144 L
.43326 .23143 L
.43456 .23144 L
.43564 .23145 L
.4368 .23148 L
.43789 .23151 L
.4389 .23155 L
.44411 .23179 L
.44666 .23189 L
.44776 .23192 L
.44897 .23195 L
.45022 .23198 L
.45141 .23199 L
.45207 .23199 L
.45277 .23199 L
.45403 .23198 L
.45468 .23197 L
.45539 .23196 L
.45666 .23194 L
.45956 .23186 L
.46447 .23172 L
.46589 .23169 L
.46721 .23166 L
.46841 .23165 L
.4697 .23164 L
.47039 .23163 L
.47115 .23163 L
.47195 .23163 L
.47269 .23163 L
.47338 .23164 L
.47401 .23164 L
.47543 .23166 L
.47816 .23169 L
.48074 .23173 L
.48317 .23176 L
.48451 .23178 L
.48575 .23179 L
.48681 .2318 L
Mistroke
.48795 .2318 L
.48922 .23181 L
.49038 .23181 L
.49102 .23181 L
.49171 .23181 L
.49294 .2318 L
.49441 .2318 L
.49574 .2318 L
.49701 .23179 L
.49767 .23179 L
.49837 .23179 L
.49966 .23179 L
.50085 .23179 L
.50206 .23179 L
.50275 .23179 L
.50339 .23179 L
.5058 .2318 L
.50693 .2318 L
.50799 .23181 L
.50909 .23181 L
.51031 .23181 L
.51155 .2318 L
.51286 .2318 L
.51398 .23179 L
.5152 .23178 L
.51793 .23175 L
.52047 .23171 L
.52285 .23168 L
.52402 .23166 L
.52511 .23165 L
.52609 .23164 L
.52713 .23163 L
.52817 .23163 L
.52933 .23163 L
.53056 .23164 L
.53168 .23165 L
.53298 .23167 L
.53422 .23169 L
.53879 .23181 L
.54139 .23189 L
.54266 .23192 L
.54383 .23195 L
.5449 .23197 L
.54602 .23198 L
.54715 .23199 L
.54839 .23199 L
.54908 .23198 L
.54973 .23198 L
.55095 .23196 L
.55226 .23192 L
Mistroke
.55368 .23188 L
.55862 .23166 L
.56101 .23156 L
.56218 .23151 L
.56326 .23148 L
.56438 .23145 L
.5656 .23143 L
.56685 .23143 L
.56749 .23143 L
.56818 .23144 L
.56934 .23146 L
.57039 .23149 L
.57161 .23154 L
.57276 .2316 L
.57701 .23186 L
.57925 .232 L
.58165 .23212 L
.58236 .23215 L
.58303 .23218 L
.58429 .23221 L
.58547 .23222 L
.58675 .23221 L
.58745 .2322 L
.58811 .23218 L
.58934 .23214 L
.59067 .23207 L
.5921 .23197 L
.59705 .23156 L
.59947 .23136 L
.60066 .23129 L
.60173 .23123 L
.60287 .23118 L
.60409 .23116 L
.60473 .23116 L
.60542 .23116 L
.60667 .23119 L
.60773 .23123 L
.6089 .2313 L
.61127 .2315 L
.61551 .23197 L
.61799 .23224 L
.6193 .23236 L
.62002 .23242 L
.6207 .23246 L
.62135 .2325 L
.62205 .23253 L
.62326 .23256 L
.6245 .23256 L
.62564 .23253 L
.62675 .23247 L
Mistroke
.62779 .23239 L
.63015 .23213 L
.63491 .23144 L
.63762 .23106 L
.63895 .23091 L
.64018 .2308 L
.6413 .23073 L
.64249 .2307 L
.64368 .23071 L
.64499 .23077 L
.64567 .23082 L
.64639 .23088 L
.64767 .23104 L
.65056 .23152 L
.65325 .23206 L
.65579 .23257 L
.65696 .23277 L
.65819 .23295 L
.65883 .23303 L
.65954 .2331 L
.66079 .23319 L
.66192 .23321 L
.66314 .23318 L
.66429 .23309 L
.66533 .23297 L
.66663 .23276 L
.66784 .23251 L
.67056 .23181 L
.67312 .23108 L
.67553 .23043 L
.67662 .23018 L
.67777 .22996 L
.67904 .22979 L
.6802 .22971 L
.68124 .22969 L
.68221 .22974 L
.68328 .22985 L
.68442 .23005 L
.68565 .23034 L
.68697 .23074 L
.68938 .23166 L
.6939 .23361 L
.69504 .23404 L
.69626 .23444 L
.69741 .23474 L
.69845 .23492 L
.69963 .23502 L
.70074 .23501 L
.70195 .23485 L
.70325 .23452 L
Mistroke
.70388 .2343 L
.70458 .23401 L
.70598 .23329 L
.7085 .23162 L
.71332 .22786 L
.71473 .22688 L
.71607 .22612 L
.71681 .22579 L
.71762 .22553 L
.71835 .22538 L
.71903 .22534 L
.72026 .22549 L
.72096 .22572 L
.72161 .22605 L
.7223 .22651 L
.72294 .22704 L
.72436 .22864 L
.72561 .2305 L
.72677 .23263 L
.72941 .23887 L
.73472 .25654 L
.73941 .27523 L
.74449 .29454 L
.74682 .3019 L
.74929 .30817 L
.7514 .31213 L
.7526 .3138 L
.75372 .31497 L
.75438 .31549 L
.7551 .31592 L
.7564 .31636 L
.75767 .3164 L
.75885 .31612 L
.75957 .31582 L
.76025 .31546 L
.76152 .31461 L
.76436 .31214 L
.76678 .30983 L
.76937 .30757 L
.77062 .30666 L
.77181 .30594 L
.77288 .30544 L
.77404 .30504 L
.77521 .30482 L
.77646 .30476 L
.77752 .30486 L
.7787 .30512 L
.77997 .30554 L
.78133 .30615 L
.78381 .30751 L
Mistroke
.78884 .3104 L
.79006 .31096 L
.79136 .31145 L
.79212 .31167 L
.7928 .31183 L
.79348 .31196 L
.79413 .31204 L
.7953 .31209 L
.79654 .31202 L
.79759 .31186 L
.79876 .31159 L
.8 .31121 L
.80135 .31071 L
.80377 .30966 L
.80805 .30781 L
.80928 .30738 L
.81044 .30705 L
.81148 .30682 L
.8126 .30665 L
.81324 .30659 L
.81394 .30656 L
.81467 .30656 L
.81535 .30659 L
.81656 .30673 L
.81787 .30697 L
.81918 .3073 L
.82042 .30768 L
.82274 .3085 L
.82531 .30946 L
.82804 .31034 L
.82946 .31069 L
.83027 .31085 L
.83103 .31096 L
.83172 .31104 L
.83236 .31109 L
.83309 .31111 L
.83379 .31111 L
.83506 .31103 L
.8362 .31088 L
.83684 .31078 L
.83753 .31064 L
.83877 .31034 L
.8434 .30892 L
.84606 .30811 L
.84751 .30774 L
.84887 .30747 L
.85002 .3073 L
.85126 .30719 L
.85197 .30716 L
.85264 .30716 L
Mistroke
.8539 .30722 L
.85503 .30733 L
.85626 .30752 L
.85848 .30801 L
.86354 .30944 L
.86615 .3101 L
.86746 .31035 L
.86821 .31047 L
.86889 .31056 L
.87012 .31067 L
.87143 .31071 L
.87264 .31068 L
.87379 .31058 L
.87486 .31045 L
.87602 .31025 L
.87839 .30973 L
.88263 .30861 L
.88501 .30805 L
.88633 .3078 L
.88758 .30762 L
.88873 .3075 L
.89 .30744 L
.89114 .30745 L
.89221 .3075 L
.8935 .30763 L
.89415 .30772 L
.89486 .30783 L
.8973 .30833 L
.89995 .30898 L
.90279 .30967 L
.90418 .30996 L
.90549 .31019 L
.90667 .31035 L
.90795 .31046 L
.90916 .31051 L
.91045 .3105 L
.91155 .31043 L
.91276 .31031 L
.92183 .30839 L
.92404 .30796 L
.92527 .30778 L
.92639 .30767 L
.92703 .30762 L
.92772 .30759 L
.92897 .30758 L
.93022 .30763 L
.93137 .30773 L
.93258 .30788 L
.93371 .30806 L
.93629 .30859 L
Mistroke
.939 .30922 L
.94148 .30976 L
.94258 .30996 L
.94378 .31015 L
.94491 .31029 L
.94595 .31037 L
.94706 .31042 L
.94828 .31042 L
.94955 .31035 L
.95075 .31024 L
.95604 .30927 L
.95893 .30862 L
.96034 .30832 L
.96163 .30808 L
.96273 .30791 L
.96393 .30777 L
.96519 .30767 L
.96639 .30763 L
.96771 .30765 L
.96837 .30768 L
.96911 .30774 L
.9704 .30788 L
.97161 .30806 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0?Oooool3o`0006_ooooo1?l00017ooooo`001Ol00002ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo0_l0000mooooo`04o`000?ooooooooooooooo`;o00000oooool6o`0000Co
oooo1_l00004ooooo`Ko00000_oooolZo`0000;ooooo1ol00004ooooo`Go00001?ooool6o`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool00_ooool4o`00
00Kooooo1?l00006ooooo`Co00001_ooool3o`0002Sooooo0ol00007ooooo`Co00001Oooool4o`00
00Kooooo1?l00004ooooo`03o`000?oooooooooo04Cooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0@ooo
ool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0@oooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo
1Ol00004ooooo`;o0000??ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo04?ooooo
000Wooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`12ooooo`009oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo07Cooooo00?o0000
ooooooooool0@_ooool002Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1doooo
o`03o`000?oooooooooo04;ooooo000Wooooo`;o0000>oooool00ol0003oooooooooo`1dooooo`03
o`000?oooooooooo04;ooooo000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`00
0?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`0Iooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`?o00008_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001co
oooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0002Oo
oooo0ol00007ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Iooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000007?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool01_ooool002Oo
oooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool00007ooooo`Go00008Oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000007?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
02Oooooo00?o0000ooooooooool01_ooool002Oooooo0_l0000Vooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool00007ooooo`Co0000
7Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool3o`0002So
oooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Joooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000008_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00002Oooool2
o`0002;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0Nooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002Ko
oooo0_l00008ooooo`009oooool00ol0003oooooooooo`0Vooooo`;o00002Oooool3o`0000Cooooo
00?o0000ooooooooool06oooool2o`0000_ooooo00?o0000ooooooooool08Oooool2o`0000[ooooo
0_l0000Nooooo`04o`000?ooooooooooooooo`;o00002Oooool3o`0002Sooooo00?o0000oooooooo
ool01_ooool002Oooooo0_l0000hooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
?oooool002Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1jooooo`03o`000?oo
oooooooo03oooooo000Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0oooooo`009oooool00ol0003oooooooooo`0Uooooo`?o00001_ooool4o`00
00Gooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`03ooooo`Co00001oooool2o`00
02oooooo000Qoooooooo0000000Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`?o00001_ooool5o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l000000ooooooo0000
o`000004ooooo`Go00001oooool2o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool00oooool3o`0002Oooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Uooooo`?o00001Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Gooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool0m_oo
ool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o
00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooo
oooo0?Kooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0
003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
oooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0
m_ooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Go
oooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool0
0ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`00
0?l000000ol00004ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2
o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool001Cooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000Coooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3f
ooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0003g
ooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000Coooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooo
oooooooo00002?ooool2o`000?oooooo000Dooooo`;o00002_ooool00ol0003oooooooooo`3moooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .32125 L
.0522 .32852 L
.05756 .33162 L
.06244 .33391 L
.07286 .33833 L
.0753 .33929 L
.0779 .34018 L
.08011 .34079 L
.08137 .34105 L
.08255 .34125 L
.08325 .34133 L
.08392 .34139 L
.08517 .34145 L
.08587 .34146 L
.08651 .34144 L
.08723 .3414 L
.08798 .34134 L
.08875 .34125 L
.08957 .34113 L
.09107 .34086 L
.09388 .34021 L
.09655 .33954 L
.09802 .33919 L
.09941 .3389 L
.10071 .33868 L
.10139 .33859 L
.10212 .33851 L
.1034 .33843 L
.10458 .33841 L
.1057 .33845 L
.10691 .33856 L
.10805 .33871 L
.1091 .3389 L
.11409 .34012 L
.11672 .3408 L
.118 .34109 L
.11917 .3413 L
.1204 .34147 L
.12172 .34157 L
.12241 .34159 L
.12316 .34159 L
.12387 .34156 L
.12452 .34152 L
.12573 .34137 L
.12704 .34115 L
.12939 .34057 L
.13475 .33894 L
.13614 .33857 L
.13687 .3384 L
Mistroke
.13765 .33824 L
.1384 .33812 L
.13908 .33803 L
.13977 .33796 L
.14041 .33792 L
.14171 .33792 L
.1429 .33801 L
.1442 .33821 L
.14486 .33834 L
.14558 .33851 L
.1481 .3393 L
.15084 .34035 L
.15325 .34127 L
.15458 .34171 L
.15581 .34205 L
.15692 .34229 L
.15812 .34245 L
.15876 .3425 L
.15944 .34251 L
.16066 .34245 L
.16177 .34228 L
.1628 .34205 L
.16393 .3417 L
.16513 .34124 L
.17078 .33834 L
.17213 .33766 L
.17355 .33704 L
.17477 .33661 L
.17546 .33643 L
.1761 .3363 L
.17731 .33617 L
.17841 .33619 L
.17968 .3364 L
.18088 .33677 L
.18217 .33737 L
.18336 .33808 L
.18606 .34016 L
.19068 .34428 L
.19195 .34524 L
.19264 .3457 L
.19328 .34607 L
.19442 .34655 L
.19567 .3468 L
.19685 .34672 L
.19796 .34633 L
.19895 .34569 L
.20003 .34467 L
.20121 .34316 L
.20246 .34108 L
.2047 .33613 L
Mistroke
.20714 .32905 L
.20976 .31978 L
.2145 .30042 L
.2201 .2781 L
.22282 .2693 L
.22529 .26311 L
.22651 .26076 L
.22782 .25874 L
.22905 .25732 L
.23019 .25642 L
.2314 .25586 L
.23209 .25572 L
.23273 .25569 L
.23402 .25591 L
.23475 .25618 L
.23541 .2565 L
.23682 .25741 L
.23812 .25844 L
.24108 .26112 L
.24385 .26353 L
.2452 .26452 L
.24644 .26528 L
.24753 .2658 L
.24867 .26619 L
.24982 .26643 L
.25108 .2665 L
.25236 .26638 L
.25307 .26624 L
.25373 .26607 L
.25499 .26563 L
.25619 .26511 L
.26112 .26247 L
.26373 .26121 L
.2652 .26067 L
.26589 .26046 L
.26654 .26031 L
.26777 .2601 L
.26842 .26004 L
.26912 .26001 L
.2704 .26006 L
.27157 .26021 L
.27273 .26046 L
.27399 .26081 L
.27627 .26161 L
.28128 .26356 L
.2825 .26394 L
.2838 .26428 L
.28455 .26443 L
.28523 .26454 L
.28592 .26463 L
Mistroke
.28657 .26468 L
.28773 .26471 L
.28896 .26466 L
.29002 .26454 L
.29118 .26435 L
.29242 .26407 L
.29377 .26371 L
.29619 .26296 L
.29839 .26227 L
.30046 .26169 L
.30161 .26143 L
.30286 .26121 L
.30398 .26107 L
.30502 .261 L
.30624 .26098 L
.30693 .261 L
.30757 .26104 L
.30887 .26118 L
.3096 .26129 L
.31026 .26141 L
.31512 .26259 L
.31783 .26329 L
.31926 .2636 L
.32005 .26374 L
.32078 .26386 L
.32147 .26395 L
.32211 .26402 L
.32281 .26407 L
.32357 .26411 L
.32483 .26411 L
.32615 .26404 L
.32741 .26392 L
.32855 .26375 L
.33112 .26325 L
.33574 .2622 L
.337 .26194 L
.33833 .26172 L
.33903 .26162 L
.33979 .26153 L
.34049 .26146 L
.34114 .26142 L
.34242 .26138 L
.3436 .26139 L
.34424 .26143 L
.34495 .26148 L
.34624 .26161 L
.35111 .26248 L
.35368 .26301 L
.35508 .26328 L
.35639 .26349 L
Mistroke
.35753 .26364 L
.35876 .26375 L
.35946 .2638 L
.36012 .26382 L
.36136 .26383 L
.3625 .26379 L
.36356 .26372 L
.36471 .2636 L
.36594 .26344 L
.37117 .26249 L
.37395 .26201 L
.37552 .2618 L
.37626 .26172 L
.37695 .26167 L
.37815 .2616 L
.37946 .26158 L
.38073 .26161 L
.38145 .26165 L
.3821 .2617 L
.38329 .26182 L
.38458 .26199 L
.38692 .26237 L
.3915 .26316 L
.39281 .26335 L
.39406 .2635 L
.39518 .2636 L
.39641 .26367 L
.39705 .26368 L
.39776 .26369 L
.3985 .26368 L
.3992 .26365 L
.40045 .26357 L
.40115 .26351 L
.40179 .26344 L
.40424 .26311 L
.40683 .26267 L
.40934 .26226 L
.41072 .26206 L
.41203 .2619 L
.41325 .26179 L
.41457 .26171 L
.41577 .26168 L
.41688 .26169 L
.41819 .26175 L
.41942 .26185 L
.42077 .26199 L
.42222 .26219 L
.42496 .26263 L
.42788 .26309 L
.4293 .26329 L
Mistroke
.43063 .26344 L
.43183 .26354 L
.43312 .2636 L
.43436 .26362 L
.43566 .2636 L
.43677 .26354 L
.43799 .26344 L
.43943 .26328 L
.44074 .2631 L
.44369 .26263 L
.44646 .2622 L
.44768 .26204 L
.44902 .26189 L
.45026 .2618 L
.45142 .26174 L
.45264 .26172 L
.45396 .26174 L
.45462 .26177 L
.45533 .26182 L
.45677 .26195 L
.4581 .26211 L
.45934 .26228 L
.46181 .26267 L
.46442 .26308 L
.46666 .26337 L
.46793 .26349 L
.46911 .26357 L
.47038 .26361 L
.47155 .26361 L
.47219 .26359 L
.47289 .26356 L
.47416 .26347 L
.47489 .2634 L
.47554 .26333 L
.47701 .26314 L
.47964 .26273 L
.4821 .26234 L
.48339 .26214 L
.48476 .26197 L
.48596 .26185 L
.48727 .26176 L
.48846 .26171 L
.48958 .2617 L
.49073 .26173 L
.49199 .26181 L
.49318 .26191 L
.49428 .26204 L
.49855 .2627 L
.50096 .26309 L
.50322 .2634 L
Mistroke
.50435 .26352 L
.50557 .2636 L
.50627 .26364 L
.50693 .26365 L
.50816 .26365 L
.50941 .26361 L
.51011 .26356 L
.51075 .26351 L
.51193 .26339 L
.51318 .26322 L
.51774 .26246 L
.52009 .26208 L
.52138 .26191 L
.52261 .26177 L
.5233 .26171 L
.52405 .26167 L
.52537 .26162 L
.52602 .26162 L
.52671 .26163 L
.52795 .26169 L
.52908 .26178 L
.53012 .26189 L
.53246 .26224 L
.53669 .263 L
.53912 .2634 L
.54031 .26356 L
.54138 .26367 L
.54253 .26375 L
.54375 .26379 L
.54438 .26379 L
.54508 .26377 L
.54633 .26371 L
.54756 .26359 L
.54869 .26345 L
.55122 .26303 L
.55579 .26213 L
.55702 .26192 L
.55834 .26172 L
.5591 .26162 L
.55978 .26155 L
.56047 .2615 L
.56112 .26146 L
.56239 .26143 L
.56356 .26146 L
.56484 .26154 L
.56548 .2616 L
.56619 .26169 L
.56894 .26215 L
.57145 .26269 L
.57414 .26328 L
Mistroke
.57556 .26356 L
.57707 .2638 L
.57836 .26394 L
.5791 .264 L
.57978 .26404 L
.58099 .26405 L
.58229 .264 L
.58355 .26389 L
.58487 .2637 L
.58723 .26324 L
.59215 .26201 L
.59332 .26173 L
.59456 .26148 L
.59571 .26129 L
.59679 .26116 L
.59801 .26107 L
.59866 .26105 L
.59935 .26105 L
.6001 .26108 L
.60081 .26113 L
.60144 .26119 L
.60213 .26128 L
.60335 .2615 L
.60465 .26179 L
.60699 .26243 L
.60938 .26316 L
.61196 .2639 L
.61315 .26418 L
.6144 .26441 L
.61547 .26455 L
.61664 .26463 L
.61778 .26463 L
.61882 .26457 L
.62002 .26442 L
.62115 .2642 L
.62317 .26365 L
.62536 .26288 L
.62991 .26116 L
.63122 .26075 L
.63246 .26044 L
.63358 .26024 L
.6348 .26011 L
.63551 .26009 L
.63615 .2601 L
.63689 .26016 L
.63758 .26025 L
.63883 .26051 L
.63952 .2607 L
.64017 .26091 L
.64261 .26194 L
Mistroke
.6452 .26329 L
.6477 .26462 L
.64908 .26527 L
.65038 .26578 L
.65159 .26613 L
.65291 .26636 L
.65411 .26641 L
.65522 .26631 L
.65653 .26599 L
.65776 .26551 L
.6591 .26478 L
.66056 .26379 L
.6633 .26149 L
.66623 .25885 L
.66756 .25776 L
.66882 .25689 L
.66995 .25629 L
.67118 .25588 L
.67235 .25578 L
.67358 .25602 L
.67463 .25653 L
.67579 .25747 L
.67649 .25822 L
.67716 .25908 L
.6784 .26105 L
.6812 .26726 L
.68362 .27449 L
.68626 .28399 L
.69197 .30751 L
.69476 .31881 L
.69733 .32807 L
.69963 .335 L
.70215 .34083 L
.70346 .34307 L
.70469 .34468 L
.70598 .34589 L
.7067 .34635 L
.70736 .34664 L
.70858 .34689 L
.70988 .34676 L
.71099 .34638 L
.71221 .34572 L
.71352 .34479 L
.71494 .34361 L
.71749 .34127 L
.71992 .33915 L
.72125 .33816 L
.72249 .33739 L
.72355 .33686 L
.72468 .33645 L
Mistroke
.72593 .33617 L
.72707 .33609 L
.72838 .33618 L
.72904 .33629 L
.72977 .33647 L
.73105 .3369 L
.73225 .33742 L
.73787 .3404 L
.73908 .341 L
.74039 .34156 L
.74155 .34196 L
.74278 .34228 L
.74346 .34241 L
.74421 .34251 L
.7449 .34256 L
.74554 .34257 L
.74675 .34251 L
.74805 .34232 L
.75306 .34074 L
.75581 .33964 L
.75717 .33914 L
.75842 .33873 L
.75957 .33841 L
.76084 .33814 L
.76212 .33796 L
.76282 .3379 L
.76347 .33787 L
.76463 .33789 L
.76568 .33798 L
.76691 .33815 L
.76807 .33838 L
.77329 .33991 L
.77583 .34067 L
.77694 .34095 L
.77813 .34121 L
.77945 .34142 L
.78069 .34155 L
.78137 .34159 L
.7821 .3416 L
.7834 .34156 L
.78409 .34151 L
.78482 .34143 L
.78615 .34123 L
.78772 .34091 L
.78916 .34056 L
.79397 .33931 L
.79514 .33905 L
.7964 .33882 L
.79712 .33871 L
.79778 .33863 L
Mistroke
.79908 .33851 L
.80018 .33847 L
.80121 .33848 L
.80234 .33855 L
.80355 .33867 L
.80482 .33885 L
.80601 .33906 L
.80825 .33954 L
.81309 .34062 L
.81427 .34082 L
.81553 .341 L
.81626 .34108 L
.81692 .34113 L
.81822 .34119 L
.81893 .3412 L
.8196 .34119 L
.82033 .34115 L
.8211 .3411 L
.82184 .34103 L
.82254 .34095 L
.82384 .34076 L
.82902 .33974 L
.83127 .33931 L
.83252 .33911 L
.83369 .33896 L
.83436 .33889 L
.83508 .33883 L
.83634 .33877 L
.83763 .33877 L
.83881 .33881 L
.84005 .3389 L
.8412 .33903 L
.84383 .33943 L
.84655 .33994 L
.84915 .34041 L
.85137 .34073 L
.85263 .34086 L
.8538 .34094 L
.85488 .34098 L
.85586 .34098 L
.85699 .34094 L
.85805 .34087 L
.85922 .34076 L
.86045 .34061 L
.86265 .34027 L
.86521 .33982 L
.86763 .33942 L
.86878 .33926 L
.87001 .33912 L
.87064 .33906 L
Mistroke
.87135 .33901 L
.87259 .33895 L
.87371 .33893 L
.87492 .33896 L
.87606 .33902 L
.8771 .33911 L
.87833 .33924 L
.87947 .33939 L
.88205 .3398 L
.88473 .34023 L
.88605 .34042 L
.88726 .34057 L
.88834 .34068 L
.88949 .34076 L
.89064 .34081 L
.8919 .34083 L
.89295 .3408 L
.89408 .34075 L
.89515 .34066 L
.89612 .34056 L
.90109 .33986 L
.90325 .33954 L
.90439 .3394 L
.90559 .33928 L
.90687 .33918 L
.90805 .33913 L
.90915 .33912 L
.91037 .33914 L
.91164 .33921 L
.91235 .33927 L
.913 .33933 L
.91545 .33962 L
.9177 .33993 L
.91889 .34008 L
.92015 .34022 L
.92125 .34031 L
.92246 .34037 L
.92357 .34038 L
.9246 .34033 L
.92581 .3402 L
.9265 .3401 L
.92714 .33997 L
.92843 .33965 L
.92981 .33919 L
.93231 .33806 L
.93458 .33673 L
.94533 .32846 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo0<7ooooo000Wooooo`03o`000?oooooooooo033o
oooo1?l0001/ooooo`Co0000D_ooool002Oooooo0_l0000aooooo`04o`000?ooooooooooooooo`;o
00000oooool6o`0000?ooooo1ol00002ooooo`Oo000000?oooooo`000?l00000;?l000000ooooooo
0000o`000006o`0000;ooooo1_l00003ooooo`Ko00001?ooool01Ol0003ooooooooooooooooo0000
05;ooooo000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?oooooooooooooo
o`Wo00001Oooool4o`0000Kooooo0ol00006ooooo`?o00000_ooool2o`0000?ooooo0_l00005oooo
o`Co00002?ooool00ol0003oooooooooo`06ooooo`;o00001oooool2o`0000Gooooo1Ol000000ooo
oooo0000ooooo`03ooooo`Co00001Oooool4o`0000Gooooo00?o0000ooooooooool04?ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0002Oooooo0ol00007ooooo`009oooool00ol0003o
ooooooooo`0Uooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`0Nooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool08?ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Woooo
o`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooo
oooo00001_ooool01?l0003oooooooooool0000Rooooo`04o`000?ooooooooooo`0000Oooooo1Ol0
000Qooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000002Oooooo00?o0000ooooooooool01_ooool002Oooooo0_l0000Vooooo`04o`000?oooooooooo
o`0000Kooooo00Go0000ooooooooooooooooo`00000Qooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00008_ooool01?l0003oooooooooool00007ooooo`Co00003oooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Sooooo0ol0000Xooooo`03o`000?oooooo
oooo00Kooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo00001_ooool2
o`0000?ooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000002;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
02Oooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool07_ooool01?l0
003oooooooooool00009ooooo`;o00008_ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000009_ooool2o`0000Sooooo000Wooooo`03o`000?oooooooooo02Kooooo
0_l00006ooooo`03o`000?oooooooooo00?o00008_ooool2o`0000_ooooo00?o0000ooooooooool0
8Oooool2o`0000[ooooo0_l0000@ooooo`03o`000?oooooooooo00oooooo0_l00009ooooo`?o0000
:?ooool00ol0003oooooooooo`06ooooo`009oooool2o`0002oooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooooooo`1>ooooo`009oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo07Gooooo00?o0000ooooooooool0C_ooool002Oooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`1fooooo`03o`000?oooooooooo04gooooo000Wooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`1=ooooo`008Oooooooo`0000009ooo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooo`000007ooooo`009oooool0
1?l0003oooooooooool0000[ooooo`;o0000;oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Yooooo`;o00000_oo
ool00ol0003oooooooooo`05ooooo`009oooool01?l0003oooooooooooooool2o`0002Wooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo000W
ooooo`;o00001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`009oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0koooo
o`;o00003_ooool002Oooooo00?o0000ooooooooool01Oooool4o`0002;ooooo00?o0000oooooooo
ool0N_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00kooooo000Wooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o0000
1_ooool4o`0000Gooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`03ooooo`Co0000
1Oooool4o`0002Sooooo0_l0000Aooooo`009oooool2o`0000_ooooo4?l00002ooooo`?o000000?o
ooooo`000?l000001?ooool01Ol0003ooooooooooooooooo000007kooooo00Go0000oooooooooooo
ooooo`000004ooooo`;o000000Coooooo`000?l0003o00000ooooolYo`0001;ooooo000Wooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool4o`0007kooooo1?l00006ooooo`;o
0000@Oooool002Oooooo00?o0000ooooooooool0:?ooool2o`00083ooooo0_l0001:ooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002
ooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool2o`000?Oooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0003ooooo
ooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0?Kooooo0008ooooo`;o
00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`3fooooo`00
9oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003g
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`00
00Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00_ooool2o`000?Oooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Ko
oooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`00
00Gooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:
ooooo`;o00000_ooool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0
m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo
00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3foooo
o`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oo
oooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooooooo
o`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`;o0000moooool001Cooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3fooooo`004oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0003gooooo`004oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo00002?ooool2o`00
0?oooooo000Dooooo`;o00002_ooool00ol0003oooooooooo`3mooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .3344 L
.08255 .34621 L
.08383 .34644 L
.08518 .34675 L
.08666 .3472 L
.08802 .34775 L
.09049 .3491 L
.0932 .35121 L
.09916 .35774 L
.10458 .36425 L
.10719 .36683 L
.10848 .36786 L
.10968 .36865 L
.11104 .36934 L
.11177 .36962 L
.11254 .36984 L
.11325 .36998 L
.11391 .37006 L
.11516 .37007 L
.11636 .36993 L
.11764 .36965 L
.11872 .36933 L
.11992 .3689 L
.12261 .36784 L
.12379 .3674 L
.12507 .367 L
.12634 .36671 L
.12751 .36656 L
.12864 .36655 L
.12983 .36668 L
.13108 .36701 L
.13226 .36748 L
.13355 .36818 L
.13494 .36914 L
.13939 .37313 L
.14184 .37542 L
.14415 .37721 L
.1454 .37788 L
.1461 .37815 L
.14675 .37831 L
.1479 .37838 L
.14911 .37811 L
.15024 .37751 L
.15131 .37664 L
.15247 .37529 L
.15372 .3734 L
.15653 .36746 L
.15919 .3598 L
.16419 .34149 L
Mistroke
.16908 .32185 L
.17429 .30367 L
.17583 .2994 L
.17728 .29597 L
.1787 .29319 L
.18 .29113 L
.18124 .28961 L
.18254 .28845 L
.18385 .28772 L
.1846 .28749 L
.18529 .28738 L
.18656 .28742 L
.1872 .28756 L
.1879 .28778 L
.18915 .28834 L
.19031 .28902 L
.19577 .29303 L
.1981 .29458 L
.19937 .29527 L
.20054 .29579 L
.20183 .29622 L
.2025 .29638 L
.20323 .29651 L
.20452 .29661 L
.20568 .29658 L
.20685 .29644 L
.20807 .29618 L
.20912 .29589 L
.21027 .29551 L
.21524 .29356 L
.21749 .29276 L
.21873 .2924 L
.2199 .29212 L
.22099 .29193 L
.22218 .29179 L
.22325 .29172 L
.22425 .29172 L
.22543 .29178 L
.22666 .29191 L
.22772 .29207 L
.22888 .29229 L
.23386 .2935 L
.23612 .29403 L
.23737 .29428 L
.23854 .29447 L
.23963 .29462 L
.24082 .29472 L
.2419 .29478 L
.24289 .2948 L
.24408 .29477 L
Mistroke
.24535 .2947 L
.24655 .29458 L
.24765 .29445 L
.25289 .2936 L
.25549 .29319 L
.25686 .29302 L
.25762 .29293 L
.25832 .29287 L
.259 .29282 L
.25973 .29277 L
.261 .29272 L
.2623 .29272 L
.26349 .29274 L
.26475 .2928 L
.26595 .29289 L
.26819 .29311 L
.27323 .29369 L
.27534 .2939 L
.2765 .294 L
.27759 .29407 L
.27876 .29412 L
.28005 .29415 L
.28115 .29416 L
.28233 .29415 L
.28363 .29411 L
.28484 .29405 L
.28758 .29386 L
.29048 .29363 L
.29311 .29342 L
.29429 .29334 L
.29557 .29327 L
.29678 .29322 L
.29789 .29319 L
.29907 .29317 L
.30037 .29316 L
.30102 .29317 L
.30173 .29318 L
.30299 .29321 L
.30791 .29343 L
.3106 .29358 L
.31313 .2937 L
.31458 .29375 L
.31534 .29377 L
.31615 .29379 L
.31682 .29381 L
.31757 .29382 L
.31887 .29383 L
.31957 .29382 L
.3202 .29382 L
.32093 .29381 L
Mistroke
.32162 .2938 L
.32285 .29378 L
.32418 .29375 L
.32926 .29358 L
.33059 .29354 L
.33203 .2935 L
.33337 .29347 L
.33464 .29345 L
.33578 .29344 L
.33704 .29343 L
.33817 .29343 L
.33923 .29343 L
.34051 .29344 L
.34168 .29345 L
.34429 .29348 L
.34916 .29355 L
.35035 .29357 L
.35161 .29358 L
.35234 .29359 L
.35301 .29359 L
.35431 .2936 L
.35549 .2936 L
.35658 .2936 L
.35777 .2936 L
.35904 .2936 L
.36014 .2936 L
.36117 .2936 L
.36353 .2936 L
.36483 .29359 L
.36607 .2936 L
.36675 .2936 L
.36749 .2936 L
.36878 .2936 L
.37115 .29361 L
.37245 .29361 L
.37367 .29362 L
.37493 .29362 L
.3756 .29362 L
.37632 .29362 L
.3776 .29362 L
.37877 .29362 L
.37948 .29361 L
.38013 .29361 L
.38163 .29359 L
.38294 .29358 L
.38434 .29356 L
.38697 .29352 L
.3898 .29347 L
.3911 .29345 L
.39181 .29344 L
Mistroke
.39247 .29344 L
.39364 .29343 L
.39493 .29342 L
.39617 .29343 L
.39735 .29343 L
.39841 .29344 L
.39956 .29346 L
.40081 .29349 L
.40214 .29352 L
.40452 .29359 L
.40875 .29371 L
.40991 .29374 L
.41114 .29377 L
.41218 .29378 L
.41332 .29379 L
.41457 .29379 L
.41527 .29379 L
.41591 .29379 L
.41715 .29377 L
.41832 .29374 L
.4195 .29371 L
.42058 .29367 L
.42302 .29357 L
.4277 .29337 L
.42905 .29332 L
.43033 .29329 L
.43148 .29326 L
.43273 .29325 L
.43382 .29325 L
.43502 .29326 L
.43627 .29329 L
.43745 .29332 L
.43955 .29341 L
.44181 .29353 L
.44453 .2937 L
.44705 .29383 L
.44843 .2939 L
.44969 .29394 L
.45041 .29396 L
.45109 .29397 L
.4518 .29397 L
.45258 .29398 L
.45377 .29397 L
.45507 .29394 L
.45573 .29391 L
.45644 .29388 L
.45772 .29382 L
.46246 .29349 L
.465 .2933 L
.46639 .29321 L
Mistroke
.46771 .29314 L
.46893 .29309 L
.46962 .29307 L
.47026 .29306 L
.47138 .29305 L
.47257 .29306 L
.47388 .29309 L
.47462 .29312 L
.47529 .29316 L
.47783 .29333 L
.4836 .29385 L
.486 .29404 L
.48721 .29412 L
.48791 .29415 L
.48855 .29417 L
.48924 .29419 L
.48999 .2942 L
.49064 .29421 L
.49134 .2942 L
.49257 .29417 L
.49327 .29414 L
.49392 .2941 L
.4952 .29401 L
.4964 .29391 L
.49865 .29367 L
.50126 .29337 L
.50369 .2931 L
.50484 .29299 L
.50593 .29291 L
.50718 .29283 L
.50833 .29279 L
.50959 .29278 L
.51076 .29279 L
.51205 .29284 L
.51277 .29289 L
.51342 .29294 L
.51597 .2932 L
.51872 .29358 L
.5211 .29393 L
.52237 .2941 L
.52371 .29426 L
.52498 .29439 L
.52614 .29447 L
.5273 .29453 L
.52839 .29455 L
.52963 .29454 L
.53076 .29449 L
.53201 .29439 L
.53333 .29425 L
.5355 .29394 L
Mistroke
.53754 .29358 L
.54217 .29277 L
.54341 .2926 L
.54409 .29252 L
.54474 .29245 L
.54599 .29236 L
.54712 .29232 L
.54778 .29232 L
.54848 .29233 L
.54972 .29239 L
.55042 .29245 L
.55106 .29252 L
.55254 .29273 L
.55502 .2932 L
.55729 .29372 L
.55994 .29434 L
.56111 .29459 L
.5624 .29483 L
.56353 .29499 L
.5646 .29511 L
.56573 .29518 L
.56695 .2952 L
.56821 .29515 L
.56884 .2951 L
.56953 .29502 L
.57076 .29482 L
.5719 .29459 L
.57626 .29335 L
.57848 .29264 L
.58092 .29195 L
.58225 .29165 L
.5835 .29145 L
.58482 .29133 L
.58556 .2913 L
.58624 .29131 L
.58744 .2914 L
.58875 .2916 L
.58999 .29189 L
.59115 .29224 L
.59697 .29475 L
.5995 .29587 L
.60084 .29635 L
.60156 .29657 L
.60224 .29674 L
.60349 .29696 L
.60415 .29702 L
.60486 .29703 L
.60612 .29694 L
.60727 .29671 L
.60843 .29634 L
Mistroke
.6097 .29578 L
.612 .29439 L
.61736 .2901 L
.61864 .28912 L
.61998 .28821 L
.62113 .2876 L
.62239 .28713 L
.62352 .28694 L
.62474 .28703 L
.62588 .28741 L
.62692 .28803 L
.62813 .28911 L
.62943 .29074 L
.63066 .29272 L
.6318 .29493 L
.6342 .3008 L
.63685 .30895 L
.64218 .32918 L
.64742 .34993 L
.65031 .35989 L
.65304 .36758 L
.65558 .37287 L
.65702 .37502 L
.65771 .37583 L
.65835 .37647 L
.65958 .37738 L
.6607 .37785 L
.6619 .37801 L
.6632 .37784 L
.67267 .37065 L
.67398 .36959 L
.6754 .36859 L
.67665 .36788 L
.67733 .36756 L
.67798 .36731 L
.67917 .36697 L
.68049 .3668 L
.6816 .36681 L
.6828 .36698 L
.68354 .36715 L
.68423 .36735 L
.68578 .36796 L
.68861 .3694 L
.6914 .37096 L
.69392 .37223 L
.69516 .37274 L
.69581 .37296 L
.6965 .37317 L
.69777 .37346 L
.69894 .37361 L
Mistroke
.70025 .37365 L
.70148 .37357 L
.70219 .37347 L
.70283 .37336 L
.70428 .373 L
.709 .37123 L
.71158 .37019 L
.71401 .36937 L
.71527 .36904 L
.71592 .36891 L
.71663 .36879 L
.71736 .3687 L
.71813 .36863 L
.71885 .36861 L
.71951 .36861 L
.7208 .3687 L
.72197 .36886 L
.72262 .36897 L
.72332 .36912 L
.7246 .36945 L
.72946 .37099 L
.73212 .3718 L
.73343 .37212 L
.73461 .37235 L
.7357 .37251 L
.73673 .37261 L
.73782 .37265 L
.73901 .37263 L
.74023 .37254 L
.74152 .37237 L
.74274 .37215 L
.74385 .37191 L
.74874 .37059 L
.75141 .36992 L
.75271 .36966 L
.7539 .36947 L
.75499 .36935 L
.75602 .36927 L
.75712 .36924 L
.7583 .36927 L
.75952 .36936 L
.76081 .36952 L
.76191 .3697 L
.76313 .36993 L
.76831 .37115 L
.77102 .37172 L
.77239 .37194 L
.77317 .37204 L
.77388 .37211 L
.7752 .37219 L
Mistroke
.77593 .37221 L
.77661 .37221 L
.77783 .37216 L
.77914 .37205 L
.78036 .3719 L
.78165 .3717 L
.78396 .37125 L
.78629 .37075 L
.78882 .37023 L
.78998 .37003 L
.79121 .36985 L
.79226 .36973 L
.79342 .36963 L
.79474 .36958 L
.79548 .36958 L
.79616 .36959 L
.79741 .36965 L
.79873 .36977 L
.79993 .36992 L
.80104 .37009 L
.80357 .37054 L
.80576 .37097 L
.80813 .37139 L
.80921 .37156 L
.81036 .37171 L
.81135 .37181 L
.81243 .37189 L
.81366 .37194 L
.81436 .37195 L
.81499 .37194 L
.81622 .37189 L
.81739 .37181 L
.81851 .37169 L
.81954 .37156 L
.8219 .3712 L
.82698 .37034 L
.82837 .37014 L
.82984 .36998 L
.8311 .36988 L
.83181 .36984 L
.83247 .36982 L
.83376 .36981 L
.83499 .36984 L
.83609 .3699 L
.83728 .37 L
.83858 .37014 L
.83996 .37032 L
.84243 .37069 L
.84669 .37131 L
.84786 .37144 L
Mistroke
.84908 .37155 L
.85013 .37163 L
.85128 .37168 L
.85254 .3717 L
.85325 .3717 L
.85389 .37169 L
.85514 .37164 L
.85632 .37157 L
.8575 .37147 L
.85858 .37136 L
.86104 .37108 L
.86572 .37055 L
.86707 .37042 L
.86835 .37032 L
.87074 .37018 L
.87514 .37002 L
.8764 .36997 L
.87759 .36991 L
.87866 .36983 L
.87982 .36971 L
.88112 .36953 L
.88249 .36928 L
.88366 .36901 L
.88494 .36863 L
.8874 .36769 L
.8897 .36652 L
.8949 .36294 L
.90046 .35821 L
.94189 .33064 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`00023ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooo
ooooo`0Tooooo`Co00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo
0_l0000:ooooo`;o000000?oooooo`000?ooool07oooool2o`0000Wooooo0ol0000Xooooo`03o`00
0?oooooooooo00Kooooo000Wooooo`;o00009Oooool01?l0003oooooooooooooool2o`0000?ooooo
H_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0G?ooool002Oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`Co0000FOooool2o`0000Oooooo0ol0
0005ooooo`03o`000?oooooooooo05cooooo000Wooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1Kooooo`009oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Foooool0027oooooool0000002Oooooo
00?o0000ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01oooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo
000Wooooo`03o`000?oooooooooo00;o00008?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00007ooooo`009ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooooooo`1=ooooo`;o00002oooool002Oooooo0_l00004ooooo`;o00007Oooool0
0ol0003oooooooooo`1dooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool02oooool0
02Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
07Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003o
ooooooooo`06ooooo`;o00006Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo04So
oooo0_l0000?ooooo`009oooool00ol0003oooooooooo`08ooooo`;o00005oooool00ol0003ooooo
ooooo`1fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool03oooool002Oooooo0_l0
000;ooooo`;o00005?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo04Cooooo0_l0
000Booooo`009oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`12ooooo`;o00005?ooool002Oooooo00?o0000oooo
ooooool03?ooool3o`00017ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo01Cooooo000Wooooo`03o`000?oooooooooo00kooooo0_l0000?ooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool0?oooool2o`0001Oooooo000Wooooo`;o0000
4Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0Gooooo`009oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo01Sooooo000Wooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo03[ooooo0_l0000Kooooo`009oooool00ol0
003oooooooooo`0Booooo`So00001?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo
00?ooooo1?l00006ooooo`Co00001Oooool5o`0000Gooooo1?l00007ooooo`;o00002Oooool4o`00
01gooooo000Wooooo`;o00005?ooool2o`0000Gooooo00Go0000ooooooooooooooooo`00001noooo
o`05o`000?ooooooooooooooool000001?ooool6o`0000Cooooo1_l00004ooooo`Ko00000_ooool8
o`000003ooooool0003o000000Wo00008?ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool06oooool00ol0
003oooooo`00001oooooo`;o000000?oooooo`000?ooool0E?ooool000Oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
Ooooool2o`0005Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000?Oooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooo000000?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo0?Kooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go0000
1?ooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2
o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo
00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool0m_ooool000gooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000
ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0003goooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`002?oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2
o`000?Oooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go0000
00?oooooo`000?l000000ol00004ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000mooo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooooooo
o`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oo
oooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool001Co
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3fooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Co
oooo0_l0003gooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?go
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002?ooool2o`000?oooooo000Dooooo`;o00002_ooool00ol0003ooooo
ooooo`3mooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33564 L
.06484 .33739 L
.06744 .33891 L
.06989 .33998 L
.07216 .3407 L
.0748 .34135 L
.0776 .34203 L
.07996 .34284 L
.0813 .34345 L
.08255 .34417 L
.08542 .34638 L
.08805 .34914 L
.09396 .35721 L
.09656 .36082 L
.09794 .36251 L
.0994 .36403 L
.10013 .36465 L
.10081 .36514 L
.10209 .36579 L
.10328 .36604 L
.10458 .36588 L
.10577 .36531 L
.10705 .36422 L
.10826 .36274 L
.10936 .36099 L
.11205 .35522 L
.1146 .34803 L
.1201 .32917 L
.12519 .31219 L
.12746 .30612 L
.12959 .30172 L
.13066 .30004 L
.13182 .29864 L
.1331 .29759 L
.13427 .29709 L
.13546 .29702 L
.13657 .29733 L
.13779 .29805 L
.13908 .29921 L
.14045 .30081 L
.14174 .3026 L
.14415 .30643 L
.14917 .31476 L
.15163 .31817 L
.15387 .32061 L
.15509 .32163 L
.15624 .32238 L
.15745 .32298 L
.15814 .32322 L
Mistroke
.15877 .32339 L
.15948 .32353 L
.16014 .3236 L
.16139 .32362 L
.16208 .32357 L
.16272 .32349 L
.16342 .32338 L
.16417 .32323 L
.16842 .3222 L
.16964 .32195 L
.1708 .32178 L
.17184 .32168 L
.17297 .32164 L
.17423 .32169 L
.17486 .32176 L
.17556 .32186 L
.1768 .32211 L
.17796 .32242 L
.18262 .32416 L
.1849 .32508 L
.18733 .32591 L
.18873 .32627 L
.19 .32651 L
.19127 .32665 L
.19248 .32668 L
.19374 .32663 L
.19437 .32656 L
.19507 .32646 L
.1963 .32622 L
.19745 .32594 L
.20284 .32418 L
.20524 .32344 L
.20642 .32314 L
.20751 .32291 L
.2085 .32276 L
.20955 .32265 L
.21061 .3226 L
.21177 .32261 L
.21301 .32271 L
.21415 .32286 L
.2154 .32309 L
.21671 .32339 L
.22136 .32472 L
.22392 .3254 L
.22518 .32567 L
.22635 .32587 L
.22741 .32599 L
.22852 .32608 L
.22965 .3261 L
.23089 .32605 L
Mistroke
.23157 .326 L
.23221 .32593 L
.23342 .32575 L
.23473 .32551 L
.23615 .32519 L
.23873 .32453 L
.24107 .32394 L
.24222 .32368 L
.24345 .32344 L
.24452 .32327 L
.24569 .32313 L
.24693 .32304 L
.24824 .32302 L
.24946 .32306 L
.2506 .32315 L
.25174 .3233 L
.25283 .32347 L
.25486 .32388 L
.25943 .32492 L
.26165 .32535 L
.26289 .32554 L
.26403 .32567 L
.2653 .32576 L
.26594 .32578 L
.26664 .32578 L
.26791 .32574 L
.2691 .32566 L
.26974 .32559 L
.27044 .3255 L
.2717 .32531 L
.27406 .32485 L
.27658 .32432 L
.27936 .32378 L
.28052 .32359 L
.28177 .32344 L
.28294 .32333 L
.28402 .32328 L
.28523 .32326 L
.28655 .3233 L
.28779 .3234 L
.28895 .32353 L
.29119 .32387 L
.29323 .32425 L
.29778 .32511 L
.29891 .32528 L
.30012 .32542 L
.30081 .32548 L
.30145 .32553 L
.30268 .32558 L
.30395 .32559 L
Mistroke
.30467 .32557 L
.30533 .32553 L
.30655 .32543 L
.30784 .32529 L
.31011 .32494 L
.31224 .32456 L
.31455 .32413 L
.31708 .32374 L
.31776 .32365 L
.31848 .32358 L
.31977 .32347 L
.32046 .32344 L
.32111 .32342 L
.32232 .32341 L
.32352 .32345 L
.32463 .32353 L
.32584 .32365 L
.32712 .32381 L
.33277 .32476 L
.33524 .32513 L
.33663 .32529 L
.33792 .3254 L
.33904 .32546 L
.34028 .32548 L
.34157 .32545 L
.34279 .32538 L
.34394 .32528 L
.345 .32515 L
.34739 .32481 L
.35224 .32401 L
.35357 .32383 L
.35499 .32367 L
.35568 .32361 L
.35633 .32356 L
.35755 .32351 L
.35863 .3235 L
.35978 .32352 L
.36076 .32357 L
.36183 .32365 L
.36299 .32377 L
.36423 .32392 L
.36648 .32426 L
.37103 .32498 L
.37234 .32515 L
.37358 .32527 L
.37468 .32535 L
.37588 .3254 L
.37652 .32542 L
.37721 .32542 L
.37794 .3254 L
Mistroke
.37862 .32537 L
.37983 .3253 L
.38113 .32517 L
.38368 .32484 L
.38601 .32447 L
.38872 .32404 L
.39016 .32385 L
.39094 .32376 L
.39168 .32369 L
.39237 .32363 L
.39301 .32359 L
.39371 .32355 L
.39447 .32353 L
.39572 .32353 L
.39705 .32358 L
.39831 .32366 L
.39945 .32378 L
.40202 .32412 L
.40665 .32485 L
.40791 .32503 L
.40924 .32519 L
.40994 .32526 L
.41071 .32532 L
.4114 .32537 L
.41205 .32539 L
.41334 .32542 L
.41451 .3254 L
.41516 .32537 L
.41586 .32533 L
.41715 .32522 L
.42204 .32453 L
.42461 .32411 L
.42602 .3239 L
.42732 .32374 L
.42847 .32362 L
.4297 .32354 L
.4304 .32351 L
.43107 .32349 L
.43231 .3235 L
.43345 .32354 L
.4345 .32361 L
.43566 .32373 L
.43689 .32388 L
.44204 .32473 L
.44456 .32512 L
.44566 .32526 L
.44686 .32538 L
.44816 .32546 L
.44939 .3255 L
.45007 .3255 L
Mistroke
.4508 .32548 L
.45211 .32541 L
.45286 .32535 L
.45367 .32527 L
.45514 .32507 L
.45788 .32461 L
.46024 .32417 L
.46247 .32379 L
.46371 .32362 L
.46436 .32354 L
.46505 .32348 L
.46626 .32339 L
.46739 .32335 L
.46803 .32335 L
.46872 .32336 L
.46996 .32342 L
.47068 .32348 L
.47144 .32356 L
.47279 .32374 L
.47783 .3247 L
.48035 .32518 L
.48173 .3254 L
.48304 .32557 L
.48426 .32567 L
.48558 .32572 L
.48678 .32572 L
.48789 .32566 L
.4892 .32553 L
.49044 .32536 L
.49324 .32482 L
.49617 .32414 L
.49889 .32355 L
.50014 .32333 L
.50131 .32317 L
.50196 .3231 L
.50266 .32304 L
.50388 .323 L
.50453 .323 L
.50525 .32302 L
.506 .32307 L
.50671 .32314 L
.50796 .32332 L
.50931 .32357 L
.51438 .32491 L
.51688 .32557 L
.51798 .32581 L
.51919 .32603 L
.52035 .32618 L
.52144 .32626 L
.5226 .32628 L
Mistroke
.52384 .32622 L
.52448 .32615 L
.52519 .32605 L
.52648 .32581 L
.52773 .32549 L
.52889 .32514 L
.53349 .32352 L
.53551 .32286 L
.53658 .32257 L
.53773 .32232 L
.539 .32214 L
.54019 .32206 L
.54089 .32207 L
.54155 .32211 L
.54279 .32226 L
.54346 .32239 L
.54416 .32257 L
.54542 .32296 L
.54828 .32418 L
.55075 .32543 L
.55341 .32673 L
.55463 .32723 L
.55592 .32765 L
.55702 .32789 L
.55823 .32803 L
.55939 .32801 L
.56044 .32787 L
.56166 .32753 L
.56281 .32706 L
.56485 .32588 L
.56707 .32418 L
.5695 .32207 L
.57211 .31987 L
.57337 .31899 L
.57458 .31833 L
.57565 .31794 L
.57683 .31776 L
.57808 .31791 L
.5792 .31838 L
.58051 .31936 L
.58173 .32074 L
.58287 .32243 L
.58392 .32435 L
.58628 .32991 L
.5887 .33725 L
.59134 .34689 L
.59669 .36897 L
.60194 .38928 L
.60489 .3981 L
.60628 .4014 L
Mistroke
.60757 .40391 L
.60878 .40579 L
.61007 .40728 L
.61136 .40827 L
.6121 .40862 L
.61279 .40881 L
.61403 .40886 L
.61516 .4086 L
.61641 .40804 L
.61772 .40717 L
.62264 .40275 L
.62506 .40062 L
.62728 .39907 L
.62853 .39843 L
.62985 .39797 L
.63053 .39782 L
.63117 .39774 L
.63188 .3977 L
.63263 .39773 L
.63393 .39793 L
.63517 .39829 L
.63628 .39872 L
.63749 .39929 L
.64211 .40191 L
.64464 .40321 L
.64588 .40372 L
.64702 .40409 L
.64811 .40435 L
.64926 .40451 L
.6504 .40456 L
.65166 .40449 L
.65271 .40434 L
.65384 .40409 L
.65586 .40344 L
.66082 .40138 L
.66213 .40086 L
.66353 .40037 L
.66484 .4 L
.66607 .39973 L
.66676 .39963 L
.66751 .39954 L
.66882 .39949 L
.66958 .39951 L
.67038 .39957 L
.67115 .39967 L
.67184 .39978 L
.67316 .40007 L
.67458 .40046 L
.67716 .40131 L
.6798 .40221 L
Mistroke
.68226 .40293 L
.6835 .40321 L
.68414 .40332 L
.68483 .40343 L
.68559 .40351 L
.68631 .40356 L
.687 .40358 L
.68765 .40358 L
.6888 .40352 L
.68987 .40341 L
.69106 .40321 L
.69233 .40295 L
.6973 .40156 L
.6997 .40091 L
.70101 .40061 L
.70226 .40038 L
.70342 .40023 L
.70467 .40013 L
.70582 .4001 L
.70687 .40013 L
.70812 .40023 L
.70929 .40039 L
.71058 .40061 L
.71195 .40091 L
.71734 .40226 L
.71865 .40255 L
.72004 .40281 L
.72085 .40293 L
.72157 .40302 L
.72231 .40309 L
.72299 .40313 L
.72365 .40316 L
.72434 .40316 L
.72557 .40313 L
.72626 .40308 L
.7269 .40302 L
.72836 .40283 L
.72967 .4026 L
.73091 .40235 L
.73323 .40182 L
.73592 .40121 L
.73723 .40095 L
.73844 .40075 L
.73952 .4006 L
.74065 .40049 L
.74179 .40043 L
.74304 .40042 L
.74431 .40046 L
.74502 .40051 L
.74567 .40057 L
Mistroke
.74693 .40073 L
.74811 .40092 L
.75346 .402 L
.75581 .40245 L
.75705 .40263 L
.75773 .40272 L
.75838 .40279 L
.75954 .40288 L
.76061 .40292 L
.7616 .40292 L
.76268 .40288 L
.76383 .4028 L
.76505 .40268 L
.76723 .40235 L
.77223 .4014 L
.77442 .40103 L
.77558 .40087 L
.77681 .40074 L
.77805 .40066 L
.77917 .40062 L
.7803 .40062 L
.78137 .40067 L
.78256 .40075 L
.78367 .40087 L
.78617 .40123 L
.79097 .40208 L
.79228 .40228 L
.7937 .40247 L
.79438 .40255 L
.79504 .40261 L
.79626 .40269 L
.79732 .40272 L
.79846 .40272 L
.79953 .40268 L
.8005 .40262 L
.80164 .40252 L
.80288 .40238 L
.80513 .40205 L
.80967 .40134 L
.81097 .40117 L
.81221 .40104 L
.81332 .40096 L
.81453 .40091 L
.81577 .40089 L
.81708 .40093 L
.81821 .40099 L
.81945 .40109 L
.82182 .40135 L
.82404 .40163 L
.82532 .40177 L
Mistroke
.82601 .40183 L
.82666 .40189 L
.82781 .40195 L
.82906 .40196 L
.82977 .40194 L
.83044 .40189 L
.83168 .40175 L
.83238 .40163 L
.83302 .4015 L
.83448 .4011 L
.83569 .40067 L
.837 .4001 L
.83935 .39881 L
.84471 .39489 L
.85555 .38626 L
.89684 .35975 L
.93661 .33432 L
.97487 .30966 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool06?ooool3o`000=_ooooo000Wooooo`03
o`000?oooooooooo01Sooooo00Co0000ooooool0003o0000f_ooool002Oooooo00?o0000oooooooo
ool05oooool01Ol0003ooooooooooooooooo00000=[ooooo000Qoooooooo0000000Wooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooooooool02Oooool2o`0000Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`06ooooo`00
9oooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Sooooo0ol00003ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo0000
00Oooooo000Wooooo`04o`000?ooooooooooooooo`;o00004oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Co00001oooool00ol0003oooooooooo`1@ooooo`?o00001Oooool2o`00
0003ooooool0003o000005cooooo0_l0000<ooooo`009oooool2o`0000Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`07ooooo`;o00001?oooomKo`000003ooooool0003o000000?o
oooo0_l00003ooooo`03o`000?oooooooooo05Sooooo0_l0000>ooooo`009oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool2o`0005[ooooo
1?l00004ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool03_ooool002Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool0EOooool2o`00017ooooo000Wooooo`03o`000?oooooooooo00Kooooo0_l0000=
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0A
ooooo`009oooool2o`0000Wooooo0ol00009ooooo`03o`000?oooooooooo07Gooooo00?o0000oooo
ooooool0DOooool2o`0001Cooooo000Wooooo`03o`000?oooooooooo00_ooooo0_l00007ooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Dooooo`00
9oooool00ol0003oooooooooo`0<ooooo`;o00001_ooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0C?oo
ool2o`0001Sooooo000Wooooo`;o00003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Hooooo`009oooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooo`0007_ooooo00?o0000ooooooooool0B?ooool2
o`0001_ooooo000Wooooo`03o`000?oooooooooo00oooooo1?l0001kooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool06oooool002Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo04Gooooo0_l0000Nooooo`009oooool2o`0008oooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Nooooo`002?ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003ooooooooo
o`2>ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool07oooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08oooooo00?o0000oooo
ooooool0@?ooool2o`0002;ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Soooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02;ooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0002@ooooo`03o`000?oooooooooo03gooooo0_l0
000Uooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0Soooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo02Gooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool0T?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Kooooo0008oooo
o`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`2@oooo
o`;o00000oooool5o`0000Cooooo1_l00004ooooo`Go00001?ooool5o`0000Cooooo1Ol00005oooo
o`Co00000_ooool3o`0002Wooooo000Wooooo`;o0000T_ooool00ol0003oooooooooo`02o`0000Co
oooo1?l00005ooooo`Ko00001?ooool5o`0000Cooooo1?l00005ooooo`Go00001?ooool3o`0002_o
oooo000Wooooo`03o`000?oooooooooo097ooooo0ol0001Rooooo`009oooool00ol0003ooooooooo
o`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03
o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000mooo
ool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooooooo
o`3fooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005
ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
m_ooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00;ooooo0_l0003gooooo`003Oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3foooo
o`003Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005
ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo0?Kooooo000>ooooo`;o00002_oo
ool2o`0000;ooooo1Ol00004ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`;o0000moooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Ko
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3f
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005ooooo`03
o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0m_ooool0
00Sooooo0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?ooool00ol0
003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool2o`000?Oooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`004oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0003o
ooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02499 .30848 L
.02605 .30803 L
.02729 .3076 L
.02846 .30734 L
.02954 .30724 L
.03053 .3073 L
.03163 .30756 L
.03279 .30807 L
.03395 .30883 L
.0352 .30994 L
.03746 .31268 L
.04016 .31701 L
.04262 .32164 L
.04748 .33085 L
.04881 .33298 L
.05023 .33489 L
.05092 .33566 L
.05157 .33628 L
.05278 .33714 L
.05396 .33756 L
.0552 .33755 L
.05626 .33715 L
.05742 .33629 L
.05868 .33486 L
.06002 .33277 L
.06244 .32765 L
.06787 .31145 L
.07376 .29151 L
.07646 .28351 L
.07933 .27665 L
.08051 .27443 L
.08178 .27244 L
.08251 .2715 L
.08318 .27077 L
.08448 .26967 L
.08566 .26907 L
.08691 .2688 L
.08809 .26889 L
.08916 .26922 L
.09042 .26989 L
.09179 .27091 L
.09427 .27336 L
.0996 .27984 L
.10458 .28547 L
.10914 .28925 L
.1117 .29078 L
.11404 .2919 L
.12446 .29631 L
.12962 .29941 L
Mistroke
.13525 .30354 L
.1455 .31118 L
.1862 .33702 L
.19536 .34329 L
.20503 .34979 L
.21009 .35248 L
.21296 .35364 L
.21563 .35447 L
.2169 .35477 L
.2181 .35501 L
.21919 .35519 L
.22034 .35534 L
.2216 .35547 L
.22275 .35556 L
.224 .35562 L
.22471 .35564 L
.22538 .35566 L
.22663 .35567 L
.22735 .35567 L
.22801 .35566 L
.22871 .35565 L
.22934 .35564 L
.23077 .35561 L
.23571 .35549 L
.23846 .35543 L
.24001 .35541 L
.24143 .3554 L
.24683 .35536 L
.2515 .35531 L
.25664 .35523 L
.25797 .35522 L
.25923 .35521 L
.25992 .3552 L
.26068 .3552 L
.26137 .3552 L
.262 .3552 L
.26316 .35521 L
.26443 .35522 L
.26507 .35523 L
.26576 .35525 L
.26701 .35528 L
.27196 .35544 L
.27433 .35552 L
.27657 .35559 L
.27784 .35561 L
.27855 .35563 L
.27922 .35564 L
.28038 .35564 L
.28162 .35564 L
.28226 .35563 L
Mistroke
.28295 .35563 L
.2842 .3556 L
.28496 .35558 L
.28568 .35555 L
.28703 .3555 L
.29191 .35526 L
.29459 .35513 L
.29591 .35508 L
.29712 .35504 L
.29782 .35503 L
.29855 .35501 L
.2993 .35501 L
.30011 .35501 L
.30079 .35501 L
.30151 .35502 L
.30282 .35505 L
.30351 .35507 L
.30425 .3551 L
.30559 .35516 L
.30812 .35531 L
.31265 .3556 L
.31389 .35567 L
.3152 .35573 L
.31631 .35577 L
.31753 .3558 L
.31823 .35581 L
.31887 .35582 L
.31961 .35581 L
.3203 .35581 L
.32154 .35578 L
.32224 .35575 L
.32288 .35573 L
.32533 .35559 L
.32791 .35539 L
.33039 .35519 L
.33274 .35502 L
.33403 .35495 L
.33472 .35492 L
.33544 .35489 L
.33673 .35485 L
.33792 .35484 L
.33866 .35484 L
.33946 .35485 L
.34021 .35487 L
.3409 .3549 L
.34222 .35496 L
.3436 .35505 L
.34892 .35552 L
.35148 .35575 L
.35274 .35584 L
Mistroke
.3539 .35591 L
.35496 .35595 L
.35608 .35598 L
.3572 .35599 L
.35844 .35598 L
.35976 .35593 L
.36097 .35587 L
.36236 .35577 L
.36369 .35565 L
.36861 .35512 L
.37082 .3549 L
.37202 .35481 L
.37316 .35473 L
.37423 .35468 L
.37538 .35465 L
.37642 .35465 L
.37739 .35466 L
.37854 .3547 L
.37961 .35476 L
.38078 .35485 L
.38204 .35497 L
.38697 .35557 L
.38953 .35587 L
.39093 .35601 L
.39225 .35611 L
.39336 .35617 L
.39457 .35621 L
.39522 .35621 L
.39591 .35621 L
.39713 .35617 L
.39846 .35609 L
.3992 .35603 L
.39987 .35597 L
.40242 .35566 L
.40542 .35522 L
.4082 .35482 L
.40944 .35467 L
.41061 .35455 L
.41182 .35446 L
.41247 .35442 L
.41316 .3544 L
.41385 .35438 L
.4146 .35438 L
.41531 .3544 L
.41597 .35442 L
.41722 .3545 L
.41791 .35456 L
.41854 .35462 L
.42096 .35495 L
.42358 .35539 L
Mistroke
.42606 .35583 L
.42831 .35618 L
.42946 .35632 L
.43069 .35644 L
.432 .35652 L
.43324 .35655 L
.4344 .35653 L
.43563 .35646 L
.43668 .35637 L
.43784 .35623 L
.44043 .35579 L
.44323 .35521 L
.44585 .35466 L
.44828 .35424 L
.44952 .35408 L
.45084 .35397 L
.4516 .35394 L
.45231 .35393 L
.45295 .35394 L
.45364 .35396 L
.45432 .354 L
.45507 .35407 L
.45585 .35417 L
.45658 .35428 L
.45928 .35482 L
.46451 .35618 L
.46681 .35671 L
.46813 .35694 L
.46936 .35709 L
.47052 .35717 L
.47178 .35719 L
.47243 .35717 L
.47312 .35712 L
.47435 .35698 L
.475 .35687 L
.47569 .35674 L
.47694 .35644 L
.47979 .35558 L
.48222 .35473 L
.48487 .35385 L
.48608 .35351 L
.48737 .35323 L
.48847 .35305 L
.48968 .35294 L
.49094 .35293 L
.49209 .35301 L
.49273 .35309 L
.49342 .35322 L
.49469 .35353 L
.49587 .35391 L
Mistroke
.49713 .3544 L
.49939 .35544 L
.50368 .35754 L
.50585 .35838 L
.50708 .35873 L
.50822 .35894 L
.50892 .359 L
.50958 .35902 L
.51081 .35893 L
.5115 .35881 L
.51214 .35865 L
.51284 .35843 L
.51358 .35813 L
.51592 .35684 L
.51851 .35489 L
.52112 .35266 L
.52387 .35046 L
.52531 .34954 L
.52612 .34913 L
.52688 .34884 L
.52758 .34866 L
.52821 .34857 L
.52895 .34857 L
.52964 .34868 L
.5309 .34917 L
.53154 .34957 L
.53224 .35013 L
.53348 .35146 L
.53463 .3531 L
.53724 .3582 L
.54004 .36579 L
.54981 .40273 L
.55472 .42065 L
.55746 .42852 L
.55995 .43388 L
.56137 .43614 L
.56211 .4371 L
.5629 .43793 L
.56359 .43852 L
.56435 .43901 L
.56504 .43933 L
.56568 .43953 L
.56637 .43963 L
.56702 .43962 L
.56825 .43938 L
.56956 .43883 L
.57031 .4384 L
.57099 .43795 L
.57603 .43369 L
.57849 .43165 L
Mistroke
.58075 .43016 L
.58196 .42957 L
.58312 .42915 L
.58434 .42888 L
.58503 .4288 L
.58567 .42877 L
.58638 .4288 L
.58705 .42887 L
.5883 .42912 L
.589 .42932 L
.58964 .42953 L
.5911 .43013 L
.59579 .43254 L
.59837 .4338 L
.59964 .43431 L
.60082 .4347 L
.60192 .43497 L
.60309 .43517 L
.60427 .43527 L
.60557 .43525 L
.60664 .43515 L
.6078 .43495 L
.6089 .4347 L
.6099 .43441 L
.61511 .43251 L
.61765 .43162 L
.61876 .4313 L
.61996 .43101 L
.62122 .43079 L
.62241 .43065 L
.62307 .43061 L
.62377 .4306 L
.62502 .43064 L
.62568 .43069 L
.62638 .43077 L
.62766 .43098 L
.62917 .43131 L
.63056 .43168 L
.63533 .43309 L
.63671 .43345 L
.638 .43375 L
.63916 .43396 L
.64042 .43413 L
.64152 .43423 L
.64274 .43427 L
.644 .43424 L
.64518 .43415 L
.64629 .43402 L
.6473 .43386 L
.64956 .43339 L
Mistroke
.65467 .43216 L
.65606 .43186 L
.65755 .43159 L
.65882 .43142 L
.65954 .43135 L
.66021 .43129 L
.66145 .43124 L
.66275 .43125 L
.66385 .43131 L
.66507 .43142 L
.66638 .43159 L
.66778 .43182 L
.67029 .43232 L
.67287 .43286 L
.67528 .43331 L
.67659 .43351 L
.67779 .43366 L
.67847 .43372 L
.67912 .43376 L
.67981 .4338 L
.68055 .43382 L
.68131 .43382 L
.68201 .4338 L
.6828 .43377 L
.68355 .43371 L
.68425 .43365 L
.68489 .43358 L
.68633 .43339 L
.69166 .43246 L
.69392 .43208 L
.69517 .4319 L
.69634 .43177 L
.69701 .43171 L
.69774 .43165 L
.699 .43159 L
.70029 .43158 L
.70147 .43161 L
.70271 .43168 L
.70386 .43178 L
.70513 .43192 L
.7065 .4321 L
.70907 .4325 L
.71182 .43294 L
.71323 .43314 L
.71457 .43329 L
.71576 .43341 L
.71706 .43349 L
.71829 .43354 L
.71959 .43354 L
.7207 .43351 L
Mistroke
.72192 .43345 L
.72266 .4334 L
.72336 .43333 L
.72467 .43319 L
.72763 .43281 L
.73021 .43245 L
.73162 .43226 L
.73295 .43211 L
.73419 .43199 L
.73533 .43191 L
.73659 .43185 L
.73725 .43183 L
.73795 .43182 L
.73909 .43183 L
.74016 .43186 L
.74132 .43192 L
.74257 .43201 L
.74539 .43229 L
.74806 .4326 L
.75063 .4329 L
.75189 .43302 L
.75304 .43312 L
.75418 .43319 L
.75527 .43324 L
.75642 .43328 L
.75767 .43329 L
.75895 .43328 L
.75966 .43326 L
.76031 .43323 L
.76157 .43317 L
.76276 .4331 L
.76812 .43267 L
.77305 .43233 L
.77728 .43214 L
.77952 .43203 L
.78078 .43196 L
.78192 .43187 L
.78316 .43174 L
.78433 .43159 L
.78658 .43118 L
.78781 .43088 L
.78894 .43055 L
.7915 .42958 L
.79393 .42839 L
.79615 .42706 L
.80115 .42339 L
.8102 .41601 L
.83082 .40415 L
.87049 .37838 L
.90864 .35357 L
Mistroke
.94925 .32718 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo00cooooo0ol0000Fooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo0000023ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oo
oooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool02oooool2o`0000;ooooo
00?o0000ooooooooool04oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo023o
oooo00Co0000oooooooooooo00001oooool5o`00027ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000002Oooooo00?o0000ooooooooool01_ooool002Oooooo0_l0000<ooooo`05o`00
0?ooooooooooooooool000005Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo
01oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0000Rooooo`04o`000?oo
ooooooooo`0000Oooooo1?l0000Qooooo`04o`000?ooooooooooo`0000Sooooo0ol0000Xooooo`03
o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000008_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool01_ooool002Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00002Oooool2o`0002;ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`0Qooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Vooooo`;o
00002?ooool002Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`;o0000
4_ooool2o`0000Wooooo0ol0000Rooooo`;o00002oooool00ol0003oooooooooo`0Qooooo`;o0000
2_ooool2o`0002;ooooo0_l00009ooooo`?o0000:?ooool00ol0003oooooooooo`06ooooo`009ooo
ool2o`0000[ooooo00?o0000ooooooooool02?ooool2o`000>3ooooo000Wooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool2o`000=kooooo000Wooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3Kooooo`009oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00kooooo0_l0003Kooooo`008Oooooooo`0000009ooo
ool01?l0003oooooooooool00007ooooo`;o00002oooool00ol0003oooooooooo`04ooooo`;o0000
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
1oooool002Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo
0_l0000=ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo00001oooool002Oooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0aoooool00ol0003oooooooooo`09ooooo`009oooool2o`0000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Gooooo`;o0000a_ooool00ol0003oooooooooo`0:ooooo`009ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool2o`000<;ooooo
0_l0000=ooooo`009oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001kooooo
00?o0000ooooooooool0_Oooool2o`0000oooooo000Wooooo`03o`000?oooooooooo00?ooooo1?l0
000Oooooo`03o`000?oooooooooo0;[ooooo0_l0000Aooooo`009oooool2o`0002Sooooo00?o0000
ooooooooool0^?ooool00ol0003oooooooooo`0Aooooo`009oooool00ol0003oooooooooo`0Xoooo
o`?o0000]Oooool2o`0001Cooooo000Wooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0C_ooool3o`0005oooooo0_l0000Fooooo`009oooool00ol0003oooooooooo`0/ooooo`;o0000
>oooool2o`0000Oooooo1?l00005ooooo`;o000000?oooooo`000?ooool0G?ooool2o`0001Sooooo
000Wooooo`;o0000;_oooollo`0000;ooooo1ol00003ooooo`?o000000?oooooo`000?l000000ooo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo000Wooooo`03o`000?oooooo
oooo07Oooooo0ol00005ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool06Oooool0
02Oooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1Eooooo`;o00007?ooool002Oo
oooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01co
oooo000Wooooo`;o0000POooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01gooooo
0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol0
0005ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0DOooool00ol0003ooooooooo
o`0Nooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0POooool00ol0003oooooooooo`1?ooooo`;o00008Oooool000Oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo04gooooo0_l0000S
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000P_ooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo02?ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0003o
ooooooooo`21ooooo`03o`000?oooooooooo04[ooooo0_l0000Vooooo`001oooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Aoooool2o`0002Sooooo0008oooo
o`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0:?ooool002Oooooo0_l00023ooooo`03
o`000?oooooooooo04Cooooo0_l0000[ooooo`009oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo04;ooooo0_l0000]ooooo`009oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo043ooooo0_l0000_ooooo`009oooool2o`0008Cooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0_ooooo`009oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool0<?ooool002Oooooo00?o0000ooooooooool0Poooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo037ooooo000Wooooo`03o`000?oooooooooo08Cooooo
00?o0000ooooooooool01?ooool2o`0003?ooooo0_l0000dooooo`009oooool2o`0008Gooooo00?o
0000ooooooooool00_ooool6o`0000?ooooo1_l00005ooooo`Go00001?ooool6o`0000?ooooo1ol0
0003ooooo`So0000=Oooool002Oooooo00?o0000ooooooooool0QOooool01Ol0003ooooooooooooo
oooo000000Gooooo0ol00006ooooo`Go00001Oooool4o`0000Kooooo1?l00006ooooo`?o0000?Ooo
ool002Oooooo00?o0000ooooooooool0QOooool4o`0006gooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo000=ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02oooo
o`;o0000moooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000gooooo00Co0000oooo
oooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00002?ooool00ol0003oooooooooo`3fooooo`003_ooool2o`0000[ooooo0_l00002ooooo`Go0000
1?ooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo
00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000
ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`00
9oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2
o`000?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`;o0000moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`3foooo
o`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0?Kooooo0008ooooo`;o00002_ooool2
o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo00?o0000ooooooooool0m_ooool0
02Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
0_l0003gooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o
0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01?ooool2o`000?Oooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`3mooooo`004oooool01?l0003oooooooooool00008ooooo`;o0000ooooool001Cooooo0_l0000:
ooooo`03o`000?oooooooooo0?gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .27486 L
.03068 .26067 L
.03279 .24936 L
.03398 .24402 L
.03527 .23915 L
.03635 .23587 L
.03754 .23308 L
.03882 .231 L
.03952 .23026 L
.04018 .22983 L
.04135 .22962 L
.04262 .23015 L
.04393 .23144 L
.04516 .23321 L
.04793 .23874 L
.05297 .25081 L
.05533 .25586 L
.05756 .25968 L
.05879 .26133 L
.06012 .26271 L
.06133 .26361 L
.06244 .26416 L
.10458 .28625 L
.14407 .31034 L
.18204 .33462 L
.22246 .36 L
.2411 .37346 L
.24617 .3776 L
.25093 .38055 L
.25332 .38164 L
.25589 .38257 L
.26137 .38397 L
.26713 .38518 L
.2724 .38627 L
.27498 .38674 L
.27738 .38709 L
.27859 .38721 L
.27988 .38731 L
.28061 .38734 L
.28131 .38736 L
.28261 .38735 L
.28377 .38731 L
.28505 .38722 L
.2857 .38716 L
.28639 .38708 L
.28764 .38692 L
.29227 .38617 L
.29507 .38572 L
.29645 .38554 L
Mistroke
.29774 .38542 L
.29889 .38533 L
.30013 .38529 L
.30083 .38528 L
.30149 .38528 L
.30273 .38532 L
.3039 .3854 L
.30515 .38552 L
.3074 .38582 L
.31252 .38664 L
.31385 .38683 L
.3153 .38701 L
.31596 .38707 L
.31667 .38713 L
.31793 .3872 L
.31914 .38723 L
.32027 .38722 L
.32151 .38716 L
.32221 .38711 L
.32285 .38706 L
.32745 .38644 L
.33179 .38576 L
.33296 .38561 L
.3342 .38548 L
.33484 .38543 L
.33555 .38538 L
.3368 .38533 L
.33793 .38533 L
.33914 .38536 L
.34029 .38543 L
.34134 .38552 L
.34375 .38583 L
.34638 .38624 L
.3487 .38662 L
.34997 .38681 L
.35116 .38696 L
.35234 .38708 L
.35342 .38716 L
.35462 .38722 L
.35591 .38723 L
.35693 .38721 L
.35804 .38715 L
.35921 .38705 L
.3603 .38693 L
.36545 .38611 L
.36797 .3857 L
.36909 .38555 L
.37031 .38542 L
.37161 .38531 L
.37233 .38528 L
Mistroke
.373 .38526 L
.37373 .38525 L
.3744 .38526 L
.37518 .38529 L
.37591 .38534 L
.37718 .38545 L
.37835 .38559 L
.38101 .38602 L
.38348 .38648 L
.38609 .38693 L
.38746 .38713 L
.38818 .38721 L
.38896 .38729 L
.38967 .38734 L
.39032 .38737 L
.39159 .3874 L
.39286 .38737 L
.39404 .38729 L
.39533 .38715 L
.39671 .38695 L
.40155 .38598 L
.40375 .38554 L
.4049 .38534 L
.40612 .38517 L
.40718 .38506 L
.40835 .38498 L
.40941 .38495 L
.4104 .38497 L
.41167 .38506 L
.41287 .38519 L
.41395 .38536 L
.41512 .38559 L
.42016 .38682 L
.42252 .38737 L
.42385 .38761 L
.42506 .38778 L
.42618 .38788 L
.42741 .38791 L
.42856 .38788 L
.42964 .38779 L
.43029 .3877 L
.431 .38758 L
.43229 .38731 L
.43468 .38665 L
.43725 .38581 L
.44005 .38491 L
.44139 .38456 L
.44212 .3844 L
.44282 .38427 L
.44346 .38418 L
Mistroke
.44417 .3841 L
.44539 .38405 L
.44607 .38406 L
.44681 .38412 L
.44759 .38421 L
.44832 .38434 L
.44962 .38466 L
.45102 .38513 L
.4559 .38732 L
.45858 .38854 L
.45989 .38902 L
.4611 .38936 L
.46242 .38959 L
.46311 .38964 L
.46385 .38965 L
.46503 .38953 L
.46634 .38922 L
.46755 .38876 L
.46885 .38809 L
.4712 .3865 L
.47391 .38426 L
.47686 .38184 L
.47821 .38092 L
.47895 .38051 L
.47965 .38019 L
.48087 .37983 L
.48152 .37976 L
.48223 .37979 L
.4835 .38013 L
.48422 .38051 L
.48489 .38099 L
.48625 .38236 L
.48771 .38444 L
.48906 .38697 L
.49034 .38988 L
.49273 .39661 L
.50231 .43418 L
.50473 .44384 L
.50733 .45309 L
.50974 .46014 L
.51203 .46524 L
.51325 .46729 L
.5139 .46817 L
.51459 .46897 L
.5158 .47003 L
.51693 .47062 L
.51763 .47081 L
.51838 .47088 L
.5191 .47081 L
.51975 .47065 L
Mistroke
.521 .47011 L
.52232 .46926 L
.52728 .46471 L
.52972 .46247 L
.53079 .46162 L
.53197 .46081 L
.53296 .46027 L
.53402 .45981 L
.53514 .45949 L
.53619 .45934 L
.53735 .45934 L
.53858 .45952 L
.53962 .45981 L
.54077 .46024 L
.54315 .46145 L
.54569 .46298 L
.54789 .46428 L
.55026 .46546 L
.55096 .46573 L
.55169 .46598 L
.55301 .46632 L
.55424 .4665 L
.55494 .46654 L
.5556 .46654 L
.55682 .46643 L
.55793 .46623 L
.55922 .46589 L
.56043 .46547 L
.56469 .46362 L
.56702 .4626 L
.56922 .46183 L
.57035 .46152 L
.57157 .46129 L
.57224 .4612 L
.57293 .46115 L
.57418 .46113 L
.57532 .46121 L
.57637 .46136 L
.57754 .4616 L
.57878 .46193 L
.58374 .46368 L
.58645 .46461 L
.58778 .46497 L
.589 .46524 L
.59032 .46544 L
.59105 .46551 L
.59174 .46554 L
.59249 .46555 L
.59319 .46552 L
.59395 .46547 L
Mistroke
.59477 .46537 L
.59546 .46527 L
.5962 .46512 L
.59756 .46481 L
.60009 .46407 L
.60273 .46323 L
.60519 .46253 L
.60654 .46221 L
.60776 .46199 L
.60846 .4619 L
.60912 .46183 L
.60982 .46178 L
.61058 .46176 L
.61174 .46178 L
.61301 .46187 L
.61365 .46195 L
.61434 .46206 L
.61559 .46229 L
.62023 .4635 L
.62263 .46415 L
.62395 .46447 L
.62519 .46472 L
.62635 .4649 L
.62761 .46504 L
.62875 .4651 L
.62981 .46511 L
.63106 .46505 L
.63223 .46494 L
.63351 .46475 L
.63489 .46449 L
.64028 .46318 L
.64298 .46258 L
.64373 .46245 L
.64452 .46233 L
.64526 .46224 L
.64594 .46217 L
.64663 .46212 L
.64739 .46209 L
.64805 .46208 L
.64875 .4621 L
.64997 .46216 L
.65066 .46223 L
.6513 .4623 L
.65261 .46249 L
.65385 .46272 L
.65617 .46323 L
.65886 .46385 L
.66138 .46436 L
.66252 .46454 L
.6636 .46468 L
Mistroke
.66484 .46479 L
.66599 .46484 L
.66724 .46484 L
.66841 .46479 L
.66969 .46467 L
.67041 .46458 L
.67106 .46449 L
.67599 .46353 L
.67859 .46299 L
.68001 .46274 L
.68133 .46255 L
.68247 .46243 L
.68369 .46235 L
.68438 .46232 L
.68504 .46231 L
.68627 .46233 L
.68741 .4624 L
.68845 .4625 L
.6896 .46264 L
.69082 .46283 L
.69518 .46365 L
.69756 .46409 L
.69871 .46426 L
.69977 .4644 L
.70089 .46451 L
.7021 .46459 L
.70341 .46462 L
.70465 .4646 L
.70577 .46454 L
.7068 .46445 L
.70793 .46433 L
.70913 .46416 L
.71434 .46329 L
.71565 .46309 L
.71689 .46292 L
.718 .4628 L
.71922 .46271 L
.72027 .46266 L
.7214 .46264 L
.72245 .46265 L
.72341 .4627 L
.72453 .46277 L
.72573 .46288 L
.72792 .46313 L
.73035 .46341 L
.73157 .46353 L
.73226 .46358 L
.73291 .46361 L
.73407 .46364 L
.73512 .46361 L
Mistroke
.73634 .46352 L
.73749 .46335 L
.73864 .46311 L
.73987 .46275 L
.74209 .46187 L
.74474 .4604 L
.74716 .45872 L
.75742 .45012 L
.7664 .44433 L
.77585 .43989 L
.81399 .4152 L
.85458 .38896 L
.89365 .36353 L
.93517 .33618 L
.97518 .30983 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
00Coooooo`000?l0003o0000loooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01_l0
003oooooooooool0003oooooo`000??ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo0?3ooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`3`ooooo`002?ooool2o`0000[ooooo0_l0
0003ooooo`?o00000_ooool5o`0000Cooooo0ol00004ooooo`03o`000?oooooooooo0>oooooo000W
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0koooool002Oooooo00?o0000oooo
ool000001?ooool00ol0003oooooooooo`3_ooooo`009oooool2o`0000Kooooo00?o0000oooooooo
ool0k_ooool002Oooooo0_l00006ooooo`;o0000koooool002Oooooo0_l00007ooooo`;o00007_oo
ool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`?o00008_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0002;ooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00001oooool002Oooooo0_l0
0009ooooo`;o00006oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00023o
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Pooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o0000
2oooool3o`0001Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Pooooo`04
o`000?ooooooooooo`0000Oooooo1Ol0000Qooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00000Wooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o00003_ooool2o`0001Kooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool00007ooooo`Co00008Ooo
ool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`06ooooo`009ooo
ool2o`00013ooooo0_l0000Dooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000008_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool01_ooool002Oooooo0_l0
000Booooo`;o00004_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000002Kooooo0_l00008ooooo`009oooool2o`0001Cooooo0_l0000Aooooo`;o00002Ooo
ool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0000:ooooo`;o00008_oo
ool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o00005_ooool0
0ol0003oooooooooo`3Nooooo`009oooool00ol0003oooooooooo`0Fooooo`;o0000g_ooool002Oo
oooo00?o0000ooooooooool06?ooool2o`000=cooooo000Wooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0fOooool0027oooooool0000002Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001oooool002Oooooo00?o0000
ooooooooool07_ooool2o`0000gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:Oooool2o`0000;ooooo00?o0000
ooooooooool01Oooool002Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`36oooo
o`03o`000?oooooooooo00[ooooo000Wooooo`;o00008_ooool00ol0003oooooooooo`34ooooo`03
o`000?oooooooooo00_ooooo000Wooooo`03o`000?oooooooooo02;ooooo0_l00032ooooo`;o0000
3_ooool002Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2nooooo`03o`000?oo
oooooooo00kooooo000Wooooo`03o`000?oooooooooo02Gooooo0_l0002looooo`;o00004Oooool0
02Oooooo0_l0000Xooooo`;o0000^Oooool00ol0003oooooooooo`0Aooooo`009oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo0;Cooooo0_l0000Dooooo`009oooool00ol0003ooooo
ooooo`0Zooooo`;o0000/oooool00ol0003oooooooooo`0Dooooo`009oooool00ol0003ooooooooo
o`0/ooooo`;o0000/?ooool00ol0003oooooooooo`0Eooooo`009oooool2o`0002oooooo00?o0000
ooooooooool0Zoooool2o`0001Sooooo000Wooooo`03o`000?oooooooooo02oooooo0_l0002Zoooo
o`03o`000?oooooooooo01Sooooo000Wooooo`03o`000?oooooooooo037ooooo0_l0002Vooooo`;o
00006oooool002Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2Qooooo`;o0000
7Oooool002Oooooo0_l0000eooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool07Ooo
ool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3
o`0000Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Looooo`;o00008?ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Ko
oooo0_l0000hooooo`?o0000Goooool2o`0002;ooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>?ooool4o`0000Kooooo0ol00006ooooo`?o00001_ooool4o`00
00Gooooo1?l00005ooooo`Co00001Oooool2o`000003ooooool0003ooooo05gooooo00?o0000oooo
ooooool08_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0003gooooo1ol00002
ooooo`Oo00000_ooool6o`0000?ooooo1ol00003ooooo`Ko00000oooool5o`0000Cooooo00?o0000
ooooooooool0FOooool2o`0002Gooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool09Oooool000Oooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo05Gooooo0_l0000Xoooo
o`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000oooooooo
ool0M?ooool00ol0003oooooooooo`1Cooooo`;o0000:_ooool002Oooooo0_l0001eooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool0:_ooool002Oooooo00?o0000ooooooooool0MOoo
ool00ol0003oooooooooo`1?ooooo`;o0000;Oooool002Oooooo00?o0000ooooooooool0MOooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02gooooo000Wooooo`;o0000M_ooool00ol0
003oooooooooo`1<ooooo`;o0000<?ooool002Oooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo033ooooo000Wooooo`03o`000?oooooooooo07Gooooo
00?o0000ooooooooool0BOooool2o`0003?ooooo000Wooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0cooooo`009oooool2o`0007Oooooo00?o0000
ooooooooool0AOooool2o`0003Kooooo000Wooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`0fooooo`009oooool00ol0003oooooooooo`1fooooo`03
o`000?oooooooooo04;ooooo0_l0000iooooo`009oooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooooooo03oooooo0_l0000kooooo`009oooool2o`0007Sooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0kooooo`009oooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo03cooooo0_l0000nooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`00
00?ooooo0ol00005ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0nooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool00oooool3o`0003?ooooo00?o0000ooooooooool0?oooool000gooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo
0_l0001iooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000oooool6o`0000?ooooo
1ol00002ooooo`So000000?oooooo`000?l000001_l000000ooooooo0000o`000008o`0004;ooooo
000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07Wooooo00Co0000oooooooooooo00001Oooool4o`00
00Kooooo0ol00006ooooo`?o00001oooool3o`0000Oooooo0_l0001;ooooo`003Oooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03o`000?oooooo
oooo07Wooooo0ol0001jooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo00002?ooool00ol0003oooooooooo`3fooooo`003_ooool2o`0000[ooooo0_l0
0002ooooo`Go00001?ooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000
moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3f
ooooo`009oooool2o`000?Oooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0m_ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`;o0000moooool000Oooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0?Kooooo0008oooo
o`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo0_l0003gooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01?ooool2o`000?Oooooo000Cooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00008ooooo`;o0000ooooool0
01Cooooo0_l0000:ooooo`03o`000?oooooooooo0?gooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02499 .3087 L
.02605 .30844 L
.02729 .30822 L
.02846 .30813 L
.02954 .30817 L
.03053 .30833 L
.03163 .30866 L
.03279 .30921 L
.03395 .30997 L
.0352 .31103 L
.03746 .31357 L
.04262 .32168 L
.04516 .32618 L
.04793 .33075 L
.04919 .33254 L
.05054 .33416 L
.05182 .33535 L
.05297 .33609 L
.05419 .3365 L
.05531 .33651 L
.05655 .33609 L
.05785 .33515 L
.05898 .33391 L
.06004 .3324 L
.06244 .32776 L
.06506 .32105 L
.06791 .31229 L
.07308 .29483 L
.07769 .28093 L
.08032 .27488 L
.08152 .2727 L
.08278 .27083 L
.08344 .27003 L
.08416 .2693 L
.08542 .26836 L
.08614 .26803 L
.0869 .26782 L
.08762 .26776 L
.08827 .26782 L
.08902 .26801 L
.08971 .2683 L
.09047 .26873 L
.09127 .26931 L
.0941 .2722 L
.09958 .27974 L
.10197 .28307 L
.10458 .2863 L
.10709 .28884 L
.10942 .29064 L
Mistroke
.11165 .29188 L
.11289 .2924 L
.11402 .29278 L
.11889 .29385 L
.12145 .2944 L
.12274 .29475 L
.12415 .29522 L
.1267 .29636 L
.12907 .2978 L
.13359 .30144 L
.14247 .30992 L
.14749 .31381 L
.15033 .31548 L
.15295 .31672 L
.15766 .31856 L
.16286 .32077 L
.16751 .3235 L
.17187 .32684 L
.18143 .33509 L
.22017 .36023 L
.26136 .38724 L
.27131 .39234 L
.27677 .39478 L
.28193 .39785 L
.29194 .40632 L
.29628 .41005 L
.29874 .41187 L
.30104 .41328 L
.30327 .41435 L
.30567 .41518 L
.30699 .4155 L
.30824 .41572 L
.30936 .41587 L
.31058 .41598 L
.31163 .41603 L
.31279 .41607 L
.314 .41609 L
.31514 .4161 L
.31613 .4161 L
.31717 .41611 L
.31831 .41614 L
.31936 .41618 L
.3206 .41625 L
.32173 .41634 L
.32303 .41648 L
.32426 .41664 L
.32883 .41742 L
.33124 .41785 L
.3338 .41824 L
.33514 .41838 L
Mistroke
.3359 .41844 L
.33661 .41848 L
.33786 .41851 L
.33856 .4185 L
.3392 .41848 L
.34049 .41839 L
.3417 .41825 L
.34279 .41809 L
.34397 .41788 L
.34905 .4167 L
.35137 .41618 L
.35263 .41594 L
.35382 .41575 L
.35482 .41564 L
.3559 .41556 L
.3571 .41553 L
.3582 .41556 L
.35948 .41566 L
.36013 .41574 L
.36085 .41585 L
.3633 .41636 L
.36884 .41797 L
.37135 .41862 L
.37275 .41891 L
.37404 .41909 L
.37518 .41919 L
.37642 .41922 L
.37772 .41915 L
.37893 .419 L
.3802 .41876 L
.38156 .41842 L
.38398 .41762 L
.38681 .41654 L
.38946 .41557 L
.39063 .41521 L
.39174 .41492 L
.39302 .41467 L
.39419 .41454 L
.39549 .4145 L
.39668 .41458 L
.398 .41479 L
.39873 .41496 L
.3994 .41515 L
.40408 .41719 L
.40845 .41947 L
.41065 .42038 L
.41188 .42074 L
.413 .42096 L
.41423 .42104 L
.41492 .42102 L
Mistroke
.41557 .42095 L
.41674 .4207 L
.41799 .42026 L
.41918 .41968 L
.42046 .4189 L
.42278 .41713 L
.42548 .41475 L
.42805 .41255 L
.42917 .41172 L
.43036 .41099 L
.43166 .41043 L
.43287 .41017 L
.43407 .4102 L
.43519 .41054 L
.4362 .41111 L
.43729 .41204 L
.43859 .41358 L
.4398 .41547 L
.44257 .42135 L
.44526 .42908 L
.44814 .43915 L
.45813 .47804 L
.46069 .48619 L
.46341 .49305 L
.46573 .49725 L
.46705 .49895 L
.4683 .5001 L
.46894 .50053 L
.46965 .50088 L
.47039 .50111 L
.47107 .50122 L
.4723 .50115 L
.47362 .50077 L
.47436 .50043 L
.47517 .49998 L
.47663 .49897 L
.47936 .49672 L
.48198 .4945 L
.48444 .49273 L
.48568 .49202 L
.48701 .49143 L
.48776 .49117 L
.48848 .49099 L
.48912 .49088 L
.48983 .4908 L
.4911 .4908 L
.49225 .49093 L
.49289 .49106 L
.49358 .49124 L
.49483 .49165 L
Mistroke
.49948 .4938 L
.50186 .49495 L
.50317 .49552 L
.50441 .49598 L
.50556 .49634 L
.50681 .49663 L
.50795 .4968 L
.509 .49687 L
.51025 .49686 L
.51141 .49676 L
.51269 .49656 L
.51341 .49641 L
.51407 .49625 L
.51945 .49448 L
.52182 .4937 L
.52312 .49333 L
.52435 .49304 L
.52505 .49291 L
.52581 .49279 L
.52713 .49265 L
.52779 .49261 L
.52848 .49259 L
.52972 .49263 L
.531 .49274 L
.53172 .49283 L
.53238 .49293 L
.53486 .49346 L
.53755 .49416 L
.54052 .49493 L
.54171 .49521 L
.54299 .49546 L
.5442 .49565 L
.54531 .49577 L
.5465 .49586 L
.5478 .49588 L
.54845 .49587 L
.54915 .49584 L
.55041 .49573 L
.55159 .49559 L
.55288 .49538 L
.55521 .49493 L
.55957 .494 L
.56207 .49357 L
.56275 .49348 L
.56348 .4934 L
.56417 .49333 L
.56481 .49329 L
.56552 .49325 L
.5663 .49323 L
.56698 .49323 L
Mistroke
.56771 .49325 L
.56843 .49328 L
.5691 .49332 L
.57036 .49344 L
.57157 .49359 L
.57285 .49378 L
.57515 .49417 L
.5778 .49465 L
.58032 .49505 L
.58147 .49519 L
.5827 .49531 L
.58334 .49536 L
.58404 .4954 L
.58528 .49543 L
.5864 .49543 L
.58761 .49539 L
.58876 .49532 L
.5898 .49522 L
.59217 .49494 L
.59475 .49455 L
.59748 .49414 L
.59867 .49398 L
.59997 .49383 L
.60119 .49372 L
.60233 .49364 L
.60341 .49359 L
.60456 .49357 L
.60577 .49358 L
.60689 .49361 L
.60813 .49369 L
.60946 .4938 L
.61408 .49435 L
.61626 .49463 L
.6183 .49487 L
.61951 .49498 L
.62081 .49507 L
.622 .49513 L
.62308 .49516 L
.62427 .49516 L
.62556 .49514 L
.62622 .49511 L
.62691 .49508 L
.62818 .49499 L
.63064 .49477 L
.63297 .49452 L
.63504 .49429 L
.63733 .49407 L
.63854 .49397 L
.63984 .49389 L
.64055 .49386 L
Mistroke
.64121 .49383 L
.6425 .49381 L
.64367 .49381 L
.64494 .49383 L
.64615 .49388 L
.64727 .49394 L
.65001 .49415 L
.6525 .49437 L
.65515 .49459 L
.65656 .4947 L
.65807 .49479 L
.65939 .49485 L
.66059 .49489 L
.66179 .49491 L
.66294 .49491 L
.66422 .4949 L
.6654 .49487 L
.6667 .49482 L
.66808 .49476 L
.6773 .49431 L
.67961 .49422 L
.68206 .49412 L
.68333 .49405 L
.68473 .49396 L
.686 .49385 L
.68719 .49372 L
.68861 .49352 L
.68991 .49328 L
.69131 .49297 L
.69282 .49254 L
.69554 .49155 L
.69811 .49033 L
.73901 .46362 L
.77838 .43793 L
.81625 .41331 L
.85656 .38702 L
.89536 .36179 L
.93661 .33481 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo00cooooo0ol0000Fooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo0000023ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oo
oooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool02oooool01Ol0003ooooo
oooooooooooo000001Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Poooo
o`04o`000?ooooooooooo`0000Oooooo1Ol0000Qooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`00000Wooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o00003?ooool01Ol0003o
oooooooooooooooo000001Gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0O
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003ooooo
ooooool00007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0
003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?o
oooo0_l0000Cooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000P
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000008_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000002Oooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooooooooooo00002Ooo
ool2o`0002;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0Qooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Vooooo`;o00002?ooool002Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017o
oooo0_l00009ooooo`?o00008_ooool2o`0000_ooooo00?o0000ooooooooool08Oooool2o`0000[o
oooo0_l0000Rooooo`;o00002Oooool3o`0002Sooooo00?o0000ooooooooool01_ooool002Oooooo
0_l0000:ooooo`03o`000?oooooooooo00Oooooo1?l0003Oooooo`009oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo0ol0003Mooooo`009oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0f_ooool002Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0=Wooooo000Qoooooooo
0000000Wooooo`04o`000?ooooooooooo`0000Oooooo0_l0000;ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooool000001oooool002Oooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`0Booooo`?o00003Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`;o00000_ooool00ol0003o
ooooooooo`05ooooo`009oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00[ooooo000Wooooo`;o0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
a?ooool00ol0003oooooooooo`0;ooooo`009oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000006oooool2o`000<;ooooo0_l0000>ooooo`009oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool0__ooool00ol0003ooooo
ooooo`0>ooooo`009oooool00ol0003oooooooooo`04ooooo`;o00007oooool2o`000;cooooo0_l0
000Aooooo`009oooool2o`0002Sooooo0_l0002hooooo`;o00004oooool002Oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo01?ooooo000Wooooo`03
o`000?oooooooooo02[ooooo0_l0002booooo`;o00005_ooool002Oooooo00?o0000ooooooooool0
;?ooool2o`000:kooooo0_l0000Hooooo`009oooool2o`0002oooooo00?o0000ooooooooool0Z_oo
ool00ol0003oooooooooo`0Hooooo`009oooool00ol0003oooooooooo`0_ooooo`;o0000Z?ooool2
o`0001_ooooo000Wooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Y?ooool00ol0
003oooooooooo`0Kooooo`009oooool00ol0003oooooooooo`0booooo`;o0000X_ooool2o`0001ko
oooo000Wooooo`;o0000=Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo01kooooo
0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol0
0005ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0Oooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0=_ooool2o`0009[ooooo0_l0000Rooooo`001oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0R
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000>_ooool3o`0009?ooooo0_l0
000Uooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`2?ooooo`03o`000?oooooooooo02Gooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`2<ooooo`;o0000:?ooool000Sooooo0_l0000:oooo
o`;o00000oooool3o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo03kooooo0_l0002;oooo
o`03o`000?oooooooooo02Sooooo000Wooooo`;o0000@Oooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo02Wooooo000Wooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
Q?ooool2o`0002cooooo000Wooooo`03o`000?oooooooooo04;ooooo0_l0000Oooooo`Co0000H?oo
ool00ol0003oooooooooo`0/ooooo`009oooool2o`0004Gooooo1_l00005ooooo`Go00001Oooool5
o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo05cooooo0_l0000_ooooo`009oooool00ol0
003oooooooooo`1:ooooo`Go00001Oooool5o`0000Gooooo1?l00004ooooo`03o`000?oooooooooo
05[ooooo0_l0000aooooo`009oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo05So
oooo00?o0000ooooooooool0<Oooool002Oooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`1Fooooo`;o0000=?ooool002Oooooo0_l0001Yooooo`03o`000?oooooooooo05?ooooo0_l0
000fooooo`009oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool0=_ooool002Oooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1@oooo
o`;o0000>Oooool002Oooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1>ooooo`;o
0000>oooool002Oooooo0_l0001Yooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
>oooool002Oooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1:ooooo`;o0000?_oo
ool000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo04Sooooo0_l00010ooooo`003Oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`10ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool2o`0006_ooooo00?o0000ooooooooool0A?ooool2o`0004?o
oooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`13ooooo`003Oooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
o`000?ooool01?l00005ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0@Oooool2
o`0004Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00008ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`16ooooo`003_ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool2o`0006cooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`17ooooo`009oooool00ol0003oooooooooo`1[
ooooo`03o`000?oooooooooo03cooooo0_l0001:ooooo`009oooool00ol0003oooooooooo`1/oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0B_ooool002Oooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`03ooooo`?o0000<_ooool2o`0004gooooo000Wooooo`;o0000
KOooool00ol0003oooooooooo`02ooooo`;o00000_ooool3o`0000;ooooo;_l0001>ooooo`009ooo
ool00ol0003oooooooooo`1]ooooo`04o`000?ooooooooooo`0000Kooooo0ol0001looooo`009ooo
ool00ol0003oooooooooo`1^ooooo`;o0000Q_ooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo0008oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o
0000moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`3fooooo`001oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00
0008ooooo`03o`000?oooooooooo0?Kooooo0008ooooo`;o00002_ooool2o`0000;ooooo1Ol00000
0ooooooo0000o`000003o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003goooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`005?oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0m_oo
ool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?Kooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?oo
ool2o`000?Oooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOoo
ool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool0
1?l0003oooooooooool00008ooooo`;o0000ooooool001Cooooo0_l0000:ooooo`03o`000?oooooo
oooo0?gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33571 L
.06484 .33745 L
.06744 .33895 L
.06989 .33999 L
.07216 .34067 L
.0748 .34128 L
.07625 .3416 L
.0776 .34194 L
.07996 .34273 L
.08121 .3433 L
.08255 .34407 L
.08561 .34648 L
.08851 .34968 L
.09396 .3573 L
.09642 .36076 L
.09904 .36384 L
.09981 .36455 L
.10054 .36512 L
.10126 .36556 L
.10191 .36587 L
.10319 .36616 L
.10387 .36614 L
.10458 .36598 L
.10584 .36534 L
.10704 .36427 L
.10812 .36294 L
.10929 .36108 L
.11191 .35546 L
.11434 .34868 L
.12344 .31747 L
.12574 .31054 L
.12822 .30445 L
.12963 .30176 L
.13093 .29984 L
.13218 .2985 L
.13349 .29764 L
.13476 .2973 L
.13548 .29733 L
.13612 .29748 L
.13739 .2981 L
.13858 .29903 L
.13997 .3005 L
.14125 .30214 L
.14415 .30653 L
.14883 .31397 L
.1514 .31746 L
.15385 .32005 L
.15611 .32176 L
.1574 .32244 L
Mistroke
.15858 .32291 L
.15969 .32322 L
.16068 .32342 L
.16183 .32357 L
.16292 .32366 L
.16422 .32373 L
.16543 .32379 L
.1667 .32389 L
.16737 .32397 L
.16809 .32407 L
.16936 .32433 L
.17057 .32468 L
.17166 .3251 L
.17284 .32567 L
.17554 .32742 L
.17841 .3299 L
.18355 .33529 L
.18813 .33997 L
.19063 .3421 L
.19295 .34372 L
.19547 .3451 L
.19823 .34623 L
.20307 .34778 L
.20545 .34862 L
.2077 .3496 L
.21192 .3521 L
.21645 .35573 L
.22136 .36023 L
.26233 .38748 L
.30178 .41298 L
.33972 .43741 L
.34451 .43943 L
.34973 .44173 L
.35921 .44764 L
.36196 .44937 L
.36347 .45018 L
.36489 .45079 L
.36609 .45117 L
.36738 .45142 L
.36808 .45149 L
.36882 .45149 L
.37014 .45135 L
.37133 .45104 L
.37261 .45053 L
.37381 .4499 L
.3749 .4492 L
.38012 .44499 L
.38132 .44403 L
.38261 .44312 L
.38384 .44242 L
Mistroke
.38495 .44196 L
.38621 .44172 L
.38739 .44179 L
.38868 .44225 L
.38941 .4427 L
.39008 .44325 L
.39128 .44456 L
.39242 .4462 L
.39453 .45031 L
.39681 .45625 L
.39928 .46426 L
.40919 .50434 L
.41191 .51421 L
.41482 .52278 L
.41623 .52602 L
.41756 .52852 L
.41876 .53026 L
.42007 .53164 L
.4213 .53246 L
.42246 .53284 L
.42373 .53285 L
.42444 .53269 L
.42509 .53245 L
.42634 .53177 L
.42769 .53076 L
.43043 .52818 L
.43302 .52558 L
.43546 .52341 L
.43652 .52263 L
.43765 .52196 L
.43888 .5214 L
.44002 .52107 L
.44132 .52091 L
.44253 .52097 L
.44323 .52108 L
.44387 .52124 L
.4446 .52147 L
.4453 .52175 L
.448 .52316 L
.45094 .52503 L
.45349 .52658 L
.45489 .5273 L
.45621 .52784 L
.45744 .52822 L
.45813 .52837 L
.45877 .52847 L
.4599 .52855 L
.46109 .52851 L
.49913 .52744 L
.50436 .52619 L
Mistroke
.50711 .52524 L
.51003 .52429 L
.51126 .52397 L
.51258 .52369 L
.51333 .52357 L
.51403 .52348 L
.51472 .52342 L
.51539 .52339 L
.51661 .5234 L
.51775 .52347 L
.519 .52364 L
.5197 .52376 L
.52033 .52389 L
.5251 .52522 L
.52761 .52598 L
.52899 .52634 L
.53027 .52663 L
.53139 .52683 L
.53259 .52698 L
.53328 .52704 L
.53393 .52707 L
.53514 .52707 L
.53626 .52701 L
.53729 .5269 L
.53842 .52673 L
.53963 .52649 L
.54423 .52529 L
.54664 .52464 L
.54796 .52433 L
.54918 .5241 L
.55026 .52393 L
.55142 .52381 L
.5527 .52374 L
.55386 .52374 L
.55492 .5238 L
.55607 .52391 L
.55715 .52406 L
.55815 .52424 L
.56329 .52547 L
.5658 .52607 L
.56689 .5263 L
.56809 .5265 L
.56933 .52666 L
.5705 .52675 L
.57115 .52678 L
.57185 .52679 L
.5731 .52676 L
.57381 .52672 L
.57459 .52665 L
.57599 .52646 L
Mistroke
.57735 .52622 L
.57861 .52597 L
.58332 .52488 L
.58468 .5246 L
.58596 .52437 L
.58711 .5242 L
.58836 .52407 L
.58946 .52401 L
.59066 .52398 L
.59191 .52402 L
.59309 .52411 L
.59419 .52423 L
.5952 .52438 L
.59746 .52479 L
.59999 .52533 L
.60269 .52589 L
.60399 .52611 L
.60523 .52629 L
.60634 .52641 L
.60754 .5265 L
.60882 .52654 L
.60947 .52653 L
.61017 .52651 L
.61143 .52644 L
.6126 .52632 L
.614 .52614 L
.61527 .52593 L
.61814 .5254 L
.62062 .52495 L
.62192 .52475 L
.6233 .52457 L
.62451 .52446 L
.62583 .52438 L
.62703 .52436 L
.62815 .52438 L
.62943 .52444 L
.63059 .52453 L
.63321 .52481 L
.63462 .52498 L
.63612 .52515 L
.63739 .52526 L
.63812 .5253 L
.6388 .52533 L
.63999 .52533 L
.64107 .52527 L
.64233 .52512 L
.64352 .5249 L
.64479 .52456 L
.64597 .52415 L
.64864 .52288 L
Mistroke
.651 .52138 L
.65314 .51976 L
.65794 .51562 L
.69622 .4904 L
.7363 .46396 L
.77485 .43884 L
.81587 .41203 L
.85536 .38645 L
.89334 .36184 L
.93377 .33584 L
.97269 .31075 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool06?ooool3o`000=_ooooo000Wooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooool00000foooool002Oooooo00?o0000ooooooooool0
5oooool01Ol0003ooooooooooooooooo00000=[ooooo000Qoooooooo0000000Wooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooo000000Oooooo000Wooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Wooooo0_l00002ooooo`03o`000?oo
oooooooo00Gooooo000Wooooo`04o`000?ooooooooooooooo`;o00004oooool00ol0003ooooooooo
o`05ooooo`;o0000bOooool00ol0003oooooooooo`0:ooooo`009oooool2o`0000Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`06ooooo`Go0000a?ooool00ol0003oooooooooo`0;
ooooo`009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02oooool2o`000<7ooooo0_l0000>ooooo`009oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2nooooo`03
o`000?oooooooooo00kooooo000Wooooo`03o`000?oooooooooo00Kooooo0_l0000=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0^oooool2o`00017ooooo000Wooooo`;o00002Ooo
ool3o`0000[ooooo00?o0000ooooooooool03_ooool2o`000;Wooooo0_l0000Cooooo`009oooool0
0ol0003oooooooooo`0;ooooo`;o00001oooool00ol0003oooooooooo`0Aooooo`;o0000]Oooool2
o`0001Gooooo000Wooooo`03o`000?oooooooooo00cooooo0_l00006ooooo`03o`000?oooooooooo
01?ooooo0_l0002booooo`03o`000?oooooooooo01Gooooo000Wooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`;o0000[_ooool2o`0001So
oooo000Wooooo`;o00003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0ZOooool2o`0001[ooooo000Wooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooo00007?ooool2o`000:Oooooo0_l0000Looooo`009oooool00ol0003ooooooooo
o`0@ooooo`?o00007_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo01cooooo000W
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool2o`000:;ooooo00?o0000
ooooooooool07Oooool002Oooooo0_l0000eooooo`03o`000?oooooooooo09gooooo0_l0000Poooo
o`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o
00001Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo09_ooooo00?o0000oooooooo
ool08?ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03Kooooo0_l0002Jooooo`03o`000?oooooooooo027ooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2Fooooo`03o`00
0?oooooooooo02;ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0000jooooo`;o
0000U?ooool2o`0002Gooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`0k
ooooo`;o0000T?ooool2o`0002Oooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo02Oooooo0008ooooo`;o00002_oo
ool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`0nooooo`;o0000R_oo
ool2o`0002[ooooo000Wooooo`;o0000@Oooool2o`0008Kooooo0_l0000/ooooo`009oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0;?ooool002Oo
oooo00?o0000ooooooooool0@oooool2o`00083ooooo0_l0000_ooooo`009oooool2o`0004Kooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0_ooooo`009oooool00ol0003ooooooooo
o`16ooooo`;o0000N_ooool2o`0003;ooooo000Wooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0MOooool2o`0003Cooooo000Wooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`0dooooo`009oooool2o`0004_ooooo0_l0001aooooo`;o
0000=oooool002Oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo03Oooooo000Wooooo`03o`000?oooooooooo04gooooo0_l0001[ooooo`;o0000>_oo
ool002Oooooo00?o0000ooooooooool0Coooool3o`0000Gooooo1?l0001Nooooo`03o`000?oooooo
oooo03[ooooo000Wooooo`;o0000Doooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0005cooooo0_l0000mooooo`009oooool00ol0003oooooooooo`1Cooooo`Co00001?ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo03gooooo000>ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`1Fooooo`;o0000@?ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0@?ooool000gooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l0
001Mooooo`03o`000?oooooooooo05;ooooo0_l00013ooooo`003Oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0@oooool000gooooo00Co
0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo04oooooo0_l00016ooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo04cooooo0_l00018ooooo`003_ooool2o`0000[ooooo0_l00002oooo
o`Go00001?ooool2o`0005kooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`18oooo
o`009oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04Wooooo0_l0001;ooooo`00
9oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
Boooool002Oooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`15ooooo`;o0000C_oo
ool002Oooooo0_l0001Oooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0C_ooool0
02Oooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`12ooooo`;o0000DOooool002Oo
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo057o
oooo000Wooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0?_ooool2o`0005Cooooo
000Wooooo`;o0000H?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo05Cooooo000W
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1E
ooooo`009oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0E_ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`02ooooo`Co
00004?ooool2o`00023ooooo0_l0001Iooooo`009oooool2o`00067ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooooooool2o`0000Kooooo:ol0001Jooooo`002?ooool2o`0000Cooooo
00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo
00?o0000ooooooooool0HOooool01?l0003oooooo`000?l00005ooooo`Oo0000QOooool000Oooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo067ooooo0ol0002B
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005ooooo`03
o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0m_ooool0
00Sooooo0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?ooool00ol0
003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Woooo
o`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0
m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool2o`000?Oooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`3fooooo`004oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool001?ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0003o
ooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool0oOooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33426 L
.10458 .363 L
.10702 .36508 L
.10967 .36698 L
.11217 .36838 L
.11448 .36933 L
.11576 .36973 L
.11717 .37009 L
.12002 .37066 L
.12137 .37092 L
.12266 .3712 L
.12391 .37153 L
.12507 .3719 L
.12734 .37291 L
.12854 .37362 L
.12981 .37452 L
.13249 .37695 L
.13492 .37975 L
.13941 .38598 L
.14415 .3925 L
.14649 .39494 L
.14713 .39545 L
.14782 .39592 L
.14905 .39651 L
.15027 .39675 L
.15141 .39664 L
.15244 .39624 L
.15357 .39547 L
.15478 .39424 L
.15613 .39238 L
.15885 .38711 L
.16138 .38061 L
.16375 .3734 L
.17256 .34454 L
.17498 .33819 L
.17631 .3353 L
.17756 .333 L
.17873 .33127 L
.18 .32985 L
.18115 .32897 L
.18221 .32851 L
.18338 .32839 L
.18448 .32861 L
.18569 .32921 L
.18698 .33023 L
.18834 .33166 L
.18963 .33329 L
.19204 .3369 L
.19741 .34557 L
Mistroke
.20002 .34922 L
.20239 .35185 L
.20345 .3528 L
.2046 .35365 L
.20559 .35425 L
.20668 .35478 L
.20784 .35518 L
.20906 .35547 L
.21019 .35562 L
.21124 .35569 L
.2125 .35571 L
.21368 .3557 L
.21491 .35568 L
.21556 .35568 L
.21626 .3557 L
.21744 .35577 L
.21868 .35594 L
.21974 .35618 L
.2209 .35654 L
.22215 .35708 L
.2235 .35782 L
.22592 .3596 L
.23137 .36527 L
.23648 .37127 L
.23898 .37388 L
.24129 .3759 L
.24356 .37746 L
.24596 .37864 L
.24721 .37908 L
.24837 .3794 L
.24965 .37968 L
.25102 .37992 L
.25339 .38027 L
.25456 .38047 L
.25564 .38068 L
.25766 .38122 L
.25872 .38161 L
.25986 .38211 L
.26223 .38348 L
.26473 .38543 L
.26921 .38996 L
.27444 .39592 L
.27699 .39856 L
.2793 .40059 L
.28147 .4021 L
.28352 .40316 L
.28464 .40359 L
.28568 .40391 L
.28682 .40418 L
.28803 .40439 L
Mistroke
.29058 .40468 L
.29184 .4048 L
.29301 .40493 L
.29407 .40509 L
.29519 .40532 L
.29644 .40567 L
.29757 .4061 L
.29991 .40733 L
.30122 .40825 L
.30243 .40926 L
.307 .41423 L
.31183 .42056 L
.31438 .42373 L
.31712 .42656 L
.31836 .42757 L
.31953 .42834 L
.32059 .42888 L
.32173 .42929 L
.32281 .42953 L
.32396 .42961 L
.32494 .42955 L
.32603 .42938 L
.32725 .42907 L
.32836 .4287 L
.33088 .42777 L
.33203 .42739 L
.3331 .42712 L
.33421 .42696 L
.33543 .42697 L
.33671 .42726 L
.33735 .42752 L
.33806 .42792 L
.33931 .42892 L
.34049 .43022 L
.34187 .43225 L
.34313 .43459 L
.34596 .44162 L
.3484 .44954 L
.35106 .45988 L
.3559 .48168 L
.36051 .50299 L
.36293 .51323 L
.36548 .52271 L
.36773 .52968 L
.37018 .53572 L
.37126 .53784 L
.37241 .53976 L
.3735 .54125 L
.37449 .54237 L
.37583 .54353 L
Mistroke
.37653 .54399 L
.37728 .54438 L
.37853 .54484 L
.37925 .54501 L
.37992 .54511 L
.38116 .54519 L
.38229 .54517 L
.3836 .54508 L
.38485 .54498 L
.38597 .54491 L
.38717 .54488 L
.3883 .54492 L
.38933 .54502 L
.39054 .54525 L
.39185 .54563 L
.39308 .54611 L
.39422 .54667 L
.39946 .55031 L
.40234 .5527 L
.40508 .55486 L
.40761 .55655 L
.40895 .55727 L
.41038 .55787 L
.41157 .55825 L
.41289 .55853 L
.41409 .55866 L
.41521 .55867 L
.41631 .5586 L
.41751 .55842 L
.41877 .55816 L
.41993 .55784 L
.42427 .55641 L
.42669 .55562 L
.42898 .55504 L
.43025 .55481 L
.43097 .55471 L
.43163 .55464 L
.43279 .55456 L
.43403 .55456 L
.43531 .55463 L
.43648 .55475 L
.43712 .55484 L
.43783 .55495 L
.43911 .5552 L
.44386 .55631 L
.44658 .55689 L
.4481 .55715 L
.44882 .55725 L
.44948 .55732 L
.45077 .55743 L
Mistroke
.45145 .55746 L
.45216 .55748 L
.45337 .55747 L
.45469 .5574 L
.456 .55728 L
.45721 .55713 L
.45994 .55669 L
.46231 .55626 L
.46491 .55581 L
.46604 .55564 L
.46724 .55549 L
.46839 .55538 L
.46943 .55531 L
.47055 .55526 L
.47177 .55525 L
.47304 .55528 L
.47423 .55535 L
.4794 .55593 L
.48212 .55633 L
.48361 .55653 L
.485 .5567 L
.48631 .55683 L
.48751 .55692 L
.4882 .55696 L
.48885 .55699 L
.48954 .55701 L
.49028 .55702 L
.49151 .55701 L
.49281 .55697 L
.49392 .5569 L
.49515 .55681 L
.50023 .55626 L
.5029 .55596 L
.50436 .55582 L
.50571 .55572 L
.50691 .55565 L
.50818 .55561 L
.50891 .55559 L
.5096 .55559 L
.51089 .5556 L
.51207 .55564 L
.51317 .55569 L
.51437 .55577 L
.51564 .55587 L
.5199 .55626 L
.52226 .55647 L
.52449 .55663 L
.52575 .55669 L
.52646 .55672 L
.52712 .55674 L
Mistroke
.52828 .55675 L
.52952 .55675 L
.5308 .55672 L
.532 .55668 L
.53307 .55663 L
.53424 .55656 L
.53883 .55623 L
.54135 .55605 L
.5426 .55597 L
.54375 .55592 L
.5451 .55586 L
.54581 .55584 L
.54657 .55583 L
.54779 .55582 L
.54849 .55582 L
.54914 .55583 L
.55041 .55585 L
.55157 .55589 L
.55284 .55594 L
.55418 .556 L
.55905 .55626 L
.56033 .55633 L
.56172 .55639 L
.56295 .55643 L
.56424 .55647 L
.56498 .55648 L
.5658 .5565 L
.56654 .55651 L
.56723 .55651 L
.56854 .55651 L
.56927 .55651 L
.56994 .5565 L
.57125 .55649 L
.57267 .55646 L
.57525 .55641 L
.58058 .55631 L
.58185 .55628 L
.58319 .55625 L
.58444 .55622 L
.5856 .55618 L
.58663 .55613 L
.58774 .55607 L
.58898 .55597 L
.5901 .55586 L
.5913 .55572 L
.5926 .55552 L
.59496 .55503 L
.59748 .55431 L
.60026 .55323 L
.60587 .55016 L
Mistroke
.61595 .54274 L
.65622 .51642 L
.69496 .49128 L
.73616 .46448 L
.77585 .43874 L
.81401 .41399 L
.85464 .38766 L
.89374 .36231 L
.9353 .33545 L
.97534 .30954 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo000Woooo
o`03o`000?oooooooooo00;o0000:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>Co
oooo00?o0000ooooooooool02_ooool002Oooooo0_l00004ooooo`;o0000hoooool00ol0003ooooo
ooooo`0;ooooo`009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo0ol0
002oooooo`;o00003_ooool002Oooooo00?o0000ooooooooool01_ooool2o`0001cooooo00Co0000
ooooool0003o0000_Oooool00ol0003oooooooooo`0>ooooo`009oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00002kooooo`;o00004Ooo
ool002Oooooo0_l0000:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2gooooo`03o`000?oooooooooo017ooooo000Wooooo`03o`000?oooooooooo
00[ooooo0_l0000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0]?ooool2o`00
01Cooooo000Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool05?ooool002Oooooo
00?o0000ooooooooool03Oooool2o`0001?ooooo00?o0000ooooooooool01Oooool2o`000;;ooooo
00?o0000ooooooooool05Oooool002Oooooo0_l0000@ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01oooool5o`000:cooooo0_l0000Hooooo`009oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2X
ooooo`03o`000?oooooooooo01Sooooo000Wooooo`03o`000?oooooooooo017ooooo0_l0000>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0YOooool2o`0001_ooooo000Wooooo`03
o`000?oooooooooo01;ooooo0ol0000;ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0X_ooool2o`0001gooooo000Wooooo`;o00005Oooool4o`0000Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo01gooooo0008ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo09gooooo0_l0000Pooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01;ooooo1?l0002Iooooo`;o00008_ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool2
o`0009Kooooo00?o0000ooooooooool08_ooool000Oooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool2o`0001_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo09;ooooo0_l0000Uooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool06oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo093ooooo00?o0000oooo
ooooool09Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0Looooo`?o00007Ooo
ool00ol0003oooooooooo`2=ooooo`;o0000:?ooool000Sooooo0_l0000:ooooo`;o00000oooool3
o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo03gooooo0_l0002;ooooo`;o0000:_ooool0
02Oooooo0_l0000oooooo`Go0000Q_ooool00ol0003oooooooooo`0Zooooo`009oooool00ol0003o
ooooooooo`12ooooo`;o0000Poooool2o`0002gooooo000Wooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0]ooooo`009oooool2o`0004Kooooo00?o
0000ooooooooool0O?ooool2o`00033ooooo000Wooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`0`ooooo`009oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo07Sooooo0_l0000cooooo`009oooool00ol0003oooooooooo`17ooooo`;o
000000?oooooo`000?l000000_l0001booooo`03o`000?oooooooooo03?ooooo000Wooooo`;o0000
BOooool3o`0000;ooooo00?o0000ooooooooool0K_ooool2o`0003Kooooo000Wooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0fooooo`009oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06[ooooo0_l0000iooooo`009oooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo06Sooooo0_l0000kooooo`009oooool2o`0004oo
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0kooooo`009oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo06Cooooo0_l0000nooooo`003_ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool0H_ooool2o`00043ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo043ooooo000=ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02oooo
o`;o0000DOooool00ol0003oooooooooo`1Nooooo`;o0000@oooool000gooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04?ooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`1Kooooo`;o0000A_ooool000gooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`1Hooooo`;o0000B?ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo0_l0001Booooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
B?ooool002Oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Eooooo`;o0000Booo
ool002Oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo04_ooooo000Wooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0D_ooool2o`00
04kooooo000Wooooo`;o0000Doooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04ko
oooo000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0C_ooool2o`00057ooooo
000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`1Aooooo`009oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0D_ooool002Oooooo0_l0001Dooooo`03o`000?oooooooooo04Wooooo0_l0001Eoooo
o`009oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0EOooool002Oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`16ooooo`;o0000
F?ooool002Oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`14ooooo`;o0000F_oo
ool002Oooooo0_l0001Dooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0F_ooool0
00Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00005ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0@?ooool2o`00
05gooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo03kooooo0_l0001Oooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`1Oooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000E_ooool2o`0003_o
oooo0_l0001Rooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo05Kooooo1_l0000eoooo
o`03o`000?oooooooooo06;ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06?ooooo0008ooooo`;o00002_ooool2
o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`04ooooo`?o00009oooool2o`0006Kooooo000Wooooo`;o0000Goooool6o`00
00;ooooo:?l0001Xooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003ooooo
ooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo000Woooo
o`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`00
0?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool0
02Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo
0_l0003gooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o
0000ooooooooool0m_ooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?Kooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01?ooool2o`000?Oooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`3mooooo`004oooool01?l0003oooooooooool00008ooooo`;o0000ooooool001Cooooo0_l0000:
ooooo`03o`000?oooooooooo0?gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33352 L
.10458 .35999 L
.14415 .38528 L
.14906 .39016 L
.1544 .39584 L
.15684 .39808 L
.15943 .39997 L
.16164 .40112 L
.1629 .40158 L
.16408 .4019 L
.1652 .40211 L
.16642 .40226 L
.16757 .40234 L
.16864 .40238 L
.16968 .40241 L
.17066 .40246 L
.17179 .40254 L
.17281 .40268 L
.17396 .40291 L
.17516 .40329 L
.17619 .40373 L
.17733 .40436 L
.17854 .40522 L
.17985 .40636 L
.18221 .40901 L
.18702 .41623 L
.18956 .42043 L
.19226 .42451 L
.19339 .42596 L
.19461 .42727 L
.19531 .42788 L
.19595 .42834 L
.1972 .42894 L
.19827 .42911 L
.19943 .4289 L
.20065 .42823 L
.20178 .42718 L
.20246 .42634 L
.20321 .42525 L
.20455 .42284 L
.20707 .41688 L
.21273 .3986 L
.21789 .38067 L
.22041 .3732 L
.22272 .3677 L
.22384 .36557 L
.22506 .36368 L
.22621 .36231 L
.22728 .36141 L
Mistroke
.22853 .36079 L
.22965 .36061 L
.23096 .36081 L
.23218 .36138 L
.23345 .36228 L
.23479 .36354 L
.23719 .36633 L
.24259 .37344 L
.2451 .37635 L
.24779 .37888 L
.25032 .38069 L
.25263 .38194 L
.26364 .38709 L
.27291 .39433 L
.27517 .39593 L
.2776 .3973 L
.27899 .39789 L
.28026 .39831 L
.28148 .3986 L
.28276 .39882 L
.28526 .39909 L
.28591 .39916 L
.28663 .39924 L
.28792 .39945 L
.28872 .39964 L
.28945 .39987 L
.29013 .40013 L
.29084 .40048 L
.29213 .40132 L
.29356 .40262 L
.29486 .40422 L
.29604 .40604 L
.29871 .41161 L
.30119 .41868 L
.30353 .42702 L
.31317 .47158 L
.31571 .48328 L
.31845 .49443 L
.32087 .50251 L
.32219 .50612 L
.32342 .50895 L
.32456 .51111 L
.3256 .5127 L
.32675 .51406 L
.32798 .51507 L
.32901 .51559 L
.33013 .51586 L
.33119 .51588 L
.33217 .51571 L
.33332 .51534 L
Mistroke
.3344 .51487 L
.33686 .5136 L
.33809 .51298 L
.33925 .51247 L
.3399 .51224 L
.3406 .51203 L
.34183 .51183 L
.34248 .5118 L
.34316 .51184 L
.34439 .51209 L
.3457 .51263 L
.34645 .51306 L
.34715 .51354 L
.34957 .51575 L
.35216 .51888 L
.35664 .52519 L
.36152 .5314 L
.36294 .53281 L
.36445 .53405 L
.36584 .53497 L
.36716 .53563 L
.36838 .53609 L
.36969 .53643 L
.37041 .53655 L
.37115 .53665 L
.37179 .53672 L
.37249 .53677 L
.375 .53687 L
.37572 .5369 L
.3764 .53695 L
.37768 .53708 L
.37888 .53729 L
.37999 .53756 L
.38121 .53798 L
.3825 .53857 L
.38503 .54018 L
.38743 .54223 L
.39194 .54709 L
.39721 .55305 L
.39977 .55552 L
.40208 .55735 L
.40427 .55868 L
.40633 .5596 L
.40851 .56028 L
.41085 .56081 L
.41324 .56127 L
.41455 .56155 L
.4158 .56188 L
.41821 .56272 L
.4204 .56381 L
Mistroke
.42278 .56538 L
.42498 .56718 L
.42994 .57218 L
.43492 .57742 L
.43756 .57983 L
.4404 .58193 L
.44181 .58274 L
.44315 .58338 L
.44446 .58387 L
.44568 .58423 L
.44682 .58448 L
.44804 .58468 L
.44874 .58476 L
.4494 .58483 L
.45063 .58491 L
.45312 .58499 L
.45378 .58501 L
.4545 .58504 L
.4558 .58509 L
.4566 .58514 L
.45734 .58519 L
.45874 .58534 L
.46007 .58552 L
.46148 .58576 L
.46651 .58697 L
.46897 .58762 L
.47124 .58815 L
.47236 .58837 L
.47359 .58855 L
.47483 .58869 L
.47614 .58875 L
.47685 .58876 L
.47749 .58875 L
.47824 .58871 L
.47894 .58866 L
.48019 .58851 L
.48155 .58828 L
.48615 .5872 L
.48868 .58656 L
.48993 .58628 L
.49109 .58605 L
.49226 .58587 L
.49332 .58574 L
.4945 .58565 L
.49575 .58562 L
.49681 .58565 L
.49795 .58572 L
.49903 .58584 L
.50002 .58599 L
.50221 .58641 L
Mistroke
.50462 .58697 L
.50716 .58757 L
.50948 .58804 L
.51081 .58825 L
.51208 .58839 L
.51277 .58845 L
.51341 .58848 L
.51411 .5885 L
.51486 .5885 L
.51609 .58845 L
.51725 .58835 L
.51852 .5882 L
.51988 .58798 L
.52524 .58689 L
.52793 .58641 L
.52866 .5863 L
.52945 .58621 L
.53019 .58614 L
.53086 .58609 L
.53217 .58603 L
.53285 .58603 L
.53358 .58604 L
.5348 .58609 L
.53549 .58614 L
.53614 .58619 L
.54092 .58676 L
.54218 .58689 L
.54287 .58695 L
.54351 .58699 L
.54465 .58703 L
.54592 .58701 L
.54658 .58696 L
.54728 .58689 L
.54853 .58668 L
.54923 .58652 L
.54988 .58634 L
.55135 .58583 L
.55385 .58461 L
.55613 .58313 L
.56124 .57889 L
.57979 .56581 L
.61972 .54052 L
.65815 .51575 L
.69902 .48974 L
.73838 .46433 L
.77622 .43975 L
.81652 .41366 L
.8553 .38844 L
.89653 .36137 L
.93624 .33531 L
Mistroke
.97445 .31043 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo000Woooo
o`03o`000?oooooooooo00;o0000:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>Co
oooo00?o0000ooooooooool02_ooool002Oooooo0_l00004ooooo`;o0000hoooool00ol0003ooooo
ooooo`0;ooooo`009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=kooooo0_l0
000>ooooo`009oooool00ol0003oooooooooo`06ooooo`;o0000gOooool00ol0003oooooooooo`0>
ooooo`009oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Sooooo0_l0000Aoooo
o`009oooool2o`0000[ooooo0_l0003Fooooo`;o00004oooool002Oooooo00?o0000ooooooooool0
2oooool2o`000=?ooooo00?o0000ooooooooool04oooool002Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`3>ooooo`;o00005_ooool002Oooooo00?o0000ooooooooool03_ooool2
o`000<cooooo0_l0000Hooooo`009oooool2o`00017ooooo00?o0000ooooooooool0b?ooool00ol0
003oooooooooo`0Hooooo`009oooool00ol0003oooooooooo`0Aooooo`;o00007Oooool3o`000:Ko
oooo0_l0000Kooooo`009oooool00ol0003oooooooooo`0Cooooo`;o00006_ooool2o`000003oooo
ool0003ooooo0:Cooooo00?o0000ooooooooool06oooool002Oooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool00000X_ooool2o`0001kooooo
000Wooooo`;o00005oooool2o`0001Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2Nooooo`03o`000?oooooooooo01kooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01Sooooo0_l0000E
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0O
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0VOooool2o`0002;ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo0ol0002Goooo
o`03o`000?oooooooooo02;ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0000L
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2B
ooooo`;o00009Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo01cooooo
0_l0000?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0Uooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`;o0000S_ooool2o`0002Sooooo0008ooooo`;o
00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`0Nooooo`?o
00003?ooool00ol0003oooooooooo`0=ooooo`Go0000ROooool00ol0003oooooooooo`0Xooooo`00
9oooool2o`00027ooooo1Ol00008ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
Q_ooool00ol0003oooooooooo`0Yooooo`009oooool00ol0003oooooooooo`0Tooooo`;o00001_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08?ooooo0_l0000/ooooo`009oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo02cooooo000Wooooo`;o00009oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0P?ooool2o`00
02oooooo000Wooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`00000Goooo
o`03o`000?oooooooooo07gooooo0_l0000aooooo`009oooool00ol0003oooooooooo`0Wooooo`05
o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo
037ooooo000Wooooo`03o`000?oooooooooo02Sooooo0ol0000Iooooo`03o`000?oooooooooo07Wo
oooo0_l0000dooooo`009oooool2o`0002[ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`1gooooo`;o0000=_ooool002Oooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo03Kooooo000Wooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool0M?ooool2o`0003Wooooo000Wooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool0LOooool2o`0003_ooooo000Wooooo`;o0000A_ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo03_ooooo000Wooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
K_ooool2o`0003kooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000ooo
ool3o`0000Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1/ooooo`;o0000@?oo
ool000gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool0@?ooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l00017ooooo`03o`000?oooooooooo
06Sooooo0_l00013ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool0@oooool000gooooo00Co0000oooooooooooo00002?ooool0
1Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo06Gooooo0_l00016ooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?oo
ooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0A_ooool000kooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo
0_l00018ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Aoooool002Oooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`1Pooooo`;o0000B_ooool002Oooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo04[ooooo000Woooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0GOooool2o`0004gooooo000Wooooo`;o
0000B?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo04gooooo000Wooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool0F_ooool2o`00053ooooo000Wooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1@ooooo`009oooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0DOooool0
02Oooooo0_l0001:ooooo`03o`000?oooooooooo05Cooooo0_l0001Dooooo`009oooool00ol0003o
ooooooooo`19ooooo`Oo0000Coooool00ol0003oooooooooo`1Dooooo`009oooool00ol0003ooooo
ooooo`1:ooooo`;o00000oooool2o`0004cooooo0_l0001Gooooo`009oooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo04Sooooo0_l0001Iooooo`009oooool2o`0005;ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1Iooooo`002?ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`13ooooo`;o0000G?ooool000Oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05?ooooo0_l00011ooooo`;o0000G_oo
ool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Dooooo`Go0000
??ooool00ol0003oooooooooo`1Nooooo`001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o
0000FOooool2o`0003Wooooo0_l0001Qooooo`001oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo
05[ooooo00?o0000ooooooooool0=?ooool2o`0006?ooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo06?ooooo0008
ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`0`ooooo`;o0000I_ooool002Oooooo0_l0001Moooo
o`;o0000;_ooool2o`0006Sooooo000Wooooo`03o`000?oooooooooo05kooooo1?l0000Yooooo`03
o`000?oooooooooo06Sooooo000Wooooo`03o`000?oooooooooo067ooooo0_l0000Vooooo`;o0000
Joooool002Oooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo06_ooooo000Wooooo`;o0000IOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo06cooooo000Wooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1]ooooo`009oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0K_ooool002Oooooo00?o0000ooooooooool0Ioooool6o`0000Kooooo
1?l00006ooooo`?o00000_ooool3o`00077ooooo000Wooooo`;o0000K_ooool6o`0000Cooooo1_l0
0003ooooo`?o0000Loooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`005?oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0m_oo
ool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?Kooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?oo
ool2o`000?Oooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOoo
ool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`004oooool0
1?l0003oooooooooool00008ooooo`;o0000ooooool001Cooooo0_l0000:ooooo`03o`000?oooooo
oooo0?gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 3.09017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -36 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -30 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.075)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.025)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.025)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.05)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.075)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33409 L
.10458 .36147 L
.14415 .38716 L
.18221 .41186 L
.22272 .43816 L
.26171 .46347 L
.30316 .49036 L
.34309 .51627 L
.3815 .54121 L
.42237 .56767 L
.46172 .5931 L
.48147 .60636 L
.48566 .6095 L
.49012 .61244 L
.49268 .61378 L
.49501 .6147 L
.49613 .61503 L
.49735 .61529 L
.4985 .61545 L
.49955 .61552 L
.50074 .61551 L
.50186 .61541 L
.50308 .61521 L
.50439 .61488 L
.50576 .61443 L
.50706 .61389 L
.5095 .61265 L
.51896 .60603 L
.53984 .59219 L
.57817 .56734 L
.61895 .54092 L
.65822 .51544 L
.69597 .49093 L
.73617 .46484 L
.77486 .43973 L
.816 .41303 L
.85562 .38731 L
.89373 .36257 L
.93429 .33624 L
.97334 .31089 L
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0594086,
  AnimationCycleOffset->-1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`000?ko
oooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool000cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000moooool001?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Ko
oooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo0?Ko
oooo000Dooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooo
ooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`00
0?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool002Oooooo00?o0000oooo
ooooool0m_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`001Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0m_ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000moooool002Oo
oooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o
0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3foooo
o`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009ooo
ool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo
0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o0000moooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`3fooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Kooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3fooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000?Oooooo000=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0m_ooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool0m_ooool000kooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0m_ooool002Oooooo0_l0003gooooo`009oooool0
0ol0003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0003o
ooooooooo`3fooooo`009oooool2o`000?Oooooo000Wooooo`03o`000?oooooooooo0?Kooooo000W
ooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o
0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000ooooooooool0m_oo
ool002Oooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3fooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0m_ooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
moooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3fooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0m_ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`3fooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00000_oo
ool5o`0000Cooooo0_l0003gooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool00ol0
003oooooooooo`3fooooo`009oooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
8Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
9oooool3o`0000Oooooo000Wooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`Go00008Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`00
9oooool2o`0002Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool0
0007ooooo`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003ooooo
ooooo`06ooooo`009oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000008_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008?ooool01?l0003oooooooooool00009ooooo`;o00008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000002Kooooo0_l00008ooooo`009oooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0
000:ooooo`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo000W
ooooo`;o0000moooool002Oooooo00?o0000ooooooooool0m_ooool002Oooooo00?o0000oooooooo
ool0m_ooool002Oooooo00?o0000ooooooooool0m_ooool0027oooooool0000002Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00001oooool002Oooooo00?o0000oooo
ooooool00_l0000[ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02[ooooo0_l000000ooooooo0000ooooo`06oooo
o`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>Gooooo00?o0000oooooooo
ool02Oooool002Oooooo0_l00004ooooo`;o0000hoooool2o`0000cooooo000Wooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0g_ooool2o`0000kooooo000Wooooo`03o`000?oooooo
oooo00Kooooo0_l0003Mooooo`03o`000?oooooooooo00kooooo000Wooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0f?ooool2o`00017ooooo000Wooooo`;o00002_ooool2o`000=Oo
oooo00?o0000ooooooooool04Oooool002Oooooo00?o0000ooooooooool02oooool2o`000=?ooooo
0_l0000Dooooo`009oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<oooooo00?o
0000ooooooooool05?ooool002Oooooo00?o0000ooooooooool03_ooool2o`000<kooooo00?o0000
ooooooooool05Oooool002Oooooo0_l0000Aooooo`03o`000?oooooooooo0<Wooooo0_l0000Hoooo
o`009oooool00ol0003oooooooooo`0Aooooo`;o0000b?ooool00ol0003oooooooooo`0Hooooo`00
9oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<?ooooo0_l0000Kooooo`009ooo
ool00ol0003oooooooooo`0Dooooo`;o0000`Oooool2o`0001gooooo000Wooooo`;o00005oooool0
0ol0003oooooooooo`2mooooo`03o`000?oooooooooo01gooooo0008ooooo`;o00001?ooool00ol0
003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0^_ooool2o`00023ooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`;o0000^?ooool2o`0002;ooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`2dooooo`03o`000?oooooooooo02;ooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo0_l0000Looooo`;o0000/_ooool2o`0002Gooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Ooo
ool00ol0003oooooooooo`0Mooooo`;o0000[_ooool2o`0002Oooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Oo
oooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003ooooo
ooooo`0Pooooo`;o0000Z?ooool2o`0002[ooooo000Wooooo`;o00008oooool2o`000:Cooooo0_l0
000/ooooo`009oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0:3ooooo00?o0000
ooooooooool0;?ooool002Oooooo00?o0000ooooooooool09Oooool2o`0009kooooo0_l0000_oooo
o`009oooool2o`0002Sooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0_ooooo`00
9oooool00ol0003oooooooooo`0Xooooo`;o0000V?ooool2o`0003;ooooo000Wooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0Toooool2o`0003Cooooo000Wooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0dooooo`009oooool2o`00
02gooooo0_l0002?ooooo`;o0000=oooool002Oooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`2;ooooo`03o`000?oooooooooo03Oooooo000Wooooo`03o`000?oooooooooo02oooooo
0_l00029ooooo`;o0000>_ooool002Oooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo00?o
0000ooooooooool0>_ooool002Oooooo0_l0000dooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0>oooool002Oooooo00?o0000ooooooooool0=?ooool2o`00083ooooo0_l0000noooo
o`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03
o`000?oooooooooo03Kooooo0_l0001mooooo`03o`000?oooooooooo03kooooo000=ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo03oooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`02ooooo`;o0000>_ooool2o`0007Sooooo00?o0000ooooooooool0@?oo
ool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1cooooo`;o0000
@oooool000gooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co
00001Oooool00ol0003oooooooooo`0looooo`;o0000LOooool2o`0004Gooooo000=ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooo
oooo03kooooo0_l0001]ooooo`;o0000Aoooool000kooooo0_l0000:ooooo`;o00000_ooool5o`00
00Cooooo0_l00011ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0Aoooool002Oo
oooo00?o0000ooooooooool0@Oooool2o`0006Oooooo0_l0001:ooooo`009oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo06;ooooo0_l0001<ooooo`009oooool00ol0003ooooooooo
o`14ooooo`;o0000H?ooool2o`0004kooooo000Wooooo`;o0000Aoooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo04kooooo000Wooooo`03o`000?oooooooooo04Oooooo0_l0001Joooo
o`;o0000DOooool002Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo057ooooo000Wooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
Doooool2o`0005Cooooo000Wooooo`;o0000C?ooool2o`0005;ooooo00?o0000ooooooooool0E?oo
ool002Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1=ooooo`;o0000Eoooool0
02Oooooo00?o0000ooooooooool0C_ooool2o`0004cooooo00?o0000ooooooooool0Eoooool002Oo
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`17ooooo`;o0000F_ooool002Oooooo
0_l0001Booooo`;o0000A_ooool00ol0003oooooooooo`1Jooooo`002?ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05_ooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Dooooo`;o
0000@?ooool2o`0005kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo05kooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo0_l0001Hooooo`;o0000>_ooool2o`00067ooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`00
0003o`0000Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo067ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0F_ooool2o`0003Co
oooo0_l0001Tooooo`002?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`000?l00000
0ol00004ooooo`03o`000?oooooooooo05cooooo0_l0000`ooooo`;o0000I_ooool002Oooooo0_l0
001Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0I_ooool002Oooooo00?o0000
ooooooooool0Goooool2o`0002[ooooo0_l0001Yooooo`009oooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0JOooool002Oooooo00?o0000oooooooo
ool0H_ooool2o`0002Cooooo0_l0001/ooooo`009oooool2o`0006Gooooo0_l0000Qooooo`03o`00
0?oooooooooo06cooooo000Wooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool07?oo
ool2o`0006oooooo000Wooooo`03o`000?oooooooooo06Oooooo0_l0000Kooooo`03o`000?oooooo
oooo06oooooo000Wooooo`03o`000?oooooooooo06Wooooo0_l0000Gooooo`;o0000L_ooool002Oo
oooo0_l0001/ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0L_ooool002Oooooo
00?o0000ooooooooool0K?ooool2o`00017ooooo0_l0001eooooo`009oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo00cooooo0_l0001gooooo`009oooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Wooooo0_l0001iooooo`009oooool2o`00077ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1iooooo`005?ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0LOooool2o`0000Kooooo00?o0000oooooooo
ool0N_ooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo07?ooooo0_l00002ooooo`;o0000OOooool001?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`04ooooo`;o0000MOooool4o`0007kooooo000Cooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool0oOooool001?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`3mooooo`004oooool01?l0003oooooooooool00008ooooo`;o
0000ooooool001Cooooo0_l0000:ooooo`03o`000?oooooooooo0?gooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162025, -0.112772, \
0.004136, 0.0012747}}]
}, Closed]]
}, Open  ]],

Cell["The waveform surface", "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[ U[50,x,t], {x,0,L}, {t,0,2}, ViewPoint->{1.542, -2.913, \
0.764} ]\
\>", "Input",
  CellLabel->"In[76]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .52254 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.34664e-16 1.06069 -0.221727 1.06069 [
[.0155 .11094 -2.85174 -9 ]
[.0155 .11094 3.14826 0 ]
[.13911 .08899 -8.66128 -9 ]
[.13911 .08899 9.33872 0 ]
[.27011 .06572 -8.7742 -9 ]
[.27011 .06572 9.2258 0 ]
[.40921 .04102 -8.89464 -9 ]
[.40921 .04102 9.10536 0 ]
[.55716 .01474 -9.02338 -9 ]
[.55716 .01474 8.97662 0 ]
[.71485 -0.01326 -3.05377 -9 ]
[.71485 -0.01326 2.94623 0 ]
[-0.00065 .4379 -3.14826 0 ]
[-0.00065 .4379 2.85174 9 ]
[.11945 .46709 -9.34325 0 ]
[.11945 .46709 8.65675 9 ]
[.22506 .49276 -3.08481 0 ]
[.22506 .49276 2.91519 9 ]
[.31864 .5155 -9.17606 0 ]
[.31864 .5155 8.82394 9 ]
[.40214 .53579 -3.03547 0 ]
[.40214 .53579 2.96453 9 ]
[.0015 .1323 -24 -3.70804 ]
[.0015 .1323 0 5.29196 ]
[-0.00202 .20275 -30 -3.78217 ]
[-0.00202 .20275 0 5.21783 ]
[-0.0056 .27416 -6 -3.85743 ]
[-0.0056 .27416 0 5.14257 ]
[-0.00921 .34655 -24 -3.93385 ]
[-0.00921 .34655 0 5.06615 ]
[-0.01288 .41994 -18 -4.01146 ]
[-0.01288 .41994 0 4.98854 ]
[ 0 0 0 0 ]
[ 1 .52254 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01485 .12419 m
.71509 0 L
s
.01485 .12419 m
.01452 .13081 L
s
[(0)] .0155 .11094 -0.04942 1 Mshowa
.13861 .10224 m
.13836 .10886 L
s
[(0.2)] .13911 .08899 -0.03764 1 Mshowa
.26978 .07897 m
.26961 .0856 L
s
[(0.4)] .27011 .06572 -0.02509 1 Mshowa
.40905 .05427 m
.40897 .0609 L
s
[(0.6)] .40921 .04102 -0.01171 1 Mshowa
.5572 .028 m
.55721 .03463 L
s
[(0.8)] .55716 .01474 .0026 1 Mshowa
.71509 0 m
.71521 .00663 L
s
[(1)] .71485 -0.01326 .01792 1 Mshowa
.125 Mabswid
.04513 .11882 m
.04494 .12279 L
s
.07584 .11337 m
.07567 .11734 L
s
.107 .10784 m
.10684 .11182 L
s
.17068 .09655 m
.17054 .10052 L
s
.20323 .09078 m
.2031 .09475 L
s
.23626 .08492 m
.23614 .0889 L
s
.30381 .07294 m
.30372 .07692 L
s
.33836 .06681 m
.33828 .07079 L
s
.37343 .06059 m
.37337 .06457 L
s
.44522 .04786 m
.44519 .05184 L
s
.48196 .04134 m
.48194 .04532 L
s
.51928 .03473 m
.51928 .0387 L
s
.59572 .02117 m
.59574 .02515 L
s
.63486 .01423 m
.6349 .01821 L
s
.67465 .00717 m
.67471 .01115 L
s
.25 Mabswid
0 .42466 m
.4023 .52254 L
s
0 .42466 m
.00033 .41804 L
s
[(0)] -0.00065 .4379 .04942 -1 Mshowa
.11996 .45384 m
.12021 .44722 L
s
[(0.5)] .11945 .46709 .03814 -1 Mshowa
.22543 .47951 m
.22562 .47288 L
s
[(1)] .22506 .49276 .02827 -1 Mshowa
.3189 .50224 m
.31903 .49562 L
s
[(1.5)] .31864 .5155 .01956 -1 Mshowa
.4023 .52254 m
.40238 .51591 L
s
[(2)] .40214 .53579 .01182 -1 Mshowa
.125 Mabswid
.02529 .43081 m
.02548 .42684 L
s
.04991 .4368 m
.05008 .43283 L
s
.07387 .44263 m
.07404 .43866 L
s
.09721 .44831 m
.09737 .44434 L
s
.14212 .45924 m
.14226 .45526 L
s
.16373 .46449 m
.16387 .46052 L
s
.18481 .46962 m
.18493 .46565 L
s
.20537 .47462 m
.20549 .47065 L
s
.24502 .48427 m
.24512 .48029 L
s
.26414 .48892 m
.26424 .48495 L
s
.28282 .49347 m
.28291 .48949 L
s
.30107 .49791 m
.30115 .49393 L
s
.33633 .50649 m
.3364 .50251 L
s
.35337 .51063 m
.35344 .50666 L
s
.37004 .51469 m
.3701 .51071 L
s
.38634 .51865 m
.3864 .51468 L
s
.25 Mabswid
.01485 .12419 m
0 .42466 L
s
.01456 .13001 m
.02109 .12886 L
s
[(-0.1)] .0015 .1323 1 -0.17599 Mshowa
.01107 .20067 m
.01762 .19962 L
s
[(-0.05)] -0.00202 .20275 1 -0.15952 Mshowa
.00753 .27229 m
.01409 .27135 L
s
[(0)] -0.0056 .27416 1 -0.14279 Mshowa
.00394 .3449 m
.01052 .34407 L
s
[(0.05)] -0.00921 .34655 1 -0.12581 Mshowa
.0003 .41851 m
.00689 .41779 L
s
[(0.1)] -0.01288 .41994 1 -0.10856 Mshowa
.125 Mabswid
.01387 .14406 m
.01779 .14338 L
s
.01317 .15816 m
.01709 .15749 L
s
.01247 .17229 m
.0164 .17164 L
s
.01177 .18646 m
.0157 .18582 L
s
.01037 .21491 m
.0143 .2143 L
s
.00966 .2292 m
.01359 .2286 L
s
.00895 .24352 m
.01289 .24293 L
s
.00824 .25789 m
.01218 .25731 L
s
.00682 .28673 m
.01076 .28618 L
s
.0061 .30121 m
.01004 .30068 L
s
.00538 .31573 m
.00933 .31521 L
s
.00466 .33029 m
.00861 .32978 L
s
.00322 .35954 m
.00717 .35905 L
s
.00249 .37422 m
.00644 .37375 L
s
.00177 .38894 m
.00572 .38848 L
s
.00104 .4037 m
.00499 .40326 L
s
.25 Mabswid
.01485 .12419 m
0 .42466 L
s
0 .42466 m
.4023 .52254 L
s
.4023 .52254 m
.40513 .2832 L
s
.40513 .2832 m
.01485 .12419 L
s
.71509 0 m
.98832 .20842 L
s
.98832 .20842 m
1 .47665 L
s
1 .47665 m
.72132 .34739 L
s
.72132 .34739 m
.71509 0 L
s
.01485 .12419 m
0 .42466 L
s
0 .42466 m
.72132 .34739 L
s
.72132 .34739 m
.71509 0 L
s
.71509 0 m
.01485 .12419 L
s
.40513 .2832 m
.98832 .20842 L
s
.98832 .20842 m
1 .47665 L
s
1 .47665 m
.4023 .52254 L
s
.4023 .52254 m
.40513 .2832 L
s
0 0 m
1 0 L
1 .52254 L
0 .52254 L
closepath
clip
newpath
.5 Mabswid
0 .37 .673 r
.39062 .39725 .40373 .40153 .42556 .40891 .41258 .40441 Metetra
0 .391 .699 r
.41258 .40441 .42556 .40891 .44764 .41637 .43479 .41157 Metetra
0 .435 .748 r
.43479 .41157 .44764 .41637 .46997 .42391 .45725 .41839 Metetra
.591 .847 .993 r
.45725 .41839 .46997 .42391 .49256 .43154 .48003 .41264 Metetra
.643 .686 .875 r
.48003 .41264 .49256 .43154 .51541 .43926 .50302 .40692 Metetra
.525 .546 .819 r
.50302 .40692 .51541 .43926 .53852 .44707 .52621 .4141 Metetra
.517 .539 .817 r
.52621 .4141 .53852 .44707 .5619 .45496 .54967 .42231 Metetra
.331 .423 .805 r
.54967 .42231 .5619 .45496 .58555 .46295 .57347 .44377 Metetra
0 .308 .8 r
.57347 .44377 .58555 .46295 .60949 .47103 .59761 .4656 Metetra
0 .423 .763 r
.59761 .4656 .60949 .47103 .6337 .47921 .62198 .47407 Metetra
.395 .784 .989 r
.62198 .47407 .6337 .47921 .65821 .48745 .64654 .47284 Metetra
.576 .71 .934 r
.64654 .47284 .65821 .48745 .68299 .49482 .67135 .47099 Metetra
.602 .64 .86 r
.67135 .47099 .68299 .49482 .70776 .48349 .69641 .46906 Metetra
.584 .718 .935 r
.69641 .46906 .70776 .48349 .73272 .47109 .72172 .46658 Metetra
.689 .909 .972 r
.72172 .46658 .73272 .47109 .75789 .45855 .7471 .45453 Metetra
.692 .92 .97 r
.7471 .45453 .75789 .45855 .78326 .44591 .77268 .44185 Metetra
.692 .922 .97 r
.77268 .44185 .78326 .44591 .80885 .43316 .79847 .42902 Metetra
.692 .923 .969 r
.79847 .42902 .80885 .43316 .83464 .42031 .82448 .41606 Metetra
.692 .923 .969 r
.82448 .41606 .83464 .42031 .86066 .40734 .85071 .40296 Metetra
.692 .923 .969 r
.85071 .40296 .86066 .40734 .8869 .39427 .87716 .38971 Metetra
.693 .923 .969 r
.87716 .38971 .8869 .39427 .91335 .38108 .90384 .37634 Metetra
.694 .923 .969 r
.90384 .37634 .91335 .38108 .94003 .36779 .93075 .36282 Metetra
.694 .922 .969 r
.93075 .36282 .94003 .36779 .96694 .35437 .95789 .34918 Metetra
.695 .921 .969 r
.95789 .34918 .96694 .35437 .99409 .34085 .98526 .33541 Metetra
0 .425 .722 r
.37727 .3929 .39062 .39725 .41258 .40441 .39937 .39925 Metetra
.598 .854 .993 r
.39937 .39925 .41258 .40441 .43479 .41157 .42184 .39317 Metetra
.647 .692 .878 r
.42184 .39317 .43479 .41157 .45725 .41839 .44451 .38711 Metetra
.523 .55 .825 r
.44451 .38711 .45725 .41839 .48003 .41264 .46731 .3938 Metetra
.426 .585 .906 r
.46731 .3938 .48003 .41264 .50302 .40692 .49037 .4011 Metetra
0 .457 .795 r
.49037 .4011 .50302 .40692 .52621 .4141 .5137 .40868 Metetra
0 .433 .765 r
.5137 .40868 .52621 .4141 .54967 .42231 .5373 .41649 Metetra
0 .467 .804 r
.5373 .41649 .54967 .42231 .57347 .44377 .56119 .42412 Metetra
.583 .66 .891 r
.56119 .42412 .57347 .44377 .59761 .4656 .58532 .42311 Metetra
.511 .506 .788 r
.58532 .42311 .59761 .4656 .62198 .47407 .60979 .43489 Metetra
.5 .51 .798 r
.60979 .43489 .62198 .47407 .64654 .47284 .63457 .44685 Metetra
.597 .625 .85 r
.63457 .44685 .64654 .47284 .67135 .47099 .65951 .44554 Metetra
.601 .631 .853 r
.65951 .44554 .67135 .47099 .69641 .46906 .68471 .44373 Metetra
.602 .633 .855 r
.68471 .44373 .69641 .46906 .72172 .46658 .71017 .44177 Metetra
.602 .637 .858 r
.71017 .44177 .72172 .46658 .7471 .45453 .73589 .43971 Metetra
.584 .719 .936 r
.73589 .43971 .7471 .45453 .77268 .44185 .76187 .43707 Metetra
.688 .91 .972 r
.76187 .43707 .77268 .44185 .79847 .42902 .78788 .42467 Metetra
.692 .921 .97 r
.78788 .42467 .79847 .42902 .82448 .41606 .81411 .41161 Metetra
.693 .922 .969 r
.81411 .41161 .82448 .41606 .85071 .40296 .84056 .39837 Metetra
.693 .922 .969 r
.84056 .39837 .85071 .40296 .87716 .38971 .86723 .38497 Metetra
.694 .922 .969 r
.86723 .38497 .87716 .38971 .90384 .37634 .89414 .37141 Metetra
.695 .922 .969 r
.89414 .37141 .90384 .37634 .93075 .36282 .92127 .3577 Metetra
.696 .921 .969 r
.92127 .3577 .93075 .36282 .95789 .34918 .94865 .34385 Metetra
.697 .921 .969 r
.94865 .34385 .95789 .34918 .98526 .33541 .97625 .32986 Metetra
.805 .877 .899 r
.36369 .38847 .37727 .3929 .39937 .39925 .38625 .36903 Metetra
.526 .558 .831 r
.38625 .36903 .39937 .39925 .42184 .39317 .40868 .37484 Metetra
.423 .591 .912 r
.40868 .37484 .42184 .39317 .44451 .38711 .43135 .38166 Metetra
0 .447 .773 r
.43135 .38166 .44451 .38711 .46731 .3938 .45428 .38884 Metetra
0 .417 .735 r
.45428 .38884 .46731 .3938 .49037 .4011 .47748 .39624 Metetra
0 .434 .747 r
.47748 .39624 .49037 .4011 .5137 .40868 .50095 .40337 Metetra
.43 .798 .995 r
.50095 .40337 .5137 .40868 .5373 .41649 .52471 .40146 Metetra
.584 .709 .929 r
.52471 .40146 .5373 .41649 .56119 .42412 .54871 .39915 Metetra
.604 .634 .854 r
.54871 .39915 .56119 .42412 .58532 .42311 .57295 .39692 Metetra
.603 .628 .848 r
.57295 .39692 .58532 .42311 .60979 .43489 .59744 .39484 Metetra
.605 .574 .793 r
.59744 .39484 .60979 .43489 .63457 .44685 .62218 .39326 Metetra
.531 .498 .764 r
.62218 .39326 .63457 .44685 .65951 .44554 .64734 .40514 Metetra
.501 .509 .797 r
.64734 .40514 .65951 .44554 .68471 .44373 .67282 .41718 Metetra
.596 .625 .851 r
.67282 .41718 .68471 .44373 .71017 .44177 .69842 .41571 Metetra
.6 .632 .854 r
.69842 .41571 .71017 .44177 .73589 .43971 .72429 .41372 Metetra
.602 .634 .855 r
.72429 .41372 .73589 .43971 .76187 .43707 .75042 .41155 Metetra
.602 .637 .858 r
.75042 .41155 .76187 .43707 .78788 .42467 .77683 .40924 Metetra
.586 .718 .934 r
.77683 .40924 .78788 .42467 .81411 .41161 .80351 .40633 Metetra
.69 .909 .972 r
.80351 .40633 .81411 .41161 .84056 .39837 .8302 .39349 Metetra
.695 .919 .969 r
.8302 .39349 .84056 .39837 .86723 .38497 .8571 .37996 Metetra
.696 .92 .969 r
.8571 .37996 .86723 .38497 .89414 .37141 .88423 .36625 Metetra
.696 .92 .969 r
.88423 .36625 .89414 .37141 .92127 .3577 .9116 .35238 Metetra
.697 .92 .969 r
.9116 .35238 .92127 .3577 .94865 .34385 .93921 .33836 Metetra
.697 .92 .968 r
.93921 .33836 .94865 .34385 .97625 .32986 .96706 .3242 Metetra
0 .427 .724 r
.34985 .38395 .36369 .38847 .38625 .36903 .37219 .39033 Metetra
.443 .102 .29 r
.37219 .39033 .38625 .36903 .40868 .37484 .39496 .38405 Metetra
.166 0 0 r
.39496 .38405 .40868 .37484 .43135 .38166 .41793 .37777 Metetra
0 .422 .704 r
.41793 .37777 .43135 .38166 .45428 .38884 .44101 .38399 Metetra
.434 .807 .993 r
.44101 .38399 .45428 .38884 .47748 .39624 .4644 .38162 Metetra
.587 .716 .932 r
.4644 .38162 .47748 .39624 .50095 .40337 .48804 .37894 Metetra
.606 .639 .857 r
.48804 .37894 .50095 .40337 .52471 .40146 .51192 .37634 Metetra
.606 .636 .854 r
.51192 .37634 .52471 .40146 .54871 .39915 .53603 .3738 Metetra
.605 .635 .854 r
.53603 .3738 .54871 .39915 .57295 .39692 .56039 .37131 Metetra
.605 .634 .853 r
.56039 .37131 .57295 .39692 .59744 .39484 .58501 .36887 Metetra
.604 .632 .852 r
.58501 .36887 .59744 .39484 .62218 .39326 .60988 .3665 Metetra
.603 .628 .849 r
.60988 .3665 .62218 .39326 .64734 .40514 .635 .36426 Metetra
.604 .575 .794 r
.635 .36426 .64734 .40514 .67282 .41718 .6604 .36249 Metetra
.531 .498 .764 r
.6604 .36249 .67282 .41718 .69842 .41571 .68627 .37436 Metetra
.503 .51 .797 r
.68627 .37436 .69842 .41571 .72429 .41372 .71248 .38638 Metetra
.597 .625 .85 r
.71248 .38638 .72429 .41372 .75042 .41155 .73877 .38466 Metetra
.601 .631 .853 r
.73877 .38466 .75042 .41155 .77683 .40924 .76534 .38239 Metetra
.603 .633 .854 r
.76534 .38239 .77683 .40924 .80351 .40633 .79218 .37992 Metetra
.603 .637 .857 r
.79218 .37992 .80351 .40633 .8302 .39349 .81932 .37732 Metetra
.589 .716 .932 r
.81932 .37732 .8302 .39349 .8571 .37996 .84673 .3741 Metetra
.693 .907 .971 r
.84673 .3741 .8571 .37996 .88423 .36625 .87412 .36081 Metetra
.697 .917 .969 r
.87412 .36081 .88423 .36625 .9116 .35238 .90173 .34683 Metetra
.697 .918 .969 r
.90173 .34683 .9116 .35238 .93921 .33836 .92958 .33269 Metetra
.697 .919 .969 r
.92958 .33269 .93921 .33836 .96706 .3242 .95768 .31841 Metetra
0 .377 .679 r
.33575 .37936 .34985 .38395 .37219 .39033 .35821 .38657 Metetra
.227 0 0 r
.35821 .38657 .37219 .39033 .39496 .38405 .38094 .3933 Metetra
.327 0 0 r
.38094 .3933 .39496 .38405 .41793 .37777 .40406 .39048 Metetra
.40406 .39048 .41793 .37777 .44101 .38399 .42753 .37407 Metetra
.759 .818 .899 r
.42753 .37407 .44101 .38399 .4644 .38162 .45118 .35757 Metetra
.613 .646 .859 r
.45118 .35757 .4644 .38162 .48804 .37894 .47493 .35414 Metetra
.608 .64 .857 r
.47493 .35414 .48804 .37894 .51192 .37634 .49892 .35119 Metetra
.607 .638 .856 r
.49892 .35119 .51192 .37634 .53603 .3738 .52316 .34838 Metetra
.606 .637 .855 r
.52316 .34838 .53603 .3738 .56039 .37131 .54765 .34562 Metetra
.606 .636 .855 r
.54765 .34562 .56039 .37131 .58501 .36887 .57239 .34291 Metetra
.605 .635 .854 r
.57239 .34291 .58501 .36887 .60988 .3665 .59738 .34022 Metetra
.605 .634 .853 r
.59738 .34022 .60988 .3665 .635 .36426 .62264 .33756 Metetra
.604 .632 .852 r
.62264 .33756 .635 .36426 .6604 .36249 .64816 .33493 Metetra
.603 .628 .849 r
.64816 .33493 .6604 .36249 .68627 .37436 .67396 .33242 Metetra
.604 .575 .794 r
.67396 .33242 .68627 .37436 .71248 .38638 .70004 .33038 Metetra
.532 .498 .764 r
.70004 .33038 .71248 .38638 .73877 .38466 .72666 .34217 Metetra
.505 .511 .796 r
.72666 .34217 .73877 .38466 .76534 .38239 .75364 .35411 Metetra
.598 .625 .849 r
.75364 .35411 .76534 .38239 .79218 .37992 .78065 .3521 Metetra
.602 .631 .852 r
.78065 .3521 .79218 .37992 .81932 .37732 .80795 .34955 Metetra
.603 .633 .853 r
.80795 .34955 .81932 .37732 .84673 .3741 .83554 .34681 Metetra
.603 .637 .857 r
.83554 .34681 .84673 .3741 .87412 .36081 .86344 .34396 Metetra
.59 .715 .93 r
.86344 .34396 .87412 .36081 .90173 .34683 .89162 .3405 Metetra
.692 .907 .971 r
.89162 .3405 .90173 .34683 .92958 .33269 .91974 .32684 Metetra
.695 .918 .969 r
.91974 .32684 .92958 .33269 .95768 .31841 .9481 .31251 Metetra
.443 .814 .994 r
.32139 .37467 .33575 .37936 .35821 .38657 .34415 .37201 Metetra
.586 .718 .934 r
.34415 .37201 .35821 .38657 .38094 .3933 .36714 .3693 Metetra
.606 .643 .861 r
.36714 .3693 .38094 .3933 .40406 .39048 .39036 .36653 Metetra
.607 .645 .862 r
.39036 .36653 .40406 .39048 .42753 .37407 .41381 .36361 Metetra
.57 .771 .974 r
.41381 .36361 .42753 .37407 .45118 .35757 .43751 .36019 Metetra
.712 .981 .904 r
.43751 .36019 .45118 .35757 .47493 .35414 .46153 .34345 Metetra
.757 .816 .899 r
.46153 .34345 .47493 .35414 .49892 .35119 .48573 .32659 Metetra
.613 .647 .86 r
.48573 .32659 .49892 .35119 .52316 .34838 .51009 .32297 Metetra
.608 .641 .857 r
.51009 .32297 .52316 .34838 .54765 .34562 .5347 .31981 Metetra
.607 .639 .856 r
.5347 .31981 .54765 .34562 .57239 .34291 .55957 .31677 Metetra
.606 .637 .855 r
.55957 .31677 .57239 .34291 .59738 .34022 .58469 .31376 Metetra
.606 .636 .854 r
.58469 .31376 .59738 .34022 .62264 .33756 .61008 .31076 Metetra
.606 .635 .854 r
.61008 .31076 .62264 .33756 .64816 .33493 .63574 .30778 Metetra
.606 .634 .853 r
.63574 .30778 .64816 .33493 .67396 .33242 .66167 .30481 Metetra
.605 .632 .851 r
.66167 .30481 .67396 .33242 .70004 .33038 .68788 .30188 Metetra
.604 .628 .848 r
.68788 .30188 .70004 .33038 .72666 .34217 .71438 .29907 Metetra
.604 .574 .794 r
.71438 .29907 .72666 .34217 .75364 .35411 .74118 .29674 Metetra
.533 .498 .764 r
.74118 .29674 .75364 .35411 .78065 .3521 .76858 .30848 Metetra
.506 .511 .796 r
.76858 .30848 .78065 .3521 .80795 .34955 .79637 .3204 Metetra
.598 .625 .849 r
.79637 .3204 .80795 .34955 .83554 .34681 .82414 .31818 Metetra
.602 .631 .852 r
.82414 .31818 .83554 .34681 .86344 .34396 .85221 .31542 Metetra
.603 .633 .854 r
.85221 .31542 .86344 .34396 .89162 .3405 .88059 .31251 Metetra
.602 .637 .857 r
.88059 .31251 .89162 .3405 .91974 .32684 .90929 .30952 Metetra
.582 .712 .932 r
.90929 .30952 .91974 .32684 .9481 .31251 .93832 .30648 Metetra
.726 .885 .954 r
.30676 .3699 .32139 .37467 .34415 .37201 .32985 .35713 Metetra
.709 .755 .888 r
.32985 .35713 .34415 .37201 .36714 .3693 .35313 .34472 Metetra
.609 .644 .859 r
.35313 .34472 .36714 .3693 .39036 .36653 .37646 .34146 Metetra
.605 .639 .858 r
.37646 .34146 .39036 .36653 .41381 .36361 .40002 .33862 Metetra
.605 .641 .86 r
.40002 .33862 .41381 .36361 .43751 .36019 .42382 .3357 Metetra
.606 .646 .863 r
.42382 .3357 .43751 .36019 .46153 .34345 .44787 .3326 Metetra
.572 .771 .973 r
.44787 .3326 .46153 .34345 .48573 .32659 .47217 .32897 Metetra
.712 .981 .903 r
.47217 .32897 .48573 .32659 .51009 .32297 .49676 .31178 Metetra
.757 .817 .899 r
.49676 .31178 .51009 .32297 .5347 .31981 .52155 .29445 Metetra
.614 .647 .86 r
.52155 .29445 .5347 .31981 .55957 .31677 .54654 .29054 Metetra
.609 .641 .857 r
.54654 .29054 .55957 .31677 .58469 .31376 .5718 .28708 Metetra
.608 .638 .855 r
.5718 .28708 .58469 .31376 .61008 .31076 .59732 .28372 Metetra
.607 .637 .854 r
.59732 .28372 .61008 .31076 .63574 .30778 .62312 .28039 Metetra
.607 .636 .853 r
.62312 .28039 .63574 .30778 .66167 .30481 .64919 .27709 Metetra
.607 .635 .853 r
.64919 .27709 .66167 .30481 .68788 .30188 .67555 .2738 Metetra
.606 .633 .852 r
.67555 .2738 .68788 .30188 .71438 .29907 .70219 .27055 Metetra
.605 .631 .851 r
.70219 .27055 .71438 .29907 .74118 .29674 .72912 .26736 Metetra
.604 .627 .847 r
.72912 .26736 .74118 .29674 .76858 .30848 .75635 .26431 Metetra
.603 .574 .794 r
.75635 .26431 .76858 .30848 .79637 .3204 .7839 .26178 Metetra
.532 .498 .764 r
.7839 .26178 .79637 .3204 .82414 .31818 .81214 .27358 Metetra
.506 .511 .796 r
.81214 .27358 .82414 .31818 .85221 .31542 .84078 .2856 Metetra
.592 .622 .851 r
.84078 .2856 .85221 .31542 .88059 .31251 .86937 .28381 Metetra
.491 .568 .861 r
.86937 .28381 .88059 .31251 .90929 .30952 .89864 .29179 Metetra
.385 .598 .931 r
.89864 .29179 .90929 .30952 .93832 .30648 .92832 .30032 Metetra
.724 .885 .955 r
.29185 .36504 .30676 .3699 .32985 .35713 .3151 .3522 Metetra
.724 .887 .955 r
.3151 .3522 .32985 .35713 .35313 .34472 .33854 .33925 Metetra
.725 .881 .953 r
.33854 .33925 .35313 .34472 .37646 .34146 .36218 .32618 Metetra
.709 .757 .889 r
.36218 .32618 .37646 .34146 .40002 .33862 .38601 .31345 Metetra
.609 .644 .86 r
.38601 .31345 .40002 .33862 .42382 .3357 .40993 .30998 Metetra
.605 .64 .858 r
.40993 .30998 .42382 .3357 .44787 .3326 .4341 .30691 Metetra
.606 .641 .859 r
.4341 .30691 .44787 .3326 .47217 .32897 .45852 .30372 Metetra
.607 .645 .862 r
.45852 .30372 .47217 .32897 .49676 .31178 .48319 .30034 Metetra
.577 .77 .97 r
.48319 .30034 .49676 .31178 .52155 .29445 .50812 .2964 Metetra
.717 .981 .905 r
.50812 .2964 .52155 .29445 .54654 .29054 .53332 .27868 Metetra
.757 .817 .899 r
.53332 .27868 .54654 .29054 .5718 .28708 .5587 .26081 Metetra
.614 .646 .859 r
.5587 .26081 .5718 .28708 .59732 .28372 .58436 .25657 Metetra
.61 .64 .856 r
.58436 .25657 .59732 .28372 .62312 .28039 .6103 .2528 Metetra
.608 .638 .854 r
.6103 .2528 .62312 .28039 .64919 .27709 .63651 .24915 Metetra
.608 .636 .854 r
.63651 .24915 .64919 .27709 .67555 .2738 .66301 .24556 Metetra
.607 .635 .853 r
.66301 .24556 .67555 .2738 .70219 .27055 .6898 .24201 Metetra
.606 .634 .853 r
.6898 .24201 .70219 .27055 .72912 .26736 .71689 .23851 Metetra
.605 .633 .852 r
.71689 .23851 .72912 .26736 .75635 .26431 .74427 .23507 Metetra
.604 .631 .851 r
.74427 .23507 .75635 .26431 .7839 .26178 .77197 .23173 Metetra
.598 .625 .849 r
.77197 .23173 .7839 .26178 .81214 .27358 .79999 .22909 Metetra
.532 .53 .798 r
.79999 .22909 .81214 .27358 .84078 .2856 .82864 .23717 Metetra
.425 .448 .78 r
.82864 .23717 .84078 .2856 .86937 .28381 .85814 .26059 Metetra
.154 .389 .837 r
.85814 .26059 .86937 .28381 .89864 .29179 .88815 .28449 Metetra
.013 .513 .868 r
.88815 .28449 .89864 .29179 .92832 .30032 .91811 .29403 Metetra
.724 .885 .955 r
.27665 .36008 .29185 .36504 .3151 .3522 .30006 .34714 Metetra
.724 .886 .955 r
.30006 .34714 .3151 .3522 .33854 .33925 .32367 .33409 Metetra
.724 .887 .955 r
.32367 .33409 .33854 .33925 .36218 .32618 .34748 .3209 Metetra
.724 .887 .955 r
.34748 .3209 .36218 .32618 .38601 .31345 .37148 .30756 Metetra
.726 .881 .952 r
.37148 .30756 .38601 .31345 .40993 .30998 .39569 .29407 Metetra
.709 .757 .889 r
.39569 .29407 .40993 .30998 .4341 .30691 .4201 .28091 Metetra
.61 .644 .859 r
.4201 .28091 .4341 .30691 .45852 .30372 .44465 .27713 Metetra
.606 .639 .858 r
.44465 .27713 .45852 .30372 .48319 .30034 .46945 .27375 Metetra
.607 .641 .858 r
.46945 .27375 .48319 .30034 .50812 .2964 .49451 .27024 Metetra
.608 .645 .861 r
.49451 .27024 .50812 .2964 .53332 .27868 .51984 .26654 Metetra
.581 .767 .967 r
.51984 .26654 .53332 .27868 .5587 .26081 .54543 .26229 Metetra
.72 .981 .907 r
.54543 .26229 .5587 .26081 .58436 .25657 .57125 .24406 Metetra
.757 .817 .899 r
.57125 .24406 .58436 .25657 .6103 .2528 .59727 .22569 Metetra
.614 .646 .858 r
.59727 .22569 .6103 .2528 .63651 .24915 .62363 .2212 Metetra
.609 .64 .856 r
.62363 .2212 .63651 .24915 .66301 .24556 .65027 .2172 Metetra
.608 .638 .855 r
.65027 .2172 .66301 .24556 .6898 .24201 .67722 .21336 Metetra
.607 .636 .854 r
.67722 .21336 .6898 .24201 .71689 .23851 .70446 .20961 Metetra
.601 .633 .855 r
.70446 .20961 .71689 .23851 .74427 .23507 .73201 .20645 Metetra
.491 .572 .864 r
.73201 .20645 .74427 .23507 .77197 .23173 .7601 .21349 Metetra
.389 .601 .931 r
.7601 .21349 .77197 .23173 .79999 .22909 .78858 .22129 Metetra
.07 .552 .896 r
.78858 .22129 .79999 .22909 .82864 .23717 .81746 .22938 Metetra
.058 .543 .891 r
.81746 .22938 .82864 .23717 .85814 .26059 .84674 .23791 Metetra
.412 .571 .901 r
.84674 .23791 .85814 .26059 .88815 .28449 .87646 .24766 Metetra
.136 .286 .754 r
.87646 .24766 .88815 .28449 .91811 .29403 .90767 .2876 Metetra
.724 .885 .955 r
.26116 .35502 .27665 .36008 .30006 .34714 .28473 .34193 Metetra
.724 .885 .955 r
.28473 .34193 .30006 .34714 .32367 .33409 .30851 .32872 Metetra
.724 .885 .955 r
.30851 .32872 .32367 .33409 .34748 .3209 .33248 .31538 Metetra
.725 .885 .954 r
.33248 .31538 .34748 .3209 .37148 .30756 .35666 .30189 Metetra
.725 .885 .954 r
.35666 .30189 .37148 .30756 .39569 .29407 .38105 .28824 Metetra
.726 .885 .954 r
.38105 .28824 .39569 .29407 .4201 .28091 .40565 .27443 Metetra
.727 .878 .951 r
.40565 .27443 .4201 .28091 .44465 .27713 .43046 .26047 Metetra
.71 .756 .889 r
.43046 .26047 .44465 .27713 .46945 .27375 .45548 .24684 Metetra
.611 .643 .858 r
.45548 .24684 .46945 .27375 .49451 .27024 .48067 .24275 Metetra
.606 .639 .857 r
.48067 .24275 .49451 .27024 .51984 .26654 .50613 .23907 Metetra
.607 .64 .858 r
.50613 .23907 .51984 .26654 .54543 .26229 .53187 .23529 Metetra
.608 .644 .861 r
.53187 .23529 .54543 .26229 .57125 .24406 .55788 .23134 Metetra
.583 .766 .966 r
.55788 .23134 .57125 .24406 .59727 .22569 .58417 .22686 Metetra
.718 .981 .907 r
.58417 .22686 .59727 .22569 .62363 .2212 .61065 .2082 Metetra
.757 .819 .902 r
.61065 .2082 .62363 .2212 .65027 .2172 .63733 .18944 Metetra
.608 .644 .86 r
.63733 .18944 .65027 .2172 .67722 .21336 .66443 .18532 Metetra
.49 .576 .869 r
.66443 .18532 .67722 .21336 .70446 .20961 .69199 .19181 Metetra
.384 .606 .936 r
.69199 .19181 .70446 .20961 .73201 .20645 .71993 .19913 Metetra
.047 .547 .882 r
.71993 .19913 .73201 .20645 .7601 .21349 .74826 .20675 Metetra
.008 .526 .859 r
.74826 .20675 .7601 .21349 .78858 .22129 .77697 .21469 Metetra
0 .502 .84 r
.77697 .21469 .78858 .22129 .81746 .22938 .80609 .22336 Metetra
.567 .01 0 r
.80609 .22336 .81746 .22938 .84674 .23791 .83606 .24714 Metetra
.751 .309 .202 r
.83606 .24714 .84674 .23791 .87646 .24766 .86653 .27141 Metetra
.622 .27 .352 r
.86653 .27141 .87646 .24766 .90767 .2876 .89701 .28103 Metetra
.724 .885 .955 r
.24536 .34987 .26116 .35502 .28473 .34193 .2691 .33658 Metetra
.725 .885 .954 r
.2691 .33658 .28473 .34193 .30851 .32872 .29304 .32316 Metetra
.725 .884 .954 r
.29304 .32316 .30851 .32872 .33248 .31538 .31719 .30962 Metetra
.725 .883 .954 r
.31719 .30962 .33248 .31538 .35666 .30189 .34155 .29594 Metetra
.726 .883 .953 r
.34155 .29594 .35666 .30189 .38105 .28824 .36612 .28212 Metetra
.726 .883 .953 r
.36612 .28212 .38105 .28824 .40565 .27443 .3909 .26816 Metetra
.726 .883 .953 r
.3909 .26816 .40565 .27443 .43046 .26047 .41589 .25405 Metetra
.727 .883 .953 r
.41589 .25405 .43046 .26047 .45548 .24684 .44111 .23979 Metetra
.727 .877 .95 r
.44111 .23979 .45548 .24684 .48067 .24275 .46654 .22539 Metetra
.709 .756 .889 r
.46654 .22539 .48067 .24275 .50613 .23907 .4922 .21135 Metetra
.61 .643 .858 r
.4922 .21135 .50613 .23907 .53187 .23529 .51807 .20703 Metetra
.606 .639 .857 r
.51807 .20703 .53187 .23529 .55788 .23134 .54423 .20316 Metetra
.606 .64 .858 r
.54423 .20316 .55788 .23134 .58417 .22686 .57067 .19922 Metetra
.602 .642 .863 r
.57067 .19922 .58417 .22686 .61065 .2082 .59741 .19565 Metetra
.297 .632 .963 r
.59741 .19565 .61065 .2082 .63733 .18944 .62454 .20166 Metetra
.214 0 0 r
.62454 .20166 .63733 .18944 .66443 .18532 .65186 .19388 Metetra
.08 0 0 r
.65186 .19388 .66443 .18532 .69199 .19181 .67947 .18612 Metetra
0 .521 .83 r
.67947 .18612 .69199 .19181 .71993 .19913 .70762 .19303 Metetra
0 .495 .821 r
.70762 .19303 .71993 .19913 .74826 .20675 .73618 .20112 Metetra
.598 .038 0 r
.73618 .20112 .74826 .20675 .77697 .21469 .76546 .22433 Metetra
.749 .315 .22 r
.76546 .22433 .77697 .21469 .80609 .22336 .79525 .24802 Metetra
.617 .27 .36 r
.79525 .24802 .80609 .22336 .83606 .24714 .82511 .25703 Metetra
.569 .083 .063 r
.82511 .25703 .83606 .24714 .86653 .27141 .85539 .26565 Metetra
0 .493 .817 r
.85539 .26565 .86653 .27141 .89701 .28103 .8861 .2743 Metetra
.726 .885 .954 r
.22924 .34461 .24536 .34987 .2691 .33658 .25316 .33108 Metetra
.726 .884 .954 r
.25316 .33108 .2691 .33658 .29304 .32316 .27727 .31743 Metetra
.726 .883 .953 r
.27727 .31743 .29304 .32316 .31719 .30962 .3016 .30367 Metetra
.726 .882 .953 r
.3016 .30367 .31719 .30962 .34155 .29594 .32613 .28978 Metetra
.726 .882 .953 r
.32613 .28978 .34155 .29594 .36612 .28212 .35088 .27578 Metetra
.726 .882 .953 r
.35088 .27578 .36612 .28212 .3909 .26816 .37585 .26165 Metetra
.726 .882 .953 r
.37585 .26165 .3909 .26816 .41589 .25405 .40103 .24741 Metetra
.726 .882 .953 r
.40103 .24741 .41589 .25405 .44111 .23979 .42644 .23303 Metetra
.726 .883 .953 r
.42644 .23303 .44111 .23979 .46654 .22539 .45207 .21853 Metetra
.726 .884 .954 r
.45207 .21853 .46654 .22539 .4922 .21135 .47793 .20391 Metetra
.726 .879 .952 r
.47793 .20391 .4922 .21135 .51807 .20703 .50402 .18918 Metetra
.704 .757 .893 r
.50402 .18918 .51807 .20703 .54423 .20316 .53035 .17537 Metetra
.483 .578 .874 r
.53035 .17537 .54423 .20316 .57067 .19922 .55697 .18149 Metetra
.364 .602 .939 r
.55697 .18149 .57067 .19922 .59741 .19565 .58394 .18875 Metetra
0 .522 .85 r
.58394 .18875 .59741 .19565 .62454 .20166 .61128 .19613 Metetra
0 .481 .792 r
.61128 .19613 .62454 .20166 .65186 .19388 .63899 .20362 Metetra
.565 .086 .077 r
.63899 .20362 .65186 .19388 .67947 .18612 .66707 .21121 Metetra
.607 .265 .364 r
.66707 .21121 .67947 .18612 .70762 .19303 .69554 .21891 Metetra
.608 .268 .369 r
.69554 .21891 .70762 .19303 .73618 .20112 .72441 .22672 Metetra
.607 .265 .364 r
.72441 .22672 .73618 .20112 .76546 .22433 .75368 .23463 Metetra
.564 .084 .074 r
.75368 .23463 .76546 .22433 .79525 .24802 .78335 .24266 Metetra
0 .485 .798 r
.78335 .24266 .79525 .24802 .82511 .25703 .81345 .2508 Metetra
0 .512 .836 r
.81345 .2508 .82511 .25703 .85539 .26565 .84398 .25906 Metetra
0 .523 .852 r
.84398 .25906 .85539 .26565 .8861 .2743 .87494 .26743 Metetra
.727 .885 .953 r
.21281 .33925 .22924 .34461 .25316 .33108 .23689 .32548 Metetra
.727 .884 .953 r
.23689 .32548 .25316 .33108 .27727 .31743 .26118 .31159 Metetra
.727 .883 .953 r
.26118 .31159 .27727 .31743 .3016 .30367 .28569 .2976 Metetra
.727 .882 .953 r
.28569 .2976 .3016 .30367 .32613 .28978 .3104 .2835 Metetra
.726 .882 .953 r
.3104 .2835 .32613 .28978 .35088 .27578 .33534 .26931 Metetra
.726 .882 .953 r
.33534 .26931 .35088 .27578 .37585 .26165 .36049 .25502 Metetra
.726 .882 .953 r
.36049 .25502 .37585 .26165 .40103 .24741 .38587 .24063 Metetra
.725 .882 .953 r
.38587 .24063 .40103 .24741 .42644 .23303 .41147 .22615 Metetra
.724 .883 .954 r
.41147 .22615 .42644 .23303 .45207 .21853 .4373 .21157 Metetra
.717 .884 .958 r
.4373 .21157 .45207 .21853 .47793 .20391 .46336 .19742 Metetra
.487 .825 .999 r
.46336 .19742 .47793 .20391 .50402 .18918 .48962 .19321 Metetra
.017 0 0 r
.48962 .19321 .50402 .18918 .53035 .17537 .51617 .18952 Metetra
.367 0 .04 r
.51617 .18952 .53035 .17537 .55697 .18149 .54302 .18586 Metetra
.074 0 0 r
.54302 .18586 .55697 .18149 .58394 .18875 .57018 .18281 Metetra
0 .478 .795 r
.57018 .18281 .58394 .18875 .61128 .19613 .59773 .19052 Metetra
.648 .094 0 r
.59773 .19052 .61128 .19613 .63899 .20362 .62579 .21361 Metetra
.75 .329 .248 r
.62579 .21361 .63899 .20362 .66707 .21121 .65432 .23701 Metetra
.612 .27 .367 r
.65432 .23701 .66707 .21121 .69554 .21891 .68312 .24553 Metetra
.603 .263 .367 r
.68312 .24553 .69554 .21891 .72441 .22672 .7123 .25305 Metetra
.428 .082 .275 r
.7123 .25305 .72441 .22672 .75368 .23463 .74159 .2452 Metetra
.155 0 0 r
.74159 .2452 .75368 .23463 .78335 .24266 .77119 .23717 Metetra
0 .517 .821 r
.77119 .23717 .78335 .24266 .81345 .2508 .80152 .24443 Metetra
0 .526 .845 r
.80152 .24443 .81345 .2508 .84398 .25906 .8323 .25231 Metetra
.012 .533 .858 r
.8323 .25231 .84398 .25906 .87494 .26743 .86353 .2604 Metetra
.728 .885 .953 r
.19604 .33378 .21281 .33925 .23689 .32548 .22029 .31979 Metetra
.728 .885 .953 r
.22029 .31979 .23689 .32548 .26118 .31159 .24476 .30569 Metetra
.727 .884 .953 r
.24476 .30569 .26118 .31159 .28569 .2976 .26945 .29148 Metetra
.727 .884 .953 r
.26945 .29148 .28569 .2976 .3104 .2835 .29435 .27719 Metetra
.726 .883 .953 r
.29435 .27719 .3104 .2835 .33534 .26931 .31947 .26282 Metetra
.726 .883 .953 r
.31947 .26282 .33534 .26931 .36049 .25502 .34481 .24837 Metetra
.725 .883 .954 r
.34481 .24837 .36049 .25502 .38587 .24063 .37038 .23385 Metetra
.717 .883 .958 r
.37038 .23385 .38587 .24063 .41147 .22615 .39618 .21978 Metetra
.479 .823 .998 r
.39618 .21978 .41147 .22615 .4373 .21157 .4221 .21573 Metetra
.023 0 0 r
.4221 .21573 .4373 .21157 .46336 .19742 .44831 .21222 Metetra
.375 0 .054 r
.44831 .21222 .46336 .19742 .48962 .19321 .47482 .20877 Metetra
.39 0 .081 r
.47482 .20877 .48962 .19321 .51617 .18952 .50163 .20541 Metetra
.407 0 .099 r
.50163 .20541 .51617 .18952 .54302 .18586 .52875 .20254 Metetra
.645 .252 .284 r
.52875 .20254 .54302 .18586 .57018 .18281 .55622 .21439 Metetra
.638 .326 .427 r
.55622 .21439 .57018 .18281 .59773 .19052 .58409 .22639 Metetra
.525 .225 .4 r
.58409 .22639 .59773 .19052 .62579 .21361 .61226 .22403 Metetra
.561 .083 .078 r
.61226 .22403 .62579 .21361 .65432 .23701 .64088 .23166 Metetra
0 .46 .768 r
.64088 .23166 .65432 .23701 .68312 .24553 .6699 .23972 Metetra
0 .483 .797 r
.6699 .23972 .68312 .24553 .7123 .25305 .69933 .24773 Metetra
0 .478 .783 r
.69933 .24773 .7123 .25305 .74159 .2452 .72917 .25562 Metetra
.543 .054 .046 r
.72917 .25562 .74159 .2452 .77119 .23717 .75943 .26297 Metetra
.413 .059 .252 r
.75943 .26297 .77119 .23717 .80152 .24443 .78973 .25464 Metetra
.127 0 0 r
.78973 .25464 .80152 .24443 .8323 .25231 .82038 .24612 Metetra
.019 .548 .855 r
.82038 .24612 .8323 .25231 .86353 .2604 .85185 .2532 Metetra
.728 .885 .953 r
.17892 .3282 .19604 .33378 .22029 .31979 .20336 .31403 Metetra
.728 .885 .953 r
.20336 .31403 .22029 .31979 .24476 .30569 .228 .29976 Metetra
.727 .885 .953 r
.228 .29976 .24476 .30569 .26945 .29148 .25287 .28538 Metetra
.727 .885 .954 r
.25287 .28538 .26945 .29148 .29435 .27719 .27795 .27092 Metetra
.726 .885 .954 r
.27795 .27092 .29435 .27719 .31947 .26282 .30326 .2564 Metetra
.717 .885 .958 r
.30326 .2564 .31947 .26282 .34481 .24837 .32879 .24234 Metetra
.47 .824 .996 r
.32879 .24234 .34481 .24837 .37038 .23385 .35438 .23834 Metetra
.034 0 0 r
.35438 .23834 .37038 .23385 .39618 .21978 .38025 .23491 Metetra
.375 0 .055 r
.38025 .23491 .39618 .21978 .4221 .21573 .40641 .23155 Metetra
.39 0 .079 r
.40641 .23155 .4221 .21573 .44831 .21222 .43286 .22833 Metetra
.407 0 .097 r
.43286 .22833 .44831 .21222 .47482 .20877 .45962 .22563 Metetra
.648 .257 .29 r
.45962 .22563 .47482 .20877 .50163 .20541 .48664 .23773 Metetra
.638 .329 .431 r
.48664 .23773 .50163 .20541 .52875 .20254 .51404 .25 Metetra
.537 .269 .457 r
.51404 .25 .52875 .20254 .55622 .21439 .54184 .24733 Metetra
.505 .189 .365 r
.54184 .24733 .55622 .21439 .58409 .22639 .56996 .24404 Metetra
.407 0 .121 r
.56996 .24404 .58409 .22639 .61226 .22403 .59842 .24051 Metetra
.389 0 .085 r
.59842 .24051 .61226 .22403 .64088 .23166 .62722 .23682 Metetra
.099 0 0 r
.62722 .23682 .64088 .23166 .6699 .23972 .65637 .23353 Metetra
0 .511 .823 r
.65637 .23353 .6699 .23972 .69933 .24773 .68603 .241 Metetra
0 .512 .834 r
.68603 .241 .69933 .24773 .72917 .25562 .71612 .24901 Metetra
0 .515 .835 r
.71612 .24901 .72917 .25562 .75943 .26297 .74665 .25697 Metetra
0 .512 .822 r
.74665 .25697 .75943 .26297 .78973 .25464 .77762 .26468 Metetra
.513 .01 0 r
.77762 .26468 .78973 .25464 .82038 .24612 .809 .27133 Metetra
.1 0 .084 r
.809 .27133 .82038 .24612 .85185 .2532 .8399 .24584 Metetra
.727 .885 .953 r
.16146 .3225 .17892 .3282 .20336 .31403 .18606 .30822 Metetra
.727 .886 .954 r
.18606 .30822 .20336 .31403 .228 .29976 .21089 .29382 Metetra
.726 .887 .954 r
.21089 .29382 .228 .29976 .25287 .28538 .23594 .27934 Metetra
.718 .887 .958 r
.23594 .27934 .25287 .28538 .27795 .27092 .2612 .26529 Metetra
.459 .824 .994 r
.2612 .26529 .27795 .27092 .30326 .2564 .28645 .26134 Metetra
.048 0 0 r
.28645 .26134 .30326 .2564 .32879 .24234 .31197 .25794 Metetra
.376 0 .059 r
.31197 .25794 .32879 .24234 .35438 .23834 .33779 .25463 Metetra
.39 0 .083 r
.33779 .25463 .35438 .23834 .38025 .23491 .36389 .25145 Metetra
.407 0 .099 r
.36389 .25145 .38025 .23491 .40641 .23155 .39029 .24881 Metetra
.65 .263 .298 r
.39029 .24881 .40641 .23155 .43286 .22833 .41684 .26105 Metetra
.639 .33 .432 r
.41684 .26105 .43286 .22833 .45962 .22563 .44378 .27349 Metetra
.535 .266 .454 r
.44378 .27349 .45962 .22563 .48664 .23773 .4712 .27096 Metetra
.503 .185 .361 r
.4712 .27096 .48664 .23773 .51404 .25 .49895 .26785 Metetra
.407 0 .118 r
.49895 .26785 .51404 .25 .54184 .24733 .52703 .26452 Metetra
.396 0 .097 r
.52703 .26452 .54184 .24733 .56996 .24404 .55545 .26105 Metetra
.391 0 .088 r
.55545 .26105 .56996 .24404 .59842 .24051 .58421 .25744 Metetra
.387 0 .083 r
.58421 .25744 .59842 .24051 .62722 .23682 .61331 .2537 Metetra
.383 0 .079 r
.61331 .2537 .62722 .23682 .65637 .23353 .64277 .24981 Metetra
.372 0 .058 r
.64277 .24981 .65637 .23353 .68603 .241 .67258 .24575 Metetra
.061 0 0 r
.67258 .24575 .68603 .241 .71612 .24901 .70277 .242 Metetra
.042 .561 .87 r
.70277 .242 .71612 .24901 .74665 .25697 .73353 .24876 Metetra
.573 .861 .996 r
.73353 .24876 .74665 .25697 .77762 .26468 .7644 .24008 Metetra
.633 .71 .902 r
.7644 .24008 .77762 .26468 .809 .27133 .79562 .23121 Metetra
.505 .551 .837 r
.79562 .23121 .809 .27133 .8399 .24584 .82766 .23829 Metetra
.725 .885 .954 r
.14362 .31668 .16146 .3225 .18606 .30822 .1684 .30235 Metetra
.717 .887 .958 r
.1684 .30235 .18606 .30822 .21089 .29382 .19339 .28843 Metetra
.448 .823 .992 r
.19339 .28843 .21089 .29382 .23594 .27934 .21831 .28461 Metetra
.06 0 0 r
.21831 .28461 .23594 .27934 .2612 .26529 .24349 .28132 Metetra
.376 0 .062 r
.24349 .28132 .2612 .26529 .28645 .26134 .26895 .27809 Metetra
.39 0 .086 r
.26895 .27809 .28645 .26134 .31197 .25794 .2947 .27498 Metetra
.407 0 .103 r
.2947 .27498 .31197 .25794 .33779 .25463 .32074 .27239 Metetra
.651 .268 .307 r
.32074 .27239 .33779 .25463 .36389 .25145 .34682 .28473 Metetra
.639 .331 .434 r
.34682 .28473 .36389 .25145 .39029 .24881 .37329 .29727 Metetra
.533 .263 .452 r
.37329 .29727 .39029 .24881 .41684 .26105 .40033 .2948 Metetra
.501 .183 .359 r
.40033 .2948 .41684 .26105 .44378 .27349 .42771 .29175 Metetra
.406 0 .119 r
.42771 .29175 .44378 .27349 .4712 .27096 .45541 .28851 Metetra
.395 0 .097 r
.45541 .28851 .4712 .27096 .49895 .26785 .48344 .28516 Metetra
.39 0 .087 r
.48344 .28516 .49895 .26785 .52703 .26452 .51182 .2817 Metetra
.386 0 .081 r
.51182 .2817 .52703 .26452 .55545 .26105 .54053 .27814 Metetra
.383 0 .076 r
.54053 .27814 .55545 .26105 .58421 .25744 .56959 .27446 Metetra
.379 0 .07 r
.56959 .27446 .58421 .25744 .61331 .2537 .59901 .27063 Metetra
.372 0 .063 r
.59901 .27063 .61331 .2537 .64277 .24981 .62879 .26655 Metetra
.355 0 .047 r
.62879 .26655 .64277 .24981 .67258 .24575 .65893 .2618 Metetra
.65893 .2618 .67258 .24575 .70277 .242 .68919 .2409 Metetra
.717 .977 .918 r
.68919 .2409 .70277 .242 .73353 .24876 .71974 .21979 Metetra
.593 .661 .886 r
.71974 .21979 .73353 .24876 .7644 .24008 .75091 .21516 Metetra
.426 .595 .914 r
.75091 .21516 .7644 .24008 .79562 .23121 .78277 .22245 Metetra
.073 .562 .896 r
.78277 .22245 .79562 .23121 .82766 .23829 .81512 .23057 Metetra
.429 .807 .992 r
.12541 .31074 .14362 .31668 .1684 .30235 .14996 .30772 Metetra
.069 0 0 r
.14996 .30772 .1684 .30235 .19339 .28843 .17479 .30467 Metetra
.377 0 .06 r
.17479 .30467 .19339 .28843 .21831 .28461 .1999 .30164 Metetra
.391 0 .086 r
.1999 .30164 .21831 .28461 .24349 .28132 .22529 .2987 Metetra
.408 0 .104 r
.22529 .2987 .24349 .28132 .26895 .27809 .25097 .29625 Metetra
.653 .274 .314 r
.25097 .29625 .26895 .27809 .2947 .27498 .27658 .30877 Metetra
.639 .333 .436 r
.27658 .30877 .2947 .27498 .32074 .27239 .30258 .32146 Metetra
.531 .26 .45 r
.30258 .32146 .32074 .27239 .34682 .28473 .32924 .31906 Metetra
.498 .18 .358 r
.32924 .31906 .34682 .28473 .37329 .29727 .35624 .31607 Metetra
.406 0 .121 r
.35624 .31607 .37329 .29727 .40033 .2948 .38356 .31288 Metetra
.395 0 .1 r
.38356 .31288 .40033 .2948 .42771 .29175 .41121 .30957 Metetra
.39 0 .09 r
.41121 .30957 .42771 .29175 .45541 .28851 .43919 .30617 Metetra
.386 0 .083 r
.43919 .30617 .45541 .28851 .48344 .28516 .46752 .30268 Metetra
.383 0 .077 r
.46752 .30268 .48344 .28516 .51182 .2817 .49618 .2991 Metetra
.378 0 .07 r
.49618 .2991 .51182 .2817 .54053 .27814 .5252 .29538 Metetra
.372 0 .062 r
.5252 .29538 .54053 .27814 .56959 .27446 .55457 .29146 Metetra
.354 0 .044 r
.55457 .29146 .56959 .27446 .59901 .27063 .58431 .28689 Metetra
.58431 .28689 .59901 .27063 .62879 .26655 .61428 .26615 Metetra
.714 .978 .916 r
.61428 .26615 .62879 .26655 .65893 .2618 .64453 .2452 Metetra
.567 .755 .966 r
.64453 .2452 .65893 .2618 .68919 .2409 .67528 .24024 Metetra
.221 .742 .835 r
.67528 .24024 .68919 .2409 .71974 .21979 .70643 .23579 Metetra
.348 0 .015 r
.70643 .23579 .71974 .21979 .75091 .21516 .73797 .23143 Metetra
.352 0 .023 r
.73797 .23143 .75091 .21516 .78277 .22245 .76992 .22706 Metetra
.032 0 0 r
.76992 .22706 .78277 .22245 .81512 .23057 .80229 .22266 Metetra
.261 0 0 r
.10682 .30468 .12541 .31074 .14996 .30772 .13108 .31329 Metetra
.558 .04 0 r
.13108 .31329 .14996 .30772 .17479 .30467 .1557 .32158 Metetra
.417 0 .098 r
.1557 .32158 .17479 .30467 .1999 .30164 .18098 .31995 Metetra
.656 .279 .32 r
.18098 .31995 .1999 .30164 .22529 .2987 .20612 .33278 Metetra
.64 .334 .437 r
.20612 .33278 .22529 .2987 .25097 .29625 .23164 .34574 Metetra
.529 .257 .447 r
.23164 .34574 .25097 .29625 .27658 .30877 .25792 .34353 Metetra
.497 .177 .355 r
.25792 .34353 .27658 .30877 .30258 .32146 .28454 .34069 Metetra
.406 0 .122 r
.28454 .34069 .30258 .32146 .32924 .31906 .31148 .33762 Metetra
.395 0 .102 r
.31148 .33762 .32924 .31906 .35624 .31607 .33874 .33441 Metetra
.39 0 .093 r
.33874 .33441 .35624 .31607 .38356 .31288 .36633 .33108 Metetra
.386 0 .086 r
.36633 .33108 .38356 .31288 .41121 .30957 .39426 .32765 Metetra
.383 0 .08 r
.39426 .32765 .41121 .30957 .43919 .30617 .42253 .32411 Metetra
.378 0 .074 r
.42253 .32411 .43919 .30617 .46752 .30268 .45115 .32045 Metetra
.372 0 .065 r
.45115 .32045 .46752 .30268 .49618 .2991 .48011 .31659 Metetra
.354 0 .046 r
.48011 .31659 .49618 .2991 .5252 .29538 .50944 .3121 Metetra
.50944 .3121 .5252 .29538 .55457 .29146 .53912 .29138 Metetra
.718 .977 .918 r
.53912 .29138 .55457 .29146 .58431 .28689 .56907 .27049 Metetra
.562 .756 .969 r
.56907 .27049 .58431 .28689 .61428 .26615 .5994 .26569 Metetra
.21 .735 .827 r
.5994 .26569 .61428 .26615 .64453 .2452 .63012 .26143 Metetra
.347 0 .012 r
.63012 .26143 .64453 .2452 .67528 .24024 .66124 .2573 Metetra
.36 0 .036 r
.66124 .2573 .67528 .24024 .70643 .23579 .69275 .25318 Metetra
.352 0 .038 r
.69275 .25318 .70643 .23579 .73797 .23143 .72466 .24844 Metetra
.057 0 0 r
.72466 .24844 .73797 .23143 .76992 .22706 .75673 .23189 Metetra
.425 .855 .729 r
.75673 .23189 .76992 .22706 .80229 .22266 .78913 .21455 Metetra
.318 0 0 r
.08782 .29848 .10682 .30468 .13108 .31329 .11218 .30811 Metetra
.782 .288 .037 r
.11218 .30811 .13108 .31329 .1557 .32158 .13633 .33277 Metetra
.764 .384 .336 r
.13633 .33277 .1557 .32158 .18098 .31995 .1609 .35774 Metetra
.611 .312 .437 r
.1609 .35774 .18098 .31995 .20612 .33278 .1864 .36712 Metetra
.501 .178 .35 r
.1864 .36712 .20612 .33278 .23164 .34574 .21261 .36513 Metetra
.406 0 .119 r
.21261 .36513 .23164 .34574 .25792 .34353 .23916 .36232 Metetra
.396 0 .1 r
.23916 .36232 .25792 .34353 .28454 .34069 .26603 .35933 Metetra
.391 0 .092 r
.26603 .35933 .28454 .34069 .31148 .33762 .29323 .35619 Metetra
.387 0 .087 r
.29323 .35619 .31148 .33762 .33874 .33441 .32076 .35292 Metetra
.383 0 .082 r
.32076 .35292 .33874 .33441 .36633 .33108 .34863 .34951 Metetra
.379 0 .076 r
.34863 .34951 .36633 .33108 .39426 .32765 .37684 .34595 Metetra
.372 0 .068 r
.37684 .34595 .39426 .32765 .42253 .32411 .4054 .34217 Metetra
.354 0 .049 r
.4054 .34217 .42253 .32411 .45115 .32045 .43432 .33774 Metetra
.43432 .33774 .45115 .32045 .48011 .31659 .4637 .31701 Metetra
.721 .978 .917 r
.4637 .31701 .48011 .31659 .50944 .3121 .49335 .29611 Metetra
.557 .76 .972 r
.49335 .29611 .50944 .3121 .53912 .29138 .52327 .29136 Metetra
.194 .724 .812 r
.52327 .29136 .53912 .29138 .56907 .27049 .55356 .28719 Metetra
.348 0 .014 r
.55356 .28719 .56907 .27049 .5994 .26569 .58424 .28316 Metetra
.36 0 .037 r
.58424 .28316 .5994 .26569 .63012 .26143 .61531 .27917 Metetra
.351 0 .036 r
.61531 .27917 .63012 .26143 .66124 .2573 .64678 .27461 Metetra
.042 0 0 r
.64678 .27461 .66124 .2573 .69275 .25318 .67849 .2582 Metetra
.438 .864 .743 r
.67849 .2582 .69275 .25318 .72466 .24844 .71053 .24105 Metetra
.691 .923 .97 r
.71053 .24105 .72466 .24844 .75673 .23189 .74291 .22373 Metetra
.694 .918 .97 r
.74291 .22373 .75673 .23189 .78913 .21455 .77564 .20624 Metetra
.883 .484 .267 r
.0684 .29215 .08782 .29848 .11218 .30811 .09162 .33262 Metetra
.628 .277 .357 r
.09162 .33262 .11218 .30811 .13633 .33277 .11651 .34324 Metetra
.604 .143 .133 r
.11651 .34324 .13633 .33277 .1609 .35774 .14179 .35287 Metetra
.332 0 0 r
.14179 .35287 .1609 .35774 .1864 .36712 .16745 .36229 Metetra
.321 0 0 r
.16745 .36229 .1864 .36712 .21261 .36513 .19348 .37165 Metetra
.551 .032 0 r
.19348 .37165 .21261 .36513 .23916 .36232 .21991 .38042 Metetra
.395 0 .078 r
.21991 .38042 .23916 .36232 .26603 .35933 .24702 .37802 Metetra
.384 0 .079 r
.24702 .37802 .26603 .35933 .29323 .35619 .27449 .37489 Metetra
.379 0 .074 r
.27449 .37489 .29323 .35619 .32076 .35292 .30229 .37156 Metetra
.372 0 .067 r
.30229 .37156 .32076 .35292 .34863 .34951 .33044 .36796 Metetra
.354 0 .049 r
.33044 .36796 .34863 .34951 .37684 .34595 .35895 .36369 Metetra
.35895 .36369 .37684 .34595 .4054 .34217 .38803 .34303 Metetra
.724 .978 .918 r
.38803 .34303 .4054 .34217 .43432 .33774 .41738 .32216 Metetra
.551 .763 .976 r
.41738 .32216 .43432 .33774 .4637 .31701 .44687 .3175 Metetra
.176 .712 .793 r
.44687 .3175 .4637 .31701 .49335 .29611 .47674 .31339 Metetra
.348 0 .019 r
.47674 .31339 .49335 .29611 .52327 .29136 .50698 .30943 Metetra
.36 0 .041 r
.50698 .30943 .52327 .29136 .55356 .28719 .53761 .3055 Metetra
.351 0 .039 r
.53761 .3055 .55356 .28719 .58424 .28316 .56863 .301 Metetra
.029 0 0 r
.56863 .301 .58424 .28316 .61531 .27917 .59998 .28464 Metetra
.445 .869 .749 r
.59998 .28464 .61531 .27917 .64678 .27461 .63165 .26754 Metetra
.691 .923 .969 r
.63165 .26754 .64678 .27461 .67849 .2582 .66367 .25031 Metetra
.694 .918 .97 r
.66367 .25031 .67849 .2582 .71053 .24105 .69603 .23294 Metetra
.693 .918 .97 r
.69603 .23294 .71053 .24105 .74291 .22373 .72875 .21542 Metetra
.693 .918 .97 r
.72875 .21542 .74291 .22373 .77564 .20624 .76182 .19772 Metetra
.315 0 0 r
.04856 .28567 .0684 .29215 .09162 .33262 .07318 .29538 Metetra
.049 .279 .772 r
.07318 .29538 .09162 .33262 .11651 .34324 .09754 .32044 Metetra
0 .066 .595 r
.09754 .32044 .11651 .34324 .14179 .35287 .12233 .34583 Metetra
.279 0 0 r
.12233 .34583 .14179 .35287 .16745 .36229 .14811 .35588 Metetra
.268 0 0 r
.14811 .35588 .16745 .36229 .19348 .37165 .1743 .36542 Metetra
.26 0 0 r
.1743 .36542 .19348 .37165 .21991 .38042 .20088 .37484 Metetra
.273 0 0 r
.20088 .37484 .21991 .38042 .24702 .37802 .22785 .3842 Metetra
.531 0 0 r
.22785 .3842 .24702 .37802 .27449 .37489 .25525 .39285 Metetra
.361 0 .038 r
.25525 .39285 .27449 .37489 .30229 .37156 .28332 .38948 Metetra
.28332 .38948 .30229 .37156 .33044 .36796 .3121 .36903 Metetra
.728 .977 .921 r
.3121 .36903 .33044 .36796 .35895 .36369 .34114 .34832 Metetra
.545 .764 .978 r
.34114 .34832 .35895 .36369 .38803 .34303 .37021 .34386 Metetra
.16 .7 .779 r
.37021 .34386 .38803 .34303 .41738 .32216 .39964 .33993 Metetra
.349 0 .021 r
.39964 .33993 .41738 .32216 .44687 .3175 .42945 .3361 Metetra
.361 0 .044 r
.42945 .3361 .44687 .3175 .47674 .31339 .45963 .33229 Metetra
.351 0 .042 r
.45963 .33229 .47674 .31339 .50698 .30943 .49021 .32788 Metetra
.018 0 0 r
.49021 .32788 .50698 .30943 .53761 .3055 .52119 .31154 Metetra
.45 .871 .749 r
.52119 .31154 .53761 .3055 .56863 .301 .55251 .29445 Metetra
.692 .925 .969 r
.55251 .29445 .56863 .301 .59998 .28464 .58415 .27723 Metetra
.694 .919 .969 r
.58415 .27723 .59998 .28464 .63165 .26754 .61615 .25989 Metetra
.694 .919 .97 r
.61615 .25989 .63165 .26754 .66367 .25031 .64848 .2424 Metetra
.693 .919 .97 r
.64848 .2424 .66367 .25031 .69603 .23294 .68117 .22476 Metetra
.693 .919 .97 r
.68117 .22476 .69603 .23294 .72875 .21542 .71422 .20696 Metetra
.692 .919 .97 r
.71422 .20696 .72875 .21542 .76182 .19772 .74763 .18898 Metetra
.257 0 0 r
.02827 .27906 .04856 .28567 .07318 .29538 .05307 .28779 Metetra
0 .363 .686 r
.05307 .28779 .07318 .29538 .09754 .32044 .07823 .29676 Metetra
.272 .534 .916 r
.07823 .29676 .09754 .32044 .12233 .34583 .10372 .30637 Metetra
.085 .295 .778 r
.10372 .30637 .12233 .34583 .14811 .35588 .129 .33184 Metetra
0 .101 .633 r
.129 .33184 .14811 .35588 .1743 .36542 .15473 .35767 Metetra
0 .353 .683 r
.15473 .35767 .1743 .36542 .20088 .37484 .18145 .36762 Metetra
0 .394 .711 r
.18145 .36762 .20088 .37484 .22785 .3842 .20861 .37652 Metetra
.553 .853 .998 r
.20861 .37652 .22785 .3842 .25525 .39285 .23663 .36899 Metetra
.617 .713 .914 r
.23663 .36899 .25525 .39285 .28332 .38948 .26498 .36125 Metetra
.383 .565 .907 r
.26498 .36125 .28332 .38948 .3121 .36903 .29331 .3693 Metetra
.143 .688 .786 r
.29331 .3693 .3121 .36903 .34114 .34832 .32228 .36628 Metetra
.35 0 .018 r
.32228 .36628 .34114 .34832 .37021 .34386 .35164 .36275 Metetra
.361 0 .042 r
.35164 .36275 .37021 .34386 .39964 .33993 .38138 .35919 Metetra
.351 0 .04 r
.38138 .35919 .39964 .33993 .42945 .3361 .4115 .35499 Metetra
.004 0 0 r
.4115 .35499 .42945 .3361 .45963 .33229 .44212 .33877 Metetra
.456 .876 .754 r
.44212 .33877 .45963 .33229 .49021 .32788 .47307 .32178 Metetra
.692 .926 .968 r
.47307 .32178 .49021 .32788 .52119 .31154 .50435 .30463 Metetra
.695 .921 .969 r
.50435 .30463 .52119 .31154 .55251 .29445 .53597 .28732 Metetra
.694 .921 .969 r
.53597 .28732 .55251 .29445 .58415 .27723 .56793 .26985 Metetra
.693 .921 .969 r
.56793 .26985 .58415 .27723 .61615 .25989 .60024 .25223 Metetra
.693 .921 .969 r
.60024 .25223 .61615 .25989 .64848 .2424 .63291 .23445 Metetra
.693 .921 .97 r
.63291 .23445 .64848 .2424 .68117 .22476 .66593 .21649 Metetra
.693 .92 .97 r
.66593 .21649 .68117 .22476 .71422 .20696 .69932 .19835 Metetra
.693 .92 .97 r
.69932 .19835 .71422 .20696 .74763 .18898 .73308 .18002 Metetra
.238 0 0 r
.00753 .27229 .02827 .27906 .05307 .28779 .03248 .28075 Metetra
0 .363 .672 r
.03248 .28075 .05307 .28779 .07823 .29676 .05779 .28934 Metetra
0 .376 .692 r
.05779 .28934 .07823 .29676 .10372 .30637 .08347 .29805 Metetra
0 .402 .733 r
.08347 .29805 .10372 .30637 .129 .33184 .10952 .30688 Metetra
.307 .548 .918 r
.10952 .30688 .129 .33184 .15473 .35767 .13596 .31585 Metetra
.436 .516 .843 r
.13596 .31585 .15473 .35767 .18145 .36762 .16278 .32495 Metetra
.438 .515 .84 r
.16278 .32495 .18145 .36762 .20861 .37652 .19001 .33418 Metetra
.436 .516 .842 r
.19001 .33418 .20861 .37652 .23663 .36899 .21766 .34355 Metetra
.308 .548 .918 r
.21766 .34355 .23663 .36899 .26498 .36125 .24572 .35306 Metetra
0 .406 .739 r
.24572 .35306 .26498 .36125 .29331 .3693 .27421 .36271 Metetra
0 .366 .676 r
.27421 .36271 .29331 .3693 .32228 .36628 .30314 .37248 Metetra
.501 0 0 r
.30314 .37248 .32228 .36628 .35164 .36275 .33254 .38115 Metetra
.33254 .38115 .35164 .36275 .38138 .35919 .36277 .36583 Metetra
.467 .884 .768 r
.36277 .36583 .38138 .35919 .4115 .35499 .39335 .34909 Metetra
.691 .925 .969 r
.39335 .34909 .4115 .35499 .44212 .33877 .42426 .33213 Metetra
.694 .921 .969 r
.42426 .33213 .44212 .33877 .47307 .32178 .45551 .31499 Metetra
.694 .921 .969 r
.45551 .31499 .47307 .32178 .50435 .30463 .48709 .29765 Metetra
.693 .922 .969 r
.48709 .29765 .50435 .30463 .53597 .28732 .51902 .28013 Metetra
.693 .922 .969 r
.51902 .28013 .53597 .28732 .56793 .26985 .5513 .26241 Metetra
.693 .923 .969 r
.5513 .26241 .56793 .26985 .60024 .25223 .58393 .2445 Metetra
.693 .922 .969 r
.58393 .2445 .60024 .25223 .63291 .23445 .61693 .22639 Metetra
.693 .922 .969 r
.61693 .22639 .63291 .23445 .66593 .21649 .65029 .20807 Metetra
.694 .921 .969 r
.65029 .20807 .66593 .21649 .69932 .19835 .68403 .18955 Metetra
.694 .92 .969 r
.68403 .18955 .69932 .19835 .73308 .18002 .71815 .17082 Metetra
0 g
.25 Mabswid
.71509 0 m
.98832 .20842 L
s
.98832 .20842 m
1 .47665 L
s
1 .47665 m
.72132 .34739 L
s
.72132 .34739 m
.71509 0 L
s
.01485 .12419 m
0 .42466 L
s
0 .42466 m
.72132 .34739 L
s
.72132 .34739 m
.71509 0 L
s
.71509 0 m
.01485 .12419 L
s
.01485 .12419 m
.71509 0 L
s
.01485 .12419 m
.01452 .13081 L
s
[(0)] .0155 .11094 -0.04942 1 Mshowa
.13861 .10224 m
.13836 .10886 L
s
[(0.2)] .13911 .08899 -0.03764 1 Mshowa
.26978 .07897 m
.26961 .0856 L
s
[(0.4)] .27011 .06572 -0.02509 1 Mshowa
.40905 .05427 m
.40897 .0609 L
s
[(0.6)] .40921 .04102 -0.01171 1 Mshowa
.5572 .028 m
.55721 .03463 L
s
[(0.8)] .55716 .01474 .0026 1 Mshowa
.71509 0 m
.71521 .00663 L
s
[(1)] .71485 -0.01326 .01792 1 Mshowa
.125 Mabswid
.04513 .11882 m
.04494 .12279 L
s
.07584 .11337 m
.07567 .11734 L
s
.107 .10784 m
.10684 .11182 L
s
.17068 .09655 m
.17054 .10052 L
s
.20323 .09078 m
.2031 .09475 L
s
.23626 .08492 m
.23614 .0889 L
s
.30381 .07294 m
.30372 .07692 L
s
.33836 .06681 m
.33828 .07079 L
s
.37343 .06059 m
.37337 .06457 L
s
.44522 .04786 m
.44519 .05184 L
s
.48196 .04134 m
.48194 .04532 L
s
.51928 .03473 m
.51928 .0387 L
s
.59572 .02117 m
.59574 .02515 L
s
.63486 .01423 m
.6349 .01821 L
s
.67465 .00717 m
.67471 .01115 L
s
.25 Mabswid
0 .42466 m
.4023 .52254 L
s
0 .42466 m
.00033 .41804 L
s
[(0)] -0.00065 .4379 .04942 -1 Mshowa
.11996 .45384 m
.12021 .44722 L
s
[(0.5)] .11945 .46709 .03814 -1 Mshowa
.22543 .47951 m
.22562 .47288 L
s
[(1)] .22506 .49276 .02827 -1 Mshowa
.3189 .50224 m
.31903 .49562 L
s
[(1.5)] .31864 .5155 .01956 -1 Mshowa
.4023 .52254 m
.40238 .51591 L
s
[(2)] .40214 .53579 .01182 -1 Mshowa
.125 Mabswid
.02529 .43081 m
.02548 .42684 L
s
.04991 .4368 m
.05008 .43283 L
s
.07387 .44263 m
.07404 .43866 L
s
.09721 .44831 m
.09737 .44434 L
s
.14212 .45924 m
.14226 .45526 L
s
.16373 .46449 m
.16387 .46052 L
s
.18481 .46962 m
.18493 .46565 L
s
.20537 .47462 m
.20549 .47065 L
s
.24502 .48427 m
.24512 .48029 L
s
.26414 .48892 m
.26424 .48495 L
s
.28282 .49347 m
.28291 .48949 L
s
.30107 .49791 m
.30115 .49393 L
s
.33633 .50649 m
.3364 .50251 L
s
.35337 .51063 m
.35344 .50666 L
s
.37004 .51469 m
.3701 .51071 L
s
.38634 .51865 m
.3864 .51468 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[76]:=",
  ImageSize->{308.188, 161.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004d0000XB000`400?l00000o`00003ooooooole
ooooo`00g_ooool3o`0005?ooooo003Oooooo`03o`000?oooooooooo05;ooooo003Oooooo`03o`00
0?oooooooooo05;ooooo003Oooooo`03o`000?oooooooooo05;ooooo003Oooooo`03o`000?oooooo
oooo05;ooooo003Nooooo`;o0000E?ooool00=oooooo00?o0000ooooooooool0D_ooool00?oooooo
=Oooool00;3ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0001fooooo`00[oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000MOooool00:oooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000007Gooooo002_ooooo`04o`00
0?ooooooooooo`0000Sooooo0ol0001fooooo`00[oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000007_ooool5o`0005;ooooo002_ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Iooooo`Go00000oooool00ol0003oooooo`00001A
ooooo`00R_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001Sooooo0_l00009oooo
o`?o00005?ooool6o`0000Sooooo00Co0000oooooooooooo0000D?ooool008Wooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000003?ooooo1_l00004ooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooooooo0_l0001>ooooo`00ROooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000;_ooool5o`0001Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1;ooooo`00ROooool01?l0003oooooooooool00007ooooo`Co
0000:Oooool6o`0000Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo04[ooooo0029ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool09?ooool7o`0001kooooo00?o0000ooooooooool01Oooool2o`0004[ooooo0029ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool07_ooool5o`0002Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`17ooooo`00R_ooool2o`0000[ooooo0_l0000Hooooo`Ko0000
00?oooooo`000?ooool09oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Kooooo
001Vooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o0000=Oooool6o`0000Oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Gooooo001U
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0;oooool5o`0000?ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0:ooooo`;o0000AOooool006Gooooo00Co0000
oooooooooooo00001oooool5o`0002[ooooo1_l0000kooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0@_ooool006Gooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool0000Uooooo`Ko00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0@Oooool006Gooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00000Pooooo`Go000000?oooooo`000?ooool0A?ooool00ol0003oooooooooo`0>ooooo`;o0000
@Oooool006Gooooo00Co0000oooooooooooo00002Oooool2o`0001[ooooo1_l0001<ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0?_ooool004Cooooo0_l00004ooooo`04o`000?oo
ooooooooooooo`Go00004oooool2o`0000_ooooo00?o0000ooooooooool04_ooool6o`0000?ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03gooooo
0013ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000<?ooool6o`0000So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`;o0000?Oooool004?ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Zooooo`Ko00001Oooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0>_ooool004?ooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Sooooo`Ko00000_ooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>Oooool004?ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001oooooo1Ol0001Yoooo
o`03o`000?oooooooooo01Kooooo0_l0000iooooo`00@oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000006Oooool6o`0000Cooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Kooooo000Zooooo`;o00006?ooool2o`00
00Wooooo0ol0000Dooooo`Ko000000?oooooo`000?ooool0LOooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo03Gooooo000Yooooo`04o`000?ooooooooooo`0003Cooooo1Ol00007oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool06_ooool2o`0003Gooooo000Yooooo`04
o`000?ooooooooooo`0002kooooo1_l00003ooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0booooo`00:Oooool01?l0003oooooooooool0000Xoooo
o`Ko000000?oooooo`000?ooool0Poooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
037ooooo000Yooooo`04o`000?ooooooooooo`0002?ooooo1Ol0002<ooooo`03o`000?oooooooooo
01gooooo0_l0000aooooo`00:Oooool01?l0003oooooooooool0000Mooooo`Ko00000oooool00ol0
003oooooooooo`2;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0;_ooool002[o
oooo0_l0000Hooooo`Ko000000?oooooo`000?ooool0U?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02gooooo000oooooo`Go00001oooool00ol0003oooooooooo`2Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0;?ooool003Wooooo1_l00004ooooo`03o`000?oo
oooooooo09_ooooo00?o0000ooooooooool08_ooool2o`0002cooooo000cooooo`Ko00000_ooool0
0ol0003oooooooooo`2Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool0
02kooooo1_l0002]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0:?ooool002_o
oooo0ol00005ooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool09_ooool2o`0002So
oooo000Gooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001_ooool5o`000;7ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Uooooo`005_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`000:oooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Tooooo`003oooool5o`0000;ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0ol0002/ooooo`03o`000?oooooooooo02[ooooo0_l0000Tooooo`005_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool2o`000:[ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Qooooo`005_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`?o0000Yoooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo023ooooo000Fooooo`04o`000?ooooooooooo`0000Sooooo
0_l00007ooooo`03o`000?oooooooooo00cooooo0_l0002Uooooo`03o`000?oooooooooo02kooooo
0_l0000Pooooo`005oooool2o`0000[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0>ooooo`;o0000Xoooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo000[
ooooo`03o`000?oooooooooo013ooooo0ol0002Pooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool07?ooool002[ooooo0_l0000Eooooo`;o0000W_ooool00ol0003oooooooooo`0boooo
o`;o00007?ooool002_ooooo00?o0000ooooooooool05Oooool3o`0009_ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Iooooo`00:_ooool00ol0003oooooooooo`0Iooooo`;o0000
VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Sooooo000Zooooo`;o00007?oo
ool3o`0009Gooooo0ol0000gooooo`;o00006?ooool002[ooooo00?o0000ooooooooool07_ooool2
o`0006;ooooo1?l0000[ooooo`;o000000?o/N_ho`000?najoP00_l0000gooooo`03o`000?oooooo
oooo01Gooooo000Zooooo`03o`000?oooooooooo023ooooo0ol0001Mooooo`;o000000Co1000o`00
0?mM00[oG@0:0ol0000Vooooo`;o00000onajoP00ol0003o/N_hok7[n002o`0003Oooooo00?o0000
ooooooooool05?ooool002[ooooo00?o0000ooooooooool08oooool2o`0005[ooooo00Co0000o`@0
0?l4003o00001OmM00X9o`0001gooooo00?o0000ok7[n?najoP00onajoP3o`0000;o/N_h00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Cooooo`00:_ooool2o`0002Kooooo0ol0001Eoooo
o`;o00000_l400000ol0003oG@0:o`000006o`0000CoYD1800?o0000oj=CKOnSDfd00ol0000?oooo
o`_o00001OnajoP2o`0000Go/N_h00?o0000ooooooooool0=Oooool2o`0001?ooooo000Zooooo`03
o`000?oooooooooo02Sooooo0_l0001Aooooo`So00000omX01T00ol0003oYD18ojE0B004ojE0B003
o`000?nSDfgoXe=]00CoXe=]0ol00007ooooo`Go000000?o=P00o`000?l000000_l00002oi0F4`?o
00001OnajoP00ol0003o/N_ho`000005ok7[n0?o0000=oooool00ol0003oooooooooo`0@ooooo`00
:_ooool00ol0003oooooooooo`0Zooooo`?o0000BOooool7o`0000;oH`0D00?o0000ofP06OmX01T0
0omX01T00ol0003oYD18ojE0B005ojE0B003o`000?nSDfgoXe=]00GoXe=]00?o0000ohHiI_l00000
1Oooool2o`0000;o=P001?l00003oi0F4`;o00000onajoP2o`000003ok7[n?l0003o000000;o/N_h
00Co0000ok7[n?najoSo/N_h0_l00003ok7[n0;o0000=_ooool00ol0003oooooooooo`0?ooooo`00
4?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00006ooooo`03o`00
0?oooooooooo02gooooo0_l00012ooooo`Go00000_mO00d00ol0003oH`0Dof<05003of<05003o`00
0?mX01WoJ00I00?oJ00I00?o0000ojE0B?nU@4P01OnU@4P00ol0003oXe=]oj=CK@05oj=CK@04o`00
0?n6>FKoQSUVohHiIP[o00001?n@5Q<2o`0000Ko/N_h0ol00003ok7[n004o`000?najoSo0000o`00
00Ko/N_h0ol0000eooooo`;o00003oooool000oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00oooool3o`0002oooooo0ol0
000mooooo`?o00001OmO00d00ol0003oH`0Dof<05003of<05003o`000?mX01WoJ00I00Go00001onU
@4P00ol0003oXe=]oj=CK@05oj=CK@03o`000?n6>FKoQSUV00;oQSUV00?o0000ojDH0?l000000_l0
0002o`1kbP03o`000?n@5Q?oT1HC00;oT1HC00?o0000ok7[n?najoP01?najoP2o`0000?o/N_h0_l0
00000onajoSo0000o`000007ok7[n004o`000?najoSo/N_hok7[n0;o0000=Oooool00ol0003ooooo
ooooo`0<ooooo`002?ooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<_ooool2o`0003[o
oooo00?o0000o`D00?l000001OmO00d00ol0003oH`0Dof<05007o`0000?oXeA^00?o0000ohU4M?l0
00000_l00003ojE0B003o`000?nSDfgoXe=]00GoXe=]00?o0000ohHiI_n6>FH01?n6>FH01?l0003o
YAP0ojDH0?nU6004o`000003oi0F4ol0003o000000Go/N_h0_l00006ok7[n0?o00001_najoP2o`00
00Go/N_h0ol0000dooooo`03o`000?oooooooooo00_ooooo000?ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Cooooo0_l0000fooooo`;o000000Co1@00o`000?mO00goG`0=1ol00003ojE1BP03o`000?nS
E6koXeA^00CoXeA^00?o0000ohU4M?n9A7@00_n9A7@2o`000003ojE0B?l0003oXe=]00KoXe=]00?o
0000ohHiI_n6>FH01On6>FH00ol0003oYAP0o`000003okmD?`?o00001OnajoP00ol0003o/N_hok7[
n004ok7[n0;o00000_najoP2o`0000?o/N_h0_l00005ok7[n0;o00000onajoP00ol0003ooooooooo
o`0^ooooo`Go00003?ooool000oooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
ool0003ooooo00Co00001_ooool2o`0003Oooooo0ol0000`ooooo`Wo00000_mX01P00ol0003oYD5:
ojE1BP04ojE1BP03o`000?nSE6koXeA^00CoXeA^00?o0000ohU4M?n9A7@01On9A7@2o`0000OoXe=]
00?o0000ohHiI_n6>FH01On6>FH3o`000003okmD?ol0003o000000?o/Nch0_l000000onajoSo0000
o`000005ok7[n0;o00001?najoP01Ol0003o/N_ho`000?najoSo000000Go/N_h0_l00005ok7[n0?o
00009_ooool8o`0000Cooooo00?o0000ooooooooool02_ooool000oooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000Wooooo00?o0000ooooooooool0>Oooool2
o`0002Wooooo1ol00002of<05003o`000?mX01SoJ00H00?oJ00H00?o0000ojE1B_nU@DX01OnU@DX0
0ol0003oXeA^oj=DKP04oj=DKP03o`000?n9A7CoRDAd00GoRDAd00?o0000oh4`GOl000000_l00003
oj=CK@03o`000?n6>FKoQSUV00GoQSUV00?o0000ohlE4on?5A<00_l00006ok7/n0?o00001OnajoP0
0ol0003o/N_hok7[n004ok7[n003o`000?najoSo000000;o00001?najoP00ol0003o/N_hok7[n004
ok7[n004o`000?m/f[[oK=ZjofcJ^P;o00007?ooool8o`0000cooooo00?o0000ooooooooool02_oo
ool0013ooooo0_l0000:ooooo`;o00000_ooool5o`0000Gooooo00?o0000ooooooooool0>oooool3
o`00027ooooo1Ol00002oel03P03o`000?mS01CoH`0D00?oH`0D00?o0000ofP06?mX01P00omX01P0
0ol0003oYD5:ojE1BP05ojE1BP03o`000?nSE6koXeA^00GoXeA^00?o0000ohU4M?n9A7@01?n9A7@0
0ol0003oPC1Moh4`G@03oh4`G@;o000000?oXe=]o`000?n6>FH01On6>FH01?l0003oSaDCo`000?l0
0007ok7/n004o`000?najoSo/N_hok7[n0;o000000?o/N_ho`000?l000001onajoP2o`0000?o/N_h
00Co0000ok7[n?l0003o00001OnajoP2o`0000CoK=Zj0ol0000Cooooo`So00005?ooool00ol0003o
ooooooooo`0:ooooo`00:_ooool00ol0003oooooooooo`0nooooo`;o00007Oooool3o`0000GoG`0>
00?o0000of<05?mS01@00omS01@00ol0003oJ00HofP06005o`0000OoYD5:00?o0000oj=DK_nSE6h0
1?nSE6h00ol0003oRDAdohU4M005ohU4M003o`000?n1<5goPC1M00GoPC1M2ol00006ok7/n0;o0000
1OnajoP3o`0000Go/N_h1?l00004ok7[n0?o00001?najoP2o`000003ofcJ^_l0003o000000Go0000
00?o2000o`000?l000002Oooool8o`0001cooooo00?o0000ooooooooool02_ooool002Wooooo0ol0
0011ooooo`?o00006?ooool2o`000003o`P00?l0003oG`0>00CoG`0>00?o0000of<05?mS01@01ol0
0003oj=DKP03o`000?n8A7Co000000;o00000onU@DX00ol0003oXeA^oj=DKP05oj=DKP03o`000?n9
A7CoRDAd00CoRDAd00?o0000oh4`GOn1<5d01_n1<5d00ol0003oJ00NofP07P03ofP07P;o00000ona
k?P01?l0003o/Nchok7/n?nak?P2o`0000Ko/N_h00Co0000ok7[n?najoSo/N_h0_l000000onajoSo
0000o`000003ok7[n003o`000?najoSo/N_h00;o00000on`k?P2o`000003ok7[n?l0003o000000;o
00001?m]V>T00ol0003o4XoUoa:?i@0<o`0002Cooooo00?o0000ooooooooool02_ooool002[ooooo
00?o0000ooooooooool0@oooool2o`0001Cooooo0_l00002o`P00003o`000?mO00koG`0>00Oo0000
0onV@d`00ol0003oXeA^oj=DKP04oj=DKP03o`000?n8A7CoR4Ad00;oR4Ad0_l000000onU@D[o0000
oj=DKP06oj=DKP03o`000?n9A7CoRDAd00CoRDAd00?o0000oh4`GOn1<5d01On1<5d00ol0003oJ00N
ofP07P02ofP07P;o00001_nak?P00ol0003o/Ncho`000006ok7[n0;o00001OnajoP3o`0000Co/N_h
0ol00006ok3/n0?o00001_m]V>T5o`0000;o4XoU0_l000000onA0P3o0000o`000002o`0002Kooooo
00?o0000ooooooooool02_ooool002[ooooo00?o0000ooooooooool0AOooool3o`0000oooooo2Ol0
0002ofP06@03o`000?nV@dcoYT=<00CoYT=<00?o0000oj=DK_nSE6h01?nSE6h00ol0003oR4AdohQ4
M005ohQ4M0;o00001_nSE6h00ol0003oRDAdohU4M005ohU4M003o`000?n1<5goPC1M00CoPC1M00?o
0000ofP07_mX01h00_mX01h00ol0003o/Nchok7/n006ok7/n0?o00001?najoP2o`0000Ko/N_h00Co
0000ok7[n?najoSo/N_h0_l000000onajoSo0000o`000006ok3/n0;o00000_nGZN800ol0003oKISY
offHj@04o`0000;oX[GV00?o0000oh6=e_n1SMH01Ol00004oi4200?o00008oooool00ol0003ooooo
ooooo`0:ooooo`00:Oooool00ol0003oooooooooo`19ooooo`;o00002Oooool6o`0000;oH`0E00?o
0000ofP06OmX01T00omX01T00ol0003oYT=<ojI3C005ojI3C003o`000?nSE6koXeA^00CoXeA^00?o
0000ohQ4M?n8A7@01On8A7@01?l0003oP2mLo`000?l00004oj=DKP03o`000?n9A7CoRDAd00CoRDAd
00?o0000oh4`GOn1<5d01?n1<5d00ol0003oJ00NofP07P03o`0000Oo/Nch0_l00003ok7[n0;o0000
00?o/N_ho`000?najoP01OnajoP2o`0000Go/N_h1?l00003ok3/n0?o00000onGZN84o`0000KoX[GV
00?o0000oh6=e_n1SMH01?n1SMH4o`000004oi420?l0003o`4lcol1?<`?o00008?ooool00ol0003o
ooooooooo`0:ooooo`00:Oooool2o`0004cooooo0ol000000ooooooo0000o`000003o`000003of00
3ol0003oH`0E00CoH`0E00?o0000ofP06OmX01T00omX01T00ol0003oYT=<ojI3C005ojI3C003o`00
0?nSE6koXeA^00GoXeA^00?o0000ohQ4M?n8A7@01?n8A7@00ol0003oP2mLoh0_G002oh0_G005o`00
0?nSE6koXeA^oj=DK_l000001_n9A7@00ol0003oPC1Moh4`G@09o`0000Go/Nch0ol00006ok7[n0?o
00001?najoP2o`0000Ko/N_h00Ko0000og3M__m`gKkoL=fno`000?n`k?P2o`0000;oUjWR1?l00002
oi;LoP03o`000?nR]NKoX[GV00KoX[GV00?o0000oh6=e_n1SMH01_n1SMH3o`0000Go`4lc0ol0000M
ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo04cooooo1?l00004of00
3`03o`000?mS01GoH`0E00?oH`0E00?o0000ofP06OmX01T01Ol00007ojI3C003o`000?nSE6koXeA^
00CoXeA^00?o0000ohQ4M?n8A7@01On8A7@00ol0003oP2mLoh0_G003oh0_G0?o00000on9A7@7o`00
00?oI@0H00?o0000of@05_l000000onak?P2o`000003ok7/n?l0003o000000Oo/N_h0_l00003ok7[
n0;o000000?o/N_ho`000?najoP01OnajoP2o`000003og3M__l0003o000000?o000000Co2XoNo`00
0?l0003o00001onBg?h00ol0003oX[GVoj:eiP05oj:eiP03o`000?n1SMKoPHgF00GoPHgF0_l00002
oaT05@03o`000?o0Cc?o`4lc00Go`4lc00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:
ooooo`00:Oooool00ol0003oooooooooo`1:ooooo`;o00000_l<00000ol0003oH00?of003`02of00
3`03o`000?mS01GoH`0E00Oo00000onSE6l00ol0003oR4=co`000002o`0000?oYT=<00?o0000oj=D
K_nSE6h01OnSE6h00ol0003oR4AdohQ4M004ohQ4M003o`000?n0;ecoP2mL00KoP2mL1?l00002ofP0
7P03o`000?mU01SoI@0H00CoI@0H0ol00005ok7/n0?o00001OnajoP3o`0000Ko/N_h0ol00004ok7[
n0oo00001_nBg?h00ol0003oX[GVoj:eiP05oj:eiP03o`000?n1SMKoPHgF00CoPHgF2?l00005ol1?
<`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool002Wooooo0_l00018ooooo`?o
00000ol<00000ol0003oH00?o`000006o`0000?oYTA>00?o0000oj=DKonSE6l01?nSE6l00ol0003o
R4=cohQ3L`02ohQ3L`;o000000?oYT=<o`000?nSE6h01_nSE6h00ol0003oR4AdohQ4M004ohQ4M003
o`000?n0;ecoP2mL00GoP2mL00?o0000ofP07_mX01h00omX01h00ol0003oI@0HofD06004ofD060;o
00001_nak?P01?l0003o/N_hok7[n?najoP2o`000003ok7[n?l0003o000000Oo/N_h0_l00003ok3/
n0;o000000Go/N_ho`000?nKX][oVj;Jo`000005oi^RfP[o00001?nBg?h00ol0003oX[GVoj:eiP05
oj:eiP03o`000?n1SMKoPHgF00;oPHgF2_l00003ol1?<`03o`000?nOAE[o000001cooooo00?o0000
ooooooooool02Oooool002Wooooo00?o0000ooooooooool0A?ooool;o`0000;oJ00J00?o0000ojI4
C_nVA4h01?nVA4h00ol0003oXeA_oj=DK`04oj=DK`03o`000?n8@g?oR4=c00GoR4=c0_l00006oj=D
KP03o`000?n8A7CoR4Ad00GoR4Ad00?o0000oh0_G?n0;e`01?n0;e`00ol0003oJ00NofP07P03ofP0
7P03o`000?mU01SoI@0H00Go00001_nak?P2o`0000Go/N_h0ol00005ok7[n0?o00001_n`k?P2o`00
00?oVj;J00?o0000oi^Rf_nKX]X00onKX]X00ol0003oVj;Jo`000003oiZRfPWo00001onR]NH01Ol0
003oPHgFoh6=e_n1SMKo000000;oR8O<1_l000001_l3R=_o0000o`000?l0003o`4lco`0000;oWdEJ
00?o0000ooooooooool06Oooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003ooooooooo
o`11ooooo`?o000000?oH00?o`000?mS01H00omS01H00ol0003oJ00JofP06P03ofP06P03o`000?nV
A4koYTA>00GoYTA>00?o0000oj=DKonSE6l01?nSE6l00ol0003oR4=cohQ3L`05ohQ3L`04o`000?n0
;U_o0000o`0000CoXeA^00?o0000ohQ4M?n8A7@01?n8A7@00ol0003oP2mLoh0_G004oh0_G003o`00
0?mX01koJ00N00Oo00000_mR01@3o`0000Co/Nch0_l00006ok7[n004o`000?najoSo/N_hok7[n0;o
000000?o/N_ho`000?l000001on`k?P2o`0000KoVj;J00?o0000oi^Rf_nKX]X00onKX]X2o`0000Co
VZ;J2ol00004oj:eiP04o`000?n1SMKoPHgFo`0000CoR8O<00?o0000ofabaol000001ol00004oim5
FP03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool002;ooooo0_l00005ooooo`03
o`000?oooooooooo03kooooo0ol00003of003`03o`000?mS01KoH`0F00;oH`0F00?o0000ofP06_mX
01X00omX01X00ol0003oYTA>ojI4CP05ojI4CP03o`000?nSE6ooXeA_00GoXeA_00?o0000ohQ3Lon8
@g<01?n8@g<00ol0003oP2iKoh0^F`02oh0^F`05o`000?nSE6koXeA^oj=DK_l000001_n8A7@00ol0
003oP2mLoh0_G007o`0000?oH`0F00Co0000of805?mR01CoHP0D0_l00003ok7/n0;o000000?o/Nch
o`000?najoP01OnajoP2o`0000Go/N_h0ol00005ok3/n0?o000000?oVj;Jo`000?nKX]X01OnKX]X0
0ol0003oVj;Joi^RfP02oi^RfPOo00000onJX=P00ol0003oVY;;oiZBb`04oiZBb`Go000000?oX[GV
o`000?l000001On8Ql`00ol0003oK7;7ofaba`02ofaba`?o000000Co08GJo`000?l0003o00000onO
AEX00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo000Qooooo`04o`000?oooooo
ooooo`0000Cooooo0ol0000kooooo`?o00001OmP00l00ol0003oH`0Fof<05P02of<05P03o`000?mX
01[oJ00J00Go00001onVA4h00ol0003oXeA_oj=DK`04oj=DK`03o`000?n8@g?oR4=c00GoR4=c00?o
0000oh0^Fon0;U/00on0;U/3o`0000?oR4Ad1ol00003ofD06003o`000?mS01KoH`0F00?oH`0F00?o
0000of805?l000000_l00006ok7/n0?o00001?najoP2o`0000Ko/N_h00Co0000og7N_omag[ooLMjo
0_l000000on`k?So0000o`000004oi^RfP03o`000?nKX][oVj;J00;oVj;J1ol000001?nJXMWo0000
oiZQfOl00006oiZPf003o`000?nJT/_oVY;;00CoVY;;00?o0000ohQo`on8Ol<00_n8Ol<3o`0000Ko
R8O<00?o0000ofabaom/L/L00om/L/L6o`0000;oWdEJ00?o0000ooooooooool05oooool00ol0003o
ooooooooo`09ooooo`008Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000;o
0000=oooool2o`000003o`l00?l0003oH00?00CoH00?00?o0000of<05_l000001_l00003oj=EK`04
o`000?n7@W?o0000o`0000GoYTA>00?o0000oj=DKonSE6l01?nSE6l00ol0003oR4=cohQ3L`04ohQ3
L`03o`000?n0;U_oP2iK00KoP2iK1?l00003ofL07P03o`000?mU01SoI@0H00?oI@0H00?o0000of<0
5_mS01H00omS01H3o`0000Oo/Nch0_l00003ok7[n0;o000000?o/N_ho`000?najoP01OnajoP2o`00
00;oLMjo1Ol00004oi^RfPOo00000onKX]X00ol0003oVZ7IoiZQf@02oiZQf@04o`000?nJXMWoVZ7I
o`0000KoVZ3H00?o0000oiZBbonJT//01?nJT//00ol0003oR7o3ohQo``03ohQo``;o00001On8Ql`0
0ol0003oK7;7ofaba`04ofaba`03o`000?lWHmKo000000Co000000?oWdEJo`000?ooool05oooool0
0ol0003oooooooooo`09ooooo`008Oooool01?l0003oooooooooool00004ooooo`04o`000?oooooo
ooooooooo`Co0000<_ooool2o`0000;o3`0000?o0000of003omP00l01_l00003ojM6D003o`000?nS
EFooXeE_00?oXeE_00?o0000ohM2Lon7@W<00_n7@W<01Ol0003oYTA>ojI4C_nVA4ko000000OoXeA_
00?o0000ohQ3Lon8@g<01?n8@g<00ol0003oP2iKoh0^F`05oh0^F`03o`000?mW01koI`0N00CoI`0N
00?o0000ofD06?mU01P00omU01P00ol0003oH`0Fof<05P03of<05P?o00001_nak?P2o`0000Ko/N_h
0ol00004ok7[n0oo00000onKX]X00ol0003oVj;Joi^RfP05oi^RfP05o`000?nJXMWoVZ7IoiZQfOl0
00000_nJXMT00ol0003oVZ3HoiZPf004oiZPf003o`000?nJT/_oVY;;00CoVY;;00?o0000ohQo`on8
Ol<00on8Ol<00ol0003oPH;;o`000002o`0000;oR8O<00?o0000ofabaom/L/L01?m/L/L00ol0003o
9f?FobMSeP02obMSeP?o000000?oWdEJo`000?ooool05_ooool00ol0003oooooooooo`09ooooo`00
8Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo1Ol0000/ooooo`[o
00000_mX01X00ol0003oYdI@ojM6D003ojM6D003o`000?nSEFooXeE_00CoXeE_00?o0000ohM2Lon7
@W<00on7@W<2o`000003ojI4C_l0003oXeA_00GoXeA_00?o0000ohQ3Lon8@g<01On8@g<00ol0003o
P2iKoh0^F`04oh0^F`03o`000?mW01koI`0N00CoI`0N00?o0000ofD06?mU01P00omU01P00ol0003o
H`0Fof<05P04o`0000?o/Nch0ol000000onak?So0000o`000006ok7[n0;o00000onak?P2o`000003
ok7[n?l0003o000000?oVj?J00?o0000oi^Rf_nKX]X01?nKX]X00ol0003oVj;Joi^RfP05oi^RfP03
o`000?nKX][oVj;J00CoVj;J00Go0000oiZQfOnJXMWoVZ7Io`000002oiZQf@03o`000?nJX=SoVZ3H
00CoVZ3H00?o0000oiZBbonJT//01?nJT//00ol0003oR7o3ohQo``03ohQo``03o`000?n1P/_oPH;;
00;oPH;;1?l00003ofaba`Ko00000_lWHmH5o`0001Kooooo00?o0000ooooooooool02Oooool0027o
oooo00Co0000oooooooooooo00001?ooool2o`0000Oooooo1_l0000Pooooo`_o000000?oI00Fo`00
0?mX01X01OmX01X00ol0003oYdI@ojM6D004ojM6D003o`000?nSEFooXeE_00CoXeE_00?o0000ohM2
Lon7@W<01On7@W<2o`0000KoXeA_00?o0000ohQ3Lon8@g<01?n8@g<00ol0003oP2iKoh0^F`04oh0^
F`03o`000?mW01koI`0N00CoI`0N00?o0000ofD06?mU01P01ol000000omR01?o0000o`000006ok7/
n0?o00001OnajoP2o`0000Ko/Nch0_l00006oi^SfP03o`000?nKX][oVj;J00CoVj;J00?o0000oi^R
f_nKX]X01?nKX]X00ol0003oVj;Joi^RfP05oi^RfP04o`000?nJXMWoVZ7Io`0000?oVZ7I00?o0000
oiZPf?nJX=P00onJX=P00ol0003oVY;;oiZBb`04oiZBb`03o`000?n8Ol?oR7o300CoR7o300?o0000
oh62bon1P//01?n1P//4o`0000?oUioI00?o0000ogfAg?mmTM`02Ol0000Dooooo`03o`000?oooooo
oooo00Wooooo000Rooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`Ko00007?ooool2o`00
00GoH00?00?o0000of@05_mT01H00_mT01H00ol0003oJ00JofP06P04ofP06P03o`000?nWAU3oYdI@
00CoYdI@00?o0000oj=EKonSEFl01?nSEFl00ol0003oQd9cohM2L`06ohM2L`03o`000?mo;U_o0000
00;o00000onSE6l00ol0003oR4=cohQ3L`04ohQ3L`03o`000?n0;U_oP2iK00ko00000_mR01D01?l0
003oHP0Cof804omR01<2o`0000Ko/Nch0_l00003ok7[n0;o000000?o/N_ho`000?l000001_nak?P2
o`0000;oVj?J00?o0000oi^Sf_nKXmX00onKXmX00ol0003oVj;Joi^RfP04oi^RfP03o`000?nKX][o
Vj;J00GoVj;J00?o0000oi^Rf_nKX]X01?nKX]X01?l0003oVZ7IoiZQfOl00003oiZQf@03o`000?nJ
X=SoVZ3H00CoVZ3H00?o0000oiZBbonJT//00onJT//00ol0003oR7o3ohQo``04ohQo``03o`000?n1
P/_oPH;;00CoPH;;00?o0000oiNOfOnGWmT01OnGWmT00ol0003oOI7LogfAg003ogfAg0Ko00004ooo
ool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`Ko00005oooool3
o`0000GoH00?00?o0000of@05_mT01H00_mT01H00ol0003oJ00JofP06P04ofP06P03o`000?nWAU3o
YdI@00GoYdI@00?o0000oj=EKonSEFl01?nSEFl00ol0003oQd9cohM2L`05ohM2L`03o`000?mo;U_o
ObiK00?oObiK0ol00003ohQ3L`Oo00000_mU01T00ol0003oH`0Gof<05`04of<05`03o`000?mR01Go
HP0E00?oHP0E00Go0000of804omR01?oHP0Co`000006ok7/n0;o00001_najoP3o`0000Go/Nch0_l0
0004oi^SfP03o`000?nKXm[oVj?J00?oVj?J00?o0000oi^Rf_nKX]X01OnKX]X00ol0003oVj;Joi^R
fP04oi^RfP03o`000?nKX][oVj;J00CoVj;J00Co0000oiZQfOnJXMWo00000onJXMT00ol0003oVZ3H
oiZPf004oiZPf003o`000?nJT/_oVY;;00CoVY;;00?o0000ohQo`on8Ol<00on8Ol<00ol0003oPH;;
oh62b`04oh62b`03o`000?nGWmWoUioI00GoUioI00?o0000ogfAg?mmTM`01?mmTM`00ol0003oHYW^
o`000003o`0001;ooooo00?o0000ooooooooool02Oooool002Wooooo00?o0000ooooooooool03_oo
ool6o`0001Cooooo00?o0000oa400?l000001OmP00l00ol0003oI00Fo`00000;o`0000OoYdI@00?o
0000oj=EKonSEFl00onSEFl00ol0003oQd9cohM2L`05ohM2L`03o`000?mo;U_oObiK00KoObiK1?l0
0002ofL07P03o`000?mU01WoI@0I00?oI@0I00?o0000of<05omS01L01?mS01L00ol0003oHP0Eof80
5@03of805@03o`000?mR01?oHP0C00?o00001Onak?P00ol0003o/N_hok7[n004ok7[n0;o00000omc
g[l2o`000003ok7/n?l0003o000000OoVj?J00?o0000oi^Sf_nKXmX00onKXmX00ol0003oVj;Joi^R
fP04oi^RfP03o`000?nKX][oVj;J00CoVj;J00?o0000oi^Rf_nKX]X00_nKX]X<o`0000CoVZ3H00?o
0000oiZBbonJT//01?nJT//00ol0003oR7o3ohQo``04ohQo``03o`000?n1P/_oPH;;00CoPH;;00?o
0000oiNOfOnGWmT01?nGWmT00ol0003oOI7LogfAg005ogfAg004o`000?mRVNkoHYW^of:IkP;o0000
4Oooool00ol0003oooooooooo`09ooooo`00:Oooool2o`0000oooooo0_l00002odF8jPGo00003_oo
ool3o`000004oa400?l0003oH00?of003`Ko00000onWAe400ol0003oXeE_oj=EK`04oj=EK`03o`00
0?n7@G;o000000;o00000onWAU000ol0003oXeE_oj=EK`04oj=EK`03o`000?n7@W?oQd9c00GoQd9c
00?o0000ogl^Fomo;U/01Omo;U/00ol0003oI`0NofL07P03ofL07P03o`000?mU01WoI@0I00?oI@0I
00?o0000of<05omS01L01?mS01L00ol0003oHP0Eof805@07o`0000?o/N_h0_l000000onak?So0000
o`000005ok7[n0;o00000omcg[l5o`0000;oVjCK00?o0000oi^Sf_nKXmX01?nKXmX00ol0003oVj?J
oi^SfP03oi^SfP03o`000?nKX][oVj;J00CoVj;J00?o0000oi^Rf_nKX]X00_nKX]X7o`0000?oVZ3I
00?o0000oiZBbol000001?nJT//00ol0003oR7o3o`000002o`000003oiZPf?l0003oVY;;00GoVY;;
00?o0000ohQo`on8Ol<01?n8Ol<00ol0003oPH;;oh62b`04oh62b`03o`000?nGWmWoUioI00GoUioI
00?o0000ogfAg?mmTM`01?mmTM`00ol0003oHYW^of:IkP03of:IkP?o00003_ooool00ol0003ooooo
ooooo`09ooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o00001?m5R>X5o`0000Gooooo3Ol0
0002ofX06@03o`000?nWAe7oYdMA00?oYdMA00?o0000oj=EKonSEFl01?nSEFl00ol0003oQd5bohM1
LP03ohM1LP;o000000?oYdI@o`000?nSEFl01OnSEFl00ol0003oQd9cohM2L`04ohM2L`03o`000?mo
;U_oObiK00GoObiK00?o0000ofL07_mW01h00omW01h00ol0003oI@0IofD06@03ofD06@03o`000?mS
01OoH`0G00So00000omP0182o`0000Ko/N_h1Ol00002ok7[n0So00001_nKY=/00ol0003oVj?Joi^S
fP04oi^SfP03o`000?nKXm[oVj?J00?oVj?J00?o0000oi^Rf_nKX]X00_nKX]X7o`0000?oVZ7I00?o
0000oiZPfOnJX=T01?nJX=T00ol0003oVY;;o`000004oiZBb`03o`000?n8Ol?oR7o300;oR7o30ol0
0005oiZBb`03o`000?n8Ol?oR7o300CoR7o300?o0000oh62bon1P//01?n1P//00ol0003oUioIoiNO
f@05oiNOf@03o`000?mmTMcoOI7L00CoOI7L00?o0000of:Ik_mRVNh00_mRVNh5o`0000gooooo00?o
0000ooooooooool02Oooool002Wooooo00?o0000ooooooooool03oooool3o`0000CoAHSZ0_l00000
0om>S>_o0000o`000006o`0000GoSPX000?o0000ofX06OmZ01T01?mZ01T00ol0003oYdMAojM7D@04
ojM7D@03o`000?nSEFooXeE_00CoXeE_00?o0000ohM1L_n7@G801On7@G82o`0000GoXeE_00?o0000
ohM2Lon7@W<01On7@W<00ol0003oObiKogl^F`04ogl^F`03o`000?mW01koI`0N00?oI`0N00?o0000
ofD06OmU01T01ol00003of805003o`000?mP01;oH00B00?oH00B0_l00006ok7[n0;o00001OnakOL4
o`0000KoWJGL00?o0000oi^TfonKY=/00onKY=/00ol0003oVj?Joi^SfP02oi^SfPgo00000onKX]X0
0ol0003oVZ7IoiZQf@05oiZQf@03o`000?nJX=WoVZ3I00CoVZ3I0_l00005oiZBb`03o`000?n8Ol?o
R7o300?oR7o30_l00004oiZBb`03o`000?n8Ol?oR7o300CoR7o300?o0000oh62bon1P//01On1P//0
0ol0003oUioIoiNOf@04oiNOf@03o`000?mmTMcoOI7L00;oOI7L1ol00005oiBfkP03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool002Wooooo00?o0000ooooooooool04?ooool00ol0
003o34O5o`000004odF8jP;o00000om>S>/4o`0000GoSPX000?o0000ofX06OmZ01T01?mZ01T00ol0
003oYdMAojM7D@04ojM7D@03o`000?nSEFooXeE_00GoXeE_00?o0000ohM1L_n7@G801On7@G801?l0
003oObeJo`000?l00003oj=EK`03o`000?n7@W?oQd9c00CoQd9c00?o0000ogl^Fomo;U/01?mo;U/0
0ol0003oI`0NofL07P07o`0000?oHP0F00?o0000of805?mR01@00omR01@00ol0003oH00Bof004P02
of004P?o00001OnajoP2o`0000Ko/Ngg00Go0000ol7Ai_o1dNKo`M7Vo`000006oifUg004o`000?nK
Y=_oVjCKoi^Tf`Oo00000onKX]X00ol0003oVj;Joi^RfP03oi^RfP03o`000?nKX][oVj;J00GoVj;J
00?o0000oiZQfOnJXMT01?nJXMT00ol0003oVZ3IoiZPf@04oiZPf@;o00001OnJT//00ol0003oR7o3
ohQo``03ohQo``03o`000?n1P/_o000000;o00000_nJT//00ol0003oR7o3ohQo``04ohQo``04o`00
0?n1P/_oPH;;oh62b`oo00000onJXm/00ol0003oU;K^oiBfkP06oiBfkPCo00002Oooool00ol0003o
ooooooooo`09ooooo`00:?ooool00ol0003oooooooooo`0Booooo`03o`000?l<AlGo000000?oAHSZ
0ol00004odj<j`Go000000?oSPX0o`000?mZ01T01OmZ01T00ol0003oYdMAojM7D@04ojM7D@03o`00
0?nSEFooXeE_00GoXeE_00?o0000ohM1L_n7@G801On7@G800ol0003oObeJogl]FP02ogl]FP;o0000
00CoXeE_o`000?n7@W?oQd9c3_l00003of<05`03o`000?mR01KoHP0F00?oHP0F00?o0000of805?mR
01@00omR01@6o`0000?o/N_h0_l000000onajoSo0000o`000006ok7]m`;o00001?o1dNH00ol0003o
WJGLoifUg002oifUg0Ko00000onKXmX00ol0003oVj;Joi^RfP05oi^RfP03o`000?nKX][oVj;J00?o
Vj;J00?o0000oi^Rf_nKX]X01?nKX]X00ol0003oVZ7IoiZQf@05oiZQf@03o`000?nJX=WoVZ3I00?o
VZ3I0_l00005oiZBb`03o`000?n8Ol?oR7o300?oR7o300?o0000oh62bon1P//00_n1P//3o`0000?o
R7o31ol00003oiZQfP03o`000?nJX][oVZ;J00GoVZ;J00?o0000oiZSfonJXm/01OnJXm/00ol0003o
U;K^oiBfkP02oiBfkP?o00000onajoP2o`0000Sooooo00?o0000ooooooooool02Oooool002Sooooo
00?o0000ooooooooool04_ooool00ol0003o34O5o`a7a@02o`0000;oAHSZ0ol00003odj<j`03o`00
0?m_Q=OoKhCG00_o00001_nWAe400ol0003oXeE_oj=EK`05oj=EK`03o`000?n7@G;oQd5b00GoQd5b
00?o0000ogl]F_mo;EX01?mo;EX4o`0000?oI`0O00?o0000ofD06_mU01X00omU01X00ol0003oH`0G
of<05`04of<05`03o`000?mR01KoHP0F00?oHP0F00?o0000of805?mR01@01Ol00002oeT01@;o0000
1OnajoP3o`0000Go/Ngg3Ol00003oi^Sf`03o`000?nKXm[oVj?J00CoVj?J00?o0000oi^Rf_nKX]X0
1?nKX]X00ol0003oVj;Joi^RfP03oi^RfP03o`000?nKX][oVj;J00GoVj;J00?o0000oiZQfOnJXMT0
1?nJXMT00ol0003oVZ3IoiZPf@04oiZPf@03o`000?nJT/_oVY;;00?oVY;;00?o0000ohQo`on8Ol<0
1?n8Ol<00ol0003oPH;;oh62b`03oh62b`Co00000onIWmT00ol0003oVZ7JoiZQfP05oiZQfP03o`00
0?nJX][oVZ;J00GoVZ;J00?o0000oiZSfonJXm/01OnJXm/01?l0003oU;K^o`000?l00004ok7[n0;o
00000_nbjoP00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo000Xooooo`03o`00
0?oooooooooo01?ooooo00Wo0000o`a7aOl0003o012Ho`000?m5R>[o0000oaE;aol000001?m>S>/0
0ol0003oKhCGofn4e`02ofn4e`Co00000_o3HUH01?l0003oW4m_o`000?l00003ojM7D@03o`000?nS
EFooXeE_00GoXeE_00?o0000ohM1L_n7@G801On7@G800ol0003oObeJogl]FP05ogl]FP03o`000?mW
01ooI`0O00?oI`0O00?o0000ofD06_mU01X00omU01X00ol0003oH`0Gof<05`04of<05`03o`000?mR
01KoHP0F00?oHP0F00?o0000of805?mR01@00_l00004oeT01@;o00001_najoP01?l0003oM>31ogCP
`Omdh<43o`000003ok7]mol0003oW:GL00;oW:GL00?o0000oi^TfonKY=/00onKY=/00ol0003oVj?K
oi^Sf`05oi^Sf`03o`000?nKXm[oVj?J00?oVj?J00?o0000oi^Rf_nKX]X01OnKX]X00ol0003oVj;J
oi^RfP03oi^RfP03o`000?nKX][oVj;J00CoVj;J00?o0000oiZQfOnJXMT01?nJXMT00ol0003oVZ3I
oiZPf@04oiZPf@03o`000?nJT/_oVY;;00?oVY;;00?o0000ohQo`on8Ol<01?n8Ol<00ol0003oPH;;
oh62b`03oh62b`03o`000?nIWmWoVIoI00GoVIoI00?o0000oiZQf_nJXMX01?nJXMX00ol0003oVZ;J
oiZRfP05oiZRfP03o`000?nJXm_oVZ?K00GoVZ?K0ol00004ok7[n003o`000?nbjoSo/^_h00;o/^_h
1?l00004ooooo`03o`000?oooooooooo00Wooooo000Xooooo`;o00005?ooool02_l0003o34O5o`a7
aOl0003o012Ho`000?m5R>[o0000oaE;aol00003odj<j`03o`000?m_Q=OoKhCG00?oKhCG00?o0000
og23eom`PmL00ol00003oia?K`;o000000?oYdMAo`000?nSEFl01_nSEFl00ol0003oQd5bohM1LP04
ohM1LP03o`000?mo;E[oObeJ00GoObeJ00?o0000ofL07omW01l00omW01l00ol0003oI@0JofD06P03
ofD06P03o`000?mS01OoH`0G00CoH`0G00?o0000of805_mR01H02?l00004oeT01@03o`000?najoSo
/N_h00Co/N_h0_l00003ogCP`@Go00001OnLYM`00ol0003oVjCKoi^Tf`03oi^Tf`03o`000?nKXm_o
Vj?K00CoVj?K00?o0000oi^Sf_nKXmX01?nKXmX00ol0003oVj;Joi^RfP04oi^RfP03o`000?nKX][o
Vj;J00CoVj;J00?o0000oi^Rf_nKX]X00onKX]X00ol0003oVZ7IoiZQf@02oiZQf@Go00001?nJX=T0
0ol0003oVY;;oiZBb`04oiZBb`03o`000?n8Ol?oR7o300?oR7o300?o0000oh62bon1P//01?n1P//0
0ol0003oVIoIoiVOf@04oiVOf@03o`000?nJXM[oVZ7J00CoVZ7J00?o0000oiZRf_nJX]X01_nJX]X0
0ol0003oVZ?KoiZSf`02oiZSf`;o00000onaj?P01?l0003o/N_ho`000?l00002ok;[n0?o00000onb
joL2o`0000?ooooo00?o0000ooooooooool02Oooool002Sooooo00?o0000ooooooooool05?ooool2
o`000003o`a7aOl0003o012H00;o00000_lEBlL2o`0000;oCXc[00?o0000ofn4eom_Q=L00om_Q=L0
0ol0003oL8?Gog23e`02og23e`?o00000_nLCfl2o`0000KoXeE_00?o0000ohM1L_n7@G801On7@G80
0ol0003oObeJogl]FP04ogl]FP03o`000?mW01ooI`0O00?oI`0O00?o0000ofD06_mU01X03_l00000
1?mQ01?o0000oel04OmO0143o`0000?oF@050ol00004ok7[n0So00000oo1d>H00ol0003oW:GLoibU
g003oibUg003o`000?nKY=_oVjCK00CoVjCK00?o0000oi^SfonKXm/01?nKXm/00ol0003oVj?Joi^S
fP04oi^SfP03o`000?nKX][oVj;J00?oVj;J00?o0000oi^Rf_nKX]X01?nKX]X01?l0003oVj;Joi^R
f_nKX]X7o`0000?oVY?;00?o0000ohQo`ol000000_l000000onJX=Wo0000oiZBb`05oiZBb`03o`00
0?n8Ol?oR7o300CoR7o300?o0000oh62bon1P//00on1P//00ol0003oVIoIoiVOf@04oiVOf@03o`00
0?nJXM[oVZ7J00GoVZ7J00?o0000oiZRf_nJX]X01OnJX]X01Ol0003oVZ?KoiZSfonJXm_o000000Go
/NSh0ol000000onbjoSo0000o`000004ok;[m`;o00000_nbjoP01?l0003oooooooooool0000;oooo
o`00:?ooool00ol0003oooooooooo`0Fooooo`?o000000Wo012Ho`000?l0003o5D_7o`000?l06J;o
0000odj<jol000001Om_Q=L00ol0003oL8?Gog23e`03og23e`03o`000?m_Q=Oo000000;o000000Co
P2eIo`000?l0003o00000onSEFl00ol0003oQd5bohM1LP04ohM1LP03o`000?mo;E[oObeJ00CoObeJ
00?o0000ofL07omW01l01ol00002of<05P03o`000?mR01CoHP0D00?oHP0D00?o0000of404omQ01<0
0omQ01<01_l0003oG`0Aoel04Ol0003o:;?7o`0000;oF@050_l00003ok3/n0;o000000Co/N_ho`00
0?l0003o00000onBaOT00ol0003o`M3Vol7@iP03ol7@iP03o`000?nLYMcoW:GL00CoW:GL00?o0000
oi^TfonKY=/00onKY=/00ol0003oVj?Koi^Sf`04oi^Sf`03o`000?nKXm[oVj?J00CoVj?J00Co0000
oi^Rf_nKX][oVj;J3Ol00003oiZPf@03o`000?nJTl_oVY?;00CoVY?;00?o0000ohQo`on8Ol<00_n8
Ol<3o`0000GoVY;;00?o0000ohQo`on8Ol<01?n8Ol<00ol0003oPH;;oh62b`04oh62b`03o`000?nI
WmWoVIoI00CoVIoI00?o0000oiZQf_nJXMX01?nJXMX00ol0003oVZ;JoiZRfP05oiZRfP04o`000?nJ
Xm_o0000o`0000Co/NSh0_l00002ok;[n0;o00001?nbjoL2o`0000Co/^_h1?l0000;ooooo`003ooo
ool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oo
oooooooo01Sooooo0_l000002Ol049So0000oaE;aolEBlOo0000o`0IX_l0003oCXc[o`000005ofn4
e`03o`000?m`PmOoL8?G00?oL8?G00Co0000ofn4eom_Q=OoKhCG0_l00002oh0]F@;o000000?oXeE_
o`000?n7@G801On7@G800ol0003oObeJogl]FP07o`0000;oI00G00?o0000of<05_mS01H00omS01H0
0ol0003oHP0Dof805003of805003o`000?mQ01?oH@0C00?oH@0C00?o0000oel04Ol000001_l00006
ok3/n0;o00000onKYM`00ol0003oT/Gio`000007ol7@iP03o`000?nLYMcoW:GL00?oW:GL00?o0000
oi^TfonKY=/01?nKY=/00ol0003oVj?Koi^Sf`03oi^Sf`03o`000?nKXm[oVj?J00;oVj?J1_l00003
oiZRfP03o`000?nJXM[oVZ7J00CoVZ7J00?o0000oiZPfOnJX=T01?nJX=T00ol0003oVY?;oiZCb`04
oiZCb`03o`000?n8Ol?oR7o300;oR7o30ol00004oiZBb`03o`000?n8Ol?oR7o300CoR7o300?o0000
oh62bon1P//01?n1P//00ol0003oVIoIoiVOf@04oiVOf@03o`000?nJXM[oVZ7J00CoVZ7J00?o0000
oiZRf_nJX]X00_nJX]X5o`0000Co/NSh0_l00002ok;[n0;o00000_nbjoP01?l0003o/^_go`000?l0
0003ok;[n0?o00000_najoP2o`0000_ooooo000>ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Jooooo`Co
000000?o5D_7o`000?l06J800_l00005ofn4e`03o`000?m`PmOoL8?G00?oL8?G00?o0000ofn4eom_
Q=L00om_Q=L3o`000003oh0]FOl0003o000000Wo00000_mU01T00ol0003oI00Gof@05`03of@05`03
o`000?mS01KoH`0F00?oH`0F00?o0000of805?mR01@00omR01@9o`0000?oG00:0_l00006ok3/n0;o
00001OnKYM`3o`0000Oo`M3V00?o0000oibUg?nLYM`00onLYM`00ol0003oVjCKoi^Tf`02oi^Tf`go
00000onJX]X00ol0003oVZ;JoiZRfP04oiZRfP03o`000?nJXM[oVZ7J00CoVZ7J00?o0000oiZPfOnJ
X=T00onJX=T00ol0003oVY?;oiZCb`04oiZCb`03o`000?n8Ol?oR7o300;oR7o30_l000001_n1P/_o
0000o`000?l0003oVY;;o`0000KoR7o300?o0000oh62bon1P//01?n1P//00ol0003oVIoIoiVOf@04
oiVOf@03o`000?nJXM[oVZ7J00;oVZ7J1ol00005oiNgkP04o`000?naj?So0000o`0000?o/^_h00?o
0000ok;[n?nbjoP00_nbjoP4o`000003ok;[n?l0003o000000?o/N_h0_l00002ooooo`03o`000?oo
oooooooo00Sooooo000>ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo1?l000000ol06J;o0000
o`000005ofn4e`03o`000?m`PmOoL8?G00?oL8?G00?o0000ofn4eom_Q=L00_m_Q=L00ol0003oCXc[
odj<j`04o`0000?oI`0N00?o0000ofD06OmU01T00omU01T00ol0003oI00Gof@05`03of@05`03o`00
0?mS01KoH`0F00?oH`0F00?o0000of805?mR01@01Ol00003oeT01003o`000?mL00[oG00:00?oG00:
0ol00005ok3/n0?o00001OnKYM`01?l0003o]__WokKkionfnnL2o`0000Go`M3V00Co0000oibUg?nL
YMcoW:GL1ol00003oi^SfP03o`000?nKX][oVj;J00?oVj;J00?o0000oiZRf_nJX]X01OnJX]X00ol0
003oVZ;JoiZRfP03oiZRfP03o`000?nJXM[oVZ7J00CoVZ7J00?o0000oiZPfOnJX=T00onJX=T00ol0
003oVY?;oiZCb`04oiZCb`Oo00001?n1P//3o`0000KoR7o300Co0000oh62bon1P/_oPH;;3_l00003
oiZSf`03o`000?nG]nkoUkO^00KoUkO^1?l000000onbjoSo0000o`000002ok;[n0?o00000onbjoP2
o`0000Co/N_h00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`003_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Pooooo`;o000000?o01VRo`000?m_Q=L01?m_Q=L00ol0003oL8?Gog23
e`03og23e`03o`000?m_Q=OoKhCG00?oKhCG00?o0000odj<jom>S>/00om>S>/3o`0000GoI@0I00?o
0000of@05omT01L00omT01L00ol0003oH`0Fof<05P08o`0000KoF@0400?o0000oe`02_mL00X00omL
00X01?l0003oMn;4ogORa?mgh/@2o`000003ok3/n?l0003o000000?oVZCL00?o0000oi^Ug?nKYM`0
0_l00003okKki`co00000onKXm/00ol0003oVj?Joi^SfP05oi^SfP03o`000?nKX][oVj;J00?oVj;J
00?o0000oiZRf_nJX]X01?nJX]X00ol0003oVZ;JoiZRfP04oiZRfP03o`000?nJXM[oVZ7J00CoVZ7J
00?o0000oiZPfOnJX=T02_l00006ohQo``;o00001?n1P//;o`0000?oVZ7J00?o0000oiZRf_nJX]X0
1?nJX]X00ol0003oVZ?KoiZSf`05oiZSf`03o`000?nG]nkoUkO^00;oUkO^0ol00003ok;Zn0?o0000
00?o/^_ho`000?l000001?nbjoP2o`0000;o/Nch00Co0000ok7[n?l0003o00001Oooool00ol0003o
ooooooooo`08ooooo`003_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`00
0?ooool01?l00005ooooo`03o`000?oooooooooo02;ooooo1?l00003ofn4e`03o`000?m`PmOoL8?G
00CoL8?G00?o0000ofn4eom_Q=L00om_Q=L00ol0003oCXc[odj<j`05odj<j`?o000000CoI@0Io`00
0?mT01OoI00G1ol00002of404P03o`000?mO017o000000;o00001_mI00@00ol0003oG00:oe`02P02
oe`02P;o00000omgh/@4o`0000GoVZCL00?o0000oi^Ug?l000001Ol00003oibUf`03o`000?nKXm_o
Vj?K00?oVj?K00?o0000oi^SfonKXm/01?nKXm/00ol0003oVj?Joi^SfP04oi^SfP03o`000?nKX][o
Vj;J00?oVj;J00?o0000oiZRf_nJX]X01OnJX]X00ol0003oVZ;JoiZRfP03oiZRfP[o00000onJX=T0
0ol0003oVY?;oiZCb`03oiZCb`03o`000?n8Ol?oR7o300CoR7o300Co0000oh62bol0003o00000_n1
P//00ol0003oVIoIoiVOf@04oiVOf@03o`000?nJXM[oVZ7J00GoVZ7J00?o0000oiZRf_nJX]X01?nJ
X]X00ol0003oVZ?KoiZSf`05oiZSf`04o`000?nG]nko0000o`0000Co/^[h0_l00002ok;[n0?o0000
1?nbjoP00ol0003o/Nchok7/n002ok7/n0;o00001oooool00ol0003oooooooooo`08ooooo`003_oo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool2o`00
02Gooooo1Ol000000om_Q=Oo0000og23e`04og23e`03o`000?m_Q=OoKhCG00CoKhCG00?o0000odj<
jom>S>/01Om>S>/6o`0000;oHP0D00?o0000of404_mQ01800omQ01801Ol0003oG`0Ao`000?lT/<Wo
000000KoF@0400?o0000oe`02_mL00X02?l00003oiZSf`04o`000?nJY=coVZCLoiZTg0Ko000000?o
`]7Vo`000?nLYM/01OnLYM/00ol0003oVj?Koi^Sf`03oi^Sf`03o`000?nKXm_oVj?K00?oVj?K00?o
0000oi^Sf_nKXmX01OnKXmX00ol0003oVj;Joi^RfP03oi^RfP04o`000?nJX][oVZ;JoiZRfP[o0000
1_nJXMX00ol0003oVZ3IoiZPf@03oiZPf@03o`000?nJTl_oVY?;00CoVY?;00?o0000ohQo`on8Ol<0
0on8Ol<01?l0003oPH;;oh62bon1P//4o`0000KoVIoI00?o0000oiZQf_nJXMX01?nJXMX00ol0003o
VZ;JoiZRfP04oiZRfP03o`000?nJXm_oVZ?K00GoVZ?K0ol00004ok;Zn003o`000?nbjoSo/^_h00;o
00000onak?P01?l0003o/^_ho`000?l00002ok7/n0?o00002Oooool00ol0003oooooooooo`08oooo
o`003oooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`0Wooooo`Co
00001Om`PmL00ol0003oKhCGofn4e`05ofn4e`03o`000?m>S>_oCXc[00Co00000_nM]^T00ol0003o
HY3Xo`000003o`0000GoH@0B00Go0000oel04Ol0003o9;39o`000002oeT010_o00000_nKY=/01?l0
003oVZ?KoiZSfonJXm/6o`0000CoTLGi00Go0000ol;Ai_o2dNKo`]7Vo`000005oibUf`03o`000?nK
Xm_oVj?K00?oVj?K00?o0000oi^SfonKXm/01?nKXm/00ol0003oVj?Joi^SfP04oi^SfP[o00000onJ
X]X01?l0003oVZ;JoiZRf_nJX]X<o`0000CoVZ3I00?o0000oiZCbonJTl/00onJTl/00ol0003oR7o3
ohQo``04ohQo``03o`000?n1P/_oPH;;00?oPH;;0_l00005oiVOf@03o`000?nJXM[oVZ7J00GoVZ7J
00?o0000oiZRf_nJX]X01?nJX]X00ol0003oVZ?KoiZSf`02oiZSf`;o00000onaj?P01?l0003o/^[h
o`000?l00002ok;[n003o`000?nak?So/Nch00?o/Nch0ol000000onak?So0000o`00000<ooooo`03
o`000?oooooooooo00Sooooo000Xooooo`03o`000?oooooooooo02[ooooo1?l00003og23e`03o`00
0?m_Q=OoKhCG00?oKhCG1?l00007oiffj@04o`000?mRT>SoHY3Xof:@j0go00000_n0000?o`0000Go
VjGL00Go0000oi75nOnAaOWoTLGio`000004ol;AiP03o`000?nLYM_oW:GK00CoW:GK00?o0000oi^S
fonKXm/00onKXm/00ol0003oVj?Koi^Sf`02oi^Sf`Wo00000onKX]X=o`0000?oVZ3I00?o0000oiZC
bonJTl/01?nJTl/00ol0003oQgo3o`000002o`000003oiZPfOl0003oVY?;00CoVY?;00?o0000ohQo
`on8Ol<01?n8Ol<00ol0003oPH;;oh62b`03oh62b`04o`000?nIWmWo0000o`0000CoVIoI00?o0000
oiZQf_nJXMX01?nJXMX00ol0003oVZ;JoiZRfP04oiZRfP05o`000?nJXm_oVZ?KoiZSfol000001Ona
j?P3o`000003ok;[n?l0003o000000?o/Nch0ol00002ok7/n0;o00003_ooool00ol0003ooooooooo
o`08ooooo`00:?ooool00ol0003oooooooooo`0]ooooo`Go00000_m_Q=L3o`0000;oSM[o00?o0000
oiffjOnM]^T01_nM]^T00ol0003oHY3Xof:@j004of:@j0Co00001on00005o`0000;oU[O_00?o0000
oi^Tg?nKY=`00onKY=`00ol0003oVjGLoi^Ug006oi^Ug003o`000?nAaOWo000000Ko`]7V00?o0000
oibUfonLYM/00onLYM/;o`0000;oVj?K00Co0000oi^Sf_nKXm[oVj?J1_l00003oiZRfP03o`000?nJ
XM[oVZ7J00CoVZ7J00?o0000oiZPfOnJX=T00onJX=T00ol0003oVY?;oiZCb`04oiZCb`03o`000?n7
Ol?oQgo300;oQgo30_l00005oiZCb`03o`000?n8Ol?oR7o300CoR7o300?o0000oh62bon1P//01?n1
P//00ol0003oVIoIoiVOf@02o`0000;oVIoI00?o0000oiZQf_nJXMX01?nJXMX00ol0003oVZ;JoiZR
fP04oiZRfP04o`000?nJXm_o0000o`0000?o/NSh0ol00002ok;[n0Co000000?o/Ncho`000?l00000
0_nak?P3o`00013ooooo00?o0000ooooooooool02?ooool002Sooooo0_l0000aooooo`Co00001_n=
f_l00ol0003oWKKYoiffj@06oiffj@03o`000?mRT>SoHY3X00CoHY3X00?o0000ooooooooool01?l0
0002oh0000Co00001OnF]nl00ol0003oVjCLoi^Tg003oi^Tg003o`000?nKYMcoVjGL00GoVjGL0ol0
0004ol;AiPWo00000onKXm/=o`0000?oVZ;J00?o0000oiZRf_nJX]X01?nJX]X00ol0003oVZ7JoiZQ
fP04oiZQfP03o`000?nJX=WoVZ3I00?oVZ3I00?o0000oiZCbonJTl/01?nJTl/00ol0003oQgo3ohMo
``03ohMo``;o00000onJTl/00ol0003oR7o3ohQo``04ohQo``03o`000?n1P/_oPH;;00CoPH;;00?o
0000oiVOfOnIWmT00_nIWmT3o`0000CoVZ7J3Ol000000onaj?So0000o`000002ok;[n0?o00000ona
k?P3o`000003ok7/n?l0003o000001?ooooo00?o0000ooooooooool02?ooool002Sooooo00?o0000
ooooooooool0<oooool4o`0000CoSM[o00?o0000oiffjOnM]^T01OnM]^T00ol0003oHY3Xof:@j002
of:@j0;o00001oooool5o`000003og7@o_l0003oU[O_00?oU[O_00?o0000oi^Tg?nKY=`01?nKY=`0
0ol0003oVjGLoi^Ug002oi^Ug0Wo00000_o2dNH01?l0003oW:GKoibUfonLYM/6o`0000?oVj?K00?o
0000oi^Rf_nKX]X01?nKX]X00ol0003oVZ;JoiZRfP04oiZRfP03o`000?nJX][oVZ;J00?oVZ;J00?o
0000oiZQf_nJXMX01?nJXMX00ol0003oVZ3IoiZPf@03oiZPf@03o`000?nJTl_oVY?;00CoVY?;00?o
0000ohMo`on7Ol<00on7Ol<01?l0003oP8;<o`000?l00002oiZCb`03o`000?n8Ol?oR7o300CoR7o3
00?o0000oh62bon1P//00on1P//00ol0003oVIoIoiVOf@02oiVOf@Oo00000onJXm/00ol0003oU[O^
oiJgkP06oiJgkP?o000000?o/^_ho`000?l000001?nak?P2o`0000;o/Nch0_l0000Eooooo`03o`00
0?oooooooooo00Sooooo000Xooooo`03o`000?oooooooooo03Kooooo0ol00003ohgJo`03o`000?nM
]^WoWKKY00GoWKKY00Co0000of:@j?mRT>So00003_ooool3o`0000CoU[O_3?l00002ofbGj@co0000
0onF]nh00ol0003oVj?Koi^Sf`04oi^Sf`03o`000?nKX][oVj;J00CoVj;J00?o0000oiZRf_nJX]X0
0onJX]X00ol0003oVZ;JoiZRfP04oiZRfP03o`000?nJXM[oVZ7J00CoVZ7J00?o0000oiZPfOnJX=T0
0_nJX=T00ol0003oVY?;oiZCb`04oiZCb`03o`000?n7Ol?oQgo300?oQgo300Co0000oh22c?n0P/co
P8;<0ol00003ohQo``ko00000onJX]X01?l0003oVZ?Ko`000?l00004oiZSf`03o`000?nF]nkoU[O^
00?oU[O^0_l00002ok7[n0?o00001?nak?P00ol0003o/Nchok7/n002o`0001Oooooo00?o0000oooo
ooooool02?ooool002Sooooo00?o0000ooooooooool0>Oooool4o`0000OoWKKY00?o0000of:@j?l0
00003_ooool:o`0000GoVjCL00Go0000oi^Ug?l0003oQXkDo`000005ofbGj@Oo000000?oKlkno`00
0?nF]nh00onF]nh00ol0003oVj?Koi^Sf`03oi^Sf`03o`000?nKX][oVj;J00CoVj;J00?o0000oiZR
f_nJX]X01?nJX]X00ol0003oVZ;JoiZRfP04oiZRfP03o`000?nJXM[oVZ7J00?oVZ7J00?o0000oiZP
fOnJX=T00onJX=T00ol0003oVY?;oiZCb`03oiZCb`03o`000?n7Ol?oQgo300CoQgo300?o0000oh22
c?n0P/`00_n0P/`4o`0000?oV9oI00?o0000oiVQf_nIXMX01?nIXMX00ol0003oVZ;JoiZRfP05oiZR
fP03o`000?nJXm_oVZ?K00;o00000onJXm/01Ol0003oU[O^oiJgk_nF]nko000000;o/N_h0_l00003
ok7/n004o`000?nak?So0000o`0000;o/Nch00?o0000ooooooooool05oooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`0mooooo`;o00001?nM]^T4o`0000Gooooo2_l00007
ooooo`?o00000onKY=`4o`0000;oQXkD00?o0000ofbGjOm/UnT00ol000001?nU/N3o0000ohF<don5
S=<6o`0000CoU[O^00?o0000oi^SfonKXm/00onKXm/00ol0003oVj;Joi^RfP04oi^RfP03o`000?nJ
X][oVZ;J00?oVZ;J00?o0000oiZRf_nJX]X01?nJX]X00ol0003oVZ7JoiZQfP03oiZQfP03o`000?nJ
X=WoVZ3I00?oVZ3I00?o0000oiZCbonJTl/00onJTl/00ol0003oQgo3ohMo``04ohMo``03o`000?n0
P/coP8;<00;oP8;<00?o0000oiROfOnHWmT01OnHWmT00ol0003oVJ7JoiVQfP04oiVQfP03o`000?nJ
X][oVZ;J00CoVZ;J00?o0000oiZSfonJXm/00_nJXm/2o`000003oiZSfol0003oU[O^00;o00000_na
joP00ol0003o/Nchok7/n003ok7/n0?o000000?o/Ncho`000?l000006_ooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`0oooooo`go00004oooool5o`0000?oQXkD1Ol00005
ojFah003o`000?n5S=?oQHcC00;oQHcC1_l000000onF]nko0000oi^Sf`05oi^Sf`03o`000?nKX][o
Vj;J00?oVj;J00?o0000oiZRf_nJX]X00onJX]X00ol0003oVZ;JoiZRfP02oiZRfP_o00000onJX=T0
0ol0003oVY?;oiZCb`04oiZCb`03o`000?n7Ol?oQgo300?oQgo300?o0000oh22c?n0P/`00on0P/`0
0ol0003oV9oIoiROf@04oiROf@03o`000?nIXM[oVJ7J00CoVJ7J00?o0000oiZRf_nJX]X01OnJX]X0
0ol0003oVZ?KoiZSf`03oiZSf`Co000000?o/N_ho`000?l000000onak?P3o`0000;o/Nch0_l0000L
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo03[ooooo2Ol0000Ooooo
o`Go00000onIf_h00ol0003oYK7PojFah004ojFah003o`000?n5S=?oQHcC00;oQHcC00?o0000offE
iom]UNL01_l00005oi^Sf`04o`000?nKX][oVj;Joi^RfPgo00000onJX=T00ol0003oVY;;oiZBb`03
oiZBb`06o`000?n7Ol?o0000o`000?nJX=Wo00001_nJTl/00ol0003oQgo3ohMo``04ohMo``03o`00
0?n0P/coP8;<00;oP8;<00?o0000oiROfOnHWmT01OnHWmT00ol0003oVJ7JoiVQfP04oiVQfP03o`00
0?nJX][oVZ;J00CoVZ;J00Co0000oiZSfonJXm_oVZ?K0ol000000on`j?So0000o`000003o`000003
ok7/n?l0003o000000?o/Nch0_l0000Nooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o0000
<Oooool:o`0002_ooooo0ol00003oiWJoP03o`000?nU/N3oYK7P00?oYK7P00?o0000ohF<don5S=<0
0on5S=<00ol0003oKIGWoffEi`02offEi`co00000onE]Nd00ol0003oVZ;JoiZRfP03oiZRfP03o`00
0?nJX=WoVZ3I00CoVZ3I00?o0000oiZBbonJT//00onJT//01?l0003oQgo3ohMo`on7Ol<3o`0000Go
VY?;00?o0000ohMo`on7Ol<01?n7Ol<00ol0003oP8;<oh22c003oh22c003o`000?nHWmWoV9oI00Co
V9oI00?o0000oiVQf_nIXMX01?nIXMX00ol0003oVZ;JoiZRfP04oiZRfP04o`000?nJXm_o0000o`00
00?o/>Sh0_l000000onak?So0000o`000004o`000003ok7/n?l0003o0000023ooooo00?o0000oooo
ooooool02?ooool002Oooooo00?o0000ooooooooool09oooool9o`0003Gooooo00?o0000oooooooo
ool01Ol00005ojFah003o`000?n5S=?oQHcC00?oQHcC00?o0000offEiom]UNL00om]UNL4o`0000?o
K/cn00?o0000oiFekOnE]Nd01?nE]Nd00ol0003oVZ;JoiZRfP03oiZRfP03o`000?nJX=WoVZ3I00Co
VZ3I00?o0000oiZBbonJT//00onJT//00ol0003oQgo3ohMo``02ohMo``;o00001?nJTl/00ol0003o
Qgo3ohMo``04ohMo``03o`000?n0P/coP8;<00?oP8;<00?o0000oiROfOnHWmT01?nHWmT00ol0003o
VJ7JoiVQfP04oiVQfP03o`000?nJX][oVZ;J00;oVZ;J1_l000000on`j?So0000o`000003ok7/n0;o
000000?o/Ncho`000?l000000_l0000Rooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`00
0?oooooooooo01kooooo2Ol0000nooooo`03o`000?oooooooooo00?ooooo1Ol00002ojFah003o`00
0?n5S=?oQHcC00?oQHcC00?o0000offEiom]UNL00ol000001?nT[moo0000ohJ;dOn6Rm43o`000003
ofk<o_l0003oUKG]00CoUKG]00?o0000oiZRf_nJX]X00onJX]X00ol0003oVZ3IoiZPf@04oiZPf@03
o`000?nJT/_oVY;;00?oVY;;00?o0000ohMo`on7Ol<00_n7Ol<00ol0003oP8;<o`000002o`000003
oiZCbol0003oQgo300KoQgo300?o0000oh22c?n0P/`00_n0P/`00ol0003oV9oIoiROf@02oiROf@ko
00001OnF]nl2o`0000Co/Nch00Co0000ok7/n?nak?So/Nch1?l0000Rooooo`03o`000?oooooooooo
00Sooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`0Dooooo`[o0000Aoooool00ol0003oooooooooo`06ooooo`Go00000on5S=<5o`0000Go
Y:oO00?o0000ohJ;dOn6Rm400_n6Rm43o`0000GoUKG]00?o0000oiZRf_nJX]X00onJX]X00ol0003o
VZ3IoiZPf@03oiZPf@03o`000?nJT/_oVY;;00?oVY;;00?o0000ohMo`on7Ol<00on7Ol<01?l0003o
P8;<oh22c?n0P/`3o`0000?oQgo33Ol00003oiZRfP03o`000?nJXm_oVZ?K00CoVZ?K00?o0000oiJg
konF]nl01?nF]nl2o`0000;o/N_h00Co0000ok7/n?l0003o00000onak?P00ol0003oooooooooo`02
ooooo`;o00008?ooool00ol0003oooooooooo`08ooooo`004oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00Cooooo0ol0000;ooooo`Wo0000DOooool00ol0003oooooooooo`09
ooooo`Go00000onGf?h00ol0003oY:oOojB_g`04ojB_g`03o`000?n6Rm7oQX_A00;oQX_A00?o0000
ohB9dOn4RM400ol00002oiFek@03o`000?nJX][oVZ;J00?oVZ;J00?o0000oiZPfOnJX=T01?nJX=T0
0ol0003oVY;;oiZBb`02oiZBb`03o`000?n7Ol?oQgo300?oQgo300?o0000oh22c?n0P/`00on0P/`4
o`0000?oV9oI00?o0000oiVQf_nIXMX00onIXMX00ol0003oVZ;JoiZRfP05oiZRfP03o`000?nJXm_o
VZ?K00CoVZ?K00?o0000oiJgkonF]nl00_nF]nl00ol0003o/N_hok7[n002ok7[n0Co000000?o/Nch
o`000?l000001oooool2o`0001kooooo00?o0000ooooooooool02?ooool001?ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo2Ol0001J
ooooo`03o`000?oooooooooo00cooooo0ol00003oiOHoP03o`000?nT[mooY:oO00?oY:oO00?o0000
ohJ;dOn6Rm400on6Rm400ol0003oQ8WAohB9d@02ohB9d@?o00000onJX]X5o`0000CoVZ3I00?o0000
oiZBbonJT//00onJT//00ol0003oQgo3ohMo``02ohMo``03o`000?n0P/coP8;<00?oP8;<00?o0000
oiROfOnHWmT01OnHWmT00ol0003oVJ7JoiVQfP03oiVQfP03o`000?nJX][oVZ;J00CoVZ;J00?o0000
oiZSfonJXm/01OnJXm/01?l0003oU[O_o`000?l00003ok7[n0;o00000onak?P2o`0000_ooooo0ol0
000Kooooo`03o`000?oooooooooo00Sooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01?ooool5o`0000;ooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`0?ooooo`;o00000_nGf?h00ol0003oY:oOojB_g`03ojB_g`03o`000?n6Rm7oQX_A00;oQX_A00?o
0000ohB9dOn4RM400_n4RM42o`000004o`1gcOl0003o0000o`0000?oUJST00?o0000oh:1bOl00000
0_l000000onJX=Wo0000oiZBb`04oiZBb`03o`000?n7Ol?oQgo300?oQgo300?o0000oh22c?n0P/`0
0on0P/`00ol0003oV9oIoiROf@04oiROf@03o`000?nIXM[oVJ7J00?oVJ7J00?o0000oiZRf_nJX]X0
1OnJX]X00ol0003oVZ?KoiZSf`04oiZSf`Co000000?o/N_ho`000?l000000_nak?P3o`00013ooooo
0_l0000Iooooo`03o`000?oooooooooo00Sooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool01oooool5o`00063ooooo00?o0000ooooooooool04Oooool3o`0000GoY:oO
00?o0000ohJ;dOn6Rm400_n6Rm400ol0003oQ8WAohB9d@03ohB9d@?o00001_nEZ>@01?l0003oPX79
oh:1bOn2PLT3o`0000CoVY;;00?o0000ohMo`on7Ol<00on7Ol<00ol0003oP8;<oh22c003oh22c003
o`000?nHWmWoV9oI00GoV9oI00?o0000oiVQf_nIXMX00onIXMX00ol0003oVZ;JoiZRfP04oiZRfP04
o`000?nJXm_oVZ?KoiZSf`?o00000on`j?P3o`000003ok7/n?l0003o000001Gooooo0_l0000Goooo
o`03o`000?oooooooooo00Sooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo0_l0000=oooo
o`Co00000_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Cooooo0ol00002ojB_
g`03o`000?n6Rm7oQX_A00?oQX_A00?o0000ohB9dOn4RM400_n4RM401?l0003oE6c>o`000?l00005
oiFXi003o`000?n2PLWoPX7900?oPX790_l00003oiZBb`03o`000?n7Ol?oQgo300CoQgo300?o0000
oh22c?n0P/`00on0P/`00ol0003oV9oIoiROf@04oiROf@03o`000?nIXM[oVJ7J00?oVJ7J00?o0000
oiZRf_nJX]X01?nJX]X01?l0003oVZ?Ko`000?l00003ok3Xn0?o00000_nak?P2o`0001Wooooo0_l0
000Fooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o00002_ooool00ol0003oooooooooo`0?
ooooo`Go00000oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01Oooooo1?l00004
ohJ;d@03o`000?n4RM7oQ8WA00;oQ8WA00?o0000oeA/c_mDK<h00_l00004oiFXi003o`000?n2PLWo
PX7900?oPX7900Ko0000ogn2c?l0003o0000oiZBbol00006ohMo``03o`000?n0P/coP8;<00?oP8;<
00?o0000oiROfOnHWmT01?nHWmT00ol0003oVJ7JoiVQfP03oiVQfP03o`000?nJX][oVZ;J00;oVZ;J
1_l000000on`j?So0000o`000003ok7/n0;o00007Oooool2o`0001Cooooo00?o0000ooooooooool0
1oooool003Oooooo1?l0001Dooooo`03o`000?oooooooooo01[ooooo0ol00002ohJ;d@03o`000?n4
RM7oQ8WA00?oQ8WA00Co0000oeA/c_mDK<ko00001OnEZ>@00ol0003oPX79oh:1b@02oh:1b@04o`00
0?moP/coOh;<ogn2c0?o00001On7Ol<00ol0003oP8;<oh22c003oh22c003o`000?nHWmWoV9oI00;o
V9oI3Ol00005oiFhk`Co000000?o/Ncho`000?l000008Oooool2o`0001;ooooo00?o0000oooooooo
ool01oooool003_ooooo1?l000000ooooooo0000ooooo`1=ooooo`03o`000?oooooooooo01gooooo
1?l00004ohB9d@04o`000?mDK<koE6c>oeA/cP;o00000onEZ>@00ol0003oPX79oh:1b@03oh:1b@03
o`000?moP/coOh;<00;oOh;<4Ol00003oiZRfP03o`000?nJXm_oVZ?K00CoVZ?K00?o0000oiFhkonE
^>l00_nE^>l3o`0000?o/N_h0_l0000Uooooo`?o00003oooool00ol0003oooooooooo`07ooooo`00
9_ooool2o`0001Oooooo1?l00003ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
8?ooool3o`0000;oQ8WA00Oo0000oeA/c_mDK<koE6c>o`000?l0C/co000000;oUJST00?o0000oh:1
bOn2PLT00on2PLT00ol0003oOh;<ogn2c002ogn2c003o`000?nHWmWoV9oI00CoV9oI00?o0000oiVQ
f_nIXMX00onIXMX00ol0003oVZ;JoiZRfP05oiZRfP03o`000?nJXm_oVZ?K00CoVZ?K00Co0000oiFh
kol0003o00001?najoP2o`0002[ooooo0_l0000=ooooo`03o`000?oooooooooo00Oooooo000Uoooo
o`04o`000?ooooooooooo`0001[ooooo1?l00018ooooo`03o`000?oooooooooo02?ooooo1?l00003
oeA/cP06o`000?l0C/co0000o`000?nEZ>Co00001?n2PLT00ol0003oOh;<ogn2c003ogn2c003o`00
0?nHWmWoV9oI00CoV9oI00?o0000oiVQf_nIXMX00onIXMX00ol0003oVZ;JoiZRfP04oiZRfP03o`00
0?nJXm_oVZ?K00CoVZ?K0ol00004ok7[n003o`000?oooooooooo02cooooo0_l0000;ooooo`03o`00
0?oooooooooo00Oooooo000Uooooo`04o`000?ooooooooooo`0001kooooo1?l000000ooooooo0000
ooooo`11ooooo`03o`000?oooooooooo02Kooooo0ol00002oeA/cP03o`000?l0C/co04k<00;o0000
1On2PLT00ol0003oOh;<ogn2c002ogn2c003o`000?nHWmWoV9oI00CoV9oI00?o0000oiVQf_nIXMX0
0onIXMX00ol0003oVZ;JoiZRfP05oiZRfP03o`000?nJXm_oVZ?K00;oVZ?K00Ko0000ok3Xn?n`j?So
/>Sho`000?najoP2o`00037ooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo000Uooooo`04
o`000?ooooooooooo`0002;ooooo1Ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo
02Wooooo0ol00003o`1>c003o`000?n2PLWoPX7900?oPX7900?o0000ogn2c?moP/`00omoP/`00ol0
003oV9oIoiROf@04oiROf@03o`000?nIXM[oVJ7J00?oVJ7J00?o0000oiZRf_nJX]X01?nJX]X00ol0
003oVZ?KoiZSf`02o`0000Co/>Sh0_l0000eooooo`;o00001oooool00ol0003oooooooooo`07oooo
o`009Oooool01?l0003oooooooooool0000Wooooo`Co00000oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02cooooo0ol000000ol0C/co0000o`000003oh:1b@03o`000?moP/coOh;<
00?oOh;<00?o0000oiROfOnHWmT01?nHWmT00ol0003oVJ7JoiVQfP03oiVQfP03o`000?nJX][oVZ;J
00CoVZ;J00?o0000oiZSfol000001?n`j?P2o`0003Wooooo0ol00004ooooo`03o`000?oooooooooo
00Oooooo000Uooooo`04o`000?ooooooooooo`0002_ooooo1?l0000gooooo`03o`000?oooooooooo
02oooooo1Ol000000on2PLWo0000ogn2c004ogn2c003o`000?nHWmWoV9oI00CoV9oI00Co0000oiVQ
f_nIXM[oVJ7J3Ol000000on`j?So0000o`00000nooooo`;o00000_ooool00ol0003oooooooooo`07
ooooo`009_ooool2o`00033ooooo1Ol00004ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0<_ooool5o`0000;oOh;<3Ol00003oiZSg003o`000?nE]nooUKO_00KoUKO_0_l00012oooo
o`?o00002Oooool005cooooo1?l000000ooooooo0000ooooo`0/ooooo`03o`000?oooooooooo03Ko
oooo0ol00003ofG8o@03o`000?nC]NooTkG_00CoTkG_00?o0000oiZSg?nJXm`01?nJXm`00ol0003o
UKO_oiFgk`02oiFgk`?o0000@?ooool7o`0000Wooooo000oooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00004oooool4o`0000;ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0iooooo`?o000000?oILSmo`000?nC]Nl01OnC]Nl00ol0003oVZ?LoiZSg004oiZSg004o`00
0?nE]noo0000o`0003Kooooo3Ol0000@ooooo`00?_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000005_ooool4o`0000?ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0looooo`?o00001OnC]Nl00ol0003oVZ?LoiZSg004oiZSg0;o0000:oooool=o`00
01gooooo000nooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool06?ooool5o`00
02;ooooo00?o0000ooooooooool0?oooool3o`0000?oTkG_00Co0000oiZSg?nJXmcoVZ?L0_l0000P
ooooo`go0000:_ooool003kooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0M
ooooo`Co00007_ooool00ol0003oooooooooo`12ooooo`Co000000?oVZ?Lo`000?l000005Oooool=
o`0003Oooooo000nooooo`04o`000?ooooooooooo`0000Oooooo1?l0000Sooooo`Ko00001?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Gooooo0_l0000:ooooo`go0000A?ooool0
03kooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Yooooo`Co000000?ooooo
o`000?ooool04oooool00ol0003oooooooooo`14ooooo`go0000DOooool003oooooo0_l00008oooo
o`Go00004Oooool3o`0001Oooooo1?l000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo
03Oooooo3Ol0001Nooooo`00H?ooool00ol0003oooooooooo`0Jooooo`Co000000?oooooo`000?oo
ool02oooool00ol0003oooooooooo`0Zooooo`go0000Joooool0063ooooo00?o0000ooooooooool0
7_ooool5o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool07Oooool=o`0007Sooooo
001Pooooo`03o`000?oooooooooo02?ooooo1?l000000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo013ooooo3Ol00025ooooo`00H?ooool00ol0003oooooooooo`0Wooooo`Co000000?ooooo
o`000?ooool01?ooool=o`0009;ooooo001Oooooo`;o0000;Oooool7o`0009oooooo001Pooooo`03
o`000?oooooooooo00kooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol0002dooooo`00
L_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000/oooool007;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`2aooooo`00L_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0;7ooooo001booooo`03o`000?oooooooooo00Oooooo1?l0002d
ooooo`00LOooool2o`0000Wooooo00?o0000ooooooooool03Oooool5o`000:?ooooo001booooo`03
o`000?oooooooooo00Oooooo1Ol0000<ooooo`04o`000?ooooooooooo`000:?ooooo002>ooooo`03
o`000?oooooooooo0:?ooooo002?ooooo`03o`000?oooooooooo0:;ooooo002<ooooo`05o`000?oo
ooooooooooooool00000Xoooool008cooooo00Go0000ooooooooooooooooo`00002Sooooo`00SOoo
ool3o`000:Cooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 385.062}, {416.938, 256.875}} -> {-0.427631, \
1.09973, 0.00364375, 0.00364375}}]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{703, 796},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 139, 3, 33, "Text"],
Cell[1896, 56, 70, 0, 28, "Text"],
Cell[1969, 58, 830, 33, 68, "Text"],
Cell[2802, 93, 148, 3, 24, "Text"],
Cell[2953, 98, 238, 6, 48, "Text"],
Cell[3194, 106, 369, 12, 33, "Text"],
Cell[3566, 120, 58, 2, 28, "Text"],
Cell[3627, 124, 79, 0, 28, "Text"],
Cell[3709, 126, 571, 23, 48, "Text"],
Cell[4283, 151, 196, 5, 33, "Text"],
Cell[4482, 158, 221, 11, 28, "Text"],
Cell[4706, 171, 238, 5, 33, "Text"],
Cell[4947, 178, 1158, 47, 102, "Text"],
Cell[6108, 227, 209, 7, 28, "Text"],
Cell[6320, 236, 63, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[6408, 242, 202, 6, 83, "Input"],
Cell[6613, 250, 13859, 386, 95, 3511, 253, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[20487, 639, 130, 3, 28, "Text"],
Cell[20620, 644, 150, 3, 24, "Text"],
Cell[20773, 649, 100, 2, 29, "Input"],
Cell[20876, 653, 112, 3, 28, "Text"],
Cell[20991, 658, 97, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[21113, 665, 179, 5, 47, "Input"],
Cell[21295, 672, 250, 4, 83, "Output"],
Cell[21548, 678, 115, 2, 45, "Output"]
}, Open  ]],
Cell[21678, 683, 193, 8, 28, "Text"],
Cell[21874, 693, 162, 5, 47, "Input"],
Cell[22039, 700, 337, 12, 48, "Text"],

Cell[CellGroupData[{
Cell[22401, 716, 196, 5, 47, "Input"],
Cell[22600, 723, 44113, 1917, 142, 26897, 1699, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[66728, 2643, 316, 9, 60, "Text"],

Cell[CellGroupData[{
Cell[67069, 2656, 174, 5, 47, "Input"],
Cell[67246, 2663, 17158, 468, 98, 5101, 314, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[84419, 3134, 117, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[84561, 3143, 112, 2, 29, "Input"],
Cell[84676, 3147, 18616, 670, 85, 8204, 537, "GraphicsData", "PostScript", \
"Graphics"],
Cell[103295, 3819, 155, 4, 27, "Output"]
}, Open  ]],
Cell[103465, 3826, 55, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[103545, 3830, 122, 2, 29, "Input"],
Cell[103670, 3834, 48661, 2274, 146, 31959, 2063, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[152346, 6111, 203, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[152574, 6120, 169, 6, 65, "Input"],

Cell[CellGroupData[{
Cell[152768, 6130, 17954, 485, 147, 4458, 312, "GraphicsData", "PostScript", \
"Graphics"],
Cell[170725, 6617, 24220, 719, 186, 7480, 505, "GraphicsData", "PostScript", \
"Graphics"],
Cell[194948, 7338, 24643, 764, 186, 8268, 555, "GraphicsData", "PostScript", \
"Graphics"],
Cell[219594, 8104, 24872, 773, 186, 8387, 562, "GraphicsData", "PostScript", \
"Graphics"],
Cell[244469, 8879, 25408, 824, 186, 9268, 618, "GraphicsData", "PostScript", \
"Graphics"],
Cell[269880, 9705, 24808, 835, 186, 9603, 640, "GraphicsData", "PostScript", \
"Graphics"],
Cell[294691, 10542, 26631, 933, 186, 11037, 733, "GraphicsData", \
"PostScript", "Graphics"],
Cell[321325, 11477, 27617, 1003, 186, 12165, 805, "GraphicsData", \
"PostScript", "Graphics"],
Cell[348945, 12482, 27409, 1003, 186, 12220, 808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[376357, 13487, 28133, 1060, 186, 13159, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[404493, 14549, 28133, 1091, 186, 13730, 906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[432629, 15642, 27559, 1052, 186, 13144, 867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[460191, 16696, 27302, 1009, 186, 12389, 818, "GraphicsData", \
"PostScript", "Graphics"],
Cell[487496, 17707, 27013, 990, 186, 12063, 798, "GraphicsData", \
"PostScript", "Graphics"],
Cell[514512, 18699, 25950, 910, 186, 10774, 716, "GraphicsData", \
"PostScript", "Graphics"],
Cell[540465, 19611, 25683, 865, 186, 9976, 664, "GraphicsData", "PostScript", \
"Graphics"],
Cell[566151, 20478, 24848, 813, 186, 9149, 612, "GraphicsData", "PostScript", \
"Graphics"],
Cell[591002, 21293, 24081, 747, 186, 8062, 542, "GraphicsData", "PostScript", \
"Graphics"],
Cell[615086, 22042, 23791, 721, 186, 7655, 515, "GraphicsData", "PostScript", \
"Graphics"],
Cell[638880, 22765, 24687, 749, 186, 7964, 536, "GraphicsData", "PostScript", \
"Graphics"],
Cell[663570, 23516, 20374, 516, 186, 4456, 312, "GraphicsData", "PostScript", \
"Graphics"],
Cell[683947, 24034, 24372, 730, 186, 7657, 517, "GraphicsData", "PostScript", \
"Graphics"],
Cell[708322, 24766, 24303, 737, 186, 7831, 527, "GraphicsData", "PostScript", \
"Graphics"],
Cell[732628, 25505, 24708, 765, 186, 8260, 555, "GraphicsData", "PostScript", \
"Graphics"],
Cell[757339, 26272, 25169, 809, 186, 9004, 602, "GraphicsData", "PostScript", \
"Graphics"],
Cell[782511, 27083, 25953, 877, 186, 10133, 675, "GraphicsData", \
"PostScript", "Graphics"],
Cell[808467, 27962, 26674, 935, 186, 11085, 736, "GraphicsData", \
"PostScript", "Graphics"],
Cell[835144, 28899, 27427, 994, 186, 12052, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[862574, 29895, 26818, 969, 186, 11706, 775, "GraphicsData", \
"PostScript", "Graphics"],
Cell[889395, 30866, 27777, 1050, 186, 13050, 861, "GraphicsData", \
"PostScript", "Graphics"],
Cell[917175, 31918, 28159, 1091, 186, 13760, 906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[945337, 33011, 27944, 1066, 186, 13327, 879, "GraphicsData", \
"PostScript", "Graphics"],
Cell[973284, 34079, 27125, 1001, 186, 12228, 810, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1000412, 35082, 27117, 991, 186, 12095, 799, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1027532, 36075, 26256, 926, 186, 11015, 731, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1053791, 37003, 24987, 839, 186, 9649, 643, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1078781, 37844, 24981, 817, 186, 9193, 615, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1103765, 38663, 24051, 742, 186, 7976, 537, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1127819, 39407, 25219, 797, 186, 8763, 587, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1153041, 40206, 24595, 741, 186, 7835, 527, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1177639, 40949, 20384, 516, 186, 4458, 312, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[1198050, 41469, 36, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[1198111, 41473, 149, 5, 47, "Input"],
Cell[1198263, 41480, 105372, 2315, 170, 52410, 1656, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

