(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     58281,       1711]*)
(*NotebookOutlinePosition[     60568,       1781]*)
(*  CellTagsIndexPosition[     60524,       1777]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Appendix A4. Sound Advice and Encouraging Words", \
"Section"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Save early, save often", "Subsubsection"]], "Text"],

Cell[TextData[{
  "This may be the best advice you will get for working with any computer \
application. This, and a heads up about  NotebookAuto save. This save feature \
is activated from the ",
  StyleBox["Preferences...",
    FontWeight->"Bold"],
  " dialogue (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " menu on a Macintosh). Choose Notebook Options/File Options and put a \
check in the box for NotebookAutoSave. Once this is done your notebook will \
be automatically saved after each new input. We also suggest that you also \
become accustomed to pressing Command-S (Control-S on a PC) every once and a  \
while. This is the keyboard equivalent for Save on the File menu. Certainly \
you will want to \"do a  save\" as you  finish a major part of a worksheet or \
are about to embark on a doubtful computation. "
}], "Text"],

Cell[TextData[StyleBox["What you see may not be what you get ", \
"Subsubsection"]], "Text"],

Cell[TextData[{
  "When you look at a Notebook on the computer screen, you see what might be \
called its \"visible state\".  This is not the same as the \"internal \
state\", which we can think of as being what ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " sees in the Notebook.  There are two kinds of problems that can arise. "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" sees things that you cannot see ",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "The internal state of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " may not be distinguishing between different Notebooks that are active on \
the display.  To see this, open ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and execute the entry ",
  StyleBox["b = 2",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  "Now open a new ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebook (Command-N) and use it to execute the entry \"b\" ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will return a value of 2 for \"b\" even though the value was not assigned \
in that Notebook. This is referred to as \"sharing the kernel\". All  open \
Notebooks store their values in the same kernel and they immediately take \
effect in all open Notebooks. This can be handy for experimentation, but \
remember: After the experimentation in a new Notebook any assignments made \
will become active in the original Notebook also."
}], "Text"],

Cell[TextData[{
  StyleBox["You see things that ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" cannot see ",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "When you quit ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and save a Notebook, all of the output cells are saved with it. Then, \
when you load that Notebook later, the output is still visible.  However, the \
internal state of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not include any of this visible output. One way to \"fix\" this is \
by executing all the inputs, top to bottom, by choosing ",
  StyleBox["Kernel/Evaluation/Evaluate Notebook",
    FontWeight->"Bold"],
  ". As an alternative consider thinking about what you want to accomplish \
(always a good idea), and then working your way through the newly opened \
Notebook, executing only those entries that you think you will need to \
accomplish the task at hand. It may be as simple as redefining a variable or \
two. "
}], "Text"],

Cell[TextData[{
  StyleBox["Whenever, during the course of Notebook development, ", 
    "DisplayFormula"],
  StyleBox["Mathematica", "DisplayFormula",
    FontSlant->"Italic"],
  StyleBox[" seems to be unable, or unwilling, to obey an input command, \
consider \"starting over\" by choosing ", "DisplayFormula"],
  StyleBox["Kernel/Quit Kernel/Local", "DisplayFormula",
    FontWeight->"Bold"],
  StyleBox[" and then choose ", "DisplayFormula"],
  StyleBox["Kernel/Start Kernel/Local", "DisplayFormula",
    FontWeight->"Bold"],
  StyleBox[". Then figure out exactly what  other inputs are needed to \
accomplish the troublesome task. Execute only those inputs, then the \
troublesome input and hope for  the best. If it still fails to \"work\" then \
at least you know that the visual state is also the internal state so the \
problem is probably with that particular input. Ask  someone else to take a \
look at it.  ", "DisplayFormula"]
}], "Text"],

Cell[TextData[StyleBox["The famous \"e\" error (and others) ",
  FontWeight->"Bold"]], "Text"],

Cell[TextData[{
  "Certain names and letters are reserved by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for specific uses. Examples include \"D\" (for differentiation), \
\"Sqrt\", \"Sin\", \"Cos\", \"Exp\", \"Pi\" (for the mathematical constant \
\[Pi] = 3.14.. ), and \"E\" (for the mathematical constant ",
  StyleBox["e",
    FontSlant->"Italic"],
  " = 2.78...)  Consider these examples. "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses E for the base of the natural logarithm function. E in an input cell \
prints in the output cell as \[ExponentialE]."
}], "Text"],

Cell[CellGroupData[{

Cell["{E, N[E]}", "Input",
  CellLabel->"In[15]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({\[ExponentialE], 2.718281828459045`}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[ E^(-x), {x,-1,1} ]", "Input",
  CellLabel->"In[19]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 0.216535 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -12 -9 ]
[.2619 .00222 12 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .12298 -18 -4.5 ]
[.4875 .12298 0 4.5 ]
[.4875 .23125 -6 -4.5 ]
[.4875 .23125 0 4.5 ]
[.4875 .33952 -18 -4.5 ]
[.4875 .33952 0 4.5 ]
[.4875 .44779 -6 -4.5 ]
[.4875 .44779 0 4.5 ]
[.4875 .55605 -18 -4.5 ]
[.4875 .55605 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-0.5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(0.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .12298 m
.50625 .12298 L
s
[(0.5)] .4875 .12298 1 0 Mshowa
.5 .23125 m
.50625 .23125 L
s
[(1)] .4875 .23125 1 0 Mshowa
.5 .33952 m
.50625 .33952 L
s
[(1.5)] .4875 .33952 1 0 Mshowa
.5 .44779 m
.50625 .44779 L
s
[(2)] .4875 .44779 1 0 Mshowa
.5 .55605 m
.50625 .55605 L
s
[(2.5)] .4875 .55605 1 0 Mshowa
.125 Mabswid
.5 .03637 m
.50375 .03637 L
s
.5 .05802 m
.50375 .05802 L
s
.5 .07968 m
.50375 .07968 L
s
.5 .10133 m
.50375 .10133 L
s
.5 .14464 m
.50375 .14464 L
s
.5 .16629 m
.50375 .16629 L
s
.5 .18794 m
.50375 .18794 L
s
.5 .2096 m
.50375 .2096 L
s
.5 .2529 m
.50375 .2529 L
s
.5 .27456 m
.50375 .27456 L
s
.5 .29621 m
.50375 .29621 L
s
.5 .31786 m
.50375 .31786 L
s
.5 .36117 m
.50375 .36117 L
s
.5 .38283 m
.50375 .38283 L
s
.5 .40448 m
.50375 .40448 L
s
.5 .42613 m
.50375 .42613 L
s
.5 .46944 m
.50375 .46944 L
s
.5 .49109 m
.50375 .49109 L
s
.5 .51275 m
.50375 .51275 L
s
.5 .5344 m
.50375 .5344 L
s
.5 .57771 m
.50375 .57771 L
s
.5 .59936 m
.50375 .59936 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .55745 L
.10458 .51149 L
.14415 .47188 L
.18221 .43676 L
.22272 .40234 L
.26171 .37187 L
.30316 .3421 L
.34309 .31576 L
.3815 .29243 L
.42237 .26959 L
.46172 .24938 L
.49955 .23145 L
.53984 .21387 L
.57861 .1983 L
.61984 .18307 L
.65954 .1696 L
.69774 .15767 L
.73838 .14597 L
.77751 .13562 L
.81909 .12551 L
.85916 .11657 L
.89771 .10865 L
.93871 .1009 L
.97619 .09437 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{149, 92},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002E0000G2000`400?l00000o`00003oUOooool0
00gooooo0ol0000Gooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000;oooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001Kooooo0ol0000:ooooo`003_ooool00ol0003o
ooooooooo`0Eooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000]
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`00
0?oooooooooo00Wooooo0006ooooo`Go00000oooool00ol0003oooooooooo`0>ooooo`Go00000_oo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo000>ooooo`03o`00
0?oooooooooo01Gooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0[ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09oooo
o`003_ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Oooooo1?l0000^oooo
o`04o`000?ooooooooooo`0000Oooooo1?l0000Gooooo`03o`000?oooooooooo00Wooooo000=oooo
o`;o00005oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02oooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`0Gooooo`;o00002oooool000kooooo00?o0000
ooooooooool05_ooool2o`0000Sooooo1Ol0000^ooooo`;o00002?ooool5o`0001Kooooo00?o0000
ooooooooool02Oooool009Gooooo001;ooooo`03o`000?oooooooooo04Oooooo001;ooooo`03o`00
0?oooooooooo04Oooooo0008ooooohKo00001oooool000cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo001;ooooo`03o`000?oooooooooo
04Oooooo001;ooooo`03o`000?oooooooooo04Oooooo001;ooooo`03o`000?oooooooooo04Oooooo
001;ooooo`03o`000?oooooooooo04Oooooo001;ooooo`03o`000?oooooooooo04Oooooo001;oooo
o`03o`000?oooooooooo04Oooooo001;ooooo`03o`000?oooooooooo04Oooooo001;ooooo`03o`00
0?oooooooooo04Oooooo001;ooooo`03o`000?oooooooooo04Oooooo001;ooooo`03o`000?oooooo
oooo03[ooooo0ol0000:ooooo`00>Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Cooooo00?o0000ooooooooool0=Oooool5o`0000gooooo000hooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo033ooooo1Ol0000B
ooooo`00>?ooool01?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool00000;?oo
ool6o`0001Oooooo000hooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo
0_l0000Vooooo`Go00007Oooool003Sooooo00Co0000oooooooooooo00001oooool4o`0000Cooooo
00?o0000ooooooooool08Oooool4o`0002;ooooo000hooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`?o00009_ooool003Wooooo0_l0
0008ooooo`Go00000oooool00ol0003oooooooooo`0Jooooo`Co0000:Oooool004_ooooo00?o0000
ooooooooool05_ooool4o`0002gooooo001;ooooo`03o`000?oooooooooo01?ooooo0ol0000aoooo
o`00Boooool00ol0003oooooooooo`0Aooooo`;o0000=?ooool004_ooooo00?o0000ooooooooool0
3_ooool3o`0003Kooooo001;ooooo`03o`000?oooooooooo00cooooo0_l0000iooooo`00Boooool0
0ol0003oooooooooo`09ooooo`?o0000>oooool004_ooooo00?o0000ooooooooool01_ooool3o`00
03kooooo0014ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`?o0000@Oooool004Gooooo
00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0004Cooooo0015ooooo`03o`00
0?oooooooooo00?ooooo1?l00016ooooo`00AOooool00ol0003oooooooooo`02ooooo`?o0000B?oo
ool004Gooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`18ooooo`00A?ooool3o`00
00Cooooo00?o0000ooooooooool0Aoooool004?ooooo0ol00005ooooo`03o`000?oooooooooo04Oo
oooo0012ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Aoooool0043ooooo0_l0
0009ooooo`03o`000?oooooooooo04Oooooo000nooooo`;o00002oooool00ol0003oooooooooo`17
ooooo`00??ooool2o`0000gooooo00?o0000ooooooooool0Aoooool003[ooooo0_l0000?ooooo`03
o`000?oooooooooo04Oooooo000hooooo`;o00004Oooool00ol0003oooooooooo`17ooooo`00=ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Oooooo000eooooo`;o00005?ooool0
0ol0003oooooooooo`17ooooo`00=?ooool01?l0003oooooooooooooool3o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0Aoooool003?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`17ooooo`00<_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooooooo0_l00018ooooo`00<?ooool2o`0000Oooooo00?o0000oooo
ooooool02oooool01Ol0003ooooooooooooooooo000004Wooooo000_ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool4o`0000Cooooo00?o0000ooooooooool0Aoooool002go
oooo0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Oo
oooo000/ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool5o`0000?ooooo
00?o0000ooooooooool0Aoooool002[ooooo0_l0000Oooooo`03o`000?oooooooooo04Oooooo000Y
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Aoooool002Sooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`17ooooo`009oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo04Oooooo000Uooooo`;o00009?ooool00ol0003oooooooooo`17ooooo`009?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Oooooo000Sooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0Aoooool002;ooooo00?o0000ooooooooool07_ooool5o`00
00?ooooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool08?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo04Oooooo000Pooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`17ooooo`007oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00;ooooo0_l00018ooooo`007_ooool00ol0003ooooooooo
o`0Rooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`17ooooo`007Ooo
ool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`17ooooo`006oooool2o`0002Oooooo0ol00004ooooo`03o`000?oooooooooo04Oooooo000J
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Aoooool001Wooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`17ooooo`006?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo04Oooooo000Gooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
Aoooool001Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`17ooooo`005_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo04Oooooo000Eooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0Aoooool001Cooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`17ooooo`004oooool00ol0003oooooooooo`0Qooooo`Go00000oooool00ol0003ooooo
ooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`17ooooo`004_ooool00ol0003ooooooooo
o`0Sooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo04Oooooo000Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
2oooool01?l0003oooooooooooooool2o`0004Sooooo000Aooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000004Wooooo000@ooooo`03o`00
0?oooooooooo02Cooooo00Go0000ooooooooooooooooo`000007ooooo`Co00001?ooool00ol0003o
ooooooooo`17ooooo`003oooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo000>ooooo`03o`00
0?oooooooooo02Oooooo0ol00008ooooo`Go00000oooool00ol0003oooooooooo`17ooooo`003_oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo04Oooooo000=ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0Aoooool000cooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`17ooooo`00Boooool00ol0003oooooooooo`17ooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 225.875}, {217.875, 126.875}} -> {-2.41752, \
4.03047, 0.0157709, 0.0346824}}]
}, Open  ]],

Cell["Errors occur when e is used as if it were E.", "Text"],

Cell[CellGroupData[{

Cell["Plot[ e^(-x), {x,-1,1} ]", "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(e\\^\\(-x\\)\\) is \
not a machine-size real number at \\!\\(x\\) = \\!\\(-0.9999999166666667`\\). \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message",\

  CellLabel->"From In[20]:="],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(e\\^\\(-x\\)\\) is \
not a machine-size real number at \\!\\(x\\) = \\!\\(-0.9188660168541684`\\). \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message",\

  CellLabel->"From In[20]:="],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(e\\^\\(-x\\)\\) is \
not a machine-size real number at \\!\\(x\\) = \\!\\(-0.8303824002812525`\\). \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message",\

  CellLabel->"From In[20]:="],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Plot :: \\\"plnr\\\"\\) will be suppressed during this calculation. \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[20]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{152, 93.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002H0000GB000`400?l00000o`00003oV?ooool0
02Oooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00002_ooool2o`0000Cooooo00?o0000
ooooooooool00oooool3o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000;
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00004?ooool3o`0000Gooooo000Voooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002Oooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo0000013ooooo00?o0000ooooooooool01?ooool002Kooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00009ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00Cooooo000V
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooooooo00001oooool4o`00
00[ooooo00Co0000oooooooooooo00002?ooool3o`00017ooooo00?o0000ooooooooool01?ooool0
02Kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Wooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00000:ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool02oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000004?ooool00ol0003oooooooooo`04ooooo`009_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00009ooooo`;o0000
2_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000oooooo0_l00006ooooo`009oooool2o`00
00Wooooo0ol0000;ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`;o00002_ooool2o`00
00_ooooo0_l00009ooooo`?o00004Oooool00ol0003oooooooooo`04ooooo`005?ooool00ol0003o
ooooooooo`21ooooo`005?ooool00ol0003oooooooooo`21ooooo`004Ooooon5o`0000;ooooo000D
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`005?ooool00ol0003oooooooooo`21ooooo`005?ooool00ol0003oooooooooo`21ooooo`00
5?ooool2o`0008;ooooo000Dooooo`03o`000?oooooooooo087ooooo000Dooooo`03o`000?oooooo
oooo087ooooo000Dooooo`03o`000?oooooooooo087ooooo000Dooooo`;o0000P_ooool001Cooooo
00?o0000ooooooooool0POooool001Cooooo00?o0000ooooooooool0POooool001Cooooo00?o0000
ooooooooool0POooool001Cooooo0_l00022ooooo`000oooool2o`0000Cooooo00Co0000oooooooo
oooooooo1Ol00002ooooo`03o`000?oooooooooo087ooooo0002ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`21ooooo`000_ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0POooool0
00;ooooo00Co0000oooooooooooo00002_ooool01?l0003oooooooooooooool2o`0008;ooooo0002
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo087ooooo0002ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo087ooooo0003ooooo`;o00002Oooool3o`0000?ooooo
00?o0000ooooooooool0POooool001Cooooo0_l00022ooooo`005?ooool00ol0003oooooooooo`21
ooooo`005?ooool00ol0003oooooooooo`21ooooo`005?ooool00ol0003oooooooooo`21ooooo`00
5?ooool2o`0008;ooooo000Dooooo`03o`000?oooooooooo087ooooo000Dooooo`03o`000?oooooo
oooo087ooooo000Dooooo`;o0000P_ooool001Cooooo00?o0000ooooooooool0POooool000?ooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooooooo087ooooo
0002ooooo`04o`000?ooooooooooo`0000[ooooo00Go0000ooooooooooooooooo`000023ooooo`00
0_ooool01?l0003oooooooooool00007ooooo`Go00000_ooool2o`0008;ooooo0002ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`21oooo
o`000_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ooooool0POooool000;ooooo00Co0000oooooooooooo00002Oooool2o`0000?ooooo00?o0000oooo
ooooool0POooool000?ooooo0_l0000;ooooo`04o`000?ooooooooooooooo`;o0000P_ooool001Co
oooo00?o0000ooooooooool0POooool001Cooooo00?o0000ooooooooool0POooool001Cooooo00?o
0000ooooooooool0POooool001Cooooo0_l00022ooooo`005?ooool00ol0003oooooooooo`21oooo
o`005?ooool00ol0003oooooooooo`21ooooo`005?ooool00ol0003oooooooooo`21ooooo`005?oo
ool2o`0008;ooooo0003ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool0
0ol0003oooooooooo`21ooooo`000_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`21ooooo`000_ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`21ooooo`000_oo
ool01?l0003oooooooooool00007ooooo`Co00000oooool2o`0008;ooooo0002ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`21ooooo`000_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
POooool000?ooooo0_l0000:ooooo`;o00000oooool00ol0003oooooooooo`21ooooo`005?ooool2
o`0008;ooooo000Dooooo`03o`000?oooooooooo087ooooo000Dooooo`03o`000?oooooooooo087o
oooo000Dooooo`03o`000?oooooooooo087ooooo000Dooooo`;o0000P_ooool001Cooooo00?o0000
ooooooooool0POooool001Cooooo00?o0000ooooooooool0POooool001Cooooo00?o0000oooooooo
ool0POooool001Cooooo0_l00022ooooo`000oooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000?ooooo00?o0000ooooooooool0POooool000;ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0POooool000;ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00022ooooo`00
0_ooool01?l0003oooooooooool00008ooooo`?o00000oooool00ol0003oooooooooo`21ooooo`00
0_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`21ooooo`000_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`21ooooo`000oooool2o`0000Wooooo0ol00003oooo
o`;o0000P_ooool001Cooooo00?o0000ooooooooool0POooool001Cooooo00?o0000ooooooooool0
POooool001Cooooo00?o0000ooooooooool0POooool001Cooooo0_l00022ooooo`005?ooool00ol0
003oooooooooo`21ooooo`005?ooool00ol0003oooooooooo`21ooooo`005?ooool00ol0003ooooo
ooooo`21ooooo`005?ooool2o`0008;ooooo000>ooooo`?o00000oooool00ol0003oooooooooo`21
ooooo`003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo087ooooo000?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0POooool000oooooo00?o0000ooooooooool0
0_ooool2o`0008;ooooo000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0POoo
ool000kooooo0_l00004ooooo`03o`000?oooooooooo087ooooo000?ooooo`03o`000?oooooooooo
08Kooooo002Hooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 228.875}, {472.75, 379.875}} -> {-0.785209, \
4.75045, 0.00795164, 0.012866}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses Pi for the ratio of the circumference to the diameter of a circle."
}], "Text"],

Cell[CellGroupData[{

Cell["{Pi, N[Pi]}", "Input",
  CellLabel->"In[16]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({\[Pi], 3.141592653589793`}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[ Sin[Pi*x], {x,-1,1} ]", "Input",
  CellLabel->"In[21]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309018 0.294303 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .01471 -12 -4.5 ]
[.4875 .01471 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .01471 m
.50625 .01471 L
s
[(-1)] .4875 .01471 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .23481 L
.10458 .15951 L
.14415 .09914 L
.18221 .05447 L
.20178 .03757 L
.21267 .03011 L
.22272 .0245 L
.23293 .02007 L
.23832 .01827 L
.24402 .01676 L
.24641 .01625 L
.24897 .01579 L
.25119 .01545 L
.25361 .01516 L
.25507 .01501 L
.25643 .01491 L
.25773 .01483 L
.2584 .01479 L
.25912 .01476 L
.25983 .01474 L
.26048 .01473 L
.26176 .01472 L
.26293 .01472 L
.26416 .01475 L
.26538 .01479 L
.26607 .01483 L
.26671 .01486 L
.26912 .01505 L
.27131 .01528 L
.27364 .0156 L
.27847 .01647 L
.2838 .01778 L
.29326 .02099 L
.30213 .02502 L
.32232 .03778 L
.34082 .05371 L
.38045 .10022 L
.41855 .15838 L
.45911 .23059 L
.49816 .30545 L
.53966 .38514 L
.57964 .45663 L
.61811 .51582 L
.63759 .54096 L
.65902 .56418 L
.67938 .58152 L
.69843 .5933 L
.70884 .59785 L
.71396 .5996 L
Mistroke
.71872 .60092 L
.72301 .60186 L
.72758 .60261 L
.7302 .60292 L
.73148 .60304 L
.73266 .60313 L
.73371 .6032 L
.73487 .60325 L
.73603 .60329 L
.73725 .60332 L
.73856 .60332 L
.73977 .6033 L
.7404 .60329 L
.7411 .60326 L
.74251 .6032 L
.74375 .60312 L
.74508 .60301 L
.74748 .60276 L
.74985 .60244 L
.75235 .60202 L
.7568 .60108 L
.76198 .59967 L
.7668 .59806 L
.77773 .59332 L
.78828 .58734 L
.79823 .58046 L
.81683 .5645 L
.85534 .51958 L
.89632 .45703 L
.93577 .38657 L
.97371 .31383 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{162, 100},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002R0000I2000`400?l00000o`00003oX_ooool0
0:;ooooo001:ooooo`?o0000EOooool004_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1>ooooo`00@oooool5o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1>ooooo`00:_ooool8o`0001Wooooo00?o0000ooooooooool00oooool2o`0004oooooo000Voooo
o`Co00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0C_ooool002Gooooo00?o0000ooooooooool02oooool2o`0001Gooooo0_l00005ooooo`03
o`000?oooooooooo04kooooo000Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04kooooo000Sooooo`03o`000?oo
oooooooo013ooooo0_l0000Iooooo`;o0000Coooool002;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04kooooo000Qooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1>ooooo`008Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0C_ooool0023ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04kooooo
000Oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04oooool2o`0004oooooo000N
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1>
ooooo`007Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0C_ooool001cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo04kooooo000Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3oooool2o`0004oooooo000Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1>ooooo`006_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0C_ooool001Wooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo04kooooo000Iooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1>ooooo`006?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00cooooo0_l0001?ooooo`005oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0C_ooool001Oooooo00?o0000
ooooooooool09Oooool2o`0000;ooooo00?o0000ooooool000001?ooool3o`0000Cooooo00?o0000
ooooooooool0C_ooool001Kooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo04kooooo000Eooooo`03o`000?oooooooooo01oooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2o`0004oooooo
000Eooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool00000D?ooool001Cooooo00?o0000ooooooooool0
9oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Co00001?ooool00ol0003o
ooooooooo`1>ooooo`005?ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Co
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1>ooooo`004oooool00ol0003o
ooooooooo`0Yooooo`;o00001_ooool00ol0003oooooo`000004o`0000?ooooo00?o0000oooooooo
ool0C_ooool001;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`;o0000
Coooool001;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04kooooo000Aooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1>ooooo`004Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0C_ooool0013ooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`04ooooo`;o0000Coooool000oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04kooooo000?ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1>ooooo`003_ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool000Wooooo0ol00002oooo
o`03o`000?oooooooooo01Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Eoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0001_ooooo0ol00007ooooo`002_ooool01?l0003oooooooooool0000Joooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oo
oooooooo00;ooooo0_l0000Kooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00000Kooooo`03o`000?oooooooooo00Kooooo0002ooooo`Go00000oooool01?l0003ooooo
ooooool0000Cooooo`Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo
01?ooooo00Go0000ooooooooooooooooo`00000Looooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`002_ooool00ol0003oooooo`00000K
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooo
oooooooo000001cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Kooooo000:ooooo`03o`000?oooooo000001_ooooo00Co0000oooooooooooo
00001oooool4o`0001Oooooo00Co0000oooooooooooo00007?ooool01?l0003oooooooooool00007
ooooo`Co00007?ooool00ol0003oooooooooo`06ooooo`002Oooool3o`0001cooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0Iooooo`04o`000?oooooo0000o`0001_ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`0Looooo`;o00002?ooool000[ooooo00?o
0000ooooooooool07?ooool2o`0000Sooooo1Ol0000Gooooo`03o`000?oooooo000001gooooo0_l0
0008ooooo`Go00006oooool00ol0003oooooooooo`06ooooo`002_ooool00ol0003oooooooooo`13
ooooo`;o0000D?ooool000Wooooo00?o0000ooooooooool0A?ooool2o`00053ooooo0009ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0C_ooool000GoooooV_l00003ooooo`002?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`00DOooool2
o`0004Oooooo00?o0000ooooooooool01Oooool0057ooooo00?o0000ooooool00000AOooool00ol0
003oooooooooo`06ooooo`00DOooool3o`0004Gooooo00?o0000ooooooooool01_ooool0057ooooo
00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`07ooooo`00DOooool01?l0003ooooo
ooooool00013ooooo`03o`000?oooooooooo00Oooooo001Aooooo`04o`000?ooooooooooo`0004;o
oooo00?o0000ooooooooool02?ooool0057ooooo00Go0000ooooooooooooooooo`000010ooooo`03
o`000?oooooooooo00Wooooo001Aooooo`;o00000_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00Wooooo001Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0:ooooo`00DOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool02_ooool0057ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00_ooooo001Aooooo`;o00001?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00_ooooo001Aooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0<ooooo`00DOooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03?ooool0057ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo001Aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=oooo
o`00DOooool2o`0000Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`00
DOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
3oooool003oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0?ooooo`00?_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool003kooooo00Co
0000oooooooooooo00002oooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0@ooooo`00?_ooool01?l0003oooooooooool0000;ooooo`05
o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
017ooooo000nooooo`04o`000?ooooooooooo`0000Oooooo1?l00004ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`00?_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01;ooooo000oooooo`;o00002?ooool5o`0000?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01?o
oooo001Aooooo`;o00003?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo
001Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Dooooo`00DOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool05Oooool0057ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01Gooooo001Aooooo`;o00003oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01Kooooo001Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Gooooo`00DOooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool05oooool0057ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Sooooo001Aooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`00DOooool2o`0001?o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Jooooo`00DOooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool0057ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo001A
ooooo`03o`000?oooooooooo01Gooooo0_l0000Gooooo`03o`000?oooooooooo01gooooo001Aoooo
o`;o00006?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01kooooo001Aooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Oooooo`00
B_ooool3o`0000Cooooo00?o0000ooooooooool06Oooool3o`0000kooooo0_l0000Rooooo`00Booo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?oo
ool3o`0002Cooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool2
o`0000Kooooo0_l0000Wooooo`00Boooool00ol0003oooooooooo`03ooooo`;o00008?ooool6o`00
02Wooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool004[ooooo
0_l00005ooooo`03o`000?oooooooooo04kooooo001;ooooo`03o`000?oooooooooo05Cooooo002R
ooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 238.875}, {670.75, 571.75}} -> {-2.19138, \
11.6057, 0.0137344, 0.0222226}}]
}, Open  ]],

Cell["Errors occur when pi is used as if it were Pi.", "Text"],

Cell[CellGroupData[{

Cell["Plot[ Sin[pi*x], {x,-1,1} ]", "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(Sin[\\(\\(pi\\\\ \
x\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(-0.9999999166666667`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[22]:="],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(Sin[\\(\\(pi\\\\ \
x\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(-0.9188660168541684`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[22]:="],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(Sin[\\(\\(pi\\\\ \
x\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(-0.8303824002812525`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[22]:="],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Plot :: \\\"plnr\\\"\\) will be suppressed during this calculation. \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[22]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  ImageSize->{162, 100},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002R0000I2000`400?l00000o`00003oX_ooool0
02Wooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00003?ooool2o`0000Cooooo00?o0000
ooooooooool00oooool3o`0000cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000=
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00004_ooool3o`0000Gooooo000Xoooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002oooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000_ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000001;ooooo00?o0000ooooooooool01?ooool002Sooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Oooooo1Ol0000;ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00Cooooo000X
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool02_ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000cooooo00Co0000oooooooooooo00001oooool4o`00
00cooooo00Co0000oooooooooooo00002?ooool3o`0001?ooooo00?o0000ooooooooool01?ooool0
02Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00000<ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000004_ooool00ol0003oooooooooo`04ooooo`00:?ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000002oooool01?l0003oooooooooool00009ooooo`;o0000
3?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo0000017ooooo0_l00006ooooo`00:Oooool2o`00
00Wooooo0ol0000=ooooo`;o00002oooool00ol0003oooooooooo`0;ooooo`;o00002_ooool2o`00
00gooooo0_l00009ooooo`?o00004oooool00ol0003oooooooooo`04ooooo`00X_ooool001Cooooo
00?o0000ooooooooool0Roooool001Cooooo00?o0000ooooooooool0Roooool0017oooooSol00002
ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool001Cooooo00?o0000ooooooooool0Roooool001Cooooo00?o0000ooooooooool0
Roooool001Cooooo0_l0002<ooooo`005?ooool00ol0003oooooooooo`2;ooooo`005?ooool00ol0
003oooooooooo`2;ooooo`005?ooool00ol0003oooooooooo`2;ooooo`005?ooool00ol0003ooooo
ooooo`2;ooooo`005?ooool2o`0008cooooo000Dooooo`03o`000?oooooooooo08_ooooo000Doooo
o`03o`000?oooooooooo08_ooooo000Dooooo`03o`000?oooooooooo08_ooooo000Dooooo`;o0000
S?ooool001Cooooo00?o0000ooooooooool0Roooool000?ooooo0_l00004ooooo`04o`000?oooooo
ooooooooo`Go00000_ooool00ol0003oooooooooo`2;ooooo`000_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Roooool000;ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`;o0000S?ooool000;ooooo00Co
0000oooooooooooo00002_ooool01Ol0003ooooooooooooooooo000008gooooo0002ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
08_ooooo0002ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo08_ooooo0003ooooo`;o00002Oooool3o`0000?ooooo0_l0002<oooo
o`005?ooool00ol0003oooooooooo`2;ooooo`005?ooool00ol0003oooooooooo`2;ooooo`005?oo
ool00ol0003oooooooooo`2;ooooo`005?ooool2o`0008cooooo000Dooooo`03o`000?oooooooooo
08_ooooo000Dooooo`03o`000?oooooooooo08_ooooo000Dooooo`03o`000?oooooooooo08_ooooo
000Dooooo`03o`000?oooooooooo08_ooooo000Dooooo`;o0000S?ooool000?ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooooooo08_ooooo0002ooooo`04
o`000?ooooooooooo`0000[ooooo00Go0000ooooooooooooooooo`00002=ooooo`000_ooool01?l0
003oooooooooool00007ooooo`Go00000_ooool00ol0003oooooooooo`2;ooooo`000_ooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000?ooooo0_l0002<ooooo`000_ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0Rooo
ool000;ooooo00Co0000oooooooooooo00002Oooool2o`0000?ooooo00?o0000ooooooooool0Rooo
ool000?ooooo0_l0000;ooooo`05o`000?ooooooooooooooool00000SOooool001Cooooo0_l0002<
ooooo`005?ooool00ol0003oooooooooo`2;ooooo`005?ooool00ol0003oooooooooo`2;ooooo`00
5?ooool00ol0003oooooooooo`2;ooooo`005?ooool2o`0008cooooo000Dooooo`03o`000?oooooo
oooo08_ooooo000Dooooo`03o`000?oooooooooo08_ooooo000Dooooo`03o`000?oooooooooo08_o
oooo000Dooooo`;o0000S?ooool001Cooooo00?o0000ooooooooool0Roooool000?ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooooooo08_ooooo0002oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo08_ooooo0002ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo08_ooooo0002ooooo`04o`000?ooooooooooo`0000Oooooo
1?l00003ooooo`;o0000S?ooool000;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08_ooooo0002ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2;ooooo`000oooool2o`0000[ooooo0_l0
0003ooooo`03o`000?oooooooooo08_ooooo000Dooooo`;o0000S?ooool001Cooooo00?o0000oooo
ooooool0Roooool001Cooooo00?o0000ooooooooool0Roooool001Cooooo00?o0000ooooooooool0
Roooool001Cooooo0_l0002<ooooo`005?ooool00ol0003oooooooooo`2;ooooo`005?ooool00ol0
003oooooooooo`2;ooooo`005?ooool00ol0003oooooooooo`2;ooooo`005?ooool2o`0008cooooo
000Dooooo`03o`000?oooooooooo08_ooooo0003ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00000oooool00ol0003oooooooooo`2;ooooo`000_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`2;ooooo`000_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000_ooool2o`0008cooooo
0002ooooo`04o`000?ooooooooooo`0000Sooooo0ol00003ooooo`03o`000?oooooooooo08_ooooo
0002ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo08_ooooo0002ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo08_ooooo0003ooooo`;o00002Oooool3o`0000?o
oooo0_l0002<ooooo`005?ooool00ol0003oooooooooo`2;ooooo`005?ooool00ol0003ooooooooo
o`2;ooooo`005?ooool00ol0003oooooooooo`2;ooooo`005?ooool00ol0003oooooooooo`2;oooo
o`005?ooool2o`0008cooooo000Dooooo`03o`000?oooooooooo08_ooooo000Dooooo`03o`000?oo
oooooooo08_ooooo000Dooooo`03o`000?oooooooooo08_ooooo000Dooooo`;o0000S?ooool000ko
oooo0ol00003ooooo`03o`000?oooooooooo08_ooooo000?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Roooool000oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2;ooooo`003oooool00ol0003oooooooooo`02ooooo`;o0000S?ooool000oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2;ooooo`003_ooool2o`0000Cooooo00?o0000oooooooo
ool0Roooool000oooooo00?o0000ooooooooool0T?ooool00:;ooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 238.875}, {314.875, 215.875}} -> {-0.729625, \
2.44975, 0.007382, 0.0119443}}]
}, Open  ]],

Cell["\<\
Moral: When you get a strange result or a syntax error and  there \
doesn't seem to be anything wrong, look back in your  worksheet to see if you \
used the wrong spelling for \[Pi] or  perhaps entered e^x instead of Exp[x] \
or E^x.\
\>", "Text"],

Cell[TextData[StyleBox["Some encouraging words help abounds", \
"Subsubsection"]], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s help facility is top notch and we hope you become accustomed to using \
it. Anytime a  function seems to be acting up, or you want to learn about a \
new process, check the examples in the Help Browser. Just highlight the \
procedure name in the Notebook, pull down the ",
  StyleBox["Help",
    FontWeight->"Bold"],
  " menu, and choose the second item: ",
  StyleBox["Find Selected Function...",
    FontWeight->"Bold"],
  " .  The help system is set up as a browser encouraging you to explore \
related issues, feel free. You can navigate back and forth between help pages \
by clicking on the arrow icons at the top of the Help browser window. "
}], "Text"],

Cell[TextData[StyleBox["Take a tour", "Subsubsection"]], "Text"],

Cell[TextData[{
  "If you have not done so already, consider taking tour. You may select ",
  StyleBox["Tour",
    FontWeight->"Bold"],
  " directly from the left pane of the ",
  StyleBox["Help Browser",
    FontWeight->"Bold"],
  ". We also recommend the ",
  StyleBox["Tour of Mathematica",
    FontWeight->"Bold"],
  " available by first selecting ",
  StyleBox["The Mathematica Book",
    FontWeight->"Bold"],
  " in the left pane."
}], "Text"]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{703, 796},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 143, 3, 33, "Text"],
Cell[1900, 56, 75, 0, 28, "Text"],
Cell[1978, 58, 848, 16, 128, "Text"],
Cell[2829, 76, 92, 1, 28, "Text"],
Cell[2924, 79, 355, 7, 68, "Text"],
Cell[3282, 88, 175, 6, 28, "Text"],
Cell[3460, 96, 353, 12, 48, "Text"],
Cell[3816, 110, 654, 13, 108, "Text"],
Cell[4473, 125, 214, 8, 28, "Text"],
Cell[4690, 135, 851, 18, 128, "Text"],
Cell[5544, 155, 952, 18, 108, "Text"],
Cell[6499, 175, 94, 1, 28, "Text"],
Cell[6596, 178, 422, 10, 68, "Text"],
Cell[7021, 190, 206, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[7252, 199, 76, 2, 31, "Input"],
Cell[7331, 203, 96, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7464, 210, 91, 2, 31, "Input"],
Cell[7558, 214, 11007, 344, 100, 3296, 244, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[18580, 561, 60, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[18665, 565, 66, 1, 31, "Input"],
Cell[18734, 568, 363, 6, 26, "Message"],
Cell[19100, 576, 363, 6, 26, "Message"],
Cell[19466, 584, 363, 6, 26, "Message"],
Cell[19832, 592, 358, 6, 42, "Message"],
Cell[20193, 600, 9970, 292, 102, 2862, 199, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[30178, 895, 156, 4, 28, "Text"],

Cell[CellGroupData[{
Cell[30359, 903, 78, 2, 31, "Input"],
Cell[30440, 907, 86, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30563, 914, 69, 1, 31, "Input"],
Cell[30635, 917, 14179, 410, 108, 3929, 278, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[44829, 1330, 62, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[44916, 1334, 69, 1, 31, "Input"],
Cell[44988, 1337, 376, 6, 26, "Message"],
Cell[45367, 1345, 376, 6, 26, "Message"],
Cell[45746, 1353, 376, 6, 26, "Message"],
Cell[46125, 1361, 358, 6, 42, "Message"],
Cell[46486, 1369, 10169, 294, 109, 2862, 199, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[56670, 1666, 257, 5, 48, "Text"],
Cell[56930, 1673, 90, 1, 28, "Text"],
Cell[57023, 1676, 735, 15, 108, "Text"],
Cell[57761, 1693, 64, 0, 28, "Text"],
Cell[57828, 1695, 449, 14, 68, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

