(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16095,        328]*)
(*NotebookOutlinePosition[     17177,        363]*)
(*  CellTagsIndexPosition[     17133,        359]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Technology Manual\n",
  StyleBox["by\nDonald Hartig\nDepartment of Mathematics\nCalifornia \
Polytechnic State Unversity\nSan Luis Obispo, CA\n\nto acompany\n\n", 
    "Subsubtitle"],
  StyleBox["Differential Equations and Mathematical  Modeling", "Subsubtitle",
    
    FontSlant->"Italic"],
  StyleBox[" by Glenn Ledder", "Subsubtitle"]
}], "Title",
  TextAlignment->Center],

Cell["\<\










Copyright \[Copyright]2005 by The McGraw-Hill Companies, Inc. All rights \
reserved. No part of this publication may be reproduced or distributed in any \
form or by any means, or stored in a database or retrieval system, without \
the prior written consent of The McGraw-Hill Companies, Inc., including, but \
not limited to, in any network or other electronic storage or transmission, \
or broadcast for distance learning.\
\>", "Text",
  PageBreakBelow->True],

Cell[TextData[{
  StyleBox["Preface\n", "Subsection"],
  "This manual provides a straightforward and practical introduction to the \
computer algebra system ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for students and instructors who wish to use it in the study of ordinary \
differential equations. Readers will find what they need to get a quick start \
with the program in the context of simple numerical calculations, fundamental \
calculus computations, and elementary graphing techniques. Applications are \
interwoven with explanations of how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " works and examples illustrating the important features of this important \
software tool. \nOnce a sufficient level of confidence has been attained, the \
reader is guided through ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " procedures designed to solve differential equations, analyze the behavior \
of solutions, and use solutions, both exact and approximate, in the \
mathematical modeling process. The exercises can be used to clarify the \
reader's understanding of how the procedures work. Annotated examples guide \
the reader through the more challenging problems.\n",
  StyleBox["Prerequisites and Corequisites\n", "Subsection"],
  "Instructions in the manual are written with the assumption that the reader \
knows how to start a computer and make a document using a word processor. The \
ability to use a mouse: point and click, select and drag, pull down a menu, \
etc. will be taken for granted. The only mathematics prerequisite is the \
successful completion of a university level calculus course or its \
equivalent. As a corequisite it is hoped that the reader is actively engaged \
in the learning of the fundamentals of ordinary differential equations. \
Please note that this is not a text in differential equations. Indeed, the \
reader will often be referred to a differential equations textbook (Ledder) \
for statements of definitions, algorithms, solution techniques, and solution \
formulas, as well as background material for some of the examples and \
exercises."
}], "Text",
  PageBreakBelow->True],

Cell[TextData[{
  StyleBox["Part I. The ", "Subsection"],
  StyleBox["Mathematica", "Subsection",
    FontSlant->"Italic"],
  StyleBox[" Notebook\n", "Subsection"],
  "This is a brief overview of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s notebook interface. The essential components of a notebook are \
described and simple examples illustrate how to enter and process mathematics \
and text.\n",
  StyleBox["Part II. Calculations and Calculus with ", "Subsection"],
  StyleBox["Mathematica", "Subsection",
    FontSlant->"Italic"],
  StyleBox["\n", "Subsection"],
  "The second part contains a more detailed introduction to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and how to use it to \"do mathematics.\" The input/output paradigm is \
stressed as the reader learns how to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as a calculator. The very useful Table function is discussed. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " output can be used as subsequent input by assigning the output a name, \
and then referring to it by that name just as one might do using paper and \
pencil. The notion of assignments are important for the successful use of any \
mathematics software to a problem that requires more than one calculation. \
This idea is illustrated several times using familiar examples from calculus. \
Graphing examples introduce plotting procedures.\n",
  StyleBox["Part III. First Order Ordinary Differential Equations\n", 
    "Subsection"],
  "The discussion of differential equations in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " starts here in the context of mathematical models requiring first order \
equations in their analysis. Readers who are already familiar with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " are encouraged to skim over Parts I and II and begin in Part III. \
Direction fields and exact solution curves are plotted. Implementation of \
Euler's method provides the reader with an opportunity to learn how to write \
a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program that can easily be converted into a user-defined procedure.\n",
  StyleBox["Part IV. Linear Differential Equations\n", "Subsection"],
  "Linear differential equations, linear systems, and Laplace transforms are \
featured in this part of the manual. Procedures in the LinearAlgebra package \
are introduced to handle vectors and matrices gracefully. \n",
  StyleBox["Exercises\n", "Subsection"],
  "Exercise sets are divided by Part and Section. Solutions to asterisked \
exercises appear in the solution section.\n",
  StyleBox["Appendix\n", "Subsection"],
  "The appendix, which itself is divided into parts 1 - 5 contains \
miscellaneous items that did not fit nicely into Part I, II, III, or IV: \
Power series and special functions, Picard iterates, Partial differential \
equations, and some Sound advice and encouraging words. \n",
  StyleBox["Solutions to Selected Exercises\n", "Subsection"],
  "A list of solutions to the exercises that appear with an asterisk.\n\nThe \
Table of Contents that follows is detailed enough to be used as a complete \
outline of the topics that are treated in the manual."
}], "Text",
  CellDingbat->None,
  PageBreakBelow->True],

Cell[TextData[{
  StyleBox["Table of Contents\n", "Subsection"],
  StyleBox["Part I. The ",
    FontFamily->"Courier",
    FontSize->10],
  StyleBox["Mathematica",
    FontFamily->"Courier",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox[" Notebook\n  Section 1. Cells: \
Input/Output............................................1\n    Input \
comments: Use a hash mark #.......................................1\n    The \
pull down menus.....................................................2\n  \
Section 2. Entering Text..................................................4\n \
   Annotating input and output: An example.................................4\n\
    Undo it: Command-Z......................................................5\
\n    Delete all of it: Select the cell bracket and press \
[delete]............5\nPart II. Calculations and Calculus with ",
    FontFamily->"Courier",
    FontSize->10],
  StyleBox["Mathematica",
    FontFamily->"Courier",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox["\n  Section 1. Getting Started: ",
    FontFamily->"Courier",
    FontSize->10],
  StyleBox["Mathematica",
    FontFamily->"Courier",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox[" as a Calculator...................6\n    Parentheses for \
grouping must be the round kind: ().....................8\n    Lists in ",
    FontFamily->"Courier",
    FontSize->10],
  StyleBox["Mathematica",
    FontFamily->"Courier",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox["....................................................9\n    The \
Table function......................................................9\n    \
Using the Table function...............................................10\n   \
 The Table function is very versatile...................................11\n  \
  Moving towards symbolic calculations: Factoring in ",
    FontFamily->"Courier",
    FontSize->10],
  StyleBox["Mathematica",
    FontFamily->"Courier",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox[".........12\n  Section 2. Symbolics: Equations and \
Assignments..........................14\n    Variables, equations, and \
assignments..................................14\n    Solving equations \
exactly: The Solve function .........................16\n    Approximate \
solutions using NSolve and FindRoot........................17\n    More about \
Solve and FindRoot..........................................18\n    Using \
variables as functions...........................................20\n  \
Section 3. Functions as Transformations..................................23\n \
   Using a transformation to define a function............................23\n\
    Plot several tangent lines.............................................25\
\n    Find the length of the \
curve...........................................26\n    An area \
calculation....................................................28\n    Higher \
derivatives.....................................................29\n    \
Unevaluated derivatives................................................31\n   \
 The chain rule.........................................................31\n  \
  Just a little bit about differential equations.........................32\n \
   Working with the solution..............................................33\n\
    Getting at the solution formula........................................33\
\nPart III. First Order Ordinary Differential Equations\n  Section 1. \
Entering and Solving..........................................35\n    Solve \
this: DSolve.....................................................35\n    \
Checking the solution..................................................35\n   \
 Plotting solution curves...............................................36\n  \
  Solving an initial value problem.......................................36\n \
   Getting information out of the solution formula........................37\n\
    A solution formula in terms of the initial condition...................38\
\n    Look before you \
leap...................................................40\n  Section 2. \
Working with Solutions: Modeling..............................45\n    \
Exponential Models.....................................................45\n   \
 A more interesting problem.............................................46\n  \
  Monthly payments.......................................................48\n \
   Heating and cooling....................................................48\n\
    Variable ambient temperataure..........................................50\
\n  Section 3. Slope \
Fields..................................................54\n    The tool you \
need: PlotVectorField.....................................54\n    Keep your \
eye on f(t,y)................................................57\n  Section 4. \
Approximate Solutions.........................................61\n    One \
step at a time: Euler's algorithm..................................61\n    \
Make it yours: User defined procedures.................................63\n   \
 Modify it: The Euler two step algorithm................................65\n  \
  Using NDSolve to generate numeric solutions............................66\n \
   A preview of second order equations: An aging spring...................68\n\
Part IV. Linear Differential Equations\n  Section 1. Linear \
Oscillators............................................70\n    Solve this \
too: DSolve and the unforced equation.......................70\n    The phase \
plane trajectory.............................................72\n    Simple \
harmonic motion.................................................74\n    The \
phase plane trajectory for underdamped oscillations................76\n    \
Phase plane trajectories and vector fields.............................78\n  \
Section 2. State Space...................................................81\n \
   Autonomous equations...................................................81\n\
    Force it: A non-autonomous equation....................................83\
\n    State space trajectories: The ParametricPlot3D \
function................86\n    Numerical solutions: \
NDSolve...........................................88\n  Section 3. Two \
Dimensional Systems.......................................91\n    Fields and \
flows.......................................................91\n    \
Estimating the period: Numeric data....................................93\n   \
 Nullclines, critical points............................................95\n  \
  Symbolic solutions, integral curves....................................96\n \
   Linear systems, linear flows...........................................98\n\
  Section 4. Matrix Methods...............................................101\
\n    Matrices and \
Vectors..................................................101\n    \
Eigenvectors and eigenvalues..........................................105\n   \
 Eigenvector solutions to v' = Av......................................107\n  \
  The matrix exponential................................................109\n \
   A three dimensional example, approximate solutions....................109\n\
  Section 5. The Laplace Transform........................................112\
\n    Laplace transforms and the inverse Laplace \
transform..................112\n    Typical driver: Off, then on, then off \
again..........................114\n    The Dirac delta: \
DiracDelta...........................................116\n    Applying the \
Laplace transform method to a linear system..............117\nExercises\n\
Appendices\n  A1. Power Series and Special Functions\n  A2. Picard Iteration\n\
  A3. Partial Differential Equations\n  A4. Sound advice and encouraging \
words\nSelected Solutions",
    FontFamily->"Courier",
    FontSize->10]
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{671, 800},
WindowMargins->{{5, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageHeaderLines->{False, False},
PageFooterLines->{Inherited, False},
PrintingOptions->{"FirstPageFooter"->False,
"FacingPages"->False},
CellLabelAutoDelete->False,
ShowCellTags->True,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 449, 12, 338, "Title"],
Cell[2228, 67, 482, 18, 408, "Text",
  PageBreakBelow->True],
Cell[2713, 87, 2165, 37, 438, "Text",
  PageBreakBelow->True],
Cell[4881, 126, 3293, 65, 815, "Text",
  PageBreakBelow->True],
Cell[8177, 193, 7902, 132, 2540, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

