(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8298,        279]*)
(*NotebookOutlinePosition[     10583,        349]*)
(*  CellTagsIndexPosition[     10539,        345]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part 1. The ", "Section"],
  StyleBox["Mathematica", "Section",
    FontSlant->"Italic"],
  StyleBox[" Notebook", "Section"],
  "\n",
  StyleBox["Section 2. Mixing Text and Mathematics", "Subsection"],
  "\nAs a general rule a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook consists of alternating text and mathematics (input and output). \
Here is a typical example.\n ",
  StyleBox["Annotating input and output: An example\n ", "Subsubsection"],
  StyleBox["Use Mathematica to find an antiderivative for the function",
    FontSlant->"Italic"],
  " y = ",
  Cell[BoxData[
      \(TraditionalForm\`\(tan(x)\)\/\(sin(x)\)\^4\)]],
  StyleBox["and verify that it differentiates to",
    FontSlant->"Italic"],
  " y .\nThe following input entry defines the ",
  StyleBox["y",
    FontSlant->"Italic"],
  " variable as a function of ",
  StyleBox["x",
    FontSlant->"Italic"],
  ". We made it by pressing the down arrow, typing \"y = Tan[x]/Sin[x]^2\" \
and pressing [shift]-[return] ([shift]-[Enter] on a PC). Once the entry is \
processed an Input paragraph is automatically inserted. The text entry was \
made by choosing Text on the pop up paragraph style menu. (Remember to select \
",
  StyleBox["Show Ruler",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Show Toolbar",
    FontWeight->"Bold"],
  " on the ",
  StyleBox["Format",
    FontWeight->"Bold"],
  " menu."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["y=Tan[x]/Sin[x]^4", "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(Csc[x]\^3\ Sec[x]\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[TextData[{
  "Note that a function definition like this is made with the equals sign \
just as you would write it with paper and pencil. Note also that both the \
tangent function and the sin function must be capitalized in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Moreover, the argument x must be placed inside of square brackets. \
Finally, you will observe that when ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " processed the input it \"simplified\" the fraction using trig identities.\
\nOnce ",
  StyleBox["y",
    FontSlant->"Italic"],
  " is defined as a function of ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", an antiderivative function ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " can be defined as follows."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Y=Integrate[y,x]", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ Csc[x]\^2 - Log[Cos[x]] + Log[Sin[x]]\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[TextData[{
  "It is certainly not obvious that the function ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " differentiates to ",
  StyleBox["y",
    FontSlant->"Italic"],
  ". A check that it does might go like this.\nFirst differentiate ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " with respect to ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", naming the derivative function Y'. Note that the syntax for \
differentiation is simply D[Y,x]."
}], "Text",
  TextJustification->0],

Cell[CellGroupData[{

Cell["Y'=D[Y,x]", "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(Cot[x] + Cot[x]\ Csc[x]\^2 + Tan[x]\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Y'",
    FontSlant->"Italic"],
  " should be the same function as ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", but its formula does not look like the one defining ",
  StyleBox["y",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Simplify procedure could be useful here. Apply it to ",
  StyleBox["Y'",
    FontSlant->"Italic"],
  " with the entry"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["Simplify[Y']", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Simplify[Y']", "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Csc[x]\^3\ Sec[x]\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "The output is identical to the \"simplified\" version of ",
  StyleBox["y",
    FontSlant->"Italic"],
  ". This shows that ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " is an antiderivative for ",
  StyleBox["y",
    FontSlant->"Italic"],
  ".\n",
  StyleBox["End of Example",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell["\<\
So, the question is, how to get a text cell after an input/output \
cell?
Answer: Click in the white space below the output and use the pop up style \
menu to change the paragraph style from Input to Text.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Question: How to I insert a Text cell or Input/Output between two \
cells?
Answer: Click between the cells, note that the paragraph style is Input so \
just type away if you want to make a mathematics entry. If you want a text \
entry just use the pop up style menu to choose the style you want.\
\>", \
"Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Note. Paragraph styles can also be accessed on the ", 
    "SmallText"],
  StyleBox["Format/Style", "SmallText",
    FontWeight->"Bold"],
  StyleBox[" menu. Pull it down now and you will also discover the keyboard \
equivalent for each paragraph style. Press Command-7 for the Text style and \
Command-9 for the Input style. ", "SmallText"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Hint. ",
  StyleBox["If you are in a text cell and want another text cell to follow, \
you can do it quickly by pressing Option-[return].", "SmallText"]
}], "Text"],

Cell[TextData[{
  StyleBox["Undo it: Command-Z\n",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses the standard keyboard equivalents for Copy: Command-C, Paste: \
Command-V, Cut (and copy): Command-X and Undo: Command-Z. Command-Z can be \
especially useful for editing out typing mistakes. Of course you can also \
just press [delete]. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Delete all of it: Select the cell bracket and press [delete]",
    FontWeight->"Bold"],
  "\nIf you wish to delete a whole cell, select the cell bracket on the right \
and press the [delete] key. Remember, if you delete something then see that \
you made a mistake press Command-Z to undo the deletion."
}], "Text",
  TextAlignment->Left,
  TextJustification->0]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{649, 756},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->4,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "   Page  ", 
          CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "   Page  ", 
          CounterBox[ "Page"]}], "Footer"], None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 1479, 42, 278, "Text"],

Cell[CellGroupData[{
Cell[3258, 97, 58, 1, 31, "Input"],
Cell[3319, 100, 75, 2, 30, "Output"]
}, Open  ]],
Cell[3409, 105, 824, 23, 120, "Text"],

Cell[CellGroupData[{
Cell[4258, 132, 57, 1, 31, "Input"],
Cell[4318, 135, 110, 2, 45, "Output"]
}, Open  ]],
Cell[4443, 140, 491, 16, 80, "Text"],

Cell[CellGroupData[{
Cell[4959, 160, 50, 1, 31, "Input"],
Cell[5012, 163, 93, 2, 30, "Output"]
}, Open  ]],
Cell[5120, 168, 484, 18, 48, "Text"],
Cell[5607, 188, 77, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[5709, 194, 53, 1, 31, "Input"],
Cell[5765, 197, 75, 2, 30, "Output"]
}, Open  ]],
Cell[5855, 202, 342, 14, 59, "Text"],
Cell[6200, 218, 276, 7, 80, "Text"],
Cell[6479, 227, 368, 9, 80, "Text"],
Cell[6850, 238, 427, 10, 38, "Text"],
Cell[7280, 250, 183, 4, 30, "Text"],
Cell[7466, 256, 435, 11, 84, "Text"],
Cell[7904, 269, 390, 8, 66, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

