(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27854,       1136]*)
(*NotebookOutlinePosition[     30302,       1212]*)
(*  CellTagsIndexPosition[     30213,       1206]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part II. Calculations and Calculus with ", "Section"],
  StyleBox["Mathematica", "Section",
    FontSlant->"Italic"],
  "\n",
  StyleBox["Section 1. Getting Started: ", "Subsection"],
  StyleBox["Mathematica", "Subsection",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["as a Calculator", "Subsection"],
  " \n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is one of a handful of computer software applications that \"does \
mathematics\". It works following an  input/output paradigm. The user types \
the input in an Input cell, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " processes the  input and returns the result, referred to as the output. \
An input cell appears automatically at the end of every worksheet and can be \
obtained anywhere by clicking between cells. \nTo add 1 and 2  below, we \
clicked below this text cell, typed \"1+2\" and then pressed the \
[shift]-[return] key. PC users,  press the [shift]-[Enter] key. \nThe input \
is displayed on the computer screen in a bold monospaced font.  The output \
appears directly below the input."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1+2", "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["About the input",
    FontWeight->"Bold"],
  ". When an input entry is made with no trailing punctuation ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " processes it and places the output in an output cell. Several entries can \
be made in one input cell. Simply press the [return] key and type in another \
entry. If a particular entry is terminated with a semicolon ( ; ) then ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will process the entry but will not show the output. The output is said \
to be suppressed.\nThe next input cell contains three entries asking for \
three square roots. Multiplication is specified with an asterisk  * (shift-8) \
and exponentiation with the carat symbol ^ (shift-6). The multiplication sign \
can be omitted and replaced by a space if so desired. The square root \
function is denoted Sqrt (remember, square brackets must be used for all ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions)j."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Sqrt[2*3]
Sqrt[5]; 
Sqrt[3^4]\
\>", "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(\@6\)], "Output",
  CellLabel->"Out[134]="],

Cell[BoxData[
    \(9\)], "Output",
  CellLabel->"Out[136]="]
}, Open  ]],

Cell[TextData[{
  "All three square roots were processed, but only the first and third \
outputs are shown because the second entry terminated with a semicolon \
suppressing the output.\nThe entry Sqrt[3*2] outputs as ",
  Cell[BoxData[
      \(TraditionalForm\`\@6\)]],
  " , the exact value. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " always attempts to return exact values, if exact values are entered. \
Compare the first output to the output for the entry"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["Sqrt[2*3.0]", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Sqrt[2*3.0]", "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(2.449489742783178`\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " interprets Sqrt[2*3.0] as an approximate input and returns an approximate \
output in what is called \"floating point form\" (6 digit accuracy is the \
default). It is often desirable to have floating point output even though the \
input is exact. In that case use the N function ( evaluate as a floating \
point number) as follows."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["(Sqrt[20]+Sqrt[30])/(Sqrt[5]+Sqrt[7])", "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(\(2\ \@5 + \@30\)\/\(\@5 + \@7\)\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["This is an exact value. The entry", "Text"],

Cell["N[%]", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
will output the number in 6 digit floating point form. The percent \
sign refers to the most recent output.\
\>", "Text"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(2.03804379923639`\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["\<\
If a 4 digit approximation is adequate, then enter the following. \
Two percent signs refer to the second to most  recent output. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["N[%%,4]", "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(2.0380437992363900839`3.9999999999999996\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "The next entry generates a 60 digit approximation to \[Pi]. Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["Pi", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
to denote the mathematical constant \[Pi]. Be sure to capitalize \
the p.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Pi
N[Pi,60]\
\>", "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(\[Pi]\)], "Output",
  CellLabel->"Out[31]="],

Cell[BoxData[
    \(3.1415926535897932384626433832795028841971693993751058209749445923078163\
4669469`60. \)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[TextData[{
  "Note that the output for Pi is \[Pi].\nA 10 digit approximation to the \
famous number ",
  StyleBox["e",
    FontSlant->"Italic"],
  " appears next. There are two ways to get ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to output ",
  StyleBox["e",
    FontSlant->"Italic"],
  ". One way is to enter E. The other way is to apply the exponential \
function Exp to the number 1. These ideas are illustrated below. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
E
N[E,10]\
\>", "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(\[ExponentialE]\)], "Output",
  CellLabel->"Out[25]="],

Cell[BoxData[
    \(2.7182818284590452349`10. \)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
  "Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " prints e in its output as \[ExponentialE] . The same output can be \
obtained as follows"
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Exp[1]
N[Exp[1],10]\
\>", "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(\[ExponentialE]\)], "Output",
  CellLabel->"Out[29]="],

Cell[BoxData[
    \(2.7182818284590452349`10. \)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parentheses for grouping must be the round kind: ( )", "Subsubsection"],

Cell["\<\
Parentheses are often essential when entering complicated \
expressions. For example, the calculation of \
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(2\^50 - 1\)\/\(2\^49 + 1\)\)]]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["must be made as follows.", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["(2^50-1)/(2^49+1)", "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(375299968947541\/187649984473771\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[TextData[{
  "As usual, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " outputs the exact value. Here is the same number in floating point form \
(10 digits)."
}], "Text"],

Cell[CellGroupData[{

Cell["N[%,10]", "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(1.9999999999999946709294817993`9.999999999999998\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell["And here is the 20 digit floating point form.", "Text"],

Cell[CellGroupData[{

Cell["N[%%,20]", "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(1.99999999999999467092948179925807229743`20. \)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[{
  "When grouping terms in an entry, never use square brackets, [ ] , or set \
brackets, {}. Square brackets are reserved in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to enter arguments in functions and set brackets are used to make lists \
of things like"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["{ milk, eggs, sugar, butter }", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Likewise, all of the familiar functions that you know from your calculus \
days should be entered into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  using square brackets and they must be capitalized. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is case sensitive.  "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["x=Sin[Pi/3] - Log[2] + Exp[4]", "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(\@3\/2 + \[ExponentialE]\^4 - Log[2]\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[TextData[{
  "Observe that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " simplified Sin[Pi/3] because it has a nice exact form. The following \
entry puts ",
  StyleBox["x",
    FontSlant->"Italic"],
  " into floating point form (5 digits). "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["N[x,5]", "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(54.7710282565595539084`5.000000000000002\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[TextData[{
  "Log[2] is the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s notation for the base ",
  StyleBox["e",
    FontSlant->"Italic"],
  " or ",
  StyleBox["natural",
    FontSlant->"Italic"],
  " logarithm. ",
  "If a base b logarithm is needed, b positive and not 1, use  square \
brackets to enter  "
}], "Text"],

Cell["Log[b,x]", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["as illustrated below.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Log[10,100]
Log[2,256]\
\>", "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(2\)], "Output",
  CellLabel->"Out[42]="],

Cell[BoxData[
    \(8\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Lists in ", "Subsection"],
  StyleBox["Mathematica", "Subsection",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "Several expressions, entered as a sequence separated by commas, and \
enclosed in set brackets, is called a ",
  StyleBox["list",
    FontSlant->"Italic"],
  ". Lists can be made easily using the Table function. These ideas are \
illustrated below.\nThe next input cell enters the list of the first four \
factorials."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["{1!, 2!, 3!, 4! }", "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \({1, 2, 6, 24}\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell[TextData[{
  "Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " calculates the values and outputs the values in the same list brackets. \
Any list can be processed like this. If floating point form is desired apply \
N."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
{Sin[1], Sin[2], Sin[3] }
N[%,2]\
\>", "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \({Sin[1], Sin[2], Sin[3]}\)], "Output",
  CellLabel->"Out[52]="],

Cell[BoxData[
    \({0.8414709848078965064`1.9999999999999998, 
      0.9092974268256816955`2.0000000000000018, 
      0.1411200080598672221`1.9999999999999998}\)], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Important Observation",
    FontWeight->"Bold"],
  ": ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " assumes that the arguments in a trigonometric function are in radians, \
never degrees."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["The Table function", "Subsection"]], "Text"],

Cell["\<\
The two lists above are of the form { f(1), f(2), f(3), ..., f(n) \
}. Such a list can be obtained quickly and easily using the Table function in \
the form\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Table[f[k], {k,n}]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Table[Sin[k],{k,3}]", "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \({Sin[1], Sin[2], Sin[3]}\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table[n!, {n,4}]", "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \({1, 2, 6, 24}\)], "Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell["\<\
The nth term in a list L can be obtained with the entry L[[n]]. The \
next entry defines L to be a list and the following entry picks out the \
fourth entry in the list.\
\>", "Text"],

Cell[CellGroupData[{

Cell["L=Table[3^k, {k,5}]", "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \({3, 9, 27, 81, 243}\)], "Output",
  CellLabel->"Out[82]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["L[[4]]", "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(81\)], "Output",
  CellLabel->"Out[83]="]
}, Open  ]],

Cell["\<\
Suppose that the elements in a list are themselves lists, like the \
following example.\
\>", "Text"],

Cell[CellGroupData[{

Cell["L=Table[ {x,x/(1+x),Sin[x]}, {x,2,12,3}]", "Input",
  CellLabel->"In[3]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{2, 2\/3, Sin[2]}, {5, 5\/6, Sin[5]}, {8, 8\/9, Sin[8]}, {11, 11\/12, 
        Sin[11]}}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
Then L[[m,n]] refers to the nth member of the mth list. See below\
\
\>", "Text"],

Cell[CellGroupData[{

Cell["{L[[3,2]], L[[1,1]], L[[2,3]]}", "Input",
  CellLabel->"In[7]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({8\/9, 2, Sin[5]}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[StyleBox["Using the Table function",
  FontWeight->"Bold"]], "Text"],

Cell["\<\
The Table function is very handy. The following entries will give \
you a better idea of how it works.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["1. Make the list of odd integers from 11 to 37.", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Table[k, {k,11,37,2}]", "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \({11, 13, 15, 17, 19, 21, 23, 25, 27, 29, 31, 33, 35, 37}\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell["\<\
2. Make the sequence of numbers from 1/3 to 37/3 in increments of \
4/3. Convert it to floating point form (5  digits). \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Table[k, {k,1/3,37/3,4/3}]
N[%,5]\
\>", "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \({1\/3, 5\/3, 3, 13\/3, 17\/3, 7, 25\/3, 29\/3, 11, 37\/3}\)], "Output",
  CellLabel->"Out[66]="],

Cell[BoxData[
    \({0.3333333333333333333`5.0000000000000036, 
      1.6666666666666666667`5.000000000000002, 3.`5.000000000000002, 
      4.3333333333333333333`5.000000000000002, 
      5.6666666666666666667`5.000000000000002, 7.`5.000000000000002, 
      8.3333333333333333333`5.000000000000002, 
      9.6666666666666666667`5.000000000000002, 11.`5.000000000000002, 
      12.3333333333333333333`5.000000000000002}\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell["3. Make a sequence of 20 prime integers starting at 7. ", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Table[Prime[k], {k,4,23}]", "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \({7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61, 67, 71, 73, 
      79, 83}\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell[TextData[{
  "That was neat, how did it work?\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a function called Prime, whose value at n, Prime[n], is the nth \
prime. For example, Prime[1] is 2, which is the first prime; 7 is the fourth \
prime, so Prime[4] = 7. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has other integer functions like this. For example, the PrimeQ[n] \
function returns true when n is prime and false otherwise."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["PrimeQ[10001237]", "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[72]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["PrimeQ[100001237]", "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[73]="]
}, Open  ]],

Cell["\<\
4. Make a list of the binomial coefficients in the 15th row of \
Pascal's triangle.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Table[Binomial[15,n], {n,0,15}]", "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \({1, 15, 105, 455, 1365, 3003, 5005, 6435, 6435, 5005, 3003, 1365, 455, 
      105, 15, 1}\)], "Output",
  CellLabel->"Out[79]="]
}, Open  ]],

Cell["Add them up.", "Text"],

Cell[CellGroupData[{

Cell["Sum[%[[k]],{k,16}]", "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(32768\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]],

Cell[TextData[{
  "Check that this sum is the same as ",
  Cell[BoxData[
      \(TraditionalForm\`2\^15\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["2^15", "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(32768\)], "Output",
  CellLabel->"Out[81]="]
}, Open  ]],

Cell["\<\
Wow, what just happened?
The Sum function will add the first n terms in a list L via the syntax\
\>", \
"Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Sum[ L[[k]], {k,1,n} ]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "That's nice, but what I meant was why is the sum equal to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2\^15\)\(\ \)\(?\)\)\)],
    TextAlignment->Left,
    TextJustification->0]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Oh that.Well, the 15th row of Pascal's triangle contains the \
coefficients in the expansion of the expression\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\((a + b)\)\^15\)]]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Replacing the letters ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and ",
  StyleBox["b",
    FontSlant->"Italic"],
  " with the number 1 makes the number ",
  Cell[BoxData[
      \(TraditionalForm\`2\^15\)]],
  "and, at the same time, has the effect of adding the coefficients in the \
expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 + 1)\)\^15\)]],
  "."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["The Table function is very versatile", \
"Subsection"]], "Text"],

Cell["\<\
Examine the following examples to see the versatility of the Table \
function.\
\>", "Text"],

Cell["Table can make a list of lists as follows.", "Text"],

Cell[CellGroupData[{

Cell["Table[a^m+b^n, {m,2,4}, {n,4,6} ]", "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \({{a\^2 + b\^4, a\^2 + b\^5, a\^2 + b\^6}, {a\^3 + b\^4, a\^3 + b\^5, 
        a\^3 + b\^6}, {a\^4 + b\^4, a\^4 + b\^5, a\^4 + b\^6}}\)], "Output",
  CellLabel->"Out[85]="]
}, Open  ]],

Cell["Table can work with text like this.", "Text"],

Cell[CellGroupData[{

Cell["\<\
L = {me,you,him,us,you,them};
Table[ (L[[k]]+TheKing)/L[[k]], {k,6}]\
\>", "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \({\(me + TheKing\)\/me, \(TheKing + you\)\/you, \(him + TheKing\)\/him, \
\(TheKing + us\)\/us, \(TheKing + you\)\/you, \(TheKing + them\)\/them}\)], \
"Output",
  CellLabel->"Out[90]="]
}, Open  ]],

Cell["\<\
Several lists can be joined together with the Join function. The \
next input cell first creates three lists (output suppressed) then joins them \
into one long list.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
L1=Table[11,{3}]; L2=Table[4,{12}]; L3=Table[12,{13}];
S=Join[L1,L2,L3]\
\>", "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({11, 11, 11, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 12, 12, 12, 12, 12, 
      12, 12, 12, 12, 12, 12, 12, 12}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["\<\
The Product function multiplies the numbers in the list named \
S.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Product[S[[k]],{k,28}]", "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(2389209043962657308147712\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["FactorInteger generates the prime factorization.", "Text"],

Cell[CellGroupData[{

Cell["FactorInteger[%]", "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({{2, 50}, {3, 13}, {11, 3}}\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[{
  "Interpret the output as ",
  Cell[BoxData[
      \(TraditionalForm\`\(2\^50\) \(3\^13\) 11\^3\)]],
  "."
}], "Text"],

Cell[TextData[{
  "I get it, Product is like Sum, only it multiplies, right?\nRight. See the \
",
  StyleBox["Help",
    FontWeight->"Bold"],
  " page.\nThe ",
  StyleBox["Help",
    FontWeight->"Bold"],
  " page?\nYes. For example, to learn about the FactorInteger function you \
can  enter"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["?FactorInteger", "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    RowBox[{"\<\"FactorInteger[n] gives a list of the prime factors of the \
integer n, together with their exponents.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"FactorInteger",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3303731803-8151617"]
}, Open  ]],

Cell["and click on More... for more information.", "Text"],

Cell[TextData[{
  StyleBox["Moving towards symbolic calculations: Factoring in ", 
    "Subsection"],
  StyleBox["Mathematica", "Subsection",
    FontSlant->"Italic"],
  StyleBox[".", "Subsection"]
}], "Text"],

Cell[TextData[{
  "The last example shows that the FactorInteger function factors integers. \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Factor function will factor polynomials. We will define a polynomial in \
the ",
  StyleBox["x",
    FontSlant->"Italic"],
  " variable named \"Poly\" below. However, before we define it we must free \
up the x variable since at the present time (in this Notebook) ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is already in use."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["x", "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(\@3\/2 + \[ExponentialE]\^4 - Log[2]\)], "Output",
  CellLabel->"Out[112]="]
}, Open  ]],

Cell["Free x with the entry", "Text"],

Cell["Clear[x]", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["or the entry", "Text"],

Cell["x = .", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["x = .", "Input",
  CellLabel->"In[113]:="],

Cell["Here is the definition of Poly.", "Text"],

Cell[CellGroupData[{

Cell["Poly = Sum[ 2^k*x^k, {k,4}]", "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(2\ x + 4\ x\^2 + 8\ x\^3 + 16\ x\^4\)], "Output",
  CellLabel->"Out[129]="]
}, Open  ]],

Cell["The Factor function will factor Poly over the integers.", "Text"],

Cell[CellGroupData[{

Cell["Factor[Poly]", "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(2\ x\ \((1 + 2\ x)\)\ \((1 + 4\ x\^2)\)\)], "Output",
  CellLabel->"Out[130]="]
}, Open  ]],

Cell["Add the optional expression ", "Text"],

Cell[TextData[StyleBox["Extension -> {I}",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "to factor Poly over the complex numbers of the form ",
  StyleBox["a",
    FontSlant->"Italic"],
  " + ",
  StyleBox["i",
    FontSlant->"Italic"],
  " ",
  StyleBox["b",
    FontSlant->"Italic"],
  " where ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and ",
  StyleBox["b",
    FontSlant->"Italic"],
  " are integers. These are called Gaussian integers",
  ". (The symbol I represents the complex number ",
  StyleBox["i",
    FontSlant->"Italic"],
  " , i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-1\)\)]],
  " .)"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Factor[Poly,Extension->{I}]", "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \(2\ x\ \((\(-\[ImaginaryI]\) + 2\ x)\)\ \((\[ImaginaryI] + 
          2\ x)\)\ \((1 + 2\ x)\)\)], "Output",
  CellLabel->"Out[131]="]
}, Open  ]],

Cell[TextData[{
  "Note that in the output ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses the symbol \[ImaginaryI] to represent ",
  StyleBox["i",
    FontSlant->"Italic"],
  " .\nTo see the zeros of Poly use the Solve function as follows."
}], "Text"],

Cell[CellGroupData[{

Cell["Solve[Poly==0,x]", "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \({{x \[Rule] \(-\(1\/2\)\)}, {x \[Rule] 
          0}, {x \[Rule] \(-\(\[ImaginaryI]\/2\)\)}, {x \[Rule] \[ImaginaryI]\
\/2}}\)], "Output",
  CellLabel->"Out[132]="]
}, Open  ]],

Cell[TextData[{
  "Note two things.\n1. The syntax for Solve is ",
  StyleBox["Solve[ equation, variable]",
    FontWeight->"Bold"],
  ". The equation to be solved must be in the form "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["lhs == rhs", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
 to distinguish it from an equation defining the value of a \
variable.
2. The output is list of lists. Each list contains a solution in the form x \
-> a.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["We will have more to say about Solve in the next section.", "Text",
  TextAlignment->Left,
  TextJustification->0]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{710, 742},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->6,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "   Page  ", 
          CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "   Page  ", 
          CounterBox[ "Page"]}], "Footer"], None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3303731803-8151617"->{
    Cell[23390, 952, 361, 9, 42, "Print",
      CellTags->"Info3303731803-8151617"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3303731803-8151617", 30102, 1199}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 1205, 28, 241, "Text"],

Cell[CellGroupData[{
Cell[2984, 83, 44, 1, 31, "Input"],
Cell[3031, 86, 59, 2, 27, "Output"]
}, Open  ]],
Cell[3105, 91, 1062, 22, 160, "Text"],

Cell[CellGroupData[{
Cell[4192, 117, 80, 5, 71, "Input"],
Cell[4275, 124, 63, 2, 31, "Output"],
Cell[4341, 128, 61, 2, 27, "Output"]
}, Open  ]],
Cell[4417, 133, 536, 13, 100, "Text"],
Cell[4956, 148, 76, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[5057, 154, 53, 1, 31, "Input"],
Cell[5113, 157, 77, 2, 27, "Output"]
}, Open  ]],
Cell[5205, 162, 464, 10, 68, "Text"],

Cell[CellGroupData[{
Cell[5694, 176, 79, 1, 31, "Input"],
Cell[5776, 179, 91, 2, 54, "Output"]
}, Open  ]],
Cell[5882, 184, 49, 0, 28, "Text"],
Cell[5934, 186, 69, 2, 28, "Text"],
Cell[6006, 190, 131, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[6162, 197, 46, 1, 23, "Input"],
Cell[6211, 200, 76, 2, 18, "Output"]
}, Open  ]],
Cell[6302, 205, 201, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[6528, 214, 49, 1, 31, "Input"],
Cell[6580, 217, 99, 2, 27, "Output"]
}, Open  ]],
Cell[6694, 222, 213, 7, 28, "Text"],
Cell[6910, 231, 67, 2, 28, "Text"],
Cell[6980, 235, 144, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[7149, 244, 61, 4, 51, "Input"],
Cell[7213, 250, 64, 2, 27, "Output"],
Cell[7280, 254, 145, 3, 27, "Output"]
}, Open  ]],
Cell[7440, 260, 506, 15, 80, "Text"],

Cell[CellGroupData[{
Cell[7971, 279, 59, 4, 51, "Input"],
Cell[8033, 285, 74, 2, 27, "Output"],
Cell[8110, 289, 85, 2, 27, "Output"]
}, Open  ]],
Cell[8210, 294, 189, 6, 28, "Text"],

Cell[CellGroupData[{
Cell[8424, 304, 69, 4, 51, "Input"],
Cell[8496, 310, 74, 2, 27, "Output"],
Cell[8573, 314, 85, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8695, 321, 77, 0, 36, "Subsubsection"],
Cell[8775, 323, 129, 3, 28, "Text"],
Cell[8907, 328, 142, 3, 32, "Text"],
Cell[9052, 333, 87, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[9164, 339, 59, 1, 31, "Input"],
Cell[9226, 342, 91, 2, 45, "Output"]
}, Open  ]],
Cell[9332, 347, 187, 6, 28, "Text"],

Cell[CellGroupData[{
Cell[9544, 357, 49, 1, 31, "Input"],
Cell[9596, 360, 107, 2, 27, "Output"]
}, Open  ]],
Cell[9718, 365, 61, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[9804, 369, 50, 1, 31, "Input"],
Cell[9857, 372, 104, 2, 27, "Output"]
}, Open  ]],
Cell[9976, 377, 347, 9, 48, "Text"],
Cell[10326, 388, 94, 2, 28, "Text"],
Cell[10423, 392, 373, 11, 48, "Text"],

Cell[CellGroupData[{
Cell[10821, 407, 71, 1, 31, "Input"],
Cell[10895, 410, 95, 2, 50, "Output"]
}, Open  ]],
Cell[11005, 415, 319, 11, 48, "Text"],

Cell[CellGroupData[{
Cell[11349, 430, 48, 1, 31, "Input"],
Cell[11400, 433, 99, 2, 27, "Output"]
}, Open  ]],
Cell[11514, 438, 341, 13, 48, "Text"],
Cell[11858, 453, 73, 2, 28, "Text"],
Cell[11934, 457, 37, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[11996, 461, 72, 4, 51, "Input"],
Cell[12071, 467, 60, 2, 27, "Output"],
Cell[12134, 471, 60, 2, 27, "Output"]
}, Open  ]],
Cell[12209, 476, 131, 4, 29, "Text"],
Cell[12343, 482, 396, 10, 80, "Text"],

Cell[CellGroupData[{
Cell[12764, 496, 59, 1, 31, "Input"],
Cell[12826, 499, 72, 2, 27, "Output"]
}, Open  ]],
Cell[12913, 504, 256, 7, 48, "Text"],

Cell[CellGroupData[{
Cell[13194, 515, 82, 4, 51, "Input"],
Cell[13279, 521, 83, 2, 27, "Output"],
Cell[13365, 525, 199, 4, 27, "Output"]
}, Open  ]],
Cell[13579, 532, 288, 10, 48, "Text"],
Cell[13870, 544, 68, 0, 29, "Text"],
Cell[13941, 546, 227, 6, 48, "Text"],
Cell[14171, 554, 125, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[14321, 561, 61, 1, 31, "Input"],
Cell[14385, 564, 83, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14505, 571, 58, 1, 31, "Input"],
Cell[14566, 574, 72, 2, 27, "Output"]
}, Open  ]],
Cell[14653, 579, 193, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[14871, 587, 61, 1, 31, "Input"],
Cell[14935, 590, 78, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15050, 597, 48, 1, 31, "Input"],
Cell[15101, 600, 61, 2, 27, "Output"]
}, Open  ]],
Cell[15177, 605, 111, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[15313, 612, 106, 2, 31, "Input"],
Cell[15422, 616, 147, 3, 45, "Output"]
}, Open  ]],
Cell[15584, 622, 91, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[15700, 629, 96, 2, 31, "Input"],
Cell[15799, 633, 75, 2, 45, "Output"]
}, Open  ]],
Cell[15889, 638, 82, 1, 28, "Text"],
Cell[15974, 641, 173, 5, 28, "Text"],
Cell[16150, 648, 110, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[16285, 654, 63, 1, 31, "Input"],
Cell[16351, 657, 115, 2, 27, "Output"]
}, Open  ]],
Cell[16481, 662, 191, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[16697, 671, 83, 4, 51, "Input"],
Cell[16783, 677, 116, 2, 45, "Output"],
Cell[16902, 681, 457, 8, 45, "Output"]
}, Open  ]],
Cell[17374, 692, 118, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[17517, 698, 67, 1, 31, "Input"],
Cell[17587, 701, 145, 3, 27, "Output"]
}, Open  ]],
Cell[17747, 707, 529, 13, 99, "Text"],

Cell[CellGroupData[{
Cell[18301, 724, 58, 1, 31, "Input"],
Cell[18362, 727, 63, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18462, 734, 59, 1, 31, "Input"],
Cell[18524, 737, 64, 2, 27, "Output"]
}, Open  ]],
Cell[18603, 742, 107, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[18735, 749, 73, 1, 31, "Input"],
Cell[18811, 752, 148, 3, 27, "Output"]
}, Open  ]],
Cell[18974, 758, 28, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[19027, 762, 60, 1, 31, "Input"],
Cell[19090, 765, 64, 2, 27, "Output"]
}, Open  ]],
Cell[19169, 770, 126, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[19320, 779, 46, 1, 31, "Input"],
Cell[19369, 782, 64, 2, 27, "Output"]
}, Open  ]],
Cell[19448, 787, 168, 6, 60, "Text"],
Cell[19619, 795, 129, 3, 28, "Text"],
Cell[19751, 800, 259, 8, 28, "Text"],
Cell[20013, 810, 181, 5, 28, "Text"],
Cell[20197, 817, 129, 3, 24, "Text"],
Cell[20329, 822, 452, 17, 48, "Text"],
Cell[20784, 841, 88, 1, 29, "Text"],
Cell[20875, 844, 102, 3, 28, "Text"],
Cell[20980, 849, 58, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[21063, 853, 75, 1, 31, "Input"],
Cell[21141, 856, 191, 3, 32, "Output"]
}, Open  ]],
Cell[21347, 862, 51, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[21423, 866, 118, 4, 51, "Input"],
Cell[21544, 872, 205, 4, 90, "Output"]
}, Open  ]],
Cell[21764, 879, 190, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[21979, 887, 121, 4, 51, "Input"],
Cell[22103, 893, 166, 3, 45, "Output"]
}, Open  ]],
Cell[22284, 899, 90, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[22399, 906, 64, 1, 31, "Input"],
Cell[22466, 909, 84, 2, 27, "Output"]
}, Open  ]],
Cell[22565, 914, 64, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[22654, 918, 58, 1, 31, "Input"],
Cell[22715, 921, 86, 2, 27, "Output"]
}, Open  ]],
Cell[22816, 926, 135, 5, 28, "Text"],
Cell[22954, 933, 351, 12, 124, "Text"],

Cell[CellGroupData[{
Cell[23330, 949, 57, 1, 31, "Input"],
Cell[23390, 952, 361, 9, 42, "Print",
  CellTags->"Info3303731803-8151617"]
}, Open  ]],
Cell[23766, 964, 58, 0, 28, "Text"],
Cell[23827, 966, 209, 6, 29, "Text"],
Cell[24039, 974, 547, 16, 68, "Text"],

Cell[CellGroupData[{
Cell[24611, 994, 44, 1, 31, "Input"],
Cell[24658, 997, 96, 2, 50, "Output"]
}, Open  ]],
Cell[24769, 1002, 37, 0, 28, "Text"],
Cell[24809, 1004, 73, 2, 28, "Text"],
Cell[24885, 1008, 28, 0, 28, "Text"],
Cell[24916, 1010, 70, 2, 28, "Text"],
Cell[24989, 1014, 48, 1, 31, "Input"],
Cell[25040, 1017, 47, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[25112, 1021, 70, 1, 31, "Input"],
Cell[25185, 1024, 95, 2, 30, "Output"]
}, Open  ]],
Cell[25295, 1029, 71, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[25391, 1033, 55, 1, 31, "Input"],
Cell[25449, 1036, 99, 2, 32, "Output"]
}, Open  ]],
Cell[25563, 1041, 44, 0, 28, "Text"],
Cell[25610, 1043, 123, 3, 28, "Text"],
Cell[25736, 1048, 608, 26, 48, "Text"],

Cell[CellGroupData[{
Cell[26369, 1078, 70, 1, 31, "Input"],
Cell[26442, 1081, 152, 3, 27, "Output"]
}, Open  ]],
Cell[26609, 1087, 269, 8, 60, "Text"],

Cell[CellGroupData[{
Cell[26903, 1099, 59, 1, 31, "Input"],
Cell[26965, 1102, 184, 4, 45, "Output"]
}, Open  ]],
Cell[27164, 1109, 244, 7, 60, "Text"],
Cell[27411, 1118, 75, 2, 28, "Text"],
Cell[27489, 1122, 226, 7, 60, "Text"],
Cell[27718, 1131, 120, 2, 28, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

