(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    123337,       3850]*)
(*NotebookOutlinePosition[    125625,       3920]*)
(*  CellTagsIndexPosition[    125581,       3916]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part II. Calculations and Calculus with ", "Section"],
  StyleBox["Mathematica", "Section",
    FontSlant->"Italic"],
  "\n",
  StyleBox["Section 2. Symbolics: Equations and Assignments", "Subsection"],
  " \n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is an excellent calculator. However, calculus and differential equations \
applications require symbolic  capabilities. Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " makes symbolic computations in a natural way (see the examples in Section \
1), it  is essential that users have a clear understanding of how it handles \
variables, equations, and functions."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Variables, equations and assignments", "Subsection"],

Cell["\<\
The equation x = 2, the expression y + x, and the expression y/x \
all involve the variables x and y. They are  entered separately below.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell["\<\
x = 3
y + x
y/x\
\>", "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[16]="],

Cell[BoxData[
    \(3 + y\)], "Output",
  CellLabel->"Out[17]="],

Cell[BoxData[
    \(y\/3\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Key observation",
    FontWeight->"Bold"],
  ": The equation x = 3 has assigned the value 3 to the x variable. This can \
be seen from the output for the second and third entries."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Once 3 has been assigned to the x variable, it stays that way. \
Examine carefully the three terms in the output for the following \
list..\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["{y + x, x^3 - x*z, x^3}", "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({3 + y, 27 - 3\ z, 27}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
There are two ways to undo the assignment of 3 to the x variable. \
One way is to enter\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Clear[x]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["And the other is to enter", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["x = .",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["as shown below.", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
x = .
y + x\
\>", "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(x + y\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[{
  "Note that the entry ",
  StyleBox["x = .",
    FontWeight->"Bold"],
  " has no output. Neither does ",
  StyleBox["Clear[x]",
    FontWeight->"Bold"],
  "."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Multiple assignments: Full evaluation",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not mind if several assignments are made to the same variable. It \
only remembers the last one. Consider the following example."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
x=1; x=2; x=3
x\
\>", "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[45]="],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell["Now clear x and check that it is free.", "Text"],

Cell[CellGroupData[{

Cell["Clear[x]; x", "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(x\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["A chain of functions",
    FontWeight->"Bold"],
  "\nSuppose now that several variables are defined in a \"chain\" like \
this."
}], "Text"],

Cell[CellGroupData[{

Cell["y=x^2; x=2z; z=3Log[w]; w=Exp[1]", "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(\[ExponentialE]\)], "Output",
  CellLabel->"Out[95]="]
}, Open  ]],

Cell[TextData[{
  "Then w is assigned the number ",
  StyleBox["e",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell["{w, N[w]}", "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \({\[ExponentialE], 2.718281828459045`}\)], "Output",
  CellLabel->"Out[96]="]
}, Open  ]],

Cell[TextData[{
  "and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will dig down all the way to ",
  StyleBox["e",
    FontSlant->"Italic"],
  " when ",
  "asked to evaluate y, x, z and w. This can be referred to as \"full \
evaluation\"."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["{y, x, z, w}", "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \({36, 6, 3, \[ExponentialE]}\)], "Output",
  CellLabel->"Out[97]="]
}, Open  ]],

Cell["\<\
Make sure that you understand the output. What is Log(w)? Why did x \
evaluate to 36?
If the assignment to w is subsequently changed: \
\>", "Text"],

Cell[CellGroupData[{

Cell["w=Sin[3]", "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(Sin[3]\)], "Output",
  CellLabel->"Out[98]="]
}, Open  ]],

Cell["\<\
This change will be reflected in the evaluation of y, x, and z as \
well.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["{y, x, z, w}", "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \({36\ Log[Sin[3]]\^2, 6\ Log[Sin[3]], 3\ Log[Sin[3]], 
      Sin[3]}\)], "Output",
  CellLabel->"Out[99]="]
}, Open  ]],

Cell["Before proceeding we clear x, y, z, and w.", "Text"],

Cell["Clear[x,y,z,w]", "Input",
  CellLabel->"In[100]:="],

Cell[TextData[{
  StyleBox["Some remarks on input",
    FontWeight->"Bold"],
  "\nBefore proceeding it would be appropriate to explain some things about \
how ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "handles input.\n1. Regarding multiplication. Although multiplication can \
always to denoted with an asterisk, it is sometimes not required. A space can \
be used instead and not even a space is required for a product like 4x. For \
example, the entry "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["x^2 + 3x - x y", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "with a space between the last x and y and no space between 3 and x will be \
interpreted by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as the same as"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["x^2 + 3*x - x*y.", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["See below.", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Poly = x^2 + 3x - x y
Factor[Poly]\
\>", "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(3\ x + x\^2 - x\ y\)], "Output",
  CellLabel->"Out[84]="],

Cell[BoxData[
    \(x\ \((3 + x - y)\)\)], "Output",
  CellLabel->"Out[85]="]
}, Open  ]],

Cell["\<\
2. If several computations (in sequence) are needed to obtain some \
particular output consider using semicolons to suppress (and compress) the \
preliminary inputs, and finish with no semicolon to show the last \
output.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Solving equations exactly: The Solve function",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"Solve\" procedure is very powerful. Ask for exact solutions for x in \
\"equation\" by entering the  following: "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Solve[ lhs = = rhs, x ]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Note that the equation to be solved must be in the form  rhs == lhs. \
Having named the solution \"solns\" the entry solns[[k]]  can be used to \
obtain the kth solution in the sequence. If exact solutions are found, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " returns them in a list. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Solve[ x^3 - x == x^2, x]", "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \({{x \[Rule] 0}, {x \[Rule] 1\/2\ \((1 - \@5)\)}, {x \[Rule] 
          1\/2\ \((1 + \@5)\)}}\)], "Output",
  CellLabel->"Out[101]="]
}, Open  ]],

Cell["\<\
If the solution values are to be used in a subsequent input, then \
assign a name to the Solve entry as shown in the next example. The same name \
will be assigned to the output.
In the next example a name has also been assigned to the equation. This is \
recommended or two  reasons:   
1. The equation can be checked for correctness by examining the output.   
2. If the equation has to be used again, simply type its name. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
eqn = x^3 - 5x^2 == 2 - 6x
solns = Solve[ eqn, x]\
\>", "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(\(-5\)\ x\^2 + x\^3 \[Equal] 2 - 6\ x\)], "Output",
  CellLabel->"Out[102]="],

Cell[BoxData[
    \({{x \[Rule] 1}, {x \[Rule] 2 - \@2}, {x \[Rule] 2 + \@2}}\)], "Output",
  CellLabel->"Out[103]="]
}, Open  ]],

Cell["\<\
Having named the solution \"solns\" the entry solns[[k]] can be \
used to obtain the kth solution in the sequence. \
\>", "Text"],

Cell[CellGroupData[{

Cell["solns[[1]]", "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \({x \[Rule] 1}\)], "Output",
  CellLabel->"Out[104]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["solns[[2]]", "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \({x \[Rule] 2 - \@2}\)], "Output",
  CellLabel->"Out[105]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["solns[[3]]", "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \({x \[Rule] 2 + \@2}\)], "Output",
  CellLabel->"Out[106]="]
}, Open  ]],

Cell["Check by substitution (the arrow makes it easy)", "Text"],

Cell["\<\
An expression like \"eqn\" can be evaluated for various x values \
using an input of the form\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "e",
  StyleBox["qn/.x->value",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "The ",
  StyleBox["/.",
    FontWeight->"Bold"],
  " notation is described by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as \"Replace all\". It can also be interpreted as \"substitute for the x \
value indicated\". Here is a simple example. Note that no simplification is \
applied."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Sin[3(x+y)]/.x->Pi", "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(Sin[3\ \((\[Pi] + y)\)]\)], "Output",
  CellLabel->"Out[112]="]
}, Open  ]],

Cell["\<\
And here is an example showing how to check the second solution \
above.\
\>", "Text"],

Cell[CellGroupData[{

Cell["eqn/.solns[[2]]", "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    RowBox[{\(N::"meprec"\), \(\(:\)\(\ \)\), "\<\"Internal precision limit \
$MaxExtraPrecision = \\!\\(50.`\\) reached while evaluating \\!\\(\\(\\(-2\\)\
\\) + \\(\\(6\\\\ \\(\\((2 - \\@2)\\)\\)\\)\\) - \\(\\(5\\\\ \\((2 - \\@2)\\)\
\\^2\\)\\) + \\((2 - \\@2)\\)\\^3\\). \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::meprec\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[108]:="],

Cell[BoxData[
    \(\(-5\)\ \((2 - \@2)\)\^2 + \((2 - \@2)\)\^3 \[Equal] 
      2 - 6\ \((2 - \@2)\)\)], "Output",
  CellLabel->"Out[108]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " did not simplify the equation and cannot, using numerical evaluation, \
verify if the left side is identical to the right side. Applying Simplify \
will clarify the situation."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Simplify[%]", "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[109]="]
}, Open  ]],

Cell["\<\
Note that the output is the word \"True\" indicating that the \
output is an identity.\
\>", "Text"],

Cell["\<\
If numerical solutions are needed apply the N function to \
solns.\
\>", "Text"],

Cell[CellGroupData[{

Cell["N[solns]", "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \({{x \[Rule] 1.`}, {x \[Rule] 0.5857864376269049`}, {x \[Rule] 
          3.414213562373095`}}\)], "Output",
  CellLabel->"Out[113]="]
}, Open  ]],

Cell[TextData[StyleBox["Approximate solutions using NSolve and FindRoot",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "The Solve function often fails to return satisfactory solutions because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " cannot find an exact solution  formula. When this happens, floating point \
solutions to polynomial equations can be obtained by using the NSsolve \
procedure. The  syntax for NSolve is "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["NSolve[ lhs = = rhs, x]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
If a particular solution is required use FindRoot using the \
syntax\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["FindRoot[ lhs = = rhs, {x, x0} ]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["where x0 is the approximate value of the desired solution.", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
The next input requests a solution to \"eqn\" (defined above) near \
to x =0.5. Compare the output to the middle term in the last output list. \
\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["FindRoot[ eqn, {x,0.5} ]", "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \({x \[Rule] 0.5857864376269049`}\)], "Output",
  CellLabel->"Out[114]="]
}, Open  ]],

Cell["\<\
In the next input we have    
1. Entered and named the polynomial equation  x^5  - x^4  + x^3  + x - 1 = = \
0.
2. Used NSolve to generate a sequence of floating point solutions named \
solns.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
eqn = x^5 - x^4 + x^3 + x - 1 == 0
solns = NSolve[ eqn, x ]\
\>", "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(\(-1\) + x + x\^3 - x\^4 + x\^5 \[Equal] 0\)], "Output",
  CellLabel->"Out[116]="],

Cell[BoxData[
    \({{x \[Rule] \(-0.5797227181624978`\) - 
            0.7393202820865448`\ \[ImaginaryI]}, {x \[Rule] \
\(-0.5797227181624978`\) + 0.7393202820865448`\ \[ImaginaryI]}, {x \[Rule] 
          0.7124526119462912`}, {x \[Rule] \(\(0.7234964121893521`\)\(\
\[InvisibleSpace]\)\) - 
            1.0328239787275457`\ \[ImaginaryI]}, {x \[Rule] \
\(\(0.7234964121893521`\)\(\[InvisibleSpace]\)\) + 
            1.0328239787275457`\ \[ImaginaryI]}}\)], "Output",
  CellLabel->"Out[117]="]
}, Open  ]],

Cell["\<\
Observe that the third solution in the solution sequence is purely \
real. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["solns[[3]]", "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \({x \[Rule] 0.7124526119462912`}\)], "Output",
  CellLabel->"Out[118]="]
}, Open  ]],

Cell[TextData[{
  "The other four solutions are complex, appearing in conjugate pairs (the \
symbol \[ImaginaryI] is used by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to denote  ",
  StyleBox["i = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\@\(-1\)\)]],
  ")."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["{solns[[1]],solns[[2]]}", "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \({{x \[Rule] \(-0.5797227181624978`\) - 
            0.7393202820865448`\ \[ImaginaryI]}, {x \[Rule] \
\(-0.5797227181624978`\) + 0.7393202820865448`\ \[ImaginaryI]}}\)], "Output",
  CellLabel->"Out[119]="]
}, Open  ]],

Cell["\<\
The next entry checks the third solution. Because a float has been \
substituted, the output is in floating point  form and automatically \
simplified. The output is \"True\" indicating that, to 50 digits, the \
equation is true.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["eqn/.solns[[3]]", "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[120]="]
}, Open  ]],

Cell[TextData[StyleBox["More about Solve and FindRoot",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
When the Solve function cannot find exact solutions to an equation, \
it returns an explanation with some indication of why no solution is \
forthcoming. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
eqn = Tan[x] == x
solns = Solve[ eqn, x]\
\>", "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(Tan[x] \[Equal] x\)], "Output",
  CellLabel->"Out[121]="],

Cell[BoxData[
    RowBox[{\(Solve::"tdep"\), \(\(:\)\(\ \)\), "\<\"The equations appear to \
involve the variables to be solved for in an essentially non-algebraic way. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::tdep\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[121]:="],

Cell[BoxData[
    \(Solve[Tan[x] \[Equal] x, x]\)], "Output",
  CellLabel->"Out[122]="]
}, Open  ]],

Cell["\<\
We will take this is a signal to use FindRoot as shown below. \
\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
FindRoot[ eqn, {x,4} ]
FindRoot[ eqn, {x,7} ]\
\>", "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \({x \[Rule] 4.493409457909064`}\)], "Output",
  CellLabel->"Out[123]="],

Cell[BoxData[
    \({x \[Rule] 7.725251836937707`}\)], "Output",
  CellLabel->"Out[124]="]
}, Open  ]],

Cell[TextData[{
  "In order to search successfully it would be helpful to have the graph of \
the function tan(x) - x. This is easy to obtain using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Plot function. It has the following basic form. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Plot( f[x], {x,a,b} )",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
 The next entry asks for the graph of tan(x) - x from x = 0 to x = \
10. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Plot[ Tan[x] - x, {x,0,10} ]", "Input",
  CellLabel->"In[125]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.382405 0.0154934 [
[.21429 .3699 -3 -9 ]
[.21429 .3699 3 0 ]
[.40476 .3699 -3 -9 ]
[.40476 .3699 3 0 ]
[.59524 .3699 -3 -9 ]
[.59524 .3699 3 0 ]
[.78571 .3699 -3 -9 ]
[.78571 .3699 3 0 ]
[.97619 .3699 -6 -9 ]
[.97619 .3699 6 0 ]
[.01131 .07254 -18 -4.5 ]
[.01131 .07254 0 4.5 ]
[.01131 .15 -18 -4.5 ]
[.01131 .15 0 4.5 ]
[.01131 .22747 -18 -4.5 ]
[.01131 .22747 0 4.5 ]
[.01131 .30494 -12 -4.5 ]
[.01131 .30494 0 4.5 ]
[.01131 .45987 -6 -4.5 ]
[.01131 .45987 0 4.5 ]
[.01131 .53734 -12 -4.5 ]
[.01131 .53734 0 4.5 ]
[.01131 .61481 -12 -4.5 ]
[.01131 .61481 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .3824 m
.21429 .38865 L
s
[(2)] .21429 .3699 0 1 Mshowa
.40476 .3824 m
.40476 .38865 L
s
[(4)] .40476 .3699 0 1 Mshowa
.59524 .3824 m
.59524 .38865 L
s
[(6)] .59524 .3699 0 1 Mshowa
.78571 .3824 m
.78571 .38865 L
s
[(8)] .78571 .3699 0 1 Mshowa
.97619 .3824 m
.97619 .38865 L
s
[(10)] .97619 .3699 0 1 Mshowa
.125 Mabswid
.07143 .3824 m
.07143 .38615 L
s
.11905 .3824 m
.11905 .38615 L
s
.16667 .3824 m
.16667 .38615 L
s
.2619 .3824 m
.2619 .38615 L
s
.30952 .3824 m
.30952 .38615 L
s
.35714 .3824 m
.35714 .38615 L
s
.45238 .3824 m
.45238 .38615 L
s
.5 .3824 m
.5 .38615 L
s
.54762 .3824 m
.54762 .38615 L
s
.64286 .3824 m
.64286 .38615 L
s
.69048 .3824 m
.69048 .38615 L
s
.7381 .3824 m
.7381 .38615 L
s
.83333 .3824 m
.83333 .38615 L
s
.88095 .3824 m
.88095 .38615 L
s
.92857 .3824 m
.92857 .38615 L
s
.25 Mabswid
0 .3824 m
1 .3824 L
s
.02381 .07254 m
.03006 .07254 L
s
[(-20)] .01131 .07254 1 0 Mshowa
.02381 .15 m
.03006 .15 L
s
[(-15)] .01131 .15 1 0 Mshowa
.02381 .22747 m
.03006 .22747 L
s
[(-10)] .01131 .22747 1 0 Mshowa
.02381 .30494 m
.03006 .30494 L
s
[(-5)] .01131 .30494 1 0 Mshowa
.02381 .45987 m
.03006 .45987 L
s
[(5)] .01131 .45987 1 0 Mshowa
.02381 .53734 m
.03006 .53734 L
s
[(10)] .01131 .53734 1 0 Mshowa
.02381 .61481 m
.03006 .61481 L
s
[(15)] .01131 .61481 1 0 Mshowa
.125 Mabswid
.02381 .08803 m
.02756 .08803 L
s
.02381 .10352 m
.02756 .10352 L
s
.02381 .11902 m
.02756 .11902 L
s
.02381 .13451 m
.02756 .13451 L
s
.02381 .1655 m
.02756 .1655 L
s
.02381 .18099 m
.02756 .18099 L
s
.02381 .19648 m
.02756 .19648 L
s
.02381 .21198 m
.02756 .21198 L
s
.02381 .24296 m
.02756 .24296 L
s
.02381 .25846 m
.02756 .25846 L
s
.02381 .27395 m
.02756 .27395 L
s
.02381 .28944 m
.02756 .28944 L
s
.02381 .32043 m
.02756 .32043 L
s
.02381 .33592 m
.02756 .33592 L
s
.02381 .35142 m
.02756 .35142 L
s
.02381 .36691 m
.02756 .36691 L
s
.02381 .3979 m
.02756 .3979 L
s
.02381 .41339 m
.02756 .41339 L
s
.02381 .42889 m
.02756 .42889 L
s
.02381 .44438 m
.02756 .44438 L
s
.02381 .47537 m
.02756 .47537 L
s
.02381 .49086 m
.02756 .49086 L
s
.02381 .50635 m
.02756 .50635 L
s
.02381 .52185 m
.02756 .52185 L
s
.02381 .55283 m
.02756 .55283 L
s
.02381 .56833 m
.02756 .56833 L
s
.02381 .58382 m
.02756 .58382 L
s
.02381 .59931 m
.02756 .59931 L
s
.02381 .05704 m
.02756 .05704 L
s
.02381 .04155 m
.02756 .04155 L
s
.02381 .02606 m
.02756 .02606 L
s
.02381 .01056 m
.02756 .01056 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3824 m
.02499 .3824 L
.02605 .38241 L
.02729 .38241 L
.02846 .38241 L
.02954 .38241 L
.03053 .38241 L
.03163 .38241 L
.03279 .38241 L
.03395 .38241 L
.0352 .38241 L
.03746 .38242 L
.03884 .38243 L
.04016 .38243 L
.04262 .38245 L
.045 .38246 L
.04753 .38249 L
.0521 .38255 L
.05489 .38259 L
.05752 .38265 L
.06244 .38277 L
.06757 .38295 L
.07299 .3832 L
.07761 .38347 L
.08269 .38385 L
.08815 .38435 L
.09401 .38505 L
.09954 .38588 L
.10458 .38683 L
.10939 .38795 L
.11449 .38942 L
.12366 .39308 L
.12875 .39592 L
.13353 .39937 L
.13877 .40441 L
.14151 .40777 L
.14443 .41211 L
.14702 .41684 L
.14938 .42208 L
.15178 .42864 L
.154 .43618 L
.15658 .44757 L
.15791 .45498 L
.15938 .46478 L
.16185 .48699 L
.1632 .50373 L
.16447 .52402 L
.16577 .55206 L
.16651 .57263 L
.16719 .59609 L
Mistroke
Mfstroke
.16719 .59609 m
.16765 .61803 L
s
.17236 .61803 m
.17241 0 L
s
.17757 0 m
.17788 .02732 L
.17852 .06864 L
.17926 .10506 L
.17995 .13193 L
.18135 .17145 L
.18264 .19728 L
.18406 .21839 L
.18557 .23536 L
.18796 .25506 L
.19047 .26973 L
.19262 .27916 L
.19496 .28727 L
.1975 .2942 L
.2002 .3001 L
.20508 .30805 L
.21001 .31381 L
.21467 .31786 L
.21884 .3207 L
.22337 .32317 L
.23286 .32689 L
.23825 .32839 L
.24328 .32952 L
.25344 .33117 L
.25914 .33183 L
.26434 .33231 L
.26914 .33266 L
.27424 .33296 L
.27859 .33316 L
.2834 .33333 L
.28855 .33347 L
.29125 .33353 L
.2941 .33358 L
.2966 .33362 L
.29934 .33365 L
.30184 .33367 L
.30415 .33369 L
.30668 .3337 L
.30799 .33371 L
.30943 .33372 L
.31185 .33372 L
.31317 .33373 L
.31441 .33373 L
.31561 .33373 L
.31676 .33373 L
.31779 .33373 L
.31891 .33373 L
.32012 .33373 L
.32141 .33373 L
.32263 .33373 L
Mistroke
.32374 .33373 L
.32505 .33373 L
.32571 .33373 L
.32644 .33373 L
.32772 .33373 L
.32892 .33373 L
.32965 .33373 L
.33034 .33373 L
.33163 .33373 L
.33301 .33374 L
.33452 .33374 L
.33574 .33374 L
.33708 .33375 L
.3398 .33376 L
.34232 .33377 L
.34468 .33379 L
.34938 .33384 L
.35205 .33388 L
.35452 .33393 L
.35953 .33404 L
.36488 .33421 L
.36987 .33441 L
.37458 .33466 L
.38339 .3353 L
.38802 .33575 L
.39312 .33636 L
.39808 .3371 L
.40342 .33808 L
.4084 .33923 L
.41295 .34051 L
.42187 .34393 L
.42666 .34645 L
.43176 .34992 L
.43656 .35422 L
.44091 .35937 L
.44605 .36783 L
.44895 .37431 L
.4516 .38191 L
.45394 .39044 L
.4565 .40271 L
.45779 .41055 L
.45917 .42062 L
.46165 .44529 L
.46288 .46213 L
.46423 .48644 L
.46491 .50191 L
.46564 .52194 L
.46696 .57137 L
Mfstroke
.46696 .57137 m
.46774 .61803 L
s
.47187 .61803 m
.47187 0 L
s
.47741 0 m
.47761 .01399 L
.47831 .04994 L
.47894 .07583 L
.47963 .09845 L
.48037 .11851 L
.4817 .14605 L
.48295 .1656 L
.48536 .1923 L
.48673 .20339 L
.48802 .21199 L
.49061 .22549 L
.49341 .2362 L
.49587 .24344 L
.49846 .24951 L
.50309 .25769 L
.50809 .26397 L
.51263 .26821 L
.51787 .27192 L
.52282 .27461 L
.53163 .27808 L
.5366 .2795 L
.54118 .28057 L
.54585 .28147 L
.55087 .28226 L
.55994 .28332 L
.56547 .28378 L
.57072 .28413 L
.57543 .28438 L
.58057 .28459 L
.5859 .28475 L
.59091 .28487 L
.59541 .28494 L
.59795 .28497 L
.60028 .28499 L
.60263 .28501 L
.60515 .28503 L
.60659 .28503 L
.60791 .28504 L
.61049 .28505 L
.61186 .28505 L
.61314 .28505 L
.61454 .28505 L
.61524 .28506 L
.61602 .28506 L
.61732 .28506 L
.61805 .28506 L
.61872 .28506 L
.61996 .28506 L
.62126 .28506 L
Mistroke
.6225 .28506 L
.6232 .28506 L
.62384 .28506 L
.62502 .28506 L
.62627 .28506 L
.62739 .28506 L
.62844 .28506 L
.62959 .28506 L
.63082 .28506 L
.63214 .28506 L
.63356 .28507 L
.63491 .28507 L
.63616 .28507 L
.63852 .28508 L
.64103 .2851 L
.6432 .28511 L
.64553 .28514 L
.64976 .28519 L
.65221 .28523 L
.65479 .28527 L
.65941 .28539 L
.6644 .28554 L
.66893 .28573 L
.67417 .28601 L
.67912 .28634 L
.68792 .28715 L
.69289 .28777 L
.69747 .28846 L
.70213 .28931 L
.70714 .29044 L
.7162 .29322 L
.72173 .29556 L
.72698 .29846 L
.73169 .30182 L
.73683 .30668 L
.73938 .30973 L
.74215 .31367 L
.74458 .31786 L
.74715 .32324 L
.74948 .32921 L
.75203 .33746 L
.75435 .34711 L
.75651 .35883 L
.75781 .36767 L
.75923 .37939 L
.76048 .39219 L
.76181 .40933 L
.763 .42916 L
.76431 .45842 L
.76551 .4957 L
Mistroke
.76663 .54644 L
.76727 .58619 L
Mfstroke
.76727 .58619 m
.76764 .61803 L
s
.7706 .61803 m
.77062 0 L
s
.77748 0 m
.77748 .00014 L
.77878 .0483 L
.77998 .07926 L
.7813 .10419 L
.7827 .12406 L
.78404 .13875 L
.7853 .14988 L
.78765 .16586 L
.78998 .17754 L
.79211 .18586 L
.79694 .19928 L
.79945 .20435 L
.80179 .20826 L
.80711 .21511 L
.81229 .2199 L
.81783 .22371 L
.82314 .22646 L
.82803 .22845 L
.83331 .23015 L
.83912 .23163 L
.84889 .23341 L
.85424 .23412 L
.85925 .23465 L
.86421 .23508 L
.86962 .23544 L
.87473 .23571 L
.87948 .23591 L
.88418 .23605 L
.88844 .23616 L
.8908 .2362 L
.89336 .23625 L
.898 .2363 L
.90037 .23633 L
.90291 .23635 L
.90531 .23636 L
.90749 .23637 L
.91006 .23637 L
.9115 .23638 L
.91285 .23638 L
.91401 .23638 L
.91531 .23638 L
.91595 .23638 L
.91665 .23638 L
.91792 .23638 L
.91861 .23638 L
.91926 .23638 L
.92001 .23638 L
.92069 .23638 L
.92134 .23638 L
Mistroke
.92203 .23638 L
.92327 .23638 L
.92456 .23638 L
.92522 .23638 L
.92596 .23638 L
.92669 .23638 L
.92748 .23638 L
.92822 .23639 L
.9289 .23639 L
.93018 .23639 L
.93137 .23639 L
.93268 .23639 L
.93407 .2364 L
.93664 .2364 L
.93898 .23642 L
.94114 .23643 L
.94351 .23645 L
.94582 .23647 L
.94829 .2365 L
.95273 .23658 L
.95686 .23667 L
.96206 .23682 L
.96697 .23701 L
.97139 .23722 L
.97619 .23752 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[125]:=",
  ImageSize->{203, 125.375},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;0000OB000`400?l00000o`00003oboooool0
0<_ooooo003;ooooo`005?ooool00ol0003oooooooooo`0Hooooo`;o0000=Oooool2o`0003Kooooo
0_l0000[ooooo`005?ooool00ol0003oooooooooo`0Hooooo`;o0000=Oooool2o`0003Kooooo0_l0
000[ooooo`005?ooool2o`0001Wooooo0_l0000eooooo`03o`000?oooooo000003Gooooo0_l0000[
ooooo`005?ooool00ol0003oooooooooo`0Hooooo`;o0000=Oooool00ol0003oooooo`00000eoooo
o`;o0000:oooool001Cooooo00?o0000ooooooooool06?ooool2o`0003Gooooo00?o0000ooooool0
0000=Oooool2o`0002_ooooo000Dooooo`;o00006Oooool2o`0003Gooooo00?o0000ooooool00000
=Oooool2o`0002_ooooo000Dooooo`03o`000?oooooooooo01Sooooo0_l0000eooooo`03o`000?oo
oooo000003Gooooo0_l0000[ooooo`005?ooool00ol0003oooooooooo`0Hooooo`;o0000=Oooool0
0ol0003oooooo`00000eooooo`;o0000:oooool001Cooooo0_l0000Iooooo`;o0000=Oooool00ol0
003oooooo`00000eooooo`;o0000:oooool001Cooooo00?o0000ooooooooool06?ooool2o`0003Go
oooo00?o0000ooooool00000=Oooool2o`0002_ooooo000Dooooo`03o`000?oooooooooo01Sooooo
0_l0000eooooo`03o`000?oooooo000003Gooooo0_l0000[ooooo`001_ooool5o`0000?ooooo0_l0
0004ooooo`;o00006Oooool2o`0003Gooooo00?o0000ooooool00000=Oooool2o`0002_ooooo0007
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`0Hooooo`;o0000=Oooool00ol0003oooooo`00000eooooo`;o0000:oooool000Go00000ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
6?ooool2o`0003Gooooo00?o0000ooooool00000=Oooool2o`0002_ooooo0009ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooooooool2o`0001Wooooo0_l0000eooooo`03
o`000?oooooo000003Gooooo0_l0000[ooooo`001_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Hooooo`;o0000=Oooool00ol0
003oooooo`00000eooooo`;o0000:oooool000Kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06?ooool2o`0003Gooooo00?o0000
ooooool00000=Oooool2o`0002_ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0000Ioooo
o`;o0000=Oooool00ol0003oooooo`00000eooooo`;o0000:oooool001Cooooo00?o0000oooooooo
ool06?ooool2o`0003Gooooo00?o0000ooooool00000=Oooool00ol0003oooooo`00000Zooooo`00
5?ooool2o`0001Wooooo0_l0000eooooo`03o`000?oooooo000003Gooooo00?o0000ooooool00000
:_ooool001Cooooo00?o0000ooooooooool06?ooool2o`0003Gooooo00?o0000ooooool00000=Ooo
ool00ol0003oooooo`00000Zooooo`005?ooool00ol0003oooooooooo`0Hooooo`;o0000=Oooool0
0ol0003oooooo`00000eooooo`03o`000?oooooo000002[ooooo000Dooooo`;o00006Oooool2o`00
03Gooooo00?o0000ooooool00000=Oooool00ol0003oooooo`00000Zooooo`005?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooo000003Cooooo00?o0000ooooool00000=Oooool00ol0003o
ooooo`00000Zooooo`005?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000003Cooooo
00?o0000ooooool00000=Oooool00ol0003oooooo`00000Zooooo`005?ooool2o`0001Wooooo00?o
0000ooooool00000=?ooool00ol0003oooooo`00000eooooo`03o`000?oooooo000002[ooooo0007
ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00000d
ooooo`03o`000?oooooo000003Gooooo00?o0000ooooool00000:_ooool000Sooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000006_ooool00ol0003oooooo`00
000dooooo`03o`000?oooooo000003Gooooo00?o0000ooooool00000:_ooool000Go00000oooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o00006Oooool00ol0003oooooo`00
000dooooo`03o`000?oooooo000003Gooooo00?o0000ooooool00000:_ooool000Sooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooool00000=?oo
ool00ol0003oooooo`00000eooooo`03o`000?oooooo000002[ooooo0008ooooo`04o`000?oooooo
ooooooooo`Co00001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000003Cooooo00Co
0000oooooooooooo0000=?ooool01?l0003oooooooooool0000Yooooo`001oooool2o`0000?ooooo
00?o0000ooooooooool01Oooool2o`0001Wooooo00?o0000ooooool00000=?ooool01?l0003ooooo
ooooool0000dooooo`04o`000?ooooooooooo`0002Wooooo0008ooooo`04o`000?oooooooooooooo
o`Go00000oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000003Cooooo00Co0000oooo
oooooooo0000=?ooool01?l0003oooooooooool0000Yooooo`005?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooo000003Cooooo00Co0000oooooooooooo0000=?ooool01?l0003ooooooooo
ool0000Yooooo`005?ooool2o`0001Wooooo00?o0000ooooool00000=?ooool01?l0003ooooooooo
ool0000dooooo`04o`000?ooooooooooo`0002Wooooo000Dooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooool00000=?ooool01?l0003oooooooooool0000dooooo`05o`000?oooooooooooooo
ool00000:?ooool001Cooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00000dooooo`04
o`000?ooooooooooo`0003Cooooo00Go0000ooooooooooooooooo`00000Xooooo`005?ooool2o`00
01Wooooo00?o0000ooooool00000=?ooool01?l0003oooooooooool0000dooooo`05o`000?oooooo
ooooooooool00000:?ooool001Cooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00000d
ooooo`04o`000?ooooooooooo`0003Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Uooooo`005?ooool2o`0001Wooooo00?o0000ooooool00000=?ooool01?l0003oooooooooool0
000dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09Oooool000Oooooo0ol00004
ooooo`;o00001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000003Cooooo00Co0000
oooooooooooo0000=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo0008
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooo000003Cooooo00Go0000ooooooooooooooooo`00000cooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool08oooool000Go00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Iooooo`03o`000?oooooo000003Cooooo
00Go0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo00Gooooo0ol0000Rooooo`00
2?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool06?ooool01?l0003oooooooooool0000cooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`08ooooo`Co00007_ooool000Sooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo0000<ooo
ool01Ol0003ooooooooooooooooo000003?ooooo00?o0000ooooooooool03?oooolHo`0000Kooooo
0007ooooo`;o00001?ooool01?l0003oooooooooool00003ooooo`;o00006Oooool01?l0003ooooo
ooooool0000cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Zooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003ooooo
ooooo`0Hooooo`04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo02[ooooo000Dooooo`03o`000?oooooooooo01Sooooo
00Co0000oooooooooooo0000<oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0:_ooool001Cooooo0_l0000Iooooo`04o`000?ooooooooooo`0003?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02[o
oooo000Dooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Zooooo`00
5?ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:_ooool001Cooooo
0_l0000Iooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`06ooooo`;o
0000;Oooool00ol0003oooooooooo`0Zooooo`005?ooool00ol0003oooooooooo`0Hooooo`05o`00
0?ooooooooooooooool00000<_ooool00ol0003oooooooooo`08ooooo`Ko00009oooool00ol0003o
ooooooooo`0Zooooo`005?ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool0
0000<_ooool00ol0003oooooooooo`0>oooooaWo00003_ooool00ol0003oooooooooo`0Zooooo`00
3Oooool3o`0000Cooooo0_l0000Iooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003o
ooooooooo`0Wooooo`Go00002Oooool00ol0003oooooooooo`0Zooooo`003?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0;?ooool2o`0000Oooooo00?o0000oooooooo
ool0:_ooool000Kooooo1Ol00005ooooo`05o`000?ooooooooooooooool000006_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02[ooooo000@ooooo`04o`000?ooooooooooooooo`;o
00006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0;_ooool2o`0000Gooooo00?o0000ooooooooool0:_ooool000cooooo1?l00004ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`003?oo
ool00ol0003oooooooooo`05ooooo`;o00006Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02[ooooo000<ooooo`Go00000oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00Kooooo0_l0000/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Zooooo`005?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00;ooooo1Ol000000ooooooo0000o`000003o`0001[ooooo0ol0000:ooooo`03o`000?oooooooooo
01;ooooo0ol0000Looooo`04o`000?ooooooooooooooo`?o00007_ooool3o`0000Cooooo0_l00003
ooooo`005?ooool2o`0001Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006
oooooa[o000000?oooooo`000?ooool02_ooool00ol0003oooooooooo`0Aooooo`05o`000?oooooo
ooooooooool000006oooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo000Dooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`Ko00002Ooo
ool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooo
ooooo`02o`0000;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo000Dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000;ooooo0_l00007ooooo`03
o`000?oooooooooo017ooooo1?l0000Mooooo`03o`000?oooooooooo00?o00007oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo000Dooooo`;o00006Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007oooool00ol0003oooooo`000004oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Noooo
o`04o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo000Dooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo0000023ooooo0_l00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`04o`000?oo
oooo0000o`0000;ooooo00?o0000ooooooooool06oooool2o`0000Cooooo00Co0000oooooooooooo
00000_ooool001Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`?o0000
8_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4oooool2o`0001gooooo00?o0000ooooooooool00ol0000Oooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`005?ooool2o`0001Wooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooo
oooooooo000003Cooooo00Co0000oooooooooooo0000;?ooool001Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool00000=?ooool01?l0003o
ooooooooool0000/ooooo`005?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo033o
oooo00Go0000ooooooooooooooooo`00000dooooo`04o`000?ooooooooooo`0002cooooo000?oooo
ok[o00000_ooool001Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`Co
00002?ooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool001Cooooo00?o0000ooooooooool03oooool2o`0000Oooooo00?o0000ooooooooool0<Ooo
ool01?l0003oooooooooool0000eooooo`03o`000?oooooo000002cooooo000Dooooo`;o00004_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooool00000=Ooo
ool00ol0003oooooo`00000/ooooo`005?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooo`00000eooooo`03o`000?oooooo
000002cooooo000Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0booooo`03o`000?oooooo000003Gooooo00?o0000ooooool00000;?ooool001Co
oooo0_l0000Eooooo`05o`000?ooooooooooooooool00000=?ooool00ol0003oooooo`00000eoooo
o`03o`000?oooooo000002cooooo000Dooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooo
ooooooooo`00000dooooo`03o`000?oooooo000003Gooooo00?o0000ooooool00000;?ooool001Co
oooo0_l0000Eooooo`05o`000?ooooooooooooooool00000=?ooool00ol0003oooooo`00000eoooo
o`03o`000?oooooo000002cooooo000Dooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooo
ooooooooo`00000dooooo`03o`000?oooooo000003Gooooo00?o0000ooooool00000;?ooool001Co
oooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0000eooooo`;o0000=Oooool00ol0
003oooooo`00000/ooooo`005?ooool2o`0001Kooooo00Co0000oooooooooooo0000=Oooool2o`00
03Gooooo00?o0000ooooool00000;?ooool000gooooo0ol00004ooooo`03o`000?oooooooooo01Go
oooo00Co0000oooooooooooo0000=Oooool2o`0003Gooooo00?o0000ooooool00000;?ooool000co
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ool00000=Oooool2o`0003Gooooo00?o0000ooooool00000;?ooool0013ooooo00Co0000oooooooo
oooooooo0_l0000Gooooo`03o`000?oooooo000003Gooooo0_l0000eooooo`03o`000?oooooo0000
02cooooo000@ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooo`00000eoooo
o`;o0000=Oooool00ol0003oooooo`00000/ooooo`003?ooool4o`0000Cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooo`00000eooooo`;o0000=Oooool00ol0003oooooo`00000/ooooo`00
3?ooool00ol0003oooooooooo`05ooooo`;o00005oooool00ol0003oooooo`00000eooooo`;o0000
=Oooool00ol0003oooooo`00000/ooooo`003?ooool5o`0000?ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooo`00000eooooo`;o0000=_ooool2o`0002cooooo000Dooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooool00000=Oooool2o`0003Kooooo0_l0000/ooooo`005?ooool2o`00
01Oooooo00?o0000ooooool00000=Oooool2o`0003Kooooo0_l0000/ooooo`005?ooool00ol0003o
ooooooooo`0Gooooo`;o0000=Oooool2o`0003Kooooo0_l0000/ooooo`005?ooool00ol0003ooooo
ooooo`0Gooooo`;o0000=Oooool2o`0003Kooooo0_l0000/ooooo`005?ooool2o`0001Sooooo0_l0
000eooooo`;o0000=_ooool2o`0002cooooo000Dooooo`03o`000?oooooooooo01Oooooo0_l0000e
ooooo`;o0000=_ooool2o`0002cooooo000Dooooo`03o`000?oooooooooo01Oooooo0_l0000eoooo
o`;o0000=_ooool2o`0002cooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0000Hooooo`;o
0000=Oooool2o`0003Kooooo0_l0000/ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool05oooool2o`0003Gooooo0_l0000fooooo`;o
0000;?ooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`;o
00006?ooool2o`0003Gooooo0_l0000fooooo`;o0000;?ooool000Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Oooooo0_l0000eooooo`;o
0000=_ooool2o`0002cooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`0Gooooo`;o0000=Oooool2o`0003Kooooo0_l0000/ooooo`00
1oooool2o`0000Cooooo00Co0000oooooooooooo00000oooool2o`0001Sooooo0_l0000fooooo`03
o`000?oooooooooo03Cooooo0_l0000/ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool00ol0003oooooooooo`0Gooooo`;o0000=_ooool00ol0003oooooooooo`0dooooo`;o0000
;?ooool001Cooooo00?o0000ooooooooool05oooool2o`0003Kooooo00?o0000ooooooooool0=?oo
ool2o`0002cooooo000Dooooo`;o00006?ooool2o`0003Kooooo00?o0000ooooooooool0=?ooool2
o`0002cooooo000Dooooo`03o`000?oooooooooo01Oooooo0_l0000fooooo`03o`000?oooooooooo
03Cooooo0_l0000/ooooo`005?ooool00ol0003oooooooooo`0Gooooo`;o0000=_ooool00ol0003o
ooooooooo`0dooooo`;o0000;?ooool001Cooooo0_l0000Hooooo`;o0000=_ooool00ol0003ooooo
ooooo`0dooooo`;o0000;?ooool001Cooooo00?o0000ooooooooool05oooool2o`0003Kooooo00?o
0000ooooooooool0=?ooool2o`0002cooooo000Dooooo`03o`000?oooooooooo01Oooooo0_l0000f
ooooo`03o`000?oooooooooo03Cooooo0_l0000/ooooo`001oooool3o`0000?ooooo0ol00004oooo
o`;o00006?ooool2o`0003Kooooo00?o0000ooooooooool0=?ooool2o`0002cooooo0008ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001Wooooo0_l0000f
ooooo`03o`000?oooooooooo03Cooooo0_l0000/ooooo`002?ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000006Oooool2o`0003Kooooo00?o0000ooooooooool0=?ooool2
o`0002cooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l0000H
ooooo`;o0000=_ooool00ol0003oooooooooo`0dooooo`;o0000;?ooool000Sooooo00Co0000oooo
oooooooooooo1?l0002kooooo`001oooool2o`0000?ooooo00?o0000ooooooooool0_?ooool000So
oooo00Co0000oooooooooooooooo1Ol0002jooooo`00boooool00<_ooooo003;ooooo`00boooool0
0001\
\>"],
  ImageRangeCache->{{{112.875, 314.875}, {491.25, 366.875}} -> {-7.58039, \
102.548, 0.0569176, 0.349873}}]
}, Open  ]],

Cell[TextData[{
  "This is a pretty good picture. Observe that the four branches of the graph \
are connected with vertical lines that appear to be the asymptotes. This is \
because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " made the graph by plotting lots of points and  connecting the dots. This \
is the default plot behavior. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
It appears that the only solutions to tan(x) = x in the interval \
from 0 to 10, other than x = 0, are the two that were just found using \
FindRoot. However, it may be worth looking more closely at the graph near x = \
0. The next input shows how to control the vertical plot range and add a \
title to the plot.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Plot[ Tan[x] - x, {x,0,0.2}, PlotRange->{0,0.001},
                             PlotLabel->\"A closer look near 0\" ]\
\>", \
"Input",
  CellLabel->"In[140]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.7619 0 618.034 [
[.2619 -0.0125 -12 -9 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .12361 -36 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -36 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -36 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -36 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -30 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -62.0312 0 ]
[.5 .63053 62.0312 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(0.0002)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.0004)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.0006)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.0008)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.001)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -123.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
75.062 13.000 moveto
(closer) show
117.062 13.000 moveto
(look) show
147.062 13.000 moveto
(near) show
177.062 13.000 moveto
(0) show
183.062 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03746 0 L
.03884 1e-05 L
.04016 1e-05 L
.04262 1e-05 L
.045 2e-05 L
.04753 3e-05 L
.0521 4e-05 L
.05489 6e-05 L
.05752 7e-05 L
.06244 .00011 L
.06757 .00016 L
.07299 .00023 L
.08269 .00039 L
.09312 .00064 L
.10458 .00101 L
.11478 .00144 L
.12409 .00192 L
.145 .0034 L
.16409 .00527 L
.18485 .00797 L
.20462 .01128 L
.22563 .0157 L
.26338 .02626 L
.30359 .04184 L
.34227 .06173 L
.38341 .08892 L
.42304 .12174 L
.46115 .16013 L
.50171 .20908 L
.54075 .2648 L
.58225 .3341 L
.62223 .41146 L
.6607 .49643 L
.70162 .59896 L
s
.70162 .59896 m
.70836 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[140]:=",
  ImageSize->{207.375, 128.062},
  ImageMargins->{{35, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003?0000P2000`400?l00000o`00003ocoooool0
04Cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00005_ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001Kooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00003ooooo`?o00005oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00003
ooooo`00@oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool05?ooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool004?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo01;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Doooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0C
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool004?ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01;ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool00_ooool004?ooooo00Co0000oooooooooooo00002?ooool0
1Ol0003oooooooooool0003ooooo00Co00005Oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo01Cooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooooooool4o`00
01Kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo0013
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0000Hooooo`04
o`000?ooooooooooo`0000Sooooo0_l0000Fooooo`04o`000?ooooooooooo`0000Sooooo0_l00003
ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000?ooooo0014ooooo`;o00002_ooool2o`0000;ooooo1Ol0000Eooooo`;o00002_oo
ool00ol0003oooooooooo`0Eooooo`;o00002_ooool01?l0003oooooooooooooool5o`0001Kooooo
0_l00009ooooo`?o00001?ooool00<oooooo003?ooooo`00coooool002?oooooY_l00006ooooo`00
9oooool00ol0003oooooooooo`0Go`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`009oooool00ol0003oooooooooo`0Gooooo`Oo00001_ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`0Nooooo`?o0000Q?ooool002Oooooo00?o0000oooo
ooooool08Oooool3o`00087ooooo000Wooooo`03o`000?oooooooooo02Cooooo0ol0001nooooo`00
9oooool00ol0003oooooooooo`0Wooooo`?o0000Noooool002Oooooo00?o0000ooooooooool0:_oo
ool3o`0007Sooooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0MOooool0
02Oooooo00?o0000ooooooooool0;_ooool2o`0007Gooooo000Wooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0L_ooool002Oooooo00?o0000ooooooooool0<Oooool2o`0007;ooooo
000Wooooo`03o`000?oooooooooo03?ooooo0_l0001`ooooo`009oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo06gooooo000Wooooo`03o`000?oooooooooo03Kooooo0_l0001]oooo
o`009oooool00ol0003oooooooooo`0hooooo`;o0000Joooool002Oooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`1Xooooo`009oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo06Oooooo0003ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000Cooooo0_l00002ooooo`Go00000oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo06Kooooo0002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo06Gooooo0002ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo06Cooooo0002ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00_ooool2o`00043ooooo00?o0000ooooooooool0Hoooool0
00;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`05o`000?oooooooooo
ooooool00000@_ooool00ol0003oooooooooo`1Rooooo`000_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00Go0000ooooooooooooooooo`000013ooooo`03o`000?oooooo
oooo067ooooo0003ooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool3o`00
00Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1Pooooo`009oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo05oooooo000Wooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool0G_ooool002Oooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`1Mooooo`009oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo05gooooo000Woooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0G?ooool002Oooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`1Kooooo`009oooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo05[ooooo000Wooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0FOoo
ool002Oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Hooooo`009oooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo05Oooooo000Wooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool0E_ooool002Oooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1Fooooo`009oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo05Gooooo000W
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0E?ooool000?ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0ol00003oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool0E?ooool000;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool0Doooool000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo0000ooooo`05
o`0000?ooooo0_l0001Aooooo`03o`000?oooooooooo05;ooooo0002ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool0D_ooool000;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
DOooool000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2o`0000Cooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`1@ooooo`000oooool2o`0000[ooooo0_l00004oooo
o`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo053ooooo000Wooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0Coooool002Oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1?ooooo`009ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04kooooo000Wooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool0COooool002Oooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`1=ooooo`009oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo04co
oooo000Wooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0C?ooool002Oooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`1;ooooo`009oooool00ol0003oooooooooo`1H
ooooo`03o`000?oooooooooo04[ooooo000Wooooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool0B_ooool002Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`19ooooo`00
9oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo04Wooooo000Wooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool0B?ooool000?ooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0ol00004ooooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool0B?ooool000;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`05o`000?ooooooooooooooool00000GOooool00ol0003oooooooooo`17
ooooo`000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go0000oooo
ooooooooooooo`00001Mooooo`03o`000?oooooooooo04Oooooo0002ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooo`000?ooool01?l00004ooooo`;o0000GOooool00ol0003oooooooooo`16ooooo`00
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`16ooooo`000_ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`15
ooooo`000oooool2o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00004oooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool0AOooool002Oooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`14ooooo`009oooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo04Cooooo000Wooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0@ooo
ool002Oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`13ooooo`009oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo04;ooooo000Wooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0@_ooool002Oooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`11ooooo`009oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo047ooooo000W
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0@?ooool002Oooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`10ooooo`009oooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo03oooooo000Wooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
?oooool002Oooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0nooooo`009oooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo03kooooo0003ooooo`;o00001?ooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`?o00001?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo03gooooo0002ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo000006Oooooo00?o0000oooo
ooooool0?Oooool000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04
o`000?ooooooooooooooo`;o0000Ioooool00ol0003oooooooooo`0looooo`000_ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo03cooooo0002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool01Ol0003ooooooooooooooooo000006Wooooo00?o0000ooooooooool0>oooool000;ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`05o`000?ooooooooooooooool00000
JOooool00ol0003oooooooooo`0kooooo`000oooool2o`0000[ooooo0_l00004ooooo`;o00001?oo
ool2o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0>ooo
ool002Oooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0jooooo`009oooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo03[ooooo000Wooooo`03o`000?oooooooooo06So
oooo00?o0000ooooooooool0>_ooool002Oooooo00?o0000ooooooooool0JOooool00ol0003ooooo
ooooo`0iooooo`009oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03Wooooo000W
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0>Oooool002Oooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`0hooooo`009oooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo03Sooooo000Wooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
>?ooool002Oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0gooooo`009oooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo03Oooooo000Wooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool0=oooool002Oooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`0fooooo`002Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo
0_l00003ooooo`?o00001?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo03Kooooo
0008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0eooooo`002?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`;o0000Kooo
ool00ol0003oooooooooo`0dooooo`002?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2[ooooo`00
2?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`2[ooooo`002?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool2o`000:gooooo
0009ooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo0:_ooooo003?
ooooo`00>Oooool2o`000004ooooool0003o0000o`0000Oooooo0ol00002ooooo`Go00000_ooool3
o`0000;ooooo1?l00003ooooo`?o00000_ooool3o`0000Wooooo1Ol00002ooooo`?o00000oooool3
o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`?o000000Coooooo`000?l0003ooooo0ol0
0003ooooo`Co000000Coooooo`000?l0003o00002oooool2o`00023ooooo000iooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001_ooool00ol0
003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003
ooooo`06o`000?ooooooooooo`000?oooooo00002Oooool01_l0003oooooooooool0003oooooo`00
00Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`04o`000?oooooo
ooooo`0001oooooo000iooooo`Go00001oooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03o`0000;ooooo1Ol00002ooooo`03o`000?oo
oooooooo00[ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool00_l0000:ooooo`05o`000?ooooooooooo`000?ooool01Ol00002ooooo`?o
00000oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0001oooooo000jooooo`03
o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooo`000005ooooo`05o`000?ooooooooooooooool000000_oo
ool2o`0000_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo
00Ko0000oooooooooooo0000ooooool00009ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooo`000002ooooo`04o`000?ooooooooooooooo`;o00002_ooool01?l0003ooooo
ooooool0000Oooooo`00>_ooool00ol0003oooooo`000009ooooo`?o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00000oooool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
2Oooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000?ooooo00Co0000ooooool0003o
00001oooool4o`0000?ooooo0ol00003ooooo`;o00000oooool2o`000003ooooool0003o000000So
oooo00Co0000oooooooooooo00007oooool003_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool01?l0003o
ooooooooool0000Oooooo`00>_ooool2o`0000oooooo0ol0000Qooooo`?o00003oooool2o`0002[o
oooo0_l0000Pooooo`00coooool00<oooooo0000\
\>"],
  ImageRangeCache->{{{112.875, 319.25}, {225.938, 98.875}} -> {-0.193589, \
0.000861428, 0.00127319, 9.80983*^-6}}]
}, Open  ]],

Cell[TextData[StyleBox["Using variables as functions",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
A typical calculus book is full of problems like the following. \
\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Graph the function",
    FontSlant->"Italic"],
  " ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "sin(",
  StyleBox["x",
    FontSlant->"Italic"],
  ")",
  " ",
  StyleBox["over the interval from",
    FontSlant->"Italic"],
  " ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 0 ",
  StyleBox["to",
    FontSlant->"Italic"],
  " ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 3. ",
  StyleBox["Find its maximum and minimum values on the interval.",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  " To handle this problem in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " we can define the variable ",
  StyleBox["y",
    FontSlant->"Italic"],
  " as a function of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " using the equals operator.  This is done in the first entry. The second \
entry uses the Plot function to display the graph of the function  over the \
given interval. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
y = x^2 Sin[x]
Plot[ y, {x,0,3} ]\
\>", "Input",
  CellLabel->"In[232]:="],

Cell[BoxData[
    \(x\^2\ Sin[x]\)], "Output",
  CellLabel->"Out[232]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.149191 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16391 -6 -4.5 ]
[.01131 .16391 0 4.5 ]
[.01131 .3131 -6 -4.5 ]
[.01131 .3131 0 4.5 ]
[.01131 .46229 -6 -4.5 ]
[.01131 .46229 0 4.5 ]
[.01131 .61148 -6 -4.5 ]
[.01131 .61148 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16391 m
.03006 .16391 L
s
[(1)] .01131 .16391 1 0 Mshowa
.02381 .3131 m
.03006 .3131 L
s
[(2)] .01131 .3131 1 0 Mshowa
.02381 .46229 m
.03006 .46229 L
s
[(3)] .01131 .46229 1 0 Mshowa
.02381 .61148 m
.03006 .61148 L
s
[(4)] .01131 .61148 1 0 Mshowa
.125 Mabswid
.02381 .04455 m
.02756 .04455 L
s
.02381 .07439 m
.02756 .07439 L
s
.02381 .10423 m
.02756 .10423 L
s
.02381 .13407 m
.02756 .13407 L
s
.02381 .19374 m
.02756 .19374 L
s
.02381 .22358 m
.02756 .22358 L
s
.02381 .25342 m
.02756 .25342 L
s
.02381 .28326 m
.02756 .28326 L
s
.02381 .34294 m
.02756 .34294 L
s
.02381 .37277 m
.02756 .37277 L
s
.02381 .40261 m
.02756 .40261 L
s
.02381 .43245 m
.02756 .43245 L
s
.02381 .49213 m
.02756 .49213 L
s
.02381 .52197 m
.02756 .52197 L
s
.02381 .5518 m
.02756 .5518 L
s
.02381 .58164 m
.02756 .58164 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03746 .01473 L
.03884 .01473 L
.04016 .01474 L
.04262 .01475 L
.045 .01476 L
.04753 .01478 L
.0521 .01482 L
.05752 .01489 L
.06244 .01498 L
.06787 .01511 L
.07287 .01526 L
.08414 .01573 L
.09408 .01632 L
.10458 .01715 L
.11406 .0181 L
.12422 .01936 L
.14255 .02234 L
.16379 .0271 L
.18391 .03305 L
.22224 .04882 L
.24202 .05944 L
.26302 .07268 L
.30077 .10169 L
.34098 .13995 L
.37967 .18353 L
.42081 .23616 L
.46043 .29155 L
.49854 .34739 L
.5391 .40724 L
.57814 .46263 L
.61964 .51584 L
.65962 .55818 L
.67794 .57369 L
.69809 .58738 L
.70767 .59253 L
.71797 .597 L
.72365 .59898 L
.72884 .60048 L
.73406 .60167 L
Mistroke
.73901 .60251 L
.74161 .60284 L
.74288 .60296 L
.74405 .60307 L
.7451 .60314 L
.74625 .60321 L
.7474 .60326 L
.74862 .6033 L
.74931 .60331 L
.74996 .60332 L
.75118 .60332 L
.75249 .60329 L
.75323 .60327 L
.75392 .60324 L
.75506 .60319 L
.75631 .6031 L
.75885 .60287 L
.76124 .60258 L
.76343 .60225 L
.76835 .60127 L
.77269 .60013 L
.77725 .59866 L
.78682 .59464 L
.79704 .5889 L
.81541 .57466 L
.8368 .55148 L
.85696 .52276 L
.89548 .4484 L
.93645 .33975 L
.97591 .20527 L
.97619 .2042 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[232]:=",
  ImageSize->{203.812, 126},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;0000OR000`400?l00000o`00003oboooool0
02Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Dooooo`?o00005?ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001?ooooo1Ol0000Booooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00005?ooool3o`0000cooooo000Uooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000001?ooooo00Co0000oooooooooooo0000
4oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000004_ooool01Ol0
003ooooooooooooooooo000000_ooooo000Uooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`09ooooo`009Oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01;ooooo0_l0000<ooooo`009Oooool01?l0003oooooooooool00007
ooooo`Co00005Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo1?l0000C
ooooo`05o`000?ooooooooooooooool000004_ooool01Ol0003ooooooooooooooooo000000Oooooo
1?l0000Gooooo`03o`000?oooooooooo00Wooooo000Uooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool05Oooool2o`0001Gooooo0_l00009ooooo`03o`000?oooooooooo01Cooooo
00Go0000ooooooooooooooooo`00000Booooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000002oooool002Kooooo0_l00008oooo
o`Go00005?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo1Ol0000Coooo
o`?o00005?ooool3o`0000Sooooo1Ol0000Cooooo`?o00003?ooool00<_ooooo000@ooooo`03o`00
0?oooooooooo0;Sooooo000@ooooo`03o`000?oooooooooo0;Sooooo000@ooooo`03o`000?oooooo
oooo0;Sooooo000;oooookSo00002?ooool0013ooooo00?o0000ooooooooool03oooool6o`0000Go
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[o
oooo000@ooooo`03o`000?oooooooooo01Gooooo1?l0002Oooooo`004?ooool00ol0003ooooooooo
o`0Iooooo`?o0000W?ooool0013ooooo00?o0000ooooooooool07?ooool3o`0009Wooooo000@oooo
o`03o`000?oooooooooo01oooooo0_l0002Gooooo`004?ooool00ol0003oooooooooo`0Qooooo`;o
0000UOooool0013ooooo00?o0000ooooooooool08oooool2o`0009?ooooo000@ooooo`03o`000?oo
oooooooo02Gooooo0_l0002Aooooo`004?ooool00ol0003oooooooooo`0Wooooo`;o0000Soooool0
013ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2<ooooo`004?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo08_ooooo000@ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0R_ooool0013ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`29ooooo`004?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08Sooooo000@oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Qoooool0013ooooo00?o0000oooooooo
ool0;oooool2o`0008Oooooo000@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
Q?ooool0013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`23ooooo`004?ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo08;ooooo000@ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0POooool0013ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`20ooooo`004?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo07oooooo
000@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0O_ooool0013ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1nooooo`002?ooool3o`0000Gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`1mooooo`002Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0O?ooool000Wooooo00?o0000ooooooooool0
1?ooool2o`0003_ooooo00?o0000ooooooooool0Noooool000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07[ooooo0009ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1iooooo`002?ooool2o`00
00Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1hooooo`002Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Moooool0013ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1gooooo`004?ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo07Kooooo000@ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`0:ooooo`004?ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool02_ooool0013ooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00[ooooo000@ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0:ooooo`004?oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02ooo
ool0013ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo00_ooooo000@ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0;ooooo`004?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool03?ooool0013ooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00cooooo000@ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`0<ooooo`004?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool0013ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00gooooo000@ooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0=ooooo`00
4?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
3Oooool0013ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo00kooooo000@ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0>ooooo`004?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool03_ooool0013ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo00oooooo0007ooooo`Go00001?ooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool03oooool000Sooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool03oooool000Wooooo00?o0000ooooooooool01?ooool2o`00053ooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`0?ooooo`002_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0@
ooooo`001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0DOooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo013ooooo0007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool04?ooool000Sooooo0ol00005ooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0Aooooo`004?ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool04Oooool0013ooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo017ooooo000@ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`004?ooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04_ooool0
013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
01;ooooo000@ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`0Cooooo`004?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool04oooool0013ooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo01Cooooo000@ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Dooooo`004?ooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05?ooool0013ooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Gooooo000@ooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`004?oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05_oo
ool0013ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01Kooooo000@ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0Fooooo`004?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool05oooool0013ooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo01Oooooo000@ooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0Hooooo`004?ooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool06?ooool0013ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo0008ooooo`?o
00001Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool06Oooool000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Iooooo`002oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Jooooo`002Oooool2o`0000Gooooo0_l0001Sooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool06_ooool000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06oooool000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Kooooo`002?ooool3o`0000Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01cooooo000@ooooo`03o`000?oooooooooo06Go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Looooo`004?ooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool07Oooool0013ooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01gooooo000@
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0N
ooooo`004?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool07_ooool0013ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01oooooo000@ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Oooooo`004?ooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool08?ooool0013ooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo023ooooo000@ooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Qooooo`004?ooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08_ooool0013ooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo
000@ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Sooooo`004?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09?ooool0013ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02Gooooo000@ooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Vooooo`004?ooool00ol0003oooooooooo`1dooooo`;o0000
5oooool2o`0002Wooooo000@ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Yooooo`004?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0:_ooool0013ooooo00?o0000ooooooooool0N?ooool2o`00
00oooooo0_l0000]ooooo`002Oooool3o`0000Cooooo00?o0000ooooooooool0N_ooool3o`0000_o
oooo00?o0000ooooooooool0;Oooool000[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1mooooo`_o0000<?ooool000Oooooo1Ol00004ooooo`03o`000?oooooooooo087ooooo0_l0
000eooooo`001oooool01?l0003oooooooooool00005ooooo`;o0000^Oooool000Sooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`2hooooo`002Oooool2o`000<3ooooo000:ooooo`03
o`000?oooooooooo0;kooooo003;ooooo`00\
\>"],
  ImageRangeCache->{{{112.875, 315.688}, {547.375, 422.375}} -> {-2.22213, \
15.0565, 0.0172125, 0.036626}}]
}, Open  ]],

Cell[TextData[{
  "Clearly the minimum ",
  StyleBox["y",
    FontSlant->"Italic"],
  " value on this interval is ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = 0, attained at the left endpoint where ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 0. To find the  maximum ",
  StyleBox["y",
    FontSlant->"Italic"],
  " value we will compute the derivative function and then find its zero near \
",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 2.5. The D function can be used to obtain the derivative. The syntax \
for differentiating variable y with respect to variable x is simply "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["D[y,x]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Following the usual calculus convention we name the derivative function ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "' ."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["y' = D[y,x]", "Input",
  CellLabel->"In[237]:="],

Cell[BoxData[
    \(x\^2\ Cos[x] + 2\ x\ Sin[x]\)], "Output",
  CellLabel->"Out[237]="]
}, Open  ]],

Cell[TextData[{
  "Now use FindRoot to find the zero of ",
  StyleBox["y'",
    FontSlant->"Italic"],
  " near to 2.5. Solve will not work here; try it. We name the zero of y' \
xmax and the corresponding y value ymax. Note the use of /., twice."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["FindRoot[ y' == 0, {x,2.5} ]", "Input",
  CellLabel->"In[238]:="],

Cell[BoxData[
    \({x \[Rule] 2.2889297281034056`}\)], "Output",
  CellLabel->"Out[238]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["xmax = x/.%", "Input",
  CellLabel->"In[239]:="],

Cell[BoxData[
    \(2.2889297281034056`\)], "Output",
  CellLabel->"Out[239]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["ymax = y/.%%", "Input",
  CellLabel->"In[240]:="],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(ymax\\)\\\" is similar to existing symbol \\\
\"\\!\\(xmax\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[240]:="],

Cell[BoxData[
    \(3.9453016252843254`\)], "Output",
  CellLabel->"Out[240]="]
}, Open  ]],

Cell[TextData[{
  "Now that the two coordinates of the high point have been found, it can be \
displayed on the graph by adding the point (xmax,ymax). ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses the notation {xmax,ymax} to denote a point and the ListPlot function \
to plot lists of points. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
The next input uses the Show function to display the original plot \
and the ListPlot of the high point. The actual output consisted of three \
plots. The first two were deleted. Note how spaces and carriage returns were \
used to clarify the Show input which has the general syntax\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Show[ { P1, P2, ... , Pn } ]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["where P1, P2, ... , Pn are Plot functions.", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
HighPoint = {xmax,ymax}
Show[ { Plot[ y, {x,0,3}], 
        ListPlot[ {HighPoint}, 
                   PlotStyle->PointSize[0.03] ]
      } 
    ]\
\>", "Input",
  CellLabel->"In[241]:="],

Cell[BoxData[
    \({2.2889297281034056`, 3.9453016252843254`}\)], "Output",
  CellLabel->"Out[241]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.149191 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16391 -6 -4.5 ]
[.01131 .16391 0 4.5 ]
[.01131 .3131 -6 -4.5 ]
[.01131 .3131 0 4.5 ]
[.01131 .46229 -6 -4.5 ]
[.01131 .46229 0 4.5 ]
[.01131 .61148 -6 -4.5 ]
[.01131 .61148 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16391 m
.03006 .16391 L
s
[(1)] .01131 .16391 1 0 Mshowa
.02381 .3131 m
.03006 .3131 L
s
[(2)] .01131 .3131 1 0 Mshowa
.02381 .46229 m
.03006 .46229 L
s
[(3)] .01131 .46229 1 0 Mshowa
.02381 .61148 m
.03006 .61148 L
s
[(4)] .01131 .61148 1 0 Mshowa
.125 Mabswid
.02381 .04455 m
.02756 .04455 L
s
.02381 .07439 m
.02756 .07439 L
s
.02381 .10423 m
.02756 .10423 L
s
.02381 .13407 m
.02756 .13407 L
s
.02381 .19374 m
.02756 .19374 L
s
.02381 .22358 m
.02756 .22358 L
s
.02381 .25342 m
.02756 .25342 L
s
.02381 .28326 m
.02756 .28326 L
s
.02381 .34294 m
.02756 .34294 L
s
.02381 .37277 m
.02756 .37277 L
s
.02381 .40261 m
.02756 .40261 L
s
.02381 .43245 m
.02756 .43245 L
s
.02381 .49213 m
.02756 .49213 L
s
.02381 .52196 m
.02756 .52196 L
s
.02381 .5518 m
.02756 .5518 L
s
.02381 .58164 m
.02756 .58164 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03746 .01473 L
.03884 .01473 L
.04016 .01474 L
.04262 .01475 L
.045 .01476 L
.04753 .01478 L
.0521 .01482 L
.05752 .01489 L
.06244 .01498 L
.06787 .01511 L
.07287 .01526 L
.08414 .01573 L
.09408 .01632 L
.10458 .01715 L
.11406 .0181 L
.12422 .01936 L
.14255 .02234 L
.16379 .0271 L
.18391 .03305 L
.22224 .04882 L
.24202 .05944 L
.26302 .07268 L
.30077 .10169 L
.34098 .13995 L
.37967 .18353 L
.42081 .23616 L
.46043 .29155 L
.49854 .34739 L
.5391 .40724 L
.57814 .46263 L
.61964 .51584 L
.65962 .55818 L
.67794 .57369 L
.69809 .58738 L
.70767 .59253 L
.71797 .597 L
.72365 .59898 L
.72884 .60048 L
.73406 .60167 L
Mistroke
.73901 .60251 L
.74161 .60283 L
.74288 .60296 L
.74405 .60306 L
.7451 .60314 L
.74625 .60321 L
.7474 .60326 L
.74862 .6033 L
.74931 .60331 L
.74996 .60332 L
.75118 .60332 L
.75249 .60329 L
.75323 .60327 L
.75392 .60324 L
.75506 .60319 L
.75631 .6031 L
.75885 .60287 L
.76124 .60258 L
.76343 .60225 L
.76835 .60126 L
.77269 .60013 L
.77725 .59866 L
.78682 .59463 L
.79704 .5889 L
.81541 .57466 L
.8368 .55147 L
.85696 .52276 L
.89548 .4484 L
.93645 .33975 L
.97591 .20526 L
.97619 .2042 L
Mfstroke
.03 w
.75045 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[241]:=",
  ImageSize->{202.812, 125.375},
  ImageMargins->{{36, 0}, {0, 5}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003:0000OB000`400?l00000o`00003ob_ooool0
02Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Cooooo`?o00005?ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001?ooooo1Ol0000Booooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00005?ooool3o`0000cooooo000Uooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000001?ooooo00Co0000oooooooooooo0000
4oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000004_ooool01Ol0
003ooooooooooooooooo000000_ooooo000Uooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`09ooooo`009Oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01;ooooo0_l0000<ooooo`009Oooool01?l0003oooooooooool00007
ooooo`Co00005?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo1?l0000C
ooooo`05o`000?ooooooooooooooool000004_ooool01Ol0003ooooooooooooooooo000000Oooooo
1?l0000Gooooo`03o`000?oooooooooo00Wooooo000Uooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool05?ooool2o`0001Gooooo0_l00009ooooo`03o`000?oooooooooo01Cooooo
00Go0000ooooooooooooooooo`00000Booooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000002oooool002Kooooo0_l00008oooo
o`Go00004oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo1Ol0000Coooo
o`?o00005?ooool3o`0000Sooooo1Ol0000Cooooo`?o00003?ooool00<[ooooo000@ooooo`03o`00
0?oooooooooo0;Oooooo000@ooooo`03o`000?oooooooooo0;Oooooo000;oooookOo00002?ooool0
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`[o00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool0013o
oooo00?o0000ooooooooool04_ooool3o`0000Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo000@ooooo`03o`000?oooooooooo01Gooooo
1?l0002Nooooo`004?ooool00ol0003oooooooooo`0Iooooo`?o0000Voooool0013ooooo00?o0000
ooooooooool07?ooool3o`0009Sooooo000@ooooo`03o`000?oooooooooo01oooooo0_l0002Foooo
o`004?ooool00ol0003oooooooooo`0Qooooo`;o0000U?ooool0013ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`2Aooooo`004?ooool00ol0003oooooooooo`0Tooooo`;o0000TOoo
ool0013ooooo00?o0000ooooooooool09_ooool2o`0008oooooo000@ooooo`03o`000?oooooooooo
02Sooooo0_l0002=ooooo`004?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08[o
oooo000@ooooo`03o`000?oooooooooo02_ooooo0_l0002:ooooo`004?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo08Oooooo000@ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0Q_ooool0013ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`25oooo
o`004?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo08Cooooo000@ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Poooool0013ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`22ooooo`004?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo087ooooo000@ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0P?ooool0013o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1oooooo`004?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo07kooooo000@ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0O_ooool000Sooooo0ol00005ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0OOooool000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo07cooooo0009ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`1kooooo`002Oooool00ol0003oooooooooo`04ooooo`;o0000
>oooool00ol0003oooooooooo`1jooooo`002Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0NOooool000Sooooo0_l00006ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0N?ooool000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo07Oooooo000@ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0Moooool0013ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`1fooooo`004?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo07Gooooo000@
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0:
ooooo`004?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool02_ooool0013ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo00[ooooo000@ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0;ooooo`004?ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool02oooool0013ooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00_ooooo000@ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`004?ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0013ooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00cooooo
000@ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`0<ooooo`004?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool03Oooool0013ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo00gooooo000@ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0=ooooo`004?ooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool03_ooool0013ooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0>ooooo`004?ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool03_ooool000Oo
oooo1Ol00004ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`0?ooooo`002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0?ooooo`002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`0?ooooo`002_ooool00ol0003oooooooooo`03ooooo`;o0000Coooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool04?oo
ool000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0@ooooo`002?ooool3o`0000Gooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo013ooooo000@oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Aoooo
o`004?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool04Oooool0013ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo017ooooo000@ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0Booooo`004?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04_ooool0013ooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo01;ooooo000@ooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Cooooo`004?ooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04oooool0013ooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Cooooo000@
ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0D
ooooo`004?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool05Oooool0013ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo01Gooooo000@ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0Eooooo`004?ooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool05_ooool0013ooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Kooooo000@ooooo`03o`000?oooooooooo
05_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Gooooo`004?ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool05oooool0013ooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01Sooooo
000@ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Hooooo`004?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool06?ooool000Sooooo0ol00005ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0Iooooo`001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
01Wooooo000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo01[ooooo0009ooooo`;o00001Oooool2o`0006?ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Jooooo`002oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0Kooooo`001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01_ooooo0008ooooo`?o00001Oooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool07?ooool0
013ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01cooooo000@ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Mooooo`004?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool07Oooool0013ooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo01kooooo000@ooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Nooooo`004?ooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07oooool0013ooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01oooooo000@ooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Pooooo`004?oo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08?oo
ool0013ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo027ooooo000@ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Rooooo`004?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool08_ooool0013ooooo00?o0000ooooooooool0Koooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02?ooooo000@ooooo`03o`000?oooooooooo073ooooo0_l0
000Nooooo`03o`000?oooooooooo02Cooooo000@ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Uooooo`004?ooool00ol0003oooooooooo`1coooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09_ooool0013ooooo00?o0000oooooooo
ool0M?ooool00ol0003oooooooooo`0Eooooo`;o0000:Oooool0013ooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Wooooo000@ooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Zooooo`004?ooool0
0ol0003oooooooooo`1gooooo`;o00004?ooool00ol0003oooooooooo`0[ooooo`002Oooool3o`00
00Cooooo00?o0000ooooooooool0NOooool3o`0000Cooooo0ol00004ooooo`;o0000;_ooool000[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1looooo`_o0000<?ooool000Oooooo
1Ol00004ooooo`03o`000?oooooooooo07oooooo1Ol0000cooooo`001oooool01?l0003ooooooooo
ool00005ooooo`;o0000P?ooool5o`0003?ooooo0008ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool0P?ooool3o`0003Cooooo0009ooooo`;o0000_oooool000[ooooo00?o0000oooo
ooooool0_Oooool00<[ooooo0000\
\>"],
  ImageRangeCache->{{{113.875, 315.688}, {635.25, 510.875}} -> {-2.25187, \
18.4015, 0.0173095, 0.0368325}}]
}, Open  ]],

Cell["\<\
Unfortunately, it appears that, in addition to showing the plots \
together, Show will also plot each of the component graphs. These were \
deleted, leaving only the composite plot in view above.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Note. It is possible to suppress the component plots \
by creating them separately and adding the option DisplayFunction -> \
Identity. One then adds the option DisplayFunction -> $DisplayFunction to the \
Show input. See below.", "SmallText"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
P1 = Plot[ y, {x,0,3}, DisplayFunction \[Rule] Identity];
P2 = ListPlot[ {HighPoint}, 
     PlotStyle \[Rule] PointSize[0.03],
     DisplayFunction \[Rule] Identity];
Show[ {P1,P2}, DisplayFunction \[Rule] $DisplayFunction ]\
\>", "Input",
  CellLabel->"In[246]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.149191 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16391 -6 -4.5 ]
[.01131 .16391 0 4.5 ]
[.01131 .3131 -6 -4.5 ]
[.01131 .3131 0 4.5 ]
[.01131 .46229 -6 -4.5 ]
[.01131 .46229 0 4.5 ]
[.01131 .61148 -6 -4.5 ]
[.01131 .61148 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16391 m
.03006 .16391 L
s
[(1)] .01131 .16391 1 0 Mshowa
.02381 .3131 m
.03006 .3131 L
s
[(2)] .01131 .3131 1 0 Mshowa
.02381 .46229 m
.03006 .46229 L
s
[(3)] .01131 .46229 1 0 Mshowa
.02381 .61148 m
.03006 .61148 L
s
[(4)] .01131 .61148 1 0 Mshowa
.125 Mabswid
.02381 .04455 m
.02756 .04455 L
s
.02381 .07439 m
.02756 .07439 L
s
.02381 .10423 m
.02756 .10423 L
s
.02381 .13407 m
.02756 .13407 L
s
.02381 .19374 m
.02756 .19374 L
s
.02381 .22358 m
.02756 .22358 L
s
.02381 .25342 m
.02756 .25342 L
s
.02381 .28326 m
.02756 .28326 L
s
.02381 .34294 m
.02756 .34294 L
s
.02381 .37277 m
.02756 .37277 L
s
.02381 .40261 m
.02756 .40261 L
s
.02381 .43245 m
.02756 .43245 L
s
.02381 .49213 m
.02756 .49213 L
s
.02381 .52196 m
.02756 .52196 L
s
.02381 .5518 m
.02756 .5518 L
s
.02381 .58164 m
.02756 .58164 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03746 .01473 L
.03884 .01473 L
.04016 .01474 L
.04262 .01475 L
.045 .01476 L
.04753 .01478 L
.0521 .01482 L
.05752 .01489 L
.06244 .01498 L
.06787 .01511 L
.07287 .01526 L
.08414 .01573 L
.09408 .01632 L
.10458 .01715 L
.11406 .0181 L
.12422 .01936 L
.14255 .02234 L
.16379 .0271 L
.18391 .03305 L
.22224 .04882 L
.24202 .05944 L
.26302 .07268 L
.30077 .10169 L
.34098 .13995 L
.37967 .18353 L
.42081 .23616 L
.46043 .29155 L
.49854 .34739 L
.5391 .40724 L
.57814 .46263 L
.61964 .51584 L
.65962 .55818 L
.67794 .57369 L
.69809 .58738 L
.70767 .59253 L
.71797 .597 L
.72365 .59898 L
.72884 .60048 L
.73406 .60167 L
Mistroke
.73901 .60251 L
.74161 .60283 L
.74288 .60296 L
.74405 .60306 L
.7451 .60314 L
.74625 .60321 L
.7474 .60326 L
.74862 .6033 L
.74931 .60331 L
.74996 .60332 L
.75118 .60332 L
.75249 .60329 L
.75323 .60327 L
.75392 .60324 L
.75506 .60319 L
.75631 .6031 L
.75885 .60287 L
.76124 .60258 L
.76343 .60225 L
.76835 .60126 L
.77269 .60013 L
.77725 .59866 L
.78682 .59463 L
.79704 .5889 L
.81541 .57466 L
.8368 .55147 L
.85696 .52276 L
.89548 .4484 L
.93645 .33975 L
.97591 .20526 L
.97619 .2042 L
Mfstroke
.03 w
.75045 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[246]:=",
  ImageSize->{214.062, 132.312},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003F0000Q2000`400?l00000o`00003oe_ooool0
02Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Eooooo`?o00005_ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001Gooooo1Ol0000Cooooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00005_ooool3o`0000gooooo000Wooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000001Gooooo00Co0000oooooooooooo0000
5?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000005?ooool01Ol0
003ooooooooooooooooo000000cooooo000Wooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`009oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Cooooo0_l0000=ooooo`009oooool01?l0003oooooooooool00007
ooooo`Co00005_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo1?l0000E
ooooo`05o`000?ooooooooooooooool000004oooool01Ol0003ooooooooooooooooo000000Oooooo
1?l0000Iooooo`03o`000?oooooooooo00[ooooo000Wooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool05_ooool2o`0001Oooooo0_l00009ooooo`03o`000?oooooooooo01Kooooo
00Go0000ooooooooooooooooo`00000Cooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000003?ooool002Sooooo0_l00008oooo
o`Go00005Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo1Ol0000Eoooo
o`?o00005Oooool3o`0000Sooooo1Ol0000Eooooo`?o00003Oooool00=Kooooo000@ooooo`03o`00
0?oooooooooo0<?ooooo000@ooooo`03o`000?oooooooooo0<?ooooo000@ooooo`03o`000?oooooo
oooo0<?ooooo000;oooool?o00002?ooool0013ooooo00?o0000ooooooooool04?ooool7o`0000Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_o
oooo000@ooooo`03o`000?oooooooooo01Oooooo1?l0002Xooooo`004?ooool00ol0003ooooooooo
o`0Kooooo`?o0000YOooool0013ooooo00?o0000ooooooooool07_ooool3o`000:;ooooo000@oooo
o`;o00008_ooool2o`000:3ooooo000@ooooo`03o`000?oooooooooo02?ooooo0_l0002Nooooo`00
4?ooool00ol0003oooooooooo`0Uooooo`;o0000W?ooool0013ooooo00?o0000ooooooooool09ooo
ool2o`0009[ooooo000@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Uoooool0
013ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Fooooo`004?ooool2o`0002co
oooo0_l0002Fooooo`004?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09?ooooo
000@ooooo`03o`000?oooooooooo02kooooo0_l0002Cooooo`004?ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo093ooooo000@ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0Soooool0013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2>ooooo`00
4?ooool2o`0003Cooooo00?o0000ooooooooool0SOooool0013ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`2<ooooo`004?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo08_ooooo000@ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0R_ooool0013o
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`29ooooo`004?ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo08Sooooo000@ooooo`;o0000>_ooool00ol0003ooooooooo
o`27ooooo`004?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08Kooooo000@oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0QOooool000Sooooo0ol00005ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0Q?ooool000Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08?ooooo0009ooooo`03o`000?oo
oooooooo00Cooooo0_l0000oooooo`03o`000?oooooooooo08;ooooo0009ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`21ooooo`002Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0P?ooool000So
oooo0_l00006ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0Ooooool000Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07kooooo
000@ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0O_ooool0013ooooo0_l00014
ooooo`03o`000?oooooooooo07gooooo000@ooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool0O?ooool0013ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo00_ooooo000@ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0;ooooo`004?ooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool02oooool0013ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo000@ooooo`;o0000BOooool00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo00cooooo000@ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0<ooooo`004?ooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool03Oooool0013ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00gooooo000@
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0=
ooooo`004?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool03_ooool0013ooooo0_l0001=ooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool03_ooool0013ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0?ooooo`004?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool03oooool0013ooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000@ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`004?ooool2o`00057ooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`0@ooooo`004?ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool04?ooool0013ooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo013ooooo0007oooo
o`Go00001?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool04Oooool000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04Oooool000Wooooo00?o0000oooooooo
ool01?ooool2o`0005Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Aooooo`00
2_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`0Booooo`001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01;ooooo
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool04_ooool000Sooooo0ol00005ooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Cooooo`004?ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool04oooool0
013ooooo0_l0001Iooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool04oooool0013o
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Co
oooo000@ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0Dooooo`004?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool05?ooool0013ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo01Gooooo000@ooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`0Eooooo`004?ooool2o`0005gooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Eooooo`004?ooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool05_ooool0013ooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01Kooooo000@ooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Gooooo`004?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05oooool0013o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Oo
oooo000@ooooo`;o0000HOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo
000@ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0Hooooo`004?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool06Oooool0013ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01Wooooo000@ooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Iooooo`004?ooool2o`0006Cooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`0Jooooo`004?ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool06_ooool0013ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01[ooooo000@ooooo`03o`000?oooooooooo
06Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Kooooo`002?ooool3o`0000Go
oooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01_o
oooo0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool07?ooool000_ooooo00?o0000ooooooooool0
0_ooool2o`0006Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Looooo`002Ooo
ool2o`0000Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo01gooooo000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo01gooooo0007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool07_ooool000Sooooo0ol00005ooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Nooooo`004?ooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool07oooool0013ooooo0_l0001]ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool07oooool0013ooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01oooooo000@ooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Pooooo`004?ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08?ooool0013o
oooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo027o
oooo000@ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0Qooooo`004?ooool2o`0007;ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0Rooooo`004?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool08_ooool0013ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo02?ooooo000@ooooo`03o`000?oooooooooo07Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Tooooo`004?ooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool09Oooool0013ooooo0_l0001gooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool09_ooool0013ooooo00?o0000ooooooooool0Moooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Kooooo000@ooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Wooooo`004?ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:?ooool0013ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo
000@ooooo`03o`000?oooooooooo07_ooooo0_l0000Hooooo`;o0000;?ooool0013ooooo0_l0001n
ooooo`;o00005Oooool00ol0003oooooooooo`0/ooooo`004?ooool00ol0003oooooooooo`1ooooo
o`;o00004_ooool00ol0003oooooooooo`0]ooooo`004?ooool00ol0003oooooooooo`21ooooo`;o
00003_ooool2o`00033ooooo0009ooooo`?o00001?ooool00ol0003oooooooooo`23ooooo`03o`00
0?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo033ooooo000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Q?ooool<o`0003?ooooo0007ooooo`Go00001?ooool0
0ol0003oooooooooo`27ooooo`Go0000=oooool000Oooooo00Co0000oooooooooooo00001Oooool2
o`0008Sooooo1Ol0000gooooo`002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
08Sooooo0ol0000hooooo`002Oooool2o`000<_ooooo000:ooooo`03o`000?oooooooooo0<Wooooo
003Fooooo`00\
\>"],
  ImageRangeCache->{{{112.875, 325.938}, {266.688, 135.375}} -> {-2.10523, \
4.29683, 0.0162902, 0.0346635}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{661, 760},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->14,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "    Page  ", 
          CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "    Page  ", 
          CounterBox[ "Page"]}], "Footer"], None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 735, 18, 137, "Text"],

Cell[CellGroupData[{
Cell[2514, 73, 58, 0, 41, "Subsection"],
Cell[2575, 75, 163, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[2763, 83, 65, 5, 71, "Input"],
Cell[2831, 90, 60, 2, 27, "Output"],
Cell[2894, 94, 64, 2, 27, "Output"],
Cell[2961, 98, 63, 2, 43, "Output"]
}, Open  ]],
Cell[3039, 103, 267, 7, 48, "Text"],
Cell[3309, 112, 210, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[3544, 122, 65, 1, 31, "Input"],
Cell[3612, 125, 81, 2, 27, "Output"]
}, Open  ]],
Cell[3708, 130, 158, 5, 28, "Text"],
Cell[3869, 137, 115, 3, 28, "Text"],
Cell[3987, 142, 88, 2, 28, "Text"],
Cell[4078, 146, 112, 3, 28, "Text"],
Cell[4193, 151, 78, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[4296, 157, 61, 4, 51, "Input"],
Cell[4360, 163, 64, 2, 27, "Output"]
}, Open  ]],
Cell[4439, 168, 234, 10, 28, "Text"],
Cell[4676, 180, 142, 3, 28, "Text"],
Cell[4821, 185, 265, 7, 48, "Text"],

Cell[CellGroupData[{
Cell[5111, 196, 65, 4, 36, "Input"],
Cell[5179, 202, 60, 2, 27, "Output"],
Cell[5242, 206, 60, 2, 27, "Output"]
}, Open  ]],
Cell[5317, 211, 54, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[5396, 215, 53, 1, 31, "Input"],
Cell[5452, 218, 60, 2, 27, "Output"]
}, Open  ]],
Cell[5527, 223, 168, 5, 60, "Text"],

Cell[CellGroupData[{
Cell[5720, 232, 74, 1, 31, "Input"],
Cell[5797, 235, 74, 2, 27, "Output"]
}, Open  ]],
Cell[5886, 240, 104, 4, 28, "Text"],

Cell[CellGroupData[{
Cell[6015, 248, 51, 1, 31, "Input"],
Cell[6069, 251, 96, 2, 27, "Output"]
}, Open  ]],
Cell[6180, 256, 313, 12, 48, "Text"],

Cell[CellGroupData[{
Cell[6518, 272, 54, 1, 31, "Input"],
Cell[6575, 275, 86, 2, 27, "Output"]
}, Open  ]],
Cell[6676, 280, 158, 4, 60, "Text"],

Cell[CellGroupData[{
Cell[6859, 288, 50, 1, 31, "Input"],
Cell[6912, 291, 65, 2, 27, "Output"]
}, Open  ]],
Cell[6992, 296, 144, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[7161, 305, 54, 1, 31, "Input"],
Cell[7218, 308, 126, 3, 32, "Output"]
}, Open  ]],
Cell[7359, 314, 58, 0, 28, "Text"],
Cell[7420, 316, 57, 1, 31, "Input"],
Cell[7480, 319, 530, 13, 132, "Text"],
Cell[8013, 334, 79, 2, 28, "Text"],
Cell[8095, 338, 244, 8, 48, "Text"],
Cell[8342, 348, 81, 2, 28, "Text"],
Cell[8426, 352, 73, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[8524, 358, 84, 4, 51, "Input"],
Cell[8611, 364, 77, 2, 30, "Output"],
Cell[8691, 368, 77, 2, 27, "Output"]
}, Open  ]],
Cell[8783, 373, 292, 7, 48, "Text"],
Cell[9078, 382, 150, 3, 28, "Text"],
Cell[9231, 387, 248, 7, 48, "Text"],
Cell[9482, 396, 130, 3, 28, "Text"],
Cell[9615, 401, 379, 9, 68, "Text"],

Cell[CellGroupData[{
Cell[10019, 414, 68, 1, 31, "Input"],
Cell[10090, 417, 152, 3, 45, "Output"]
}, Open  ]],
Cell[10257, 423, 497, 10, 144, "Text"],

Cell[CellGroupData[{
Cell[10779, 437, 100, 4, 51, "Input"],
Cell[10882, 443, 97, 2, 30, "Output"],
Cell[10982, 447, 117, 2, 33, "Output"]
}, Open  ]],
Cell[11114, 452, 139, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[11278, 459, 53, 1, 31, "Input"],
Cell[11334, 462, 73, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11444, 469, 53, 1, 31, "Input"],
Cell[11500, 472, 79, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11616, 479, 53, 1, 31, "Input"],
Cell[11672, 482, 79, 2, 33, "Output"]
}, Open  ]],
Cell[11766, 487, 63, 0, 28, "Text"],
Cell[11832, 489, 164, 5, 28, "Text"],
Cell[11999, 496, 134, 6, 28, "Text"],
Cell[12136, 504, 377, 12, 48, "Text"],

Cell[CellGroupData[{
Cell[12538, 520, 61, 1, 31, "Input"],
Cell[12602, 523, 83, 2, 27, "Output"]
}, Open  ]],
Cell[12700, 528, 96, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[12821, 535, 58, 1, 31, "Input"],
Cell[12882, 538, 486, 8, 49, "Message"],
Cell[13371, 548, 140, 3, 34, "Output"]
}, Open  ]],
Cell[13526, 554, 307, 8, 48, "Text"],

Cell[CellGroupData[{
Cell[13858, 566, 54, 1, 31, "Input"],
Cell[13915, 569, 64, 2, 27, "Output"]
}, Open  ]],
Cell[13994, 574, 110, 3, 28, "Text"],
Cell[14107, 579, 90, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[14222, 586, 51, 1, 31, "Input"],
Cell[14276, 589, 153, 3, 27, "Output"]
}, Open  ]],
Cell[14444, 595, 152, 3, 28, "Text"],
Cell[14599, 600, 396, 9, 68, "Text"],
Cell[14998, 611, 130, 3, 28, "Text"],
Cell[15131, 616, 139, 5, 28, "Text"],
Cell[15273, 623, 139, 3, 28, "Text"],
Cell[15415, 628, 121, 2, 28, "Text"],
Cell[15539, 632, 216, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[15780, 642, 67, 1, 31, "Input"],
Cell[15850, 645, 91, 2, 27, "Output"]
}, Open  ]],
Cell[15956, 650, 263, 8, 92, "Text"],

Cell[CellGroupData[{
Cell[16244, 662, 110, 4, 51, "Input"],
Cell[16357, 668, 102, 2, 30, "Output"],
Cell[16462, 672, 497, 9, 45, "Output"]
}, Open  ]],
Cell[16974, 684, 146, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[17145, 693, 53, 1, 31, "Input"],
Cell[17201, 696, 91, 2, 27, "Output"]
}, Open  ]],
Cell[17307, 701, 363, 13, 48, "Text"],

Cell[CellGroupData[{
Cell[17695, 718, 66, 1, 31, "Input"],
Cell[17764, 721, 225, 4, 27, "Output"]
}, Open  ]],
Cell[18004, 728, 300, 7, 48, "Text"],

Cell[CellGroupData[{
Cell[18329, 739, 58, 1, 31, "Input"],
Cell[18390, 742, 64, 2, 27, "Output"]
}, Open  ]],
Cell[18469, 747, 134, 3, 28, "Text"],
Cell[18606, 752, 225, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[18856, 762, 91, 4, 51, "Input"],
Cell[18950, 768, 77, 2, 27, "Output"],
Cell[19030, 772, 363, 6, 42, "Message"],
Cell[19396, 780, 87, 2, 27, "Output"]
}, Open  ]],
Cell[19498, 785, 135, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[19658, 794, 96, 4, 51, "Input"],
Cell[19757, 800, 90, 2, 27, "Output"],
Cell[19850, 804, 90, 2, 27, "Output"]
}, Open  ]],
Cell[19955, 809, 317, 8, 48, "Text"],
Cell[20275, 819, 128, 3, 28, "Text"],
Cell[20406, 824, 144, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[20575, 833, 71, 1, 31, "Input"],
Cell[20649, 836, 25432, 823, 134, 9023, 615, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[46096, 1662, 406, 10, 68, "Text"],
Cell[46505, 1674, 384, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[46914, 1686, 170, 5, 71, "Input"],
Cell[47087, 1693, 20497, 502, 138, 4850, 304, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[67599, 2198, 133, 3, 28, "Text"],
Cell[67735, 2203, 137, 5, 28, "Text"],
Cell[67875, 2210, 627, 30, 47, "Text"],
Cell[68505, 2242, 475, 15, 68, "Text"],

Cell[CellGroupData[{
Cell[69005, 2261, 84, 4, 51, "Input"],
Cell[69092, 2267, 72, 2, 30, "Output"],
Cell[69167, 2271, 16142, 462, 134, 4479, 313, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[85324, 2736, 654, 21, 68, "Text"],
Cell[85981, 2759, 113, 3, 28, "Text"],
Cell[86097, 2764, 203, 7, 28, "Text"],

Cell[CellGroupData[{
Cell[86325, 2775, 54, 1, 31, "Input"],
Cell[86382, 2778, 87, 2, 30, "Output"]
}, Open  ]],
Cell[86484, 2783, 305, 8, 48, "Text"],

Cell[CellGroupData[{
Cell[86814, 2795, 71, 1, 31, "Input"],
Cell[86888, 2798, 91, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87016, 2805, 54, 1, 31, "Input"],
Cell[87073, 2808, 79, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87189, 2815, 55, 1, 31, "Input"],
Cell[87247, 2818, 387, 6, 42, "Message"],
Cell[87637, 2826, 79, 2, 27, "Output"]
}, Open  ]],
Cell[87731, 2831, 371, 9, 68, "Text"],
Cell[88105, 2842, 353, 7, 68, "Text"],
Cell[88461, 2851, 135, 3, 28, "Text"],
Cell[88599, 2856, 105, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[88729, 2862, 197, 8, 131, "Input"],
Cell[88929, 2872, 102, 2, 27, "Output"],
Cell[89034, 2876, 16892, 473, 139, 4504, 315, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[105941, 3352, 266, 6, 48, "Text"],
Cell[106210, 3360, 324, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[106559, 3369, 275, 7, 111, "Input"],
Cell[106837, 3378, 16472, 468, 141, 4504, 315, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

