(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    237523,       7920]*)
(*NotebookOutlinePosition[    239812,       7990]*)
(*  CellTagsIndexPosition[    239768,       7986]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part II. Calculations and Calculus with ", "Section"],
  StyleBox["Mathematica", "Section",
    FontSlant->"Italic"],
  "\n",
  StyleBox["Section 3. Functions as Transformations", "Subsection"],
  "\nFunctions are introduced in calculus in the general form ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  "). The letters ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " are called the independent  and dependent variables respectively and the \
letter ",
  StyleBox["f",
    FontSlant->"Italic"],
  " is often referred to as the \"function rule\". In this manual we will \
refer to ",
  StyleBox["f",
    FontSlant->"Italic"],
  " as a function or sometimes a function rule or a transformation rule or as \
a transformation. Many applications of calculus are easier to handle when the \
relevant functions are entered as transformations. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Using a transformation to define a function",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Consider the function ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "sin(",
  StyleBox["x",
    FontSlant->"Italic"],
  ") that was introduced in the calculus example in Section 2."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Another calculus example: Find the tangent line to the graph of \
this function at x ",
    FontSlant->"Italic"],
  "= 2 ",
  StyleBox["and plot it. ",
    FontSlant->"Italic"],
  " "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Begin with the definition of the function as a transformation using \
what is called \"function notation\". Read the  input as \"f transforms x to \
x^2*sin(x)\". \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["f[x_] := x^2 Sin[x]", "Input",
  CellLabel->"In[2]:="],

Cell["\<\
Note that the function is defined using a combination of a color \
and an equals sign. We will refer to this as the \"assignment operator\". (No \
space between the colon and the equals sign, please.) The function is named \
f, but any name can be used. Likewise, although the letter x was chosen to \
denote the independent variable, any other symbol would serve exactly the \
same purpose. The input x on the left of the definition appears with an \
underscore, the appearances of x are not underscored.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Having done this, the value of f when x = a is obtained by entering \
f[a]. See the following examples.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
{ f[0], f[1], f[2], f[3] }
N[%]\
\>", "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \({0, Sin[1], 4\ Sin[2], 9\ Sin[3]}\)], "Output",
  CellLabel->"Out[54]="],

Cell[BoxData[
    \({0.`, 0.8414709848078965`, 3.637189707302727`, 
      1.2700800725388048`}\)], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell["\<\
The following plot shows the graph of f over the interval [0,3]. \
\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Plot[ f[x], {x,0,3} ]", "Input",
  CellLabel->"In[9]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.149191 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16391 -6 -4.5 ]
[.01131 .16391 0 4.5 ]
[.01131 .3131 -6 -4.5 ]
[.01131 .3131 0 4.5 ]
[.01131 .46229 -6 -4.5 ]
[.01131 .46229 0 4.5 ]
[.01131 .61148 -6 -4.5 ]
[.01131 .61148 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16391 m
.03006 .16391 L
s
[(1)] .01131 .16391 1 0 Mshowa
.02381 .3131 m
.03006 .3131 L
s
[(2)] .01131 .3131 1 0 Mshowa
.02381 .46229 m
.03006 .46229 L
s
[(3)] .01131 .46229 1 0 Mshowa
.02381 .61148 m
.03006 .61148 L
s
[(4)] .01131 .61148 1 0 Mshowa
.125 Mabswid
.02381 .04455 m
.02756 .04455 L
s
.02381 .07439 m
.02756 .07439 L
s
.02381 .10423 m
.02756 .10423 L
s
.02381 .13407 m
.02756 .13407 L
s
.02381 .19374 m
.02756 .19374 L
s
.02381 .22358 m
.02756 .22358 L
s
.02381 .25342 m
.02756 .25342 L
s
.02381 .28326 m
.02756 .28326 L
s
.02381 .34294 m
.02756 .34294 L
s
.02381 .37277 m
.02756 .37277 L
s
.02381 .40261 m
.02756 .40261 L
s
.02381 .43245 m
.02756 .43245 L
s
.02381 .49213 m
.02756 .49213 L
s
.02381 .52197 m
.02756 .52197 L
s
.02381 .5518 m
.02756 .5518 L
s
.02381 .58164 m
.02756 .58164 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03746 .01473 L
.03884 .01473 L
.04016 .01474 L
.04262 .01475 L
.045 .01476 L
.04753 .01478 L
.0521 .01482 L
.05752 .01489 L
.06244 .01498 L
.06787 .01511 L
.07287 .01526 L
.08414 .01573 L
.09408 .01632 L
.10458 .01715 L
.11406 .0181 L
.12422 .01936 L
.14255 .02234 L
.16379 .0271 L
.18391 .03305 L
.22224 .04882 L
.24202 .05944 L
.26302 .07268 L
.30077 .10169 L
.34098 .13995 L
.37967 .18353 L
.42081 .23616 L
.46043 .29155 L
.49854 .34739 L
.5391 .40724 L
.57814 .46263 L
.61964 .51584 L
.65962 .55818 L
.67794 .57369 L
.69809 .58738 L
.70767 .59253 L
.71797 .597 L
.72365 .59898 L
.72884 .60048 L
.73406 .60167 L
Mistroke
.73901 .60251 L
.74161 .60284 L
.74288 .60296 L
.74405 .60307 L
.7451 .60314 L
.74625 .60321 L
.7474 .60326 L
.74862 .6033 L
.74931 .60331 L
.74996 .60332 L
.75118 .60332 L
.75249 .60329 L
.75323 .60327 L
.75392 .60324 L
.75506 .60319 L
.75631 .6031 L
.75885 .60287 L
.76124 .60258 L
.76343 .60225 L
.76835 .60127 L
.77269 .60013 L
.77725 .59866 L
.78682 .59464 L
.79704 .5889 L
.81541 .57466 L
.8368 .55148 L
.85696 .52276 L
.89548 .4484 L
.93645 .33975 L
.97591 .20527 L
.97619 .2042 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[9]:=",
  ImageSize->{163, 100.625},
  ImageMargins->{{37, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002S0000I2000`400?l00000o`00003oXoooool0
01oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000=ooooo`?o00003_ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000cooooo1Ol0000<ooooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00003Oooool3o`0000cooooo000Nooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000000cooooo00Co0000oooooooooooo0000
3Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003ooooooooooooooooo000000_ooooo000Nooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`09ooooo`007_ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`007_ooool01?l0003oooooooooool00007
ooooo`Co00003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo1?l0000<
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003ooooooooooooooooo000000Oooooo
1?l0000@ooooo`03o`000?oooooooooo00Wooooo000Nooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool03_ooool2o`0000oooooo0_l00009ooooo`03o`000?oooooooooo00gooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000002oooool001oooooo0_l00008oooo
o`Go00003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo1Ol0000<oooo
o`?o00003_ooool3o`0000Sooooo1Ol0000<ooooo`?o00003?ooool00:?ooooo000?ooooo`03o`00
0?oooooooooo097ooooo000?ooooo`03o`000?oooooooooo097ooooo000<ooooohko00002Oooool0
00oooooo00?o0000ooooooooool03_ooool7o`0001Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0:ooooo`003oooool00ol0003oooooooooo`0Dooooo`;o0000Noooool000oooooo
00?o0000ooooooooool05_ooool3o`0007Sooooo000?ooooo`;o00006_ooool2o`0007Kooooo000?
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Loooool000oooooo00?o0000oooo
ooooool07?ooool2o`0007?ooooo000?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0L?ooool000oooooo0_l0000Pooooo`;o0000L?ooool000oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1]ooooo`003oooool00ol0003oooooooooo`0Rooooo`;o0000KOooool0
00oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Zooooo`003oooool2o`0002Ko
oooo00?o0000ooooooooool0JOooool000oooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1Xooooo`003oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06Oooooo000?
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0I_ooool000oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Uooooo`003oooool2o`0002_ooooo00?o0000oooooooo
ool0I?ooool000Wooooo0ol00003ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
I?ooool000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo06?ooooo000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`1Rooooo`002_ooool00ol0003oooooooooo`02ooooo`;o0000;_ooool00ol0
003oooooooooo`1Qooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0H?ooool000Wooooo0_l00004ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0Goooool000[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo05kooooo000?ooooo`;o0000<Oooool00ol0003oooooooooo`1N
ooooo`003oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool02_ooool000oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo00[ooooo000?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0:ooooo`003oooool2o`0003Gooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`0:ooooo`003oooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool02oooool000oooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo00_ooooo000?ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0;ooooo`003oooool2o`0003Sooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0<ooooo`003oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool03?ooool000oooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00cooooo000?oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0=oooo
o`003oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool03Oooool000oooooo0_l0000kooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
3Oooool000Sooooo1Ol00002ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0>ooooo`002Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0>ooooo`002_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0>ooooo`002oooool01?l0003oooooooooooooool2o`0003kooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`002?ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00oooooo0008ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03oooool000Wooooo0ol00003oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0@oooo
o`003oooool2o`00043ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0@ooooo`00
3oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
4?ooool000oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo017ooooo000?ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0Aooooo`003oooool2o`0004?ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Aooooo`003oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool04_ooool000oooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo01;ooooo000?ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Booooo`003oooool2o`0004Kooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Cooooo`003oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04oooool000oooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01?ooooo000?ooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Dooooo`003ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?oo
ool000oooooo0_l0001:ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool0
00Wooooo0ol00003ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Eooooo`002?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Gooooo000<ooooo`04
o`000?ooooooooooo`0004gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eoooo
o`002_ooool2o`0000?ooooo0_l0001=ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool05_ooool000cooooo00Co0000oooooooooooo0000C_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo01Oooooo0008ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05oooool000Wooooo
0ol00003ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Hooooo`003oooool2o`00053ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Hooooo`003oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool06Oooool000oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo01[ooooo000?ooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Jooooo`003oooool2o`0005?ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Kooooo`003oooool00ol0003oooooooooo`1Cooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool06oooool000oooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo000?ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Mooooo`003oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07Oooool000oooooo
0_l0001Hooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool000oooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo000?
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0P
ooooo`003oooool00ol0003oooooooooo`1Jooooo`;o00004Oooool00ol0003oooooooooo`0Qoooo
o`003oooool2o`0005gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`00
2_ooool3o`0000;ooooo00?o0000ooooooooool0GOooool3o`0000[ooooo0_l0000Uooooo`002ooo
ool01Ol0003ooooooooooooooooo000006;ooooo0_l00005ooooo`?o00009oooool000Sooooo1Ol0
0002ooooo`03o`000?oooooooooo06;ooooo1_l0000Yooooo`002?ooool01?l0003oooooooooool0
0003ooooo`;o0000T_ooool000Wooooo00?o0000ooooool000000oooool00ol0003oooooooooo`2A
ooooo`002_ooool2o`0009Oooooo000;ooooo`03o`000?oooooooooo09Gooooo002Sooooo`00\
\>"],
  ImageRangeCache->{{{114.875, 276.875}, {626.5, 526.875}} -> {-2.91387, \
24.4724, 0.0222838, 0.0474171}}]
}, Open  ]],

Cell[TextData[{
  "The derivative function, also as a transformation, is obtained with the \
entry ",
  StyleBox["f '",
    FontWeight->"Bold"],
  ", the second derivative is ",
  StyleBox["f ''",
    FontWeight->"Bold"],
  " and so on."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["f'[x]", "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(x\^2\ Cos[x] + 2\ x\ Sin[x]\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["f''[x]", "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(4\ x\ Cos[x] + 2\ Sin[x] - x\^2\ Sin[x]\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["\<\
Here is the derivative of f at x = 2, computed exactly and then \
approximately.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
f'[2]
N[%]\
\>", "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(4\ Cos[2] + 4\ Sin[2]\)], "Output",
  CellLabel->"Out[15]="],

Cell[BoxData[
    \(1.9726023611141572`\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["\<\
This is the slope of the tangent line to the graph of f at the \
point ( 2 , f(2) ).
The function whose graph is the tangent line at ( 2 , f(2) ) is defined in \
the next entry. We name it T.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["T[x_] := f[2] + f'[2]*(x - 2)", "Input",
  CellLabel->"In[17]:="],

Cell["\<\
The entry T[x] will display the formula for the line in exact \
terms. Apply N to see the formula in decimal  form. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
T[x]
N[%]\
\>", "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(4\ Sin[2] + \((\(-2\) + x)\)\ \((4\ Cos[2] + 4\ Sin[2])\)\)], "Output",
  CellLabel->"Out[19]="],

Cell[BoxData[
    \(\(\(3.637189707302727`\)\(\[InvisibleSpace]\)\) + 
      1.9726023611141572`\ \((\(-2.`\) + x)\)\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
The next plot shows the graph of f and T together over the interval \
from 0 to 3. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Plot[ {f[x],T[x]}, {x,0,3} ]", "Input",
  CellLabel->"In[22]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0453512 0.0994632 [
[.18254 .03285 -9 -9 ]
[.18254 .03285 9 0 ]
[.34127 .03285 -3 -9 ]
[.34127 .03285 3 0 ]
[.5 .03285 -9 -9 ]
[.5 .03285 9 0 ]
[.65873 .03285 -3 -9 ]
[.65873 .03285 3 0 ]
[.81746 .03285 -9 -9 ]
[.81746 .03285 9 0 ]
[.97619 .03285 -3 -9 ]
[.97619 .03285 3 0 ]
[.01131 .14481 -6 -4.5 ]
[.01131 .14481 0 4.5 ]
[.01131 .24428 -6 -4.5 ]
[.01131 .24428 0 4.5 ]
[.01131 .34374 -6 -4.5 ]
[.01131 .34374 0 4.5 ]
[.01131 .4432 -6 -4.5 ]
[.01131 .4432 0 4.5 ]
[.01131 .54267 -6 -4.5 ]
[.01131 .54267 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .04535 m
.18254 .0516 L
s
[(0.5)] .18254 .03285 0 1 Mshowa
.34127 .04535 m
.34127 .0516 L
s
[(1)] .34127 .03285 0 1 Mshowa
.5 .04535 m
.5 .0516 L
s
[(1.5)] .5 .03285 0 1 Mshowa
.65873 .04535 m
.65873 .0516 L
s
[(2)] .65873 .03285 0 1 Mshowa
.81746 .04535 m
.81746 .0516 L
s
[(2.5)] .81746 .03285 0 1 Mshowa
.97619 .04535 m
.97619 .0516 L
s
[(3)] .97619 .03285 0 1 Mshowa
.125 Mabswid
.05556 .04535 m
.05556 .0491 L
s
.0873 .04535 m
.0873 .0491 L
s
.11905 .04535 m
.11905 .0491 L
s
.15079 .04535 m
.15079 .0491 L
s
.21429 .04535 m
.21429 .0491 L
s
.24603 .04535 m
.24603 .0491 L
s
.27778 .04535 m
.27778 .0491 L
s
.30952 .04535 m
.30952 .0491 L
s
.37302 .04535 m
.37302 .0491 L
s
.40476 .04535 m
.40476 .0491 L
s
.43651 .04535 m
.43651 .0491 L
s
.46825 .04535 m
.46825 .0491 L
s
.53175 .04535 m
.53175 .0491 L
s
.56349 .04535 m
.56349 .0491 L
s
.59524 .04535 m
.59524 .0491 L
s
.62698 .04535 m
.62698 .0491 L
s
.69048 .04535 m
.69048 .0491 L
s
.72222 .04535 m
.72222 .0491 L
s
.75397 .04535 m
.75397 .0491 L
s
.78571 .04535 m
.78571 .0491 L
s
.84921 .04535 m
.84921 .0491 L
s
.88095 .04535 m
.88095 .0491 L
s
.9127 .04535 m
.9127 .0491 L
s
.94444 .04535 m
.94444 .0491 L
s
.25 Mabswid
0 .04535 m
1 .04535 L
s
.02381 .14481 m
.03006 .14481 L
s
[(1)] .01131 .14481 1 0 Mshowa
.02381 .24428 m
.03006 .24428 L
s
[(2)] .01131 .24428 1 0 Mshowa
.02381 .34374 m
.03006 .34374 L
s
[(3)] .01131 .34374 1 0 Mshowa
.02381 .4432 m
.03006 .4432 L
s
[(4)] .01131 .4432 1 0 Mshowa
.02381 .54267 m
.03006 .54267 L
s
[(5)] .01131 .54267 1 0 Mshowa
.125 Mabswid
.02381 .06524 m
.02756 .06524 L
s
.02381 .08514 m
.02756 .08514 L
s
.02381 .10503 m
.02756 .10503 L
s
.02381 .12492 m
.02756 .12492 L
s
.02381 .16471 m
.02756 .16471 L
s
.02381 .1846 m
.02756 .1846 L
s
.02381 .20449 m
.02756 .20449 L
s
.02381 .22438 m
.02756 .22438 L
s
.02381 .26417 m
.02756 .26417 L
s
.02381 .28406 m
.02756 .28406 L
s
.02381 .30396 m
.02756 .30396 L
s
.02381 .32385 m
.02756 .32385 L
s
.02381 .36363 m
.02756 .36363 L
s
.02381 .38353 m
.02756 .38353 L
s
.02381 .40342 m
.02756 .40342 L
s
.02381 .42331 m
.02756 .42331 L
s
.02381 .4631 m
.02756 .4631 L
s
.02381 .48299 m
.02756 .48299 L
s
.02381 .50288 m
.02756 .50288 L
s
.02381 .52277 m
.02756 .52277 L
s
.02381 .02546 m
.02756 .02546 L
s
.02381 .00557 m
.02756 .00557 L
s
.02381 .56256 m
.02756 .56256 L
s
.02381 .58245 m
.02756 .58245 L
s
.02381 .60234 m
.02756 .60234 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04535 m
.02499 .04535 L
.02605 .04535 L
.02729 .04535 L
.02846 .04535 L
.02954 .04535 L
.03053 .04535 L
.03163 .04535 L
.03279 .04535 L
.03395 .04535 L
.0352 .04536 L
.03746 .04536 L
.03884 .04536 L
.04016 .04536 L
.04262 .04537 L
.045 .04538 L
.04753 .04539 L
.0521 .04542 L
.05752 .04547 L
.06244 .04553 L
.06787 .04562 L
.07287 .04572 L
.08414 .04603 L
.09408 .04642 L
.10458 .04697 L
.11406 .04761 L
.12422 .04845 L
.14255 .05044 L
.16379 .0536 L
.18391 .05758 L
.22224 .06809 L
.24202 .07517 L
.26302 .08399 L
.30077 .10334 L
.34098 .12884 L
.37967 .15789 L
.42081 .19299 L
.46043 .22991 L
.49854 .26714 L
.5391 .30704 L
.57814 .34397 L
.61964 .37944 L
.65962 .40767 L
.67794 .41801 L
.69809 .42714 L
.70767 .43057 L
.71797 .43355 L
.72365 .43487 L
.72884 .43587 L
.73406 .43667 L
Mistroke
.73901 .43722 L
.74161 .43744 L
.74288 .43753 L
.74405 .43759 L
.7451 .43764 L
.74625 .43769 L
.7474 .43772 L
.74862 .43775 L
.74931 .43776 L
.74996 .43776 L
.75118 .43776 L
.75249 .43775 L
.75323 .43773 L
.75392 .43771 L
.75506 .43767 L
.75631 .43762 L
.75885 .43747 L
.76124 .43727 L
.76343 .43705 L
.76835 .43639 L
.77269 .43564 L
.77725 .43466 L
.78682 .43197 L
.79704 .42815 L
.81541 .41866 L
.8368 .4032 L
.85696 .38406 L
.89548 .33448 L
.93645 .26205 L
.97591 .17239 L
.97619 .17168 L
Mfstroke
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{132, 81.375},
  ImageMargins->{{37, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000240000DB000`400?l00000o`00003oQ?ooool0
01Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000:ooooo`?o00002_ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000[ooooo1Ol00008ooooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00002_ooool3o`0000Kooooo000Eooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000000[ooooo00Co0000oooooooooooo0000
2Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0
003ooooooooooooooooo000000Gooooo000Eooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`03ooooo`005Oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo0_l00006ooooo`002Oooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`0000Oooooo1?l0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01oooool4o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool4o`0000gooooo00?o0000ooooooooool00oooool000Wooooo0_l0
000:ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02oooool2o`0000_ooooo
0_l00009ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooo
ooooool000001Oooool000Wooooo0_l0000;ooooo`;o00002?ooool5o`0000[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`07ooooo`Go00002_ooool3o`0000[ooooo0ol00008oooo
o`Go00002Oooool3o`0000Kooooo0009ooooo`Co0000Moooool000Wooooo00Go0000oooooooooooo
ooooo`00001fooooo`002Oooool00ol0003oooooooooo`02ooooo`;o0000M?ooool000KoooooNol0
0003ooooo`002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo1_l0001T
ooooo`002Oooool2o`0000Sooooo0_l0000;ooooo`Co0000H?ooool000Wooooo00?o0000oooooooo
ool02Oooool2o`0000gooooo0_l0001Nooooo`002Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo0_l0001Looooo`002Oooool2o`0000gooooo0_l0000>ooooo`;o0000F_oo
ool000Wooooo00?o0000ooooooooool03_ooool2o`0000kooooo00?o0000ooooooooool0Eoooool0
00Wooooo0_l0000Aooooo`03o`000?oooooooooo00cooooo0_l0001Gooooo`002Oooool00ol0003o
ooooooooo`0Aooooo`;o00003_ooool2o`0005Gooooo0003ooooo`?o00000oooool2o`0001Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Booooo`001?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool2o`0005;ooooo0004
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool2o`0000oooooo0_l0001@
ooooo`001?ooool00ol0003oooooooooo`02ooooo`;o00006?ooool2o`0000oooooo00?o0000oooo
ooooool0COooool000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0C?ooool000?ooooo0_l00004ooooo`;o0000
6oooool2o`0000kooooo00?o0000ooooooooool0Boooool000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Looooo`;o00003Oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo00Cooooo0009ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Cooooo0009ooooo`;o00008?ooool2o`00
00cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`05ooooo`002Oooool00ol0003o
ooooooooo`0Qooooo`;o00002oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Go
oooo0009ooooo`;o00009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool01_ooool000Wooooo00?o0000ooooooooool09?ooool2o`0000[ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`000_ooool5o`0000;ooooo0_l0000W
ooooo`;o00002Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Oooooo0003oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01oooool000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Yooooo`;o00002?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00Oooooo0005ooooo`04o`000?ooooooooooooooo`;o0000;?ooool2o`00
00Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`000_ooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02?ooool000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o0000;oooool2o`0000Kooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`09ooooo`000oooool3o`0000?ooooo00?o0000ooooooooool0<?ooool2o`0000Go
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`09ooooo`002Oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0:ooooo`002Oooool2o`0003Cooooo0_l00004ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool02_ooool000Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool000Wooooo0_l0000goooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0;oooo
o`002Oooool00ol0003oooooooooo`0gooooo`;o00000oooool2o`0002cooooo00?o0000oooooooo
ool02oooool000Wooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0<ooooo`000oooool3o`0000?ooooo0_l0000looooo`05o`000?oo
ooooooooooooool00000:Oooool00ol0003oooooooooo`0<ooooo`000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool0??ooool2o`0000;ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`02o`0003oooooo0_l0
00000ooooooo0000o`00000Uooooo`03o`000?oooooooooo00gooooo0004ooooo`;o00000oooool0
0ol0003oooooooooo`10ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool03_oo
ool000Kooooo00?o0000ooooooooool00_l00012ooooo`;o000000?oooooo`000?ooool08?ooool0
0ol0003oooooooooo`0?ooooo`000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool0@oooool3o`0001oooooo00?o0000ooooooooool04?ooool000?ooooo0ol00003oooo
o`03o`000?oooooooooo04Gooooo0ol0000Looooo`03o`000?oooooooooo017ooooo0009ooooo`;o
0000Aoooool3o`0001Wooooo0_l0000Dooooo`002Oooool00ol0003oooooooooo`18ooooo`;o0000
5oooool00ol0003oooooooooo`0Dooooo`002Oooool2o`0004_ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Eooooo`002Oooool00ol0003oooooooooo`1;ooooo`;o00004_ooool0
0ol0003oooooooooo`0Fooooo`002Oooool00ol0003oooooooooo`1=ooooo`;o00003_ooool2o`00
01Wooooo0004ooooo`?o00000_ooool2o`0004oooooo0ol0000:ooooo`;o00006oooool000Gooooo
00Go0000ooooooooooooooooo`00001Aooooo`co00007Oooool000;ooooo1Ol00002ooooo`;o0000
D_ooool2o`0000;ooooo0_l0000Qooooo`000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool08_ooool000?ooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`1Dooooo`;o00008_ooool000Cooooo0_l00003ooooo`;o0000Eoooool2
o`00023ooooo0005ooooo`05o`000?ooooooooooooooool00000F_ooool00ol0003oooooooooo`0M
ooooo`002Oooool2o`0005[ooooo0_l0000Mooooo`002Oooool00ol0003oooooooooo`1Kooooo`;o
00006oooool000Wooooo0_l0001Nooooo`03o`000?oooooooooo01Sooooo0009ooooo`03o`000?oo
oooooooo05kooooo0_l0000Hooooo`002Oooool00ol0003oooooooooo`1Pooooo`;o00005_ooool0
00?ooooo0ol00003ooooo`;o0000Hoooool00ol0003oooooooooo`0Cooooo`000_ooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool0Hoooool2o`0001?ooooo0006ooooo`03
o`000?oooooooooo00;o0000I_ooool2o`00017ooooo0006ooooo`04o`000?ooooooooooo`0006Wo
oooo00?o0000ooooooooool03_ooool000;ooooo1?l00003ooooo`03o`000?oooooooooo06Sooooo
0_l0000>ooooo`000_ooool00ol0003oooooooooo`04ooooo`;o0000Joooool2o`0000cooooo0002
ooooo`Go00000_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Wooooo0009oooo
o`;o0000K_ooool2o`0000Wooooo0009ooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool01_ooool000Wooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05ooooo`002Ooo
ool2o`0007;ooooo00?o0000ooooooooool01?ooool000Wooooo00?o0000ooooooooool0N?ooool0
0001\
\>"],
  ImageRangeCache->{{{114.875, 245.875}, {490.188, 409.812}} -> {-3.21681, \
32.9133, 0.0258261, 0.08243}}]
}, Open  ]],

Cell["\<\
Tangent lines are usually plotted over shorter intervals. This can \
be accomplished by applying Show to two plots.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Note. As was the case with Show in the last section \
the following entry produced three plots. We deleted the first two. As an \
alternative you can make the plots with DisplayFunction -> Identity and then \
add DisplayFunction -> $DisplayFunction to the Show entry. We will not say \
this anymore.", "SmallText"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Show[ Plot[ f[x], {x,0,3} ], Plot[ T[x], {x,1.5,2.5}] ]", "Input",
  CellLabel->"In[51]:=",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.127307 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .14202 -6 -4.5 ]
[.01131 .14202 0 4.5 ]
[.01131 .26933 -6 -4.5 ]
[.01131 .26933 0 4.5 ]
[.01131 .39664 -6 -4.5 ]
[.01131 .39664 0 4.5 ]
[.01131 .52394 -6 -4.5 ]
[.01131 .52394 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14202 m
.03006 .14202 L
s
[(1)] .01131 .14202 1 0 Mshowa
.02381 .26933 m
.03006 .26933 L
s
[(2)] .01131 .26933 1 0 Mshowa
.02381 .39664 m
.03006 .39664 L
s
[(3)] .01131 .39664 1 0 Mshowa
.02381 .52394 m
.03006 .52394 L
s
[(4)] .01131 .52394 1 0 Mshowa
.125 Mabswid
.02381 .04018 m
.02756 .04018 L
s
.02381 .06564 m
.02756 .06564 L
s
.02381 .0911 m
.02756 .0911 L
s
.02381 .11656 m
.02756 .11656 L
s
.02381 .16748 m
.02756 .16748 L
s
.02381 .19295 m
.02756 .19295 L
s
.02381 .21841 m
.02756 .21841 L
s
.02381 .24387 m
.02756 .24387 L
s
.02381 .29479 m
.02756 .29479 L
s
.02381 .32025 m
.02756 .32025 L
s
.02381 .34571 m
.02756 .34571 L
s
.02381 .37118 m
.02756 .37118 L
s
.02381 .4221 m
.02756 .4221 L
s
.02381 .44756 m
.02756 .44756 L
s
.02381 .47302 m
.02756 .47302 L
s
.02381 .49848 m
.02756 .49848 L
s
.02381 .54941 m
.02756 .54941 L
s
.02381 .57487 m
.02756 .57487 L
s
.02381 .60033 m
.02756 .60033 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03746 .01473 L
.03884 .01473 L
.04016 .01473 L
.04262 .01474 L
.045 .01475 L
.04753 .01477 L
.0521 .01481 L
.05752 .01487 L
.06244 .01494 L
.06787 .01505 L
.07287 .01518 L
.08414 .01558 L
.09408 .01608 L
.10458 .01679 L
.11406 .0176 L
.12422 .01868 L
.14255 .02122 L
.16379 .02528 L
.18391 .03036 L
.22224 .04382 L
.24202 .05288 L
.26302 .06417 L
.30077 .08893 L
.34098 .12158 L
.37967 .15876 L
.42081 .20368 L
.46043 .25094 L
.49854 .29859 L
.5391 .34967 L
.57814 .39693 L
.61964 .44233 L
.65962 .47846 L
.67794 .4917 L
.69809 .50338 L
.70767 .50777 L
.71797 .51159 L
.72365 .51328 L
.72884 .51456 L
.73406 .51557 L
Mistroke
.73901 .51629 L
.74161 .51657 L
.74288 .51668 L
.74405 .51676 L
.7451 .51683 L
.74625 .51689 L
.7474 .51693 L
.74862 .51696 L
.74931 .51697 L
.74996 .51698 L
.75118 .51698 L
.75249 .51696 L
.75323 .51694 L
.75392 .51692 L
.75506 .51687 L
.75631 .5168 L
.75885 .5166 L
.76124 .51635 L
.76343 .51607 L
.76835 .51523 L
.77269 .51426 L
.77725 .513 L
.78682 .50957 L
.79704 .50467 L
.81541 .49253 L
.8368 .47274 L
.85696 .44824 L
.89548 .38478 L
.93645 .29207 L
.97591 .17731 L
.97619 .17641 L
Mfstroke
.5 .35219 m
.51288 .36238 L
.52692 .37349 L
.54011 .38392 L
.5528 .39396 L
.5663 .40464 L
.5793 .41492 L
.59312 .42585 L
.60643 .43638 L
.61923 .44651 L
.63285 .45728 L
.64597 .46766 L
.65858 .47764 L
.67201 .48826 L
.68493 .49848 L
.69868 .50935 L
.71191 .51982 L
.72464 .5299 L
.73819 .54061 L
.75123 .55093 L
.76509 .5619 L
.77845 .57246 L
.7913 .58263 L
.80497 .59344 L
.81746 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[51]:=",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{140, 86.3125},
  ImageMargins->{{36, 0}, {0, 3}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002<0000ER000`400?l00000o`00003oS?ooool0
01Wooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000;ooooo`?o00002_ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000[ooooo1Ol00009ooooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00002_ooool3o`0000Wooooo000Hooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000000[ooooo00Co0000oooooooooooo0000
2_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0
003ooooooooooooooooo000000Sooooo000Hooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`006?ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`006?ooool01?l0003oooooooooool00007
ooooo`Co00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo1?l0000:
ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo
1?l0000=ooooo`03o`000?oooooooooo00Kooooo000Hooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool03?ooool2o`0000_ooooo0_l00009ooooo`03o`000?oooooooooo00_ooooo
00Go0000ooooooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000002?ooool001Wooooo0_l00008oooo
o`Go00002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo1Ol0000:oooo
o`?o00002oooool3o`0000Sooooo1Ol00009ooooo`?o00002Oooool008cooooo000<ooooo`03o`00
0?oooooooooo07gooooo000<ooooo`03o`000?oooooooooo07gooooo0009oooooggo00001_ooool0
00cooooo00?o0000ooooooooool03?ooool6o`0001?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`0Aooooo`Co0000J?ooool000cooooo
0_l0000Fooooo`?o0000IOooool000cooooo00?o0000ooooooooool06?ooool2o`0006?ooooo000<
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0H?ooool000cooooo0_l0000Loooo
o`;o0000H?ooool000cooooo00?o0000ooooooooool07Oooool2o`0005kooooo000<ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0Foooool000cooooo0_l0000Qooooo`;o0000Fooo
ool000cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Hooooo`003?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo05Oooooo000<ooooo`;o00009Oooool00ol0003o
ooooooooo`1Fooooo`001_ooool3o`0000?ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1Eooooo`001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0EOooool000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo05Cooooo0007ooooo`03o`000?oooooooooo00;ooooo0_l0000Xoooo
o`03o`000?oooooooooo05?ooooo0007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1Booooo`001_ooool2o`0000Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1Aooooo`001oooool00ol0003oooooooooo`02ooooo`;o0000:ooo
ool00ol0003oooooooooo`1@ooooo`003?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool01oooool000cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo00Oooooo000<ooooo`;o0000;_ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`08ooooo`003?ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool02?ooool000cooooo0_l0000`
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02Oooool000cooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo000<ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`09ooooo`00
3?ooool2o`0003?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`001Ooo
ool5o`0000;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo00[ooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00[ooooo0007ooooo`03o`000?oooooo
oooo00;ooooo0_l0000eooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool0
00Sooooo00Go0000ooooooooooooooooo`00000gooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool02oooool000Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0;ooooo`001Oooool01Ol0
003ooooooooooooooooo000000;ooooo0_l0000hooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool03?ooool000Kooooo0ol00003ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0<ooooo`003?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool000cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo000<ooooo`;o0000>ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00gooooo000<ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0>ooooo`003?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool000co
oooo0_l0000nooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03oooool000cooooo
00?o0000ooooooooool0>?ooool2o`0000?ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0?ooooo`003?ooool00ol0003oooooooooo`0jooooo`;o00000_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo013ooooo000<ooooo`;o0000?Oooool01?l0003oooooooooool0
000Zooooo`03o`000?oooooooooo013ooooo0006ooooo`?o00000oooool00ol0003oooooooooo`0m
ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool04?ooool000Gooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo0000
9oooool00ol0003oooooooooo`0Aooooo`002Oooool00ol0003oooooooooo`02o`00043ooooo00Co
0000oooooooooooo00009_ooool00ol0003oooooooooo`0Aooooo`001oooool2o`0000?ooooo00?o
0000ooooooooool0@?ooool3o`0002Gooooo00?o0000ooooooooool04_ooool000Wooooo00Co0000
oooooooooooo0000A?ooool2o`0002Cooooo00?o0000ooooooooool04_ooool000Gooooo00Go0000
ooooooooooooooooo`000002ooooo`;o0000A?ooool2o`0002;ooooo00?o0000ooooooooool04ooo
ool000Kooooo0ol00003ooooo`03o`000?oooooooooo04Cooooo0_l0000Pooooo`03o`000?oooooo
oooo01Cooooo000<ooooo`03o`000?oooooooooo04Gooooo0_l0000Oooooo`03o`000?oooooooooo
01Cooooo000<ooooo`;o0000B?ooool2o`0001cooooo00?o0000ooooooooool05Oooool000cooooo
00?o0000ooooooooool0B?ooool2o`0001[ooooo00?o0000ooooooooool05_ooool000cooooo00?o
0000ooooooooool0BOooool2o`0001Sooooo00?o0000ooooooooool05oooool000cooooo00?o0000
ooooooooool0B_ooool2o`0001Kooooo00?o0000ooooooooool06?ooool000cooooo0_l0001=oooo
o`;o00004oooool00ol0003oooooooooo`0Iooooo`003?ooool00ol0003oooooooooo`1=ooooo`;o
00004Oooool00ol0003oooooooooo`0Jooooo`003?ooool00ol0003oooooooooo`1>ooooo`?o0000
3Oooool2o`0001gooooo0007ooooo`?o00000_ooool2o`00053ooooo0ol0000;ooooo`03o`000?oo
oooooooo01gooooo0008ooooo`05o`000?ooooooooooooooool00000Doooool3o`0000Oooooo0_l0
000Pooooo`001Oooool5o`0000;ooooo00?o0000ooooooooool0Doooool8o`0002;ooooo0005oooo
o`04o`000?ooooooooooo`0000?ooooo0_l0001Dooooo`03o`000?oooooooooo02Oooooo0006oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool0E?ooool2o`0002Oooooo0007ooooo`;o
00000oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02Cooooo0008ooooo`04o`00
0?ooooooooooooooo`;o0000F?ooool00ol0003oooooooooo`0Sooooo`003?ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo02;ooooo000<ooooo`03o`000?oooooooooo05Wooooo0_l0
000Rooooo`003?ooool2o`0005cooooo00?o0000ooooooooool07oooool000cooooo00?o0000oooo
ooooool0G?ooool2o`0001oooooo000<ooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool07?ooool000cooooo0_l0001Pooooo`03o`000?oooooooooo01_ooooo000<ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool06_ooool000cooooo00?o0000ooooooooool0OOooool0
0001\
\>"],
  ImageRangeCache->{{{113.875, 252.875}, {150.188, 64.875}} -> {-3.21911, \
3.4436, 0.0254195, 0.0633874}}]
}, Open  ]],

Cell[TextData[StyleBox["Plot several tangent lines",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Several tangent lines can be plotted by defining the function L so \
that L[a,x] is the formula for the tangent line  to the graph of f at the \
point (a,f(a)). L is a function of two variables. See below. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["L[a_,x_] := f[a] + f'[a]*(x - a)", "Input",
  CellLabel->"In[24]:="],

Cell["\<\
The Table function can then be used to make a list of tangent line \
plots at points evenly  spaced along the curve. The list is named Lines \
(output suppressed). There are four of them. (Here we use DisplayFunction -> \
Identity.)\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Lines = Table[ Plot[ L[a,x], {x,a-0.3,a+0.3},
                      DisplayFunction -> Identity ],
                       {a,0,3} ];\
\>", "Input",
  CellLabel->"In[41]:="],

Cell["\<\
Now put Lines into the Show function (along with the graph of \
f(x)). The additional PlotRange specification is needed to force display of \
the combined plot over its full range.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Show[ {Plot[f[x],{x,0,3}], Lines}, 
              DisplayFunction -> $DisplayFunction,
              PlotRange->{{0,3},{0,4.5}} ]\
\>", "Input",
  CellLabel->"In[53]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.333333 0 0.137341 [
[.16667 -0.0125 -9 -9 ]
[.16667 -0.0125 9 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -9 -9 ]
[.83333 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .13734 -6 -4.5 ]
[-0.0125 .13734 0 4.5 ]
[-0.0125 .27468 -6 -4.5 ]
[-0.0125 .27468 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .54936 -6 -4.5 ]
[-0.0125 .54936 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(0.5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(1)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(2)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2.5)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .13734 m
.00625 .13734 L
s
[(1)] -0.0125 .13734 1 0 Mshowa
0 .27468 m
.00625 .27468 L
s
[(2)] -0.0125 .27468 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(3)] -0.0125 .41202 1 0 Mshowa
0 .54936 m
.00625 .54936 L
s
[(4)] -0.0125 .54936 1 0 Mshowa
.125 Mabswid
0 .02747 m
.00375 .02747 L
s
0 .05494 m
.00375 .05494 L
s
0 .0824 m
.00375 .0824 L
s
0 .10987 m
.00375 .10987 L
s
0 .16481 m
.00375 .16481 L
s
0 .19228 m
.00375 .19228 L
s
0 .21975 m
.00375 .21975 L
s
0 .24721 m
.00375 .24721 L
s
0 .30215 m
.00375 .30215 L
s
0 .32962 m
.00375 .32962 L
s
0 .35709 m
.00375 .35709 L
s
0 .38455 m
.00375 .38455 L
s
0 .43949 m
.00375 .43949 L
s
0 .46696 m
.00375 .46696 L
s
0 .49443 m
.00375 .49443 L
s
0 .5219 m
.00375 .5219 L
s
0 .57683 m
.00375 .57683 L
s
0 .6043 m
.00375 .6043 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 1e-05 L
.01434 1e-05 L
.01579 1e-05 L
.01716 2e-05 L
.01975 3e-05 L
.02225 4e-05 L
.02491 6e-05 L
.0297 .0001 L
.0354 .00016 L
.04057 .00025 L
.04627 .00037 L
.05151 .0005 L
.06335 .00094 L
.07378 .00148 L
.08481 .00224 L
.09476 .00311 L
.10543 .00427 L
.12468 .00702 L
.14698 .0114 L
.16811 .01688 L
.20835 .0314 L
.22912 .04117 L
.25118 .05336 L
.29081 .08007 L
.33303 .11529 L
.37365 .1554 L
.41685 .20386 L
.45845 .25485 L
.49846 .30625 L
.54105 .36135 L
.58205 .41234 L
.62562 .46132 L
.66761 .50029 L
.68684 .51458 L
.70799 .52718 L
.71806 .53192 L
.72886 .53603 L
.73483 .53786 L
.74028 .53924 L
.74576 .54033 L
Mistroke
.75096 .54111 L
.75369 .54141 L
.75503 .54152 L
.75626 .54162 L
.75736 .54169 L
.75856 .54175 L
.75977 .5418 L
.76105 .54183 L
.76177 .54184 L
.76246 .54185 L
.76374 .54185 L
.76512 .54183 L
.76589 .54181 L
.76661 .54178 L
.76781 .54173 L
.76913 .54165 L
.7718 .54144 L
.7743 .54117 L
.7766 .54086 L
.78177 .53996 L
.78633 .53892 L
.79112 .53756 L
.80117 .53386 L
.81189 .52857 L
.83119 .51547 L
.85364 .49412 L
.87481 .46769 L
.91526 .39923 L
.95828 .29922 L
.9997 .17541 L
1 .17443 L
Mfstroke
3e-05 0 m
.00024 0 L
.0005 0 L
.00077 0 L
.00103 0 L
.00127 0 L
.00152 0 L
.00179 0 L
.00205 0 L
.00228 0 L
.00256 0 L
.00271 0 L
.00286 0 L
.00312 0 L
.00325 0 L
.0034 0 L
.00354 0 L
.00369 0 L
.00396 0 L
.00411 0 L
.00425 0 L
.0044 0 L
.00457 0 L
.00471 0 L
.00486 0 L
.00501 0 L
.00514 0 L
.00539 0 L
.00566 0 L
.00591 0 L
.00619 0 L
.00645 0 L
.00669 0 L
.00693 0 L
.00715 0 L
.0074 0 L
.00764 0 L
.0079 0 L
.00817 0 L
.0084 0 L
.00866 0 L
.00894 0 L
.00909 0 L
.00923 0 L
.00951 0 L
.00976 0 L
.00999 0 L
.01023 0 L
.01048 0 L
.01072 0 L
Mistroke
.01094 0 L
.01115 0 L
.01137 0 L
.01161 0 L
.01185 0 L
.0121 0 L
.01234 0 L
.01256 0 L
.01282 0 L
.01297 0 L
.0131 0 L
.01335 0 L
.01361 0 L
.01386 0 L
.01414 0 L
.0144 0 L
.01465 0 L
.01489 0 L
.0151 0 L
.01536 0 L
.01559 0 L
.01585 0 L
.01613 0 L
.01636 0 L
.01662 0 L
.01689 0 L
.01705 0 L
.01719 0 L
.01746 0 L
.01772 0 L
.01794 0 L
.01819 0 L
.01844 0 L
.01868 0 L
.0189 0 L
.01911 0 L
.01934 0 L
.01957 0 L
.01981 0 L
.02006 0 L
.0203 0 L
.02052 0 L
.02078 0 L
.02093 0 L
.02106 0 L
.02131 0 L
.02157 0 L
.02182 0 L
.02197 0 L
.0221 0 L
Mistroke
.02235 0 L
.02261 0 L
.02284 0 L
.02306 0 L
.0233 0 L
.02356 0 L
.02382 0 L
.02396 0 L
.0241 0 L
.02437 0 L
.02453 0 L
.02467 0 L
.02492 0 L
.02519 0 L
.02545 0 L
.02569 0 L
.02591 0 L
.02615 0 L
.02637 0 L
.02658 0 L
.02682 0 L
.02708 0 L
.02733 0 L
.02756 0 L
.02782 0 L
.02806 0 L
.02828 0 L
.02852 0 L
.02878 0 L
.02905 0 L
.02928 0 L
.02954 0 L
.02981 0 L
.03007 0 L
.0302 0 L
.03035 0 L
.0305 0 L
.03064 0 L
.0309 0 L
.03114 0 L
.03141 0 L
.03169 0 L
.03192 0 L
.03217 0 L
.03241 0 L
.03262 0 L
.03287 0 L
.03315 0 L
.0334 0 L
.03364 0 L
Mistroke
.03389 0 L
.03417 0 L
.03442 0 L
.03466 0 L
.03493 0 L
.03509 0 L
.03523 0 L
.0355 0 L
.03563 0 L
.03578 0 L
.03592 0 L
.03607 0 L
.03634 0 L
.03649 0 L
.03662 0 L
.03678 0 L
.03694 0 L
.03708 0 L
.03724 0 L
.03738 0 L
.03751 0 L
.03777 0 L
.03804 0 L
.03829 0 L
.03856 0 L
.03883 0 L
.03907 0 L
.03931 0 L
.03952 0 L
.03978 0 L
.04001 0 L
.04027 0 L
.04054 0 L
.04078 0 L
.04103 0 L
.04131 0 L
.04146 0 L
.0416 0 L
.04188 0 L
.04214 0 L
.04236 0 L
.0426 0 L
.04286 0 L
.04309 0 L
.04332 0 L
.04352 0 L
.04374 0 L
.04398 0 L
.04422 0 L
.04447 0 L
Mistroke
.04472 0 L
.04494 0 L
.04519 0 L
.04534 0 L
.04547 0 L
.04572 0 L
.04598 0 L
.04624 0 L
.04651 0 L
.04677 0 L
.04702 0 L
.04726 0 L
.04748 0 L
.04773 0 L
.04796 0 L
.04822 0 L
.0485 0 L
.04873 0 L
.04899 0 L
.04926 0 L
.04942 0 L
.04956 0 L
.04983 0 L
.05009 0 L
.05031 0 L
.05056 0 L
.05081 0 L
.05105 0 L
.05127 0 L
.05148 0 L
.0517 0 L
.05194 0 L
.05218 0 L
.05243 0 L
.05267 0 L
.05289 0 L
.05315 0 L
.0533 0 L
.05343 0 L
.05368 0 L
.05394 0 L
.05419 0 L
.05434 0 L
.05447 0 L
.05472 0 L
.05498 0 L
.05521 0 L
.05543 0 L
.05567 0 L
.05593 0 L
Mistroke
.05618 0 L
.05633 0 L
.05647 0 L
.05674 0 L
.0569 0 L
.05704 0 L
.05729 0 L
.05756 0 L
.05782 0 L
.05806 0 L
.05828 0 L
.05852 0 L
.05874 0 L
.05895 0 L
.05919 0 L
.05945 0 L
.0597 0 L
.05993 0 L
.06019 0 L
.06043 0 L
.06065 0 L
.06088 0 L
.06114 0 L
.06142 0 L
.06165 0 L
.06191 0 L
.06218 0 L
.06243 0 L
.06257 0 L
.06271 0 L
.06286 0 L
.06301 0 L
.06327 0 L
.06351 0 L
.06377 0 L
.06405 0 L
.06429 0 L
.06454 0 L
.06477 0 L
.06499 0 L
.06524 0 L
.06551 0 L
.06577 0 L
.06601 0 L
.06626 0 L
.06653 0 L
.06679 0 L
.06702 0 L
.0673 0 L
.06745 0 L
Mistroke
.0676 0 L
.06786 0 L
.06801 0 L
.06814 0 L
.06828 0 L
.06843 0 L
.0687 0 L
.06885 0 L
.06899 0 L
.06914 0 L
.06931 0 L
.06945 0 L
.0696 0 L
.06974 0 L
.06988 0 L
.07013 0 L
.0704 0 L
.07065 0 L
.07093 0 L
.07119 0 L
.07143 0 L
.07167 0 L
.07189 0 L
.07214 0 L
.07238 0 L
.07263 0 L
.07291 0 L
.07314 0 L
.0734 0 L
.07367 0 L
.07383 0 L
.07397 0 L
.07424 0 L
.0745 0 L
.07472 0 L
.07496 0 L
.07522 0 L
.07546 0 L
.07568 0 L
.07588 0 L
.07611 0 L
.07634 0 L
.07658 0 L
.07684 0 L
.07708 0 L
.0773 0 L
.07756 0 L
.0777 0 L
.07784 0 L
.07808 0 L
Mistroke
.07834 0 L
.0786 0 L
.07887 0 L
.07914 0 L
.07938 0 L
.07962 0 L
.07984 0 L
.08009 0 L
.08032 0 L
.08058 0 L
.08086 0 L
.08109 0 L
.08135 0 L
.08162 0 L
.08178 0 L
.08192 0 L
.08219 0 L
.08245 0 L
.08267 0 L
.08292 0 L
.08317 0 L
.08341 0 L
.08363 0 L
.08384 0 L
.08406 0 L
.0843 0 L
.08454 0 L
.08479 0 L
.08503 0 L
.08525 0 L
.08551 0 L
.08566 0 L
.08579 0 L
.08604 0 L
.0863 0 L
.08655 0 L
.0867 0 L
.08683 0 L
.08708 0 L
.08734 0 L
.08757 0 L
.08779 0 L
.08803 0 L
.08828 0 L
.08854 0 L
.08869 0 L
.08882 0 L
.0891 0 L
.08925 0 L
.08939 0 L
Mistroke
.08965 0 L
.08992 0 L
.09018 0 L
.09041 0 L
.09064 0 L
.09087 0 L
.0911 0 L
.0913 0 L
.09154 0 L
.09181 0 L
.09205 0 L
.09228 0 L
.09254 0 L
.09279 0 L
.093 0 L
.09324 0 L
.0935 0 L
.09377 0 L
.09401 0 L
.09426 0 L
.09445 0 L
.09462 0 L
.09481 0 L
.09501 0 L
.09518 0 L
.09534 0 L
.09552 0 L
.09571 0 L
.09587 0 L
.09605 0 L
.09623 0 L
.0964 0 L
.09656 0 L
.09671 0 L
.09687 0 L
.09703 0 L
.0972 0 L
.09739 0 L
.09759 0 L
.09777 0 L
.09795 0 L
.0981 0 L
.09828 0 L
.09846 0 L
.09864 0 L
.09884 0 L
.09903 0 L
.0992 0 L
.09939 0 L
.09961 0 L
Mistroke
.09981 0 L
.1 0 L
Mfstroke
.23333 .02397 m
.24145 .0314 L
.2503 .0395 L
.25861 .04712 L
.2666 .05444 L
.2751 .06223 L
.28329 .06973 L
.292 .0777 L
.30038 .08538 L
.30845 .09277 L
.31703 .10063 L
.32529 .1082 L
.33324 .11548 L
.3417 .12323 L
.34984 .13069 L
.3585 .13862 L
.36684 .14626 L
.37486 .15361 L
.38339 .16142 L
.39161 .16895 L
.40034 .17695 L
.40876 .18466 L
.41685 .19207 L
.42546 .19996 L
.43333 .20717 L
s
.56667 .41826 m
.57478 .42485 L
.58363 .43204 L
.59194 .4388 L
.59993 .44529 L
.60844 .45221 L
.61663 .45886 L
.62533 .46594 L
.63371 .47275 L
.64178 .47931 L
.65036 .48628 L
.65863 .493 L
.66657 .49946 L
.67503 .50633 L
.68317 .51295 L
.69183 .51999 L
.70017 .52677 L
.70819 .53328 L
.71673 .54022 L
.72494 .5469 L
.73368 .554 L
.74209 .56084 L
.75019 .56742 L
.7588 .57441 L
.76667 .58081 L
s
.9 .50666 m
.90811 .4797 L
.91696 .45031 L
.92527 .4227 L
.93326 .39615 L
.94177 .36789 L
.94996 .34068 L
.95866 .31177 L
.96705 .28391 L
.97511 .25711 L
.9837 .2286 L
.99196 .20114 L
.99991 .17475 L
s
.99991 .17475 m
1 .17443 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[53]:=",
  ImageSize->{165, 101.812},
  ImageMargins->{{33, 0}, {0, 3}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002U0000IB000`400?l00000o`00003oYOooool0
01cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000@ooooo`?o00003oooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000kooooo1Ol0000=ooooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00004?ooool3o`0000Oooooo000Kooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000000kooooo00Co0000oooooooooooo0000
3_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000003_ooool01Ol0
003ooooooooooooooooo000000Kooooo000Kooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`04ooooo`006oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00kooooo0_l00007ooooo`006oooool01?l0003oooooooooool00007
ooooo`Co00004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo1?l0000>
ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooooooooooooooo000000Oooooo
1?l0000Cooooo`03o`000?oooooooooo00Cooooo000Kooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool04Oooool2o`00013ooooo0_l00009ooooo`03o`000?oooooooooo00oooooo
00Go0000ooooooooooooooooo`00000=ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000001_ooool001cooooo0_l00008oooo
o`Go00004?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo1Ol0000>oooo
o`?o00003oooool3o`0000Sooooo1Ol0000?ooooo`?o00001oooool00:Gooooo002Uooooo`00YOoo
ool000_oooooTol00007ooooo`002oooool00ol0003oooooooooo`0?ooooo`Oo0000POooool000_o
oooo00?o0000ooooooooool05_ooool2o`0007oooooo000;ooooo`03o`000?oooooooooo01Sooooo
0ol00004ooooo`03o`000?oooooooooo07Gooooo000;ooooo`;o00007?ooool2o`0000?ooooo0_l0
001eooooo`002oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0L_ooool000_ooooo00?o0000ooooooooool07_ooool3o`0000;ooooo00?o0000oooo
ooooool0LOooool000_ooooo00?o0000ooooooooool08Oooool4o`0007;ooooo000;ooooo`;o0000
9Oooool00ol0003oooooooooo`1`ooooo`002oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06oooooo000;ooooo`03o`000?oooooooooo02Kooooo0_l0001_ooooo`002oooool00ol0
003oooooooooo`0Wooooo`;o0000K_ooool000_ooooo0_l0000Zooooo`03o`000?oooooooooo06_o
oooo000;ooooo`03o`000?oooooooooo02[ooooo0_l0001[ooooo`002oooool00ol0003ooooooooo
o`0[ooooo`;o0000J_ooool000_ooooo00?o0000ooooooooool0;?ooool2o`0006Wooooo000;oooo
o`;o0000;oooool00ol0003oooooooooo`1Vooooo`001?ooool3o`0000Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`1Uooooo`001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02oooooo0_l0001Vooooo`001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo033ooooo0_l0001Uooooo`001Oooool00ol0003oooooooooo`03ooooo`;o0000<_ooool2
o`0006Cooooo0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`1Qooooo`001?ooool2o`0000Gooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`1Pooooo`001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo
0_l0001Qooooo`002oooool2o`0003Kooooo0_l0001Pooooo`002oooool00ol0003oooooooooo`0f
ooooo`?o0000E_ooool00ol0003oooooooooo`05ooooo`002oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooo000005Gooooo00?o0000ooooooooool01Oooool000_ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooo`00001Cooooo`;o00001oooool000_ooooo0_l0000jooooo`;o0000
Doooool00ol0003oooooooooo`06ooooo`002oooool00ol0003oooooooooo`0jooooo`;o0000D_oo
ool00ol0003oooooooooo`06ooooo`002oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
0000053ooooo0_l00008ooooo`002oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool01oooool000_ooooo0_l0000mooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool01oooool000_ooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool02?ooool000_ooooo0_l00010oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02Oooool000?ooooo1Ol00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`09ooooo`00
1?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`09ooooo`001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0A_ooool2o`0000_ooooo0006ooooo`03o`000?oo
oooooooo00;ooooo0_l00013ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02_oo
ool000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0:ooooo`000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`12ooooo`;o00003?oo
ool000Cooooo0ol00004ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0@Oooool2
o`0000cooooo000;ooooo`;o0000Aoooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
00_ooooo000;ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0?oooool2o`0000go
oooo000;ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0?_ooool2o`0000gooooo
000;ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0??ooool2o`0000kooooo000;
ooooo`;o0000B_ooool00ol0003oooooooooo`0kooooo`;o00003_ooool000_ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0jooooo`;o00003oooool000_ooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0iooooo`;o00003oooool000_ooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooo000000oooooo000;ooooo`;o0000COoo
ool00ol0003oooooooooo`0fooooo`;o00004?ooool000_ooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`0fooooo`;o00004?ooool000_ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0dooooo`03o`000?oooooo0000013ooooo000;ooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool0<oooool00ol0003oooooo`00000@ooooo`002oooool2o`00053ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooo`00000Aooooo`001?ooool3o`0000Cooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0aooooo`03o`000?oooooo0000017ooooo0003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo02oooooo00Co0000oooooooooooo00004Oooool000Oooooo00Go0000oooooooooooooooo
o`00001Cooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo00004Oooool000Gooooo
0_l00004ooooo`;o0000DOooool00ol0003oooooo`00000^ooooo`04o`000?ooooooooooo`0001;o
oooo0007ooooo`05o`000?ooooooooooooooool00000Doooool2o`0002gooooo00Go0000oooooooo
ooooooooo`00000Booooo`000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool0D_ooool2o`0002cooooo00Go0000ooooooooooooooooo`00000Booooo`001?ooool3o`00
00Cooooo00?o0000ooooooooool0Doooool2o`0002[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0@ooooo`002oooool2o`0005Gooooo0_l0000Yooooo`05o`000?oooooooooooooo
ool000004oooool000_ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool000_ooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4Oooool000_ooooo00?o0000ooooooooool0F?ooool2o`0002?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Booooo`002oooool2o`0005[ooooo0_l0000Qooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04_ooool000_ooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool000_o
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool000_ooooo0_l0
001Oooooo`;o00006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo05oooooo0_l0000Gooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05?ooool000_ooooo00?o0000ooooooooool0HOooool2o`0001Cooooo00?o0000oooo
ooooool07Oooool000_ooooo00?o0000ooooooooool0H_ooool2o`00017ooooo0_l0000Pooooo`00
2oooool2o`0006Cooooo0ol0000=ooooo`;o00008_ooool000Gooooo0ol00003ooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooool000002_ooool2o`0002Cooooo0006ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0IOooool<o`0002Kooooo0003ooooo`Go00000oooool2o`00
06Sooooo00?o0000ooooooooool0;Oooool000?ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo02cooooo0004ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0[ooooo`001Oooool2o`0000Cooooo
00?o0000ooooooooool0J_ooool2o`0002_ooooo0006ooooo`03o`000?oooooooooo00;ooooo0_l0
001]ooooo`03o`000?oooooooooo02Sooooo000;ooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09oooool000_ooooo00?o0000ooooooooool0Uoooool000_ooooo00?o0000oooooooo
ool0Uoooool000_ooooo0_l0002Hooooo`002oooool00ol0003oooooooooo`2Gooooo`002oooool0
0ol0003oooooooooo`2Gooooo`00\
\>"],
  ImageRangeCache->{{{110.875, 274.875}, {516.5, 415.688}} -> {-2.52345, \
20.2451, 0.020603, 0.0500044}}]
}, Open  ]],

Cell["\<\
The next plot is a little fancier. The axes have been removed (Axes \
-> None) and the option PlotStyle -> Thickness[0.01] draws the four tangent \
line segments twice as thick. A title has also been added to the plot. The \
text for a title must be placed inside of double quotes. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
NewLines = Table[ Plot[ L[a,x], {x,a-0.3,a+0.3}, 
                        PlotStyle -> Thickness[0.01],
                        DisplayFunction -> Identity ],
                        {a,0,3} ];
Show[ {Plot[f[x],{x,0,3}], NewLines}, 
              DisplayFunction -> $DisplayFunction,
              PlotRange->{{0,3},{0,4.5}},
              Axes -> None, PlotLabel \[Rule] \"Four Tangent Lines\" ]\
\>", \
"Input",
  CellLabel->"In[63]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.333333 0 0.137341 [
[.5 .63053 -56 0 ]
[.5 .63053 56 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .63053 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Four) show
93.000 13.000 moveto
(Tangent) show
141.000 13.000 moveto
(Lines) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 1e-05 L
.01434 1e-05 L
.01579 1e-05 L
.01716 2e-05 L
.01975 3e-05 L
.02225 4e-05 L
.02491 6e-05 L
.0297 .0001 L
.0354 .00016 L
.04057 .00025 L
.04627 .00037 L
.05151 .0005 L
.06335 .00094 L
.07378 .00148 L
.08481 .00224 L
.09476 .00311 L
.10543 .00427 L
.12468 .00702 L
.14698 .0114 L
.16811 .01688 L
.20835 .0314 L
.22912 .04117 L
.25118 .05336 L
.29081 .08007 L
.33303 .11529 L
.37365 .1554 L
.41685 .20386 L
.45845 .25485 L
.49846 .30625 L
.54105 .36135 L
.58205 .41234 L
.62562 .46132 L
.66761 .50029 L
.68684 .51458 L
.70799 .52718 L
.71806 .53192 L
.72886 .53603 L
.73483 .53786 L
.74028 .53924 L
.74576 .54033 L
Mistroke
.75096 .54111 L
.75369 .54141 L
.75503 .54152 L
.75626 .54162 L
.75736 .54169 L
.75856 .54175 L
.75977 .5418 L
.76105 .54183 L
.76177 .54184 L
.76246 .54185 L
.76374 .54185 L
.76512 .54183 L
.76589 .54181 L
.76661 .54178 L
.76781 .54173 L
.76913 .54165 L
.7718 .54144 L
.7743 .54117 L
.7766 .54086 L
.78177 .53996 L
.78633 .53892 L
.79112 .53756 L
.80117 .53386 L
.81189 .52857 L
.83119 .51547 L
.85364 .49412 L
.87481 .46769 L
.91526 .39923 L
.95828 .29922 L
.9997 .17541 L
1 .17443 L
Mfstroke
.01 w
3e-05 0 m
.00024 0 L
.0005 0 L
.00077 0 L
.00103 0 L
.00127 0 L
.00152 0 L
.00179 0 L
.00205 0 L
.00228 0 L
.00256 0 L
.00271 0 L
.00286 0 L
.00312 0 L
.00325 0 L
.0034 0 L
.00354 0 L
.00369 0 L
.00396 0 L
.00411 0 L
.00425 0 L
.0044 0 L
.00457 0 L
.00471 0 L
.00486 0 L
.00501 0 L
.00514 0 L
.00539 0 L
.00566 0 L
.00591 0 L
.00619 0 L
.00645 0 L
.00669 0 L
.00693 0 L
.00715 0 L
.0074 0 L
.00764 0 L
.0079 0 L
.00817 0 L
.0084 0 L
.00866 0 L
.00894 0 L
.00909 0 L
.00923 0 L
.00951 0 L
.00976 0 L
.00999 0 L
.01023 0 L
.01048 0 L
.01072 0 L
Mistroke
.01094 0 L
.01115 0 L
.01137 0 L
.01161 0 L
.01185 0 L
.0121 0 L
.01234 0 L
.01256 0 L
.01282 0 L
.01297 0 L
.0131 0 L
.01335 0 L
.01361 0 L
.01386 0 L
.01414 0 L
.0144 0 L
.01465 0 L
.01489 0 L
.0151 0 L
.01536 0 L
.01559 0 L
.01585 0 L
.01613 0 L
.01636 0 L
.01662 0 L
.01689 0 L
.01705 0 L
.01719 0 L
.01746 0 L
.01772 0 L
.01794 0 L
.01819 0 L
.01844 0 L
.01868 0 L
.0189 0 L
.01911 0 L
.01934 0 L
.01957 0 L
.01981 0 L
.02006 0 L
.0203 0 L
.02052 0 L
.02078 0 L
.02093 0 L
.02106 0 L
.02131 0 L
.02157 0 L
.02182 0 L
.02197 0 L
.0221 0 L
Mistroke
.02235 0 L
.02261 0 L
.02284 0 L
.02306 0 L
.0233 0 L
.02356 0 L
.02382 0 L
.02396 0 L
.0241 0 L
.02437 0 L
.02453 0 L
.02467 0 L
.02492 0 L
.02519 0 L
.02545 0 L
.02569 0 L
.02591 0 L
.02615 0 L
.02637 0 L
.02658 0 L
.02682 0 L
.02708 0 L
.02733 0 L
.02756 0 L
.02782 0 L
.02806 0 L
.02828 0 L
.02852 0 L
.02878 0 L
.02905 0 L
.02928 0 L
.02954 0 L
.02981 0 L
.03007 0 L
.0302 0 L
.03035 0 L
.0305 0 L
.03064 0 L
.0309 0 L
.03114 0 L
.03141 0 L
.03169 0 L
.03192 0 L
.03217 0 L
.03241 0 L
.03262 0 L
.03287 0 L
.03315 0 L
.0334 0 L
.03364 0 L
Mistroke
.03389 0 L
.03417 0 L
.03442 0 L
.03466 0 L
.03493 0 L
.03509 0 L
.03523 0 L
.0355 0 L
.03563 0 L
.03578 0 L
.03592 0 L
.03607 0 L
.03634 0 L
.03649 0 L
.03662 0 L
.03678 0 L
.03694 0 L
.03708 0 L
.03724 0 L
.03738 0 L
.03751 0 L
.03777 0 L
.03804 0 L
.03829 0 L
.03856 0 L
.03883 0 L
.03907 0 L
.03931 0 L
.03952 0 L
.03978 0 L
.04001 0 L
.04027 0 L
.04054 0 L
.04078 0 L
.04103 0 L
.04131 0 L
.04146 0 L
.0416 0 L
.04188 0 L
.04214 0 L
.04236 0 L
.0426 0 L
.04286 0 L
.04309 0 L
.04332 0 L
.04352 0 L
.04374 0 L
.04398 0 L
.04422 0 L
.04447 0 L
Mistroke
.04472 0 L
.04494 0 L
.04519 0 L
.04534 0 L
.04547 0 L
.04572 0 L
.04598 0 L
.04624 0 L
.04651 0 L
.04677 0 L
.04702 0 L
.04726 0 L
.04748 0 L
.04773 0 L
.04796 0 L
.04822 0 L
.0485 0 L
.04873 0 L
.04899 0 L
.04926 0 L
.04942 0 L
.04956 0 L
.04983 0 L
.05009 0 L
.05031 0 L
.05056 0 L
.05081 0 L
.05105 0 L
.05127 0 L
.05148 0 L
.0517 0 L
.05194 0 L
.05218 0 L
.05243 0 L
.05267 0 L
.05289 0 L
.05315 0 L
.0533 0 L
.05343 0 L
.05368 0 L
.05394 0 L
.05419 0 L
.05434 0 L
.05447 0 L
.05472 0 L
.05498 0 L
.05521 0 L
.05543 0 L
.05567 0 L
.05593 0 L
Mistroke
.05618 0 L
.05633 0 L
.05647 0 L
.05674 0 L
.0569 0 L
.05704 0 L
.05729 0 L
.05756 0 L
.05782 0 L
.05806 0 L
.05828 0 L
.05852 0 L
.05874 0 L
.05895 0 L
.05919 0 L
.05945 0 L
.0597 0 L
.05993 0 L
.06019 0 L
.06043 0 L
.06065 0 L
.06088 0 L
.06114 0 L
.06142 0 L
.06165 0 L
.06191 0 L
.06218 0 L
.06243 0 L
.06257 0 L
.06271 0 L
.06286 0 L
.06301 0 L
.06327 0 L
.06351 0 L
.06377 0 L
.06405 0 L
.06429 0 L
.06454 0 L
.06477 0 L
.06499 0 L
.06524 0 L
.06551 0 L
.06577 0 L
.06601 0 L
.06626 0 L
.06653 0 L
.06679 0 L
.06702 0 L
.0673 0 L
.06745 0 L
Mistroke
.0676 0 L
.06786 0 L
.06801 0 L
.06814 0 L
.06828 0 L
.06843 0 L
.0687 0 L
.06885 0 L
.06899 0 L
.06914 0 L
.06931 0 L
.06945 0 L
.0696 0 L
.06974 0 L
.06988 0 L
.07013 0 L
.0704 0 L
.07065 0 L
.07093 0 L
.07119 0 L
.07143 0 L
.07167 0 L
.07189 0 L
.07214 0 L
.07238 0 L
.07263 0 L
.07291 0 L
.07314 0 L
.0734 0 L
.07367 0 L
.07383 0 L
.07397 0 L
.07424 0 L
.0745 0 L
.07472 0 L
.07496 0 L
.07522 0 L
.07546 0 L
.07568 0 L
.07588 0 L
.07611 0 L
.07634 0 L
.07658 0 L
.07684 0 L
.07708 0 L
.0773 0 L
.07756 0 L
.0777 0 L
.07784 0 L
.07808 0 L
Mistroke
.07834 0 L
.0786 0 L
.07887 0 L
.07914 0 L
.07938 0 L
.07962 0 L
.07984 0 L
.08009 0 L
.08032 0 L
.08058 0 L
.08086 0 L
.08109 0 L
.08135 0 L
.08162 0 L
.08178 0 L
.08192 0 L
.08219 0 L
.08245 0 L
.08267 0 L
.08292 0 L
.08317 0 L
.08341 0 L
.08363 0 L
.08384 0 L
.08406 0 L
.0843 0 L
.08454 0 L
.08479 0 L
.08503 0 L
.08525 0 L
.08551 0 L
.08566 0 L
.08579 0 L
.08604 0 L
.0863 0 L
.08655 0 L
.0867 0 L
.08683 0 L
.08708 0 L
.08734 0 L
.08757 0 L
.08779 0 L
.08803 0 L
.08828 0 L
.08854 0 L
.08869 0 L
.08882 0 L
.0891 0 L
.08925 0 L
.08939 0 L
Mistroke
.08965 0 L
.08992 0 L
.09018 0 L
.09041 0 L
.09064 0 L
.09087 0 L
.0911 0 L
.0913 0 L
.09154 0 L
.09181 0 L
.09205 0 L
.09228 0 L
.09254 0 L
.09279 0 L
.093 0 L
.09324 0 L
.0935 0 L
.09377 0 L
.09401 0 L
.09426 0 L
.09445 0 L
.09462 0 L
.09481 0 L
.09501 0 L
.09518 0 L
.09534 0 L
.09552 0 L
.09571 0 L
.09587 0 L
.09605 0 L
.09623 0 L
.0964 0 L
.09656 0 L
.09671 0 L
.09687 0 L
.09703 0 L
.0972 0 L
.09739 0 L
.09759 0 L
.09777 0 L
.09795 0 L
.0981 0 L
.09828 0 L
.09846 0 L
.09864 0 L
.09884 0 L
.09903 0 L
.0992 0 L
.09939 0 L
.09961 0 L
Mistroke
.09981 0 L
.1 0 L
Mfstroke
.23333 .02397 m
.24145 .0314 L
.2503 .0395 L
.25861 .04712 L
.2666 .05444 L
.2751 .06223 L
.28329 .06973 L
.292 .0777 L
.30038 .08538 L
.30845 .09277 L
.31703 .10063 L
.32529 .1082 L
.33324 .11548 L
.3417 .12323 L
.34984 .13069 L
.3585 .13862 L
.36684 .14626 L
.37486 .15361 L
.38339 .16142 L
.39161 .16895 L
.40034 .17695 L
.40876 .18466 L
.41685 .19207 L
.42546 .19996 L
.43333 .20717 L
s
.56667 .41826 m
.57478 .42485 L
.58363 .43204 L
.59194 .4388 L
.59993 .44529 L
.60844 .45221 L
.61663 .45886 L
.62533 .46594 L
.63371 .47275 L
.64178 .47931 L
.65036 .48628 L
.65863 .493 L
.66657 .49946 L
.67503 .50633 L
.68317 .51295 L
.69183 .51999 L
.70017 .52677 L
.70819 .53328 L
.71673 .54022 L
.72494 .5469 L
.73368 .554 L
.74209 .56084 L
.75019 .56742 L
.7588 .57441 L
.76667 .58081 L
s
.9 .50666 m
.90811 .4797 L
.91696 .45031 L
.92527 .4227 L
.93326 .39615 L
.94177 .36789 L
.94996 .34068 L
.95866 .31177 L
.96705 .28391 L
.97511 .25711 L
.9837 .2286 L
.99196 .20114 L
.99991 .17475 L
s
.99991 .17475 m
1 .17443 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[63]:=",
  ImageSize->{183.5, 113.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003U0000SB000`400?l00000o`00003o3_oooolE
o`000<;ooooo000Qooooo`Wo0000^oooool002[ooooo1Ol0002fooooo`00;oooool3o`000;?ooooo
000booooo`?o0000/?ooool003Gooooo0ol00005ooooo`03o`000?oooooooooo0:Gooooo000hoooo
o`;o00001?ooool00ol0003oooooooooo`2Tooooo`00>_ooool2o`0000?ooooo00?o0000oooooooo
ool0Xoooool003cooooo0_l00002ooooo`;o0000Xoooool003kooooo00Go0000oooooooooooooooo
o`00002Rooooo`00?oooool01?l0003oooooooooool0002Rooooo`00@?ooool2o`000003ooooool0
003o00000:3ooooo0012ooooo`04o`000?ooooooooooo`0009oooooo0013ooooo`;o000000?ooooo
o`000?ooool0WOooool004Gooooo0ol0002Mooooo`00Aoooool2o`0009cooooo0018ooooo`;o0000
Voooool004[ooooo0_l0002Iooooo`00Boooool2o`0009Sooooo001<ooooo`03o`000?oooooooooo
09Kooooo001=ooooo`;o0000U_ooool004kooooo0_l0002Eooooo`00Coooool00ol0003ooooooooo
o`2Cooooo`00D?ooool2o`0009?ooooo001Booooo`03o`000?oooooooooo093ooooo001Cooooo`03
o`000?oooooooooo08oooooo001Dooooo`03o`000?oooooooooo08kooooo001Eooooo`03o`000?oo
oooooooo08gooooo001Fooooo`03o`000?oooooooooo08cooooo001Gooooo`03o`000?oooooooooo
08_ooooo001Hooooo`03o`000?oooooooooo08[ooooo001Iooooo`03o`000?oooooooooo08Wooooo
001Iooooo`;o0000R_ooool005[ooooo0_l00029ooooo`00Foooool3o`0008Oooooo001Looooo`03
o`000?oooooo000007Kooooo00?o0000ooooooooool03Oooool005gooooo00?o0000ooooool00000
MOooool00ol0003oooooooooo`0=ooooo`00GOooool01?l0003oooooooooool0001dooooo`03o`00
0?oooooooooo00gooooo001Nooooo`04o`000?ooooooooooo`0007;ooooo00?o0000ooooooooool0
3_ooool005oooooo00Co0000oooooooooooo0000LOooool00ol0003oooooooooo`0>ooooo`00H?oo
ool01?l0003oooooooooool0001`ooooo`03o`000?oooooooooo00kooooo001Qooooo`04o`000?oo
ooooooooo`0006kooooo0_l0000@ooooo`00HOooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo00oooooo001Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool03oooool0
06?ooooo00?o0000ooooooooool0K?ooool2o`00017ooooo001Tooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool04?ooool006Gooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`0@ooooo`00IOooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo017ooooo001V
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool04Oooool006Oooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`0Aooooo`00J?ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo01;ooooo001Yooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
4_ooool006Wooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Booooo`00J_ooool0
0ol0003oooooooooo`1Rooooo`;o00005?ooool006_ooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`0Cooooo`00K?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01?o
oooo001]ooooo`03o`000?oooooooooo05kooooo0_l0000Eooooo`00KOooool00ol0003ooooooooo
o`1Nooooo`;o00005Oooool006kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0D
ooooo`00Koooool00ol0003oooooooooo`1Kooooo`;o00005_ooool0073ooooo00?o0000oooooooo
ool0F_ooool2o`0001Kooooo001aooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
5Oooool0077ooooo00?o0000ooooooooool0F?ooool2o`0001Oooooo001booooo`03o`000?oooooo
oooo05Oooooo0_l0000Gooooo`00Loooool00ol0003oooooooooo`1Eooooo`;o00006?ooool007Co
oooo00?o0000ooooooooool0E?ooool2o`0001Sooooo001eooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooool000006?ooool007Kooooo00?o0000ooooooooool0DOooool2o`0001Wooooo001f
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooool000006Oooool007Oooooo00?o0000oooo
ooooool0Coooool00ol0003oooooo`00000Iooooo`00N?ooool00ol0003oooooooooo`1=ooooo`04
o`000?ooooooooooo`0001Wooooo001iooooo`03o`000?oooooooooo04cooooo00?o0000ooooool0
00006_ooool007[ooooo00?o0000ooooooooool0Boooool00ol0003oooooo`00000Jooooo`00N_oo
ool00ol0003oooooooooo`1:ooooo`04o`000?ooooooooooo`0001[ooooo001kooooo`03o`000?oo
oooooooo04Wooooo00Co0000oooooooooooo00006_ooool007cooooo00?o0000ooooooooool0Aooo
ool01?l0003oooooooooool0000Kooooo`00OOooool00ol0003oooooooooo`16ooooo`04o`000?oo
ooooooooo`0001_ooooo001nooooo`03o`000?oooooooooo04Cooooo00Go0000oooooooooooooooo
o`00000Kooooo`00O_ooool00ol0003oooooooooo`14ooooo`04o`000?ooooooooooo`0001cooooo
001oooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`00000Looooo`00P?oo
ool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool000007?ooool0087ooooo00?o
0000ooooooooool0?oooool01Ol0003ooooooooooooooooo000001gooooo0022ooooo`03o`000?oo
oooooooo03kooooo00Go0000ooooooooooooooooo`00000Mooooo`00Ooooool01?l0003ooooooooo
ool0000oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool0083ooooo00Co
0000oooooooooooo0000?Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo
0021ooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Looooo`00P_ooool2o`000003ooooool0003ooooo03Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Looooo`00Q?ooool00ol0003oooooo`00000iooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool07?ooool008Gooooo00?o0000ooooool00000=oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo0026ooooo`03o`000?oooooo000003Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`00Qoooool3o`0003Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`00ROooool2o`0003;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`00R_ooool2o`00037ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`00Roooool2o`0002oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Nooooo`00S?ooool2o`0002kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Nooooo`00S_ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07oooool008oooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo002@ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`00TOooool2o`00
02Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`00T_ooool2o`0002Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`00Toooool2o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`00UOooool2o`0001oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`00U_ooool3o`0001cooooo00?o0000
ooooooooool0;Oooool009Sooooo0_l0000Iooooo`;o0000<?ooool009Wooooo0_l0000Fooooo`;o
0000<_ooool009[ooooo0ol0000Booooo`;o0000=?ooool009_ooooo00Co0000ooooool0003o0000
3_ooool2o`0003Kooooo002Looooo`03o`000?oooooooooo00Co00001oooool3o`0003Sooooo002M
ooooo`03o`000?oooooooooo00?ooooo1ol0000kooooo`00W_ooool2o`0004Gooooo002Pooooo`03
o`000?oooooooooo04;ooooo002Qooooo`03o`000?oooooooooo047ooooo002Rooooo`;o0000@Ooo
ool00:Cooooo00?o0000ooooooooool0?_ooool00:Gooooo00?o0000ooooooooool0?Oooool00:Ko
oooo00?o0000ooooooooool0??ooool00:Oooooo00?o0000ooooooooool0>oooool00>Gooooo003U
ooooo`00iOooool00>Gooooo003Uooooo`00iOooool00>Gooooo003Uooooo`00iOooool00>Gooooo
001^ooooo`05ob4Q8Ol0003o0000odA4A?oMgMd0L_ooool0077ooooo00?oMgMgoc8b<_ooool0LOoo
ool007;ooooo00?o0000ooooooooool0L?ooool002oooooo0ol000000ol@413oooooooooo`02oooo
o`06onk^k_mEEEGo0000o`000?mEEEGok^k^0oooool01OnHV9So0000o`000?mgMgOo000000;o410@
1Ol00009ooooo`05oa0@4?l0003o0000o`000?l@41000oooool01_nHV9So0000o`000?mgMgOo410@
o`0000;ooooo00Co410@o`000?l0003ooooo0_l000002?l@413oooooonk^k_mEEEGo0000oa0@4?o<
c<co00000_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Co410@o`000?l0003ooooo
0_l000001?l@413ooooooooooonHV9P2o`000003odA4A?nj^[[ooooo00Cooooo00?o410@o`000?l0
00001?l00003ooooo`Go00000_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^
oeEEE@;o000000KoA4A4okZj^_oooooooooooa0@4?lb<S82o`000003oa0@4?nYZJWooooo02gooooo
000`ooooo`03o`000?oooooooooo00Cooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`05
o`000?nYZJWoooooohN7Qol000000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00?ooooo00Go0000olc<c?o^k^koQhN7o`000004ooooo`05o`000?ooooooooooooooool000000_oo
ool01_mEEEGoMgMgooooooo^k^koEEEEo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103
ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Oooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_l0003oZJVYoooo
oooooooo^[Zjo`0002kooooo000`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03o`000?oooooooooo00?ooooo00Go410@ohN7Qoooooook^k^o`000004ooooo`05o`000?oooooo
ooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000;ooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool01_ooool01Onj^[[oQhN7ofIVI_mVIVKo410@02kooooo
000`ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00?o
oooo00?o^[Zjoa0@4?l000000_l00004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0
003oooooooooooooooook^k^o`0000;ooooo1_l00003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo1_l00002ooooo`06oc8b<_lQ8B7oMgMgogMg
Mon7QhOok^k^;_ooool0033ooooo0ol00004ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oc8b<_oMgMd03?ooool00ol0003ooooo
ooooo`06ooooo`03olc<c?l0003ooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06
oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo
00Go0000ohN7QoooooooZJVYo`000003ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mE
EEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00Ko0000okZj^_ooooook^k^ogMgMol0000^ooooo`00
<?ooool01Ol0003ooooooa0@4?oooooo410@00;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2
ooooo`04oa0@4?l0003oooooooooo`;o00000_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Oooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo<S8b00;o000000OoV9RHoooo
oooooooooooooa0@4?l0003oMgMg00;o000000goV9RHooooooooooook^k^oeEEEOl0003o8B4QojVY
ZOl0003o410@ooooooo^k^koEEEE00;o000000OoA4A4onk^k_oooooooooooa0@4?l0003oMgMg00;o
000000?oV9RHooooool@41001Ol00008ooooo`03o`000?oooooooooo00Gooooo00?o410@o`000?l0
00001?ooool00ol@413o0000ogMgM`02o`000005oiRHV?ooooooooooonk^k_mEEED00_l000001_m4
A4Cok^k^ooooooooooooZJVYob4Q8@;o000000?o<S8bo`000?ooool0;Oooool0033ooooo00Go0000
ooooooooooooooooo`00000Oooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo053ooooo000_ooooo`Ko00007ooo
ool7o`0002_ooooo00?o0000ooooooooool01oooool00ol@413o0000o`000002o`0000Oooooo00?o
0000ooooooooool0A_ooool009cooooo00?o410@ooooooooool0A_ooool00>Gooooo003Uooooo`00
\
\>"],
  ImageRangeCache->{{{77.875, 260.375}, {285.125, 172.875}} -> {-1.69121, \
7.91692, 0.0188689, 0.0457958}}]
}, Open  ]],

Cell[TextData[StyleBox["Find the length of the curve",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "The integral for the length of a curve defined by ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ") over the interval ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = ",
  StyleBox["a",
    FontSlant->"Italic"],
  " to ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = ",
  StyleBox["b",
    FontSlant->"Italic"],
  " is "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_a\%b\(\@\( 
              1 + \((f' \((x)\))\)\^2\)\) \[DifferentialD]x\)],
  TextAlignment->Center,
  TextJustification->0]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Arc length integrals are notoriously difficult to evaluate exactly, \
and this one is no exception. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["ArcLength = Integrate[Sqrt[1 + f'[x]^2], {x,0,3}]", "Input",
  CellLabel->"In[65]:=",
  FormatType->InputForm],

Cell[BoxData[
    \($Aborted\)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell[TextData[{
  "As good as ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is with integration it is unable to find an antiderivative Here is a 6 \
digit approximation."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["ArcLength = NIntegrate[Sqrt[1 + f'[x]^2], {x,0,3}]", "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(7.658967484356395`\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell[TextData[{
  "Note that the numerical integration function is named ",
  StyleBox["NIntegrate",
    FontWeight->"Bold"],
  "."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Let's see how this compares to the sum of the lengths of the three \
secant line segments determined by the four  points (k,f(k)), k = 0, 1, 2, 3. \
The kth segment is the hypotenuse of a right triangle with base 1 and side \
length  \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["| f(k+1) - f(k) | , k = 0, 1, 2. ", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Add the lengths using the Sum function, then evaluate in floating \
point form. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
SecantApproximation = Sum[ Sqrt[1 + (f[k+1]-f[k])^2], {k,0,2}];
N[%]\
\>", "Input",
  CellLabel->"In[68]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(6.845785869198114`\)], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell["\<\
Now approximate the arc length with the sum of the lengths of three \
tangent line segments. The kth segment  will be the tangent line at the point \
(0.5+k,f(0.5+k)) stretching over a unit interval on the x axis. Right \
triangles  with base 1 can still be used, but the side of the triangle has \
length (plus or minus) f'(0.5+k). You may  recognize the following addition \
formula as a midpoint approximation to the integral. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
TangentLineApproximation = Sum[ Sqrt[1 + f'[0.5+k]^2], {k,0,2}];
N[%]\
\>", "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(6.775770644289187`\)], "Output",
  CellLabel->"Out[73]="]
}, Open  ]],

Cell["\<\
Both approximations are too small, but they are fairly close to one \
another. Let's try to see why. 
The following picture shows the three tangent line segments used for \
TangentLineApprox. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
TanLines = Table[ Plot[ L[0.5+k,x], {x,k,k+1}, 
                        PlotStyle -> Thickness[0.01],
                        DisplayFunction -> Identity ],
                        {k,0,3} ];
Show[ {Plot[f[x],{x,0,3}], TanLines}, 
              DisplayFunction -> $DisplayFunction,
              PlotRange->{{-0,3},{-0.5,4.5}},
              Axes -> None, PlotLabel \[Rule] \"Tangent Lines\" ]\
\>", \
"Input",
  CellLabel->"In[92]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.333333 0.0618034 0.123607 [
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tangent) show
111.000 13.000 moveto
(Lines) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
0 .0618 m
.00123 .0618 L
.00236 .0618 L
.00365 .0618 L
.00488 .0618 L
.00601 .0618 L
.00706 .0618 L
.00821 .06181 L
.00942 .06181 L
.01065 .06181 L
.01196 .06181 L
.01434 .06181 L
.01579 .06182 L
.01716 .06182 L
.01975 .06183 L
.02225 .06184 L
.02491 .06185 L
.0297 .06189 L
.0354 .06195 L
.04057 .06203 L
.04627 .06213 L
.05151 .06226 L
.06335 .06265 L
.07378 .06313 L
.08481 .06382 L
.09476 .06461 L
.10543 .06565 L
.12468 .06812 L
.14698 .07206 L
.16811 .077 L
.20835 .09006 L
.22912 .09886 L
.25118 .10982 L
.29081 .13386 L
.33303 .16556 L
.37365 .20167 L
.41685 .24528 L
.45845 .29117 L
.49846 .33743 L
.54105 .38702 L
.58205 .43291 L
.62562 .47699 L
.66761 .51207 L
.68684 .52492 L
.70799 .53626 L
.71806 .54053 L
.72886 .54423 L
.73483 .54588 L
.74028 .54712 L
.74576 .5481 L
Mistroke
.75096 .5488 L
.75369 .54907 L
.75503 .54917 L
.75626 .54926 L
.75736 .54932 L
.75856 .54938 L
.75977 .54942 L
.76105 .54945 L
.76177 .54946 L
.76246 .54947 L
.76374 .54947 L
.76512 .54945 L
.76589 .54943 L
.76661 .54941 L
.76781 .54936 L
.76913 .54929 L
.7718 .5491 L
.7743 .54886 L
.7766 .54858 L
.78177 .54777 L
.78633 .54683 L
.79112 .54561 L
.80117 .54227 L
.81189 .53752 L
.83119 .52573 L
.85364 .50651 L
.87481 .48272 L
.91526 .42111 L
.95828 .3311 L
.9997 .21968 L
1 .21879 L
Mfstroke
.01 w
0 .03343 m
.01352 .03693 L
.02827 .04075 L
.04212 .04434 L
.05544 .0478 L
.06962 .05147 L
.08327 .05501 L
.09777 .05877 L
.11175 .06239 L
.12519 .06587 L
.13949 .06958 L
.15327 .07315 L
.16651 .07658 L
.18061 .08023 L
.19418 .08375 L
.20861 .08749 L
.22251 .09109 L
.23587 .09455 L
.2501 .09824 L
.2638 .10179 L
.27835 .10556 L
.29237 .10919 L
.30587 .11269 L
.32022 .11641 L
.33333 .11981 L
s
.33333 .14444 m
.34686 .16024 L
.3616 .17748 L
.37545 .19366 L
.38877 .20923 L
.40295 .2258 L
.4166 .24175 L
.4311 .2587 L
.44508 .27504 L
.45852 .29075 L
.47283 .30747 L
.4866 .32356 L
.49984 .33904 L
.51394 .35552 L
.52751 .37138 L
.54194 .38824 L
.55584 .40448 L
.56921 .4201 L
.58343 .43673 L
.59713 .45274 L
.61168 .46975 L
.62571 .48613 L
.6392 .5019 L
.65355 .51868 L
.66667 .534 L
s
.70767 .61803 m
.70879 .6172 L
.72211 .60725 L
.73628 .59666 L
.74993 .58646 L
.76444 .57562 L
.77841 .56518 L
.79186 .55514 L
.80616 .54445 L
.81993 .53416 L
.83318 .52427 L
.84728 .51373 L
.86085 .50359 L
.87528 .49281 L
.88917 .48243 L
.90254 .47244 L
.91677 .46181 L
.93046 .45158 L
.94502 .44071 L
.95904 .43023 L
.97253 .42015 L
.98688 .40943 L
1 .39963 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[92]:=",
  ImageSize->{186.75, 115.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Y0000T2000`400?l00000o`00003ojOooool0
0>Wooooo003Yooooo`00jOooool00>Wooooo003Yooooo`00jOooool000kooooo0ol0003Hooooo`00
3_ooool6o`000=Gooooo000@ooooo`Wo0000d?ooool001?ooooo2Ol0003=ooooo`006?ooool:o`00
0<Oooooo000Kooooo`[o0000a?ooool000kooooo6_l00031ooooo`009?ooool9o`000;cooooo000W
ooooo`Wo0000^Oooool002cooooo1ol0002fooooo`00;oooool9o`000;7ooooo000booooo`Wo0000
[_ooool003Oooooo1ol0002[ooooo`00>_ooool:o`000:Gooooo000mooooo`[o0000X_ooool0043o
oooo00?o0000ooooooooool01ol0002Oooooo`00@Oooool2o`0000?ooooo2Ol0002Jooooo`00@ooo
ool00ol0003oooooooooo`03ooooo`Wo0000Uoooool004Cooooo0_l00008ooooo`Go0000U_ooool0
04Kooooo0_l00009ooooo`;o0000U_ooool004Sooooo00?o0000ooooooooool0W_ooool004Wooooo
0_l0002Nooooo`00Boooool00ol0003oooooooooo`2Kooooo`00C?ooool2o`0000?ooooo0_l0002F
ooooo`00C_ooool00ol0003oooooooooo`03o`0009Gooooo001?ooooo`;o000000Coooooo`000?l0
003o0000U?ooool0057ooooo00?o0000ooooool000000_l0002Cooooo`00D_ooool5o`0009;ooooo
001Dooooo`Co0000TOooool005Gooooo1?l0002@ooooo`00E_ooool3o`00093ooooo001Gooooo`?o
0000Soooool005Sooooo0_l0002?ooooo`00F?ooool3o`0008kooooo001Iooooo`?o0000SOooool0
05[ooooo0ol0002<ooooo`00Foooool3o`0008_ooooo001Looooo`?o0000R_ooool005gooooo0ol0
001iooooo`03o`000?oooooooooo00gooooo001Nooooo`?o0000N?ooool00ol0003oooooooooo`0=
ooooo`00Goooool3o`0007Kooooo00?o0000ooooooooool03_ooool0063ooooo0ol0001eooooo`03
o`000?oooooooooo00kooooo001Qooooo`?o0000M?ooool00ol0003oooooooooo`0>ooooo`00H_oo
ool2o`0007?ooooo00?o0000ooooooooool03oooool006;ooooo0ol0001booooo`03o`000?oooooo
oooo00oooooo001Sooooo`?o0000LOooool00ol0003oooooooooo`0?ooooo`00I?ooool3o`0006oo
oooo00?o0000ooooooooool04?ooool006Gooooo0ol0001^ooooo`03o`000?oooooooooo013ooooo
001Vooooo`?o0000KOooool00ol0003oooooooooo`0@ooooo`00Ioooool3o`0006_ooooo00?o0000
ooooooooool04Oooool006Sooooo0_l0001[ooooo`03o`000?oooooooooo017ooooo001Xooooo`?o
0000J_ooool00ol0003oooooooooo`0Aooooo`00JOooool3o`0006Sooooo00?o0000ooooooooool0
4_ooool006[ooooo0_l0001Xooooo`03o`000?oooooooooo01;ooooo001Zooooo`?o0000Ioooool0
0ol0003oooooooooo`0Booooo`00Joooool3o`0006Gooooo00?o0000ooooooooool04oooool006co
oooo0ol0001Tooooo`03o`000?oooooooooo01?ooooo001]ooooo`?o0000Hoooool00ol0003ooooo
ooooo`0Cooooo`00K_ooool3o`00067ooooo00?o0000ooooooooool05?ooool006oooooo0ol0001P
ooooo`03o`000?oooooooooo01Cooooo001`ooooo`?o0000Goooool00ol0003oooooooooo`0Doooo
o`00LOooool3o`0005gooooo00?o0000ooooooooool05Oooool007;ooooo0ol0001Looooo`03o`00
0?oooooooooo01Gooooo001cooooo`;o0000Foooool00ol0003oooooooooo`0Fooooo`00Loooool3
o`0005[ooooo00?o0000ooooooooool05_ooool007Cooooo0ol0001Hooooo`03o`000?oooooooooo
01Oooooo001eooooo`?o0000Eoooool00ol0003oooooooooo`0Gooooo`00M_ooool2o`0005Kooooo
00?o0000ooooooooool06?ooool007Kooooo0ol0001Eooooo`03o`000?oooooooooo01Sooooo001g
ooooo`?o0000Doooool00ol0003oooooooooo`0Iooooo`00N?ooool3o`0005;ooooo00?o0000oooo
ooooool06Oooool007Wooooo0ol0001@ooooo`03o`000?oooooooooo01[ooooo001jooooo`?o0000
Coooool00ol0003oooooooooo`0Jooooo`00Noooool2o`0004kooooo00?o0000ooooooooool06ooo
ool007_ooooo0ol0001=ooooo`03o`000?oooooooooo01_ooooo001looooo`?o0000Boooool00ol0
003oooooooooo`0;ooooo`;o00003oooool007gooooo0ol0001:ooooo`03o`000?oooooooooo00[o
oooo0ol0000?ooooo`00O_ooool3o`0004Sooooo00?o0000ooooooooool02Oooool4o`00013ooooo
001oooooo`?o0000Aoooool00ol0003oooooooooo`08ooooo`Co00004Oooool0083ooooo0ol00015
ooooo`03o`000?oooooooooo00Oooooo1?l0000Cooooo`00POooool3o`0004Cooooo00?o0000oooo
ooooool01_ooool4o`0001Cooooo0022ooooo`?o0000@_ooool00ol0003oooooooooo`05ooooo`Co
00005_ooool008?ooooo0ol00010ooooo`03o`000?oooooooooo00Gooooo1?l0000Gooooo`00Q?oo
ool3o`0003oooooo00?o0000ooooooooool00oooool4o`0001Wooooo0024ooooo`Co0000?Oooool0
0ol0003oooooooooo`03ooooo`Co00006_ooool008Gooooo1?l0000kooooo`03o`000?oooooooooo
00;ooooo1?l0000Looooo`00Q_ooool2o`000003ooooool0003ooooo03Wooooo00Co0000oooooooo
oooooooo1?l0000Mooooo`00Q_ooool3o`000003ooooool0003ooooo03Oooooo00Co0000oooooooo
oooooooo0ol0000Oooooo`00Qoooool3o`000003ooooool0003ooooo03Gooooo00Co0000oooooooo
oooooooo0ol0000Pooooo`00R?ooool3o`000003ooooool0003ooooo03Cooooo00?o0000ooooool0
00000ol0000Qooooo`00ROooool3o`000003ooooool0003o000003;ooooo00?o0000ooooool00000
0ol0000Rooooo`00R_ooool3o`0000;ooooo00?o0000ooooooooool0;_ooool5o`0002Cooooo002;
ooooo`?o00000_ooool00ol0003oooooooooo`0]ooooo`Co00009Oooool008cooooo0ol00002oooo
o`;o0000;?ooool3o`0002Oooooo002=ooooo`?o00000oooool00ol0003oooooooooo`0Xooooo`?o
0000:?ooool008kooooo0ol00003ooooo`03o`000?oooooooooo02Kooooo0ol0000Yooooo`00Sooo
ool2o`0000Cooooo00?o0000ooooooooool08oooool4o`0002[ooooo002?ooooo`?o00001?ooool2
o`0002;ooooo1?l0000[ooooo`00T?ooool3o`0000Gooooo00?o0000ooooooooool07Oooool4o`00
02gooooo002Aooooo`?o00001Oooool00ol0003oooooooooo`0Kooooo`Co0000;_ooool009;ooooo
0ol00005ooooo`;o00006_ooool3o`00033ooooo002Cooooo`?o00001_ooool2o`0001Oooooo0ol0
000aooooo`00U?ooool3o`0000Oooooo0_l0000Cooooo`Co0000<_ooool009Gooooo0_l00009oooo
o`;o00004?ooool4o`0003?ooooo002Rooooo`?o00002Oooool6o`0003Gooooo002Uooooo`Wo0000
00?oooooo`000?l000000_l0000fooooo`00[Oooool4o`0003Sooooo002/ooooo`Co0000>Oooool0
0:[ooooo1?l0000kooooo`00ZOooool4o`0003cooooo002Xooooo`?o0000?_ooool00:Sooooo0_l0
000oooooo`00Yoooool3o`0003oooooo002Uooooo`Co0000@?ooool00:Cooooo1?l00011ooooo`00
X_ooool4o`0004?ooooo002Qooooo`Co0000A?ooool009oooooo1?l00016ooooo`00W_ooool4o`00
04Oooooo002Mooooo`?o0000BOooool00>Wooooo003Yooooo`00jOooool005gooooo00Go8B4Qo`00
0?l0003oA4A4omgMg@27ooooo`00H?ooool00omgMgOo<S8booooo`26ooooo`00HOooool00ol0003o
ooooooooo`25ooooo`00A?ooool01Ol@413o0000o`000?l0003o410@00?ooooo00KoV9RHo`000?l0
003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000ooooo`;o000000So410@ooooooo^k^koEEEE
o`000?l@413oc<c<o`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`04oa0@4?l0
003o0000ooooo`;o000000Co410@ooooooooooooV9RH0_l000000om4A4Co^[Zjooooo`04ooooo`03
oa0@4?l0003o000000Co00000oooool5o`0000;ooooo00Co410@o`000?l0003ooooo0_l000001?l@
413oooooonk^k_mEEED2o`000006odA4A?nj^[[oooooooooool@413o<S8b0_l000000ol@413oZJVY
ooooo`12ooooo`00A_ooool00ol0003oooooooooo`03ooooo`05o`000?o<c<cok^k^ohN7Qol00000
1?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002
ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go410@okZj^_o^k^koMgMgoa0@4007ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgoooo
ooo^k^koMgMgoa0@40;ooooo00Ko0000ojVYZOoooooooooookZj^_l00013ooooo`00A_ooool00ol0
003oooooooooo`03ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00002ooooo`03o`000?oooooooooo00Ko
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00Kooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4013ooooo`00A_oo
ool00ol0003oooooooooo`03ooooo`03okZj^_l@413o000000;o00001?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00002ooooo`Ko00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00000_oo
ool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kT?ooooo0016ooooo`03o`000?oooooooooo00Kooooo
00?oc<c<o`000?ooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool01Ol0003oQhN7
oooooonYZJWo000000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06oeEEEOn7QhOok^k^
oooooon7QhOo<S8b0_ooool01_l0003o^[Zjooooooo^k^koMgMgo`0004?ooooo0013ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000oooooooooooooooooc8b<P02o`000007oiRHV?oooooooooo
ooooool@413o0000ogMgM`02o`00000=oiRHV?ooooooooooonk^k_mEEEGo0000ob4Q8OnYZJWo0000
oa0@4?ooooook^k^oeEEE@02o`000007odA4A?o^k^koooooooooool@413o0000ogMgM`02o`000003
oiRHV?oooooo410@00Go00002?ooool00ol0003oooooooooo`05ooooo`03oa0@4?l0003o000000Co
oooo00?o410@o`000?mgMgL00_l000001OnHV9Soooooooooooo^k^koEEEE00;o000000KoA4A4onk^
k_ooooooooooojVYZOlQ8B42o`000003oc8b<_l0003ooooo04;ooooo0013ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06Gooooo0013ooooo`Oo0000:oooool00ol0003oooooooooo`07ooooo`03oa0@4?l0003o
000000;o00001oooool00ol0003oooooooooo`1Kooooo`00Roooool00ol@413oooooooooo`1Koooo
o`00jOooool00>Wooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 263.625}, {507.25, 392.875}} -> {-1.65499, \
19.0761, 0.0184773, 0.049828}}]
}, Open  ]],

Cell["\<\
The three secant lines are shown next. They are drawn using \
ListPlot with the option PlotJoined -> True. The kth line joins (k,f(k)) to \
(k+1,f(k+1)), k=0, 1, 2. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
SecLines = ListPlot[ Table[{k,f[k]}, {k,0,3}], PlotJoined \[Rule] \
True,
                        PlotStyle \[Rule] Thickness[0.01],
                        DisplayFunction -> Identity ];
Show[ {Plot[f[x],{x,0,3}], SecLines}, 
              DisplayFunction -> $DisplayFunction,
              PlotRange->{{-0.5,3},{0,4.5}},
              Axes -> None, PlotLabel \[Rule] \"Secant Lines\" ]\
\>", "Input",\

  CellLabel->"In[90]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.285714 0 0.137341 [
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Secant) show
105.000 13.000 moveto
(Lines) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.14286 0 m
.14392 0 L
.14488 0 L
.14599 0 L
.14704 0 L
.14801 0 L
.14891 0 L
.14989 0 L
.15094 0 L
.15198 0 L
.15311 1e-05 L
.15515 1e-05 L
.15639 1e-05 L
.15757 2e-05 L
.15978 3e-05 L
.16193 4e-05 L
.16421 6e-05 L
.16832 .0001 L
.1732 .00016 L
.17763 .00025 L
.18251 .00037 L
.18701 .0005 L
.19716 .00094 L
.2061 .00148 L
.21555 .00224 L
.22408 .00311 L
.23322 .00427 L
.24972 .00702 L
.26884 .0114 L
.28695 .01688 L
.32145 .0314 L
.33924 .04117 L
.35815 .05336 L
.39213 .08007 L
.42831 .11529 L
.46313 .1554 L
.50015 .20386 L
.53582 .25485 L
.57011 .30625 L
.60662 .36135 L
.64176 .41234 L
.67911 .46132 L
.71509 .50029 L
.73158 .51458 L
.74971 .52718 L
.75833 .53192 L
.7676 .53603 L
.77271 .53786 L
.77738 .53924 L
.78208 .54033 L
Mistroke
.78654 .54111 L
.78888 .54141 L
.79002 .54152 L
.79108 .54162 L
.79202 .54169 L
.79305 .54175 L
.79409 .5418 L
.79519 .54183 L
.79581 .54184 L
.79639 .54185 L
.79749 .54185 L
.79867 .54183 L
.79934 .54181 L
.79995 .54178 L
.80098 .54173 L
.80211 .54165 L
.8044 .54144 L
.80655 .54117 L
.80851 .54086 L
.81294 .53996 L
.81685 .53892 L
.82096 .53756 L
.82957 .53386 L
.83876 .52857 L
.8553 .51547 L
.87455 .49412 L
.8927 .46769 L
.92736 .39923 L
.96424 .29922 L
.99975 .17541 L
1 .17443 L
Mfstroke
.01 w
.14286 0 m
.42857 .11557 L
.71429 .49953 L
1 .17443 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[90]:=",
  ImageSize->{202.75, 125.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003m0000W2000`400?l00000o`00003o;OoooolC
o`000;gooooo000]ooooo`Ko00003Oooool5o`000;Sooooo000_ooooo`Ko00004?ooool7o`000;7o
oooo000booooo`Ko00005?ooool2o`000:oooooo000dooooo`Ko00005?ooool2o`000:gooooo000g
ooooo`Ko00004oooool3o`000:[ooooo000iooooo`Ko00005?ooool3o`000:Oooooo000looooo`Go
00005Oooool2o`000:Gooooo000nooooo`Ko00005?ooool2o`000:?ooooo0010ooooo`Ko00005?oo
ool2o`000:7ooooo0013ooooo`Ko00004oooool00ol0003oooooooooo`2Nooooo`00AOooool6o`00
01;ooooo00?o0000ooooooooool0WOooool004Sooooo1_l0000@ooooo`;o0000WOooool004[ooooo
1_l0000@ooooo`03o`000?oooooooooo09[ooooo001=ooooo`Ko00003_ooool00ol0003ooooooooo
o`2Iooooo`00Coooool6o`0000gooooo0_l0002Iooooo`00D_ooool6o`0000cooooo00?o0000oooo
ooooool0U_ooool005Cooooo1_l0000;ooooo`03o`000?oooooooooo09Gooooo001Gooooo`Ko0000
2Oooool00ol0003oooooooooo`2Dooooo`00FOooool6o`0000Sooooo00?o0000ooooooooool0Tooo
ool005cooooo1Ol00007ooooo`03o`000?oooooooooo09;ooooo001Nooooo`Ko00001Oooool00ol0
003oooooooooo`2Aooooo`00H?ooool6o`0000Cooooo00?o0000ooooooooool0T?ooool006?ooooo
1_l00002ooooo`03o`000?oooooooooo08oooooo001Uooooo`Ko000000?oooooo`000?ooool0Sooo
ool006Sooooo1_l0002?ooooo`00J_ooool5o`0008kooooo001]ooooo`;o0000S_ooool006gooooo
0ol0002=ooooo`00K_ooool3o`0008cooooo001_ooooo`?o0000Roooool0073ooooo0ol0002:oooo
o`00L?ooool4o`0008Wooooo001aooooo`Co0000R?ooool007;ooooo1?l00027ooooo`00Loooool2
o`000003ooooool0003ooooo08Gooooo001cooooo`Co0000Q_ooool007Cooooo1?l00025ooooo`00
MOooool4o`0008Cooooo001fooooo`;o000000?oooooo`000?ooool0LOooool2o`0000oooooo001f
ooooo`?o000000?oooooo`000?ooool0L?ooool2o`0000oooooo001gooooo`Co0000L?ooool3o`00
00oooooo001hooooo`;o000000?oooooo`000?ooool0KOooool3o`00013ooooo001hooooo`?o0000
00?oooooo`000?ooool0Joooool4o`00013ooooo001iooooo`?o000000?oooooo`000?ooool0JOoo
ool3o`000003ooooool0003ooooo00oooooo001jooooo`?o000000?oooooo`000?ooool0Ioooool3
o`000003ooooool0003ooooo013ooooo001kooooo`;o000000?oooooo`000?ooool0I_ooool3o`00
00;ooooo00?o0000ooooooooool03oooool007_ooooo0ol000000ooooooo0000ooooo`1Tooooo`?o
00000oooool00ol0003oooooooooo`0?ooooo`00O?ooool3o`000003ooooool0003ooooo06;ooooo
0ol00004ooooo`03o`000?oooooooooo00oooooo001mooooo`Co0000Hoooool2o`0000Cooooo00?o
0000ooooooooool04?ooool007kooooo0_l000000ooooooo0000ooooo`1Pooooo`?o00001?ooool0
0ol0003oooooooooo`0@ooooo`00O_ooool3o`000003ooooool0003ooooo05kooooo0ol00005oooo
o`03o`000?oooooooooo013ooooo001oooooo`Co0000G_ooool3o`0000Gooooo00?o0000oooooooo
ool04Oooool0083ooooo1?l0001Looooo`?o00001_ooool00ol0003oooooooooo`0Aooooo`00POoo
ool2o`000003ooooool0003ooooo05Wooooo0ol00007ooooo`03o`000?oooooooooo017ooooo0021
ooooo`Co0000FOooool3o`0000Sooooo00?o0000ooooooooool04Oooool008;ooooo1?l0001Goooo
o`?o00002?ooool00ol0003oooooooooo`0Booooo`00Poooool4o`0005Gooooo0ol00009ooooo`03
o`000?oooooooooo01;ooooo0024ooooo`?o0000EOooool2o`0000[ooooo00?o0000ooooooooool0
4_ooool008Cooooo1?l0001Cooooo`?o00002Oooool00ol0003oooooooooo`0Cooooo`00QOooool4
o`00057ooooo0ol0000:ooooo`03o`000?oooooooooo01?ooooo0026ooooo`?o0000D?ooool3o`00
00_ooooo00?o0000ooooooooool04oooool008Oooooo0ol0001>ooooo`?o00003?ooool00ol0003o
ooooooooo`0Cooooo`00Qoooool4o`0004cooooo0ol0000<ooooo`03o`000?oooooooooo01Cooooo
0028ooooo`?o0000Boooool3o`0000gooooo00?o0000ooooooooool05?ooool008Wooooo0ol00019
ooooo`?o00003_ooool00ol0003oooooooooo`0Dooooo`00R_ooool2o`0004Sooooo0ol0000>oooo
o`03o`000?oooooooooo01Gooooo002:ooooo`?o0000Aoooool2o`0000oooooo00?o0000oooooooo
ool05Oooool008_ooooo0ol00015ooooo`?o00003oooool00ol0003oooooooooo`0Eooooo`00S?oo
ool3o`0004?ooooo0ol0000?ooooo`03o`000?oooooooooo01Kooooo002=ooooo`;o0000@_ooool3
o`00013ooooo00?o0000ooooooooool05_ooool008gooooo0ol00010ooooo`?o00004Oooool00ol0
003oooooooooo`0Fooooo`00S_ooool3o`0003kooooo0ol0000Aooooo`03o`000?oooooooooo01Oo
oooo002?ooooo`;o0000?Oooool3o`0001;ooooo00?o0000ooooooooool05oooool008oooooo0ol0
000kooooo`?o00004oooool00ol0003oooooooooo`0Gooooo`00T?ooool3o`0003Wooooo0ol0000C
ooooo`03o`000?oooooooooo01Sooooo002Aooooo`?o0000>?ooool2o`0001Cooooo00?o0000oooo
ooooool06?ooool009;ooooo0_l0000gooooo`?o00005?ooool00ol0003oooooooooo`0Hooooo`00
T_ooool3o`0003Gooooo0ol0000Dooooo`03o`000?oooooooooo01Wooooo002Cooooo`?o0000<ooo
ool3o`0001Gooooo00?o0000ooooooooool06Oooool009Cooooo0ol0000aooooo`?o00005Oooool0
0ol0003oooooooooo`0Jooooo`00UOooool2o`00033ooooo0ol0000Fooooo`03o`000?oooooooooo
01[ooooo002Eooooo`?o0000;_ooool3o`0001Oooooo00?o0000ooooooooool06_ooool009Kooooo
0ol0000/ooooo`?o00005oooool00ol0003oooooooooo`0Kooooo`00Uoooool3o`0002[ooooo0ol0
000Hooooo`03o`000?oooooooooo01_ooooo002Hooooo`;o0000:_ooool2o`0001Wooooo00?o0000
ooooooooool06oooool009Sooooo0ol0000Xooooo`?o00006?ooool00ol0003oooooooooo`0Loooo
o`00VOooool3o`0002Kooooo0ol0000Iooooo`03o`000?oooooooooo01cooooo002Jooooo`?o0000
9?ooool3o`0001[ooooo00?o0000ooooooooool07?ooool009_ooooo0_l0000Sooooo`?o00006_oo
ool00ol0003oooooooooo`0Mooooo`00Voooool3o`00027ooooo0ol0000Kooooo`03o`000?oooooo
oooo01gooooo002Looooo`?o00007oooool3o`0001_ooooo00?o0000ooooooooool07_ooool009go
oooo0ol0000Mooooo`?o00007?ooool00ol0003oooooooooo`0Nooooo`00WOooool3o`0001cooooo
0ol0000Looooo`03o`000?oooooooooo01oooooo002Nooooo`?o00006oooool2o`0001gooooo00?o
0000ooooooooool07oooool009oooooo0ol0000Iooooo`?o00007?ooool00ol0003oooooooooo`0P
ooooo`00X?ooool3o`0001Oooooo0ol0000Mooooo`03o`000?oooooooooo023ooooo002Qooooo`;o
00005_ooool3o`0001gooooo00?o0000ooooooooool08Oooool00:7ooooo0ol0000Dooooo`?o0000
7Oooool00ol0003oooooooooo`0Rooooo`00X_ooool3o`0001;ooooo0ol0000Nooooo`03o`000?oo
oooooooo02;ooooo002Sooooo`;o00004Oooool3o`0001kooooo00?o0000ooooooooool08oooool0
0:?ooooo0ol0000?ooooo`?o00007oooool00ol0003oooooooooo`0Sooooo`00Y?ooool3o`0000go
oooo0ol0000Oooooo`03o`000?oooooooooo02Cooooo002Uooooo`?o00003?ooool2o`00023ooooo
00?o0000ooooooooool09?ooool00:Kooooo0_l0000;ooooo`?o00007oooool00ol0003ooooooooo
o`0Uooooo`00Y_ooool3o`0000Wooooo0ol0000Pooooo`03o`000?oooooooooo02Gooooo002Woooo
o`?o00001oooool3o`00023ooooo00?o0000ooooooooool09_ooool00:Sooooo0ol00005ooooo`?o
00008?ooool00ol0003oooooooooo`0Wooooo`00ZOooool3o`0000?ooooo0ol0000Qooooo`03o`00
0?oooooooooo02Oooooo002Yooooo`Co000000Coooooo`000?l0003o00008Oooool00ol0003ooooo
ooooo`0Xooooo`00Z_ooool6o`00027ooooo00?o0000ooooooooool0:Oooool00:_ooooo1?l0000R
ooooo`03o`000?oooooooooo02Wooooo002/ooooo`?o00008Oooool00ol0003oooooooooo`0Zoooo
o`00[oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02_ooooo002`ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0;?ooool00;7ooooo0_l0000Iooooo`;o0000;ooo
ool00;?ooooo0_l0000Fooooo`03o`000?oooooooooo02oooooo002eooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0<?ooool00;Kooooo00?o0000ooooooooool03oooool2o`0003?o
oooo002gooooo`Co00002oooool2o`0003Gooooo002kooooo`?o00001Oooool3o`0003Oooooo002n
ooooo`Go0000>_ooool00?gooooo003mooooo`00oOooool00?gooooo003mooooo`00oOooool00?go
oooo003mooooo`00oOooool00?gooooo003mooooo`00oOooool00?gooooo003mooooo`00oOooool0
0?gooooo003mooooo`00oOooool00?gooooo003mooooo`00oOooool00?gooooo003mooooo`00D_oo
ool01_l@413o8B4Qo`000?l0003oA4A4omgMg@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3
ooooo`05ofIVI_l0003o0000odA4A?o<c<`00_ooool01_nHV9So0000o`000?mgMgOo410@o`0000;o
oooo00Co410@o`000?l0003ooooo0_l000001?l@413ooooooooooonHV9P2o`000003odA4A?nj^[[o
oooo00Cooooo00?o410@o`000?l000001?l00003ooooo`Go00000_ooool01?l@413o0000o`000?oo
ool2o`000004oa0@4?ooooook^k^oeEEE@;o000000KoA4A4okZj^_oooooooooooa0@4?lb<S82o`00
0003oa0@4?nYZJWooooo053ooooo001Booooo`06o`000?n7QhOooooooooooon7QhOo8B4Q0_ooool0
1_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@4102oooo
o`05o`000?o<c<cok^k^ohN7Qol000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
410@okZj^_o^k^koMgMgoa0@4007ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40;ooooo00Ko0000ojVYZOoooooooooookZj^_l0001Aooooo`00D_ooool01_lQ8B7ooooo
ooooooooooook^k^o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`05oa0@4?n7QhOoooooonk^k_l000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool01Onj^[[o
QhN7ofIVI_mVIVKo410@057ooooo001Cooooo`05omgMgOnHV9SoMgMgoa0@4?mVIVH00_ooool6o`00
00;ooooo00?o0000ooooooooool01Oooool00onj^[[o410@o`000002o`0000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000;ooooo00Ko
<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^iAooooo`00D_ooool01OmVIVKo410@oeEEEOn7QhOo^[Zj00?o
oooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000
1Oooool00oo<c<co0000ooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000000oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003o
QhN7oooooonYZJWo000000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06o`000?nj
^[[oooooonk^k_mgMgOo0000DOooool005;ooooo00Ko0000onk^k_ooooooooooolc<c?l00002oooo
o`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`0000?o
oooo00Co<S8bo`000?l0003oV9RH0oooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooo410@
00Go00002?ooool00ol0003oooooooooo`05ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`00
0?mgMgL00_l000001OnHV9Soooooooooooo^k^koEEEE00;o000000KoA4A4onk^k_ooooooooooojVY
ZOlQ8B42o`000003oc8b<_l0003ooooo053ooooo001Booooo`06oc8b<_n7QhOoooooonk^k_mVIVKo
00008oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07?ooooo001Booooo`06onk^
k_m4A4Co0000o`000?lb<S;o410@8oooool00ol0003oooooooooo`07ooooo`03oa0@4?l0003o0000
00;o00001oooool00ol0003oooooooooo`1Yooooo`00TOooool00ol@413oooooooooo`1Yooooo`00
oOooool00?gooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 279.625}, {284.625, 160.375}} -> {-2.26429, \
6.55932, 0.0196604, 0.0409}}]
}, Open  ]],

Cell["\<\
The pictures make it clear why the approximations are too small and \
are roughly the same. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["An area calculation",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Find the area between the graph of f and the graph of the secant \
line joining the endpoints of the graph over the  interval from",
    FontSlant->"Italic"],
  " 0 ",
  StyleBox["to",
    FontSlant->"Italic"],
  " 3. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
The function defined by the secant line will be named S. It's graph \
is a line through the origin with slope\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(3) - f(0)\)\/\(3 - 0\)\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["S[x_] := (f[3] - f[0])/(3 - 0)*x", "Input",
  CellLabel->"In[96]:=",
  FormatType->InputForm],

Cell["\<\
We want to find the area of the region between the two curves shown \
below. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Plot[ {f[x], S[x]}, {x,0,3} ]", "Input",
  CellLabel->"In[97]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.149191 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16391 -6 -4.5 ]
[.01131 .16391 0 4.5 ]
[.01131 .3131 -6 -4.5 ]
[.01131 .3131 0 4.5 ]
[.01131 .46229 -6 -4.5 ]
[.01131 .46229 0 4.5 ]
[.01131 .61148 -6 -4.5 ]
[.01131 .61148 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16391 m
.03006 .16391 L
s
[(1)] .01131 .16391 1 0 Mshowa
.02381 .3131 m
.03006 .3131 L
s
[(2)] .01131 .3131 1 0 Mshowa
.02381 .46229 m
.03006 .46229 L
s
[(3)] .01131 .46229 1 0 Mshowa
.02381 .61148 m
.03006 .61148 L
s
[(4)] .01131 .61148 1 0 Mshowa
.125 Mabswid
.02381 .04455 m
.02756 .04455 L
s
.02381 .07439 m
.02756 .07439 L
s
.02381 .10423 m
.02756 .10423 L
s
.02381 .13407 m
.02756 .13407 L
s
.02381 .19374 m
.02756 .19374 L
s
.02381 .22358 m
.02756 .22358 L
s
.02381 .25342 m
.02756 .25342 L
s
.02381 .28326 m
.02756 .28326 L
s
.02381 .34294 m
.02756 .34294 L
s
.02381 .37277 m
.02756 .37277 L
s
.02381 .40261 m
.02756 .40261 L
s
.02381 .43245 m
.02756 .43245 L
s
.02381 .49213 m
.02756 .49213 L
s
.02381 .52197 m
.02756 .52197 L
s
.02381 .5518 m
.02756 .5518 L
s
.02381 .58164 m
.02756 .58164 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03746 .01473 L
.03884 .01473 L
.04016 .01474 L
.04262 .01475 L
.045 .01476 L
.04753 .01478 L
.0521 .01482 L
.05752 .01489 L
.06244 .01498 L
.06787 .01511 L
.07287 .01526 L
.08414 .01573 L
.09408 .01632 L
.10458 .01715 L
.11406 .0181 L
.12422 .01936 L
.14255 .02234 L
.16379 .0271 L
.18391 .03305 L
.22224 .04882 L
.24202 .05944 L
.26302 .07268 L
.30077 .10169 L
.34098 .13995 L
.37967 .18353 L
.42081 .23616 L
.46043 .29155 L
.49854 .34739 L
.5391 .40724 L
.57814 .46263 L
.61964 .51584 L
.65962 .55818 L
.67794 .57369 L
.69809 .58738 L
.70767 .59253 L
.71797 .597 L
.72365 .59898 L
.72884 .60048 L
.73406 .60167 L
Mistroke
.73901 .60251 L
.74161 .60284 L
.74288 .60296 L
.74405 .60307 L
.7451 .60314 L
.74625 .60321 L
.7474 .60326 L
.74862 .6033 L
.74931 .60331 L
.74996 .60332 L
.75118 .60332 L
.75249 .60329 L
.75323 .60327 L
.75392 .60324 L
.75506 .60319 L
.75631 .6031 L
.75885 .60287 L
.76124 .60258 L
.76343 .60225 L
.76835 .60127 L
.77269 .60013 L
.77725 .59866 L
.78682 .59464 L
.79704 .5889 L
.81541 .57466 L
.8368 .55148 L
.85696 .52276 L
.89548 .4484 L
.93645 .33975 L
.97591 .20527 L
.97619 .2042 L
Mfstroke
.02381 .01472 m
.06244 .0224 L
.10458 .03079 L
.14415 .03866 L
.18221 .04623 L
.22272 .05429 L
.26171 .06205 L
.30316 .07029 L
.34309 .07824 L
.3815 .08588 L
.42237 .09401 L
.46172 .10184 L
.49955 .10937 L
.53984 .11738 L
.57861 .1251 L
.61984 .1333 L
.65954 .1412 L
.69774 .1488 L
.73838 .15689 L
.77751 .16467 L
.81909 .17294 L
.85916 .18092 L
.89771 .18859 L
.93871 .19674 L
.97619 .2042 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[97]:=",
  ImageSize->{183.5, 113.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003U0000SB000`400?l00000o`00003oiOooool0
0>Gooooo000Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Cooooo`Co000000?o410@ooooooooool04Oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd04oooool5o`0001?ooooo1Ol0
0005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01;ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c00>ooooo`00:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Booooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo017ooooo00Go410@
okZj^_ooooooMgMgoc8b<P0>ooooo`00:Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04_ooool00onHV9So8B4Qonk^kP0Eooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`00:Oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00kooooo00?oMgMgoc8b<_ooool05?ooool00onHV9So8B4Qonk^kP0Eooooo`03oiRHV?lQ
8B7ok^k^00oooooo00?oMgMgoc8b<_ooool05?ooool00onYZJWo410@ooooo`0=ooooo`00:Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Ko
oooo00?oMgMgofIVI_ooool05Oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`05?ooool00ol@413o0000okZj^P0>ooooo`00:Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05oooool00onj^[[o8B4Qooooo`0=ooooo`00:Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool01Ol0003o^[ZjoooooonHV9So
410@01?ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01Cooooo00Go
410@oiRHV?oooooo^[Zjo`00000>ooooo`00:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000Dooooo`03oeEEEOmVIVKo000001Gooooo00?oEEEEofIVI_l000003Oooool4o`0001Cooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00Cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`00
01?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0>ooooo`00iOooool001Cooooo00?o0000oooooooo
ool0c_ooool001Cooooo00?o0000ooooooooool0c_ooool001Cooooo00?o0000ooooooooool0c_oo
ool000ooooooc?l0000:ooooo`005?ooool00ol0003oooooooooo`02ooooo`Go00002_ooool7o`00
00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00gooooo000Dooooo`03o`000?oooooooooo00Oooooo1Ol0000<ooooo`Co0000/_ooool001Cooooo
00?o0000ooooooooool03?ooool4o`0000cooooo0ol0002_ooooo`005?ooool00ol0003ooooooooo
o`0@ooooo`Co00002oooool2o`000:gooooo000Dooooo`03o`000?oooooooooo01Cooooo1_l00007
ooooo`;o0000Zoooool001Cooooo00?o0000ooooooooool06_ooool6o`0000?ooooo0_l0002Yoooo
o`005?ooool00ol0003oooooooooo`0Pooooo`Co000000?oooooo`000?l00000Yoooool001Cooooo
00?o0000ooooooooool09?ooool6o`000:Cooooo000Dooooo`03o`000?oooooooooo02Wooooo1ol0
002Nooooo`005?ooool00ol0003oooooooooo`0[ooooo`;o00000oooool4o`0009[ooooo000Doooo
o`03o`000?oooooooooo02gooooo0_l00005ooooo`Co0000U_ooool001Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`06ooooo`Co0000T_ooool001Cooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`09ooooo`Ko0000S?ooool001Cooooo00?o0000ooooooooool0<Ooo
ool2o`0000oooooo1_l00026ooooo`005?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo01;ooooo1Ol00021ooooo`005?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
01Kooooo1_l0001kooooo`005?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01_o
oooo1_l0001eooooo`005?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo023ooooo
0ol0001booooo`005?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02;ooooo1?l0
001^ooooo`005?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo1?l0001Z
ooooo`005?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Sooooo1_l0001Toooo
o`005?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02gooooo1_l0001Nooooo`00
5?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03;ooooo1Ol0001Iooooo`005?oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Kooooo1_l0001Cooooo`005?ooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo03_ooooo1_l0001=ooooo`005?ooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo047ooooo0ol0001:ooooo`002oooool4o`000003
oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`13ooooo`Co
0000A_ooool000gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo04Kooooo1Ol00011ooooo`003Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool0B_ooool6o`0003_ooooo000=ooooo`03o`000?oooooo
oooo00Cooooo0_l00012ooooo`03o`000?oooooooooo04oooooo1_l0000eooooo`003Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0E?ooool4o`00
037ooooo000=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`1Gooooo`Ko0000:oooool000gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo05cooooo1_l0000Uooooo`002oooool00omEEEGoIVIVo`00
0006ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0HOooool4o`00027ooooo000D
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0IOooool4o`0001gooooo000Doooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0J?ooool4o`0001Wooooo000Dooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0Joooool6o`0001?ooooo000Dooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0L?ooool4o`0000oooooo000Dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0=ooooo`005?ooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03Oooool0
01Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
00kooooo000Dooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`0>ooooo`005?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool03_ooool001Cooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo00oooooo000Dooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool0K?ooool00ol0003oooooooooo`0?ooooo`005?ooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool03oooool001Cooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00oooooo000Dooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0@ooooo`005?oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool04?oo
ool001Cooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo013ooooo000Dooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo06Go
oooo00?o0000ooooooooool04Oooool001Cooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo017ooooo000Dooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04_ooool001Cooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01;ooooo000Dooooo`03
o`000?oooooooooo05Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Booooo`00
2_ooool5o`0000Gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo01?ooooo000:ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool04oooool000_ooooo00?o
V9RHob4Q8Oo^k^h01_ooool2o`0005Wooooo00?o0000ooooooooool0GOooool00ol0003ooooooooo
o`0Cooooo`003?ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`0Cooooo`003Oooool00omgMgOoIVIVooooo`04oooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Doooo
o`003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`0Dooooo`002_ooool01Ol0003o^[ZjoooooonHV9So410@00Go
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Co
oooo000:ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool05Oooool001Cooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01Gooooo000Dooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Eooooo`005?ooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool05_ooool0
01Cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
01Kooooo000Dooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`0Fooooo`005?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool05oooool001Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo01Oooooo000Dooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0Gooooo`005?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool06?ooool001Cooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01Sooooo000Dooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Hooooo`005?oo
ool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool06Ooo
ool001Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo01Wooooo000Dooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0Jooooo`005?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool06_ooool001Cooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo01[ooooo000Dooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Kooooo`005?ooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06oooool001Cooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01_ooooo000Dooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Looooo`00
5?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
7?ooool001Cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo01cooooo000:ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`1[ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool000[ooooo00Go410@
okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0Mooooo`003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Nooooo`003Oooool00onY
ZJWo410@ooooo`04ooooo`;o0000K_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
01kooooo000<ooooo`03oa0@4?l0003o^[Zj00Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo01oooooo000=ooooo`03okZj^_lQ8B7ooooo00Cooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo
000:ooooo`05oa0@4?nHV9SooooookZj^_l000001Oooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool08?ooool000[ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Pooooo`005?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool08Oooool001Cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02;ooooo000Dooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Rooooo`005?ooool00ol0003oooooooooo`1dooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool08oooool001Cooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02?ooooo000Dooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Tooooo`005?ooool0
0ol0003oooooooooo`1fooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09?ooool0
01Cooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
02Gooooo000Dooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Uooooo`005?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool09_ooool001Cooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02Oooooo000Dooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`005?ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:?ooool001Cooooo00?o0000oooooooo
ool0OOooool00ol0003oooooooooo`0Qooooo`;o0000:oooool001Cooooo00?o0000ooooooooool0
O_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02_ooooo000Dooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0/ooooo`005?ooool0
0ol0003oooooooooo`20ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;Oooool0
01Cooooo00?o0000ooooooooool0POooool2o`0001[ooooo00?o0000ooooooooool0;_ooool001Co
oooo00?o0000ooooooooool0Poooool2o`0001Oooooo00?o0000ooooooooool0;oooool001Cooooo
00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo
000Dooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool04?ooool2o`0003?ooooo000D
ooooo`03o`000?oooooooooo08Oooooo0ol0000=ooooo`;o0000=Oooool000cooooo0_l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo08[ooooo0_l0000:ooooo`03o`000?oooooooooo
03Gooooo000=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0S?ooool:o`0003So
oooo000:ooooo`Go00001Oooool00ol0003oooooooooo`3>ooooo`002_ooool01?m4A4CogMgMoooo
ool00006ooooo`;o0000coooool000[ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003ooooo
ooooo`3>ooooo`002oooool00omgMgOoc<c<o`00003Gooooo`002oooool00oo^k^koA4A4o`00003G
ooooo`003?ooool00omgMgOo0000ooooo`3Fooooo`00iOooool00001\
\>"],
  ImageRangeCache->{{{77.875, 260.375}, {603.312, 491}} -> {-1.82529, \
19.8367, 0.0194225, 0.0413288}}]
}, Open  ]],

Cell[TextData[{
  "The area equals the integral of the absolute value of f(x) - S(x) from x = \
0 to x = 3. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses  Abs[x] for the absolute value of x. The integral is calculated \
numerically."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Area = NIntegrate[ Abs[f[x] - S[x]], {x,0,3}]", "Input",
  CellLabel->"In[98]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(3.9658137249031262`\)], "Output",
  CellLabel->"Out[98]="]
}, Open  ]],

Cell["\<\
In an attempt to find an exact area formula we might try to get the \
exact value for the x coordinate of the point  of intersection of the two \
graphs near x = 0.5. Try the Solve function.. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Solve[ f[x] == S[x], x]", "Input",
  CellLabel->"In[99]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{\(Solve::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse functions are \
being used by \\!\\(Solve\\), so some solutions may not be found; use Reduce \
for complete solution information. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[99]:="],

Cell[BoxData[
    \({{x \[Rule] 0}}\)], "Output",
  CellLabel->"Out[99]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " found the solution x = 0. It did not find x = 3 nor did it find the exact \
x value we want (according to the graph a little to the right of x = 0.5). \
Try FindRoot with a specified value for x. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["FindRoot[ f[x] == S[x], {x,0.5}]", "Input",
  CellLabel->"In[101]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({x \[Rule] 0.676348497775059`}\)], "Output",
  CellLabel->"Out[101]="]
}, Open  ]],

Cell["Let's name the point b.", "Text"],

Cell[CellGroupData[{

Cell["b = x/.%", "Input",
  CellLabel->"In[102]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(0.676348497775059`\)], "Output",
  CellLabel->"Out[102]="]
}, Open  ]],

Cell["and use b to do the integration \"exactly\".", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Area2 = Integrate[S[x]-f[x],{x,0,b}] + Integrate[ \
f[x]-S[x],{x,b,3}]\
\>", "Input",
  CellLabel->"In[103]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(3.965810892364242`\)], "Output",
  CellLabel->"Out[103]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " was able to integrate exactly, but the answer is still approximate \
because ",
  StyleBox["b",
    FontSlant->"Italic"],
  " is in floating point form. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Higher Derivatives",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "The prime notation for derivatives can become tedious for order higher \
than 3. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provides a way to obtain higher derivatives using the D operator. Here, \
for example, is how to obtain the formula for the fourth derivative of the \
function f."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["D[f[x],{x,4}]", "Input",
  CellLabel->"In[104]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\(-8\)\ x\ Cos[x] - 12\ Sin[x] + x\^2\ Sin[x]\)], "Output",
  CellLabel->"Out[104]="]
}, Open  ]],

Cell["\<\
As an example using higher derivatives consider the following \
formula for the function P that is the second order Taylor polynomial \
approximation to the function f at the point a = 2.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["P[x_] := f[2] + f'[2]*(x - 2) + 1/2*f''[2]*(x - 2)^2", "Input",
  CellLabel->"In[109]:=",
  FormatType->InputForm],

Cell["\<\
This is referred to as a quadratic approximation. Enter P(x) to see \
the exact formula and apply N to see the  quadratic in floating point form. \
\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
P[x]
N[%]\
\>", "Input",
  CellLabel->"In[110]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(1\/2\ \((\(-2\) + x)\)\^2\ \((8\ Cos[2] - 2\ Sin[2])\) + 
      4\ Sin[2] + \((\(-2\) + x)\)\ \((4\ Cos[2] + 4\ Sin[2])\)\)], "Output",
  CellLabel->"Out[110]="],

Cell[BoxData[
    \(\(\(3.637189707302727`\)\(\[InvisibleSpace]\)\) + 
      1.9726023611141572`\ \((\(-2.`\) + x)\) - 
      2.5738847730142513`\ \((\(-2.`\) + x)\)\^2\)], "Output",
  CellLabel->"Out[111]="]
}, Open  ]],

Cell["The quadratic approximation plots like this. ", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Plot[ {f[x], P[x]}, {x,0,3}]", "Input",
  CellLabel->"In[112]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.367241 0.058797 [
[.18254 .35474 -9 -9 ]
[.18254 .35474 9 0 ]
[.34127 .35474 -3 -9 ]
[.34127 .35474 3 0 ]
[.5 .35474 -9 -9 ]
[.5 .35474 9 0 ]
[.65873 .35474 -3 -9 ]
[.65873 .35474 3 0 ]
[.81746 .35474 -9 -9 ]
[.81746 .35474 9 0 ]
[.97619 .35474 -3 -9 ]
[.97619 .35474 3 0 ]
[.01131 .01446 -12 -4.5 ]
[.01131 .01446 0 4.5 ]
[.01131 .13205 -12 -4.5 ]
[.01131 .13205 0 4.5 ]
[.01131 .24965 -12 -4.5 ]
[.01131 .24965 0 4.5 ]
[.01131 .48484 -6 -4.5 ]
[.01131 .48484 0 4.5 ]
[.01131 .60243 -6 -4.5 ]
[.01131 .60243 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .36724 m
.18254 .37349 L
s
[(0.5)] .18254 .35474 0 1 Mshowa
.34127 .36724 m
.34127 .37349 L
s
[(1)] .34127 .35474 0 1 Mshowa
.5 .36724 m
.5 .37349 L
s
[(1.5)] .5 .35474 0 1 Mshowa
.65873 .36724 m
.65873 .37349 L
s
[(2)] .65873 .35474 0 1 Mshowa
.81746 .36724 m
.81746 .37349 L
s
[(2.5)] .81746 .35474 0 1 Mshowa
.97619 .36724 m
.97619 .37349 L
s
[(3)] .97619 .35474 0 1 Mshowa
.125 Mabswid
.05556 .36724 m
.05556 .37099 L
s
.0873 .36724 m
.0873 .37099 L
s
.11905 .36724 m
.11905 .37099 L
s
.15079 .36724 m
.15079 .37099 L
s
.21429 .36724 m
.21429 .37099 L
s
.24603 .36724 m
.24603 .37099 L
s
.27778 .36724 m
.27778 .37099 L
s
.30952 .36724 m
.30952 .37099 L
s
.37302 .36724 m
.37302 .37099 L
s
.40476 .36724 m
.40476 .37099 L
s
.43651 .36724 m
.43651 .37099 L
s
.46825 .36724 m
.46825 .37099 L
s
.53175 .36724 m
.53175 .37099 L
s
.56349 .36724 m
.56349 .37099 L
s
.59524 .36724 m
.59524 .37099 L
s
.62698 .36724 m
.62698 .37099 L
s
.69048 .36724 m
.69048 .37099 L
s
.72222 .36724 m
.72222 .37099 L
s
.75397 .36724 m
.75397 .37099 L
s
.78571 .36724 m
.78571 .37099 L
s
.84921 .36724 m
.84921 .37099 L
s
.88095 .36724 m
.88095 .37099 L
s
.9127 .36724 m
.9127 .37099 L
s
.94444 .36724 m
.94444 .37099 L
s
.25 Mabswid
0 .36724 m
1 .36724 L
s
.02381 .01446 m
.03006 .01446 L
s
[(-6)] .01131 .01446 1 0 Mshowa
.02381 .13205 m
.03006 .13205 L
s
[(-4)] .01131 .13205 1 0 Mshowa
.02381 .24965 m
.03006 .24965 L
s
[(-2)] .01131 .24965 1 0 Mshowa
.02381 .48484 m
.03006 .48484 L
s
[(2)] .01131 .48484 1 0 Mshowa
.02381 .60243 m
.03006 .60243 L
s
[(4)] .01131 .60243 1 0 Mshowa
.125 Mabswid
.02381 .04386 m
.02756 .04386 L
s
.02381 .07326 m
.02756 .07326 L
s
.02381 .10265 m
.02756 .10265 L
s
.02381 .16145 m
.02756 .16145 L
s
.02381 .19085 m
.02756 .19085 L
s
.02381 .22025 m
.02756 .22025 L
s
.02381 .27905 m
.02756 .27905 L
s
.02381 .30844 m
.02756 .30844 L
s
.02381 .33784 m
.02756 .33784 L
s
.02381 .39664 m
.02756 .39664 L
s
.02381 .42604 m
.02756 .42604 L
s
.02381 .45544 m
.02756 .45544 L
s
.02381 .51423 m
.02756 .51423 L
s
.02381 .54363 m
.02756 .54363 L
s
.02381 .57303 m
.02756 .57303 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36724 m
.02499 .36724 L
.02605 .36724 L
.02729 .36724 L
.02846 .36724 L
.02954 .36724 L
.03053 .36724 L
.03163 .36724 L
.03279 .36724 L
.03395 .36724 L
.0352 .36724 L
.03746 .36725 L
.03884 .36725 L
.04016 .36725 L
.04262 .36725 L
.045 .36726 L
.04753 .36727 L
.0521 .36728 L
.05752 .36731 L
.06244 .36735 L
.06787 .3674 L
.07287 .36746 L
.08414 .36764 L
.09408 .36787 L
.10458 .3682 L
.11406 .36857 L
.12422 .36907 L
.14255 .37025 L
.16379 .37212 L
.18391 .37447 L
.22224 .38068 L
.24202 .38487 L
.26302 .39008 L
.30077 .40152 L
.34098 .4166 L
.37967 .43377 L
.42081 .45452 L
.46043 .47634 L
.49854 .49835 L
.5391 .52194 L
.57814 .54377 L
.61964 .56474 L
.65962 .58142 L
.67794 .58754 L
.69809 .59293 L
.70767 .59496 L
.71797 .59672 L
.72365 .5975 L
.72884 .59809 L
.73406 .59856 L
Mistroke
.73901 .59889 L
.74161 .59902 L
.74288 .59907 L
.74405 .59911 L
.7451 .59914 L
.74625 .59917 L
.7474 .59919 L
.74862 .5992 L
.74931 .59921 L
.74996 .59921 L
.75118 .59921 L
.75249 .5992 L
.75323 .59919 L
.75392 .59918 L
.75506 .59916 L
.75631 .59913 L
.75885 .59904 L
.76124 .59892 L
.76343 .59879 L
.76835 .5984 L
.77269 .59796 L
.77725 .59738 L
.78682 .59579 L
.79704 .59353 L
.81541 .58792 L
.8368 .57878 L
.85696 .56746 L
.89548 .53816 L
.93645 .49534 L
.97591 .44234 L
.97619 .44192 L
Mfstroke
.14659 0 m
.18221 .06602 L
.22272 .13633 L
.26171 .19935 L
.30316 .26133 L
.34309 .31617 L
.3815 .3644 L
.42237 .41085 L
.46172 .45083 L
.49955 .48489 L
.53984 .51643 L
.57861 .54219 L
.61984 .56462 L
.65954 .58139 L
.69774 .59306 L
.71741 .59736 L
.72833 .59925 L
.73838 .60067 L
.74867 .60181 L
.75397 .60227 L
.75979 .60268 L
.76487 .60296 L
.7696 .60314 L
.77222 .60322 L
.7746 .60327 L
.77592 .60329 L
.77662 .6033 L
.77736 .60331 L
.778 .60331 L
.77871 .60331 L
.77996 .60332 L
.78118 .60332 L
.78231 .60331 L
.78355 .6033 L
.78425 .6033 L
.78488 .60329 L
.78616 .60327 L
.78754 .60324 L
.79006 .60318 L
.7924 .6031 L
.79487 .603 L
.79931 .60278 L
.80444 .60245 L
.80924 .60207 L
.82017 .60094 L
.83057 .59954 L
.84045 .5979 L
.85899 .59404 L
.89724 .58281 L
.93793 .56604 L
Mistroke
.97619 .54574 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[112]:=",
  ImageSize->{166.75, 103},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003@0000P2000`400?l00000o`00003od?ooool0
0=3ooooo003@ooooo`00d?ooool000Sooooo00Gok^k^oc8b<_l0003o410@olc<c004ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0Y?ooool000Sooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Y?ooool000Ko00000_oo
ool01Ol0003ooooooooooooooooo000000Cooooo0_l0000Gooooo`03o`000?oooooooooo0:?ooooo
0008ooooo`05o`000?nHV9SooooooiRHV?lQ8B401?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0:?ooooo0008ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo0:;ooooo0008ooooo`03oeEEEOn7QhOooooo00Kooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`2Qooooo`002?ooool00ooMgMgo410@oiRHV006
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0XOooool000Wooooo00Coc<c<odA4
A?l0003o410@1?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0:3ooooo000Aoooo
o`;o00006_ooool00ol0003oooooooooo`2Pooooo`004Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo09oooooo000Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
W_ooool0017ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Nooooo`004Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo09gooooo000Aooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0WOooool0017ooooo0_l0000Nooooo`03o`000?oooooooooo09co
oooo000Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0W?ooool0017ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`2Kooooo`004Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo09[ooooo000Aooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0V_ooool0017ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2Iooooo`00
4Oooool2o`00027ooooo00?o0000ooooooooool0VOooool0017ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`2Hooooo`004Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Sooooo000:ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo09Oooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`2Fooooo`001_l00002ooooo`Go00001?ooool2o`0002Cooooo
00?o0000ooooooooool0U_ooool000Sooooo00CoA4A4omgMgOoooooo00001Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo09Gooooo0008ooooo`04omgMgOmEEEGoooooo`0000Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`2Eooooo`002Oooool00omgMgOoc<c<o`00
0005ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0U?ooool000Wooooo00?ok^k^
odA4A?l000001Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo09Cooooo000:oooo
o`03ogMgMol0003ooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Coooo
o`004Oooool2o`0002Sooooo00?o0000ooooooooool0T_ooool0017ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`2Booooo`004Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo097ooooo000Aooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0TOooool0
017ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2@ooooo`004Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo08oooooo000Aooooo`;o0000:oooool00ol0003ooooo
ooooo`2?ooooo`004Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08kooooo000A
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0S_ooool0017ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`2=ooooo`004Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo08cooooo000Aooooo`;o0000;_ooool00ol0003oooooooooo`2<ooooo`004Ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo08_ooooo000Aooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0R_ooool0017ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`2:ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`29ooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`28ooooo`001_l00003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo
0_l0000booooo`03o`000?oooooooooo08Sooooo000:ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`27ooooo`002oooool00omgMgOoIVIVooooo`03
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0Q_ooool000cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo08Kooooo0008ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
08Gooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo08Cooooo000Aooooo`;o0000=oooool00ol0003oooooooooo`23ooooo`00
4Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo08?ooooo000Aooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0P_ooool0017ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`21ooooo`004Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
087ooooo000Aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0P?ooool0017ooooo
0_l0000Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Booooo`Co000000?o410@ooooooooool04?ooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd04Oooool5o`00017ooooo1Ol00005
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM017ooooo00GoV9RHoa0@4?l0003o<S8b
olc<c004ooooo`004Oooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool04oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo013ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A00Aooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool04?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Cooooo000Aooooo`03o`000?oooooooooo
017ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?oV9RH
ob4Q8Oo^k^h04oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00_ooool0017ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool04oooool2o`0001Gooooo00?o0000ooooooooool03_ooool0
0omgMgOo<S8booooo`0Booooo`03oiRHV?lQ8B7ok^k^01?ooooo00?oV9RHob4Q8Oo^k^h03oooool0
0omgMgOo<S8booooo`0Cooooo`03ojVYZOl@413ooooo00?ooooo000Aooooo`03o`000?oooooooooo
017ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?oo
ool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Dooooo`03ogMgMomVIVKooooo01?ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<01?ooooo00?o410@o`000?nj^[X01?ooool0017ooooo0_l0000Booooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`00
01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03okZj^_lQ8B7ooooo
00?ooooo000Aooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool04oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00Go
0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01?ooooo00Go410@oiRHV?oooooo
^[Zjo`000004ooooo`004Oooool00ol0003oooooooooo`0Aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0001?ooooo00?oEEEEofIVI_l000000oooool00ol0003oooooooooo`0>ooooo`03
oeEEEOmVIVKo000000gooooo1?l0000Booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool01OnH
V9So410@o`000?lQ8B7oc<c<00cooooo1?l0000Booooo`05ojVYZOl@413o0000oa0@4?nYZJT01?oo
ool0017ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1iooooo`004Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo07Sooooo000Aooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0Moooool000coooooa?l00000017ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo
3?l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo000Aooooo`03o`000?oooooooooo01oooooo1?l0
000Qooooo`03o`000?oooooooooo07Gooooo000Aooooo`03o`000?oooooooooo02?ooooo1_l0000L
ooooo`03o`000?oooooooooo07Cooooo000Aooooo`03o`000?oooooooooo02Wooooo0_l0000Koooo
o`03o`000?oooooooooo07?ooooo000Aooooo`03o`000?oooooooooo02_ooooo0ol0000Iooooo`03
o`000?oooooooooo07;ooooo000Aooooo`;o0000;oooool4o`0001Kooooo00?o0000ooooooooool0
LOooool0017ooooo00?o0000ooooooooool0<_ooool3o`0001Cooooo00?o0000ooooooooool0L?oo
ool0017ooooo00?o0000ooooooooool0=Oooool3o`0001;ooooo00?o0000ooooooooool0Koooool0
017ooooo00?o0000ooooooooool0>?ooool3o`00013ooooo00?o0000ooooooooool0K_ooool0017o
oooo00?o0000ooooooooool0>oooool2o`0000oooooo00?o0000ooooooooool0KOooool0017ooooo
00?o0000ooooooooool0?Oooool3o`0000gooooo00?o0000ooooooooool0K?ooool0017ooooo0_l0
0011ooooo`;o00003?ooool00ol0003oooooooooo`1[ooooo`004Oooool00ol0003oooooooooo`12
ooooo`;o00002oooool00ol0003oooooooooo`1Zooooo`004Oooool00ol0003oooooooooo`14oooo
o`;o00002_ooool00ol0003oooooooooo`1Yooooo`004Oooool00ol0003oooooooooo`16ooooo`;o
00002Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00?ooooo000Aooooo`03o`00
0?oooooooooo04Sooooo0_l00008ooooo`;o0000H_ooool00ol0003oooooooooo`03ooooo`004Ooo
ool2o`0004_ooooo0_l00008ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool01?oo
ool0017ooooo00?o0000ooooooooool0C?ooool2o`0000Oooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`05ooooo`004Oooool00ol0003oooooooooo`1>ooooo`;o00001_ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo00Gooooo0008ooooo`Go00001?ooool00ol0003o
ooooooooo`1@ooooo`;o00001Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Ko
oooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00ol0003oooooooooo`1Booooo`;o
00001?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Oooooo0009ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool02?ooool000[ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool2o`0005Kooooo0_l00003ooooo`;o0000EOooool00ol0003oooooooooo`08ooooo`002oooool0
0omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Wooooo000<ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool02_ooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo05Wooooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool02oooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo
05_ooooo0_l00002ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool03?ooool0017o
oooo00?o0000ooooooooool0GOooool2o`000003ooooool0003ooooo04[ooooo00?o0000oooooooo
ool03Oooool0017ooooo0_l0001Pooooo`Co0000B?ooool00ol0003oooooooooo`0>ooooo`004Ooo
ool00ol0003oooooooooo`1Qooooo`?o0000A_ooool00ol0003oooooooooo`0?ooooo`004Oooool0
0ol0003oooooooooo`1Sooooo`?o0000@oooool00ol0003oooooooooo`0@ooooo`004Oooool00ol0
003oooooooooo`1Uooooo`?o0000@?ooool00ol0003oooooooooo`0Aooooo`004Oooool00ol0003o
ooooooooo`1Wooooo`;o0000?Oooool2o`0001Cooooo000Aooooo`;o0000J_ooool2o`0003[ooooo
00?o0000ooooooooool05?ooool0017ooooo00?o0000ooooooooool0Joooool2o`0003Oooooo00?o
0000ooooooooool03_ooool2o`0000Gooooo000Aooooo`03o`000?oooooooooo06cooooo0ol0000c
ooooo`;o00003oooool2o`0000Oooooo000Aooooo`03o`000?oooooooooo06kooooo0ol0000`oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool0017ooooo00?o0000oooooooo
ool0L?ooool3o`0002gooooo00?o0000ooooooooool03Oooool2o`0000[ooooo000Aooooo`03o`00
0?oooooooooo077ooooo1?l0000Yooooo`;o00003_ooool2o`0000cooooo000Aooooo`;o0000M?oo
ool4o`0002Gooooo0_l0000=ooooo`?o00003_ooool0017ooooo00?o0000ooooooooool0M_ooool3
o`00027ooooo0_l0000<ooooo`?o00004Oooool0017ooooo00?o0000ooooooooool0NOooool3o`00
01cooooo0_l0000;ooooo`?o00005?ooool000[ooooo0_l000000ol@413oooooooooo`02ooooo`03
o`000?oooooooooo07cooooo0ol0000Fooooo`?o00002Oooool4o`0001Oooooo000;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Ooooool5o`0000kooooo0ol00009ooooo`?o0000
6oooool000Sooooo1Ol00004ooooo`03o`000?oooooooooo08?ooooo3ol00007ooooo`Go00007_oo
ool000Sooooo00CoA4A4omgMgOoooooo00001Oooool2o`0008Wooooo4Ol0000Sooooo`002?ooool0
1?oMgMgoEEEEooooool00005ooooo`03o`000?oooooooooo0;cooooo0009ooooo`03ogMgMoo<c<co
000000Gooooo00?o0000ooooooooool0_?ooool000Wooooo00?ok^k^odA4A?l000001Oooool00ol0
003oooooooooo`2looooo`002_ooool00omgMgOo0000ooooo`33ooooo`00d?ooool00=3ooooo0000
\
\>"],
  ImageRangeCache->{{{77.875, 243.625}, {290.875, 188.875}} -> {-1.85992, \
14.0793, 0.0202563, 0.109369}}]
}, Open  ]],

Cell[TextData[{
  "Near ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 2 the approximation is very good. The next plot uses the option Frame \
-> True to obtain the kind of  picture that is popular in engineering texts. \
The function and the approximation are plotted using the dashing PlotStyle. \
Note that Dashing[{0,0}] is just a solid line. (I do not know why there is a \
vertical line at x = 1.6.)"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Plot[ {f[x], P[x]}, {x,1.5,2.5}, Frame -> True,
      PlotStyle \[Rule] {Dashing[{0,0}],Dashing[{0.03,0.03}]}]\
\>", "Input",
  CellLabel->"In[123]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.40476 0.952381 -0.573801 0.293171 [
[.11905 -0.0125 -9 -9 ]
[.11905 -0.0125 9 0 ]
[.30952 -0.0125 -9 -9 ]
[.30952 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -9 -9 ]
[.69048 -0.0125 9 0 ]
[.88095 -0.0125 -9 -9 ]
[.88095 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01254 -6 -4.5 ]
[-0.0125 .01254 0 4.5 ]
[-0.0125 .15913 -18 -4.5 ]
[-0.0125 .15913 0 4.5 ]
[-0.0125 .30571 -6 -4.5 ]
[-0.0125 .30571 0 4.5 ]
[-0.0125 .4523 -18 -4.5 ]
[-0.0125 .4523 0 4.5 ]
[-0.0125 .59888 -6 -4.5 ]
[-0.0125 .59888 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(1.6)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(1.8)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2.2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(2.4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01254 m
.00625 .01254 L
s
[(2)] -0.0125 .01254 1 0 Mshowa
0 .15913 m
.00625 .15913 L
s
[(2.5)] -0.0125 .15913 1 0 Mshowa
0 .30571 m
.00625 .30571 L
s
[(3)] -0.0125 .30571 1 0 Mshowa
0 .4523 m
.00625 .4523 L
s
[(3.5)] -0.0125 .4523 1 0 Mshowa
0 .59888 m
.00625 .59888 L
s
[(4)] -0.0125 .59888 1 0 Mshowa
.125 Mabswid
0 .04186 m
.00375 .04186 L
s
0 .07117 m
.00375 .07117 L
s
0 .10049 m
.00375 .10049 L
s
0 .12981 m
.00375 .12981 L
s
0 .18844 m
.00375 .18844 L
s
0 .21776 m
.00375 .21776 L
s
0 .24708 m
.00375 .24708 L
s
0 .27639 m
.00375 .27639 L
s
0 .33503 m
.00375 .33503 L
s
0 .36435 m
.00375 .36435 L
s
0 .39366 m
.00375 .39366 L
s
0 .42298 m
.00375 .42298 L
s
0 .48161 m
.00375 .48161 L
s
0 .51093 m
.00375 .51093 L
s
0 .54025 m
.00375 .54025 L
s
0 .56956 m
.00375 .56956 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01254 m
1 .01254 L
s
.99375 .15913 m
1 .15913 L
s
.99375 .30571 m
1 .30571 L
s
.99375 .4523 m
1 .4523 L
s
.99375 .59888 m
1 .59888 L
s
.125 Mabswid
.99625 .04186 m
1 .04186 L
s
.99625 .07117 m
1 .07117 L
s
.99625 .10049 m
1 .10049 L
s
.99625 .12981 m
1 .12981 L
s
.99625 .18844 m
1 .18844 L
s
.99625 .21776 m
1 .21776 L
s
.99625 .24708 m
1 .24708 L
s
.99625 .27639 m
1 .27639 L
s
.99625 .33503 m
1 .33503 L
s
.99625 .36435 m
1 .36435 L
s
.99625 .39366 m
1 .39366 L
s
.99625 .42298 m
1 .42298 L
s
.99625 .48161 m
1 .48161 L
s
.99625 .51093 m
1 .51093 L
s
.99625 .54025 m
1 .54025 L
s
.99625 .56956 m
1 .56956 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.11905 0 m
.11905 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08418 m
.06244 .12168 L
.10458 .16246 L
.14415 .20045 L
.18221 .23651 L
.22272 .27416 L
.26171 .30948 L
.30316 .34578 L
.34309 .3793 L
.3815 .40998 L
.42237 .44067 L
.46172 .46809 L
.49955 .49224 L
.53984 .51535 L
.57861 .53479 L
.61984 .55219 L
.65954 .56552 L
.69774 .57493 L
.71741 .5784 L
.72833 .57991 L
.73838 .58103 L
.74867 .5819 L
.75408 .58224 L
.75979 .58252 L
.76219 .58262 L
.76477 .5827 L
.7672 .58276 L
.76941 .5828 L
.77076 .58282 L
.77201 .58283 L
.77266 .58284 L
.77338 .58284 L
.77413 .58284 L
.77483 .58285 L
.77612 .58284 L
.7773 .58284 L
.7786 .58283 L
.77925 .58282 L
.77996 .58281 L
.7825 .58277 L
.78393 .58274 L
.78525 .58271 L
.79024 .58253 L
.79477 .58232 L
.79958 .58202 L
.80955 .5812 L
.82053 .57998 L
.83997 .57694 L
.86087 .57242 L
.88204 .56649 L
Mistroke
.90214 .55957 L
.94039 .54283 L
.97619 .52279 L
Mfstroke
[ .03 .03 ] 0 setdash
.02381 .01472 m
.06244 .06754 L
.10458 .12233 L
.14415 .17109 L
.18221 .21553 L
.22272 .26018 L
.26171 .30058 L
.30316 .34075 L
.34309 .37675 L
.3815 .40888 L
.42237 .44036 L
.46172 .46805 L
.49955 .49224 L
.53984 .51539 L
.57861 .53511 L
.61984 .55334 L
.65954 .56822 L
.69774 .58006 L
.73838 .58999 L
.77751 .59696 L
.79892 .59969 L
.80873 .60069 L
.81909 .60157 L
.82867 .60222 L
.83374 .60251 L
.83917 .60277 L
.84417 .60296 L
.84873 .6031 L
.85092 .60316 L
.85331 .60321 L
.85557 .60325 L
.85765 .60327 L
.85998 .6033 L
.8612 .60331 L
.86249 .60331 L
.86362 .60332 L
.86467 .60332 L
.86582 .60332 L
.86704 .60332 L
.86774 .60331 L
.86839 .60331 L
.86984 .6033 L
.87112 .60329 L
.87248 .60327 L
.87483 .60324 L
.87742 .60319 L
.88265 .60306 L
.88827 .60287 L
.89843 .60239 L
.90856 .60174 L
Mistroke
.9196 .60083 L
.9397 .59867 L
.95738 .59621 L
.97619 .59302 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[123]:=",
  ImageSize->{207.562, 128.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000430000X2000`400?l00000o`00003oooooool4
ooooo`00ooooool4ooooo`00:oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`06?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`07oooool5o`00023ooooo1Ol00005ooooo`;o8B4Q1?ooool5
o`0001Oooooo1Ol00005ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo017ooooo000]oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406_ooool0
0ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01oooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00Pooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Gooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool04_ooool002gooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000001[ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooo
oooo0000023ooooo00?oV9RHob4Q8Oo^k^h08_ooool00onHV9So8B4Qonk^kP0=ooooo`03oiRHV?lQ
8B7ok^k^01Wooooo00?oV9RHob4Q8Oo^k^h03?ooool5o`0001?ooooo000]ooooo`03o`000?oooooo
oooo00[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Jooooo`03o`000?oooooooooo00[ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P0Qooooo`03oiRHV?lQ8B7ok^k^02;ooooo00?oV9RHob4Q8Oo^k^h0
3Oooool00onHV9So8B4Qonk^kP0Iooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoA4A4omgMgOoooooo
00005?ooool002gooooo00?o0000ooooooooool02_ooool01Ol0003oEEEEo`000?l@413oc<c<01[o
oooo00?o0000ooooooooool02_ooool01Oo<c<co0000o`000?l0003oc<c<02;ooooo00?oMgMgofIV
I_ooool08_ooool00omgMgOoIVIVooooo`0=ooooo`03ogMgMomVIVKooooo01Wooooo00?oMgMgofIV
I_ooool02_ooool01?oMgMgoEEEEooooool0000Dooooo`00;Oooool00ol0003oooooooooo`0:oooo
o`03oeEEEOn7QhOooooo01cooooo00?o0000ooooooooool02_ooool01Ol@413o^[Zjoooooonj^[[o
410@02?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02_ooool00omgMgOoc<c<o`00000Dooooo`00;Oooool00ol0
003oooooooooo`0:ooooo`03omgMgOl@413oV9RH01cooooo00?o0000ooooooooool02_ooool01Ol0
003o^[Zjoooooonj^[[o000001oooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05o`000?nj
^[[ooooooiRHV?l@41002oooool01Ol0003o^[ZjoooooonHV9So410@01Oooooo00Go0000okZj^_oo
ooooV9RHoa0@400<ooooo`03onk^k_m4A4Co000001Cooooo000[ooooo`03oeEEEOmVIVKo000000go
oooo00Coc<c<odA4A?l0003o410@6?ooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT07oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`05oooool01OnHV9So410@o`000?lQ8B7oc<c<
00gooooo00?oMgMgo`000?ooool04oooool00?oooooo1?ooool00?oooooo1?ooool00?oooooo1?oo
ool00?oooooo1?ooool001Woooooj_l0000000oooooo1Ol00005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?o
oooo0Ol0000000oooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`7o0000000@ooooo`03oiRH
V?lQ8B7ok^k^00Kooooo0_l0000Jooooo`03o`000?oooooooooo0<Sooooo0ol00000017ooooo00?o
V9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`02ooooo`;o00005Oooool00ol0003ooooooooo
o`3:ooooo`7o0000000Booooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`3:ooooo`7o0000000Cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`3:ooooo`7o0000000?ooooo`05o`000?nj^[[ooooooiRH
V?l@41001Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<[ooooo0Ol0000000oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0b_ooool1o`0000006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<[o
oooo0Ol0000001Wooooo0_l00008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
bOooool2o`0000006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0b_ooool1o`0000006Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0b_ooool1o`0000006Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0b_ooool1o`0000006Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0b_ooool1o`000000
6Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
b_ooool1o`0000006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<[ooooo0Ol0
000001Wooooo0_l0000Jooooo`03o`000?oooooooooo0<Wooooo0_l0000001Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`3:ooooo`7o0000000Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0b_ooool1o`0000006Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0b_ooool1o`0000006Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3:ooooo`7o0000000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<[ooooo0Ol0000001Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0b_ooool1o`0000006Oooool2o`0000Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0<Wooooo0_l0000001Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
b_ooool1o`0000006Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3:ooooo`7o0000000Iooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3:ooooo`7o0000000Ioooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3:oooo
o`7o0000000Iooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`03o`000?oooooooooo0<[o
oooo0Ol0000001Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0<[ooooo0Ol0000001Wooooo0_l0000?ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0bOooool2o`0000006Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Kooooo0_l0003<ooooo`7o0000000Iooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01Oooool2o`000<cooooo0Ol0000001Wooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0<[ooooo0Ol0000000Co00001Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01?ooool2o`000<_ooooo0Ol000000004ob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo00000<[ooooo0Ol000000003oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool0
0_ooool2o`0001Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00037ooooo`?o
000000001?ooooooV9RHob4Q8Oo^k^h?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool05Oooool01Ol0003ooooooooooooooooo00000<cooooo0Ol0000000;ooooo00?oMgMgofIVI_oo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05_ooool01?l0
003oooooooooool0003<ooooo`7o00000003ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo00000<cooooo0Ol000000004
okZj^_ooooooV9RHoa0@40cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hoooo
o`;o0000c?ooool1o`00000000Co410@o`000?lQ8B7oc<c<3?ooool4o`0000Gooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`3:ooooo`7o0000000Iooooo`03o`000?oooooooooo01Wo
oooo0_l00006ooooo`03o`000?oooooooooo0<;ooooo0Ol0000001Wooooo0_l0000Jooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool0`Oooool2o`0000006Oooool00ol0003ooooooooo
o`0Iooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0`Oooool1o`0000006Ooo
ool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`30ooooo`7o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo00?o0000ooooooooool0_oooool1o`0000006Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2n
ooooo`7o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`32ooooo`7o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`31ooooo`7o0000000Iooooo`;o00006_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;oooooo0_l0000001Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;oooooo0Ol0000001Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0^Oooool1o`0000006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`00002kooooo`7o0000000Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool02oooool2o`0000;ooooo00?o0000ooooooooool0^?ooool1o`00
00006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo00Co0000oooooooo
oooo0000^Oooool1o`0000006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00ko
oooo00Co0000oooooooooooo0000^?ooool1o`0000006Oooool2o`0001[ooooo00?o0000oooooooo
ool03oooool01?l0003oooooooooool0002fooooo`;o0000000Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2gooooo`7o0000000Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2fooooo`7o0000
000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`2eooooo`7o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`2dooooo`7o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`2cooooo`7o0000000Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool05Oooool3o`000;;ooooo0Ol0000001Wooooo0_l0000Jooooo`03o`00
0?oooooooooo01Oooooo0_l0002`ooooo`;o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06?ooool2o`000;3ooooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`;o0000[oooool1o`0000006Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01[ooooo0_l0002^ooooo`7o0000000?ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo0_l0002]oooo
o`7o0000000?ooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Zoooool1o`0000004oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`2Zooooo`7o0000000Booooo`03ojVYZOl@413ooooo00Cooooo0_l0000Jooooo`03o`00
0?oooooooooo01kooooo0_l0002Xooooo`?o0000000Aooooo`03oa0@4?l0003o^[Zj00Gooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Pooooo`;o0000Z?ooool1o`0000004_ooool0
0onj^[[o8B4Qooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08Oooool2
o`000:Oooooo0Ol0000000oooooo00Go410@oiRHV?oooooo^[Zjo`000005ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool08_ooool2o`000:Kooooo0Ol0000000oooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08oooool2
o`000:Gooooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Toooo
o`;o0000Y?ooool1o`0000006Oooool2o`0001[ooooo00?o0000ooooooooool09Oooool2o`000:;o
oooo0_l0000001Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo0:7ooooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo0:3ooooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Xooooo`;o0000X?ooool1o`0000006Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0WOooool1o`0000006Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0W?ooool1o`000000
6Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
Voooool1o`0000006Oooool2o`0001[ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`2Iooooo`;o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`2Iooooo`7o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`2Hooooo`7o0000000Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Gooooo`7o0000000Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0<Oooool2o`0009Oooooo0Ol0000001Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo09Cooooo0Ol0
000001Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo09?ooooo0Ol0000001Wooooo0_l0000Jooooo`03o`000?oooooooooo03Gooooo0_l0002Boooo
o`;o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`2@ooooo`7o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`2?ooooo`7o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`2>ooooo`7o0000000Iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0>_ooool2o`0008kooooo0Ol0000001Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0kooooo`;o0000SOooool1o`0000006Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0R_ooool1o`000000
6Oooool2o`0001[ooooo00?o0000ooooooooool0?_ooool2o`0008Wooooo0_l0000001Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08Oooooo0Ol0
000001Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo08Kooooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo08Gooooo0Ol000000004oa0@4?l0003o<S8bolc<c0Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04?ooooo0_l00025ooooo`7o000000001?nj^[[oooooogMgMolb<S85ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`22ooooo`7o00000003ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Kooooo0_l00022oooo
o`7o00000002ooooo`03ojVYZOl@413ooooo00kooooo00?oMgMgoc8b<_ooool00oooool2o`0001[o
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1mooooo`?o000000001?oooooo410@
o`000?nj^[X<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo04Wooooo0_l0001oooooo`7o00000002ooooo`03okZj^_lQ8B7ooooo00_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool0O?ooool1o`00000000CoV9RHoooooonj^[[o00003?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C?ooool2o`0007co
oooo0Ol000000004oa0@4?l0003o410@ojVYZ@cooooo1?l00005ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1iooooo`7o0000000Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0Coooool2o`0007Wooooo0Ol0000001Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo07Kooooo0Ol0
000001Wooooo0_l0000Jooooo`03o`000?oooooooooo05;ooooo0_l0001eooooo`;o0000000Ioooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1coooo
o`7o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0EOooool2o`0007?o
oooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Gooooo`;o0000
LOooool1o`0000006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05Sooooo0ol0
001_ooooo`7o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0F_ooool3
o`0006gooooo0Ol0000001Wooooo0_l0000Jooooo`03o`000?oooooooooo05cooooo0ol0001Zoooo
o`;o0000000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0G_ooool3o`0006Wo
oooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Qooooo`;o0000
Ioooool1o`0000006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06?ooooo0_l0
001Nooooo`;o00001Oooool1o`0000006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo06Cooooo0_l0001Looooo`03o`000?oooooooooo00Gooooo0Ol0000001Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`1Vooooo`;o0000F?ooool2o`0000Sooooo0Ol0000001Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Xooooo`;o0000E?ooool2o`0000[o
oooo0Ol0000001Wooooo0_l0000Jooooo`03o`000?oooooooooo06[ooooo0_l0001Aooooo`03o`00
0?oooooooooo00Wooooo0_l0000001Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1/ooooo`?o0000C?ooool2o`0000gooooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1_ooooo`;o0000B?ooool2o`0000oooooo0Ol0000001Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`1aooooo`?o0000@_ooool3o`00017ooooo0Ol0000001Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1cooooo`Co0000?Oooool2o`0001Co
oooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1eooooo`Go0000
=oooool3o`0001Kooooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1gooooo`03o`000?oooooooooo00?o0000<?ooool4o`0001Wooooo0Ol0000001Wooooo0_l0000J
ooooo`03o`000?oooooooooo07gooooo1Ol0000Xooooo`?o00007?ooool2o`0000006Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo07kooooo2Ol0000Pooooo`?o00008?ooool1o`00
00006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08;ooooo0ol00002ooooo`Ko
00004_ooool8o`0002?ooooo0Ol0000001Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`25ooooo`03o`000?oooooooooo00Gooooo4_l0000[ooooo`7o0000000Aooooo`;o000000?o
410@ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08_ooooo0_l0
000mooooo`7o0000000Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`2=ooooo`Co0000>Oooool1o`0000003oooool5o`0000Gooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`2Aooooo`;o0000:oooool6o`0000Kooooo0Ol0000000oo
oooo00CoA4A4omgMgOoooooo00001_ooool2o`0001[ooooo00?o0000ooooooooool0VOooool8o`00
01_ooooo0_l0000:ooooo`?o0000000?ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Cooooo2?l00005oooo
o`;o00005?ooool1o`0000004?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0b_ooool1o`0000004?ooool00oo^k^koA4A4o`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0Ol00000017ooooo00?oMgMgo`000?ooool01OoooooZo`000000ooooool4
ooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 284.438}, {516.125, 388.875}} -> {0.920629, \
8.87898, 0.00564356, 0.0183334}}]
}, Open  ]],

Cell["\<\
The function called Series will output the Taylor series and an \
error term for the function f. The syntax is shown below. The Normal function \
removes the error term and N evaluates the coefficients numerically..\
\>", \
"Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Series[ f[x], {x,2,2} ]
Normal[%]
N[%]\
\>", "Input",
  CellLabel->"In[129]:=",
  FormatType->InputForm],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(4\ Sin[2]\), 
        "+", \(\((4\ Cos[2] + 4\ Sin[2])\)\ \((x - 2)\)\), 
        "+", \(\((4\ Cos[2] - Sin[2])\)\ \((x - 2)\)\^2\), "+", 
        InterpretationBox[\(O[x - 2]\^3\),
          SeriesData[ x, 2, {}, 0, 3, 1],
          Editable->False]}],
      SeriesData[ x, 2, {
        Times[ 4, 
          Sin[ 2]], 
        Plus[ 
          Times[ 4, 
            Cos[ 2]], 
          Times[ 4, 
            Sin[ 2]]], 
        Plus[ 
          Times[ 4, 
            Cos[ 2]], 
          Times[ -1, 
            Sin[ 2]]]}, 0, 3, 1],
      Editable->False]], "Output",
  CellLabel->"Out[129]="],

Cell[BoxData[
    \(\((\(-2\) + x)\)\^2\ \((4\ Cos[2] - Sin[2])\) + 
      4\ Sin[2] + \((\(-2\) + x)\)\ \((4\ Cos[2] + 4\ Sin[2])\)\)], "Output",
  CellLabel->"Out[130]="],

Cell[BoxData[
    \(\(\(3.637189707302727`\)\(\[InvisibleSpace]\)\) + 
      1.9726023611141572`\ \((\(-2.`\) + x)\) - 
      2.5738847730142513`\ \((\(-2.`\) + x)\)\^2\)], "Output",
  CellLabel->"Out[131]="]
}, Open  ]],

Cell[TextData[StyleBox["Unevaluated derivatives",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "If an undefined function, say y(x), is differentiated, then ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " simply returns the derivative formula. See below."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["y'[x]", "Input",
  CellLabel->"In[132]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]], "Output",
  CellLabel->"Out[132]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["D[y[x],x]", "Input",
  CellLabel->"In[133]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]], "Output",
  CellLabel->"Out[133]="]
}, Open  ]],

Cell["The same is true for higher order derivatives. ", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["y''''[x]", "Input",
  CellLabel->"In[134]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["y", 
        TagBox[\((4)\),
          Derivative],
        MultilineFunction->None], "[", "x", "]"}]], "Output",
  CellLabel->"Out[134]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["D[y[x],{x,4}]", "Input",
  CellLabel->"In[136]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["y", 
        TagBox[\((4)\),
          Derivative],
        MultilineFunction->None], "[", "x", "]"}]], "Output",
  CellLabel->"Out[136]="]
}, Open  ]],

Cell[TextData[StyleBox["The chain rule",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is smart about differentiation. For example, the following entry shows \
that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows the chain rule. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["D[g[x[t]],t]", "Input",
  CellLabel->"In[137]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["g", "\[Prime]",
          MultilineFunction->None], "[", \(x[t]\), "]"}], " ", 
      RowBox[{
        SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]], "Output",
  CellLabel->"Out[137]="]
}, Open  ]],

Cell["\<\
The output reads as \"the derivative of g evaluated at x(t), \
multiplied by the derivative of x(t) with respect to t\". This is the chain \
rule. The next entry illustrates one of many multivariable chain rule \
formulas: g is now a  function of two variables, x and y are each functions \
of one variable. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["D[g[x[t],y[t]],t]", "Input",
  CellLabel->"In[138]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
          SuperscriptBox["g", 
            TagBox[\((0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x[t], y[t]\), "]"}]}], "+", 
      RowBox[{
        RowBox[{
          SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
          SuperscriptBox["g", 
            TagBox[\((1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[t], y[t]\), 
          "]"}]}]}]], "Output",
  CellLabel->"Out[138]="]
}, Open  ]],

Cell[TextData[{
  "The expression ",
  Cell[BoxData[
      \(TraditionalForm\`g\^\((0, 1)\)\)]],
  "[x[t] , y[t] ] in the output is ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s way of denoting the partial derivative of g with respect to its second \
variable evaluated at the point ( x(t) , y(t) ). Similarly, ",
  Cell[BoxData[
      \(TraditionalForm\`g\^\((1, 0)\)\)]],
  "[x[t] , y[t] ] is the partial derivative of g with respect to its first \
variable evaluated at the point ( x(t) , y(t) )."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Here is one more example: g is a function of 3 variables. x and p \
are both functions of one variable. The input  asks for the derivative of g( \
x(p(t)), p(t), t ) with respect to t. The output is the chain rule formula \
for this  derivative. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["D[ g[x[p[t]],p[t],t],t]", "Input",
  CellLabel->"In[139]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["g", 
          TagBox[\((0, 0, 1)\),
            Derivative],
          MultilineFunction->None], "[", \(x[p[t]], p[t], t\), "]"}], "+", 
      RowBox[{
        RowBox[{
          SuperscriptBox["p", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
          SuperscriptBox["g", 
            TagBox[\((0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[p[t]], p[t], t\), "]"}]}], "+",
       
      RowBox[{
        RowBox[{
          SuperscriptBox["p", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
          SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", \(p[t]\), "]"}], " ", 
        RowBox[{
          SuperscriptBox["g", 
            TagBox[\((1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[p[t]], p[t], t\), 
          "]"}]}]}]], "Output",
  CellLabel->"Out[139]="]
}, Open  ]],

Cell[TextData[StyleBox["Just a little bit about differential equations",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Unevaluated derivatives are exactly what are needed to define a \
differential equation. The next entry defines  what is called a first order, \
linear, differential equation. The equation is given the name DE. Note the \
use of the double equals signifying that the equation is actually an \
identity, presumed valid for all t in some open interval.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["DE = y'[t] + y[t] == t", "Input",
  CellLabel->"In[143]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(y[t]\), "+", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
      "t"}]], "Output",
  CellLabel->"Out[143]="]
}, Open  ]],

Cell[TextData[{
  "The unknown function is ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", it is a function of the variable ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and everywhere it appears in the equation it must  be entered as y[t]. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "The next equation, named DE2, is called a Bernoulli equation. The unknown \
function is ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", it is also a function  of ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and must be entered as x[t]."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["DE2 = x'[t] + x[t] == t^2*x[t]^3", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(x[t]\), "+", 
        RowBox[{
          SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], 
      "\[Equal]", \(t\^2\ x[t]\^3\)}]], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows all about these equations. For example, it can solve both of them \
symbolically using a function called DSolve. To obtain the solution to DE \
just enter "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["DSolve[ DE. y, t ]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["DSolve[ DE, y, t ]", "Input",
  CellLabel->"In[145]:="],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{t}, \(-1\) + 
              t + \[ExponentialE]\^\(-t\)\ C[1]]}}\)], "Output",
  CellLabel->"Out[145]="]
}, Open  ]],

Cell["\<\
The output is the solution as a \"pure function\" in a form \
suitable for substitution. The symbol C[1] denotes an arbitrary constant that \
arises in the solution process. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
As a \"pure function\" the output can be substituted into \
expressions and turned into a named function easily. See below.\
\>", "Note"],

Cell["\<\
The next entry asks for the solution to DE2 satisfying the \
condition x(0) = 1. The solution equation is named  soln. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["soln = DSolve[ { DE2, x[0]==1 }, x, t ]", "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    RowBox[{\(DSolve::"bvnul"\), \(\(:\)\(\ \)\), "\<\"For some branches of \
the general solution, the given boundary conditions lead to an empty \
solution. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"DSolve::bvnul\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[4]:="],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, \@2\/\@\(1 + \[ExponentialE]\^\(2\ t\) + 2\ t + 2\ \
t\^2\)]}}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["\<\
Here is the graph of the solution. Note the use of the  /.  \
construction to substitute the solution into x[t].\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Plot[ x[t]/.soln, {t,-5,5} ]", "Input",
  CellLabel->"In[5]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.376258 [
[.11905 .00222 -6 -9 ]
[.11905 .00222 6 0 ]
[.30952 .00222 -6 -9 ]
[.30952 .00222 6 0 ]
[.69048 .00222 -3 -9 ]
[.69048 .00222 3 0 ]
[.88095 .00222 -3 -9 ]
[.88095 .00222 3 0 ]
[.4875 .10878 -24 -4.5 ]
[.4875 .10878 0 4.5 ]
[.4875 .20284 -18 -4.5 ]
[.4875 .20284 0 4.5 ]
[.4875 .29691 -24 -4.5 ]
[.4875 .29691 0 4.5 ]
[.4875 .39097 -6 -4.5 ]
[.4875 .39097 0 4.5 ]
[.4875 .48504 -24 -4.5 ]
[.4875 .48504 0 4.5 ]
[.4875 .5791 -18 -4.5 ]
[.4875 .5791 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01472 m
.11905 .02097 L
s
[(-4)] .11905 .00222 0 1 Mshowa
.30952 .01472 m
.30952 .02097 L
s
[(-2)] .30952 .00222 0 1 Mshowa
.69048 .01472 m
.69048 .02097 L
s
[(2)] .69048 .00222 0 1 Mshowa
.88095 .01472 m
.88095 .02097 L
s
[(4)] .88095 .00222 0 1 Mshowa
.125 Mabswid
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.07143 .01472 m
.07143 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .10878 m
.50625 .10878 L
s
[(0.25)] .4875 .10878 1 0 Mshowa
.5 .20284 m
.50625 .20284 L
s
[(0.5)] .4875 .20284 1 0 Mshowa
.5 .29691 m
.50625 .29691 L
s
[(0.75)] .4875 .29691 1 0 Mshowa
.5 .39097 m
.50625 .39097 L
s
[(1)] .4875 .39097 1 0 Mshowa
.5 .48504 m
.50625 .48504 L
s
[(1.25)] .4875 .48504 1 0 Mshowa
.5 .5791 m
.50625 .5791 L
s
[(1.5)] .4875 .5791 1 0 Mshowa
.125 Mabswid
.5 .03353 m
.50375 .03353 L
s
.5 .05234 m
.50375 .05234 L
s
.5 .07115 m
.50375 .07115 L
s
.5 .08997 m
.50375 .08997 L
s
.5 .12759 m
.50375 .12759 L
s
.5 .14641 m
.50375 .14641 L
s
.5 .16522 m
.50375 .16522 L
s
.5 .18403 m
.50375 .18403 L
s
.5 .22166 m
.50375 .22166 L
s
.5 .24047 m
.50375 .24047 L
s
.5 .25928 m
.50375 .25928 L
s
.5 .2781 m
.50375 .2781 L
s
.5 .31572 m
.50375 .31572 L
s
.5 .33453 m
.50375 .33453 L
s
.5 .35335 m
.50375 .35335 L
s
.5 .37216 m
.50375 .37216 L
s
.5 .40979 m
.50375 .40979 L
s
.5 .4286 m
.50375 .4286 L
s
.5 .44741 m
.50375 .44741 L
s
.5 .46622 m
.50375 .46622 L
s
.5 .50385 m
.50375 .50385 L
s
.5 .52266 m
.50375 .52266 L
s
.5 .54148 m
.50375 .54148 L
s
.5 .56029 m
.50375 .56029 L
s
.5 .59791 m
.50375 .59791 L
s
.5 .61673 m
.50375 .61673 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .09782 m
.06244 .10593 L
.10458 .11679 L
.14415 .12961 L
.18221 .14533 L
.22272 .16748 L
.26171 .19698 L
.28302 .21824 L
.30316 .24315 L
.32144 .27119 L
.34157 .31017 L
.36141 .35967 L
.38244 .42728 L
.40347 .50895 L
.41346 .54775 L
.42272 .57834 L
.42732 .58991 L
.42968 .5946 L
.43223 .59861 L
.43369 .60037 L
.43503 .60164 L
.43631 .60253 L
.43696 .60285 L
.43767 .60311 L
.4389 .60332 L
.44022 .6032 L
.44146 .60276 L
.4426 .60209 L
.44377 .60113 L
.44501 .5998 L
.44725 .59665 L
.44965 .5922 L
.4523 .58609 L
.4615 .55672 L
.5017 .38432 L
.52017 .31985 L
.54039 .26436 L
.56043 .22135 L
.58153 .18541 L
.62209 .13419 L
.66113 .09928 L
.70263 .0725 L
.74261 .05413 L
.78108 .04165 L
.80095 .03676 L
.822 .0325 L
.85988 .02676 L
.87933 .02456 L
.90022 .02264 L
.91997 .02116 L
Mistroke
.9415 .01986 L
.97619 .0183 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{158.75, 98.0625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000360000NR000`400?l00000o`00003oa_ooool0
0<Kooooo000Qooooo`;o000000?o410@ooooooooool06oooool5o`0003_ooooo1Ol0000Oooooo`;o
000000?o410@ooooooooool07?ooool002;ooooo00?o0000ooooooooool07?ooool01OnHV9So8B4Q
onk^k_ooooooA4A403_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Pooooo`03o`000?oooooooooo
01gooooo000Gooooo`Ko00000_ooool5o`0001Gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^03go
oooo00?oV9RHob4Q8Oo^k^h07_ooool5o`0001kooooo000Oooooo`04odA4A?oMgMgoooooo`00023o
oooo00?oV9RHob4Q8Oo^k^h0?Oooool00onHV9So8B4Qonk^kP0Mooooo`04odA4A?oMgMgoooooo`00
01oooooo000Oooooo`04omgMgOmEEEGoooooo`00027ooooo00?oMgMgofIVI_ooool0?Oooool00omg
MgOoIVIVooooo`0Looooo`04omgMgOmEEEGoooooo`0001oooooo000Pooooo`03ogMgMoo<c<co0000
02;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Looooo`03ogMgMoo<c<co0000
01oooooo000Pooooo`03onk^k_m4A4Co000001kooooo00Go0000okZj^_ooooooV9RHoa0@400koooo
o`05o`000?nj^[[ooooooiRHV?l@41007_ooool00oo^k^koA4A4o`00000Oooooo`008Oooool00omg
MgOo0000ooooo`0Mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0>oooool01OnHV9So410@o`000?lQ
8B7oc<c<01oooooo00?oMgMgo`000?ooool07_ooool00<Kooooo001Rooooo`03o`000?oooooooooo
067ooooo001Rooooo`03o`000?oooooooooo067ooooo0009oooookCo00002Oooool000gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool:o`0000gooooo000Nooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo2_l0000G
ooooo`00H_ooool00ol0003oooooooooo`0kooooo`Go00008Oooool006;ooooo0_l0000cooooo`Wo
00009_ooool006;ooooo00?o0000ooooooooool0;_ooool4o`0002oooooo001Rooooo`03o`000?oo
oooooooo02_ooooo0ol0000cooooo`00H_ooool2o`0002Wooooo0ol0000fooooo`00H_ooool00ol0
003oooooooooo`0Vooooo`;o0000>Oooool006;ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0iooooo`00H_ooool00ol0003oooooooooo`0Sooooo`;o0000??ooool006;ooooo0_l0
000Rooooo`;o0000?_ooool006;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0n
ooooo`00H_ooool00ol0003oooooooooo`0Nooooo`;o0000@Oooool006;ooooo0_l0000Mooooo`;o
0000@oooool000gooooo0ol0000aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo000@ooooo`?o0000;_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`02
ooooo`03o`000?oooooooooo01Wooooo0_l00016ooooo`004oooool4o`0002[ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooooooo0_l0
000Iooooo`03o`000?oooooooooo04Kooooo000Gooooo`?o00009oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`02ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0Aoooool001[ooooo1?l0000Sooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo000Nooooo`?o00008?oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0BOooool0027ooooo0ol0
000Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01Oooool2o`0001Gooooo00?o0000ooooooooool0B_ooool002Cooooo
0ol0000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00004ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Boooool002Oo
oooo0_l0000iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Boooool002Wooooo
0_l0000gooooo`;o00004oooool00ol0003oooooooooo`1<ooooo`00:oooool2o`0003Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1=ooooo`00;Oooool2o`0003?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1>ooooo`00;oooool2o`00037ooooo0_l0000@oooo
o`03o`000?oooooooooo04oooooo000aooooo`;o0000;oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04oooooo000cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1@ooooo`00=?ooool2o`0002cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1Aooooo`00=_ooool00ol0003oooooooooo`0Yooooo`;o00003Oooool0
0ol0003oooooooooo`1Booooo`00=oooool00ol0003oooooooooo`0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0D_ooool003Sooooo00?o0000ooooooooool03_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Cooooo`00>?ooool00ol0003oooooooooo`0>
ooooo`05oa0@4?ooooooooooooooool@41004?ooool01?l0003oooooooooooooool2o`0000_ooooo
00?o0000ooooooooool0E?ooool003Wooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo05Cooooo000jooooo`03o`000?oooooooooo00cooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05Gooooo000kooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`03o`000?oooooooooo05Ko
oooo000looooo`03o`000?oooooooooo00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`00
?Oooool00ol0003oooooooooo`09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`00?_ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eoooool003oooooo00?o
0000ooooooooool08?ooool2o`0000Oooooo00?o0000ooooooooool0F?ooool003oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo0010oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Ioooo
o`00@Oooool00ol0003oooooooooo`0Nooooo`;o00001_ooool00ol0003oooooooooo`1Iooooo`00
@Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
F_ooool004;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05[ooooo0012ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Jooooo`00@Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`;o00001?oo
ool00ol0003oooooooooo`1Kooooo`00@Oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05_ooooo0011ooooo`05oa0@4?ooooooooooo`000?l@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`1Kooooo`00@Oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`02ooooo`;o00000oooool00ol0003oooooooooo`1Looooo`00@Ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Looooo`00
@Oooool01_l@413ooooooooooooooooo410@o`0000gooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0G?ooool0047o
oooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000:ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`1Mooooo`00@Oooool0
1oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000002Oooool5o`0000Cooooo1?l00004ooooo`05o`00
0?ooooooooooooooool00000Goooool004Oooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
oooooooooooo000005oooooo0017ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`00001Oooooo`00B?ooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?ooool0
Goooool004Sooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0001Pooooo`00B?oo
ool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`00063ooooo0019ooooo`03o`000?oo
oooooooo01Kooooo0_l000000ooooooo0000ooooo`1Oooooo`00BOooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooo0000067ooooo0019ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ool00000HOooool004[ooooo00?o0000ooooooooool05Oooool3o`00067ooooo001:ooooo`03o`00
0?oooooooooo00gooooo1?l000001ol@413ooooooooooooooooo0000ooooool00000HOooool004[o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`;o0000H_ooool004_ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`;o0000H_ooool004_ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`;o0000H_ooool004_ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`03ooooo`;o0000H_ooool004cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo067ooooo001<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool2o`0006;ooooo001<ooooo`03o`00
0?oooooooooo00_ooooo00?oEEEEofIVI_l000001Oooool00ol0003oooooooooo`1Qooooo`00COoo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo067ooooo001=ooooo`03o`000?oooooo
oooo017ooooo0_l0001Sooooo`00COooool00ol0003oooooooooo`0Aooooo`?o0000H_ooool004go
oooo00?o0000ooooooooool04Oooool2o`0006?ooooo001>ooooo`03o`000?oooooooooo013ooooo
0_l0001Sooooo`00C_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo0000o`0006;ooooo
001>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool00000Hoooool004kooooo00?o0000
ooooooooool03oooool00ol0003oooooo`00001Sooooo`00Coooool00ol0003oooooooooo`0>oooo
o`04o`000?oooooo0000o`0006;ooooo0012ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@;ooooo00?o0000ooooool000001?l00004ooooo`06odA4A?l0003o0000oc8b<_oMgMgo00000_oo
ool00ol0003oooooooooo`1Qooooo`00A?ooool00ol0003oooooooooo`04ooooo`;o8B4Q0_ooool0
1ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8bo`000002ooooo`03o`00
0?oooooooooo067ooooo0014ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooonHV9So8B4Q
onk^kP09ooooo`;o00000_ooool00ol0003oooooooooo`1Qooooo`00A?ooool00ol0003ooooooooo
o`09ooooo`06o`000?oooooooooooiRHV?lQ8B7ok^k^1oooool00omgMgOo0000ooooo`02ooooo`;o
0000H_ooool004Cooooo00?o0000ooooooooool02Oooool01_l0003oooooooooooooooooMgMgofIV
IPCooooo00Go0000ob4Q8Ol0003o<S8bo`000003ooooo`03o`000?oooooooooo067ooooo0014oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Qooooo`00A?ooool00ol0
003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l0001Rooooo`00@_ooool00omEEEGoIVIVo`00000<ooooo`05o`000?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Cooooo00?o0000ooooooooool0HOooool0057ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo067ooooo001Aoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2o`0006;ooooo001Booooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`00
D_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool005;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo067ooooo001Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool2
o`0006;ooooo001Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Qooooo`00Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0HOooool005?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`;o0000H_ooool004[ooooo1?l000000ol@413oooooooooo`02ooooo`03ob4Q8Ol0
003ooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`03o`000?oooooooooo067ooooo
001<ooooo`03o`000?oooooooooo00Cooooo00?o8B4Qo`000?ooool01Oooool01?l0003oooooogMg
Molb<S83ooooo`03o`000?oooooooooo067ooooo001<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
HOooool004cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooogMgMolb<S800oooool2o`0006;ooooo001<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00?o0000ooooooooool0
HOooool004cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`0000Oooooo00?o
0000ooooooooool0HOooool004cooooo00?o0000ooooooooool01oooool00ol0003oooooo`000002
o`0000Oooooo0_l0001Rooooo`00B_ooool00omEEEGoIVIVo`00000:ooooo`;o000000?oooooo`00
0?l000000_l00004ooooo`03o`000?oooooooooo067ooooo001Rooooo`03o`000?oooooooooo067o
oooo001Rooooo`;o0000H_ooool00001\
\>"],
  ImageRangeCache->{{{77.875, 235.625}, {182.438, 85.375}} -> {-11.5095, \
1.38625, 0.0734259, 0.0185855}}]
}, Open  ]],

Cell[TextData[StyleBox["Working with the solution",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
The solution to DE2 satisfying x(0) = 1 is a transformation rule \
that can be used to plot the solution curve and obtain solution values. For \
example, to get the value of the solution when t = 2 we can substitute t -> 2 \
into the solution expression.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
x[t]/.soln/.t->2
N[%]\
\>", "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({\@\(2\/\(13 + \[ExponentialE]\^4\)\)}\)], "Output",
  CellLabel->"Out[8]="],

Cell[BoxData[
    \({0.1720075826664332`}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Getting at the solution formula",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\nSince soln is a list containing a list, soln[[1]] represents the inner \
list and soln[[1]][[1]] will be the transformation rule itself. This is the \
same as soln[[1,1]]. See below."
}], "Text"],

Cell[CellGroupData[{

Cell["soln[[1,1]]", "Input",
  CellLabel->"In[10]:=",
  ShowCellBracket->True],

Cell[BoxData[
    \(x \[Rule] 
      Function[{t}, \@2\/\@\(1 + \[ExponentialE]\^\(2\ t\) + 2\ t + 2\ \
t\^2\)]\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["\<\
Moreover, the first term in soln[[1,1]] is x and the second term is \
the solution in \"pure function\" form. \
\>", "Text"],

Cell[CellGroupData[{

Cell["soln[[1,1,2]]", "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(Function[{t}, \@2\/\@\(1 + \[ExponentialE]\^\(2\ t\) + 2\ t + 2\ \
t\^2\)]\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["Using this, a function g can be made as follows.", "Text"],

Cell["g := soln[[1,1,2]]", "Input",
  CellLabel->"In[12]:="],

Cell[CellGroupData[{

Cell["Plot[ g[t], {t,-5,5}]", "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.376258 [
[.11905 .00222 -6 -9 ]
[.11905 .00222 6 0 ]
[.30952 .00222 -6 -9 ]
[.30952 .00222 6 0 ]
[.69048 .00222 -3 -9 ]
[.69048 .00222 3 0 ]
[.88095 .00222 -3 -9 ]
[.88095 .00222 3 0 ]
[.4875 .10878 -24 -4.5 ]
[.4875 .10878 0 4.5 ]
[.4875 .20284 -18 -4.5 ]
[.4875 .20284 0 4.5 ]
[.4875 .29691 -24 -4.5 ]
[.4875 .29691 0 4.5 ]
[.4875 .39097 -6 -4.5 ]
[.4875 .39097 0 4.5 ]
[.4875 .48504 -24 -4.5 ]
[.4875 .48504 0 4.5 ]
[.4875 .5791 -18 -4.5 ]
[.4875 .5791 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01472 m
.11905 .02097 L
s
[(-4)] .11905 .00222 0 1 Mshowa
.30952 .01472 m
.30952 .02097 L
s
[(-2)] .30952 .00222 0 1 Mshowa
.69048 .01472 m
.69048 .02097 L
s
[(2)] .69048 .00222 0 1 Mshowa
.88095 .01472 m
.88095 .02097 L
s
[(4)] .88095 .00222 0 1 Mshowa
.125 Mabswid
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.07143 .01472 m
.07143 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .10878 m
.50625 .10878 L
s
[(0.25)] .4875 .10878 1 0 Mshowa
.5 .20284 m
.50625 .20284 L
s
[(0.5)] .4875 .20284 1 0 Mshowa
.5 .29691 m
.50625 .29691 L
s
[(0.75)] .4875 .29691 1 0 Mshowa
.5 .39097 m
.50625 .39097 L
s
[(1)] .4875 .39097 1 0 Mshowa
.5 .48504 m
.50625 .48504 L
s
[(1.25)] .4875 .48504 1 0 Mshowa
.5 .5791 m
.50625 .5791 L
s
[(1.5)] .4875 .5791 1 0 Mshowa
.125 Mabswid
.5 .03353 m
.50375 .03353 L
s
.5 .05234 m
.50375 .05234 L
s
.5 .07115 m
.50375 .07115 L
s
.5 .08997 m
.50375 .08997 L
s
.5 .12759 m
.50375 .12759 L
s
.5 .14641 m
.50375 .14641 L
s
.5 .16522 m
.50375 .16522 L
s
.5 .18403 m
.50375 .18403 L
s
.5 .22166 m
.50375 .22166 L
s
.5 .24047 m
.50375 .24047 L
s
.5 .25928 m
.50375 .25928 L
s
.5 .2781 m
.50375 .2781 L
s
.5 .31572 m
.50375 .31572 L
s
.5 .33453 m
.50375 .33453 L
s
.5 .35335 m
.50375 .35335 L
s
.5 .37216 m
.50375 .37216 L
s
.5 .40979 m
.50375 .40979 L
s
.5 .4286 m
.50375 .4286 L
s
.5 .44741 m
.50375 .44741 L
s
.5 .46622 m
.50375 .46622 L
s
.5 .50385 m
.50375 .50385 L
s
.5 .52266 m
.50375 .52266 L
s
.5 .54148 m
.50375 .54148 L
s
.5 .56029 m
.50375 .56029 L
s
.5 .59791 m
.50375 .59791 L
s
.5 .61673 m
.50375 .61673 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .09782 m
.06244 .10593 L
.10458 .11679 L
.14415 .12961 L
.18221 .14533 L
.22272 .16748 L
.26171 .19698 L
.28302 .21824 L
.30316 .24315 L
.32144 .27119 L
.34157 .31017 L
.36141 .35967 L
.38244 .42728 L
.40347 .50895 L
.41346 .54775 L
.42272 .57834 L
.42732 .58991 L
.42968 .5946 L
.43223 .59861 L
.43369 .60037 L
.43503 .60164 L
.43631 .60253 L
.43696 .60285 L
.43767 .60311 L
.4389 .60332 L
.44022 .6032 L
.44146 .60276 L
.4426 .60209 L
.44377 .60113 L
.44501 .5998 L
.44725 .59665 L
.44965 .5922 L
.4523 .58609 L
.4615 .55672 L
.5017 .38432 L
.52017 .31985 L
.54039 .26436 L
.56043 .22135 L
.58153 .18541 L
.62209 .13419 L
.66113 .09928 L
.70263 .0725 L
.74261 .05413 L
.78108 .04165 L
.80095 .03676 L
.822 .0325 L
.85988 .02676 L
.87933 .02456 L
.90022 .02264 L
.91997 .02116 L
Mistroke
.9415 .01986 L
.97619 .0183 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{166.75, 103},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003@0000P2000`400?l00000o`00003od?ooool0
0=3ooooo000Rooooo`;o000000?o410@ooooooooool07Oooool5o`0003oooooo1Ol0000Qooooo`;o
000000?o410@ooooooooool07Oooool002?ooooo00?o0000ooooooooool07_ooool01OnHV9So8B4Q
onk^k_ooooooA4A403oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Rooooo`03o`000?oooooooooo
01kooooo000Hooooo`Ko00000_ooool5o`0001Oooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^047o
oooo00?oV9RHob4Q8Oo^k^h08?ooool5o`0001oooooo000Pooooo`04odA4A?oMgMgoooooo`0002;o
oooo00?oV9RHob4Q8Oo^k^h0@Oooool00onHV9So8B4Qonk^kP0Oooooo`04odA4A?oMgMgoooooo`00
023ooooo000Pooooo`04omgMgOmEEEGoooooo`0002?ooooo00?oMgMgofIVI_ooool0@Oooool00omg
MgOoIVIVooooo`0Nooooo`04omgMgOmEEEGoooooo`00023ooooo000Qooooo`03ogMgMoo<c<co0000
02Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Nooooo`03ogMgMoo<c<co0000
023ooooo000Qooooo`03onk^k_m4A4Co0000023ooooo00Go0000okZj^_ooooooV9RHoa0@400ooooo
o`05o`000?nj^[[ooooooiRHV?l@41008?ooool00oo^k^koA4A4o`00000Pooooo`008_ooool00omg
MgOo0000ooooo`0Oooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0?oooool01OnHV9So410@o`000?lQ
8B7oc<c<027ooooo00?oMgMgo`000?ooool07oooool00=3ooooo001Wooooo`03o`000?oooooooooo
06Kooooo001Wooooo`03o`000?oooooooooo06Kooooo0009oooookko00002Oooool000gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool:o`0000kooooo000Oooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01oooooo3?l0000G
ooooo`00Ioooool00ol0003oooooooooo`0nooooo`Go00008oooool006Oooooo0_l0000iooooo`Ko
0000:?ooool006Oooooo00?o0000ooooooooool0<Oooool7o`0002kooooo001Wooooo`03o`000?oo
oooooooo02kooooo0ol0000eooooo`00Ioooool2o`0002gooooo0_l0000hooooo`00Ioooool00ol0
003oooooooooo`0Zooooo`;o0000>_ooool006Oooooo00?o0000ooooooooool09oooool3o`0003co
oooo001Wooooo`03o`000?oooooooooo02Gooooo0_l0000oooooo`00Ioooool2o`0002Cooooo0_l0
0011ooooo`00Ioooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo047ooooo001Woooo
o`03o`000?oooooooooo023ooooo0_l00014ooooo`00Ioooool00ol0003oooooooooo`0Nooooo`;o
0000A_ooool006Oooooo0_l0000Nooooo`03o`000?oooooooooo04Kooooo000=ooooo`?o0000=_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00?ooooo00?o0000ooooooooool06oooool2o`0004Wooooo000@ooooo`?o0000
<oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0BOooool001?ooooo1?l0000_ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP09ooooo`04o`000?ooooooooooooooo`;o00006_ooool00ol0003oooooooooo`1:
ooooo`005oooool4o`0002_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo04_ooooo000Kooooo`Co00009oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1<ooooo`007oooool4o`0002?ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04gooooo000Sooooo`?o00008?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Gooooo
0_l0000Fooooo`03o`000?oooooooooo04kooooo000Vooooo`?o00007Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo04oooooo000Yooooo`;o0000??ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo04oooooo000[ooooo`;o0000>_ooool2o`0001Cooooo00?o
0000ooooooooool0D?ooool002gooooo0_l0000hooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0DOooool002oooooo0_l0000fooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0DOooool0037ooooo0_l0000dooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0D_ooool003?ooooo0_l0000booooo`;o00004Oooool00ol0003oooooooooo`1Cooooo`00=Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0E?oo
ool003Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo05Cooooo000gooooo`03o`000?oooooooooo02gooooo0_l0000?ooooo`03o`000?oooooooooo
05Gooooo000hooooo`03o`000?oooooooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1Fooooo`00>Oooool00ol0003oooooooooo`0Booooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo05Kooooo000jooooo`03o`000?oooooooooo017ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`1Gooooo`00>oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`02ooooo`;o00003?ooool00ol0003oooooooooo`1Hooooo`00??ooool0
0ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Hooooo`00?Ooo
ool00ol0003oooooooooo`0>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0FOooool003kooooo00?o
0000ooooooooool03Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05[ooooo000nooooo`03o`000?oo
oooooooo00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool2o`0000[ooooo
00?o0000ooooooooool0F_ooool003oooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05_ooooo0010ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Kooooo`00@Oooool00ol0003oooooooooo`0Soooo
o`;o00002?ooool00ol0003oooooooooo`1Looooo`00@_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0G?ooool004;ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05cooooo0013ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`00A?ooool0
0ol0003oooooooooo`0Pooooo`;o00001oooool00ol0003oooooooooo`1Mooooo`00A?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G_ooool004Go
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05ko
oooo0015ooooo`03o`000?oooooooooo01oooooo0_l00005ooooo`03o`000?oooooooooo05oooooo
0016ooooo`05o`000?lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Oooooo`00A_ooool01Ol0003oV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05oooooo0016ooooo`05oa0@4?l0003oooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`1Poooo
o`00A_ooool01Ol0003oooooo`000?oooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`02ooooo`;o00001?ooool00ol0003oooooooooo`1Pooooo`00A_ooool01Ol0003o
ooooo`000?oooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`00A_ooool01Ol@
413oooooooooool0003o410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool004Kooooo00GoMgMgoiRH
V?oooooo0000ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`05ooooo`;o00000oooool00ol0003oooooooooo`1Qooooo`00A_ooool01Oo^k^ko<S8bo`000?lb
<S;o000000_ooooo1Ol00004ooooo`Co00001?ooool01Ol0003ooooooooooooooooo000006Cooooo
001:ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00001Tooooo`00B_oo
ool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000I?ooool004_ooooo00?o
0000ooooooooool06Oooool2o`000003ooooool0003ooooo06Cooooo001;ooooo`03o`000?oooooo
oooo01Wooooo00Co0000oooooooooooo0000IOooool004cooooo00?o0000ooooooooool06?ooool0
1?l0003oooooooooool0001Uooooo`00C?ooool00ol0003oooooooooo`0Hooooo`;o000000?ooooo
o`000?ooool0I?ooool004cooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00001Voooo
o`00COooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo000006Kooooo001=ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooool00000I_ooool004kooooo00?o0000ooooooooool05_oo
ool3o`0006Kooooo001>ooooo`03o`000?oooooooooo00kooooo1?l000001?l@413ooooooooooooo
ool2o`0006Oooooo001>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool2
o`0006Oooooo001?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool2o`00
06Oooooo001?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool2o`0006Oo
oooo001?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Vooooo`00D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0I_ooool0053ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03
ooooo`;o0000Ioooool0053ooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`000005oooo
o`03o`000?oooooooooo06Kooooo001Aooooo`03o`000?oooooooooo01;ooooo0_l0001Xooooo`00
DOooool00ol0003oooooooooo`0Booooo`;o0000J?ooool0057ooooo00?o0000ooooooooool04_oo
ool3o`0006Oooooo001Aooooo`03o`000?oooooooooo01;ooooo0_l0001Xooooo`00D_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooo000006Sooooo001Booooo`03o`000?oooooooooo013o
oooo00Co0000ooooool0003o0000Ioooool005;ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooo`00001Xooooo`00D_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000006Sooooo
001Cooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000J?ooool005?ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02o`0006Oooooo0017ooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@04ooooool0003oooooooooo`Go00001?ooool01_m4A4Co0000o`00
0?lb<S;ogMgMo`0000;ooooo00?o0000ooooooooool0I_ooool004Wooooo00?o0000ooooooooool0
1?ooool2ob4Q8@09ooooool0003ooooooooooonHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_l000000_ooool00ol0003oooooooooo`1Vooooo`00BOooool00ol0003oooooooooo`08oooo
o`06o`000?oooooooooooiRHV?lQ8B7ok^k^2Oooool2o`0000;ooooo0_l0001Wooooo`00BOooool0
0ol0003oooooooooo`08ooooo`07o`000?oooooooooooooooonHV9So8B4Qonk^kP07ooooo`03ogMg
Mol0003ooooo00;ooooo00?o0000ooooooooool0I_ooool004Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`02ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
o`000003ooooo`03o`000?oooooooooo06Kooooo0019ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`1Vooooo`00BOooool00ol0003oooooooooo`09ooooo`;o000000Co
^[ZjoooooonHV9So410@1?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l0001Wooooo`00
Aoooool00omEEEGoIVIVo`00000;ooooo`06o`000?nHV9So410@o`000?lQ8B7oc<c<1?ooool4o`00
00Cooooo00?o0000ooooooooool0I_ooool005Gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06Kooooo001Eooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00_ooool2o`0006Oooooo001Fooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Vooooo`00E_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I_ooool005Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Kooooo001Gooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`0006Oooooo001Gooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Vooooo`00Eooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I_oo
ool005Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06Kooooo001Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`00
06Oooooo001?ooooo`Co000000?o410@ooooooooool00_ooool00ol0003o8B4Qooooo`04ooooo`?o
000000?o<S8bomgMgOooool00_ooool00ol0003oooooooooo`1Vooooo`00DOooool00ol0003ooooo
ooooo`04ooooo`03ob4Q8Ol0003ooooo00Cooooo00Go0000ooooooooooooMgMgoc8b<P03ooooo`03
o`000?oooooooooo06Kooooo001Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000?ooooo0_l0001Wooooo`00DOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooogMgMolb<S83oooo
o`03o`000?oooooooooo06Kooooo001Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool2o`000004ob4Q8Ol0003o<S8bolc<c0?ooooo00?o0000ooooooooool0I_ooool0057o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03o`0000Oooooo00?o0000oooooooo
ool0I_ooool0057ooooo00?o0000ooooooooool01_ooool4o`000003ooooool0003ooooo00Kooooo
0_l0001Wooooo`00Coooool00omEEEGoIVIVo`000009ooooo`;o00000_ooool4o`0000Cooooo00?o
0000ooooooooool0I_ooool006Oooooo00?o0000ooooooooool0I_ooool006Oooooo0_l0001Woooo
o`00\
\>"],
  ImageRangeCache->{{{77.875, 243.625}, {187.375, 85.375}} -> {-11.1766, \
1.31089, 0.0695276, 0.0175988}}]
}, Open  ]],

Cell[TextData[{
  "With g, and the graph above, let's find the positive ",
  StyleBox["t",
    FontSlant->"Italic"],
  " value such that ",
  StyleBox["g",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = 0.4. "
}], "Text"],

Cell[CellGroupData[{

Cell["FindRoot[ g[t]==0.4, {t,2}]", "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({t \[Rule] 1.005316564268866`}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["And here we check the solution.", "Text"],

Cell[CellGroupData[{

Cell["g[t]/.%", "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(0.39999999999999997`\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{767, 786},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->23,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, None, None}, {None, None, None}},
PageFooters->{{None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "   Page  ", 
          CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "   Page  ", 
          CounterBox[ "Page"]}], "Footer"], None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1.25,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 1078, 34, 208, "Text"],
Cell[2835, 87, 148, 3, 35, "Text"],
Cell[2986, 92, 320, 13, 34, "Text"],
Cell[3309, 107, 270, 10, 34, "Text"],
Cell[3582, 119, 234, 6, 58, "Text"],
Cell[3819, 127, 60, 1, 39, "Input"],
Cell[3882, 130, 576, 10, 130, "Text"],
Cell[4461, 142, 174, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[4660, 151, 81, 4, 65, "Input"],
Cell[4744, 157, 92, 2, 35, "Output"],
Cell[4839, 161, 133, 3, 35, "Output"]
}, Open  ]],
Cell[4987, 167, 138, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[5150, 176, 62, 1, 39, "Input"],
Cell[5215, 179, 13830, 433, 136, 4479, 313, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[19060, 615, 296, 11, 60, "Text"],

Cell[CellGroupData[{
Cell[19381, 630, 47, 1, 39, "Input"],
Cell[19431, 633, 86, 2, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19554, 640, 48, 1, 39, "Input"],
Cell[19605, 643, 98, 2, 36, "Output"]
}, Open  ]],
Cell[19718, 648, 151, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[19894, 657, 60, 4, 65, "Input"],
Cell[19957, 663, 80, 2, 35, "Output"],
Cell[20040, 667, 78, 2, 35, "Output"]
}, Open  ]],
Cell[20133, 672, 262, 7, 70, "Text"],
Cell[20398, 681, 71, 1, 39, "Input"],
Cell[20472, 684, 187, 5, 58, "Text"],

Cell[CellGroupData[{
Cell[20684, 693, 59, 4, 65, "Input"],
Cell[20746, 699, 116, 2, 35, "Output"],
Cell[20865, 703, 155, 3, 35, "Output"]
}, Open  ]],
Cell[21035, 709, 154, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[21214, 718, 70, 1, 39, "Input"],
Cell[21287, 721, 13390, 479, 113, 5274, 372, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[34692, 1203, 186, 5, 58, "Text"],
Cell[34881, 1210, 395, 6, 40, "Text"],

Cell[CellGroupData[{
Cell[35301, 1220, 191, 4, 65, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[35495, 1226, 13190, 458, 122, 4979, 348, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[48700, 1687, 154, 4, 35, "Text"],
Cell[48857, 1693, 277, 6, 58, "Text"],
Cell[49137, 1701, 74, 1, 39, "Input"],
Cell[49214, 1704, 303, 7, 82, "Text"],
Cell[49520, 1713, 182, 5, 91, "Input"],
Cell[49705, 1720, 251, 6, 58, "Text"],

Cell[CellGroupData[{
Cell[49981, 1730, 179, 5, 91, "Input"],
Cell[50163, 1737, 19311, 968, 141, 10170, 850, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[69489, 2708, 353, 7, 82, "Text"],

Cell[CellGroupData[{
Cell[69867, 2719, 448, 11, 247, "Input"],
Cell[70318, 2732, 19942, 845, 152, 9288, 708, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[90275, 3580, 156, 4, 35, "Text"],
Cell[90434, 3586, 503, 25, 34, "Text"],
Cell[90940, 3613, 247, 6, 54, "Text"],
Cell[91190, 3621, 171, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[91386, 3630, 116, 2, 39, "Input"],
Cell[91505, 3634, 67, 2, 35, "Output"]
}, Open  ]],
Cell[91587, 3639, 242, 8, 58, "Text"],

Cell[CellGroupData[{
Cell[91854, 3651, 92, 1, 39, "Input"],
Cell[91949, 3654, 77, 2, 35, "Output"]
}, Open  ]],
Cell[92041, 3659, 190, 7, 35, "Text"],
Cell[92234, 3668, 305, 7, 82, "Text"],
Cell[92542, 3677, 98, 2, 34, "Text"],
Cell[92643, 3681, 151, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[92819, 3690, 143, 5, 91, "Input"],
Cell[92965, 3697, 77, 2, 35, "Output"]
}, Open  ]],
Cell[93057, 3702, 501, 9, 130, "Text"],

Cell[CellGroupData[{
Cell[93583, 3715, 119, 4, 91, "Input"],
Cell[93705, 3721, 77, 2, 35, "Output"]
}, Open  ]],
Cell[93797, 3726, 263, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[94085, 3737, 445, 11, 247, "Input"],
Cell[94533, 3750, 13091, 363, 155, 4438, 251, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[107639, 4116, 236, 6, 58, "Text"],

Cell[CellGroupData[{
Cell[107900, 4126, 439, 11, 247, "Input"],
Cell[108342, 4139, 13149, 307, 167, 3287, 180, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[121506, 4449, 163, 5, 34, "Text"],
Cell[121672, 4456, 147, 4, 35, "Text"],
Cell[121822, 4462, 306, 10, 58, "Text"],
Cell[122131, 4474, 180, 5, 58, "Text"],
Cell[122314, 4481, 155, 6, 37, "Text"],
Cell[122472, 4489, 99, 2, 39, "Input"],
Cell[122574, 4493, 148, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[122747, 4502, 96, 2, 39, "Input"],
Cell[122846, 4506, 18821, 516, 152, 4874, 339, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[141682, 5025, 310, 9, 58, "Text"],

Cell[CellGroupData[{
Cell[142017, 5038, 112, 2, 39, "Input"],
Cell[142132, 5042, 78, 2, 35, "Output"]
}, Open  ]],
Cell[142225, 5047, 263, 6, 58, "Text"],

Cell[CellGroupData[{
Cell[142513, 5057, 90, 2, 39, "Input"],
Cell[142606, 5061, 398, 7, 69, "Message"],
Cell[143007, 5070, 74, 2, 35, "Output"]
}, Open  ]],
Cell[143096, 5075, 328, 8, 58, "Text"],

Cell[CellGroupData[{
Cell[143449, 5087, 100, 2, 39, "Input"],
Cell[143552, 5091, 90, 2, 35, "Output"]
}, Open  ]],
Cell[143657, 5096, 39, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[143721, 5100, 76, 2, 39, "Input"],
Cell[143800, 5104, 78, 2, 35, "Output"]
}, Open  ]],
Cell[143893, 5109, 107, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[144025, 5115, 146, 5, 65, "Input"],
Cell[144174, 5122, 78, 2, 35, "Output"]
}, Open  ]],
Cell[144267, 5127, 285, 10, 58, "Text"],
Cell[144555, 5139, 146, 4, 35, "Text"],
Cell[144704, 5145, 381, 10, 82, "Text"],

Cell[CellGroupData[{
Cell[145110, 5159, 81, 2, 39, "Input"],
Cell[145194, 5163, 105, 2, 36, "Output"]
}, Open  ]],
Cell[145314, 5168, 258, 6, 58, "Text"],
Cell[145575, 5176, 120, 2, 39, "Input"],
Cell[145698, 5180, 219, 6, 58, "Text"],

Cell[CellGroupData[{
Cell[145942, 5190, 85, 5, 65, "Input"],
Cell[146030, 5197, 181, 3, 77, "Output"],
Cell[146214, 5202, 208, 4, 36, "Output"]
}, Open  ]],
Cell[146437, 5209, 108, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[146570, 5215, 96, 2, 39, "Input"],
Cell[146669, 5219, 18064, 531, 139, 5387, 369, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[164748, 5753, 469, 11, 106, "Text"],

Cell[CellGroupData[{
Cell[165242, 5768, 161, 4, 91, "Input"],
Cell[165406, 5774, 24580, 696, 171, 5976, 461, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[190001, 6473, 288, 7, 82, "Text"],

Cell[CellGroupData[{
Cell[190314, 6484, 114, 6, 91, "Input"],
Cell[190431, 6492, 652, 22, 59, "Output"],
Cell[191086, 6516, 172, 3, 60, "Output"],
Cell[191261, 6521, 208, 4, 36, "Output"]
}, Open  ]],
Cell[191484, 6528, 151, 4, 35, "Text"],
Cell[191638, 6534, 247, 7, 58, "Text"],

Cell[CellGroupData[{
Cell[191910, 6545, 73, 2, 39, "Input"],
Cell[191986, 6549, 152, 4, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192175, 6558, 77, 2, 39, "Input"],
Cell[192255, 6562, 152, 4, 35, "Output"]
}, Open  ]],
Cell[192422, 6569, 110, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[192557, 6575, 76, 2, 39, "Input"],
Cell[192636, 6579, 188, 6, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192861, 6590, 81, 2, 39, "Input"],
Cell[192945, 6594, 188, 6, 36, "Output"]
}, Open  ]],
Cell[193148, 6603, 142, 4, 35, "Text"],
Cell[193293, 6609, 291, 10, 58, "Text"],

Cell[CellGroupData[{
Cell[193609, 6623, 80, 2, 39, "Input"],
Cell[193692, 6627, 292, 8, 35, "Output"]
}, Open  ]],
Cell[193999, 6638, 379, 8, 82, "Text"],

Cell[CellGroupData[{
Cell[194403, 6650, 85, 2, 39, "Input"],
Cell[194491, 6654, 700, 21, 36, "Output"]
}, Open  ]],
Cell[195206, 6678, 574, 15, 82, "Text"],
Cell[195783, 6695, 317, 7, 82, "Text"],

Cell[CellGroupData[{
Cell[196125, 6706, 91, 2, 39, "Input"],
Cell[196219, 6710, 1027, 30, 60, "Output"]
}, Open  ]],
Cell[197261, 6743, 174, 4, 35, "Text"],
Cell[197438, 6749, 421, 8, 106, "Text"],

Cell[CellGroupData[{
Cell[197884, 6761, 65, 1, 39, "Input"],
Cell[197952, 6764, 235, 7, 35, "Output"]
}, Open  ]],
Cell[198202, 6774, 306, 10, 58, "Text"],
Cell[198511, 6786, 320, 11, 58, "Text"],

Cell[CellGroupData[{
Cell[198856, 6801, 73, 1, 39, "Input"],
Cell[198932, 6804, 247, 7, 36, "Output"]
}, Open  ]],
Cell[199194, 6814, 293, 8, 58, "Text"],
Cell[199490, 6824, 125, 3, 35, "Text"],

Cell[CellGroupData[{
Cell[199640, 6831, 61, 1, 39, "Input"],
Cell[199704, 6834, 157, 4, 36, "Output"]
}, Open  ]],
Cell[199876, 6841, 245, 6, 58, "Text"],
Cell[200124, 6849, 147, 3, 47, "Note"],
Cell[200274, 6854, 190, 5, 58, "Text"],

Cell[CellGroupData[{
Cell[200489, 6863, 80, 1, 39, "Input"],
Cell[200572, 6866, 365, 6, 50, "Message"],
Cell[200940, 6874, 157, 4, 66, "Output"]
}, Open  ]],
Cell[201112, 6881, 183, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[201320, 6890, 69, 1, 39, "Input"],
Cell[201392, 6893, 16516, 450, 133, 3967, 290, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[217923, 7346, 153, 4, 35, "Text"],
Cell[218079, 7352, 325, 7, 82, "Text"],

Cell[CellGroupData[{
Cell[218429, 7363, 70, 4, 65, "Input"],
Cell[218502, 7369, 96, 2, 69, "Output"],
Cell[218601, 7373, 79, 2, 35, "Output"]
}, Open  ]],
Cell[218695, 7378, 312, 7, 95, "Text"],

Cell[CellGroupData[{
Cell[219032, 7389, 78, 2, 39, "Input"],
Cell[219113, 7393, 150, 4, 66, "Output"]
}, Open  ]],
Cell[219278, 7400, 134, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[219437, 7407, 55, 1, 39, "Input"],
Cell[219495, 7410, 133, 3, 66, "Output"]
}, Open  ]],
Cell[219643, 7416, 64, 0, 34, "Text"],
Cell[219710, 7418, 60, 1, 39, "Input"],

Cell[CellGroupData[{
Cell[219795, 7423, 63, 1, 39, "Input"],
Cell[219861, 7426, 16971, 456, 139, 3967, 290, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[236847, 7885, 256, 11, 34, "Text"],

Cell[CellGroupData[{
Cell[237128, 7900, 69, 1, 39, "Input"],
Cell[237200, 7903, 89, 2, 35, "Output"]
}, Open  ]],
Cell[237304, 7908, 47, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[237376, 7912, 49, 1, 39, "Input"],
Cell[237428, 7915, 79, 2, 35, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

