(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    318271,      13813]*)
(*NotebookOutlinePosition[    320446,      13878]*)
(*  CellTagsIndexPosition[    320402,      13874]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part III. ", "Section"],
  StyleBox["First Order Ordinary Differential Equations", "Section"],
  "\n",
  StyleBox["Section 1. Entering, Solving, Plotting", "Subsection"],
  "\nHere begins a more formal introduction to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and differential equations. If you have only skimmed over  Parts I and \
II, please review the discussion of differential equations found on the last \
three pages of Part II,  Section 3. In this section three first order \
equations are used to illustrate some of the features of the DSolve  \
function, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s primary tool for generating solutions to ordinary differential \
equations. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Occasional references to \"Ledder\" refer to the \
textbook entitled", "Note"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Differential Equations: A Modeling Approach", "Note",
  FontSlant->"Italic"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["by Glenn Ledder, McGraw-Hill, 2005.", "Note"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Solve this: DSolve", "Subsubsection"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "It is good practice to assign a name to a differential equation before \
beginning an analysis. Names should also be assigned to solutions. A \
differential equation for  ",
  StyleBox["y",
    FontSlant->"Italic"],
  " as a function of ",
  StyleBox["t",
    FontSlant->"Italic"],
  " is entered using unevaluated derivatives. All appearances of the function \
 ",
  StyleBox["y",
    FontSlant->"Italic"],
  " must be in the form y[t]. The equation must be entered as an identity \
(using two equal signs). See the following example."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["DE = y'[t] == y[t]/(t^2 + 1)", "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(y[t]\/\(1 + t\^2\)\)}]], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell["There are two ways to generate a solution. ", "Text"],

Cell[TextData[{
  StyleBox["Method 1",
    FontVariations->{"Underline"->True}],
  ". Enter   DSolve[ DE, y[t], t ]\n",
  StyleBox["Method 2",
    FontVariations->{"Underline"->True}],
  ". Enter DSolve[ DE, y, t ]"
}], "Text"],

Cell["\<\
The output for the first entry is named soln1. The output for the \
second is called soln2.\
\>", "Text"],

Cell[CellGroupData[{

Cell["soln1 = DSolve[ DE, y[t], t ]", "Input",
  CellLabel->"In[18]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{y[t] \[Rule] \[ExponentialE]\^ArcTan[t]\ C[1]}}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["soln2 = DSolve[ DE, y, t ]", "Input",
  CellLabel->"In[19]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{t}, \[ExponentialE]\^ArcTan[t]\ C[1]]}}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["\<\
Observe that both formulas for the general solution display the \
integration constant as C[1]. This choice  of notation is intentional to \
avoid conflicts with variables that may already be assigned in the worksheet. \
 
Note also that both solutions are in the form of a substitution rule. The \
first solution is a substitution for y[t] and the second is a substitution \
for y. The second form is called a \"pure function\" and it is the one we \
will  use most often. This is because it is easier to manipulate. For example \
it can be used to quickly check the validity of the solution.\
\>", "Text"],

Cell[TextData[StyleBox["Checking the solution",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
The solution can be checked by substitution of soln2 into DE. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell["DE/.soln2", "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({True}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[TextData[{
  "If soln2 is substituted ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not evaluate the derivative in the identity."
}], "Text"],

Cell[CellGroupData[{

Cell["DE/.soln1", "Input",
  CellLabel->"In[21]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], 
        "\[Equal]", \(\(\[ExponentialE]\^ArcTan[t]\ C[1]\)\/\(1 + t\^2\)\)}], 
      "}"}]], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[StyleBox["Plotting solution curves",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
Given the general solution, the Table function can be used to plot \
several solution curves. It is first necessary to replace C[1] with some \
other symbol, like c, because C[1] is protected. (We work with soln2.)\
\>", \
"Text"],

Cell[CellGroupData[{

Cell["soln2[[1,1]]/.C[1]->c", "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(y \[Rule] Function[{t}, \[ExponentialE]\^ArcTan[t]\ c]\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["\<\
The following  plot shows the solutions to DE when c= -3, -2, -1, \
0, 1, 2, 3. The Evaluate function is applied to Table to force evaluation of \
the functions so points can be plotted. The plot is named P1 so it can be \
shown again later. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
P1 = Plot[ Evaluate[Table[y[t]/.%, {c,-3,3}]], 
           {t,-2,2}]\
\>", "Input",
  CellLabel->"In[23]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.0324223 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .06585 -24 -4.5 ]
[.4875 .06585 0 4.5 ]
[.4875 .14691 -12 -4.5 ]
[.4875 .14691 0 4.5 ]
[.4875 .22796 -24 -4.5 ]
[.4875 .22796 0 4.5 ]
[.4875 .39007 -18 -4.5 ]
[.4875 .39007 0 4.5 ]
[.4875 .47113 -6 -4.5 ]
[.4875 .47113 0 4.5 ]
[.4875 .55218 -18 -4.5 ]
[.4875 .55218 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-1)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .06585 m
.50625 .06585 L
s
[(-7.5)] .4875 .06585 1 0 Mshowa
.5 .14691 m
.50625 .14691 L
s
[(-5)] .4875 .14691 1 0 Mshowa
.5 .22796 m
.50625 .22796 L
s
[(-2.5)] .4875 .22796 1 0 Mshowa
.5 .39007 m
.50625 .39007 L
s
[(2.5)] .4875 .39007 1 0 Mshowa
.5 .47113 m
.50625 .47113 L
s
[(5)] .4875 .47113 1 0 Mshowa
.5 .55218 m
.50625 .55218 L
s
[(7.5)] .4875 .55218 1 0 Mshowa
.125 Mabswid
.5 .08206 m
.50375 .08206 L
s
.5 .09827 m
.50375 .09827 L
s
.5 .11448 m
.50375 .11448 L
s
.5 .13069 m
.50375 .13069 L
s
.5 .16312 m
.50375 .16312 L
s
.5 .17933 m
.50375 .17933 L
s
.5 .19554 m
.50375 .19554 L
s
.5 .21175 m
.50375 .21175 L
s
.5 .24417 m
.50375 .24417 L
s
.5 .26038 m
.50375 .26038 L
s
.5 .27659 m
.50375 .27659 L
s
.5 .29281 m
.50375 .29281 L
s
.5 .32523 m
.50375 .32523 L
s
.5 .34144 m
.50375 .34144 L
s
.5 .35765 m
.50375 .35765 L
s
.5 .37386 m
.50375 .37386 L
s
.5 .40628 m
.50375 .40628 L
s
.5 .42249 m
.50375 .42249 L
s
.5 .43871 m
.50375 .43871 L
s
.5 .45492 m
.50375 .45492 L
s
.5 .48734 m
.50375 .48734 L
s
.5 .50355 m
.50375 .50355 L
s
.5 .51976 m
.50375 .51976 L
s
.5 .53597 m
.50375 .53597 L
s
.5 .04964 m
.50375 .04964 L
s
.5 .03343 m
.50375 .03343 L
s
.5 .01722 m
.50375 .01722 L
s
.5 .00101 m
.50375 .00101 L
s
.5 .5684 m
.50375 .5684 L
s
.5 .58461 m
.50375 .58461 L
s
.5 .60082 m
.50375 .60082 L
s
.5 .61703 m
.50375 .61703 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .27687 m
.06244 .27574 L
.10458 .27425 L
.14415 .27255 L
.18221 .27056 L
.22272 .26791 L
.26171 .26469 L
.30316 .26027 L
.34309 .2547 L
.3815 .24773 L
.42237 .23805 L
.46172 .22608 L
.49955 .21193 L
.53984 .19421 L
.57861 .17522 L
.61984 .15397 L
.65954 .13348 L
.69774 .1145 L
.73838 .09556 L
.77751 .07877 L
.81909 .06255 L
.85916 .04845 L
.89771 .0362 L
.93871 .02443 L
.97619 .01472 L
s
.02381 .28759 m
.06244 .28683 L
.10458 .28584 L
.14415 .28471 L
.18221 .28338 L
.22272 .28161 L
.26171 .27946 L
.30316 .27652 L
.34309 .27281 L
.3815 .26816 L
.42237 .2617 L
.46172 .25373 L
.49955 .24429 L
.53984 .23248 L
.57861 .21982 L
.61984 .20565 L
.65954 .192 L
.69774 .17934 L
.73838 .16671 L
.77751 .15552 L
.81909 .14471 L
.85916 .13531 L
.89771 .12714 L
.93871 .1193 L
.97619 .11282 L
s
.02381 .2983 m
.06244 .29792 L
.10458 .29743 L
.14415 .29686 L
.18221 .2962 L
.22272 .29531 L
.26171 .29424 L
.30316 .29277 L
.34309 .29091 L
.3815 .28859 L
.42237 .28536 L
.46172 .28137 L
.49955 .27666 L
.53984 .27075 L
.57861 .26442 L
.61984 .25733 L
.65954 .25051 L
.69774 .24418 L
.73838 .23786 L
.77751 .23227 L
.81909 .22686 L
.85916 .22216 L
.89771 .21808 L
.93871 .21416 L
.97619 .21092 L
s
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07103 .30902 L
.07173 .30902 L
.073 .30902 L
Mistroke
.07376 .30902 L
.07448 .30902 L
.07513 .30902 L
.07583 .30902 L
.0766 .30902 L
.0774 .30902 L
.07809 .30902 L
.07885 .30902 L
.07956 .30902 L
.0802 .30902 L
.08095 .30902 L
.08166 .30902 L
.08291 .30902 L
.08362 .30902 L
.08427 .30902 L
.08544 .30902 L
.08669 .30902 L
.08787 .30902 L
.08896 .30902 L
.09016 .30902 L
.09148 .30902 L
.09214 .30902 L
.09285 .30902 L
.09413 .30902 L
.09483 .30902 L
.09548 .30902 L
.09619 .30902 L
.09695 .30902 L
.09821 .30902 L
.09893 .30902 L
.09961 .30902 L
.10086 .30902 L
.10201 .30902 L
.10333 .30902 L
.10458 .30902 L
.10572 .30902 L
.10694 .30902 L
.1081 .30902 L
.10916 .30902 L
.11033 .30902 L
.11162 .30902 L
.11227 .30902 L
.11297 .30902 L
.11422 .30902 L
.11491 .30902 L
.11554 .30902 L
.11624 .30902 L
.11698 .30902 L
.11822 .30902 L
.11892 .30902 L
Mistroke
.11958 .30902 L
.12081 .30902 L
.12194 .30902 L
.12323 .30902 L
.12446 .30902 L
.12562 .30902 L
.12668 .30902 L
.12789 .30902 L
.12903 .30902 L
.13009 .30902 L
.13107 .30902 L
.13214 .30902 L
.13327 .30902 L
.13441 .30902 L
.13564 .30902 L
.1368 .30902 L
.13785 .30902 L
.13909 .30902 L
.13979 .30902 L
.14043 .30902 L
.14162 .30902 L
.14288 .30902 L
.14402 .30902 L
.14526 .30902 L
.14656 .30902 L
.14777 .30902 L
.14891 .30902 L
.14994 .30902 L
.15113 .30902 L
.15226 .30902 L
.15348 .30902 L
.15478 .30902 L
.15589 .30902 L
.15711 .30902 L
.15842 .30902 L
.15915 .30902 L
.15982 .30902 L
.16113 .30902 L
.16236 .30902 L
.16352 .30902 L
.16456 .30902 L
.16577 .30902 L
.1669 .30902 L
.16796 .30902 L
.16893 .30902 L
.16999 .30902 L
.17111 .30902 L
.17225 .30902 L
.17347 .30902 L
.17462 .30902 L
Mistroke
.17566 .30902 L
.17689 .30902 L
.17758 .30902 L
.17823 .30902 L
.1794 .30902 L
.18065 .30902 L
.18185 .30902 L
.18316 .30902 L
.18441 .30902 L
.18556 .30902 L
.1867 .30902 L
.18773 .30902 L
.18893 .30902 L
.19005 .30902 L
.19128 .30902 L
.19258 .30902 L
.19369 .30902 L
.19491 .30902 L
.19623 .30902 L
.19696 .30902 L
.19763 .30902 L
.19894 .30902 L
.20017 .30902 L
.20122 .30902 L
.20238 .30902 L
.20359 .30902 L
.20472 .30902 L
.20578 .30902 L
.20675 .30902 L
.20781 .30902 L
.20894 .30902 L
.21008 .30902 L
.21129 .30902 L
.21244 .30902 L
.21349 .30902 L
.21472 .30902 L
.21541 .30902 L
.21605 .30902 L
.21723 .30902 L
.21847 .30902 L
.21968 .30902 L
.221 .30902 L
.22224 .30902 L
.2234 .30902 L
.22454 .30902 L
.22558 .30902 L
.22677 .30902 L
.2279 .30902 L
.22914 .30902 L
.23044 .30902 L
Mistroke
.23155 .30902 L
.23277 .30902 L
.23409 .30902 L
.23482 .30902 L
.2355 .30902 L
.2368 .30902 L
.23804 .30902 L
.23909 .30902 L
.24025 .30902 L
.24146 .30902 L
.2426 .30902 L
.24365 .30902 L
.24462 .30902 L
.24569 .30902 L
.24681 .30902 L
.24795 .30902 L
.24917 .30902 L
.25032 .30902 L
.25137 .30902 L
.2526 .30902 L
.25329 .30902 L
.25393 .30902 L
.2551 .30902 L
.25635 .30902 L
.25756 .30902 L
.25888 .30902 L
.26013 .30902 L
.26129 .30902 L
.26233 .30902 L
.26348 .30902 L
.26467 .30902 L
.2658 .30902 L
.26704 .30902 L
.26835 .30902 L
.26946 .30902 L
.27068 .30902 L
.272 .30902 L
.27274 .30902 L
.27341 .30902 L
.27472 .30902 L
.27595 .30902 L
.27701 .30902 L
.27817 .30902 L
.27938 .30902 L
.28052 .30902 L
.28158 .30902 L
.28255 .30902 L
.28367 .30902 L
.28474 .30902 L
.28588 .30902 L
Mistroke
.2871 .30902 L
.28825 .30902 L
.2893 .30902 L
.29053 .30902 L
.29122 .30902 L
.29186 .30902 L
.29303 .30902 L
.29427 .30902 L
.29549 .30902 L
.29618 .30902 L
.29682 .30902 L
.29799 .30902 L
.29923 .30902 L
.30034 .30902 L
.30138 .30902 L
.30252 .30902 L
.30375 .30902 L
.30499 .30902 L
.30569 .30902 L
.30634 .30902 L
.30765 .30902 L
.30839 .30902 L
.30906 .30902 L
.31026 .30902 L
.31156 .30902 L
.31278 .30902 L
.31392 .30902 L
.31497 .30902 L
.31611 .30902 L
.31718 .30902 L
.31816 .30902 L
.3193 .30902 L
.32055 .30902 L
.32173 .30902 L
.32282 .30902 L
.32406 .30902 L
.32522 .30902 L
.32626 .30902 L
.32739 .30902 L
.32862 .30902 L
.32992 .30902 L
.33103 .30902 L
.33225 .30902 L
.33356 .30902 L
.33477 .30902 L
.33541 .30902 L
.3361 .30902 L
.33683 .30902 L
.33751 .30902 L
.33876 .30902 L
Mistroke
.33991 .30902 L
.34123 .30902 L
.34249 .30902 L
.3436 .30902 L
.3448 .30902 L
.34592 .30902 L
.34694 .30902 L
.34814 .30902 L
.34945 .30902 L
.35067 .30902 L
.35181 .30902 L
.35302 .30902 L
.35431 .30902 L
.35554 .30902 L
.35665 .30902 L
.35796 .30902 L
.3587 .30902 L
.35939 .30902 L
.36064 .30902 L
.36128 .30902 L
.36198 .30902 L
.36266 .30902 L
.36337 .30902 L
.36465 .30902 L
.36536 .30902 L
.36602 .30902 L
.36675 .30902 L
.36753 .30902 L
.3682 .30902 L
.36893 .30902 L
.36962 .30902 L
.37026 .30902 L
.37146 .30902 L
.37274 .30902 L
.37394 .30902 L
.37526 .30902 L
.37651 .30902 L
.37766 .30902 L
.3788 .30902 L
.37984 .30902 L
.38103 .30902 L
.38216 .30902 L
.38339 .30902 L
.3847 .30902 L
.38581 .30902 L
.38703 .30902 L
.38834 .30902 L
.38908 .30902 L
.38975 .30902 L
.39106 .30902 L
Mistroke
.39229 .30902 L
.39334 .30902 L
.3945 .30902 L
.39571 .30902 L
.39685 .30902 L
.39791 .30902 L
.39888 .30902 L
.39994 .30902 L
.40106 .30902 L
.40221 .30902 L
.40342 .30902 L
.40457 .30902 L
.40562 .30902 L
.40685 .30902 L
.40754 .30902 L
.40818 .30902 L
.40936 .30902 L
.4106 .30902 L
.41181 .30902 L
.41313 .30902 L
.41438 .30902 L
.41554 .30902 L
.41669 .30902 L
.41772 .30902 L
.41892 .30902 L
.42005 .30902 L
.42129 .30902 L
.42259 .30902 L
.42371 .30902 L
.42493 .30902 L
.42624 .30902 L
.42698 .30902 L
.42765 .30902 L
.42896 .30902 L
.43019 .30902 L
.43125 .30902 L
.43241 .30902 L
.43362 .30902 L
.43476 .30902 L
.43582 .30902 L
.43679 .30902 L
.43791 .30902 L
.43898 .30902 L
.44012 .30902 L
.44134 .30902 L
.44249 .30902 L
.44354 .30902 L
.44477 .30902 L
.44546 .30902 L
.4461 .30902 L
Mistroke
.44727 .30902 L
.44851 .30902 L
.44973 .30902 L
.45042 .30902 L
.45106 .30902 L
.45223 .30902 L
.45347 .30902 L
.45458 .30902 L
.45562 .30902 L
.45676 .30902 L
.45799 .30902 L
.45922 .30902 L
.45992 .30902 L
.46057 .30902 L
.46188 .30902 L
.46262 .30902 L
.46329 .30902 L
.46449 .30902 L
.46579 .30902 L
.46702 .30902 L
.46815 .30902 L
.4692 .30902 L
.47034 .30902 L
.47141 .30902 L
.47239 .30902 L
.47353 .30902 L
.47478 .30902 L
.47596 .30902 L
.47705 .30902 L
.47829 .30902 L
.47945 .30902 L
.48049 .30902 L
.48162 .30902 L
.48285 .30902 L
.48415 .30902 L
.48526 .30902 L
.48648 .30902 L
.48779 .30902 L
.489 .30902 L
.48963 .30902 L
.49033 .30902 L
.49105 .30902 L
.49174 .30902 L
.49299 .30902 L
.49413 .30902 L
.49539 .30902 L
.49671 .30902 L
.49783 .30902 L
.49902 .30902 L
.50014 .30902 L
Mistroke
.50116 .30902 L
.50236 .30902 L
.50366 .30902 L
.50489 .30902 L
.50603 .30902 L
.50723 .30902 L
.50853 .30902 L
.50975 .30902 L
.51087 .30902 L
.51218 .30902 L
.51292 .30902 L
.51361 .30902 L
.51486 .30902 L
.5155 .30902 L
.5162 .30902 L
.51687 .30902 L
.51759 .30902 L
.51886 .30902 L
.51958 .30902 L
.52024 .30902 L
.52096 .30902 L
.52174 .30902 L
.52241 .30902 L
.52314 .30902 L
.52383 .30902 L
.52447 .30902 L
.52568 .30902 L
.52695 .30902 L
.52816 .30902 L
.52947 .30902 L
.53072 .30902 L
.53187 .30902 L
.53301 .30902 L
.53405 .30902 L
.53525 .30902 L
.53637 .30902 L
.5376 .30902 L
.53891 .30902 L
.54002 .30902 L
.54124 .30902 L
.54255 .30902 L
.54329 .30902 L
.54396 .30902 L
.54526 .30902 L
.5465 .30902 L
.54755 .30902 L
.54871 .30902 L
.54992 .30902 L
.55105 .30902 L
.55211 .30902 L
Mistroke
.55308 .30902 L
.55415 .30902 L
.55527 .30902 L
.55641 .30902 L
.55763 .30902 L
.55878 .30902 L
.55982 .30902 L
.56105 .30902 L
.56175 .30902 L
.56238 .30902 L
.56356 .30902 L
.5648 .30902 L
.56601 .30902 L
.56734 .30902 L
.56858 .30902 L
.56974 .30902 L
.57088 .30902 L
.57192 .30902 L
.57312 .30902 L
.57425 .30902 L
.57548 .30902 L
.57679 .30902 L
.5779 .30902 L
.57912 .30902 L
.58044 .30902 L
.58118 .30902 L
.58185 .30902 L
.58315 .30902 L
.58439 .30902 L
.58544 .30902 L
.5866 .30902 L
.58782 .30902 L
.58895 .30902 L
.59001 .30902 L
.59098 .30902 L
.5921 .30902 L
.59317 .30902 L
.59431 .30902 L
.59553 .30902 L
.59668 .30902 L
.59773 .30902 L
.59896 .30902 L
.59965 .30902 L
.60029 .30902 L
.60146 .30902 L
.60271 .30902 L
.60392 .30902 L
.60461 .30902 L
.60525 .30902 L
.60642 .30902 L
Mistroke
.60766 .30902 L
.60876 .30902 L
.6098 .30902 L
.61094 .30902 L
.61217 .30902 L
.61341 .30902 L
.6141 .30902 L
.61475 .30902 L
.61607 .30902 L
.6168 .30902 L
.61747 .30902 L
.61867 .30902 L
.61997 .30902 L
.6212 .30902 L
.62233 .30902 L
.62339 .30902 L
.62452 .30902 L
.62559 .30902 L
.62657 .30902 L
.62771 .30902 L
.62896 .30902 L
.63014 .30902 L
.63123 .30902 L
.63247 .30902 L
.63363 .30902 L
.63467 .30902 L
.6358 .30902 L
.63703 .30902 L
.63833 .30902 L
.63944 .30902 L
.64066 .30902 L
.64197 .30902 L
.64318 .30902 L
.64381 .30902 L
.6445 .30902 L
.64523 .30902 L
.64591 .30902 L
.64716 .30902 L
.64831 .30902 L
.64956 .30902 L
.65088 .30902 L
.652 .30902 L
.65319 .30902 L
.65431 .30902 L
.65533 .30902 L
.65653 .30902 L
.65784 .30902 L
.65906 .30902 L
.6602 .30902 L
.6614 .30902 L
Mistroke
.6627 .30902 L
.66392 .30902 L
.66504 .30902 L
.66635 .30902 L
.66709 .30902 L
.66777 .30902 L
.66903 .30902 L
.66966 .30902 L
.67036 .30902 L
.67104 .30902 L
.67175 .30902 L
.67303 .30902 L
.67374 .30902 L
.6744 .30902 L
.67513 .30902 L
.67591 .30902 L
.67658 .30902 L
.67731 .30902 L
.678 .30902 L
.67864 .30902 L
.67984 .30902 L
.68112 .30902 L
.68232 .30902 L
.68364 .30902 L
.68488 .30902 L
.68603 .30902 L
.68718 .30902 L
.68821 .30902 L
.68941 .30902 L
.69053 .30902 L
.69176 .30902 L
.69307 .30902 L
.69418 .30902 L
.6954 .30902 L
.69671 .30902 L
.69745 .30902 L
.69812 .30902 L
.69942 .30902 L
.70066 .30902 L
.70171 .30902 L
.70286 .30902 L
.70407 .30902 L
.70521 .30902 L
.70627 .30902 L
.70724 .30902 L
.7083 .30902 L
.70942 .30902 L
.71056 .30902 L
.71178 .30902 L
.71293 .30902 L
Mistroke
.71398 .30902 L
.71521 .30902 L
.7159 .30902 L
.71654 .30902 L
.71771 .30902 L
.71896 .30902 L
.72017 .30902 L
.72149 .30902 L
.72273 .30902 L
.72389 .30902 L
.72503 .30902 L
.72607 .30902 L
.72727 .30902 L
.7284 .30902 L
.72963 .30902 L
.73094 .30902 L
.73205 .30902 L
.73327 .30902 L
.73458 .30902 L
.73532 .30902 L
.73599 .30902 L
.7373 .30902 L
.73853 .30902 L
.73959 .30902 L
.74075 .30902 L
.74196 .30902 L
.7431 .30902 L
.74416 .30902 L
.74513 .30902 L
.74619 .30902 L
.74731 .30902 L
.74846 .30902 L
.74967 .30902 L
.75083 .30902 L
.75187 .30902 L
.7531 .30902 L
.75379 .30902 L
.75443 .30902 L
.75561 .30902 L
.75685 .30902 L
.75806 .30902 L
.75875 .30902 L
.75939 .30902 L
.76056 .30902 L
.7618 .30902 L
.7629 .30902 L
.76394 .30902 L
.76508 .30902 L
.76631 .30902 L
.76754 .30902 L
Mistroke
.76824 .30902 L
.76889 .30902 L
.7702 .30902 L
.77094 .30902 L
.77161 .30902 L
.7728 .30902 L
.7741 .30902 L
.77533 .30902 L
.77646 .30902 L
.77752 .30902 L
.77865 .30902 L
.77972 .30902 L
.7807 .30902 L
.78184 .30902 L
.78309 .30902 L
.78427 .30902 L
.78536 .30902 L
.7866 .30902 L
.78776 .30902 L
.7888 .30902 L
.78993 .30902 L
.79116 .30902 L
.79246 .30902 L
.79357 .30902 L
.79479 .30902 L
.7961 .30902 L
.7973 .30902 L
.79793 .30902 L
.79863 .30902 L
.79936 .30902 L
.80004 .30902 L
.80129 .30902 L
.80243 .30902 L
.80369 .30902 L
.80501 .30902 L
.80612 .30902 L
.80731 .30902 L
.80843 .30902 L
.80945 .30902 L
.81066 .30902 L
.81196 .30902 L
.81318 .30902 L
.81432 .30902 L
.81552 .30902 L
.81682 .30902 L
.81804 .30902 L
.81916 .30902 L
.82047 .30902 L
.8212 .30902 L
.82189 .30902 L
Mistroke
.82315 .30902 L
.82385 .30902 L
.82448 .30902 L
.82516 .30902 L
.82587 .30902 L
.82715 .30902 L
.82786 .30902 L
.82852 .30902 L
.82925 .30902 L
.83002 .30902 L
.8307 .30902 L
.83143 .30902 L
.83212 .30902 L
.83275 .30902 L
.83396 .30902 L
.83524 .30902 L
.83644 .30902 L
.83775 .30902 L
.839 .30902 L
.84015 .30902 L
.84129 .30902 L
.84232 .30902 L
.84352 .30902 L
.84464 .30902 L
.84587 .30902 L
.84718 .30902 L
.84829 .30902 L
.8495 .30902 L
.85082 .30902 L
.85155 .30902 L
.85222 .30902 L
.85353 .30902 L
.85476 .30902 L
.85581 .30902 L
.85697 .30902 L
.85818 .30902 L
.85932 .30902 L
.86037 .30902 L
.86134 .30902 L
.86241 .30902 L
.86353 .30902 L
.86467 .30902 L
.86589 .30902 L
.86704 .30902 L
.86808 .30902 L
.86931 .30902 L
.87 .30902 L
.87064 .30902 L
.87182 .30902 L
.87306 .30902 L
Mistroke
.87427 .30902 L
.87559 .30902 L
.87684 .30902 L
.87799 .30902 L
.87914 .30902 L
.88017 .30902 L
.88137 .30902 L
.88249 .30902 L
.88373 .30902 L
.88503 .30902 L
.88615 .30902 L
.88737 .30902 L
.88868 .30902 L
.88942 .30902 L
.89009 .30902 L
.89139 .30902 L
.89263 .30902 L
.89368 .30902 L
.89484 .30902 L
.89605 .30902 L
.89719 .30902 L
.89825 .30902 L
.89922 .30902 L
.90029 .30902 L
.90141 .30902 L
.90255 .30902 L
.90377 .30902 L
.90492 .30902 L
.90596 .30902 L
.90719 .30902 L
.90789 .30902 L
.90852 .30902 L
.9097 .30902 L
.91094 .30902 L
.91216 .30902 L
.91284 .30902 L
.91348 .30902 L
.91464 .30902 L
.91589 .30902 L
.91699 .30902 L
.91803 .30902 L
.91917 .30902 L
.9204 .30902 L
.92163 .30902 L
.92233 .30902 L
.92297 .30902 L
.92429 .30902 L
.92502 .30902 L
.92569 .30902 L
.92689 .30902 L
Mistroke
.92819 .30902 L
.92941 .30902 L
.93055 .30902 L
.9316 .30902 L
.93273 .30902 L
.9338 .30902 L
.93478 .30902 L
.93592 .30902 L
.93717 .30902 L
.93835 .30902 L
.93944 .30902 L
.94068 .30902 L
.94184 .30902 L
.94288 .30902 L
.94401 .30902 L
.94524 .30902 L
.94654 .30902 L
.94765 .30902 L
.94887 .30902 L
.94975 .30902 L
.95057 .30902 L
.95146 .30902 L
.95241 .30902 L
.95324 .30902 L
.95401 .30902 L
.95486 .30902 L
.95577 .30902 L
.95653 .30902 L
.95737 .30902 L
.95824 .30902 L
.95905 .30902 L
.95981 .30902 L
.9605 .30902 L
.9613 .30902 L
.96206 .30902 L
.96287 .30902 L
.96377 .30902 L
.96471 .30902 L
.96559 .30902 L
.96641 .30902 L
.96716 .30902 L
.96802 .30902 L
.96884 .30902 L
.96972 .30902 L
.97067 .30902 L
.97155 .30902 L
.97236 .30902 L
.97331 .30902 L
.97433 .30902 L
.9753 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
.02381 .31973 m
.06244 .32011 L
.10458 .32061 L
.14415 .32117 L
.18221 .32184 L
.22272 .32272 L
.26171 .32379 L
.30316 .32527 L
.34309 .32712 L
.3815 .32945 L
.42237 .33267 L
.46172 .33666 L
.49955 .34138 L
.53984 .34729 L
.57861 .35362 L
.61984 .3607 L
.65954 .36753 L
.69774 .37386 L
.73838 .38017 L
.77751 .38577 L
.81909 .39117 L
.85916 .39587 L
.89771 .39996 L
.93871 .40388 L
.97619 .40712 L
s
.02381 .33045 m
.06244 .3312 L
.10458 .33219 L
.14415 .33333 L
.18221 .33466 L
.22272 .33642 L
.26171 .33857 L
.30316 .34151 L
.34309 .34523 L
.3815 .34988 L
.42237 .35633 L
.46172 .36431 L
.49955 .37374 L
.53984 .38555 L
.57861 .39822 L
.61984 .41238 L
.65954 .42604 L
.69774 .43869 L
.73838 .45132 L
.77751 .46252 L
.81909 .47333 L
.85916 .48273 L
.89771 .4909 L
.93871 .49874 L
.97619 .50522 L
s
.02381 .34116 m
.06244 .3423 L
.10458 .34378 L
.14415 .34548 L
.18221 .34748 L
.22272 .35012 L
.26171 .35335 L
.30316 .35776 L
.34309 .36333 L
.3815 .37031 L
.42237 .37999 L
.46172 .39195 L
.49955 .4061 L
.53984 .42382 L
.57861 .44282 L
.61984 .46407 L
.65954 .48455 L
.69774 .50353 L
.73838 .52248 L
.77751 .53926 L
.81909 .55548 L
.85916 .56958 L
.89771 .58184 L
.93871 .5936 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{216.188, 133.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QB000`400?l00000o`00003oK?ooool0
0ol0003oooooooooo`1Yooooo`00K?ooool00ol0003oooooooooo`1Yooooo`00K?ooool00ol0003o
ooooooooo`1Yooooo`00K?ooool00ol0003oooooooooo`1Qooooo`?o00001Oooool006cooooo00?o
0000ooooooooool0GOooool4o`0000Sooooo001/ooooo`03o`000?oooooooooo05[ooooo0ol0000<
ooooo`00K?ooool00ol0003oooooooooo`1Gooooo`?o00003oooool006cooooo00?o0000oooooooo
ool0E?ooool3o`0001;ooooo001/ooooo`03o`000?oooooooooo053ooooo1?l0000Eooooo`00K?oo
ool00ol0003oooooooooo`1<ooooo`Co00006Oooool006cooooo00?o0000ooooooooool0BOooool3
o`0001gooooo001/ooooo`03o`000?oooooooooo04Kooooo0ol0000Pooooo`00FOooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo04?o
oooo0ol0000Sooooo`00FOooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`10ooooo`?o00009_ooool0057ooooo1Ol00004ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_ooool2o`0003oooooo0_l0000Yooooo`00F_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>ooo
ool3o`0002_ooooo001Kooooo`03o`000?oooooooooo00Gooooo1?l00005ooooo`03o`000?oooooo
oooo03Wooooo0_l0000^ooooo`00Eoooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0gooooo`;o0000<?ooool005Oooooo1Ol00007oooo
o`Go00001?ooool00ol0003oooooooooo`0dooooo`?o0000<_ooool006cooooo00?o0000oooooooo
ool0<Oooool3o`0003Gooooo001/ooooo`03o`000?oooooooooo02oooooo0_l0000hooooo`00K?oo
ool00ol0003oooooooooo`0]ooooo`;o0000>_ooool006cooooo00?o0000ooooooooool0:oooool2
o`0003cooooo001/ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0??ooool006co
oooo00?o0000ooooooooool0:?ooool2o`0003Oooooo0ol00005ooooo`00K?ooool00ol0003ooooo
ooooo`0Vooooo`;o0000=Oooool4o`0000Sooooo001/ooooo`03o`000?oooooooooo02Cooooo0_l0
000aooooo`Ko00003?ooool006cooooo00?o0000ooooooooool08_ooool2o`0002cooooo1ol0000B
ooooo`00K?ooool00ol0003oooooooooo`0Pooooo`;o0000:_ooool4o`0001Wooooo001Tooooo`?o
00001Oooool00ol0003oooooooooo`0Nooooo`;o0000:?ooool4o`0001gooooo001Sooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Looooo`;o00009Oooool5o`00027o
oooo001Mooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`;o00006_ooool3o`0002?ooooo
1?l0000Vooooo`00Ioooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo0_l0
000Qooooo`Go0000:_ooool006?ooooo1?l00005ooooo`03o`000?oooooooooo01Gooooo0_l0000P
ooooo`?o0000;oooool006?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Coooo
o`;o00007oooool3o`0003;ooooo001Sooooo`Go00001?ooool00ol0003oooooooooo`0Aooooo`;o
00007_ooool3o`0003Gooooo001/ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
6oooool3o`0003Sooooo001/ooooo`03o`000?oooooooooo00kooooo0_l0000Iooooo`Go0000>ooo
ool006cooooo00?o0000ooooooooool03?ooool2o`0001Sooooo0ol00010ooooo`00K?ooool00ol0
003oooooooooo`0:ooooo`;o00005oooool3o`0004?ooooo001/ooooo`03o`000?oooooooooo00So
oooo0_l0000Fooooo`?o0000A_ooool006cooooo00?o0000ooooooooool01_ooool2o`0001Kooooo
0_l00019ooooo`00K?ooool00ol0003oooooooooo`04ooooo`;o00005Oooool3o`0004_ooooo001/
ooooo`04o`000?ooooooooooooooo`?o00005?ooool3o`0004kooooo001/ooooo`Co00005?ooool3
o`00057ooooo001Zooooo`?o00005?ooool3o`0004[ooooo1Ol00005ooooo`00Eoooool5o`0000?o
oooo00?o0000ooooooooool00_ooool6o`0000;ooooo00?o0000ooooooooool03oooool3o`0004Go
oooo2?l0000:ooooo`00F?ooool01?l0003oooooooooool00007ooooo`Go00001?ooool00ol0003o
ooooooooo`0<ooooo`?o0000?oooool9o`0001;ooooo001Aooooo`Go00000oooool00ol0003ooooo
ooooo`06ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo
0ol0000jooooo`So00006oooool005[ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o
0000ooooooooool00_ooool2o`0000Oooooo0ol0000dooooo`Wo00008oooool005Oooooo00Co0000
oooooooooooooooo1?l00004ooooo`Co00001Oooool00ol0003oooooooooo`03ooooo`?o0000;_oo
ool9o`0002cooooo001Gooooo`03o`000?oooooo000000;o00001oooool00ol0003oooooooooo`06
ooooo`Ko0000:Oooool8o`0003Gooooo001Dooooo`Oo00002?ooool5o`000003ooooool0003o0000
00;o00009oooool7o`0003gooooo001@ooooo`Co00004Oooool4o`0000?ooooo00?o0000oooooooo
ool08Oooool4o`0004Cooooo001<ooooo`Co00004Oooool4o`0000Oooooo00?o0000ooooooooool0
6oooool6o`0004Sooooo0016ooooo`Ko00004Oooool4o`0000_ooooo00?o0000ooooooooool05?oo
ool7o`0004kooooo0006ooooo`Go0000;oooool<o`00017ooooo1_l0000?ooooo`03o`000?oooooo
oooo00oooooo1Ol0000Jooooo`?o0000;oooool5o`0000Cooooo0007ooooo`04o`000?oooooooooo
o`00027ooooo4Ol0000Aooooo`Wo00005Oooool00ol0003oooooooooo`09ooooo`Ko00008?ooool0
0ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`0000Cooooo0005o`0000?ooooo00?o0000
ooooooooool04?oooolAo`0000Oooooo1Ol00003ooooo`03o`000?oooooooooo00Sooooo2?l0000N
ooooo`04o`000?ooooooooooooooo`So00009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Cooooo0006oooooaGo00008?ooool00ol0003oooooo`000008o`00027ooooo2Ol0000^
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00oooool000Kooooo00Go0000oooo
ooooooooooooo`00000Qoooooa7o00008_ooool8o`0000Gooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0^ooooo`05o`000?ooooooooooooooool000001?ooool000Kooooo00Co0000
oooooooooooooooo8_l0000>ooooo`;o00006oooool8o`0000gooooo00?o0000ooooooooool0;_oo
ool2o`00033ooooo00Go0000ooooooooooooooooo`000004ooooo`001_ooool4o`00037ooooo00?o
0000ooooooooool02?oooolAo`0001Gooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0_ooooo`?o00001Oooool002?ooooo8ol0000Vooooo`03o`000?oooooooooo06Wooooo0006oooo
oago0000BOooool00ol0003oooooooooo`1Yooooo`00K?ooool00ol0003oooooooooo`1Yooooo`00
f?l0000000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00?ooooo0006ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00oooool0
00Kooooo>?l0000^ooooo`03o`000?oooooooooo06Wooooo000noooooa7o00007Oooool00ol0003o
ooooooooo`1Yooooo`001_oooolNo`0002_ooooo4Ol0000<ooooo`03o`000?oooooooooo06Wooooo
000Toooooa7o0000:oooool8o`0000Cooooo00?o0000ooooooooool0JOooool000Kooooo3_l0000Q
oooooa;o00008Oooool9o`0006Oooooo000DoooooaWo00006_ooool8o`0001gooooo00?o0000oooo
ooooool00_ooool6o`00067ooooo000]ooooo`So00006_ooool9o`0001Cooooo00?o0000oooooooo
ool02?ooool4o`0005gooooo000eooooo`Wo00006_ooool6o`0000kooooo00?o0000ooooooooool0
3?ooool7o`0005Kooooo000nooooo`Wo00005oooool4o`0000[ooooo00?o0000ooooooooool04ooo
ool6o`00053ooooo0017ooooo`So00004oooool4o`0000Kooooo00?o0000ooooooooool06Oooool5
o`0004_ooooo001?ooooo`Ko00004Oooool4o`0000;ooooo00?o0000ooooooooool07_ooool6o`00
04Gooooo001Eooooo`Go00004?ooool4o`0002Gooooo2Ol0000looooo`00Eoooool6o`0000;ooooo
00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooool000000_l0000[ooooo`Ko0000
=_ooool005Sooooo00Go0000oooooooooooo0000ooooo`03o`0000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo0ol0000^ooooo`Co0000<_ooool005Wooooo
00?o0000ooooooooool01?ooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`?o0000;oooool7o`0002_ooooo001Jooooo`03o`000?oooooooooo00Kooooo0_l0
0002ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`Co0000<_ooool9o`0002;ooooo001G
ooooo`05o`000?ooooooooooooooool000001oooool5o`0000Cooooo00?o0000ooooooooool03?oo
ool4o`0003Oooooo2?l0000Jooooo`00Eoooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00_ooool3o`000003ooooool0003ooooo017ooooo0ol0000looooo`Wo00004Ooo
ool005Sooooo0ol00008ooooo`Go00000oooool2o`0001Gooooo0ol00012ooooo`co00001Oooool0
06cooooo0ol0000Fooooo`?o0000D?ooool006cooooo00?o0000ooooooooool00ol0000Fooooo`?o
0000COooool006cooooo00?o0000ooooooooool00oooool2o`0001Oooooo0ol0001:ooooo`00K?oo
ool00ol0003oooooooooo`05ooooo`;o00006?ooool2o`0004Sooooo001/ooooo`03o`000?oooooo
oooo00Oooooo0_l0000Hooooo`?o0000AOooool006cooooo00?o0000ooooooooool02Oooool2o`00
01Wooooo0ol00012ooooo`00K?ooool00ol0003oooooooooo`0;ooooo`;o00006_ooool3o`0003oo
oooo001/ooooo`03o`000?oooooooooo00gooooo0_l0000Kooooo`?o0000??ooool006cooooo00?o
0000ooooooooool03oooool2o`0001cooooo0ol0000iooooo`00K?ooool00ol0003oooooooooo`0A
ooooo`?o00007?ooool3o`0003Kooooo001Tooooo`?o00001Oooool00ol0003oooooooooo`0Doooo
o`;o00007Oooool4o`0003;ooooo001Sooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0Fooooo`;o00007oooool4o`0002kooooo001Wooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06?ooool2o`00027ooooo1Ol0000Yooooo`00Ioooool00ol0003ooooo
ooooo`02ooooo`;o00006oooool2o`0002Cooooo1?l0000Uooooo`00Hoooool4o`0000Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Uooooo`Go00008?ooool006?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`;o0000:_ooool4o`0001cooooo001Soooo
o`Go00001?ooool00ol0003oooooooooo`0Oooooo`;o0000;?ooool4o`0001Sooooo001/ooooo`03
o`000?oooooooooo027ooooo0_l0000^ooooo`Co00005?ooool006cooooo00?o0000ooooooooool0
8oooool2o`00033ooooo1Ol0000?ooooo`00K?ooool00ol0003oooooooooo`0Uooooo`;o0000<ooo
ool6o`0000Wooooo001/ooooo`03o`000?oooooooooo02Oooooo0_l0000gooooo`Co00001Oooool0
06cooooo00?o0000ooooooooool0:Oooool2o`0003kooooo001/ooooo`03o`000?oooooooooo02_o
oooo0ol0000kooooo`00K?ooool00ol0003oooooooooo`0^ooooo`;o0000>Oooool006cooooo00?o
0000ooooooooool0<?ooool2o`0003Oooooo001/ooooo`03o`000?oooooooooo03;ooooo0_l0000e
ooooo`00K?ooool00ol0003oooooooooo`0dooooo`;o0000<oooool006cooooo00?o0000oooooooo
ool0=_ooool2o`00037ooooo001Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool3o`0000Gooooo00?o0000ooooooooool0>?ooool3o`0002kooooo001Iooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03_ooooo
0ol0000[ooooo`00F_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l0
000oooooo`?o0000:?ooool005[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo047ooooo0ol0000Uooooo`00Foooool00ol0003oooooooooo`05oooo
o`Co00001Oooool00ol0003oooooooooo`14ooooo`?o00008_ooool005Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Aoooool3o`00
01oooooo001Gooooo`Go00001oooool5o`0000Cooooo00?o0000ooooooooool0B_ooool2o`0001go
oooo001/ooooo`03o`000?oooooooooo04cooooo0ol0000Jooooo`00K?ooool00ol0003ooooooooo
o`1?ooooo`?o00005oooool006cooooo00?o0000ooooooooool0D_ooool3o`0001Cooooo001/oooo
o`03o`000?oooooooooo05Gooooo1Ol0000?ooooo`00K?ooool00ol0003oooooooooo`1Jooooo`Co
00002oooool006cooooo00?o0000ooooooooool0G_ooool4o`0000Oooooo001/ooooo`03o`000?oo
oooooooo06;ooooo0_l00005ooooo`00K?ooool00ol0003oooooooooo`1Yooooo`00K?ooool00ol0
003oooooooooo`1Yooooo`00K?ooool00ol0003oooooooooo`1Yooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 293.062}, {495.5, 362.938}} -> {-3.64396, \
42.6984, 0.0195998, 0.143933}}]
}, Open  ]],

Cell[TextData[StyleBox["Solving an initial value problem",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
If the differential equation is accompanied by an initial condition \
of the form\
\>", "Text"],

Cell[TextData[{
  StyleBox["y",
    FontSlant->"Italic"],
  "(t0) = y0"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
we have an initial value problem (IVP for short). Look for a \
solution by applying DSolve to a set containing DE  and the initial condition \
(as an identity): \
\>", "Text"],

Cell[TextData[StyleBox["DSolve[ {DE, y[t0]==y0}, y, t ]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
For example, the solution to DE satisfying the initial condition \
y(1) = 3 is obtained as follows. \
\>", "Text"],

Cell[CellGroupData[{

Cell["soln = DSolve[ {DE, y[1]==3}, y, t]", "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{t}, 
            3\ \[ExponentialE]\^\(\(-\(\[Pi]\/4\)\) + ArcTan[t]\)]}}\)], \
"Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["The initial value can be checked by two substitutions.", "Text"],

Cell[CellGroupData[{

Cell["y[t]/.soln/.t->1", "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({3}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
The following picture shows the seven previous solutions, the IVP \
solution (blue and dashed), and the initial point. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
IP = ListPlot[ {{1,3}}, PlotStyle->PointSize[0.02]]
IVP = Plot[ y[t]/.soln, {t,-2,2}, 
    PlotStyle->{Dashing[{0.03,0.03}],RGBColor[0,0,1]}]
Show[ P1, IP, IVP ]\
\>", "Input",
  CellLabel->"In[26]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.0324223 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .06585 -24 -4.5 ]
[.4875 .06585 0 4.5 ]
[.4875 .14691 -12 -4.5 ]
[.4875 .14691 0 4.5 ]
[.4875 .22796 -24 -4.5 ]
[.4875 .22796 0 4.5 ]
[.4875 .39007 -18 -4.5 ]
[.4875 .39007 0 4.5 ]
[.4875 .47113 -6 -4.5 ]
[.4875 .47113 0 4.5 ]
[.4875 .55218 -18 -4.5 ]
[.4875 .55218 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-1)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .06585 m
.50625 .06585 L
s
[(-7.5)] .4875 .06585 1 0 Mshowa
.5 .14691 m
.50625 .14691 L
s
[(-5)] .4875 .14691 1 0 Mshowa
.5 .22796 m
.50625 .22796 L
s
[(-2.5)] .4875 .22796 1 0 Mshowa
.5 .39007 m
.50625 .39007 L
s
[(2.5)] .4875 .39007 1 0 Mshowa
.5 .47113 m
.50625 .47113 L
s
[(5)] .4875 .47113 1 0 Mshowa
.5 .55218 m
.50625 .55218 L
s
[(7.5)] .4875 .55218 1 0 Mshowa
.125 Mabswid
.5 .08206 m
.50375 .08206 L
s
.5 .09827 m
.50375 .09827 L
s
.5 .11448 m
.50375 .11448 L
s
.5 .13069 m
.50375 .13069 L
s
.5 .16312 m
.50375 .16312 L
s
.5 .17933 m
.50375 .17933 L
s
.5 .19554 m
.50375 .19554 L
s
.5 .21175 m
.50375 .21175 L
s
.5 .24417 m
.50375 .24417 L
s
.5 .26038 m
.50375 .26038 L
s
.5 .27659 m
.50375 .27659 L
s
.5 .29281 m
.50375 .29281 L
s
.5 .32523 m
.50375 .32523 L
s
.5 .34144 m
.50375 .34144 L
s
.5 .35765 m
.50375 .35765 L
s
.5 .37386 m
.50375 .37386 L
s
.5 .40628 m
.50375 .40628 L
s
.5 .42249 m
.50375 .42249 L
s
.5 .43871 m
.50375 .43871 L
s
.5 .45492 m
.50375 .45492 L
s
.5 .48734 m
.50375 .48734 L
s
.5 .50355 m
.50375 .50355 L
s
.5 .51976 m
.50375 .51976 L
s
.5 .53597 m
.50375 .53597 L
s
.5 .04964 m
.50375 .04964 L
s
.5 .03343 m
.50375 .03343 L
s
.5 .01722 m
.50375 .01722 L
s
.5 .00101 m
.50375 .00101 L
s
.5 .5684 m
.50375 .5684 L
s
.5 .58461 m
.50375 .58461 L
s
.5 .60082 m
.50375 .60082 L
s
.5 .61703 m
.50375 .61703 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .27687 m
.06244 .27574 L
.10458 .27425 L
.14415 .27255 L
.18221 .27056 L
.22272 .26791 L
.26171 .26469 L
.30316 .26027 L
.34309 .2547 L
.3815 .24773 L
.42237 .23805 L
.46172 .22608 L
.49955 .21193 L
.53984 .19421 L
.57861 .17522 L
.61984 .15397 L
.65954 .13348 L
.69774 .1145 L
.73838 .09556 L
.77751 .07877 L
.81909 .06255 L
.85916 .04845 L
.89771 .0362 L
.93871 .02443 L
.97619 .01472 L
s
.02381 .28759 m
.06244 .28683 L
.10458 .28584 L
.14415 .28471 L
.18221 .28338 L
.22272 .28161 L
.26171 .27946 L
.30316 .27652 L
.34309 .27281 L
.3815 .26816 L
.42237 .2617 L
.46172 .25373 L
.49955 .24429 L
.53984 .23248 L
.57861 .21982 L
.61984 .20565 L
.65954 .192 L
.69774 .17934 L
.73838 .16671 L
.77751 .15552 L
.81909 .14471 L
.85916 .13531 L
.89771 .12714 L
.93871 .1193 L
.97619 .11282 L
s
.02381 .2983 m
.06244 .29792 L
.10458 .29743 L
.14415 .29686 L
.18221 .2962 L
.22272 .29531 L
.26171 .29424 L
.30316 .29277 L
.34309 .29091 L
.3815 .28859 L
.42237 .28536 L
.46172 .28137 L
.49955 .27666 L
.53984 .27075 L
.57861 .26442 L
.61984 .25733 L
.65954 .25051 L
.69774 .24418 L
.73838 .23786 L
.77751 .23227 L
.81909 .22686 L
.85916 .22216 L
.89771 .21808 L
.93871 .21416 L
.97619 .21092 L
s
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07103 .30902 L
.07173 .30902 L
.073 .30902 L
Mistroke
.07376 .30902 L
.07448 .30902 L
.07513 .30902 L
.07583 .30902 L
.0766 .30902 L
.0774 .30902 L
.07809 .30902 L
.07885 .30902 L
.07956 .30902 L
.0802 .30902 L
.08095 .30902 L
.08166 .30902 L
.08291 .30902 L
.08362 .30902 L
.08427 .30902 L
.08544 .30902 L
.08669 .30902 L
.08787 .30902 L
.08896 .30902 L
.09016 .30902 L
.09148 .30902 L
.09214 .30902 L
.09285 .30902 L
.09413 .30902 L
.09483 .30902 L
.09548 .30902 L
.09619 .30902 L
.09695 .30902 L
.09821 .30902 L
.09893 .30902 L
.09961 .30902 L
.10086 .30902 L
.10201 .30902 L
.10333 .30902 L
.10458 .30902 L
.10572 .30902 L
.10694 .30902 L
.1081 .30902 L
.10916 .30902 L
.11033 .30902 L
.11162 .30902 L
.11227 .30902 L
.11297 .30902 L
.11422 .30902 L
.11491 .30902 L
.11554 .30902 L
.11624 .30902 L
.11698 .30902 L
.11822 .30902 L
.11892 .30902 L
Mistroke
.11958 .30902 L
.12081 .30902 L
.12194 .30902 L
.12323 .30902 L
.12446 .30902 L
.12562 .30902 L
.12668 .30902 L
.12789 .30902 L
.12903 .30902 L
.13009 .30902 L
.13107 .30902 L
.13214 .30902 L
.13327 .30902 L
.13441 .30902 L
.13564 .30902 L
.1368 .30902 L
.13785 .30902 L
.13909 .30902 L
.13979 .30902 L
.14043 .30902 L
.14162 .30902 L
.14288 .30902 L
.14402 .30902 L
.14526 .30902 L
.14656 .30902 L
.14777 .30902 L
.14891 .30902 L
.14994 .30902 L
.15113 .30902 L
.15226 .30902 L
.15348 .30902 L
.15478 .30902 L
.15589 .30902 L
.15711 .30902 L
.15842 .30902 L
.15915 .30902 L
.15982 .30902 L
.16113 .30902 L
.16236 .30902 L
.16352 .30902 L
.16456 .30902 L
.16577 .30902 L
.1669 .30902 L
.16796 .30902 L
.16893 .30902 L
.16999 .30902 L
.17111 .30902 L
.17225 .30902 L
.17347 .30902 L
.17462 .30902 L
Mistroke
.17566 .30902 L
.17689 .30902 L
.17758 .30902 L
.17823 .30902 L
.1794 .30902 L
.18065 .30902 L
.18185 .30902 L
.18316 .30902 L
.18441 .30902 L
.18556 .30902 L
.1867 .30902 L
.18773 .30902 L
.18893 .30902 L
.19005 .30902 L
.19128 .30902 L
.19258 .30902 L
.19369 .30902 L
.19491 .30902 L
.19623 .30902 L
.19696 .30902 L
.19763 .30902 L
.19894 .30902 L
.20017 .30902 L
.20122 .30902 L
.20238 .30902 L
.20359 .30902 L
.20472 .30902 L
.20578 .30902 L
.20675 .30902 L
.20781 .30902 L
.20894 .30902 L
.21008 .30902 L
.21129 .30902 L
.21244 .30902 L
.21349 .30902 L
.21472 .30902 L
.21541 .30902 L
.21605 .30902 L
.21723 .30902 L
.21847 .30902 L
.21968 .30902 L
.221 .30902 L
.22224 .30902 L
.2234 .30902 L
.22454 .30902 L
.22558 .30902 L
.22677 .30902 L
.2279 .30902 L
.22914 .30902 L
.23044 .30902 L
Mistroke
.23155 .30902 L
.23277 .30902 L
.23409 .30902 L
.23482 .30902 L
.2355 .30902 L
.2368 .30902 L
.23804 .30902 L
.23909 .30902 L
.24025 .30902 L
.24146 .30902 L
.2426 .30902 L
.24365 .30902 L
.24462 .30902 L
.24569 .30902 L
.24681 .30902 L
.24795 .30902 L
.24917 .30902 L
.25032 .30902 L
.25137 .30902 L
.2526 .30902 L
.25329 .30902 L
.25393 .30902 L
.2551 .30902 L
.25635 .30902 L
.25756 .30902 L
.25888 .30902 L
.26013 .30902 L
.26129 .30902 L
.26233 .30902 L
.26348 .30902 L
.26467 .30902 L
.2658 .30902 L
.26704 .30902 L
.26835 .30902 L
.26946 .30902 L
.27068 .30902 L
.272 .30902 L
.27274 .30902 L
.27341 .30902 L
.27472 .30902 L
.27595 .30902 L
.27701 .30902 L
.27817 .30902 L
.27938 .30902 L
.28052 .30902 L
.28158 .30902 L
.28255 .30902 L
.28367 .30902 L
.28474 .30902 L
.28588 .30902 L
Mistroke
.2871 .30902 L
.28825 .30902 L
.2893 .30902 L
.29053 .30902 L
.29122 .30902 L
.29186 .30902 L
.29303 .30902 L
.29427 .30902 L
.29549 .30902 L
.29618 .30902 L
.29682 .30902 L
.29799 .30902 L
.29923 .30902 L
.30034 .30902 L
.30138 .30902 L
.30252 .30902 L
.30375 .30902 L
.30499 .30902 L
.30569 .30902 L
.30634 .30902 L
.30765 .30902 L
.30839 .30902 L
.30906 .30902 L
.31026 .30902 L
.31156 .30902 L
.31278 .30902 L
.31392 .30902 L
.31497 .30902 L
.31611 .30902 L
.31718 .30902 L
.31816 .30902 L
.3193 .30902 L
.32055 .30902 L
.32173 .30902 L
.32282 .30902 L
.32406 .30902 L
.32522 .30902 L
.32626 .30902 L
.32739 .30902 L
.32862 .30902 L
.32992 .30902 L
.33103 .30902 L
.33225 .30902 L
.33356 .30902 L
.33477 .30902 L
.33541 .30902 L
.3361 .30902 L
.33683 .30902 L
.33751 .30902 L
.33876 .30902 L
Mistroke
.33991 .30902 L
.34123 .30902 L
.34249 .30902 L
.3436 .30902 L
.3448 .30902 L
.34592 .30902 L
.34694 .30902 L
.34814 .30902 L
.34945 .30902 L
.35067 .30902 L
.35181 .30902 L
.35302 .30902 L
.35431 .30902 L
.35554 .30902 L
.35665 .30902 L
.35796 .30902 L
.3587 .30902 L
.35939 .30902 L
.36064 .30902 L
.36128 .30902 L
.36198 .30902 L
.36266 .30902 L
.36337 .30902 L
.36465 .30902 L
.36536 .30902 L
.36602 .30902 L
.36675 .30902 L
.36753 .30902 L
.3682 .30902 L
.36893 .30902 L
.36962 .30902 L
.37026 .30902 L
.37146 .30902 L
.37274 .30902 L
.37394 .30902 L
.37526 .30902 L
.37651 .30902 L
.37766 .30902 L
.3788 .30902 L
.37984 .30902 L
.38103 .30902 L
.38216 .30902 L
.38339 .30902 L
.3847 .30902 L
.38581 .30902 L
.38703 .30902 L
.38834 .30902 L
.38908 .30902 L
.38975 .30902 L
.39106 .30902 L
Mistroke
.39229 .30902 L
.39334 .30902 L
.3945 .30902 L
.39571 .30902 L
.39685 .30902 L
.39791 .30902 L
.39888 .30902 L
.39994 .30902 L
.40106 .30902 L
.40221 .30902 L
.40342 .30902 L
.40457 .30902 L
.40562 .30902 L
.40685 .30902 L
.40754 .30902 L
.40818 .30902 L
.40936 .30902 L
.4106 .30902 L
.41181 .30902 L
.41313 .30902 L
.41438 .30902 L
.41554 .30902 L
.41669 .30902 L
.41772 .30902 L
.41892 .30902 L
.42005 .30902 L
.42129 .30902 L
.42259 .30902 L
.42371 .30902 L
.42493 .30902 L
.42624 .30902 L
.42698 .30902 L
.42765 .30902 L
.42896 .30902 L
.43019 .30902 L
.43125 .30902 L
.43241 .30902 L
.43362 .30902 L
.43476 .30902 L
.43582 .30902 L
.43679 .30902 L
.43791 .30902 L
.43898 .30902 L
.44012 .30902 L
.44134 .30902 L
.44249 .30902 L
.44354 .30902 L
.44477 .30902 L
.44546 .30902 L
.4461 .30902 L
Mistroke
.44727 .30902 L
.44851 .30902 L
.44973 .30902 L
.45042 .30902 L
.45106 .30902 L
.45223 .30902 L
.45347 .30902 L
.45458 .30902 L
.45562 .30902 L
.45676 .30902 L
.45799 .30902 L
.45922 .30902 L
.45992 .30902 L
.46057 .30902 L
.46188 .30902 L
.46262 .30902 L
.46329 .30902 L
.46449 .30902 L
.46579 .30902 L
.46702 .30902 L
.46815 .30902 L
.4692 .30902 L
.47034 .30902 L
.47141 .30902 L
.47239 .30902 L
.47353 .30902 L
.47478 .30902 L
.47596 .30902 L
.47705 .30902 L
.47829 .30902 L
.47945 .30902 L
.48049 .30902 L
.48162 .30902 L
.48285 .30902 L
.48415 .30902 L
.48526 .30902 L
.48648 .30902 L
.48779 .30902 L
.489 .30902 L
.48963 .30902 L
.49033 .30902 L
.49105 .30902 L
.49174 .30902 L
.49299 .30902 L
.49413 .30902 L
.49539 .30902 L
.49671 .30902 L
.49783 .30902 L
.49902 .30902 L
.50014 .30902 L
Mistroke
.50116 .30902 L
.50236 .30902 L
.50366 .30902 L
.50489 .30902 L
.50603 .30902 L
.50723 .30902 L
.50853 .30902 L
.50975 .30902 L
.51087 .30902 L
.51218 .30902 L
.51292 .30902 L
.51361 .30902 L
.51486 .30902 L
.5155 .30902 L
.5162 .30902 L
.51687 .30902 L
.51759 .30902 L
.51886 .30902 L
.51958 .30902 L
.52024 .30902 L
.52096 .30902 L
.52174 .30902 L
.52241 .30902 L
.52314 .30902 L
.52383 .30902 L
.52447 .30902 L
.52568 .30902 L
.52695 .30902 L
.52816 .30902 L
.52947 .30902 L
.53072 .30902 L
.53187 .30902 L
.53301 .30902 L
.53405 .30902 L
.53525 .30902 L
.53637 .30902 L
.5376 .30902 L
.53891 .30902 L
.54002 .30902 L
.54124 .30902 L
.54255 .30902 L
.54329 .30902 L
.54396 .30902 L
.54526 .30902 L
.5465 .30902 L
.54755 .30902 L
.54871 .30902 L
.54992 .30902 L
.55105 .30902 L
.55211 .30902 L
Mistroke
.55308 .30902 L
.55415 .30902 L
.55527 .30902 L
.55641 .30902 L
.55763 .30902 L
.55878 .30902 L
.55982 .30902 L
.56105 .30902 L
.56175 .30902 L
.56238 .30902 L
.56356 .30902 L
.5648 .30902 L
.56601 .30902 L
.56734 .30902 L
.56858 .30902 L
.56974 .30902 L
.57088 .30902 L
.57192 .30902 L
.57312 .30902 L
.57425 .30902 L
.57548 .30902 L
.57679 .30902 L
.5779 .30902 L
.57912 .30902 L
.58044 .30902 L
.58118 .30902 L
.58185 .30902 L
.58315 .30902 L
.58439 .30902 L
.58544 .30902 L
.5866 .30902 L
.58782 .30902 L
.58895 .30902 L
.59001 .30902 L
.59098 .30902 L
.5921 .30902 L
.59317 .30902 L
.59431 .30902 L
.59553 .30902 L
.59668 .30902 L
.59773 .30902 L
.59896 .30902 L
.59965 .30902 L
.60029 .30902 L
.60146 .30902 L
.60271 .30902 L
.60392 .30902 L
.60461 .30902 L
.60525 .30902 L
.60642 .30902 L
Mistroke
.60766 .30902 L
.60876 .30902 L
.6098 .30902 L
.61094 .30902 L
.61217 .30902 L
.61341 .30902 L
.6141 .30902 L
.61475 .30902 L
.61607 .30902 L
.6168 .30902 L
.61747 .30902 L
.61867 .30902 L
.61997 .30902 L
.6212 .30902 L
.62233 .30902 L
.62339 .30902 L
.62452 .30902 L
.62559 .30902 L
.62657 .30902 L
.62771 .30902 L
.62896 .30902 L
.63014 .30902 L
.63123 .30902 L
.63247 .30902 L
.63363 .30902 L
.63467 .30902 L
.6358 .30902 L
.63703 .30902 L
.63833 .30902 L
.63944 .30902 L
.64066 .30902 L
.64197 .30902 L
.64318 .30902 L
.64381 .30902 L
.6445 .30902 L
.64523 .30902 L
.64591 .30902 L
.64716 .30902 L
.64831 .30902 L
.64956 .30902 L
.65088 .30902 L
.652 .30902 L
.65319 .30902 L
.65431 .30902 L
.65533 .30902 L
.65653 .30902 L
.65784 .30902 L
.65906 .30902 L
.6602 .30902 L
.6614 .30902 L
Mistroke
.6627 .30902 L
.66392 .30902 L
.66504 .30902 L
.66635 .30902 L
.66709 .30902 L
.66777 .30902 L
.66903 .30902 L
.66966 .30902 L
.67036 .30902 L
.67104 .30902 L
.67175 .30902 L
.67303 .30902 L
.67374 .30902 L
.6744 .30902 L
.67513 .30902 L
.67591 .30902 L
.67658 .30902 L
.67731 .30902 L
.678 .30902 L
.67864 .30902 L
.67984 .30902 L
.68112 .30902 L
.68232 .30902 L
.68364 .30902 L
.68488 .30902 L
.68603 .30902 L
.68718 .30902 L
.68821 .30902 L
.68941 .30902 L
.69053 .30902 L
.69176 .30902 L
.69307 .30902 L
.69418 .30902 L
.6954 .30902 L
.69671 .30902 L
.69745 .30902 L
.69812 .30902 L
.69942 .30902 L
.70066 .30902 L
.70171 .30902 L
.70286 .30902 L
.70407 .30902 L
.70521 .30902 L
.70627 .30902 L
.70724 .30902 L
.7083 .30902 L
.70942 .30902 L
.71056 .30902 L
.71178 .30902 L
.71293 .30902 L
Mistroke
.71398 .30902 L
.71521 .30902 L
.7159 .30902 L
.71654 .30902 L
.71771 .30902 L
.71896 .30902 L
.72017 .30902 L
.72149 .30902 L
.72273 .30902 L
.72389 .30902 L
.72503 .30902 L
.72607 .30902 L
.72727 .30902 L
.7284 .30902 L
.72963 .30902 L
.73094 .30902 L
.73205 .30902 L
.73327 .30902 L
.73458 .30902 L
.73532 .30902 L
.73599 .30902 L
.7373 .30902 L
.73853 .30902 L
.73959 .30902 L
.74075 .30902 L
.74196 .30902 L
.7431 .30902 L
.74416 .30902 L
.74513 .30902 L
.74619 .30902 L
.74731 .30902 L
.74846 .30902 L
.74967 .30902 L
.75083 .30902 L
.75187 .30902 L
.7531 .30902 L
.75379 .30902 L
.75443 .30902 L
.75561 .30902 L
.75685 .30902 L
.75806 .30902 L
.75875 .30902 L
.75939 .30902 L
.76056 .30902 L
.7618 .30902 L
.7629 .30902 L
.76394 .30902 L
.76508 .30902 L
.76631 .30902 L
.76754 .30902 L
Mistroke
.76824 .30902 L
.76889 .30902 L
.7702 .30902 L
.77094 .30902 L
.77161 .30902 L
.7728 .30902 L
.7741 .30902 L
.77533 .30902 L
.77646 .30902 L
.77752 .30902 L
.77865 .30902 L
.77972 .30902 L
.7807 .30902 L
.78184 .30902 L
.78309 .30902 L
.78427 .30902 L
.78536 .30902 L
.7866 .30902 L
.78776 .30902 L
.7888 .30902 L
.78993 .30902 L
.79116 .30902 L
.79246 .30902 L
.79357 .30902 L
.79479 .30902 L
.7961 .30902 L
.7973 .30902 L
.79793 .30902 L
.79863 .30902 L
.79936 .30902 L
.80004 .30902 L
.80129 .30902 L
.80243 .30902 L
.80369 .30902 L
.80501 .30902 L
.80612 .30902 L
.80731 .30902 L
.80843 .30902 L
.80945 .30902 L
.81066 .30902 L
.81196 .30902 L
.81318 .30902 L
.81432 .30902 L
.81552 .30902 L
.81682 .30902 L
.81804 .30902 L
.81916 .30902 L
.82047 .30902 L
.8212 .30902 L
.82189 .30902 L
Mistroke
.82315 .30902 L
.82385 .30902 L
.82448 .30902 L
.82516 .30902 L
.82587 .30902 L
.82715 .30902 L
.82786 .30902 L
.82852 .30902 L
.82925 .30902 L
.83002 .30902 L
.8307 .30902 L
.83143 .30902 L
.83212 .30902 L
.83275 .30902 L
.83396 .30902 L
.83524 .30902 L
.83644 .30902 L
.83775 .30902 L
.839 .30902 L
.84015 .30902 L
.84129 .30902 L
.84232 .30902 L
.84352 .30902 L
.84464 .30902 L
.84587 .30902 L
.84718 .30902 L
.84829 .30902 L
.8495 .30902 L
.85082 .30902 L
.85155 .30902 L
.85222 .30902 L
.85353 .30902 L
.85476 .30902 L
.85581 .30902 L
.85697 .30902 L
.85818 .30902 L
.85932 .30902 L
.86037 .30902 L
.86134 .30902 L
.86241 .30902 L
.86353 .30902 L
.86467 .30902 L
.86589 .30902 L
.86704 .30902 L
.86808 .30902 L
.86931 .30902 L
.87 .30902 L
.87064 .30902 L
.87182 .30902 L
.87306 .30902 L
Mistroke
.87427 .30902 L
.87559 .30902 L
.87684 .30902 L
.87799 .30902 L
.87914 .30902 L
.88017 .30902 L
.88137 .30902 L
.88249 .30902 L
.88373 .30902 L
.88503 .30902 L
.88615 .30902 L
.88737 .30902 L
.88868 .30902 L
.88942 .30902 L
.89009 .30902 L
.89139 .30902 L
.89263 .30902 L
.89368 .30902 L
.89484 .30902 L
.89605 .30902 L
.89719 .30902 L
.89825 .30902 L
.89922 .30902 L
.90029 .30902 L
.90141 .30902 L
.90255 .30902 L
.90377 .30902 L
.90492 .30902 L
.90596 .30902 L
.90719 .30902 L
.90789 .30902 L
.90852 .30902 L
.9097 .30902 L
.91094 .30902 L
.91216 .30902 L
.91284 .30902 L
.91348 .30902 L
.91464 .30902 L
.91589 .30902 L
.91699 .30902 L
.91803 .30902 L
.91917 .30902 L
.9204 .30902 L
.92163 .30902 L
.92233 .30902 L
.92297 .30902 L
.92429 .30902 L
.92502 .30902 L
.92569 .30902 L
.92689 .30902 L
Mistroke
.92819 .30902 L
.92941 .30902 L
.93055 .30902 L
.9316 .30902 L
.93273 .30902 L
.9338 .30902 L
.93478 .30902 L
.93592 .30902 L
.93717 .30902 L
.93835 .30902 L
.93944 .30902 L
.94068 .30902 L
.94184 .30902 L
.94288 .30902 L
.94401 .30902 L
.94524 .30902 L
.94654 .30902 L
.94765 .30902 L
.94887 .30902 L
.94975 .30902 L
.95057 .30902 L
.95146 .30902 L
.95241 .30902 L
.95324 .30902 L
.95401 .30902 L
.95486 .30902 L
.95577 .30902 L
.95653 .30902 L
.95737 .30902 L
.95824 .30902 L
.95905 .30902 L
.95981 .30902 L
.9605 .30902 L
.9613 .30902 L
.96206 .30902 L
.96287 .30902 L
.96377 .30902 L
.96471 .30902 L
.96559 .30902 L
.96641 .30902 L
.96716 .30902 L
.96802 .30902 L
.96884 .30902 L
.96972 .30902 L
.97067 .30902 L
.97155 .30902 L
.97236 .30902 L
.97331 .30902 L
.97433 .30902 L
.9753 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
.02381 .31973 m
.06244 .32011 L
.10458 .32061 L
.14415 .32117 L
.18221 .32184 L
.22272 .32272 L
.26171 .32379 L
.30316 .32527 L
.34309 .32712 L
.3815 .32945 L
.42237 .33267 L
.46172 .33666 L
.49955 .34138 L
.53984 .34729 L
.57861 .35362 L
.61984 .3607 L
.65954 .36753 L
.69774 .37386 L
.73838 .38017 L
.77751 .38577 L
.81909 .39117 L
.85916 .39587 L
.89771 .39996 L
.93871 .40388 L
.97619 .40712 L
s
.02381 .33045 m
.06244 .3312 L
.10458 .33219 L
.14415 .33333 L
.18221 .33466 L
.22272 .33642 L
.26171 .33857 L
.30316 .34151 L
.34309 .34523 L
.3815 .34988 L
.42237 .35633 L
.46172 .36431 L
.49955 .37374 L
.53984 .38555 L
.57861 .39822 L
.61984 .41238 L
.65954 .42604 L
.69774 .43869 L
.73838 .45132 L
.77751 .46252 L
.81909 .47333 L
.85916 .48273 L
.89771 .4909 L
.93871 .49874 L
.97619 .50522 L
s
.02381 .34116 m
.06244 .3423 L
.10458 .34378 L
.14415 .34548 L
.18221 .34748 L
.22272 .35012 L
.26171 .35335 L
.30316 .35776 L
.34309 .36333 L
.3815 .37031 L
.42237 .37999 L
.46172 .39195 L
.49955 .4061 L
.53984 .42382 L
.57861 .44282 L
.61984 .46407 L
.65954 .48455 L
.69774 .50353 L
.73838 .52248 L
.77751 .53926 L
.81909 .55548 L
.85916 .56958 L
.89771 .58184 L
.93871 .5936 L
.97619 .60332 L
s
.02 w
.7381 .40628 Mdot
0 0 1 r
.5 Mabswid
[ .03 .03 ] 0 setdash
.02381 .32367 m
.06244 .32419 L
.10458 .32487 L
.14415 .32564 L
.18221 .32655 L
.22272 .32776 L
.26171 .32923 L
.30316 .33124 L
.34309 .33378 L
.3815 .33696 L
.42237 .34138 L
.46172 .34683 L
.49955 .35328 L
.53984 .36136 L
.57861 .37002 L
.61984 .37971 L
.65954 .38905 L
.69774 .3977 L
.73838 .40634 L
.77751 .414 L
.81909 .42139 L
.85916 .42782 L
.89771 .43341 L
.93871 .43877 L
.97619 .4432 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{178.062, 110},
  ImageMargins->{{0.75, 0}, {0, 0.75}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002b0000KR000`400?l00000o`00003o/_ooool0
05Wooooo0_l0001Gooooo`00FOooool00ol0003oooooooooo`1Fooooo`00FOooool00ol0003ooooo
ooooo`1?ooooo`;o00001Oooool005Wooooo0_l0001=ooooo`?o00001oooool005Wooooo00?o0000
ooooooooool0B?ooool4o`0000[ooooo001Iooooo`03o`000?oooooooooo04Gooooo0ol0000>oooo
o`00FOooool2o`0004;ooooo1?l0000Aooooo`00FOooool00ol0003oooooooooo`0nooooo`?o0000
5Oooool005Wooooo00?o0000ooooooooool0>oooool3o`0001Sooooo0017ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000iooooo`?o00006oooool0
04Oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool0=_ooool2o`0001kooooo000oooooo`Go00001?ooool00ol0003oooooooooo`0:oooo
o`04o`000?ooooooooooooooo`;o0000=Oooool2o`00023ooooo0018ooooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`00000cooooo`?o00008_ooool004Wooooo00?o0000oooo
ooooool01Oooool4o`0000Cooooo00?o0000ooooooooool0;oooool2o`0002Gooooo0015ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`05ooooo`;o0000;_ooool2o`00
02Oooooo0015ooooo`Go00001oooool5o`0000?ooooo00?o0000ooooooooool0:_ooool3o`0002Wo
oooo001Iooooo`03o`000?oooooooooo02Sooooo0_l0000/ooooo`00FOooool2o`0002Oooooo0_l0
000^ooooo`00FOooool00ol0003oooooooooo`0Sooooo`?o0000<?ooool005Wooooo00?o0000oooo
ooooool08Oooool2o`0003?ooooo001Iooooo`;o00008?ooool2o`0002cooooo1?l00005ooooo`00
FOooool00ol0003oooooooooo`0Looooo`?o0000:?ooool6o`0000Wooooo001Iooooo`03o`000?oo
oooooooo01[ooooo0_l0000Uooooo`Ko00003oooool005;ooooo0ol00004ooooo`;o00006Oooool2
o`0002Cooooo0ol0000Eooooo`00DOooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool05_ooool2o`00027ooooo1Ol0000Hooooo`00Boooool5o`0000Gooooo00Go0000oooo
ooooooooooooo`00000Gooooo`03o`000?oooooooooo01_ooooo1_l0000Mooooo`00EOooool01?l0
003oooooooooooooool2o`0001Cooooo0_l0000Kooooo`?o00008oooool0057ooooo1?l00004oooo
o`03o`000?oooooooooo017ooooo0_l0000Iooooo`Co00009_ooool0057ooooo00?o0000oooooooo
ool01Oooool2o`00013ooooo0_l0000Hooooo`?o0000:_ooool0057ooooo1Ol00003ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool05?ooool4o`0002gooooo001Iooooo`03o`000?oo
oooooooo00cooooo0_l0000Dooooo`?o0000<Oooool005Wooooo0_l0000;ooooo`;o00004_ooool4
o`0003Cooooo001Iooooo`03o`000?oooooooooo00Oooooo0ol0000Aooooo`?o0000>?ooool005Wo
oooo00?o0000ooooooooool01Oooool2o`00017ooooo0ol0000kooooo`00FOooool2o`0000Cooooo
0_l0000@ooooo`?o0000?_ooool005Wooooo00?o0000ooooooooool00ol0000@ooooo`;o0000@Ooo
ool005Wooooo0ol0000@ooooo`?o0000@oooool004Gooooo1Ol00003ooooo`03o`000?oooooooooo
00;ooooo0ol00002ooooo`Co00003_ooool3o`0003Oooooo2_l00005ooooo`00A_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00?o00000_ooool00ol0003oooooooooo`0:oooo
o`?o0000<oooool7o`0000oooooo000oooooo`Go00000oooool00ol0003oooooooooo`07ooooo`?o
000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`07ooooo`?o0000;oooool7o`0001Ko
oooo0018ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`04o`000?ooooooooooooooo`;o
00001_ooool2o`0002_ooooo1ol0000Mooooo`00AOooool01Ol0003ooooooooooooooooo000000;o
oooo0_l00003ooooo`Co00001?ooool00ol0003oooooooooo`02ooooo`?o00009_ooool7o`0002Co
oooo0015ooooo`03o`000?oooooooooo00Co00001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooo000000;o00008_ooool7o`0002_ooooo0011ooooo`So00002?ooool:o`0001kooooo1ol0
000booooo`001_ooool5o`0002Gooooo0ol00007ooooo`Oo00003oooool6o`0000?ooooo00?o0000
ooooooooool05_ooool7o`0000Sooooo0ol0000Uooooo`Go00001?ooool000Oooooo00Co0000oooo
oooooooo00009_ooool00ol0003oooooo`000006o`0001?ooooo0ol00009ooooo`;o00004?ooool7
o`00013ooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00004ooooo`001Ol00003
ooooo`03o`000?oooooooooo01kooooo2_l0000Eooooo`Go00003?ooool00ol0003oooooooooo`08
ooooo`Oo00005oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo0009oooo
o`03o`000?oooooooooo01;ooooo3_l00005ooooo`03o`000?oooooooooo00gooooo1ol0000Aoooo
o`04o`000?ooooooooooooooo`Oo00007_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00?ooooo0006oooooaSo00004oooool00ol0003oooooo`00000=o`0001Gooooo1ol0000Uoooo
o`03o`000?oooooooooo02Cooooo00Go0000ooooooooooooooooo`000004ooooo`001_ooool01Ol0
003ooooooooooooooooo000001[ooooo3_l0000Looooo`Oo00000oooool00ol0003oooooooooo`0U
ooooo`;o00009_ooool01Ol0003ooooooooooooooooo000000Cooooo0006oooooaoo00003?ooool0
0ol0003oooooooooo`0=ooooo`ko00002_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Gooooo0ol00005ooooo`00;?oooolEo`0001Sooooo0_l0001Gooooo`001_oooolVo`0002go
oooo00?o0000ooooooooool0E_ooool005Wooooo00?o0000ooooooooool0E_ooool00003ooooool0
003o00000:oo00000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`001_oooolWo`0002cooooo00?o0000ooooooooool0E_ooool000Ko
oooo1_l00?l4ooooo`Ko003o1Oooool6o`00o`Cooooo1_l00?l2oooooaGo00005oooool2o`0005Oo
oooo0006ooooob3o00002_ooool6o`00o`Cooooo1Ol00?l3ooooo`ko00002Oooool00ol0003ooooo
ooooo`1Fooooo`009_ooool>o`0000_ooooo00?o003oooooooooool00oooool4o`00o`Oooooo1ol0
0002ooooo`03o`000?oooooooooo05Kooooo0006oooooaWo00005Oooool>o`0000Oooooo0_l00?l4
ooooo`?o003o1Oooool7o`0005Cooooo000Oooooo`ko00005Oooool7o`0000Wooooo0ol00?l4oooo
o`03o`000?oooooooooo00;ooooo1ol0001=ooooo`00;Oooool7o`0001Gooooo1Ol0000;ooooo`Co
003o2?ooool7o`0004Kooooo000dooooo`Oo00004oooool3o`0000Sooooo0_l00002ooooo`;o003o
3Oooool7o`0003oooooo000kooooo`Oo00003oooool6o`0000;ooooo00?o0000ooooooooool02?oo
ool3o`00o`cooooo1ol0000hooooo`00@_ooool7o`0000kooooo1Ol0000;ooooo`?o003o4?ooool7
o`00037ooooo0015ooooo`Wo00001?ooool3o`0000Cooooo00?o0000ooooooooool00ol0000?oooo
o`;o003o4Oooool7o`0002[ooooo0016ooooo`04o`000?ooooooooooo`0000?ooooo0ol000000ooo
oooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool3o`0000kooooo0ol00?lE
ooooo`Oo00008oooool004Oooooo00?o0000ooooooooool01_ooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00007ooooo`?o00003_ooool00ol00?ooooooooooo`0Iooooo`Oo00007?ooool0
04Sooooo00?o0000ooooooooool01oooool4o`0000?ooooo00?o0000ooooooooool02Oooool2o`00
017ooooo0ol00?lKooooo`Oo00005Oooool004Gooooo00Go0000ooooooooooooooooo`000007oooo
o`Oo000000?oooooo`000?ooool03?ooool3o`00017ooooo0ol00?l3ooooo`?o00006Oooool7o`00
00kooooo0015ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`04oooo
o`?o00003oooool3o`0001Cooooo00?o0000o`00ool00?l00ol00?lMooooo`Wo00001Oooool004Ko
oooo0ol00008ooooo`Go00000oooool00ol0003oooooo`000002o`0000oooooo0ol0000Aooooo`?o
00000oooool2o`00obWooooo001Iooooo`03o`000?oooooooooo00;ooooo0_l0000@ooooo`?o0000
6_ooool3o`00ob;ooooo001Iooooo`;o00001Oooool2o`00017ooooo0_l0000Kooooo`?o003o7ooo
ool005Wooooo00?o0000ooooooooool01_ooool3o`00013ooooo0ol0000Oooooo`Ko003o5Oooool0
05Wooooo00?o0000ooooooooool02Oooool2o`00017ooooo0ol0000Vooooo`Co003o3Oooool005Wo
oooo0_l0000<ooooo`;o00004_ooool4o`0002Kooooo0ol00?l:ooooo`00FOooool00ol0003ooooo
ooooo`0=ooooo`;o00005?ooool3o`0002[ooooo00?o003oooooooooool00oooool005Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`Co0000;?ooool005;ooooo0ol00004
ooooo`;o00004Oooool2o`0001Sooooo0ol0000Yooooo`00DOooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool04_ooool2o`0001Wooooo1?l0000Uooooo`00EOooool01?l0
003oooooooooooooool2o`0001Gooooo0_l0000Kooooo`?o00008_ooool005Gooooo00Go0000oooo
ooooooooooooo`00000Hooooo`03o`000?oooooooooo01_ooooo1_l0000Looooo`00DOooool4o`00
00Cooooo00?o0000ooooooooool05oooool2o`00027ooooo1Ol0000Gooooo`00DOooool00ol0003o
ooooooooo`05ooooo`;o00006_ooool2o`0002Cooooo0ol0000Dooooo`00DOooool5o`0000?ooooo
00?o0000ooooooooool06oooool3o`0002Cooooo1_l0000>ooooo`00FOooool00ol0003ooooooooo
o`0Nooooo`;o0000:?ooool6o`0000Sooooo001Iooooo`;o00008Oooool2o`0002cooooo0ol00005
ooooo`00FOooool00ol0003oooooooooo`0Rooooo`?o0000<Oooool005Wooooo00?o0000oooooooo
ool09Oooool2o`0002oooooo001Iooooo`;o0000:?ooool2o`0002gooooo001Iooooo`03o`000?oo
oooooooo02Wooooo0ol0000Zooooo`00FOooool00ol0003oooooooooo`0/ooooo`;o0000:?ooool0
04Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`00
02oooooo0_l0000Vooooo`00Aoooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0`ooooo`?o00008oooool004Sooooo00?o0000oooooooo
ool02_ooool01Ol0003ooooooooooooooooo000003Gooooo0_l0000Qooooo`00B?ooool00ol0003o
ooooooooo`0:ooooo`04o`000?ooooooooooooooo`;o0000=_ooool2o`0001oooooo0019ooooo`03
o`000?oooooooooo00Gooooo1?l00004ooooo`03o`000?oooooooooo03Oooooo0ol0000Looooo`00
AOooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01Oooool2o`0003_o
oooo0_l0000Jooooo`00AOooool5o`0000Oooooo1Ol00003ooooo`03o`000?oooooooooo03cooooo
0ol0000Gooooo`00FOooool00ol0003oooooooooo`0oooooo`?o00005?ooool005Wooooo0_l00013
ooooo`Co00004?ooool005Wooooo00?o0000ooooooooool0A_ooool3o`0000gooooo001Iooooo`03
o`000?oooooooooo04Wooooo1?l00009ooooo`00FOooool2o`0004kooooo0ol00006ooooo`00FOoo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00?ooooo001Iooooo`03o`000?oooooo
oooo05Kooooo001Iooooo`;o0000Eoooool00001\
\>"],
  ImageRangeCache->{{{78.625, 255.688}, {374.812, 265.812}} -> {-4.02832, \
37.1933, 0.0239681, 0.176011}}]
}, Open  ]],

Cell[TextData[StyleBox["Getting information out of the solution formula: Name \
the solution function",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "Suppose, for example, we want to know the value of  ",
  StyleBox["t",
    FontSlant->"Italic"],
  " for which the IVP solution has the value 1. FindRoot should be able to \
find it. We first turn the solution into a named function f (see the last \
page in Part 2, Section 3). We also enter f[t] to check that the correct \
solution formula has been used."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
f := soln[[1,1,2]]
f[t]\
\>", "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(3\ \[ExponentialE]\^\(\(-\(\[Pi]\/4\)\) + ArcTan[t]\)\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[TextData[{
  "Now find the solution to ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = 1. (The output is named a.)"
}], "Text"],

Cell[CellGroupData[{

Cell["a = FindRoot[ f[t] == 1, {t,0.5} ]", "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \({t \[Rule] \(-0.3238750955307887`\)}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["And check that it is correct.", "Text"],

Cell[TextData[StyleBox["We wish to apply the function f to the value obtained \
above. There are two ways to do this. First note that the number 0.323875 can \
be obtained as a[[ 1, 2 ]]. This is how we get the first evaluation. The \
second one uses a substitution (a into f[t]).", "Note"]], "Text"],

Cell[CellGroupData[{

Cell["f[ a[[1,2]] ]", "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(1.`\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["f[t]/.a", "Input",
  CellLabel->"In[35]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(1.`\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[StyleBox["A solution formula in terms of the initial condition",
  
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "We look for a solution formula in terms of a generic initial condition, \
say ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(t0) = y0, as follows."
}], "Text"],

Cell[CellGroupData[{

Cell["IVPsoln = DSolve[ {DE, y[t0]==y0}, y, t ]", "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    RowBox[{\(DSolve::"bvfail"\), \(\(:\)\(\ \)\), "\<\"For some branches of \
the general solution, unable to solve the conditions. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"DSolve::bvfail\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[2]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
This method fails. However, another method can be used. First \
obtain the general solution.\
\>", "Text"],

Cell[CellGroupData[{

Cell["gensoln = DSolve[ DE, y , t ]", "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{t}, \[ExponentialE]\^ArcTan[t]\ C[1]]}}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["Use the output to make a function with C[1] replaced by c.", "Text"],

Cell["g := gensoln[[1,1,2]]/.C[1]->c", "Input",
  CellLabel->"In[10]:="],

Cell["Let's check the g is indeed the function we want.", "Text"],

Cell[CellGroupData[{

Cell["\<\
g[t]
g[1]\
\>", "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(c\ \[ExponentialE]\^ArcTan[t]\)], "Output",
  CellLabel->"Out[11]="],

Cell[BoxData[
    \(c\ \[ExponentialE]\^\(\[Pi]/4\)\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["\<\
Now use the function g to obtain the solution satisfying g(t0) = \
y0. First define this as an identity.\
\>", "Text"],

Cell[CellGroupData[{

Cell["eqn = g[t0] == y0", "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(c\ \[ExponentialE]\^ArcTan[t0] \[Equal] y0\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
Now use Solve to solve for c, substitute into the formula for g[t], \
and use it to define the function phi. This is carried out below, one step at \
a time.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Solve[ eqn, c ]", "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({{c \[Rule] \[ExponentialE]\^\(-ArcTan[t0]\)\ y0}}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["g[t]/.%[[1,1]]", "Input",
  CellLabel->"In[37]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\[ExponentialE]\^\(ArcTan[t] - ArcTan[t0]\)\ y0\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell["\<\
The next step fails when the evaluate function is not \
applied.\
\>", "Text"],

Cell["phi[t_,t0_,y0_] := Evaluate[%]", "Input",
  CellLabel->"In[38]:="],

Cell["Here we check that phi is defined correctly.", "Text"],

Cell[CellGroupData[{

Cell["phi[u,v,w]", "Input",
  CellLabel->"In[39]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\[ExponentialE]\^\(ArcTan[u] - ArcTan[v]\)\ w\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell["\<\
And here we check that phi, evaluated at t0,t0,y0 has the value y0.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell["phi[t0,t0,y0]", "Input",
  CellLabel->"In[40]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(y0\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell["\<\
We now use the phi function to create pictures of solutions \
satisfying specific initial conditions.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
startpoints = ListPlot[
       Table[ {Cos[n*Pi/4],Sin[n*Pi/4]}, {n,0,7}],
       PlotStyle->PointSize[0.04],
       DisplayFunction->Identity ];
plots = Table[ Plot[ phi[t,Cos[n*Pi/4],Sin[n*Pi/4]], {t,Cos[n*Pi/4],3},
       DisplayFunction->Identity ], {n,0,7} ];
Show[ startpoints, plots, DisplayFunction->$DisplayFunction, AspectRatio->1,
       PlotRange->{{-3,3},{-3,3}}, Frame->True, Axes->None ]\
\>", "Input",
  CellLabel->"In[78]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.5 0.166667 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -12 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -6 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(-2)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(-1)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(1)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(2)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(3)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.16667 .99375 m
.16667 1 L
s
.33333 .99375 m
.33333 1 L
s
.5 .99375 m
.5 1 L
s
.66667 .99375 m
.66667 1 L
s
.83333 .99375 m
.83333 1 L
s
.125 Mabswid
.03333 .99625 m
.03333 1 L
s
.06667 .99625 m
.06667 1 L
s
.1 .99625 m
.1 1 L
s
.13333 .99625 m
.13333 1 L
s
.2 .99625 m
.2 1 L
s
.23333 .99625 m
.23333 1 L
s
.26667 .99625 m
.26667 1 L
s
.3 .99625 m
.3 1 L
s
.36667 .99625 m
.36667 1 L
s
.4 .99625 m
.4 1 L
s
.43333 .99625 m
.43333 1 L
s
.46667 .99625 m
.46667 1 L
s
.53333 .99625 m
.53333 1 L
s
.56667 .99625 m
.56667 1 L
s
.6 .99625 m
.6 1 L
s
.63333 .99625 m
.63333 1 L
s
.7 .99625 m
.7 1 L
s
.73333 .99625 m
.73333 1 L
s
.76667 .99625 m
.76667 1 L
s
.8 .99625 m
.8 1 L
s
.86667 .99625 m
.86667 1 L
s
.9 .99625 m
.9 1 L
s
.93333 .99625 m
.93333 1 L
s
.96667 .99625 m
.96667 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .5 m
1 .5 L
s
.99375 .66667 m
1 .66667 L
s
.99375 .83333 m
1 .83333 L
s
.125 Mabswid
.99625 .03333 m
1 .03333 L
s
.99625 .06667 m
1 .06667 L
s
.99625 .1 m
1 .1 L
s
.99625 .13333 m
1 .13333 L
s
.99625 .2 m
1 .2 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .26667 m
1 .26667 L
s
.99625 .3 m
1 .3 L
s
.99625 .36667 m
1 .36667 L
s
.99625 .4 m
1 .4 L
s
.99625 .43333 m
1 .43333 L
s
.99625 .46667 m
1 .46667 L
s
.99625 .53333 m
1 .53333 L
s
.99625 .56667 m
1 .56667 L
s
.99625 .6 m
1 .6 L
s
.99625 .63333 m
1 .63333 L
s
.99625 .7 m
1 .7 L
s
.99625 .73333 m
1 .73333 L
s
.99625 .76667 m
1 .76667 L
s
.99625 .8 m
1 .8 L
s
.99625 .86667 m
1 .86667 L
s
.99625 .9 m
1 .9 L
s
.99625 .93333 m
1 .93333 L
s
.99625 .96667 m
1 .96667 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.04 w
.66667 .5 Mdot
.61785 .61785 Mdot
.5 .66667 Mdot
.38215 .61785 Mdot
.33333 .5 Mdot
.38215 .38215 Mdot
.5 .33333 Mdot
.61785 .38215 Mdot
.5 Mabswid
.66667 .5 m
.66708 .5 L
.66745 .5 L
.66788 .5 L
.66829 .5 L
.66867 .5 L
.66902 .5 L
.6694 .5 L
.66981 .5 L
.67022 .5 L
.67065 .5 L
.67107 .5 L
.67145 .5 L
.67189 .5 L
.67214 .5 L
.67237 .5 L
.6728 .5 L
.67325 .5 L
.67348 .5 L
.67372 .5 L
.67415 .5 L
.67439 .5 L
.67461 .5 L
.67486 .5 L
.67512 .5 L
.67535 .5 L
.6756 .5 L
.67605 .5 L
.67648 .5 L
.67689 .5 L
.67728 .5 L
.67765 .5 L
.67805 .5 L
.67849 .5 L
.67892 .5 L
.67938 .5 L
.67976 .5 L
.68019 .5 L
.68044 .5 L
.68067 .5 L
.68092 .5 L
.68118 .5 L
.68163 .5 L
.68189 .5 L
.68212 .5 L
.68257 .5 L
.68297 .5 L
.6832 .5 L
.68344 .5 L
.68388 .5 L
Mistroke
.68415 .5 L
.6844 .5 L
.68463 .5 L
.68487 .5 L
.68514 .5 L
.68542 .5 L
.68567 .5 L
.68593 .5 L
.68618 .5 L
.6864 .5 L
.68667 .5 L
.68691 .5 L
.68735 .5 L
.6876 .5 L
.68783 .5 L
.68824 .5 L
.68868 .5 L
.68909 .5 L
.68947 .5 L
.68989 .5 L
.69035 .5 L
.69058 .5 L
.69083 .5 L
.69128 .5 L
.69152 .5 L
.69175 .5 L
.692 .5 L
.69226 .5 L
.69271 .5 L
.69296 .5 L
.6932 .5 L
.69363 .5 L
.69404 .5 L
.6945 .5 L
.69494 .5 L
.69533 .5 L
.69576 .5 L
.69617 .5 L
.69654 .5 L
.69695 .5 L
.6974 .5 L
.69763 .5 L
.69787 .5 L
.69831 .5 L
.69855 .5 L
.69877 .5 L
.69902 .5 L
.69928 .5 L
.69971 .5 L
.69996 .5 L
Mistroke
.70019 .5 L
.70062 .5 L
.70101 .5 L
.70146 .5 L
.7019 .5 L
.7023 .5 L
.70267 .5 L
.70309 .5 L
.70349 .5 L
.70387 .5 L
.70421 .5 L
.70458 .5 L
.70498 .5 L
.70538 .5 L
.70581 .5 L
.70621 .5 L
.70658 .5 L
.70701 .5 L
.70726 .5 L
.70748 .5 L
.7079 .5 L
.70834 .5 L
.70874 .5 L
.70918 .5 L
.70963 .5 L
.71005 .5 L
.71045 .5 L
.71081 .5 L
.71123 .5 L
.71162 .5 L
.71205 .5 L
.71251 .5 L
.71289 .5 L
.71332 .5 L
.71378 .5 L
.71404 .5 L
.71427 .5 L
.71473 .5 L
.71516 .5 L
.71556 .5 L
.71593 .5 L
.71635 .5 L
.71675 .5 L
.71712 .5 L
.71746 .5 L
.71783 .5 L
.71822 .5 L
.71862 .5 L
.71905 .5 L
.71945 .5 L
Mistroke
.71982 .5 L
.72025 .5 L
.72049 .5 L
.72071 .5 L
.72112 .5 L
.72156 .5 L
.72198 .5 L
.72244 .5 L
.72288 .5 L
.72328 .5 L
.72368 .5 L
.72404 .5 L
.72446 .5 L
.72485 .5 L
.72528 .5 L
.72574 .5 L
.72613 .5 L
.72655 .5 L
.72701 .5 L
.72727 .5 L
.7275 .5 L
.72796 .5 L
.72839 .5 L
.72876 .5 L
.72917 .5 L
.72959 .5 L
.72999 .5 L
.73036 .5 L
.7307 .5 L
.73107 .5 L
.73146 .5 L
.73186 .5 L
.73229 .5 L
.73269 .5 L
.73305 .5 L
.73348 .5 L
.73373 .5 L
.73395 .5 L
.73436 .5 L
.7348 .5 L
.73522 .5 L
.73568 .5 L
.73612 .5 L
.73652 .5 L
.73692 .5 L
.73729 .5 L
.7377 .5 L
.7381 .5 L
.73853 .5 L
.73899 .5 L
Mistroke
.73938 .5 L
.7398 .5 L
.74026 .5 L
.74052 .5 L
.74076 .5 L
.74121 .5 L
.74165 .5 L
.74201 .5 L
.74242 .5 L
.74284 .5 L
.74324 .5 L
.74361 .5 L
.74395 .5 L
.74432 .5 L
.74472 .5 L
.74512 .5 L
.74554 .5 L
.74595 .5 L
.74631 .5 L
.74674 .5 L
.74698 .5 L
.74721 .5 L
.74762 .5 L
.74805 .5 L
.74848 .5 L
.74894 .5 L
.74938 .5 L
.74978 .5 L
.75015 .5 L
.75055 .5 L
.75097 .5 L
.75136 .5 L
.7518 .5 L
.75225 .5 L
.75264 .5 L
.75307 .5 L
.75353 .5 L
.75379 .5 L
.75403 .5 L
.75448 .5 L
.75492 .5 L
.75529 .5 L
.75569 .5 L
.75612 .5 L
.75651 .5 L
.75689 .5 L
.75723 .5 L
.75762 .5 L
.75799 .5 L
.75839 .5 L
Mistroke
.75882 .5 L
.75922 .5 L
.75959 .5 L
.76002 .5 L
.76026 .5 L
.76048 .5 L
.76089 .5 L
.76133 .5 L
.76176 .5 L
.762 .5 L
.76222 .5 L
.76263 .5 L
.76306 .5 L
.76345 .5 L
.76382 .5 L
.76422 .5 L
.76465 .5 L
.76508 .5 L
.76532 .5 L
.76555 .5 L
.76601 .5 L
.76627 .5 L
.7665 .5 L
.76692 .5 L
.76738 .5 L
.76781 .5 L
.7682 .5 L
.76857 .5 L
.76897 .5 L
.76935 .5 L
.76969 .5 L
.77009 .5 L
.77053 .5 L
.77094 .5 L
.77132 .5 L
.77175 .5 L
.77216 .5 L
.77253 .5 L
.77292 .5 L
.77335 .5 L
.77381 .5 L
.7742 .5 L
.77462 .5 L
.77508 .5 L
.7755 .5 L
.77573 .5 L
.77597 .5 L
.77622 .5 L
.77646 .5 L
.7769 .5 L
Mistroke
.7773 .5 L
.77776 .5 L
.7782 .5 L
.77859 .5 L
.77901 .5 L
.77941 .5 L
.77976 .5 L
.78018 .5 L
.78064 .5 L
.78107 .5 L
.78147 .5 L
.78189 .5 L
.78234 .5 L
.78277 .5 L
.78316 .5 L
.78362 .5 L
.78388 .5 L
.78412 .5 L
.78456 .5 L
.78478 .5 L
.78503 .5 L
.78526 .5 L
.78551 .5 L
.78596 .5 L
.78621 .5 L
.78644 .5 L
.7867 .5 L
.78697 .5 L
.7872 .5 L
.78746 .5 L
.7877 .5 L
.78792 .5 L
.78834 .5 L
.78879 .5 L
.78921 .5 L
.78967 .5 L
.79011 .5 L
.79051 .5 L
.79091 .5 L
.79128 .5 L
.7917 .5 L
.79209 .5 L
.79252 .5 L
.79298 .5 L
.79337 .5 L
.79379 .5 L
.79425 .5 L
.79451 .5 L
.79475 .5 L
.7952 .5 L
Mistroke
.79564 .5 L
.796 .5 L
.79641 .5 L
.79683 .5 L
.79723 .5 L
.7976 .5 L
.79794 .5 L
.79831 .5 L
.79871 .5 L
.79911 .5 L
.79953 .5 L
.79993 .5 L
.8003 .5 L
.80073 .5 L
.80097 .5 L
.8012 .5 L
.80161 .5 L
.80204 .5 L
.80247 .5 L
.80293 .5 L
.80337 .5 L
.80377 .5 L
.80417 .5 L
.80454 .5 L
.80496 .5 L
.80535 .5 L
.80578 .5 L
.80624 .5 L
.80663 .5 L
.80706 .5 L
.80752 .5 L
.80778 .5 L
.80801 .5 L
.80847 .5 L
.8089 .5 L
.80927 .5 L
.80968 .5 L
.8101 .5 L
.8105 .5 L
.81087 .5 L
.81121 .5 L
.8116 .5 L
.81198 .5 L
.81238 .5 L
.8128 .5 L
.81321 .5 L
.81357 .5 L
.814 .5 L
.81424 .5 L
.81447 .5 L
Mistroke
.81488 .5 L
.81531 .5 L
.81574 .5 L
.81598 .5 L
.8162 .5 L
.81661 .5 L
.81705 .5 L
.81744 .5 L
.8178 .5 L
.8182 .5 L
.81863 .5 L
.81906 .5 L
.81931 .5 L
.81953 .5 L
.81999 .5 L
.82025 .5 L
.82048 .5 L
.8209 .5 L
.82136 .5 L
.82179 .5 L
.82219 .5 L
.82255 .5 L
.82295 .5 L
.82333 .5 L
.82367 .5 L
.82407 .5 L
.82451 .5 L
.82492 .5 L
.8253 .5 L
.82573 .5 L
.82614 .5 L
.82651 .5 L
.8269 .5 L
.82733 .5 L
.82779 .5 L
.82818 .5 L
.8286 .5 L
.82906 .5 L
.82948 .5 L
.8297 .5 L
.82995 .5 L
.8302 .5 L
.83044 .5 L
.83088 .5 L
.83128 .5 L
.83172 .5 L
.83218 .5 L
.83257 .5 L
.83299 .5 L
.83338 .5 L
Mistroke
.83374 .5 L
.83416 .5 L
.83462 .5 L
.83505 .5 L
.83544 .5 L
.83587 .5 L
.83632 .5 L
.83675 .5 L
.83714 .5 L
.8376 .5 L
.83786 .5 L
.8381 .5 L
.83853 .5 L
.83876 .5 L
.839 .5 L
.83924 .5 L
.83949 .5 L
.83994 .5 L
.84018 .5 L
.84042 .5 L
.84067 .5 L
.84094 .5 L
.84118 .5 L
.84143 .5 L
.84168 .5 L
.8419 .5 L
.84232 .5 L
.84277 .5 L
.84319 .5 L
.84365 .5 L
.84408 .5 L
.84449 .5 L
.84489 .5 L
.84525 .5 L
.84567 .5 L
.84606 .5 L
.84649 .5 L
.84695 .5 L
.84734 .5 L
.84777 .5 L
.84823 .5 L
.84848 .5 L
.84872 .5 L
.84918 .5 L
.84961 .5 L
.84998 .5 L
.85038 .5 L
.8508 .5 L
.8512 .5 L
.85157 .5 L
Mistroke
.85191 .5 L
.85228 .5 L
.85268 .5 L
.85308 .5 L
.8535 .5 L
.85391 .5 L
.85427 .5 L
.8547 .5 L
.85494 .5 L
.85517 .5 L
.85558 .5 L
.85601 .5 L
.85644 .5 L
.8569 .5 L
.85734 .5 L
.85774 .5 L
.85814 .5 L
.85851 .5 L
.85893 .5 L
.85932 .5 L
.85975 .5 L
.86021 .5 L
.8606 .5 L
.86103 .5 L
.86149 .5 L
.86175 .5 L
.86198 .5 L
.86244 .5 L
.86287 .5 L
.86324 .5 L
.86364 .5 L
.86407 .5 L
.86447 .5 L
.86484 .5 L
.86518 .5 L
.86557 .5 L
.86594 .5 L
.86634 .5 L
.86677 .5 L
.86717 .5 L
.86754 .5 L
.86797 .5 L
.86821 .5 L
.86843 .5 L
.86885 .5 L
.86928 .5 L
.86971 .5 L
.86995 .5 L
.87017 .5 L
.87058 .5 L
Mistroke
.87101 .5 L
.8714 .5 L
.87176 .5 L
.87216 .5 L
.87259 .5 L
.87303 .5 L
.87327 .5 L
.8735 .5 L
.87396 .5 L
.87421 .5 L
.87445 .5 L
.87487 .5 L
.87532 .5 L
.87575 .5 L
.87615 .5 L
.87652 .5 L
.87692 .5 L
.87729 .5 L
.87763 .5 L
.87803 .5 L
.87847 .5 L
.87888 .5 L
.87926 .5 L
.8797 .5 L
.8801 .5 L
.88047 .5 L
.88086 .5 L
.88129 .5 L
.88175 .5 L
.88214 .5 L
.88256 .5 L
.88302 .5 L
.88345 .5 L
.88367 .5 L
.88391 .5 L
.88416 .5 L
.8844 .5 L
.88484 .5 L
.88524 .5 L
.88568 .5 L
.88614 .5 L
.88653 .5 L
.88695 .5 L
.88734 .5 L
.8877 .5 L
.88812 .5 L
.88858 .5 L
.88901 .5 L
.8894 .5 L
.88982 .5 L
Mistroke
.89028 .5 L
.89071 .5 L
.8911 .5 L
.89156 .5 L
.89181 .5 L
.89205 .5 L
.89249 .5 L
.89272 .5 L
.89296 .5 L
.8932 .5 L
.89345 .5 L
.89389 .5 L
.89414 .5 L
.89437 .5 L
.89463 .5 L
.8949 .5 L
.89514 .5 L
.89539 .5 L
.89563 .5 L
.89586 .5 L
.89628 .5 L
.89673 .5 L
.89715 .5 L
.89761 .5 L
.89804 .5 L
.89845 .5 L
.89885 .5 L
.89921 .5 L
.89963 .5 L
.90002 .5 L
.90045 .5 L
.90091 .5 L
.90129 .5 L
.90172 .5 L
.90218 .5 L
.90244 .5 L
.90267 .5 L
.90313 .5 L
.90356 .5 L
.90393 .5 L
.90434 .5 L
.90476 .5 L
.90516 .5 L
.90553 .5 L
.90587 .5 L
.90624 .5 L
.90663 .5 L
.90703 .5 L
.90746 .5 L
.90786 .5 L
Mistroke
.90823 .5 L
.90866 .5 L
.9089 .5 L
.90912 .5 L
.90953 .5 L
.90997 .5 L
.91039 .5 L
.91085 .5 L
.91129 .5 L
.91169 .5 L
.9121 .5 L
.91246 .5 L
.91288 .5 L
.91327 .5 L
.9137 .5 L
.91416 .5 L
.91455 .5 L
.91498 .5 L
.91544 .5 L
.9157 .5 L
.91593 .5 L
.91639 .5 L
.91682 .5 L
.91719 .5 L
.9176 .5 L
.91802 .5 L
.91842 .5 L
.91879 .5 L
.91913 .5 L
.9195 .5 L
.91989 .5 L
.92029 .5 L
.92072 .5 L
.92112 .5 L
.92149 .5 L
.92192 .5 L
.92216 .5 L
.92238 .5 L
.9228 .5 L
.92323 .5 L
.92366 .5 L
.9239 .5 L
.92412 .5 L
.92453 .5 L
.92496 .5 L
.92535 .5 L
.92571 .5 L
.92611 .5 L
.92654 .5 L
.92697 .5 L
Mistroke
.92722 .5 L
.92744 .5 L
.9279 .5 L
.92816 .5 L
.9284 .5 L
.92881 .5 L
.92927 .5 L
.9297 .5 L
.9301 .5 L
.93046 .5 L
.93086 .5 L
.93124 .5 L
.93158 .5 L
.93198 .5 L
.93241 .5 L
.93283 .5 L
.93321 .5 L
.93364 .5 L
.93405 .5 L
.93441 .5 L
.93481 .5 L
.93524 .5 L
.93569 .5 L
.93608 .5 L
.93651 .5 L
.93697 .5 L
.93739 .5 L
.93761 .5 L
.93785 .5 L
.93811 .5 L
.93835 .5 L
.93878 .5 L
.93918 .5 L
.93962 .5 L
.94009 .5 L
.94048 .5 L
.94089 .5 L
.94129 .5 L
.94164 .5 L
.94206 .5 L
.94252 .5 L
.94295 .5 L
.94334 .5 L
.94377 .5 L
.94422 .5 L
.94465 .5 L
.94504 .5 L
.9455 .5 L
.94576 .5 L
.94599 .5 L
Mistroke
.94643 .5 L
.94668 .5 L
.9469 .5 L
.94714 .5 L
.94739 .5 L
.94783 .5 L
.94808 .5 L
.94832 .5 L
.94857 .5 L
.94884 .5 L
.94908 .5 L
.94933 .5 L
.94957 .5 L
.9498 .5 L
.95022 .5 L
.95067 .5 L
.95109 .5 L
.95155 .5 L
.95198 .5 L
.95239 .5 L
.95278 .5 L
.95315 .5 L
.95356 .5 L
.95396 .5 L
.95439 .5 L
.95484 .5 L
.95523 .5 L
.95566 .5 L
.95612 .5 L
.95638 .5 L
.95661 .5 L
.95707 .5 L
.9575 .5 L
.95787 .5 L
.95827 .5 L
.9587 .5 L
.95909 .5 L
.95946 .5 L
.9598 .5 L
.96018 .5 L
.96057 .5 L
.96097 .5 L
.96139 .5 L
.9618 .5 L
.96216 .5 L
.96259 .5 L
.96283 .5 L
.96306 .5 L
.96347 .5 L
.96391 .5 L
Mistroke
.96433 .5 L
.96479 .5 L
.96523 .5 L
.96563 .5 L
.96603 .5 L
.96639 .5 L
.96681 .5 L
.96721 .5 L
.96764 .5 L
.96809 .5 L
.96848 .5 L
.96891 .5 L
.96937 .5 L
.96963 .5 L
.96986 .5 L
.97032 .5 L
.97075 .5 L
.97112 .5 L
.97153 .5 L
.97195 .5 L
.97235 .5 L
.97272 .5 L
.97306 .5 L
.97343 .5 L
.97383 .5 L
.97423 .5 L
.97465 .5 L
.97505 .5 L
.97542 .5 L
.97585 .5 L
.97609 .5 L
.97632 .5 L
.97673 .5 L
.97716 .5 L
.97759 .5 L
.97783 .5 L
.97805 .5 L
.97846 .5 L
.97889 .5 L
.97928 .5 L
.97964 .5 L
.98004 .5 L
.98047 .5 L
.9809 .5 L
.98115 .5 L
.98137 .5 L
.98183 .5 L
.98209 .5 L
.98232 .5 L
.98274 .5 L
Mistroke
.9832 .5 L
.98363 .5 L
.98402 .5 L
.98439 .5 L
.98479 .5 L
.98516 .5 L
.98551 .5 L
.98591 .5 L
.98634 .5 L
.98676 .5 L
.98714 .5 L
.98757 .5 L
.98798 .5 L
.98834 .5 L
.98874 .5 L
.98917 .5 L
.98962 .5 L
.99001 .5 L
.99044 .5 L
.99075 .5 L
.99103 .5 L
.99135 .5 L
.99168 .5 L
.99197 .5 L
.99224 .5 L
.99253 .5 L
.99285 .5 L
.99312 .5 L
.99341 .5 L
.99372 .5 L
.994 .5 L
.99427 .5 L
.99451 .5 L
.99479 .5 L
.99505 .5 L
.99534 .5 L
.99565 .5 L
.99598 .5 L
.99629 .5 L
.99658 .5 L
.99684 .5 L
.99714 .5 L
.99743 .5 L
.99774 .5 L
.99807 .5 L
.99838 .5 L
.99866 .5 L
.99899 .5 L
.99935 .5 L
.99969 .5 L
Mistroke
1 .5 L
Mfstroke
.61785 .61785 m
.63335 .62506 L
.65026 .63264 L
.66614 .63946 L
.68141 .64572 L
.69766 .65205 L
.71331 .65782 L
.72994 .66362 L
.74596 .66888 L
.76138 .67366 L
.77777 .67845 L
.79356 .6828 L
.80875 .68675 L
.82491 .69071 L
.84047 .69432 L
.85701 .69794 L
.87294 .70123 L
.88827 .70423 L
.90458 .70726 L
.92028 .71002 L
.93696 .7128 L
.95304 .71534 L
.96851 .71767 L
.98496 .72002 L
1 .72207 L
s
.5 .66667 m
.52028 .68812 L
.5424 .71382 L
.56318 .73945 L
.58316 .76476 L
.60443 .7917 L
.6249 .81706 L
.64666 .84296 L
.66762 .86659 L
.68779 .88796 L
.70924 .90919 L
.7299 .92817 L
.74976 .94512 L
.77092 .96187 L
.79127 .97678 L
.81291 .99146 L
s
.81291 .99146 m
.82652 1 L
s
.38215 .61785 m
.40721 .63123 L
.43455 .65001 L
.46022 .67254 L
.48491 .69926 L
.51119 .73321 L
.53649 .77054 L
.56337 .81364 L
.58928 .85662 L
.6142 .89767 L
.64071 .93968 L
.66624 .97771 L
s
.66624 .97771 m
.68235 1 L
s
.33333 .5 m
.36038 .5 L
.38987 .5 L
.41757 .5 L
.44421 .5 L
.47257 .5 L
.49986 .5 L
.52888 .5 L
.55683 .5 L
.58372 .5 L
.61232 .5 L
.63987 .5 L
.66635 .5 L
.69455 .5 L
.72169 .5 L
.75055 .5 L
.77835 .5 L
.80508 .5 L
.83353 .5 L
.86093 .5 L
.89003 .5 L
.91808 .5 L
.94506 .5 L
.97377 .5 L
1 .5 L
s
.38215 .38215 m
.40721 .36877 L
.43455 .34999 L
.46022 .32746 L
.48491 .30074 L
.51119 .26679 L
.53649 .22946 L
.56337 .18636 L
.58928 .14338 L
.6142 .10233 L
.64071 .06032 L
.66624 .02229 L
s
.66624 .02229 m
.68235 0 L
s
.5 .33333 m
.52028 .31188 L
.5424 .28618 L
.56318 .26055 L
.58316 .23524 L
.60443 .2083 L
.6249 .18294 L
.64666 .15704 L
.66762 .13341 L
.68779 .11204 L
.70924 .09081 L
.7299 .07183 L
.74976 .05488 L
.77092 .03813 L
.79127 .02322 L
.81291 .00854 L
s
.81291 .00854 m
.82652 0 L
s
.61785 .38215 m
.63335 .37494 L
.65026 .36736 L
.66614 .36054 L
.68141 .35428 L
.69766 .34795 L
.71331 .34218 L
.72994 .33638 L
.74596 .33112 L
.76138 .32634 L
.77777 .32155 L
.79356 .3172 L
.80875 .31325 L
.82491 .30929 L
.84047 .30568 L
.85701 .30206 L
.87294 .29877 L
.88827 .29577 L
.90458 .29274 L
.92028 .28998 L
.93696 .2872 L
.95304 .28466 L
.96851 .28233 L
.98496 .27998 L
1 .27793 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{164, 164},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002T0000Y2000`400?l00000o`00003oY?ooool0
0:Cooooo000Vooooo`Go00005?ooool3o`0001?ooooo0_l0000Fooooo`?o00005?ooool5o`0001Go
oooo0ol00003ooooo`009oooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo017o
oooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`0Dooooo`04o`000?oooooooooo
o`0001Cooooo00Go0000ooooooooooooooooo`000002ooooo`008?ooool5o`0000?ooooo00?o0000
ooooooooool03Oooool5o`0000?ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0
000Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool1o`00007ooooo0Ooo
ool002Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo
ooooo`0001Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`;o00000ooo
ool002Kooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo017ooooo00Co
0000oooooooooooo00005_ooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool0
00006?ooool1o`00007ooooo0Oooool002Kooooo00Go0000ooooooooooooooooo`00000Dooooo`;o
00004oooool01?l0003oooooooooool0000Eooooo`;o00005Oooool01Ol0003ooooooooooooooooo
000001Cooooo00Go0000ooooooooooooooooo`000002ooooo`009oooool3o`0001Kooooo00?o0000
ooooooooool04_ooool2o`0001Oooooo00?o0000ooooooooool05?ooool3o`0001Kooooo0ol00003
ooooo`00Y?ooool00:Cooooo002Tooooo`003OoooonDo`0000?ooooo000=ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`?o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00Oooool000gooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00Oooool000gooooo0_l0001Ooooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool2o`0000?ooooo000=ooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool03Oooool2o`00027ooooo00?o0000oooooooo
ool00Oooool000gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00Ooo
ool000gooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool00Oooool000gooooo0_l0001Looooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool08oooool2o`0000?ooooo000=ooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool02_ooool2o`0002Oooooo00?o0000ooooooooool00Oooool000gooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00Oooool000gooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00Oooool000gooooo0_l0001Hooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0:Oooool2o`0000?ooooo000=ooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo007ooooo000=ooooo`;o0000EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02gooooo0_l00003ooooo`003Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`01ooooo`001_ooool5o`0000;ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool00Oooool000Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`01ooooo`001Ol00003ooooo`03o`000?oooooooooo00;ooooo0_l0001Cooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0009ooooo`05o`000?oooooo
ooooooooool00000Doooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool00Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`01ooooo`001oooool3o`0000?ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00Oooool000gooooo0_l0001@oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=?ooool2o`0000?ooooo000=ooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo007ooooo000=ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo007ooooo000=ooooo`;o0000COooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`003Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`01ooooo`003Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`01ooooo`003Oooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`01ooooo`003Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`01ooooo`003Oooool2o`0004Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0looooo`;o00000oooool000gooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool00Oooool000gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03Wooooo1ol00003ooooo`003Oooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0<oooool7o`0000Kooooo00?o0000ooooooooool00Ooo
ool000gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02oooooo1Ol0000=ooooo`03o`000?oooooooooo007ooooo000=ooooo`;o0000AOooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo1?l0000Aooooo`;o00000oooool000go
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02So
oooo1Ol0000Fooooo`03o`000?oooooooooo007ooooo0007ooooo`?o00000oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool5o`0001_ooooo
00?o0000ooooooooool00Oooool000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo00Co00009Oooool2o`00023ooooo00?o0000ooooooooool00Ooo
ool000Go00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo0_l00002
ooooo`Go00008?ooool5o`0002;ooooo00?o0000ooooooooool00Oooool000Sooooo00?o0000oooo
ooooool00_ooool2o`00043ooooo00?o0000ooooooooool00_ooool5o`0001kooooo0_l0000Voooo
o`;o00000oooool000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00?ooooo1Ol0000Looooo`;o0000:Oooool00ol0003oooooooooo`01ooooo`00
1oooool2o`0000Cooooo00?o0000ooooooooool0??ooool2o`0000Oooooo0ol0000Jooooo`?o0000
:oooool00ol0003oooooooooo`01ooooo`002?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool08_ooool2o`0002kooooo00?o0000ooooooooool00Ooo
ool000gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Qooooo`;o0000<?ooool0
0ol0003oooooooooo`01ooooo`003Oooool2o`0003Gooooo0ol000000ooooooo0000o`00000Loooo
o`?o00000_ooool3o`00037ooooo0_l00003ooooo`003Oooool00ol0003oooooooooo`0cooooo`Go
00007Oooool6o`0003Gooooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0
<oooool5o`0001gooooo1Ol0000fooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oo
oooooooo03?ooooo1Ol0000Mooooo`Go0000=_ooool00ol0003oooooooooo`01ooooo`003Oooool0
0ol0003oooooooooo`0dooooo`?o00007oooool3o`0003Oooooo00?o0000ooooooooool00Oooool0
00gooooo0_l0002@ooooo`;o00000oooool000gooooo00?o0000ooooooooool0T?ooool00ol0003o
ooooooooo`01ooooo`003Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo007ooooo
000=ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool00Oooool000gooooo0_l0002@
ooooo`;o00000oooool000gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`01oooo
o`003Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`00
0?oooooooooo093ooooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`01ooooo`003Oooool2o`00093ooooo0_l00003ooooo`003Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo093o
oooo00?o0000ooooooooool00Oooool000Sooooo0_l00003ooooo`03o`000?oooooooooo093ooooo
00?o0000ooooooooool00Oooool000Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0]ooooo`?o0000;Oooool3o`00033ooooo00?o0000ooooooooool00Oooool000Oooooo00Co
0000oooooooooooo00000_ooool2o`0002goooooIOl00003ooooo`001oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo02cooooo1Ol0000[ooooo`Go0000;oooool00ol0003ooooo
ooooo`01ooooo`001oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02cooooo
1Ol0000[ooooo`Go0000;oooool00ol0003oooooooooo`01ooooo`001oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo02gooooo0ol0000]ooooo`?o0000<?ooool00ol0003ooooo
ooooo`01ooooo`002?ooool2o`0000?ooooo00?o0000ooooooooool0T?ooool00ol0003ooooooooo
o`01ooooo`003Oooool2o`00093ooooo0_l00003ooooo`003Oooool00ol0003oooooooooo`2@oooo
o`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo093ooooo00?o0000oooooooo
ool00Oooool000gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`01ooooo`003Ooo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo007ooooo000=ooooo`;o0000T?ooool2
o`0000?ooooo000=ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool00Oooool000go
oooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`01ooooo`003Oooool00ol0003ooooo
ooooo`2@ooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool00Oooool000gooooo0_l0002@ooooo`;o00000oooool000gooooo00?o0000oooo
ooooool0=?ooool3o`0001oooooo0ol0000gooooo`03o`000?oooooooooo007ooooo000=ooooo`03
o`000?oooooooooo03?ooooo1Ol0000Mooooo`Go0000=_ooool00ol0003oooooooooo`01ooooo`00
3Oooool00ol0003oooooooooo`0cooooo`Ko00007?ooool6o`0003Gooooo00?o0000ooooooooool0
0Oooool000gooooo00?o0000ooooooooool0<oooool5o`000003ooooool0003o000001[ooooo1Ol0
00000ooooooo0000ooooo`0cooooo`03o`000?oooooooooo007ooooo000=ooooo`;o0000=Oooool3
o`0000Cooooo00?o0000ooooooooool06?ooool3o`0000?ooooo0ol0000`ooooo`;o00000oooool0
00gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`Co0000;Oooool00ol0
003oooooooooo`01ooooo`001oooool3o`0000?ooooo00?o0000ooooooooool0?Oooool2o`0002Co
oooo0ol0000Zooooo`03o`000?oooooooooo007ooooo0008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`?o00007_ooool2o`0002Sooooo
00?o0000ooooooooool00Oooool000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`10ooooo`04o`000?ooooooooooooooo`Go00007oooool2o`0002Kooooo00?o0000ooooooooool0
0Oooool000Sooooo00?o0000ooooooooool00_ooool2o`0004;ooooo00?o0000ooooooooool01Ol0
000Qooooo`?o00008_ooool2o`0000?ooooo0008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`05o`0002Cooooo1?l0000Oooooo`03o`000?oooooo
oooo007ooooo0007ooooo`;o00001?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
00Co0000:?ooool5o`0001[ooooo00?o0000ooooooooool00Oooool000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00?ooooo0_l0000[ooooo`;o
00006?ooool00ol0003oooooooooo`01ooooo`003Oooool2o`0004Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Zooooo`Go00004_ooool2o`0000?ooooo000=ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0^ooooo`Oo00003?oo
ool00ol0003oooooooooo`01ooooo`003Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=?ooool5o`0000Oooooo00?o0000ooooooooool00Oooool0
00gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03Wooooo2?l00003ooooo`003Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`01ooooo`003Oooool2o`0004Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0mooooo`;o00000oooool000gooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool00Oooool000gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool00Oooool000gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool00Oooool000gooooo0_l0001<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo000=ooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo007ooooo000=ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
007ooooo000=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo007ooooo000=ooooo`;o0000Coooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`003Oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`01ooooo`001_ooool5o`0000;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00Oooool000Oooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`01ooooo`002?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo007ooooo0009ooooo`04o`000?ooooooooooooooo`;o0000D_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo0_l00003ooooo`001_ooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool00Oooool000Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo007ooooo0007ooooo`?o00000oooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`01ooooo`003Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`01ooooo`003Oooool2o`0005Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0]ooooo`;o00000oooool000gooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool00Oooool000gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool00Oooool000gooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool00Oooool000gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool00Oooool000gooooo0_l0001Hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0:?ooool2o`0000?ooooo000=ooooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo007ooooo000=ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo007o
oooo000=ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool02oooool2o`0002Kooooo
00?o0000ooooooooool00Oooool000gooooo0_l0001Looooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool08_ooool2o`0000?ooooo000=ooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo007ooooo000=oooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo007ooooo000=ooooo`;o0000
G_ooool00ol0003oooooooooo`0>ooooo`;o00007oooool2o`0000?ooooo000=ooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo007ooooo000=ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool2
o`0001gooooo00?o0000ooooooooool00Oooool000Oooooo0ol00003ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Foooo
o`;o00004oooool2o`000003ooooool0003ooooo01Oooooo00?o0000ooooooooool00Oooool000[o
oooo00?o0000ooooooooool0U?l00003ooooo`002?ooool2o`0009[ooooo000:ooooo`03o`000?oo
oooooooo09Oooooo0006ooooo`05o`000?ooooooooooooooool00000VOooool000Oooooo0ol0002J
ooooo`00Y?ooool00001\
\>"],
  ImageRangeCache->{{{77.875, 240.875}, {463.25, 300.25}} -> {-6.76418, \
8.84931, 0.0410476, 0.0410476}}]
}, Open  ]],

Cell["Now run time backwards from the same initial points.", "Text"],

Cell[CellGroupData[{

Cell["\<\
plots = Table[ Plot[ phi[t,Cos[n*Pi/4],Sin[n*Pi/4]], \
{t,-3,Cos[n*Pi/4]},
       DisplayFunction->Identity ], {n,0,7} ];
Show[ startpoints, plots, DisplayFunction->$DisplayFunction, AspectRatio->1,
       PlotRange->{{-3,3},{-3,3}}, Frame->True, Axes->None ]\
\>", "Input",
  CellLabel->"In[81]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.5 0.166667 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -12 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -6 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(-2)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(-1)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(1)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(2)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(3)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.16667 .99375 m
.16667 1 L
s
.33333 .99375 m
.33333 1 L
s
.5 .99375 m
.5 1 L
s
.66667 .99375 m
.66667 1 L
s
.83333 .99375 m
.83333 1 L
s
.125 Mabswid
.03333 .99625 m
.03333 1 L
s
.06667 .99625 m
.06667 1 L
s
.1 .99625 m
.1 1 L
s
.13333 .99625 m
.13333 1 L
s
.2 .99625 m
.2 1 L
s
.23333 .99625 m
.23333 1 L
s
.26667 .99625 m
.26667 1 L
s
.3 .99625 m
.3 1 L
s
.36667 .99625 m
.36667 1 L
s
.4 .99625 m
.4 1 L
s
.43333 .99625 m
.43333 1 L
s
.46667 .99625 m
.46667 1 L
s
.53333 .99625 m
.53333 1 L
s
.56667 .99625 m
.56667 1 L
s
.6 .99625 m
.6 1 L
s
.63333 .99625 m
.63333 1 L
s
.7 .99625 m
.7 1 L
s
.73333 .99625 m
.73333 1 L
s
.76667 .99625 m
.76667 1 L
s
.8 .99625 m
.8 1 L
s
.86667 .99625 m
.86667 1 L
s
.9 .99625 m
.9 1 L
s
.93333 .99625 m
.93333 1 L
s
.96667 .99625 m
.96667 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .5 m
1 .5 L
s
.99375 .66667 m
1 .66667 L
s
.99375 .83333 m
1 .83333 L
s
.125 Mabswid
.99625 .03333 m
1 .03333 L
s
.99625 .06667 m
1 .06667 L
s
.99625 .1 m
1 .1 L
s
.99625 .13333 m
1 .13333 L
s
.99625 .2 m
1 .2 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .26667 m
1 .26667 L
s
.99625 .3 m
1 .3 L
s
.99625 .36667 m
1 .36667 L
s
.99625 .4 m
1 .4 L
s
.99625 .43333 m
1 .43333 L
s
.99625 .46667 m
1 .46667 L
s
.99625 .53333 m
1 .53333 L
s
.99625 .56667 m
1 .56667 L
s
.99625 .6 m
1 .6 L
s
.99625 .63333 m
1 .63333 L
s
.99625 .7 m
1 .7 L
s
.99625 .73333 m
1 .73333 L
s
.99625 .76667 m
1 .76667 L
s
.99625 .8 m
1 .8 L
s
.99625 .86667 m
1 .86667 L
s
.99625 .9 m
1 .9 L
s
.99625 .93333 m
1 .93333 L
s
.99625 .96667 m
1 .96667 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.04 w
.66667 .5 Mdot
.61785 .61785 Mdot
.5 .66667 Mdot
.38215 .61785 Mdot
.33333 .5 Mdot
.38215 .38215 Mdot
.5 .33333 Mdot
.61785 .38215 Mdot
.5 Mabswid
0 .5 m
.00082 .5 L
.00157 .5 L
.00244 .5 L
.00325 .5 L
.00401 .5 L
.00471 .5 L
.00547 .5 L
.00628 .5 L
.0071 .5 L
.00797 .5 L
.0088 .5 L
.00956 .5 L
.01044 .5 L
.01094 .5 L
.01141 .5 L
.01226 .5 L
.01317 .5 L
.01362 .5 L
.0141 .5 L
.01497 .5 L
.01545 .5 L
.01589 .5 L
.01639 .5 L
.01691 .5 L
.01737 .5 L
.01786 .5 L
.01876 .5 L
.01964 .5 L
.02044 .5 L
.02123 .5 L
.02197 .5 L
.02277 .5 L
.02364 .5 L
.02451 .5 L
.02542 .5 L
.0262 .5 L
.02704 .5 L
.02754 .5 L
.028 .5 L
.0285 .5 L
.02904 .5 L
.02993 .5 L
.03044 .5 L
.03092 .5 L
.0318 .5 L
.03261 .5 L
.03306 .5 L
.03354 .5 L
.03443 .5 L
Mistroke
.03497 .5 L
.03547 .5 L
.03593 .5 L
.03642 .5 L
.03695 .5 L
.03752 .5 L
.038 .5 L
.03853 .5 L
.03902 .5 L
.03948 .5 L
.04 .5 L
.04049 .5 L
.04137 .5 L
.04187 .5 L
.04232 .5 L
.04314 .5 L
.04402 .5 L
.04485 .5 L
.0456 .5 L
.04645 .5 L
.04737 .5 L
.04783 .5 L
.04833 .5 L
.04922 .5 L
.04971 .5 L
.05017 .5 L
.05067 .5 L
.0512 .5 L
.05208 .5 L
.05259 .5 L
.05306 .5 L
.05394 .5 L
.05474 .5 L
.05566 .5 L
.05654 .5 L
.05733 .5 L
.05819 .5 L
.059 .5 L
.05974 .5 L
.06057 .5 L
.06147 .5 L
.06192 .5 L
.06241 .5 L
.06329 .5 L
.06377 .5 L
.06421 .5 L
.0647 .5 L
.06522 .5 L
.06609 .5 L
.06658 .5 L
Mistroke
.06704 .5 L
.0679 .5 L
.06869 .5 L
.0696 .5 L
.07046 .5 L
.07127 .5 L
.07201 .5 L
.07286 .5 L
.07366 .5 L
.0744 .5 L
.07508 .5 L
.07583 .5 L
.07662 .5 L
.07742 .5 L
.07828 .5 L
.07909 .5 L
.07983 .5 L
.08069 .5 L
.08118 .5 L
.08164 .5 L
.08247 .5 L
.08335 .5 L
.08414 .5 L
.08502 .5 L
.08593 .5 L
.08677 .5 L
.08757 .5 L
.08829 .5 L
.08913 .5 L
.08991 .5 L
.09077 .5 L
.09168 .5 L
.09246 .5 L
.09331 .5 L
.09423 .5 L
.09474 .5 L
.09521 .5 L
.09612 .5 L
.09699 .5 L
.0978 .5 L
.09853 .5 L
.09937 .5 L
.10017 .5 L
.10091 .5 L
.10158 .5 L
.10233 .5 L
.10311 .5 L
.10391 .5 L
.10476 .5 L
.10557 .5 L
Mistroke
.1063 .5 L
.10716 .5 L
.10764 .5 L
.10809 .5 L
.10891 .5 L
.10979 .5 L
.11063 .5 L
.11155 .5 L
.11242 .5 L
.11322 .5 L
.11402 .5 L
.11475 .5 L
.11558 .5 L
.11637 .5 L
.11723 .5 L
.11814 .5 L
.11892 .5 L
.11977 .5 L
.12069 .5 L
.12121 .5 L
.12168 .5 L
.12259 .5 L
.12345 .5 L
.12419 .5 L
.125 .5 L
.12585 .5 L
.12664 .5 L
.12738 .5 L
.12806 .5 L
.1288 .5 L
.12959 .5 L
.13039 .5 L
.13124 .5 L
.13204 .5 L
.13278 .5 L
.13364 .5 L
.13412 .5 L
.13457 .5 L
.13539 .5 L
.13626 .5 L
.13711 .5 L
.13803 .5 L
.1389 .5 L
.13971 .5 L
.14051 .5 L
.14124 .5 L
.14208 .5 L
.14286 .5 L
.14373 .5 L
.14464 .5 L
Mistroke
.14542 .5 L
.14627 .5 L
.14719 .5 L
.14771 .5 L
.14818 .5 L
.14909 .5 L
.14996 .5 L
.15069 .5 L
.15151 .5 L
.15235 .5 L
.15315 .5 L
.15389 .5 L
.15457 .5 L
.15532 .5 L
.1561 .5 L
.1569 .5 L
.15775 .5 L
.15856 .5 L
.15929 .5 L
.16015 .5 L
.16064 .5 L
.16108 .5 L
.16191 .5 L
.16278 .5 L
.16363 .5 L
.16455 .5 L
.16543 .5 L
.16624 .5 L
.16696 .5 L
.16777 .5 L
.16861 .5 L
.16939 .5 L
.17026 .5 L
.17118 .5 L
.17196 .5 L
.17281 .5 L
.17373 .5 L
.17425 .5 L
.17472 .5 L
.17563 .5 L
.1765 .5 L
.17724 .5 L
.17805 .5 L
.1789 .5 L
.1797 .5 L
.18044 .5 L
.18112 .5 L
.1819 .5 L
.18265 .5 L
.18345 .5 L
Mistroke
.1843 .5 L
.18511 .5 L
.18584 .5 L
.1867 .5 L
.18719 .5 L
.18763 .5 L
.18846 .5 L
.18932 .5 L
.19018 .5 L
.19066 .5 L
.19111 .5 L
.19193 .5 L
.1928 .5 L
.19357 .5 L
.1943 .5 L
.1951 .5 L
.19596 .5 L
.19682 .5 L
.19731 .5 L
.19777 .5 L
.19869 .5 L
.1992 .5 L
.19967 .5 L
.20051 .5 L
.20142 .5 L
.20228 .5 L
.20307 .5 L
.20381 .5 L
.20461 .5 L
.20536 .5 L
.20604 .5 L
.20685 .5 L
.20772 .5 L
.20854 .5 L
.20931 .5 L
.21017 .5 L
.21099 .5 L
.21172 .5 L
.21251 .5 L
.21337 .5 L
.21428 .5 L
.21506 .5 L
.21591 .5 L
.21683 .5 L
.21767 .5 L
.21812 .5 L
.2186 .5 L
.21911 .5 L
.21959 .5 L
.22047 .5 L
Mistroke
.22127 .5 L
.22219 .5 L
.22307 .5 L
.22386 .5 L
.22469 .5 L
.22548 .5 L
.22619 .5 L
.22703 .5 L
.22795 .5 L
.22881 .5 L
.2296 .5 L
.23044 .5 L
.23135 .5 L
.23221 .5 L
.23299 .5 L
.23391 .5 L
.23443 .5 L
.23491 .5 L
.23578 .5 L
.23623 .5 L
.23672 .5 L
.23719 .5 L
.23769 .5 L
.23859 .5 L
.23909 .5 L
.23955 .5 L
.24006 .5 L
.2406 .5 L
.24107 .5 L
.24158 .5 L
.24207 .5 L
.24251 .5 L
.24336 .5 L
.24425 .5 L
.24509 .5 L
.24602 .5 L
.24689 .5 L
.24769 .5 L
.2485 .5 L
.24922 .5 L
.25006 .5 L
.25085 .5 L
.25171 .5 L
.25262 .5 L
.2534 .5 L
.25425 .5 L
.25517 .5 L
.25569 .5 L
.25616 .5 L
.25707 .5 L
Mistroke
.25794 .5 L
.25867 .5 L
.25948 .5 L
.26033 .5 L
.26113 .5 L
.26187 .5 L
.26255 .5 L
.26329 .5 L
.26408 .5 L
.26488 .5 L
.26573 .5 L
.26654 .5 L
.26727 .5 L
.26813 .5 L
.26861 .5 L
.26906 .5 L
.26988 .5 L
.27075 .5 L
.2716 .5 L
.27253 .5 L
.2734 .5 L
.27421 .5 L
.27501 .5 L
.27574 .5 L
.27658 .5 L
.27737 .5 L
.27823 .5 L
.27915 .5 L
.27993 .5 L
.28078 .5 L
.2817 .5 L
.28222 .5 L
.28269 .5 L
.2836 .5 L
.28447 .5 L
.28521 .5 L
.28602 .5 L
.28687 .5 L
.28767 .5 L
.28841 .5 L
.28909 .5 L
.28987 .5 L
.29062 .5 L
.29142 .5 L
.29227 .5 L
.29308 .5 L
.29381 .5 L
.29467 .5 L
.29516 .5 L
.2956 .5 L
Mistroke
.29642 .5 L
.29729 .5 L
.29815 .5 L
.29863 .5 L
.29907 .5 L
.29989 .5 L
.30076 .5 L
.30154 .5 L
.30227 .5 L
.30306 .5 L
.30393 .5 L
.30479 .5 L
.30528 .5 L
.30573 .5 L
.30665 .5 L
.30717 .5 L
.30764 .5 L
.30847 .5 L
.30938 .5 L
.31024 .5 L
.31104 .5 L
.31178 .5 L
.31257 .5 L
.31332 .5 L
.314 .5 L
.31481 .5 L
.31568 .5 L
.3165 .5 L
.31727 .5 L
.31813 .5 L
.31895 .5 L
.31968 .5 L
.32047 .5 L
.32133 .5 L
.32224 .5 L
.32302 .5 L
.32387 .5 L
.32479 .5 L
.32563 .5 L
.32608 .5 L
.32656 .5 L
.32707 .5 L
.32755 .5 L
.32842 .5 L
.32923 .5 L
.33011 .5 L
.33103 .5 L
.33181 .5 L
.33265 .5 L
.33343 .5 L
Mistroke
.33415 .5 L
.33499 .5 L
.3359 .5 L
.33676 .5 L
.33755 .5 L
.3384 .5 L
.3393 .5 L
.34016 .5 L
.34094 .5 L
.34186 .5 L
.34238 .5 L
.34286 .5 L
.34374 .5 L
.34418 .5 L
.34467 .5 L
.34515 .5 L
.34564 .5 L
.34654 .5 L
.34704 .5 L
.3475 .5 L
.34801 .5 L
.34855 .5 L
.34902 .5 L
.34953 .5 L
.35002 .5 L
.35046 .5 L
.35131 .5 L
.3522 .5 L
.35304 .5 L
.35397 .5 L
.35484 .5 L
.35564 .5 L
.35644 .5 L
.35717 .5 L
.358 .5 L
.35879 .5 L
.35966 .5 L
.36057 .5 L
.36135 .5 L
.3622 .5 L
.36312 .5 L
.36363 .5 L
.3641 .5 L
.36502 .5 L
.36588 .5 L
.36662 .5 L
.36743 .5 L
.36828 .5 L
.36907 .5 L
.36981 .5 L
Mistroke
.37049 .5 L
.37124 .5 L
.37202 .5 L
.37282 .5 L
.37367 .5 L
.37448 .5 L
.37521 .5 L
.37607 .5 L
.37656 .5 L
.377 .5 L
.37782 .5 L
.3787 .5 L
.37954 .5 L
.38047 .5 L
.38134 .5 L
.38215 .5 L
.38295 .5 L
.38368 .5 L
.38452 .5 L
.38531 .5 L
.38617 .5 L
.38709 .5 L
.38786 .5 L
.38872 .5 L
.38964 .5 L
.39016 .5 L
.39063 .5 L
.39154 .5 L
.39241 .5 L
.39314 .5 L
.39396 .5 L
.3948 .5 L
.3956 .5 L
.39634 .5 L
.39702 .5 L
.39781 .5 L
.39855 .5 L
.39935 .5 L
.40021 .5 L
.40101 .5 L
.40174 .5 L
.4026 .5 L
.40309 .5 L
.40354 .5 L
.40436 .5 L
.40523 .5 L
.40608 .5 L
.40656 .5 L
.40701 .5 L
.40782 .5 L
Mistroke
.40869 .5 L
.40947 .5 L
.4102 .5 L
.41099 .5 L
.41186 .5 L
.41272 .5 L
.41321 .5 L
.41366 .5 L
.41458 .5 L
.4151 .5 L
.41556 .5 L
.4164 .5 L
.41731 .5 L
.41817 .5 L
.41896 .5 L
.4197 .5 L
.4205 .5 L
.42125 .5 L
.42193 .5 L
.42273 .5 L
.42361 .5 L
.42443 .5 L
.4252 .5 L
.42606 .5 L
.42687 .5 L
.4276 .5 L
.42839 .5 L
.42925 .5 L
.43016 .5 L
.43094 .5 L
.4318 .5 L
.43271 .5 L
.43356 .5 L
.434 .5 L
.43449 .5 L
.43499 .5 L
.43547 .5 L
.43635 .5 L
.43715 .5 L
.43803 .5 L
.43895 .5 L
.43973 .5 L
.44057 .5 L
.44135 .5 L
.44207 .5 L
.44291 .5 L
.44382 .5 L
.44468 .5 L
.44547 .5 L
.44632 .5 L
Mistroke
.44722 .5 L
.44808 .5 L
.44886 .5 L
.44978 .5 L
.45029 .5 L
.45077 .5 L
.45165 .5 L
.4521 .5 L
.45259 .5 L
.45306 .5 L
.45356 .5 L
.45445 .5 L
.45495 .5 L
.45542 .5 L
.45592 .5 L
.45647 .5 L
.45694 .5 L
.45745 .5 L
.45793 .5 L
.45838 .5 L
.45922 .5 L
.46012 .5 L
.46096 .5 L
.46188 .5 L
.46275 .5 L
.46356 .5 L
.46436 .5 L
.46508 .5 L
.46592 .5 L
.46671 .5 L
.46757 .5 L
.46848 .5 L
.46926 .5 L
.47011 .5 L
.47103 .5 L
.47154 .5 L
.47201 .5 L
.47293 .5 L
.47379 .5 L
.47453 .5 L
.47534 .5 L
.47619 .5 L
.47698 .5 L
.47772 .5 L
.4784 .5 L
.47914 .5 L
.47993 .5 L
.48073 .5 L
.48158 .5 L
.48239 .5 L
Mistroke
.48312 .5 L
.48398 .5 L
.48446 .5 L
.48491 .5 L
.48573 .5 L
.4866 .5 L
.48745 .5 L
.48837 .5 L
.48925 .5 L
.49006 .5 L
.49086 .5 L
.49158 .5 L
.49242 .5 L
.49321 .5 L
.49408 .5 L
.49499 .5 L
.49577 .5 L
.49662 .5 L
.49754 .5 L
.49806 .5 L
.49853 .5 L
.49944 .5 L
.50031 .5 L
.50104 .5 L
.50186 .5 L
.50271 .5 L
.5035 .5 L
.50424 .5 L
.50492 .5 L
.50567 .5 L
.50645 .5 L
.50725 .5 L
.50811 .5 L
.50891 .5 L
.50964 .5 L
.5105 .5 L
.51099 .5 L
.51144 .5 L
.51226 .5 L
.51313 .5 L
.51398 .5 L
.51446 .5 L
.5149 .5 L
.51572 .5 L
.51659 .5 L
.51736 .5 L
.51809 .5 L
.51889 .5 L
.51975 .5 L
.52061 .5 L
Mistroke
.5211 .5 L
.52156 .5 L
.52247 .5 L
.52299 .5 L
.52346 .5 L
.5243 .5 L
.52521 .5 L
.52606 .5 L
.52686 .5 L
.5276 .5 L
.52839 .5 L
.52914 .5 L
.52982 .5 L
.53062 .5 L
.5315 .5 L
.53232 .5 L
.53309 .5 L
.53395 .5 L
.53476 .5 L
.53549 .5 L
.53628 .5 L
.53714 .5 L
.53806 .5 L
.53883 .5 L
.53969 .5 L
.5406 .5 L
.54145 .5 L
.54189 .5 L
.54237 .5 L
.54288 .5 L
.54336 .5 L
.54423 .5 L
.54503 .5 L
.54591 .5 L
.54684 .5 L
.54762 .5 L
.54845 .5 L
.54924 .5 L
.54995 .5 L
.55079 .5 L
.5517 .5 L
.55256 .5 L
.55335 .5 L
.5542 .5 L
.55511 .5 L
.55596 .5 L
.55674 .5 L
.55766 .5 L
.55818 .5 L
.55866 .5 L
Mistroke
.55954 .5 L
.56003 .5 L
.56047 .5 L
.56094 .5 L
.56144 .5 L
.56234 .5 L
.56283 .5 L
.5633 .5 L
.56381 .5 L
.56435 .5 L
.56482 .5 L
.56533 .5 L
.56582 .5 L
.56626 .5 L
.5671 .5 L
.568 .5 L
.56884 .5 L
.56976 .5 L
.57063 .5 L
.57144 .5 L
.57224 .5 L
.57296 .5 L
.5738 .5 L
.57458 .5 L
.57545 .5 L
.57636 .5 L
.57713 .5 L
.57799 .5 L
.57891 .5 L
.57942 .5 L
.57989 .5 L
.5808 .5 L
.58167 .5 L
.5824 .5 L
.58321 .5 L
.58406 .5 L
.58485 .5 L
.58559 .5 L
.58627 .5 L
.58702 .5 L
.5878 .5 L
.5886 .5 L
.58945 .5 L
.59026 .5 L
.59099 .5 L
.59185 .5 L
.59234 .5 L
.59278 .5 L
.59361 .5 L
.59448 .5 L
Mistroke
.59532 .5 L
.59625 .5 L
.59712 .5 L
.59793 .5 L
.59873 .5 L
.59945 .5 L
.60029 .5 L
.60108 .5 L
.60194 .5 L
.60286 .5 L
.60364 .5 L
.60449 .5 L
.60541 .5 L
.60593 .5 L
.6064 .5 L
.60731 .5 L
.60817 .5 L
.60891 .5 L
.60972 .5 L
.61057 .5 L
.61137 .5 L
.61211 .5 L
.61279 .5 L
.61353 .5 L
.61432 .5 L
.61512 .5 L
.61597 .5 L
.61678 .5 L
.61751 .5 L
.61837 .5 L
.61885 .5 L
.6193 .5 L
.62012 .5 L
.62099 .5 L
.62184 .5 L
.62232 .5 L
.62277 .5 L
.62358 .5 L
.62445 .5 L
.62523 .5 L
.62595 .5 L
.62675 .5 L
.62761 .5 L
.62847 .5 L
.62896 .5 L
.62942 .5 L
.63033 .5 L
.63085 .5 L
.63132 .5 L
.63215 .5 L
Mistroke
.63306 .5 L
.63392 .5 L
.63472 .5 L
.63545 .5 L
.63625 .5 L
.637 .5 L
.63768 .5 L
.63848 .5 L
.63935 .5 L
.64018 .5 L
.64094 .5 L
.64181 .5 L
.64262 .5 L
.64335 .5 L
.64414 .5 L
.645 .5 L
.64591 .5 L
.64669 .5 L
.64754 .5 L
.64816 .5 L
.64873 .5 L
.64936 .5 L
.65002 .5 L
.6506 .5 L
.65114 .5 L
.65173 .5 L
.65237 .5 L
.65291 .5 L
.65349 .5 L
.6541 .5 L
.65467 .5 L
.6552 .5 L
.65569 .5 L
.65625 .5 L
.65677 .5 L
.65735 .5 L
.65797 .5 L
.65863 .5 L
.65924 .5 L
.65982 .5 L
.66034 .5 L
.66095 .5 L
.66152 .5 L
.66214 .5 L
.6628 .5 L
.66342 .5 L
.66398 .5 L
.66465 .5 L
.66537 .5 L
.66604 .5 L
Mistroke
.66667 .5 L
Mfstroke
0 .51826 m
.02506 .51855 L
.0524 .51891 L
.07807 .51929 L
.10276 .5197 L
.12904 .52019 L
.15434 .52075 L
.18122 .52143 L
.20713 .52221 L
.23205 .52309 L
.25856 .52422 L
.28409 .52555 L
.30863 .5271 L
.33477 .52916 L
.35992 .53166 L
.38667 .53505 L
.41243 .53926 L
.43721 .54442 L
.46357 .55136 L
.48896 .55961 L
.51594 .57005 L
.54193 .58148 L
.56694 .5933 L
.59354 .6062 L
.61785 .61785 L
s
0 .5478 m
.02028 .5484 L
.0424 .54913 L
.06318 .54988 L
.08316 .55068 L
.10443 .55162 L
.1249 .55263 L
.14666 .55384 L
.16762 .55515 L
.18779 .55657 L
.20924 .55831 L
.2299 .56022 L
.24976 .56235 L
.27092 .56499 L
.29127 .56797 L
.31291 .57173 L
.33376 .57609 L
.35381 .58112 L
.37515 .58763 L
.39569 .59528 L
.41752 .60526 L
.43856 .61707 L
.4588 .6308 L
.48033 .64819 L
.5 .66667 L
s
0 .56254 m
.0155 .56314 L
.03241 .56385 L
.04829 .56456 L
.06356 .56529 L
.07981 .56614 L
.09546 .56701 L
.11209 .56803 L
.12811 .56909 L
.14353 .57021 L
.15992 .57151 L
.17571 .57288 L
.19089 .57434 L
.20706 .57605 L
.22262 .57788 L
.23916 .58005 L
.25509 .5824 L
.27042 .58495 L
.28673 .58801 L
.30243 .59136 L
.31911 .59545 L
.33519 .59999 L
.35066 .60503 L
.36711 .61125 L
.38215 .61785 L
s
0 .5 m
.01352 .5 L
.02827 .5 L
.04212 .5 L
.05544 .5 L
.06962 .5 L
.08327 .5 L
.09777 .5 L
.11175 .5 L
.12519 .5 L
.13949 .5 L
.15327 .5 L
.16651 .5 L
.18061 .5 L
.19418 .5 L
.20861 .5 L
.22251 .5 L
.23587 .5 L
.2501 .5 L
.2638 .5 L
.27835 .5 L
.29237 .5 L
.30587 .5 L
.32022 .5 L
.33333 .5 L
s
0 .43746 m
.0155 .43686 L
.03241 .43615 L
.04829 .43544 L
.06356 .43471 L
.07981 .43386 L
.09546 .43299 L
.11209 .43197 L
.12811 .43091 L
.14353 .42979 L
.15992 .42849 L
.17571 .42712 L
.19089 .42566 L
.20706 .42395 L
.22262 .42212 L
.23916 .41995 L
.25509 .4176 L
.27042 .41505 L
.28673 .41199 L
.30243 .40864 L
.31911 .40455 L
.33519 .40001 L
.35066 .39497 L
.36711 .38875 L
.38215 .38215 L
s
0 .4522 m
.02028 .4516 L
.0424 .45087 L
.06318 .45012 L
.08316 .44932 L
.10443 .44838 L
.1249 .44737 L
.14666 .44616 L
.16762 .44485 L
.18779 .44343 L
.20924 .44169 L
.2299 .43978 L
.24976 .43765 L
.27092 .43501 L
.29127 .43203 L
.31291 .42827 L
.33376 .42391 L
.35381 .41888 L
.37515 .41237 L
.39569 .40472 L
.41752 .39474 L
.43856 .38293 L
.4588 .3692 L
.48033 .35181 L
.5 .33333 L
s
0 .48174 m
.02506 .48145 L
.0524 .48109 L
.07807 .48071 L
.10276 .4803 L
.12904 .47981 L
.15434 .47925 L
.18122 .47857 L
.20713 .47779 L
.23205 .47691 L
.25856 .47578 L
.28409 .47445 L
.30863 .4729 L
.33477 .47084 L
.35992 .46834 L
.38667 .46495 L
.41243 .46074 L
.43721 .45558 L
.46357 .44864 L
.48896 .44039 L
.51594 .42995 L
.54193 .41852 L
.56694 .4067 L
.59354 .3938 L
.61785 .38215 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{171, 171},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002[0000Zb000`400?l00000o`00003oZoooool0
0:_ooooo000Wooooo`Go00005Oooool3o`0001Gooooo0_l0000Fooooo`?o00005_ooool5o`0001Ko
oooo0ol00003ooooo`00:?ooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo01?o
oooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`0Fooooo`04o`000?oooooooooo
o`0001Gooooo00Go0000ooooooooooooooooo`000002ooooo`008Oooool5o`0000?ooooo00?o0000
ooooooooool03_ooool5o`0000?ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0
000Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Oooool1o`00007ooooo0Ooo
ool002[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`04o`000?oooooo
ooooo`0001Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`;o00000ooo
ool002Oooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo01?ooooo00Co
0000oooooooooooo00005_ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00006Oooool1o`00007ooooo0Oooool002Oooooo00Go0000ooooooooooooooooo`00000Eooooo`;o
00005Oooool01?l0003oooooooooool0000Eooooo`;o00005oooool01Ol0003ooooooooooooooooo
000001Gooooo00Go0000ooooooooooooooooo`000002ooooo`00:?ooool3o`0001Oooooo00?o0000
ooooooooool05?ooool2o`0001Oooooo00?o0000ooooooooool05_ooool3o`0001Oooooo0ol00003
ooooo`00Zoooool00:_ooooo002[ooooo`003OoooonKo`0000?ooooo000=ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo007ooooo000=ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000go
oooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`01ooooo`003Oooool00ol0003ooooo
ooooo`2Gooooo`03o`000?oooooooooo007ooooo000=ooooo`;o0000Uoooool2o`0000?ooooo000=
ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000gooooo00?o0000oooo
ooooool0Uoooool00ol0003oooooooooo`01ooooo`003Oooool00ol0003oooooooooo`2Gooooo`03
o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0
0Oooool000gooooo0_l0002Gooooo`;o00000oooool000gooooo00?o0000ooooooooool0Uoooool0
0ol0003oooooooooo`01ooooo`003Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo
007ooooo000=ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000gooooo
00?o0000ooooooooool0Uoooool00ol0003oooooooooo`01ooooo`003Oooool2o`0009Oooooo0_l0
0003ooooo`003Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo007ooooo000=oooo
o`03o`000?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000gooooo00?o0000oooooooo
ool0Uoooool00ol0003oooooooooo`01ooooo`003Oooool00ol0003oooooooooo`2Gooooo`03o`00
0?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool00Ooo
ool000gooooo0_l0002Gooooo`;o00000oooool000gooooo00?o0000ooooooooool0Uoooool00ol0
003oooooooooo`01ooooo`001_ooool5o`0000;ooooo00?o0000ooooooooool0Uoooool00ol0003o
ooooooooo`01ooooo`001oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo09Oo
oooo00?o0000ooooooooool00Oooool000Go00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooooooo
0_l0002Gooooo`;o00000oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000Kooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000Oooooo0ol0
0003ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000gooooo00?o0000
ooooooooool0Uoooool00ol0003oooooooooo`01ooooo`003Oooool2o`0009Oooooo0_l00003oooo
o`003Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`00
0?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0Uooo
ool00ol0003oooooooooo`01ooooo`003Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooo
oooo007ooooo000=ooooo`;o0000Uoooool2o`0000?ooooo000=ooooo`03o`000?oooooooooo09Oo
oooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0Uoooool00ol0003ooooo
ooooo`01ooooo`003Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo007ooooo000=
ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000gooooo0_l0002Goooo
o`;o00000oooool000gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`01ooooo`00
3Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oo
oooooooo09Oooooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0Uoooool0
0ol0003oooooooooo`01ooooo`003Oooool2o`0009Oooooo0_l00003ooooo`003Oooool00ol0003o
ooooooooo`2Gooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo09Oooooo
00?o0000ooooooooool00Oooool000Oooooo0ol00003ooooo`03o`000?oooooooooo04Sooooo1?l0
001;ooooo`03o`000?oooooooooo007ooooo0008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Aoooool6o`0004[ooooo00?o0000ooooooooool00Oooool000Go00000oooool00ol0
003oooooooooo`02ooooo`;o0000B?ooool6o`0004Wooooo0_l00003ooooo`002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Oooooo1_l0001:ooooo`03o`000?oooooooooo007o
oooo0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool6o`0004[ooooo
00?o0000ooooooooool00Oooool000Oooooo0_l00004ooooo`03o`000?oooooooooo04Oooooo1Ol0
001;ooooo`03o`000?oooooooooo007ooooo0008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo007ooooo000=oooo
o`;o0000=oooool4o`0000_ooooo00?o0000ooooooooool04_ooool4o`0003Sooooo0_l00003oooo
o`003Oooool00ol0003oooooooooo`0eooooo`Ko00002?ooool2o`0001Cooooo1_l0000hooooo`03
o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo03Gooooo1_l00007ooooo`03o`00
0?oooooooooo01Cooooo1_l0000hooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oo
oooooooo03Gooooo1_l00005ooooo`;o00005oooool6o`0003Sooooo00?o0000ooooooooool00Ooo
ool000gooooo00?o0000ooooooooool0=Oooool6o`0000?ooooo0_l0000Gooooo`So0000>?ooool0
0ol0003oooooooooo`01ooooo`003Oooool2o`00037ooooo1Ol000000ooooooo0000o`000002o`00
00;ooooo0_l0000Gooooo`;o00000oooool4o`0003Sooooo0_l00003ooooo`003Oooool00ol0003o
ooooooooo`0]ooooo`?o00002Oooool3o`0001Oooooo0_l00012ooooo`03o`000?oooooooooo007o
oooo000=ooooo`03o`000?oooooooooo02Sooooo1Ol00009ooooo`?o00006?ooool2o`0004Cooooo
00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool08Oooool7o`0000_ooooo0ol0
000Iooooo`;o0000A_ooool00ol0003oooooooooo`01ooooo`003Oooool00ol0003oooooooooo`0J
ooooo`Oo00003_ooool4o`0001[ooooo0_l00018ooooo`03o`000?oooooooooo007ooooo000=oooo
o`;o00003?ooool?o`0000oooooo1_l0000Looooo`;o0000BOooool2o`0000?ooooo000=ooooo`ko
00005?ooool:o`00023ooooo0_l0001<ooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`00
0?oooooooooo01?ooooo3?l0000Wooooo`?o0000C_ooool00ol0003oooooooooo`01ooooo`003Ooo
oolFo`0002oooooo1?l0001Aooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooo
oooo03oooooo0ol0001Eooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo
03Oooooo2?l0001Hooooo`03o`000?oooooooooo007ooooo000=ooooo`;o0000<?ooool8o`0005oo
oooo0_l00003ooooo`003Oooool00ol0003oooooooooo`0GoooooaSo0000J?ooool00ol0003ooooo
ooooo`01ooooo`002?ooool2o`0000?ooooo6_l0000Hooooo`Co0000;oooool4o`00037ooooo00?o
0000ooooooooool00Oooool000Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`0^ooooo`Ko0000;Oooool6o`00033ooooo00?o0000ooooooooool00Oooool000Oooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0^ooooo`Ko0000;Oooool6o`00033ooooo00?o
0000ooooooooool00Oooool000Oooooo00Co0000oooooooooooo00000_oooomZo`0002oooooo0_l0
0003ooooo`001oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02kooooo1_l0
000]ooooo`Ko0000<?ooool00ol0003oooooooooo`01ooooo`001oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo02oooooo1?l0000_ooooo`Co0000<Oooool00ol0003ooooooooo
o`01ooooo`002?ooool2o`0000?ooooo:ol0001_ooooo`03o`000?oooooooooo007ooooo000=oooo
o`03o`000?oooooooooo02Sooooo3?l0001Sooooo`03o`000?oooooooooo007ooooo000=ooooo`;o
0000=Oooool8o`0005[ooooo0_l00003ooooo`003Oooool00ol0003oooooooooo`0looooo`Co0000
Eoooool00ol0003oooooooooo`01ooooo`003Oooool@o`0003?ooooo0ol0001Dooooo`03o`000?oo
oooooooo007ooooo000=ooooo`03o`000?oooooooooo00gooooo4?l0000Vooooo`Co0000D?ooool0
0ol0003oooooooooo`01ooooo`003Oooool8o`0001Sooooo2_l0000Pooooo`Co0000C?ooool00ol0
003oooooooooo`01ooooo`003Oooool2o`0000Kooooo4Ol0000Aooooo`Ko00007_ooool3o`0004So
oooo0_l00003ooooo`003Oooool00ol0003oooooooooo`0Fooooo`Wo00003_ooool7o`0001[ooooo
0_l00017ooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo01oooooo2?l0
000=ooooo`?o00006Oooool2o`0004Gooooo00?o0000ooooooooool00Oooool000gooooo00?o0000
ooooooooool09oooool5o`0000_ooooo0ol0000Hooooo`;o0000@oooool00ol0003oooooooooo`01
ooooo`003Oooool00ol0003oooooooooo`0/ooooo`Go00002Oooool2o`0001Sooooo0_l00011oooo
o`03o`000?oooooooooo007ooooo000=ooooo`;o0000<_ooool2o`0000?ooooo1?l00002ooooo`03
o`000?oooooooooo01Oooooo0_l00002ooooo`Co0000>?ooool2o`0000?ooooo000=ooooo`03o`00
0?oooooooooo03?ooooo2?l00002ooooo`;o00006Oooool7o`0003Sooooo00?o0000ooooooooool0
0Oooool000gooooo00?o0000ooooooooool0=Oooool6o`0000Cooooo0_l0000Hooooo`Ko0000>?oo
ool00ol0003oooooooooo`01ooooo`003Oooool00ol0003oooooooooo`0eooooo`Ko00001_ooool2
o`0001Kooooo1_l0000hooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo
03Gooooo1_l00008ooooo`03o`000?oooooooooo01?ooooo1_l0000hooooo`03o`000?oooooooooo
007ooooo000=ooooo`;o0000=oooool4o`0000[ooooo0_l0000Dooooo`Co0000>?ooool2o`0000?o
oooo000=ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`01ooooo`003Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool00Oooool000Oooooo0ol00003ooooo`03o`000?oooooooooo04Sooooo1?l0001;
ooooo`03o`000?oooooooooo007ooooo0008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0Aoooool6o`0004[ooooo00?o0000ooooooooool00Oooool000Sooooo00?o0000oooooooo
ool00_ooool2o`0004Sooooo1_l00019ooooo`;o00000oooool000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`17ooooo`Ko0000B_ooool00ol0003oooooooooo`01ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Oooooo1_l0001:ooooo`03o`000?oo
oooooooo007ooooo0007ooooo`;o00001?ooool00ol0003oooooooooo`18ooooo`Co0000Boooool0
0ol0003oooooooooo`01ooooo`002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
09Oooooo00?o0000ooooooooool00Oooool000gooooo0_l0002Gooooo`;o00000oooool000gooooo
00?o0000ooooooooool0Uoooool00ol0003oooooooooo`01ooooo`003Oooool00ol0003ooooooooo
o`2Gooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo09Oooooo00?o0000
ooooooooool00Oooool000gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`01oooo
o`003Oooool2o`0009Oooooo0_l00003ooooo`003Oooool00ol0003oooooooooo`2Gooooo`03o`00
0?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool00Ooo
ool000gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`01ooooo`003Oooool00ol0
003oooooooooo`2Gooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo09Oo
oooo00?o0000ooooooooool00Oooool000gooooo0_l0002Gooooo`;o00000oooool000gooooo00?o
0000ooooooooool0Uoooool00ol0003oooooooooo`01ooooo`003Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo09Oooooo00?o0000oooo
ooooool00Oooool000gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`01ooooo`00
3Oooool2o`0009Oooooo0_l00003ooooo`003Oooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo007ooooo0006ooooo`Go00000_ooool00ol0003oooooooooo`2Gooooo`03o`000?oooooo
oooo007ooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Uoooool0
0ol0003oooooooooo`01ooooo`002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
09Oooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooooooo0_l0002Goooo
o`;o00000oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
09Oooooo00?o0000ooooooooool00Oooool000Kooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000Oooooo0ol00003ooooo`03
o`000?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0
Uoooool00ol0003oooooooooo`01ooooo`003Oooool2o`0009Oooooo0_l00003ooooo`003Oooool0
0ol0003oooooooooo`2Gooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo
09Oooooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0Uoooool00ol0003o
ooooooooo`01ooooo`003Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo007ooooo
000=ooooo`;o0000Uoooool2o`0000?ooooo000=ooooo`03o`000?oooooooooo09Oooooo00?o0000
ooooooooool00Oooool000gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`01oooo
o`003Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`00
0?oooooooooo09Oooooo00?o0000ooooooooool00Oooool000gooooo0_l0002Gooooo`;o00000ooo
ool000gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`01ooooo`003Oooool00ol0
003oooooooooo`2Gooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo09Oo
oooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool0Uoooool00ol0003ooooo
ooooo`01ooooo`003Oooool2o`0009Oooooo0_l00003ooooo`003Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo09Oooooo00?o0000oooo
ooooool00Oooool000Oooooo0ol00003ooooo`03o`000?oooooooooo09Oooooo00?o0000oooooooo
ool00Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo007o
oooo000:ooooo`03o`000?oooooooooo09_o00000oooool000Sooooo0_l0002Qooooo`002_ooool0
0ol0003oooooooooo`2Nooooo`001_ooool01Ol0003ooooooooooooooooo00000:3ooooo0007oooo
o`?o0000XOooool00:_ooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 247.875}, {292.875, 122.875}} -> {-6.59757, \
1.35878, 0.0391939, 0.0391939}}]
}, Open  ]],

Cell[TextData[StyleBox["Look before you leap",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
Before solving any first order differential equation it is a very \
good idea to put it into normal form \
\>", "Text"],

Cell[TextData[{
  StyleBox["y",
    FontSlant->"Italic"],
  "' = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  " , ",
  StyleBox["y",
    FontSlant->"Italic"],
  " )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "and think a bit about the function on the right hand side: ",
  StyleBox["f",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  " , ",
  StyleBox["y",
    FontSlant->"Italic"],
  " )",
  " . That way unusual ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " output can be anticipated and pitfalls can be avoided. The essential \
facts to keep in  mind are given in the following theorem.   "
}], "Text"],

Cell[TextData[{
  StyleBox["Unique solution theorem",
    FontVariations->{"Underline"->True}],
  " Unique IVP solutions are guaranteed to exist inside of ",
  StyleBox["t,y",
    FontSlant->"Italic"],
  " rectangles where ",
  StyleBox["f",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  " , ",
  StyleBox["y",
    FontSlant->"Italic"],
  " )",
  " and the ",
  StyleBox["y",
    FontSlant->"Italic"],
  " partial  ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_y\ \(f(t, y)\)\)]],
  " are both continuous. (Ledder, Section 2.4, Theorem 2.4.1) \nHere is an \
example (very similar to DE above). "
}], "Text"],

Cell[CellGroupData[{

Cell["DE2 = y'[t] == y[t]/(t^2 - 1)", "Input",
  CellLabel->"In[88]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(y[t]\/\(\(-1\) + t\^2\)\)}]], "Output",
  CellLabel->"Out[88]="]
}, Open  ]],

Cell["\<\
The differential equation is already in normal form. Note that the \
function on the right side \
\>", "Text"],

Cell[TextData[{
  StyleBox["f",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  " , ",
  StyleBox["y",
    FontSlant->"Italic"],
  " )",
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`y\/\(t\^2 - 1\)\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "is continuous and has a continuous ",
  StyleBox["y",
    FontSlant->"Italic"],
  " partial derivative in any rectangle that does not contain any points on \
the  vertical line ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 1 or the vertical line ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = -1.  \nLet's see ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s general solution. "
}], "Text"],

Cell[CellGroupData[{

Cell["gensoln = DSolve[ DE2, y, t ]", "Input",
  CellLabel->"In[89]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{t}, \(\@\(\(-1\) + t\)\ C[1]\)\/\@\(1 + t\)]}}\)], \
"Output",
  CellLabel->"Out[89]="]
}, Open  ]],

Cell[TextData[{
  "Examination of the solution formula reveals that when C[1] is not 0, it is \
only valid for  ",
  StyleBox["t",
    FontSlant->"Italic"],
  " greater than 1 or ",
  StyleBox["t",
    FontSlant->"Italic"],
  " less than -1",
  ", unless the  constant is allowed to take on imaginary values. Note that \
when ",
  StyleBox["t",
    FontSlant->"Italic"],
  " is less than -1, both the numerator and the denominator are pure \
imaginary so the quotient is real.\n",
  "Several solution curves are plotted below using an input similar to the \
one used to generate the first plot in this section. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
gensoln = gensoln/.C[1]->c;
Plot[ Evaluate[Table[y[t]/.gensoln, {c,-3,3}]], {t,-2,2}]\
\>", "Input",
  CellLabel->"In[94]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.0012578 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .05746 -24 -4.5 ]
[.4875 .05746 0 4.5 ]
[.4875 .18324 -24 -4.5 ]
[.4875 .18324 0 4.5 ]
[.4875 .4348 -18 -4.5 ]
[.4875 .4348 0 4.5 ]
[.4875 .56058 -18 -4.5 ]
[.4875 .56058 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-1)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .05746 m
.50625 .05746 L
s
[(-200)] .4875 .05746 1 0 Mshowa
.5 .18324 m
.50625 .18324 L
s
[(-100)] .4875 .18324 1 0 Mshowa
.5 .4348 m
.50625 .4348 L
s
[(100)] .4875 .4348 1 0 Mshowa
.5 .56058 m
.50625 .56058 L
s
[(200)] .4875 .56058 1 0 Mshowa
.125 Mabswid
.5 .08261 m
.50375 .08261 L
s
.5 .10777 m
.50375 .10777 L
s
.5 .13292 m
.50375 .13292 L
s
.5 .15808 m
.50375 .15808 L
s
.5 .20839 m
.50375 .20839 L
s
.5 .23355 m
.50375 .23355 L
s
.5 .2587 m
.50375 .2587 L
s
.5 .28386 m
.50375 .28386 L
s
.5 .33417 m
.50375 .33417 L
s
.5 .35933 m
.50375 .35933 L
s
.5 .38449 m
.50375 .38449 L
s
.5 .40964 m
.50375 .40964 L
s
.5 .45995 m
.50375 .45995 L
s
.5 .48511 m
.50375 .48511 L
s
.5 .51027 m
.50375 .51027 L
s
.5 .53542 m
.50375 .53542 L
s
.5 .0323 m
.50375 .0323 L
s
.5 .00714 m
.50375 .00714 L
s
.5 .58573 m
.50375 .58573 L
s
.5 .61089 m
.50375 .61089 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30248 m
.06244 .30207 L
.08255 .3018 L
.10458 .30144 L
.1253 .30102 L
.14415 .30054 L
.16372 .29989 L
.17461 .29943 L
.18466 .29892 L
.19377 .29835 L
.20381 .29757 L
.2139 .29655 L
.21938 .29584 L
.22459 .29502 L
.22944 .29408 L
.23473 .29278 L
.23953 .2912 L
.244 .2892 L
.24673 .28755 L
.2493 .28552 L
.25161 .28308 L
.25291 .28131 L
.2541 .27929 L
.2554 .27652 L
.2566 .27306 L
.25729 .27048 L
.25793 .26757 L
.25865 .26319 L
.25934 .25743 L
.26001 .24906 L
.26072 .23326 L
.26133 .20072 L
.26167 .13877 L
.26183 .01472 L
s
.73837 .30893 m
.73954 .30881 L
.74077 .30873 L
.74213 .30867 L
.74486 .30857 L
.74976 .30843 L
.7608 .30821 L
.77116 .30806 L
.78081 .30793 L
.81977 .30757 L
.84105 .30743 L
.86119 .30731 L
.89957 .30712 L
.9404 .30696 L
.97619 .30684 L
s
.02381 .30466 m
.06244 .30439 L
.08255 .30421 L
.10458 .30397 L
.1253 .30369 L
.14415 .30337 L
.16372 .30293 L
.17461 .30263 L
.18466 .30228 L
.19377 .30191 L
.20381 .30139 L
.2139 .3007 L
.21938 .30023 L
.22459 .29968 L
.22944 .29906 L
.23473 .29819 L
.23953 .29714 L
.244 .2958 L
.24673 .2947 L
.2493 .29335 L
.25161 .29173 L
.25291 .29054 L
.2541 .2892 L
.2554 .28735 L
.2566 .28505 L
.25729 .28333 L
.25793 .28138 L
.25865 .27847 L
.25934 .27462 L
.26001 .26905 L
.26072 .25851 L
.26133 .23682 L
.26167 .19552 L
.26183 .11282 L
s
.73837 .30896 m
.73954 .30888 L
.74077 .30883 L
.74213 .30879 L
.74486 .30872 L
.74976 .30863 L
.7608 .30848 L
.77116 .30838 L
.78081 .3083 L
.81977 .30805 L
.84105 .30796 L
.86119 .30788 L
.89957 .30775 L
.9404 .30764 L
.97619 .30756 L
s
.02381 .30684 m
.06244 .3067 L
.08255 .30661 L
.10458 .30649 L
.1253 .30635 L
.14415 .30619 L
.16372 .30597 L
.17461 .30582 L
.18466 .30565 L
.19377 .30546 L
.20381 .3052 L
.2139 .30486 L
.21938 .30462 L
.22459 .30435 L
.22944 .30404 L
.23473 .3036 L
.23953 .30308 L
.244 .30241 L
.24673 .30186 L
.2493 .30118 L
.25161 .30037 L
.25291 .29978 L
.2541 .29911 L
.2554 .29818 L
.2566 .29703 L
.25729 .29617 L
.25793 .2952 L
.25865 .29374 L
.25934 .29182 L
.26001 .28903 L
.26072 .28376 L
.26133 .27292 L
.26167 .25227 L
.26183 .21092 L
s
.73837 .30899 m
.73954 .30895 L
.74077 .30892 L
.74213 .3089 L
.74486 .30887 L
.74976 .30882 L
.7608 .30875 L
.77116 .3087 L
.78081 .30866 L
.81977 .30854 L
.84105 .30849 L
.86119 .30845 L
.89957 .30838 L
.9404 .30833 L
.97619 .30829 L
s
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07103 .30902 L
.07173 .30902 L
.073 .30902 L
Mistroke
.07376 .30902 L
.07448 .30902 L
.07513 .30902 L
.07583 .30902 L
.0766 .30902 L
.0774 .30902 L
.07809 .30902 L
.07885 .30902 L
.07956 .30902 L
.0802 .30902 L
.08095 .30902 L
.08166 .30902 L
.08291 .30902 L
.08362 .30902 L
.08427 .30902 L
.08544 .30902 L
.08669 .30902 L
.08787 .30902 L
.08896 .30902 L
.09016 .30902 L
.09148 .30902 L
.09214 .30902 L
.09285 .30902 L
.09413 .30902 L
.09483 .30902 L
.09548 .30902 L
.09619 .30902 L
.09695 .30902 L
.09821 .30902 L
.09893 .30902 L
.09961 .30902 L
.10086 .30902 L
.10201 .30902 L
.10333 .30902 L
.10458 .30902 L
.10572 .30902 L
.10694 .30902 L
.1081 .30902 L
.10916 .30902 L
.11033 .30902 L
.11162 .30902 L
.11227 .30902 L
.11297 .30902 L
.11422 .30902 L
.11491 .30902 L
.11554 .30902 L
.11624 .30902 L
.11698 .30902 L
.11822 .30902 L
.11892 .30902 L
Mistroke
.11958 .30902 L
.12081 .30902 L
.12194 .30902 L
.12323 .30902 L
.12446 .30902 L
.12562 .30902 L
.12668 .30902 L
.12789 .30902 L
.12903 .30902 L
.13009 .30902 L
.13107 .30902 L
.13214 .30902 L
.13327 .30902 L
.13441 .30902 L
.13564 .30902 L
.1368 .30902 L
.13785 .30902 L
.13909 .30902 L
.13979 .30902 L
.14043 .30902 L
.14162 .30902 L
.14288 .30902 L
.14402 .30902 L
.14526 .30902 L
.14656 .30902 L
.14777 .30902 L
.14891 .30902 L
.14994 .30902 L
.15113 .30902 L
.15226 .30902 L
.15348 .30902 L
.15478 .30902 L
.15589 .30902 L
.15711 .30902 L
.15842 .30902 L
.15915 .30902 L
.15982 .30902 L
.16113 .30902 L
.16236 .30902 L
.16352 .30902 L
.16456 .30902 L
.16577 .30902 L
.1669 .30902 L
.16796 .30902 L
.16893 .30902 L
.16999 .30902 L
.17111 .30902 L
.17225 .30902 L
.17347 .30902 L
.17462 .30902 L
Mistroke
.17566 .30902 L
.17689 .30902 L
.17758 .30902 L
.17823 .30902 L
.1794 .30902 L
.18065 .30902 L
.18185 .30902 L
.18316 .30902 L
.18441 .30902 L
.18556 .30902 L
.1867 .30902 L
.18773 .30902 L
.18893 .30902 L
.19005 .30902 L
.19128 .30902 L
.19258 .30902 L
.19369 .30902 L
.19491 .30902 L
.19623 .30902 L
.19696 .30902 L
.19763 .30902 L
.19894 .30902 L
.20017 .30902 L
.20122 .30902 L
.20238 .30902 L
.20359 .30902 L
.20472 .30902 L
.20578 .30902 L
.20675 .30902 L
.20781 .30902 L
.20894 .30902 L
.21008 .30902 L
.21129 .30902 L
.21244 .30902 L
.21349 .30902 L
.21472 .30902 L
.21541 .30902 L
.21605 .30902 L
.21723 .30902 L
.21847 .30902 L
.21968 .30902 L
.221 .30902 L
.22224 .30902 L
.2234 .30902 L
.22454 .30902 L
.22558 .30902 L
.22677 .30902 L
.2279 .30902 L
.22914 .30902 L
.23044 .30902 L
Mistroke
.23155 .30902 L
.23277 .30902 L
.23409 .30902 L
.23482 .30902 L
.2355 .30902 L
.2368 .30902 L
.23804 .30902 L
.23909 .30902 L
.24025 .30902 L
.24146 .30902 L
.2426 .30902 L
.24365 .30902 L
.24462 .30902 L
.24569 .30902 L
.24681 .30902 L
.24795 .30902 L
.24917 .30902 L
.25032 .30902 L
.25137 .30902 L
.2526 .30902 L
.25329 .30902 L
.25393 .30902 L
.2551 .30902 L
.25635 .30902 L
.25756 .30902 L
.25888 .30902 L
.26013 .30902 L
.26129 .30902 L
.26233 .30902 L
.26348 .30902 L
.26467 .30902 L
.2658 .30902 L
.26704 .30902 L
.26835 .30902 L
.26946 .30902 L
.27068 .30902 L
.272 .30902 L
.27274 .30902 L
.27341 .30902 L
.27472 .30902 L
.27595 .30902 L
.27701 .30902 L
.27817 .30902 L
.27938 .30902 L
.28052 .30902 L
.28158 .30902 L
.28255 .30902 L
.28367 .30902 L
.28474 .30902 L
.28588 .30902 L
Mistroke
.2871 .30902 L
.28825 .30902 L
.2893 .30902 L
.29053 .30902 L
.29122 .30902 L
.29186 .30902 L
.29303 .30902 L
.29427 .30902 L
.29549 .30902 L
.29618 .30902 L
.29682 .30902 L
.29799 .30902 L
.29923 .30902 L
.30034 .30902 L
.30138 .30902 L
.30252 .30902 L
.30375 .30902 L
.30499 .30902 L
.30569 .30902 L
.30634 .30902 L
.30765 .30902 L
.30839 .30902 L
.30906 .30902 L
.31026 .30902 L
.31156 .30902 L
.31278 .30902 L
.31392 .30902 L
.31497 .30902 L
.31611 .30902 L
.31718 .30902 L
.31816 .30902 L
.3193 .30902 L
.32055 .30902 L
.32173 .30902 L
.32282 .30902 L
.32406 .30902 L
.32522 .30902 L
.32626 .30902 L
.32739 .30902 L
.32862 .30902 L
.32992 .30902 L
.33103 .30902 L
.33225 .30902 L
.33356 .30902 L
.33477 .30902 L
.33541 .30902 L
.3361 .30902 L
.33683 .30902 L
.33751 .30902 L
.33876 .30902 L
Mistroke
.33991 .30902 L
.34123 .30902 L
.34249 .30902 L
.3436 .30902 L
.3448 .30902 L
.34592 .30902 L
.34694 .30902 L
.34814 .30902 L
.34945 .30902 L
.35067 .30902 L
.35181 .30902 L
.35302 .30902 L
.35431 .30902 L
.35554 .30902 L
.35665 .30902 L
.35796 .30902 L
.3587 .30902 L
.35939 .30902 L
.36064 .30902 L
.36128 .30902 L
.36198 .30902 L
.36266 .30902 L
.36337 .30902 L
.36465 .30902 L
.36536 .30902 L
.36602 .30902 L
.36675 .30902 L
.36753 .30902 L
.3682 .30902 L
.36893 .30902 L
.36962 .30902 L
.37026 .30902 L
.37146 .30902 L
.37274 .30902 L
.37394 .30902 L
.37526 .30902 L
.37651 .30902 L
.37766 .30902 L
.3788 .30902 L
.37984 .30902 L
.38103 .30902 L
.38216 .30902 L
.38339 .30902 L
.3847 .30902 L
.38581 .30902 L
.38703 .30902 L
.38834 .30902 L
.38908 .30902 L
.38975 .30902 L
.39106 .30902 L
Mistroke
.39229 .30902 L
.39334 .30902 L
.3945 .30902 L
.39571 .30902 L
.39685 .30902 L
.39791 .30902 L
.39888 .30902 L
.39994 .30902 L
.40106 .30902 L
.40221 .30902 L
.40342 .30902 L
.40457 .30902 L
.40562 .30902 L
.40685 .30902 L
.40754 .30902 L
.40818 .30902 L
.40936 .30902 L
.4106 .30902 L
.41181 .30902 L
.41313 .30902 L
.41438 .30902 L
.41554 .30902 L
.41669 .30902 L
.41772 .30902 L
.41892 .30902 L
.42005 .30902 L
.42129 .30902 L
.42259 .30902 L
.42371 .30902 L
.42493 .30902 L
.42624 .30902 L
.42698 .30902 L
.42765 .30902 L
.42896 .30902 L
.43019 .30902 L
.43125 .30902 L
.43241 .30902 L
.43362 .30902 L
.43476 .30902 L
.43582 .30902 L
.43679 .30902 L
.43791 .30902 L
.43898 .30902 L
.44012 .30902 L
.44134 .30902 L
.44249 .30902 L
.44354 .30902 L
.44477 .30902 L
.44546 .30902 L
.4461 .30902 L
Mistroke
.44727 .30902 L
.44851 .30902 L
.44973 .30902 L
.45042 .30902 L
.45106 .30902 L
.45223 .30902 L
.45347 .30902 L
.45458 .30902 L
.45562 .30902 L
.45676 .30902 L
.45799 .30902 L
.45922 .30902 L
.45992 .30902 L
.46057 .30902 L
.46188 .30902 L
.46262 .30902 L
.46329 .30902 L
.46449 .30902 L
.46579 .30902 L
.46702 .30902 L
.46815 .30902 L
.4692 .30902 L
.47034 .30902 L
.47141 .30902 L
.47239 .30902 L
.47353 .30902 L
.47478 .30902 L
.47596 .30902 L
.47705 .30902 L
.47829 .30902 L
.47945 .30902 L
.48049 .30902 L
.48162 .30902 L
.48285 .30902 L
.48415 .30902 L
.48526 .30902 L
.48648 .30902 L
.48779 .30902 L
.489 .30902 L
.48963 .30902 L
.49033 .30902 L
.49105 .30902 L
.49174 .30902 L
.49299 .30902 L
.49413 .30902 L
.49539 .30902 L
.49671 .30902 L
.49783 .30902 L
.49902 .30902 L
.50014 .30902 L
Mistroke
.50116 .30902 L
.50236 .30902 L
.50366 .30902 L
.50489 .30902 L
.50603 .30902 L
.50723 .30902 L
.50853 .30902 L
.50975 .30902 L
.51087 .30902 L
.51218 .30902 L
.51292 .30902 L
.51361 .30902 L
.51486 .30902 L
.5155 .30902 L
.5162 .30902 L
.51687 .30902 L
.51759 .30902 L
.51886 .30902 L
.51958 .30902 L
.52024 .30902 L
.52096 .30902 L
.52174 .30902 L
.52241 .30902 L
.52314 .30902 L
.52383 .30902 L
.52447 .30902 L
.52568 .30902 L
.52695 .30902 L
.52816 .30902 L
.52947 .30902 L
.53072 .30902 L
.53187 .30902 L
.53301 .30902 L
.53405 .30902 L
.53525 .30902 L
.53637 .30902 L
.5376 .30902 L
.53891 .30902 L
.54002 .30902 L
.54124 .30902 L
.54255 .30902 L
.54329 .30902 L
.54396 .30902 L
.54526 .30902 L
.5465 .30902 L
.54755 .30902 L
.54871 .30902 L
.54992 .30902 L
.55105 .30902 L
.55211 .30902 L
Mistroke
.55308 .30902 L
.55415 .30902 L
.55527 .30902 L
.55641 .30902 L
.55763 .30902 L
.55878 .30902 L
.55982 .30902 L
.56105 .30902 L
.56175 .30902 L
.56238 .30902 L
.56356 .30902 L
.5648 .30902 L
.56601 .30902 L
.56734 .30902 L
.56858 .30902 L
.56974 .30902 L
.57088 .30902 L
.57192 .30902 L
.57312 .30902 L
.57425 .30902 L
.57548 .30902 L
.57679 .30902 L
.5779 .30902 L
.57912 .30902 L
.58044 .30902 L
.58118 .30902 L
.58185 .30902 L
.58315 .30902 L
.58439 .30902 L
.58544 .30902 L
.5866 .30902 L
.58782 .30902 L
.58895 .30902 L
.59001 .30902 L
.59098 .30902 L
.5921 .30902 L
.59317 .30902 L
.59431 .30902 L
.59553 .30902 L
.59668 .30902 L
.59773 .30902 L
.59896 .30902 L
.59965 .30902 L
.60029 .30902 L
.60146 .30902 L
.60271 .30902 L
.60392 .30902 L
.60461 .30902 L
.60525 .30902 L
.60642 .30902 L
Mistroke
.60766 .30902 L
.60876 .30902 L
.6098 .30902 L
.61094 .30902 L
.61217 .30902 L
.61341 .30902 L
.6141 .30902 L
.61475 .30902 L
.61607 .30902 L
.6168 .30902 L
.61747 .30902 L
.61867 .30902 L
.61997 .30902 L
.6212 .30902 L
.62233 .30902 L
.62339 .30902 L
.62452 .30902 L
.62559 .30902 L
.62657 .30902 L
.62771 .30902 L
.62896 .30902 L
.63014 .30902 L
.63123 .30902 L
.63247 .30902 L
.63363 .30902 L
.63467 .30902 L
.6358 .30902 L
.63703 .30902 L
.63833 .30902 L
.63944 .30902 L
.64066 .30902 L
.64197 .30902 L
.64318 .30902 L
.64381 .30902 L
.6445 .30902 L
.64523 .30902 L
.64591 .30902 L
.64716 .30902 L
.64831 .30902 L
.64956 .30902 L
.65088 .30902 L
.652 .30902 L
.65319 .30902 L
.65431 .30902 L
.65533 .30902 L
.65653 .30902 L
.65784 .30902 L
.65906 .30902 L
.6602 .30902 L
.6614 .30902 L
Mistroke
.6627 .30902 L
.66392 .30902 L
.66504 .30902 L
.66635 .30902 L
.66709 .30902 L
.66777 .30902 L
.66903 .30902 L
.66966 .30902 L
.67036 .30902 L
.67104 .30902 L
.67175 .30902 L
.67303 .30902 L
.67374 .30902 L
.6744 .30902 L
.67513 .30902 L
.67591 .30902 L
.67658 .30902 L
.67731 .30902 L
.678 .30902 L
.67864 .30902 L
.67984 .30902 L
.68112 .30902 L
.68232 .30902 L
.68364 .30902 L
.68488 .30902 L
.68603 .30902 L
.68718 .30902 L
.68821 .30902 L
.68941 .30902 L
.69053 .30902 L
.69176 .30902 L
.69307 .30902 L
.69418 .30902 L
.6954 .30902 L
.69671 .30902 L
.69745 .30902 L
.69812 .30902 L
.69942 .30902 L
.70066 .30902 L
.70171 .30902 L
.70286 .30902 L
.70407 .30902 L
.70521 .30902 L
.70627 .30902 L
.70724 .30902 L
.7083 .30902 L
.70942 .30902 L
.71056 .30902 L
.71178 .30902 L
.71293 .30902 L
Mistroke
.71398 .30902 L
.71521 .30902 L
.7159 .30902 L
.71654 .30902 L
.71771 .30902 L
.71896 .30902 L
.72017 .30902 L
.72149 .30902 L
.72273 .30902 L
.72389 .30902 L
.72503 .30902 L
.72607 .30902 L
.72727 .30902 L
.7284 .30902 L
.72963 .30902 L
.73094 .30902 L
.73205 .30902 L
.73327 .30902 L
.73458 .30902 L
.73532 .30902 L
.73599 .30902 L
.7373 .30902 L
.73853 .30902 L
.73959 .30902 L
.74075 .30902 L
.74196 .30902 L
.7431 .30902 L
.74416 .30902 L
.74513 .30902 L
.74619 .30902 L
.74731 .30902 L
.74846 .30902 L
.74967 .30902 L
.75083 .30902 L
.75187 .30902 L
.7531 .30902 L
.75379 .30902 L
.75443 .30902 L
.75561 .30902 L
.75685 .30902 L
.75806 .30902 L
.75875 .30902 L
.75939 .30902 L
.76056 .30902 L
.7618 .30902 L
.7629 .30902 L
.76394 .30902 L
.76508 .30902 L
.76631 .30902 L
.76754 .30902 L
Mistroke
.76824 .30902 L
.76889 .30902 L
.7702 .30902 L
.77094 .30902 L
.77161 .30902 L
.7728 .30902 L
.7741 .30902 L
.77533 .30902 L
.77646 .30902 L
.77752 .30902 L
.77865 .30902 L
.77972 .30902 L
.7807 .30902 L
.78184 .30902 L
.78309 .30902 L
.78427 .30902 L
.78536 .30902 L
.7866 .30902 L
.78776 .30902 L
.7888 .30902 L
.78993 .30902 L
.79116 .30902 L
.79246 .30902 L
.79357 .30902 L
.79479 .30902 L
.7961 .30902 L
.7973 .30902 L
.79793 .30902 L
.79863 .30902 L
.79936 .30902 L
.80004 .30902 L
.80129 .30902 L
.80243 .30902 L
.80369 .30902 L
.80501 .30902 L
.80612 .30902 L
.80731 .30902 L
.80843 .30902 L
.80945 .30902 L
.81066 .30902 L
.81196 .30902 L
.81318 .30902 L
.81432 .30902 L
.81552 .30902 L
.81682 .30902 L
.81804 .30902 L
.81916 .30902 L
.82047 .30902 L
.8212 .30902 L
.82189 .30902 L
Mistroke
.82315 .30902 L
.82385 .30902 L
.82448 .30902 L
.82516 .30902 L
.82587 .30902 L
.82715 .30902 L
.82786 .30902 L
.82852 .30902 L
.82925 .30902 L
.83002 .30902 L
.8307 .30902 L
.83143 .30902 L
.83212 .30902 L
.83275 .30902 L
.83396 .30902 L
.83524 .30902 L
.83644 .30902 L
.83775 .30902 L
.839 .30902 L
.84015 .30902 L
.84129 .30902 L
.84232 .30902 L
.84352 .30902 L
.84464 .30902 L
.84587 .30902 L
.84718 .30902 L
.84829 .30902 L
.8495 .30902 L
.85082 .30902 L
.85155 .30902 L
.85222 .30902 L
.85353 .30902 L
.85476 .30902 L
.85581 .30902 L
.85697 .30902 L
.85818 .30902 L
.85932 .30902 L
.86037 .30902 L
.86134 .30902 L
.86241 .30902 L
.86353 .30902 L
.86467 .30902 L
.86589 .30902 L
.86704 .30902 L
.86808 .30902 L
.86931 .30902 L
.87 .30902 L
.87064 .30902 L
.87182 .30902 L
.87306 .30902 L
Mistroke
.87427 .30902 L
.87559 .30902 L
.87684 .30902 L
.87799 .30902 L
.87914 .30902 L
.88017 .30902 L
.88137 .30902 L
.88249 .30902 L
.88373 .30902 L
.88503 .30902 L
.88615 .30902 L
.88737 .30902 L
.88868 .30902 L
.88942 .30902 L
.89009 .30902 L
.89139 .30902 L
.89263 .30902 L
.89368 .30902 L
.89484 .30902 L
.89605 .30902 L
.89719 .30902 L
.89825 .30902 L
.89922 .30902 L
.90029 .30902 L
.90141 .30902 L
.90255 .30902 L
.90377 .30902 L
.90492 .30902 L
.90596 .30902 L
.90719 .30902 L
.90789 .30902 L
.90852 .30902 L
.9097 .30902 L
.91094 .30902 L
.91216 .30902 L
.91284 .30902 L
.91348 .30902 L
.91464 .30902 L
.91589 .30902 L
.91699 .30902 L
.91803 .30902 L
.91917 .30902 L
.9204 .30902 L
.92163 .30902 L
.92233 .30902 L
.92297 .30902 L
.92429 .30902 L
.92502 .30902 L
.92569 .30902 L
.92689 .30902 L
Mistroke
.92819 .30902 L
.92941 .30902 L
.93055 .30902 L
.9316 .30902 L
.93273 .30902 L
.9338 .30902 L
.93478 .30902 L
.93592 .30902 L
.93717 .30902 L
.93835 .30902 L
.93944 .30902 L
.94068 .30902 L
.94184 .30902 L
.94288 .30902 L
.94401 .30902 L
.94524 .30902 L
.94654 .30902 L
.94765 .30902 L
.94887 .30902 L
.94975 .30902 L
.95057 .30902 L
.95146 .30902 L
.95241 .30902 L
.95324 .30902 L
.95401 .30902 L
.95486 .30902 L
.95577 .30902 L
.95653 .30902 L
.95737 .30902 L
.95824 .30902 L
.95905 .30902 L
.95981 .30902 L
.9605 .30902 L
.9613 .30902 L
.96206 .30902 L
.96287 .30902 L
.96377 .30902 L
.96471 .30902 L
.96559 .30902 L
.96641 .30902 L
.96716 .30902 L
.96802 .30902 L
.96884 .30902 L
.96972 .30902 L
.97067 .30902 L
.97155 .30902 L
.97236 .30902 L
.97331 .30902 L
.97433 .30902 L
.9753 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
.02381 .3112 m
.06244 .31133 L
.08255 .31142 L
.10458 .31154 L
.1253 .31168 L
.14415 .31184 L
.16372 .31206 L
.17461 .31221 L
.18466 .31238 L
.19377 .31257 L
.20381 .31283 L
.2139 .31317 L
.21938 .31341 L
.22459 .31368 L
.22944 .314 L
.23473 .31443 L
.23953 .31495 L
.244 .31562 L
.24673 .31617 L
.2493 .31685 L
.25161 .31766 L
.25291 .31825 L
.2541 .31893 L
.2554 .31985 L
.2566 .321 L
.25729 .32186 L
.25793 .32283 L
.25865 .32429 L
.25934 .32621 L
.26001 .329 L
.26072 .33427 L
.26133 .34512 L
.26167 .36577 L
.26183 .40712 L
s
.73837 .30905 m
.73954 .30909 L
.74077 .30911 L
.74213 .30913 L
.74486 .30917 L
.74976 .30921 L
.7608 .30929 L
.77116 .30934 L
.78081 .30938 L
.81977 .3095 L
.84105 .30955 L
.86119 .30959 L
.89957 .30965 L
.9404 .3097 L
.97619 .30974 L
s
.02381 .31337 m
.06244 .31365 L
.08255 .31383 L
.10458 .31407 L
.1253 .31435 L
.14415 .31467 L
.16372 .3151 L
.17461 .31541 L
.18466 .31575 L
.19377 .31613 L
.20381 .31665 L
.2139 .31733 L
.21938 .3178 L
.22459 .31835 L
.22944 .31897 L
.23473 .31984 L
.23953 .32089 L
.244 .32223 L
.24673 .32333 L
.2493 .32468 L
.25161 .32631 L
.25291 .32749 L
.2541 .32883 L
.2554 .33068 L
.2566 .33299 L
.25729 .33471 L
.25793 .33665 L
.25865 .33957 L
.25934 .34341 L
.26001 .34899 L
.26072 .35952 L
.26133 .38122 L
.26167 .42252 L
.26183 .50522 L
s
.73837 .30908 m
.73954 .30916 L
.74077 .30921 L
.74213 .30925 L
.74486 .30931 L
.74976 .30941 L
.7608 .30955 L
.77116 .30966 L
.78081 .30974 L
.81977 .30998 L
.84105 .31008 L
.86119 .31016 L
.89957 .31028 L
.9404 .31039 L
.97619 .31047 L
s
.02381 .31555 m
.06244 .31596 L
.08255 .31623 L
.10458 .31659 L
.1253 .31701 L
.14415 .31749 L
.16372 .31814 L
.17461 .3186 L
.18466 .31912 L
.19377 .31968 L
.20381 .32046 L
.2139 .32149 L
.21938 .3222 L
.22459 .32302 L
.22944 .32395 L
.23473 .32526 L
.23953 .32683 L
.244 .32884 L
.24673 .33049 L
.2493 .33251 L
.25161 .33495 L
.25291 .33673 L
.2541 .33874 L
.2554 .34151 L
.2566 .34497 L
.25729 .34755 L
.25793 .35047 L
.25865 .35484 L
.25934 .36061 L
.26001 .36897 L
.26072 .38478 L
.26133 .41732 L
.26167 .47926 L
.26183 .60332 L
s
.73837 .30911 m
.73954 .30922 L
.74077 .3093 L
.74213 .30936 L
.74486 .30946 L
.74976 .3096 L
.7608 .30982 L
.77116 .30998 L
.78081 .3101 L
.81977 .31046 L
.84105 .31061 L
.86119 .31073 L
.89957 .31092 L
.9404 .31108 L
.97619 .3112 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[94]:=",
  ImageSize->{223.875, 138.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003O0000RR000`400?l00000o`00003oKoooool0
0ol0003oooooooooo`1]ooooo`00Koooool00ol0003oooooooooo`1]ooooo`00Koooool2o`0006ko
oooo000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0KOooool003[ooooo00?o0000ooooooooool0<_ooool2o`0006kooooo000jooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0Nooooo`Go00000oooool2
o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo
01oooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool06?oo
ool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0
8Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooooooool3o`0006gooooo000jooooo`03o`000?oooooooooo01kooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0Nooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool07oooool3o`0000Co
oooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_ooool2o`0006kooooo000joooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0KOoo
ool003[ooooo00?o0000ooooooooool0<_ooool2o`0006kooooo000jooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo06gooooo
000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0boooo
o`;o0000K_ooool003[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00
>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`;o0000K_ooool003[o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo01oooooo0ol0
0004ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003ooooooooo
o`0Hooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00003ooooo`?o0000KOooool003[ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0Oooooo`;o00001?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0KOoo
ool003[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000Cooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`;o0000K_ooool003[ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1]oooo
o`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`00
0?oooooooooo03;ooooo0_l0001^ooooo`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0KOooool0
03[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0KOooool000Kooooo1Ol0000_ooooo`Co0000<Oooool2o`00037ooooo0ol0
000aooooo`Go00001?ooool000Oooooo00Co0000oooooooooooo0000;oooool00ol0003oooooo`00
000booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<Oooool01?l0003ooooooooo
ool00004ooooo`001Ol00003ooooo`03o`000?oooooooooo02Wooooo1ol000000ooooooo0000oooo
o`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`04ooooo`002Oooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?ooool0<Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool00oooool0
00Kooooo00Go0000ooooooooooooooooo`00000^ooooo`;o000000?oooooo`000?ooool0<Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`00
0004ooooo`001_ooool01Ol0003ooooooooooooooooo000002gooooo1Ol0000booooo`;o0000<Ooo
ool2o`0003;ooooo00Go0000ooooooooooooooooo`000004ooooo`001oooool3o`0002cooooo1Ol0
00000ooooooo0000ooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<Ooo
ool3o`0000Gooooo000cooooo`?o00000_ooool00ol0003oooooo`00000dooooo`03o`000?oooooo
oooo06gooooo000Zooooo`Wo000000?oooooo`000?l000000_l000000ooooooo0000o`00000doooo
o`03o`000?oooooooooo06gooooo0006ooooobko000000?oooooo`000?l000000ol0000eooooo`03
o`000?oooooooooo06gooooo0006oooooboo0000>_ooool00ol0003oooooooooo`10ooooobSo0000
1Oooool00=oo00000006oooooc;o00000_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`006ooooolKo`00
00;ooooo0_l0000eooooo`03o`000?oooooooooo06gooooo000`ooooo`Go000000?oooooo`000?l0
00000ol0000dooooo`03o`000?oooooooooo06gooooo000eooooo`;o000000Coooooo`000?l0003o
0000=?ooool00ol0003oooooooooo`1]ooooo`00=oooool4o`0003Cooooo0_l0001^ooooo`00>?oo
ool3o`0003Cooooo00?o0000ooooooooool0KOooool003Wooooo0_l0000dooooo`03o`000?oooooo
oooo06gooooo000iooooo`;o0000=?ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_ooool2o`0006kooooo000j
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
KOooool003[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool0
0ol0003oooooooooo`0booooo`;o0000K_ooool003[ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo06go
oooo000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0b
ooooo`;o0000K_ooool003[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1]oooo
o`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`00
0?oooooooooo01oooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool0
KOooool003[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1]ooooo`00
>_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo06gooooo000jooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo0ol0001]ooooo`00>_ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo01oooooo0_l00004
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`;o00001?ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo0_l0001^oooo
o`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0KOooool003[o
oooo00?o0000ooooooooool0<_ooool2o`0006kooooo000jooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo06gooooo000joooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`;o0000
K_ooool003[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`;o0000K_ooool003[ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo01kooooo1Ol00003oooo
o`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000oooooooo
ool07oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo027ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooooooo0ol0001]ooooo`00>_ooool00ol0003oooooooooo`0Nooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo01oooooo0ol00004ooooo`;o0000
1?ooool2o`0000Cooooo00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003oooooooooo`0booooo`;o0000K_ooool0
03[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1]ooooo`00>_ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo06gooooo000jooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0KOooool003[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`1]ooooo`00Koooool00ol0003oooooooooo`1]ooooo`00Koooool2o`0006kooooo001_ooooo`03
o`000?oooooooooo06gooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 300.75}, {382.25, 244.875}} -> {-3.58569, \
630.509, 0.0189051, 3.57864}}]
}, Open  ]],

Cell["\<\
Several error messages were generated warning that some formulas do \
not evaluate to real numbers. They were deleted.\
\>", "Text"],

Cell[TextData[{
  "It appears that solutions have a vertical asymptote at ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = -1 and they disappear at t = 1. The next plot gets  closer by \
restricting the vertical range to -10..10. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ Evaluate[Table[y[t]/.%%, {c,-3,3}]], {t,-2,2},
      PlotRange->{-10,10}]\
\>", "Input",
  CellLabel->"In[87]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.0309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -6 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -12 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-1)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-7.5)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-2.5)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(2.5)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(7.5)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(10)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .14845 m
.06244 .13839 L
.08255 .13178 L
.10458 .12299 L
.1253 .11267 L
.14415 .10081 L
.16372 .08479 L
.17461 .07348 L
.18466 .06087 L
.19377 .04699 L
.20381 .02788 L
.2139 .00269 L
s
.2139 .00269 m
.21474 0 L
s
.73837 .30678 m
.73954 .30393 L
.74077 .30209 L
.74213 .30052 L
.74486 .29804 L
.74976 .29468 L
.7608 .28924 L
.77116 .2854 L
.78081 .28242 L
.81977 .27354 L
.84105 .26993 L
.86119 .267 L
.89957 .26237 L
.9404 .2584 L
.97619 .25549 L
s
.02381 .20197 m
.06244 .19527 L
.08255 .19086 L
.10458 .185 L
.1253 .17812 L
.14415 .17021 L
.16372 .15953 L
.17461 .152 L
.18466 .14359 L
.19377 .13433 L
.20381 .12159 L
.2139 .1048 L
.21938 .09317 L
.22459 .07975 L
.22944 .0644 L
.23473 .04304 L
.23953 .01725 L
s
.23953 .01725 m
.24188 0 L
s
.73837 .30752 m
.73954 .30562 L
.74077 .3044 L
.74213 .30335 L
.74486 .3017 L
.74976 .29946 L
.7608 .29583 L
.77116 .29327 L
.78081 .29128 L
.81977 .28537 L
.84105 .28296 L
.86119 .28101 L
.89957 .27792 L
.9404 .27527 L
.97619 .27333 L
s
.02381 .25549 m
.06244 .25214 L
.08255 .24994 L
.10458 .24701 L
.1253 .24357 L
.14415 .23962 L
.16372 .23427 L
.17461 .23051 L
.18466 .2263 L
.19377 .22167 L
.20381 .21531 L
.2139 .20691 L
.21938 .20109 L
.22459 .19438 L
.22944 .18671 L
.23473 .17603 L
.23953 .16313 L
.244 .14669 L
.24673 .13318 L
.2493 .11659 L
.25161 .09661 L
.25291 .08208 L
.2541 .0656 L
.2554 .04289 L
.2566 .01455 L
s
.2566 .01455 m
.25708 0 L
s
.73837 .30827 m
.73954 .30732 L
.74077 .30671 L
.74213 .30619 L
.74486 .30536 L
.74976 .30424 L
.7608 .30242 L
.77116 .30114 L
.78081 .30015 L
.81977 .29719 L
.84105 .29599 L
.86119 .29501 L
.89957 .29347 L
.9404 .29214 L
.97619 .29118 L
s
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07103 .30902 L
.07173 .30902 L
.073 .30902 L
Mistroke
.07376 .30902 L
.07448 .30902 L
.07513 .30902 L
.07583 .30902 L
.0766 .30902 L
.0774 .30902 L
.07809 .30902 L
.07885 .30902 L
.07956 .30902 L
.0802 .30902 L
.08095 .30902 L
.08166 .30902 L
.08291 .30902 L
.08362 .30902 L
.08427 .30902 L
.08544 .30902 L
.08669 .30902 L
.08787 .30902 L
.08896 .30902 L
.09016 .30902 L
.09148 .30902 L
.09214 .30902 L
.09285 .30902 L
.09413 .30902 L
.09483 .30902 L
.09548 .30902 L
.09619 .30902 L
.09695 .30902 L
.09821 .30902 L
.09893 .30902 L
.09961 .30902 L
.10086 .30902 L
.10201 .30902 L
.10333 .30902 L
.10458 .30902 L
.10572 .30902 L
.10694 .30902 L
.1081 .30902 L
.10916 .30902 L
.11033 .30902 L
.11162 .30902 L
.11227 .30902 L
.11297 .30902 L
.11422 .30902 L
.11491 .30902 L
.11554 .30902 L
.11624 .30902 L
.11698 .30902 L
.11822 .30902 L
.11892 .30902 L
Mistroke
.11958 .30902 L
.12081 .30902 L
.12194 .30902 L
.12323 .30902 L
.12446 .30902 L
.12562 .30902 L
.12668 .30902 L
.12789 .30902 L
.12903 .30902 L
.13009 .30902 L
.13107 .30902 L
.13214 .30902 L
.13327 .30902 L
.13441 .30902 L
.13564 .30902 L
.1368 .30902 L
.13785 .30902 L
.13909 .30902 L
.13979 .30902 L
.14043 .30902 L
.14162 .30902 L
.14288 .30902 L
.14402 .30902 L
.14526 .30902 L
.14656 .30902 L
.14777 .30902 L
.14891 .30902 L
.14994 .30902 L
.15113 .30902 L
.15226 .30902 L
.15348 .30902 L
.15478 .30902 L
.15589 .30902 L
.15711 .30902 L
.15842 .30902 L
.15915 .30902 L
.15982 .30902 L
.16113 .30902 L
.16236 .30902 L
.16352 .30902 L
.16456 .30902 L
.16577 .30902 L
.1669 .30902 L
.16796 .30902 L
.16893 .30902 L
.16999 .30902 L
.17111 .30902 L
.17225 .30902 L
.17347 .30902 L
.17462 .30902 L
Mistroke
.17566 .30902 L
.17689 .30902 L
.17758 .30902 L
.17823 .30902 L
.1794 .30902 L
.18065 .30902 L
.18185 .30902 L
.18316 .30902 L
.18441 .30902 L
.18556 .30902 L
.1867 .30902 L
.18773 .30902 L
.18893 .30902 L
.19005 .30902 L
.19128 .30902 L
.19258 .30902 L
.19369 .30902 L
.19491 .30902 L
.19623 .30902 L
.19696 .30902 L
.19763 .30902 L
.19894 .30902 L
.20017 .30902 L
.20122 .30902 L
.20238 .30902 L
.20359 .30902 L
.20472 .30902 L
.20578 .30902 L
.20675 .30902 L
.20781 .30902 L
.20894 .30902 L
.21008 .30902 L
.21129 .30902 L
.21244 .30902 L
.21349 .30902 L
.21472 .30902 L
.21541 .30902 L
.21605 .30902 L
.21723 .30902 L
.21847 .30902 L
.21968 .30902 L
.221 .30902 L
.22224 .30902 L
.2234 .30902 L
.22454 .30902 L
.22558 .30902 L
.22677 .30902 L
.2279 .30902 L
.22914 .30902 L
.23044 .30902 L
Mistroke
.23155 .30902 L
.23277 .30902 L
.23409 .30902 L
.23482 .30902 L
.2355 .30902 L
.2368 .30902 L
.23804 .30902 L
.23909 .30902 L
.24025 .30902 L
.24146 .30902 L
.2426 .30902 L
.24365 .30902 L
.24462 .30902 L
.24569 .30902 L
.24681 .30902 L
.24795 .30902 L
.24917 .30902 L
.25032 .30902 L
.25137 .30902 L
.2526 .30902 L
.25329 .30902 L
.25393 .30902 L
.2551 .30902 L
.25635 .30902 L
.25756 .30902 L
.25888 .30902 L
.26013 .30902 L
.26129 .30902 L
.26233 .30902 L
.26348 .30902 L
.26467 .30902 L
.2658 .30902 L
.26704 .30902 L
.26835 .30902 L
.26946 .30902 L
.27068 .30902 L
.272 .30902 L
.27274 .30902 L
.27341 .30902 L
.27472 .30902 L
.27595 .30902 L
.27701 .30902 L
.27817 .30902 L
.27938 .30902 L
.28052 .30902 L
.28158 .30902 L
.28255 .30902 L
.28367 .30902 L
.28474 .30902 L
.28588 .30902 L
Mistroke
.2871 .30902 L
.28825 .30902 L
.2893 .30902 L
.29053 .30902 L
.29122 .30902 L
.29186 .30902 L
.29303 .30902 L
.29427 .30902 L
.29549 .30902 L
.29618 .30902 L
.29682 .30902 L
.29799 .30902 L
.29923 .30902 L
.30034 .30902 L
.30138 .30902 L
.30252 .30902 L
.30375 .30902 L
.30499 .30902 L
.30569 .30902 L
.30634 .30902 L
.30765 .30902 L
.30839 .30902 L
.30906 .30902 L
.31026 .30902 L
.31156 .30902 L
.31278 .30902 L
.31392 .30902 L
.31497 .30902 L
.31611 .30902 L
.31718 .30902 L
.31816 .30902 L
.3193 .30902 L
.32055 .30902 L
.32173 .30902 L
.32282 .30902 L
.32406 .30902 L
.32522 .30902 L
.32626 .30902 L
.32739 .30902 L
.32862 .30902 L
.32992 .30902 L
.33103 .30902 L
.33225 .30902 L
.33356 .30902 L
.33477 .30902 L
.33541 .30902 L
.3361 .30902 L
.33683 .30902 L
.33751 .30902 L
.33876 .30902 L
Mistroke
.33991 .30902 L
.34123 .30902 L
.34249 .30902 L
.3436 .30902 L
.3448 .30902 L
.34592 .30902 L
.34694 .30902 L
.34814 .30902 L
.34945 .30902 L
.35067 .30902 L
.35181 .30902 L
.35302 .30902 L
.35431 .30902 L
.35554 .30902 L
.35665 .30902 L
.35796 .30902 L
.3587 .30902 L
.35939 .30902 L
.36064 .30902 L
.36128 .30902 L
.36198 .30902 L
.36266 .30902 L
.36337 .30902 L
.36465 .30902 L
.36536 .30902 L
.36602 .30902 L
.36675 .30902 L
.36753 .30902 L
.3682 .30902 L
.36893 .30902 L
.36962 .30902 L
.37026 .30902 L
.37146 .30902 L
.37274 .30902 L
.37394 .30902 L
.37526 .30902 L
.37651 .30902 L
.37766 .30902 L
.3788 .30902 L
.37984 .30902 L
.38103 .30902 L
.38216 .30902 L
.38339 .30902 L
.3847 .30902 L
.38581 .30902 L
.38703 .30902 L
.38834 .30902 L
.38908 .30902 L
.38975 .30902 L
.39106 .30902 L
Mistroke
.39229 .30902 L
.39334 .30902 L
.3945 .30902 L
.39571 .30902 L
.39685 .30902 L
.39791 .30902 L
.39888 .30902 L
.39994 .30902 L
.40106 .30902 L
.40221 .30902 L
.40342 .30902 L
.40457 .30902 L
.40562 .30902 L
.40685 .30902 L
.40754 .30902 L
.40818 .30902 L
.40936 .30902 L
.4106 .30902 L
.41181 .30902 L
.41313 .30902 L
.41438 .30902 L
.41554 .30902 L
.41669 .30902 L
.41772 .30902 L
.41892 .30902 L
.42005 .30902 L
.42129 .30902 L
.42259 .30902 L
.42371 .30902 L
.42493 .30902 L
.42624 .30902 L
.42698 .30902 L
.42765 .30902 L
.42896 .30902 L
.43019 .30902 L
.43125 .30902 L
.43241 .30902 L
.43362 .30902 L
.43476 .30902 L
.43582 .30902 L
.43679 .30902 L
.43791 .30902 L
.43898 .30902 L
.44012 .30902 L
.44134 .30902 L
.44249 .30902 L
.44354 .30902 L
.44477 .30902 L
.44546 .30902 L
.4461 .30902 L
Mistroke
.44727 .30902 L
.44851 .30902 L
.44973 .30902 L
.45042 .30902 L
.45106 .30902 L
.45223 .30902 L
.45347 .30902 L
.45458 .30902 L
.45562 .30902 L
.45676 .30902 L
.45799 .30902 L
.45922 .30902 L
.45992 .30902 L
.46057 .30902 L
.46188 .30902 L
.46262 .30902 L
.46329 .30902 L
.46449 .30902 L
.46579 .30902 L
.46702 .30902 L
.46815 .30902 L
.4692 .30902 L
.47034 .30902 L
.47141 .30902 L
.47239 .30902 L
.47353 .30902 L
.47478 .30902 L
.47596 .30902 L
.47705 .30902 L
.47829 .30902 L
.47945 .30902 L
.48049 .30902 L
.48162 .30902 L
.48285 .30902 L
.48415 .30902 L
.48526 .30902 L
.48648 .30902 L
.48779 .30902 L
.489 .30902 L
.48963 .30902 L
.49033 .30902 L
.49105 .30902 L
.49174 .30902 L
.49299 .30902 L
.49413 .30902 L
.49539 .30902 L
.49671 .30902 L
.49783 .30902 L
.49902 .30902 L
.50014 .30902 L
Mistroke
.50116 .30902 L
.50236 .30902 L
.50366 .30902 L
.50489 .30902 L
.50603 .30902 L
.50723 .30902 L
.50853 .30902 L
.50975 .30902 L
.51087 .30902 L
.51218 .30902 L
.51292 .30902 L
.51361 .30902 L
.51486 .30902 L
.5155 .30902 L
.5162 .30902 L
.51687 .30902 L
.51759 .30902 L
.51886 .30902 L
.51958 .30902 L
.52024 .30902 L
.52096 .30902 L
.52174 .30902 L
.52241 .30902 L
.52314 .30902 L
.52383 .30902 L
.52447 .30902 L
.52568 .30902 L
.52695 .30902 L
.52816 .30902 L
.52947 .30902 L
.53072 .30902 L
.53187 .30902 L
.53301 .30902 L
.53405 .30902 L
.53525 .30902 L
.53637 .30902 L
.5376 .30902 L
.53891 .30902 L
.54002 .30902 L
.54124 .30902 L
.54255 .30902 L
.54329 .30902 L
.54396 .30902 L
.54526 .30902 L
.5465 .30902 L
.54755 .30902 L
.54871 .30902 L
.54992 .30902 L
.55105 .30902 L
.55211 .30902 L
Mistroke
.55308 .30902 L
.55415 .30902 L
.55527 .30902 L
.55641 .30902 L
.55763 .30902 L
.55878 .30902 L
.55982 .30902 L
.56105 .30902 L
.56175 .30902 L
.56238 .30902 L
.56356 .30902 L
.5648 .30902 L
.56601 .30902 L
.56734 .30902 L
.56858 .30902 L
.56974 .30902 L
.57088 .30902 L
.57192 .30902 L
.57312 .30902 L
.57425 .30902 L
.57548 .30902 L
.57679 .30902 L
.5779 .30902 L
.57912 .30902 L
.58044 .30902 L
.58118 .30902 L
.58185 .30902 L
.58315 .30902 L
.58439 .30902 L
.58544 .30902 L
.5866 .30902 L
.58782 .30902 L
.58895 .30902 L
.59001 .30902 L
.59098 .30902 L
.5921 .30902 L
.59317 .30902 L
.59431 .30902 L
.59553 .30902 L
.59668 .30902 L
.59773 .30902 L
.59896 .30902 L
.59965 .30902 L
.60029 .30902 L
.60146 .30902 L
.60271 .30902 L
.60392 .30902 L
.60461 .30902 L
.60525 .30902 L
.60642 .30902 L
Mistroke
.60766 .30902 L
.60876 .30902 L
.6098 .30902 L
.61094 .30902 L
.61217 .30902 L
.61341 .30902 L
.6141 .30902 L
.61475 .30902 L
.61607 .30902 L
.6168 .30902 L
.61747 .30902 L
.61867 .30902 L
.61997 .30902 L
.6212 .30902 L
.62233 .30902 L
.62339 .30902 L
.62452 .30902 L
.62559 .30902 L
.62657 .30902 L
.62771 .30902 L
.62896 .30902 L
.63014 .30902 L
.63123 .30902 L
.63247 .30902 L
.63363 .30902 L
.63467 .30902 L
.6358 .30902 L
.63703 .30902 L
.63833 .30902 L
.63944 .30902 L
.64066 .30902 L
.64197 .30902 L
.64318 .30902 L
.64381 .30902 L
.6445 .30902 L
.64523 .30902 L
.64591 .30902 L
.64716 .30902 L
.64831 .30902 L
.64956 .30902 L
.65088 .30902 L
.652 .30902 L
.65319 .30902 L
.65431 .30902 L
.65533 .30902 L
.65653 .30902 L
.65784 .30902 L
.65906 .30902 L
.6602 .30902 L
.6614 .30902 L
Mistroke
.6627 .30902 L
.66392 .30902 L
.66504 .30902 L
.66635 .30902 L
.66709 .30902 L
.66777 .30902 L
.66903 .30902 L
.66966 .30902 L
.67036 .30902 L
.67104 .30902 L
.67175 .30902 L
.67303 .30902 L
.67374 .30902 L
.6744 .30902 L
.67513 .30902 L
.67591 .30902 L
.67658 .30902 L
.67731 .30902 L
.678 .30902 L
.67864 .30902 L
.67984 .30902 L
.68112 .30902 L
.68232 .30902 L
.68364 .30902 L
.68488 .30902 L
.68603 .30902 L
.68718 .30902 L
.68821 .30902 L
.68941 .30902 L
.69053 .30902 L
.69176 .30902 L
.69307 .30902 L
.69418 .30902 L
.6954 .30902 L
.69671 .30902 L
.69745 .30902 L
.69812 .30902 L
.69942 .30902 L
.70066 .30902 L
.70171 .30902 L
.70286 .30902 L
.70407 .30902 L
.70521 .30902 L
.70627 .30902 L
.70724 .30902 L
.7083 .30902 L
.70942 .30902 L
.71056 .30902 L
.71178 .30902 L
.71293 .30902 L
Mistroke
.71398 .30902 L
.71521 .30902 L
.7159 .30902 L
.71654 .30902 L
.71771 .30902 L
.71896 .30902 L
.72017 .30902 L
.72149 .30902 L
.72273 .30902 L
.72389 .30902 L
.72503 .30902 L
.72607 .30902 L
.72727 .30902 L
.7284 .30902 L
.72963 .30902 L
.73094 .30902 L
.73205 .30902 L
.73327 .30902 L
.73458 .30902 L
.73532 .30902 L
.73599 .30902 L
.7373 .30902 L
.73853 .30902 L
.73959 .30902 L
.74075 .30902 L
.74196 .30902 L
.7431 .30902 L
.74416 .30902 L
.74513 .30902 L
.74619 .30902 L
.74731 .30902 L
.74846 .30902 L
.74967 .30902 L
.75083 .30902 L
.75187 .30902 L
.7531 .30902 L
.75379 .30902 L
.75443 .30902 L
.75561 .30902 L
.75685 .30902 L
.75806 .30902 L
.75875 .30902 L
.75939 .30902 L
.76056 .30902 L
.7618 .30902 L
.7629 .30902 L
.76394 .30902 L
.76508 .30902 L
.76631 .30902 L
.76754 .30902 L
Mistroke
.76824 .30902 L
.76889 .30902 L
.7702 .30902 L
.77094 .30902 L
.77161 .30902 L
.7728 .30902 L
.7741 .30902 L
.77533 .30902 L
.77646 .30902 L
.77752 .30902 L
.77865 .30902 L
.77972 .30902 L
.7807 .30902 L
.78184 .30902 L
.78309 .30902 L
.78427 .30902 L
.78536 .30902 L
.7866 .30902 L
.78776 .30902 L
.7888 .30902 L
.78993 .30902 L
.79116 .30902 L
.79246 .30902 L
.79357 .30902 L
.79479 .30902 L
.7961 .30902 L
.7973 .30902 L
.79793 .30902 L
.79863 .30902 L
.79936 .30902 L
.80004 .30902 L
.80129 .30902 L
.80243 .30902 L
.80369 .30902 L
.80501 .30902 L
.80612 .30902 L
.80731 .30902 L
.80843 .30902 L
.80945 .30902 L
.81066 .30902 L
.81196 .30902 L
.81318 .30902 L
.81432 .30902 L
.81552 .30902 L
.81682 .30902 L
.81804 .30902 L
.81916 .30902 L
.82047 .30902 L
.8212 .30902 L
.82189 .30902 L
Mistroke
.82315 .30902 L
.82385 .30902 L
.82448 .30902 L
.82516 .30902 L
.82587 .30902 L
.82715 .30902 L
.82786 .30902 L
.82852 .30902 L
.82925 .30902 L
.83002 .30902 L
.8307 .30902 L
.83143 .30902 L
.83212 .30902 L
.83275 .30902 L
.83396 .30902 L
.83524 .30902 L
.83644 .30902 L
.83775 .30902 L
.839 .30902 L
.84015 .30902 L
.84129 .30902 L
.84232 .30902 L
.84352 .30902 L
.84464 .30902 L
.84587 .30902 L
.84718 .30902 L
.84829 .30902 L
.8495 .30902 L
.85082 .30902 L
.85155 .30902 L
.85222 .30902 L
.85353 .30902 L
.85476 .30902 L
.85581 .30902 L
.85697 .30902 L
.85818 .30902 L
.85932 .30902 L
.86037 .30902 L
.86134 .30902 L
.86241 .30902 L
.86353 .30902 L
.86467 .30902 L
.86589 .30902 L
.86704 .30902 L
.86808 .30902 L
.86931 .30902 L
.87 .30902 L
.87064 .30902 L
.87182 .30902 L
.87306 .30902 L
Mistroke
.87427 .30902 L
.87559 .30902 L
.87684 .30902 L
.87799 .30902 L
.87914 .30902 L
.88017 .30902 L
.88137 .30902 L
.88249 .30902 L
.88373 .30902 L
.88503 .30902 L
.88615 .30902 L
.88737 .30902 L
.88868 .30902 L
.88942 .30902 L
.89009 .30902 L
.89139 .30902 L
.89263 .30902 L
.89368 .30902 L
.89484 .30902 L
.89605 .30902 L
.89719 .30902 L
.89825 .30902 L
.89922 .30902 L
.90029 .30902 L
.90141 .30902 L
.90255 .30902 L
.90377 .30902 L
.90492 .30902 L
.90596 .30902 L
.90719 .30902 L
.90789 .30902 L
.90852 .30902 L
.9097 .30902 L
.91094 .30902 L
.91216 .30902 L
.91284 .30902 L
.91348 .30902 L
.91464 .30902 L
.91589 .30902 L
.91699 .30902 L
.91803 .30902 L
.91917 .30902 L
.9204 .30902 L
.92163 .30902 L
.92233 .30902 L
.92297 .30902 L
.92429 .30902 L
.92502 .30902 L
.92569 .30902 L
.92689 .30902 L
Mistroke
.92819 .30902 L
.92941 .30902 L
.93055 .30902 L
.9316 .30902 L
.93273 .30902 L
.9338 .30902 L
.93478 .30902 L
.93592 .30902 L
.93717 .30902 L
.93835 .30902 L
.93944 .30902 L
.94068 .30902 L
.94184 .30902 L
.94288 .30902 L
.94401 .30902 L
.94524 .30902 L
.94654 .30902 L
.94765 .30902 L
.94887 .30902 L
.94975 .30902 L
.95057 .30902 L
.95146 .30902 L
.95241 .30902 L
.95324 .30902 L
.95401 .30902 L
.95486 .30902 L
.95577 .30902 L
.95653 .30902 L
.95737 .30902 L
.95824 .30902 L
.95905 .30902 L
.95981 .30902 L
.9605 .30902 L
.9613 .30902 L
.96206 .30902 L
.96287 .30902 L
.96377 .30902 L
.96471 .30902 L
.96559 .30902 L
.96641 .30902 L
.96716 .30902 L
.96802 .30902 L
.96884 .30902 L
.96972 .30902 L
.97067 .30902 L
.97155 .30902 L
.97236 .30902 L
.97331 .30902 L
.97433 .30902 L
.9753 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
.02381 .36254 m
.06244 .36589 L
.08255 .3681 L
.10458 .37103 L
.1253 .37447 L
.14415 .37842 L
.16372 .38376 L
.17461 .38753 L
.18466 .39173 L
.19377 .39636 L
.20381 .40273 L
.2139 .41113 L
.21938 .41694 L
.22459 .42365 L
.22944 .43133 L
.23473 .442 L
.23953 .4549 L
.244 .47135 L
.24673 .48485 L
.2493 .50145 L
.25161 .52142 L
.25291 .53595 L
.2541 .55244 L
.2554 .57514 L
.2566 .60349 L
s
.2566 .60349 m
.25708 .61803 L
s
.73837 .30976 m
.73954 .31071 L
.74077 .31133 L
.74213 .31185 L
.74486 .31268 L
.74976 .3138 L
.7608 .31561 L
.77116 .31689 L
.78081 .31788 L
.81977 .32084 L
.84105 .32205 L
.86119 .32302 L
.89957 .32457 L
.9404 .32589 L
.97619 .32686 L
s
.02381 .41606 m
.06244 .42277 L
.08255 .42717 L
.10458 .43304 L
.1253 .43992 L
.14415 .44782 L
.16372 .4585 L
.17461 .46604 L
.18466 .47445 L
.19377 .4837 L
.20381 .49644 L
.2139 .51324 L
.21938 .52487 L
.22459 .53829 L
.22944 .55364 L
.23473 .57499 L
.23953 .60079 L
s
.23953 .60079 m
.24188 .61803 L
s
.73837 .31051 m
.73954 .31241 L
.74077 .31364 L
.74213 .31468 L
.74486 .31633 L
.74976 .31857 L
.7608 .3222 L
.77116 .32476 L
.78081 .32675 L
.81977 .33267 L
.84105 .33508 L
.86119 .33703 L
.89957 .34012 L
.9404 .34276 L
.97619 .3447 L
s
.02381 .46959 m
.06244 .47964 L
.08255 .48625 L
.10458 .49505 L
.1253 .50537 L
.14415 .51722 L
.16372 .53324 L
.17461 .54455 L
.18466 .55716 L
.19377 .57105 L
.20381 .59015 L
.2139 .61535 L
s
.2139 .61535 m
.21474 .61803 L
s
.73837 .31126 m
.73954 .31411 L
.74077 .31595 L
.74213 .31751 L
.74486 .31999 L
.74976 .32335 L
.7608 .3288 L
.77116 .33264 L
.78081 .33562 L
.81977 .34449 L
.84105 .3481 L
.86119 .35103 L
.89957 .35567 L
.9404 .35964 L
.97619 .36254 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[87]:=",
  ImageSize->{217, 134.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003I0000QR000`400?l00000o`00003ofOooool0
0=Wooooo001Oooooo`?o00001?ooool2o`00077ooooo001Pooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000L?ooool005Sooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000L?ooool003?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Tooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool2o`00
06_ooooo000cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0J_ooool0
03;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Sooooo`;o00001?ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo06[ooooo000booooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0006_ooooo000booooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000<?oo
ool00ol0003oooooooooo`1Zooooo`00<Oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`00033ooooo00?o0000ooooooooool0J_ooool0037ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0000`ooooo`;o0000Joooool0037ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo0000033ooooo00?o0000ooooooooool0J_ooool0033ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo0000033ooooo00?o0000ooooooooool0J_oo
ool002oooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000033ooooo0_l0
001[ooooo`00;oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000<?oo
ool00ol0003oooooooooo`1Zooooo`00;_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool00000<?ooool00ol0003oooooooooo`1Zooooo`00;Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool2o`0006_ooooo000]oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000oooo
ooooool0J_ooool002cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0J_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Cooooo1Ol00004ooooo`03o`000?oooooooooo00[o
oooo00Co0000oooooooooooooooo0_l0001[ooooo`00:_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool00000K?ooool002Sooooo0_l0000;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`Co00001?ooool00ol0003o
ooooooooo`1Zooooo`009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Zooooo`009_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool06oooool5o`0000Oooooo1Ol00003ooooo`;o0000
Joooool002Cooooo0_l0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`1Zooooo`008oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Zooooo`008_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;oooool2o`00
06_ooooo000Pooooo`;o00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0J_ooool001kooooo0_l0000Aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Zooooo`006oooool3o`0001?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`;o0000Joooool001Oooooo1?l0000E
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Z
ooooo`005Oooool2o`0001Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo06[ooooo000Booooo`?o00006Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02Wooooo0ol00004ooooo`;o0000Joooool000oooooo0ol0000Jooooo`;o0000
2oooool00ol0003oooooooooo`0Xooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`1Zooooo`003Oooool2o`0001cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Rooooo`Go00001Oooool01Ol0003ooooooooooooooooo000006cooooo000Zooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0;?ooool01?l0003oooooooooooooool2o`0006_o
oooo000Xooooo`;o00003_ooool00ol0003oooooooooo`0Yooooo`Co00001?ooool00ol0003ooooo
ooooo`1Zooooo`009_ooool2o`00013ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo06[ooooo000Tooooo`;o00004_ooool00ol0003oooooooooo`0Y
ooooo`Go00000oooool2o`0006_ooooo000Rooooo`;o00004oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo06[ooooo000Oooooo`?o00005Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo06[ooooo000Kooooo`Co00005oooool00ol0003oooooooooo`0cooooo`;o0000
Joooool001Kooooo1Ol0000Kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0J_oo
ool0017ooooo1Ol0000Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0J_ooool0
00gooooo1?l0000Sooooo`03o`000?oooooooooo03Gooooo0_l0001[ooooo`00<oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo06[ooooo000booooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0J_ooool0033ooooo0_l0000jooooo`;o0000Joooool002kooooo0_l0000X
ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`1Z
ooooo`00;?ooool2o`0002_ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0J_ooool002[ooooo0_l0000Vooooo`Go00000oooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`;o0000Joooool002Oooooo0ol0000a
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00001/ooooo`008oooool4
o`00037ooooo00Go0000ooooooooooooooooo`000007ooooo`Co00001?ooool00ol0003ooooooooo
o`1Zooooo`007oooool4o`0003Gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0J_ooool001Kooooo2Ol0000jooooo`?o00002?ooool5
o`0000?ooooo0_l0001[ooooo`003Oooool9o`0002Oooooo0ol0000/ooooo`03o`000?oooooooooo
02_ooooo0ol0000/ooooo`Go00002oooool000kooooo00Co0000oooooooooooo0000;?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool08oooool8o`00
0005ooooool0003oooooooooool000002oooool000Oooooo1Ol00003ooooo`03o`000?oooooooooo
02Cooooo1Ol00003ooooo`03o`000?oooooooooo02_ooooo0_l0000]ooooo`03o`000?oooooooooo
01_ooooo2?l0000:ooooo`03o`000?oooooooooo00_ooooo000@ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017o
oooo2_l0000Cooooo`03o`000?oooooooooo00[ooooo000=ooooo`05o`000?ooooooooooooooool0
0000;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool03?ooool5o`0001;ooooo3Ol0000;ooooo`003Oooool01Ol0003ooooooooooooooooo000002_o
oooo0_l0000]ooooo`;o0000;?ooool2o`0000[ooooo1?l00009ooooo`ko00002?ooool01Ol0003o
oooooooooooooooo000000_ooooo000>ooooo`?o0000;Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool01?ooool4o`0000;ooooo2ol0000Gooooo`?o
00003?ooool006cooooo00?o0000ooooooooool0<?ooool3o`0000;ooooo1?l0000Qooooo`Co0000
3?ooool006cooooo0_l0000`ooooo`Ko00002ooooolJo`00013ooooo001/ooooo`03o`000?oooooo
oooo02kooooo0_l00003ooooo`go0000:_ooool006cooooo00?o0000ooooooooool0;Oooool6o`00
03Oooooo0008ooooolWo00002?ooool000gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo1ol00002ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02_ooool006cooooo00?o0000ooooooooool0;_ooool3o`0000?ooooo3Ol0
000Yooooo`00K?ooool2o`00033ooooo1_l0000<oooooa[o00003oooool006cooooo00?o0000oooo
ooooool0<Oooool3o`000003ooooool0003o000000?o00008Oooool3o`0000cooooo001/ooooo`03
o`000?oooooooooo03Cooooo1?l00002ooooo`_o00009Oooool006cooooo0_l0000iooooo`Co0000
2Oooool>o`0001Oooooo001/ooooo`03o`000?oooooooooo03cooooo1Ol0000Booooo`_o00003?oo
ool006cooooo00?o0000ooooooooool0@Oooool:o`0001oooooo001/ooooo`;o0000C?ooool8o`00
01Oooooo001/ooooo`03o`000?oooooooooo05?ooooo2?l0000?ooooo`003Oooool:o`0005Gooooo
00?o0000ooooooooool0Foooool3o`0000cooooo000Gooooo`Wo0000C?ooool2o`0006_ooooo000P
ooooo`Co0000=?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000
ooooooooool0J_ooool002Cooooo1?l0000aooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06[ooooo000Xooooo`?o0000;oooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`;o0000Joooool002_ooooo0_l0000^
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00001/ooooo`00;Oooool2
o`0002Wooooo00Go0000ooooooooooooooooo`000007ooooo`Co00001?ooool00ol0003ooooooooo
o`1Zooooo`00;oooool2o`0002Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0J_ooool0037ooooo0_l0000Vooooo`?o00002?ooool5
o`0000?ooooo0_l0001[ooooo`00<oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
06[ooooo000=ooooo`?o00008oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo06[o
oooo000@ooooo`?o00008Oooool00ol0003oooooooooo`0eooooo`;o0000Joooool001?ooooo1?l0
000Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0J_ooool001Oooooo1Ol0000I
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0J_ooool001cooooo1?l0000Foooo
o`03o`000?oooooooooo03?ooooo0_l0001[ooooo`008?ooool3o`0001?ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`1Zooooo`008oooool2o`0001;ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`1Zooooo`009Oooool2o`00013ooooo00?o0000ooooooooool0:ooo
ool3o`0000Cooooo0_l0001[ooooo`009oooool2o`0000oooooo00?o0000ooooooooool0:Oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0J_ooool002Wooooo0_l0000=
ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00001/ooooo`00:oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooooooo0_l0
001[ooooo`003Oooool3o`0001cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0X
ooooo`Co00001?ooool00ol0003oooooooooo`1Zooooo`004?ooool3o`0001[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0J_ooool001?ooooo0ol0000Hooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0:?ooool5o`0000?ooooo0_l0001[ooooo`005_ooool2o`0001Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo06[ooooo000Hooooo`Co00004ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0J_oo
ool001cooooo0ol0000Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool2
o`0006_ooooo000Oooooo`;o00004?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0J_ooool0027ooooo0_l0000>ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Zooooo`008oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;oooool2o`0006_ooooo
000Tooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo06[ooooo000Uooooo`;o00003?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0J_ooool002Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo0_l0001[oooo
o`00:?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03
o`000?oooooooooo06[ooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo06[ooooo000Zooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo
00Co0000oooooooooooooooo0_l0001[ooooo`00:oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05o`00
0?ooooooooooooooool00000K?ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool4o`0000Cooooo
00?o0000ooooooooool0J_ooool002cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0J_ooool002gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo1Ol00007ooooo`Go00000ooo
ool2o`0006_ooooo000]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06[ooooo000^ooooo`03o`000?oooooooooo
00Kooooo00Go0000ooooooooooooooooo`00000`ooooo`03o`000?oooooooooo06[ooooo000_oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000`ooooo`;o0000Joooool0
02oooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000033ooooo00?o0000
ooooooooool0J_ooool0033ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
0000033ooooo00?o0000ooooooooool0J_ooool0037ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo0000033ooooo0_l0001[ooooo`00<Oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0J_ooool003;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo06[ooooo000boooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00008oooool3o`0000Cooooo0_l00004
ooooo`;o0000Joooool003;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000T
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`1Zooooo`00<oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo06[ooooo
000cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo0_l0001[ooooo`00H?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`00073ooooo001Oooooo`;o00001?ooool01?l0003ooooo
ooooool0001`ooooo`00H?ooool00ol0003oooooooooo`03ooooo`;o0000LOooool00=Wooooo0000
\
\>"],
  ImageRangeCache->{{{77.875, 293.875}, {230.938, 97.875}} -> {-3.90182, \
5.05285, 0.020923, 0.16121}}]
}, Open  ]],

Cell[TextData[{
  "From this picture we conjecture that all solutions to DE2 that are valid \
outside the closed interval [-1,1] have a  vertical asymptote as ",
  StyleBox["t",
    FontSlant->"Italic"],
  " approaches -1 from the left and will approach 0 as ",
  StyleBox["t",
    FontSlant->"Italic"],
  " approaches the 1 from the right.  \nThe question is \"How does ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " represent solutions when t is greater than 1 or when t is less than -1?\" \
The  answer, as illustrated below, is rather unusual (and probably not the \
one you might guess). \nQuestion: What is the solution to DE2 satisfying the \
initial condition y(0) = 1? \nAnswer: See ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s solution. "
}], "Text"],

Cell[CellGroupData[{

Cell["soln2 = DSolve[ {DE2, y[0]==1}, y, t ]", "Input",
  CellLabel->"In[90]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{t}, \(-\(\(\[ImaginaryI]\ \@\(\(-1\) + t\)\)\/\@\(1 + t\)\
\)\)]}}\)], "Output",
  CellLabel->"Out[90]="]
}, Open  ]],

Cell[TextData[{
  "The same formula can be used, but with an imaginary constant:  ",
  StyleBox["i",
    FontSlant->"Italic"],
  ". See the graph below. "
}], "Text"],

Cell[CellGroupData[{

Cell["Plot[ y[t]/.soln2, {t,-1,1}, PlotRange->{-1,4} ]", "Input",
  CellLabel->"In[93]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.08008 .61803 m
.08259 .60555 L
.09412 .5614 L
.10458 .52966 L
.12383 .48445 L
.14465 .44786 L
.16419 .42088 L
.18565 .39679 L
.22514 .36235 L
.26556 .33553 L
.30447 .31483 L
.34583 .29655 L
.38568 .28151 L
.42401 .2688 L
.46479 .25672 L
.50405 .24617 L
.5418 .2368 L
.58201 .22748 L
.6207 .219 L
.66184 .21037 L
.70146 .20231 L
.73957 .19468 L
.78013 .18654 L
.81917 .17853 L
.86067 .16953 L
.90065 .15989 L
.91934 .15475 L
.93912 .14848 L
.95677 .14144 L
.96161 .13902 L
.9668 .13594 L
.96932 .13414 L
.97171 .13211 L
.97385 .12974 L
.97507 .12786 L
.97619 .12363 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{188, 116.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002l0000M2000`400?l00000o`00003o_?ooool0
0;cooooo001Gooooo`?o0000H_ooool005Sooooo00?o0000ooooooooool0HOooool0053ooooo1Ol0
0003ooooo`03o`000?oooooooooo067ooooo001Hooooo`03o`000?oooooooooo00?ooooo0_l0001L
ooooo`00F?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05_ooooo001Gooooo`;o
00001Oooool00ol0003oooooooooo`1Kooooo`00F?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo05_ooooo001Nooooo`;o0000G?ooool005kooooo00?o0000ooooooooool0Foooool0
05kooooo00?o0000ooooooooool0Foooool005kooooo00?o0000ooooooooool0Foooool005kooooo
0_l0001Looooo`00G_ooool00ol0003oooooooooo`1Kooooo`00G_ooool00ol0003oooooooooo`1K
ooooo`003Oooool3o`00027ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Ooooo
o`03o`000?oooooooooo01oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Poooo
o`?o00002oooool000kooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Nooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo00[ooooo
0006ooooo`Go00000oooool00ol0003oooooooooo`0Hooooo`Go00000_ooool01?l0003ooooooooo
ool0000;ooooo`03o`000?oooooooooo01cooooo0_l0000Oooooo`04o`000?ooooooooooo`0000_o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0:ooooo`003_ooool00ol0003ooooo
ooooo`0Oooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Nooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0:ooooo`003_ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`00
00Oooooo1?l0000Oooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00001oooool4
o`00027ooooo00?o0000ooooooooool02_ooool000gooooo0_l0000Qooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool08Oooool2o`0000cooooo000>ooooo`03o`000?oooooo
oooo023ooooo0_l00008ooooo`Go00007_ooool2o`00023ooooo0_l00008ooooo`Go00008?ooool0
0ol0003oooooooooo`0:ooooo`00G_ooool00ol0003oooooooooo`1Kooooo`00G_ooool00ol0003o
ooooooooo`1Kooooo`00G_ooool00ol0003oooooooooo`1Kooooo`002?oooon]o`0000Oooooo000<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool2o`0000_ooooo001Noooo
o`03o`000?oooooooooo04gooooo0_l0000<ooooo`00G_ooool00ol0003oooooooooo`1:ooooo`?o
00003_ooool005kooooo0_l00018ooooo`?o00004Oooool005kooooo00?o0000ooooooooool0A?oo
ool3o`0001Cooooo001Nooooo`03o`000?oooooooooo043ooooo1?l0000Gooooo`00G_ooool00ol0
003oooooooooo`0mooooo`?o00006oooool005kooooo00?o0000ooooooooool0>Oooool4o`0001ko
oooo001Nooooo`;o0000=oooool3o`0002;ooooo001Nooooo`03o`000?oooooooooo037ooooo1Ol0
000Uooooo`00G_ooool00ol0003oooooooooo`0Zooooo`Oo0000:_ooool005kooooo00?o0000oooo
ooooool09Oooool5o`00037ooooo001Nooooo`;o00008oooool3o`0003Kooooo001Nooooo`03o`00
0?oooooooooo01gooooo1Ol0000iooooo`00G_ooool00ol0003oooooooooo`0Gooooo`Ko0000?_oo
ool005kooooo00?o0000ooooooooool05?ooool3o`0004Cooooo001Nooooo`;o00004?ooool5o`00
04Oooooo001Nooooo`03o`000?oooooooooo00Wooooo1_l0001<ooooo`00Eoooool3o`0000Cooooo
00?o0000ooooooooool01_ooool3o`0005;ooooo001Hooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooooooo1Ol0001Eooooo`00F?ooool00ol0003oooooooooo`02ooooo`Go0000F_oo
ool005Sooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`1Looooo`00E_ooool4o`00
00Cooooo00?o0000ooooooooool0Foooool005?ooooo0ol000000ooooooo0000o`000005ooooo`03
o`000?oooooooooo05_ooooo001?ooooo`Co00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo05_ooooo001<ooooo`?o00003oooool2o`0005cooooo0019ooooo`?o00004_ooool0
0ol0003oooooooooo`1Kooooo`00Aoooool2o`0001Gooooo00?o0000ooooooooool0Foooool004Go
oooo0_l0000Gooooo`03o`000?oooooooooo05_ooooo0013ooooo`;o00006Oooool2o`0005cooooo
0010ooooo`?o00006oooool00ol0003oooooooooo`1Kooooo`00?Oooool3o`0001kooooo00?o0000
ooooooooool0Foooool003_ooooo0_l0000Qooooo`03o`000?oooooooooo05_ooooo000jooooo`03
o`000?oooooooooo027ooooo0_l0001Looooo`00>?ooool2o`0002Cooooo00?o0000ooooooooool0
Foooool003Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Kooooo`00=Oooool2
o`0002Oooooo00?o0000ooooooooool0Foooool003?ooooo0_l0000Yooooo`;o0000G?ooool003;o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Kooooo`00<?ooool2o`0002Cooooo
1Ol00003ooooo`03o`000?oooooooooo05_ooooo000^ooooo`;o00009oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo05_ooooo000]ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Kooooo`00;?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00;ooooo0_l0001Looooo`00:oooool00ol0003oooooooooo`0Xoooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Kooooo`00:_ooool00ol0
003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1K
ooooo`00:Oooool00ol0003oooooooooo`0[ooooo`?o00001?ooool00ol0003oooooooooo`1Koooo
o`00:?ooool00ol0003oooooooooo`0cooooo`;o0000G?ooool002Oooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`1Kooooo`009_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo05_ooooo000Uooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Foooool0
02Cooooo00?o0000ooooooooool0=oooool2o`0005cooooo000Tooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0Foooool002?ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Kooooo`008_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo05_ooooo000R
ooooo`03o`000?oooooooooo03Wooooo0_l0001Looooo`008Oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo05_ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0Foooool0023ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1Kooooo`007ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo05_ooooo000Oooooo`03o`000?oooooo
oooo03cooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`0fooooo`?o00001?ooool00ol0
003oooooooooo`1Kooooo`007Oooool00ol0003oooooooooo`0fooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`1Kooooo`007Oooool00ol0003oooooooooo`0jooooo`05
o`000?ooooooooooooooool00000GOooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Co
oooo0_l0001Looooo`007?ooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool0
0000GOooool001cooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool0Foooool001_ooooo00?o0000ooooooooool0>Oooool3o`0000Cooooo
00?o0000ooooooooool0Foooool001_ooooo00?o0000ooooooooool0@?ooool2o`0005cooooo000K
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Foooool001[ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`1Kooooo`006_ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo05_ooooo000Iooooo`03o`000?oooooooooo04;ooooo0_l0001Looooo`006Ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05_ooooo000Iooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool0Foooool001Sooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`1Kooooo`006?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo05_o
oooo000Hooooo`03o`000?oooooooooo04?ooooo0_l0001Looooo`005oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo05_ooooo000Gooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool0Foooool001Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1Koooo
o`005oooool00ol0003oooooooooo`14ooooo`;o0000G?ooool001Kooooo00?o0000ooooooooool0
?oooool3o`0000?ooooo00?o0000ooooooooool0Foooool001Kooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05_ooooo000Fooooo`03o`000?oooooo
oooo03gooooo1Ol00003ooooo`03o`000?oooooooooo05_ooooo000Fooooo`03o`000?oooooooooo
03gooooo00Co0000oooooooooooo00001?ooool2o`0005cooooo001Gooooo`03o`000?oooooo0000
06;ooooo001Hooooo`;o0000H_ooool005Wooooo00?o0000ooooooooool0H?ooool00;cooooo0000
\
\>"],
  ImageRangeCache->{{{77.875, 264.875}, {588.5, 473.438}} -> {-2.10881, \
21.1067, 0.0122369, 0.0471421}}]
}, Open  ]],

Cell[TextData[{
  "The next picture shows several solutions on the interval  -1 < ",
  StyleBox[" t <",
    FontSlant->"Italic"],
  " 1. The values for c are listed first. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Table[k*I, {k,-3,3}]
Plot[ Evaluate[Table[y[t]/.gensoln, {c,-3*I,3*I,I}]], {t,-1,1}, \
PlotRange->{-5,5}]\
\>", "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \({\(-3\)\ \[ImaginaryI], \(-2\)\ \[ImaginaryI], \(-\[ImaginaryI]\), 
      0, \[ImaginaryI], 2\ \[ImaginaryI], 3\ \[ImaginaryI]}\)], "Output",
  CellLabel->"Out[103]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.0618034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .0618 -12 -4.5 ]
[.4875 .0618 0 4.5 ]
[.4875 .18541 -12 -4.5 ]
[.4875 .18541 0 4.5 ]
[.4875 .43262 -6 -4.5 ]
[.4875 .43262 0 4.5 ]
[.4875 .55623 -6 -4.5 ]
[.4875 .55623 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .0618 m
.50625 .0618 L
s
[(-4)] .4875 .0618 1 0 Mshowa
.5 .18541 m
.50625 .18541 L
s
[(-2)] .4875 .18541 1 0 Mshowa
.5 .43262 m
.50625 .43262 L
s
[(2)] .4875 .43262 1 0 Mshowa
.5 .55623 m
.50625 .55623 L
s
[(4)] .4875 .55623 1 0 Mshowa
.125 Mabswid
.5 .09271 m
.50375 .09271 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.27668 .61803 m
.30447 .59586 L
.34583 .56843 L
.38568 .54587 L
.42401 .52681 L
.46479 .50868 L
.50405 .49286 L
.5418 .47881 L
.58201 .46482 L
.6207 .45211 L
.66184 .43916 L
.70146 .42707 L
.73957 .41562 L
.78013 .40342 L
.81917 .3914 L
.86067 .3779 L
.90065 .36344 L
.91934 .35573 L
.93912 .34633 L
.95677 .33577 L
.96161 .33214 L
.9668 .32751 L
.96932 .32482 L
.97171 .32177 L
.97385 .31821 L
.97507 .31539 L
.97619 .30905 L
s
.15569 .61803 m
.16419 .60629 L
.18565 .58221 L
.22514 .54776 L
.26556 .52094 L
.30447 .50024 L
.34583 .48196 L
.38568 .46692 L
.42401 .45421 L
.46479 .44213 L
.50405 .43158 L
.5418 .42221 L
.58201 .41289 L
.6207 .40441 L
.66184 .39578 L
.70146 .38772 L
.73957 .38009 L
.78013 .37195 L
.81917 .36394 L
.86067 .35494 L
.90065 .3453 L
.91934 .34016 L
.93912 .33389 L
.95677 .32685 L
.96161 .32443 L
.9668 .32135 L
.96932 .31955 L
.97171 .31752 L
.97385 .31515 L
.97507 .31327 L
.97619 .30904 L
s
.06075 .61803 m
.06244 .60958 L
.0675 .59087 L
.07289 .57415 L
.08259 .54999 L
.09412 .52792 L
.10458 .51204 L
.12383 .48944 L
.14465 .47114 L
.16419 .45766 L
.18565 .44561 L
.22514 .42839 L
.26556 .41498 L
.30447 .40463 L
.34583 .39549 L
.38568 .38797 L
.42401 .38161 L
.46479 .37557 L
.50405 .3703 L
.5418 .36561 L
.58201 .36095 L
.6207 .35671 L
.66184 .3524 L
.70146 .34837 L
.73957 .34455 L
.78013 .34048 L
.81917 .33648 L
.86067 .33198 L
.90065 .32716 L
.91934 .32459 L
.93912 .32145 L
.95677 .31793 L
.96161 .31672 L
.9668 .31518 L
.96932 .31429 L
.97171 .31327 L
.97385 .31208 L
.97507 .31114 L
.97619 .30903 L
s
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07103 .30902 L
.07173 .30902 L
.073 .30902 L
Mistroke
.07376 .30902 L
.07448 .30902 L
.07513 .30902 L
.07583 .30902 L
.0766 .30902 L
.0774 .30902 L
.07809 .30902 L
.07885 .30902 L
.07956 .30902 L
.0802 .30902 L
.08095 .30902 L
.08166 .30902 L
.08291 .30902 L
.08362 .30902 L
.08427 .30902 L
.08544 .30902 L
.08669 .30902 L
.08787 .30902 L
.08896 .30902 L
.09016 .30902 L
.09148 .30902 L
.09214 .30902 L
.09285 .30902 L
.09413 .30902 L
.09483 .30902 L
.09548 .30902 L
.09619 .30902 L
.09695 .30902 L
.09821 .30902 L
.09893 .30902 L
.09961 .30902 L
.10086 .30902 L
.10201 .30902 L
.10333 .30902 L
.10458 .30902 L
.10572 .30902 L
.10694 .30902 L
.1081 .30902 L
.10916 .30902 L
.11033 .30902 L
.11162 .30902 L
.11227 .30902 L
.11297 .30902 L
.11422 .30902 L
.11491 .30902 L
.11554 .30902 L
.11624 .30902 L
.11698 .30902 L
.11822 .30902 L
.11892 .30902 L
Mistroke
.11958 .30902 L
.12081 .30902 L
.12194 .30902 L
.12323 .30902 L
.12446 .30902 L
.12562 .30902 L
.12668 .30902 L
.12789 .30902 L
.12903 .30902 L
.13009 .30902 L
.13107 .30902 L
.13214 .30902 L
.13327 .30902 L
.13441 .30902 L
.13564 .30902 L
.1368 .30902 L
.13785 .30902 L
.13909 .30902 L
.13979 .30902 L
.14043 .30902 L
.14162 .30902 L
.14288 .30902 L
.14402 .30902 L
.14526 .30902 L
.14656 .30902 L
.14777 .30902 L
.14891 .30902 L
.14994 .30902 L
.15113 .30902 L
.15226 .30902 L
.15348 .30902 L
.15478 .30902 L
.15589 .30902 L
.15711 .30902 L
.15842 .30902 L
.15915 .30902 L
.15982 .30902 L
.16113 .30902 L
.16236 .30902 L
.16352 .30902 L
.16456 .30902 L
.16577 .30902 L
.1669 .30902 L
.16796 .30902 L
.16893 .30902 L
.16999 .30902 L
.17111 .30902 L
.17225 .30902 L
.17347 .30902 L
.17462 .30902 L
Mistroke
.17566 .30902 L
.17689 .30902 L
.17758 .30902 L
.17823 .30902 L
.1794 .30902 L
.18065 .30902 L
.18185 .30902 L
.18316 .30902 L
.18441 .30902 L
.18556 .30902 L
.1867 .30902 L
.18773 .30902 L
.18893 .30902 L
.19005 .30902 L
.19128 .30902 L
.19258 .30902 L
.19369 .30902 L
.19491 .30902 L
.19623 .30902 L
.19696 .30902 L
.19763 .30902 L
.19894 .30902 L
.20017 .30902 L
.20122 .30902 L
.20238 .30902 L
.20359 .30902 L
.20472 .30902 L
.20578 .30902 L
.20675 .30902 L
.20781 .30902 L
.20894 .30902 L
.21008 .30902 L
.21129 .30902 L
.21244 .30902 L
.21349 .30902 L
.21472 .30902 L
.21541 .30902 L
.21605 .30902 L
.21723 .30902 L
.21847 .30902 L
.21968 .30902 L
.221 .30902 L
.22224 .30902 L
.2234 .30902 L
.22454 .30902 L
.22558 .30902 L
.22677 .30902 L
.2279 .30902 L
.22914 .30902 L
.23044 .30902 L
Mistroke
.23155 .30902 L
.23277 .30902 L
.23409 .30902 L
.23482 .30902 L
.2355 .30902 L
.2368 .30902 L
.23804 .30902 L
.23909 .30902 L
.24025 .30902 L
.24146 .30902 L
.2426 .30902 L
.24365 .30902 L
.24462 .30902 L
.24569 .30902 L
.24681 .30902 L
.24795 .30902 L
.24917 .30902 L
.25032 .30902 L
.25137 .30902 L
.2526 .30902 L
.25329 .30902 L
.25393 .30902 L
.2551 .30902 L
.25635 .30902 L
.25756 .30902 L
.25888 .30902 L
.26013 .30902 L
.26129 .30902 L
.26233 .30902 L
.26348 .30902 L
.26467 .30902 L
.2658 .30902 L
.26704 .30902 L
.26835 .30902 L
.26946 .30902 L
.27068 .30902 L
.272 .30902 L
.27274 .30902 L
.27341 .30902 L
.27472 .30902 L
.27595 .30902 L
.27701 .30902 L
.27817 .30902 L
.27938 .30902 L
.28052 .30902 L
.28158 .30902 L
.28255 .30902 L
.28367 .30902 L
.28474 .30902 L
.28588 .30902 L
Mistroke
.2871 .30902 L
.28825 .30902 L
.2893 .30902 L
.29053 .30902 L
.29122 .30902 L
.29186 .30902 L
.29303 .30902 L
.29427 .30902 L
.29549 .30902 L
.29618 .30902 L
.29682 .30902 L
.29799 .30902 L
.29923 .30902 L
.30034 .30902 L
.30138 .30902 L
.30252 .30902 L
.30375 .30902 L
.30499 .30902 L
.30569 .30902 L
.30634 .30902 L
.30765 .30902 L
.30839 .30902 L
.30906 .30902 L
.31026 .30902 L
.31156 .30902 L
.31278 .30902 L
.31392 .30902 L
.31497 .30902 L
.31611 .30902 L
.31718 .30902 L
.31816 .30902 L
.3193 .30902 L
.32055 .30902 L
.32173 .30902 L
.32282 .30902 L
.32406 .30902 L
.32522 .30902 L
.32626 .30902 L
.32739 .30902 L
.32862 .30902 L
.32992 .30902 L
.33103 .30902 L
.33225 .30902 L
.33356 .30902 L
.33477 .30902 L
.33541 .30902 L
.3361 .30902 L
.33683 .30902 L
.33751 .30902 L
.33876 .30902 L
Mistroke
.33991 .30902 L
.34123 .30902 L
.34249 .30902 L
.3436 .30902 L
.3448 .30902 L
.34592 .30902 L
.34694 .30902 L
.34814 .30902 L
.34945 .30902 L
.35067 .30902 L
.35181 .30902 L
.35302 .30902 L
.35431 .30902 L
.35554 .30902 L
.35665 .30902 L
.35796 .30902 L
.3587 .30902 L
.35939 .30902 L
.36064 .30902 L
.36128 .30902 L
.36198 .30902 L
.36266 .30902 L
.36337 .30902 L
.36465 .30902 L
.36536 .30902 L
.36602 .30902 L
.36675 .30902 L
.36753 .30902 L
.3682 .30902 L
.36893 .30902 L
.36962 .30902 L
.37026 .30902 L
.37146 .30902 L
.37274 .30902 L
.37394 .30902 L
.37526 .30902 L
.37651 .30902 L
.37766 .30902 L
.3788 .30902 L
.37984 .30902 L
.38103 .30902 L
.38216 .30902 L
.38339 .30902 L
.3847 .30902 L
.38581 .30902 L
.38703 .30902 L
.38834 .30902 L
.38908 .30902 L
.38975 .30902 L
.39106 .30902 L
Mistroke
.39229 .30902 L
.39334 .30902 L
.3945 .30902 L
.39571 .30902 L
.39685 .30902 L
.39791 .30902 L
.39888 .30902 L
.39994 .30902 L
.40106 .30902 L
.40221 .30902 L
.40342 .30902 L
.40457 .30902 L
.40562 .30902 L
.40685 .30902 L
.40754 .30902 L
.40818 .30902 L
.40936 .30902 L
.4106 .30902 L
.41181 .30902 L
.41313 .30902 L
.41438 .30902 L
.41554 .30902 L
.41669 .30902 L
.41772 .30902 L
.41892 .30902 L
.42005 .30902 L
.42129 .30902 L
.42259 .30902 L
.42371 .30902 L
.42493 .30902 L
.42624 .30902 L
.42698 .30902 L
.42765 .30902 L
.42896 .30902 L
.43019 .30902 L
.43125 .30902 L
.43241 .30902 L
.43362 .30902 L
.43476 .30902 L
.43582 .30902 L
.43679 .30902 L
.43791 .30902 L
.43898 .30902 L
.44012 .30902 L
.44134 .30902 L
.44249 .30902 L
.44354 .30902 L
.44477 .30902 L
.44546 .30902 L
.4461 .30902 L
Mistroke
.44727 .30902 L
.44851 .30902 L
.44973 .30902 L
.45042 .30902 L
.45106 .30902 L
.45223 .30902 L
.45347 .30902 L
.45458 .30902 L
.45562 .30902 L
.45676 .30902 L
.45799 .30902 L
.45922 .30902 L
.45992 .30902 L
.46057 .30902 L
.46188 .30902 L
.46262 .30902 L
.46329 .30902 L
.46449 .30902 L
.46579 .30902 L
.46702 .30902 L
.46815 .30902 L
.4692 .30902 L
.47034 .30902 L
.47141 .30902 L
.47239 .30902 L
.47353 .30902 L
.47478 .30902 L
.47596 .30902 L
.47705 .30902 L
.47829 .30902 L
.47945 .30902 L
.48049 .30902 L
.48162 .30902 L
.48285 .30902 L
.48415 .30902 L
.48526 .30902 L
.48648 .30902 L
.48779 .30902 L
.489 .30902 L
.48963 .30902 L
.49033 .30902 L
.49105 .30902 L
.49174 .30902 L
.49299 .30902 L
.49413 .30902 L
.49539 .30902 L
.49671 .30902 L
.49783 .30902 L
.49902 .30902 L
.50014 .30902 L
Mistroke
.50116 .30902 L
.50236 .30902 L
.50366 .30902 L
.50489 .30902 L
.50603 .30902 L
.50723 .30902 L
.50853 .30902 L
.50975 .30902 L
.51087 .30902 L
.51218 .30902 L
.51292 .30902 L
.51361 .30902 L
.51486 .30902 L
.5155 .30902 L
.5162 .30902 L
.51687 .30902 L
.51759 .30902 L
.51886 .30902 L
.51958 .30902 L
.52024 .30902 L
.52096 .30902 L
.52174 .30902 L
.52241 .30902 L
.52314 .30902 L
.52383 .30902 L
.52447 .30902 L
.52568 .30902 L
.52695 .30902 L
.52816 .30902 L
.52947 .30902 L
.53072 .30902 L
.53187 .30902 L
.53301 .30902 L
.53405 .30902 L
.53525 .30902 L
.53637 .30902 L
.5376 .30902 L
.53891 .30902 L
.54002 .30902 L
.54124 .30902 L
.54255 .30902 L
.54329 .30902 L
.54396 .30902 L
.54526 .30902 L
.5465 .30902 L
.54755 .30902 L
.54871 .30902 L
.54992 .30902 L
.55105 .30902 L
.55211 .30902 L
Mistroke
.55308 .30902 L
.55415 .30902 L
.55527 .30902 L
.55641 .30902 L
.55763 .30902 L
.55878 .30902 L
.55982 .30902 L
.56105 .30902 L
.56175 .30902 L
.56238 .30902 L
.56356 .30902 L
.5648 .30902 L
.56601 .30902 L
.56734 .30902 L
.56858 .30902 L
.56974 .30902 L
.57088 .30902 L
.57192 .30902 L
.57312 .30902 L
.57425 .30902 L
.57548 .30902 L
.57679 .30902 L
.5779 .30902 L
.57912 .30902 L
.58044 .30902 L
.58118 .30902 L
.58185 .30902 L
.58315 .30902 L
.58439 .30902 L
.58544 .30902 L
.5866 .30902 L
.58782 .30902 L
.58895 .30902 L
.59001 .30902 L
.59098 .30902 L
.5921 .30902 L
.59317 .30902 L
.59431 .30902 L
.59553 .30902 L
.59668 .30902 L
.59773 .30902 L
.59896 .30902 L
.59965 .30902 L
.60029 .30902 L
.60146 .30902 L
.60271 .30902 L
.60392 .30902 L
.60461 .30902 L
.60525 .30902 L
.60642 .30902 L
Mistroke
.60766 .30902 L
.60876 .30902 L
.6098 .30902 L
.61094 .30902 L
.61217 .30902 L
.61341 .30902 L
.6141 .30902 L
.61475 .30902 L
.61607 .30902 L
.6168 .30902 L
.61747 .30902 L
.61867 .30902 L
.61997 .30902 L
.6212 .30902 L
.62233 .30902 L
.62339 .30902 L
.62452 .30902 L
.62559 .30902 L
.62657 .30902 L
.62771 .30902 L
.62896 .30902 L
.63014 .30902 L
.63123 .30902 L
.63247 .30902 L
.63363 .30902 L
.63467 .30902 L
.6358 .30902 L
.63703 .30902 L
.63833 .30902 L
.63944 .30902 L
.64066 .30902 L
.64197 .30902 L
.64318 .30902 L
.64381 .30902 L
.6445 .30902 L
.64523 .30902 L
.64591 .30902 L
.64716 .30902 L
.64831 .30902 L
.64956 .30902 L
.65088 .30902 L
.652 .30902 L
.65319 .30902 L
.65431 .30902 L
.65533 .30902 L
.65653 .30902 L
.65784 .30902 L
.65906 .30902 L
.6602 .30902 L
.6614 .30902 L
Mistroke
.6627 .30902 L
.66392 .30902 L
.66504 .30902 L
.66635 .30902 L
.66709 .30902 L
.66777 .30902 L
.66903 .30902 L
.66966 .30902 L
.67036 .30902 L
.67104 .30902 L
.67175 .30902 L
.67303 .30902 L
.67374 .30902 L
.6744 .30902 L
.67513 .30902 L
.67591 .30902 L
.67658 .30902 L
.67731 .30902 L
.678 .30902 L
.67864 .30902 L
.67984 .30902 L
.68112 .30902 L
.68232 .30902 L
.68364 .30902 L
.68488 .30902 L
.68603 .30902 L
.68718 .30902 L
.68821 .30902 L
.68941 .30902 L
.69053 .30902 L
.69176 .30902 L
.69307 .30902 L
.69418 .30902 L
.6954 .30902 L
.69671 .30902 L
.69745 .30902 L
.69812 .30902 L
.69942 .30902 L
.70066 .30902 L
.70171 .30902 L
.70286 .30902 L
.70407 .30902 L
.70521 .30902 L
.70627 .30902 L
.70724 .30902 L
.7083 .30902 L
.70942 .30902 L
.71056 .30902 L
.71178 .30902 L
.71293 .30902 L
Mistroke
.71398 .30902 L
.71521 .30902 L
.7159 .30902 L
.71654 .30902 L
.71771 .30902 L
.71896 .30902 L
.72017 .30902 L
.72149 .30902 L
.72273 .30902 L
.72389 .30902 L
.72503 .30902 L
.72607 .30902 L
.72727 .30902 L
.7284 .30902 L
.72963 .30902 L
.73094 .30902 L
.73205 .30902 L
.73327 .30902 L
.73458 .30902 L
.73532 .30902 L
.73599 .30902 L
.7373 .30902 L
.73853 .30902 L
.73959 .30902 L
.74075 .30902 L
.74196 .30902 L
.7431 .30902 L
.74416 .30902 L
.74513 .30902 L
.74619 .30902 L
.74731 .30902 L
.74846 .30902 L
.74967 .30902 L
.75083 .30902 L
.75187 .30902 L
.7531 .30902 L
.75379 .30902 L
.75443 .30902 L
.75561 .30902 L
.75685 .30902 L
.75806 .30902 L
.75875 .30902 L
.75939 .30902 L
.76056 .30902 L
.7618 .30902 L
.7629 .30902 L
.76394 .30902 L
.76508 .30902 L
.76631 .30902 L
.76754 .30902 L
Mistroke
.76824 .30902 L
.76889 .30902 L
.7702 .30902 L
.77094 .30902 L
.77161 .30902 L
.7728 .30902 L
.7741 .30902 L
.77533 .30902 L
.77646 .30902 L
.77752 .30902 L
.77865 .30902 L
.77972 .30902 L
.7807 .30902 L
.78184 .30902 L
.78309 .30902 L
.78427 .30902 L
.78536 .30902 L
.7866 .30902 L
.78776 .30902 L
.7888 .30902 L
.78993 .30902 L
.79116 .30902 L
.79246 .30902 L
.79357 .30902 L
.79479 .30902 L
.7961 .30902 L
.7973 .30902 L
.79793 .30902 L
.79863 .30902 L
.79936 .30902 L
.80004 .30902 L
.80129 .30902 L
.80243 .30902 L
.80369 .30902 L
.80501 .30902 L
.80612 .30902 L
.80731 .30902 L
.80843 .30902 L
.80945 .30902 L
.81066 .30902 L
.81196 .30902 L
.81318 .30902 L
.81432 .30902 L
.81552 .30902 L
.81682 .30902 L
.81804 .30902 L
.81916 .30902 L
.82047 .30902 L
.8212 .30902 L
.82189 .30902 L
Mistroke
.82315 .30902 L
.82385 .30902 L
.82448 .30902 L
.82516 .30902 L
.82587 .30902 L
.82715 .30902 L
.82786 .30902 L
.82852 .30902 L
.82925 .30902 L
.83002 .30902 L
.8307 .30902 L
.83143 .30902 L
.83212 .30902 L
.83275 .30902 L
.83396 .30902 L
.83524 .30902 L
.83644 .30902 L
.83775 .30902 L
.839 .30902 L
.84015 .30902 L
.84129 .30902 L
.84232 .30902 L
.84352 .30902 L
.84464 .30902 L
.84587 .30902 L
.84718 .30902 L
.84829 .30902 L
.8495 .30902 L
.85082 .30902 L
.85155 .30902 L
.85222 .30902 L
.85353 .30902 L
.85476 .30902 L
.85581 .30902 L
.85697 .30902 L
.85818 .30902 L
.85932 .30902 L
.86037 .30902 L
.86134 .30902 L
.86241 .30902 L
.86353 .30902 L
.86467 .30902 L
.86589 .30902 L
.86704 .30902 L
.86808 .30902 L
.86931 .30902 L
.87 .30902 L
.87064 .30902 L
.87182 .30902 L
.87306 .30902 L
Mistroke
.87427 .30902 L
.87559 .30902 L
.87684 .30902 L
.87799 .30902 L
.87914 .30902 L
.88017 .30902 L
.88137 .30902 L
.88249 .30902 L
.88373 .30902 L
.88503 .30902 L
.88615 .30902 L
.88737 .30902 L
.88868 .30902 L
.88942 .30902 L
.89009 .30902 L
.89139 .30902 L
.89263 .30902 L
.89368 .30902 L
.89484 .30902 L
.89605 .30902 L
.89719 .30902 L
.89825 .30902 L
.89922 .30902 L
.90029 .30902 L
.90141 .30902 L
.90255 .30902 L
.90377 .30902 L
.90492 .30902 L
.90596 .30902 L
.90719 .30902 L
.90789 .30902 L
.90852 .30902 L
.9097 .30902 L
.91094 .30902 L
.91216 .30902 L
.91284 .30902 L
.91348 .30902 L
.91464 .30902 L
.91589 .30902 L
.91699 .30902 L
.91803 .30902 L
.91917 .30902 L
.9204 .30902 L
.92163 .30902 L
.92233 .30902 L
.92297 .30902 L
.92429 .30902 L
.92502 .30902 L
.92569 .30902 L
.92689 .30902 L
Mistroke
.92819 .30902 L
.92941 .30902 L
.93055 .30902 L
.9316 .30902 L
.93273 .30902 L
.9338 .30902 L
.93478 .30902 L
.93592 .30902 L
.93717 .30902 L
.93835 .30902 L
.93944 .30902 L
.94068 .30902 L
.94184 .30902 L
.94288 .30902 L
.94401 .30902 L
.94524 .30902 L
.94654 .30902 L
.94765 .30902 L
.94887 .30902 L
.94975 .30902 L
.95057 .30902 L
.95146 .30902 L
.95241 .30902 L
.95324 .30902 L
.95401 .30902 L
.95486 .30902 L
.95577 .30902 L
.95653 .30902 L
.95737 .30902 L
.95824 .30902 L
.95905 .30902 L
.95981 .30902 L
.9605 .30902 L
.9613 .30902 L
.96206 .30902 L
.96287 .30902 L
.96377 .30902 L
.96471 .30902 L
.96559 .30902 L
.96641 .30902 L
.96716 .30902 L
.96802 .30902 L
.96884 .30902 L
.96972 .30902 L
.97067 .30902 L
.97155 .30902 L
.97236 .30902 L
.97331 .30902 L
.97433 .30902 L
.9753 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
.06075 0 m
.06244 .00846 L
.0675 .02717 L
.07289 .04388 L
.08259 .06804 L
.09412 .09012 L
.10458 .10599 L
.12383 .1286 L
.14465 .14689 L
.16419 .16038 L
.18565 .17242 L
.22514 .18965 L
.26556 .20306 L
.30447 .2134 L
.34583 .22255 L
.38568 .23007 L
.42401 .23642 L
.46479 .24246 L
.50405 .24774 L
.5418 .25242 L
.58201 .25708 L
.6207 .26132 L
.66184 .26564 L
.70146 .26967 L
.73957 .27348 L
.78013 .27755 L
.81917 .28156 L
.86067 .28605 L
.90065 .29088 L
.91934 .29344 L
.93912 .29658 L
.95677 .3001 L
.96161 .30131 L
.9668 .30285 L
.96932 .30375 L
.97171 .30477 L
.97385 .30595 L
.97507 .30689 L
.97619 .309 L
s
.15569 0 m
.16419 .01174 L
.18565 .03583 L
.22514 .07028 L
.26556 .09709 L
.30447 .11779 L
.34583 .13608 L
.38568 .15112 L
.42401 .16382 L
.46479 .17591 L
.50405 .18646 L
.5418 .19582 L
.58201 .20515 L
.6207 .21362 L
.66184 .22225 L
.70146 .23031 L
.73957 .23795 L
.78013 .24608 L
.81917 .2541 L
.86067 .26309 L
.90065 .27274 L
.91934 .27787 L
.93912 .28414 L
.95677 .29118 L
.96161 .2936 L
.9668 .29669 L
.96932 .29848 L
.97171 .30052 L
.97385 .30289 L
.97507 .30477 L
.97619 .30899 L
s
.27668 0 m
.30447 .02218 L
.34583 .04961 L
.38568 .07217 L
.42401 .09123 L
.46479 .10935 L
.50405 .12518 L
.5418 .13923 L
.58201 .15321 L
.6207 .16593 L
.66184 .17887 L
.70146 .19096 L
.73957 .20241 L
.78013 .21462 L
.81917 .22664 L
.86067 .24013 L
.90065 .2546 L
.91934 .2623 L
.93912 .2717 L
.95677 .28227 L
.96161 .2859 L
.9668 .29052 L
.96932 .29321 L
.97171 .29627 L
.97385 .29982 L
.97507 .30264 L
.97619 .30898 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[103]:=",
  ImageSize->{193.625, 119.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000310000Mb000`400?l00000o`00003o3Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo0_l0000Yooooo`03o`000?oooooo
oooo05gooooo000=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo05gooooo000=ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05go
oooo000=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo05gooooo000>ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool05oooool2o`0002Cooooo00?o0000ooooooooool0GOooool000kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0GOooool000kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0GOooool000oooooo00?o0000oooooooo
ool04_ooool2o`0001Wooooo0_l0000Pooooo`03o`000?oooooooooo05gooooo000?ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo05gooooo000?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Eooooo`?o00001?ooool00ol0003oooooooooo`1Mooooo`004?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo0_l0000Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool0013ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Iooooo`;o00002oooool5o`000003ooooool0003o000000?o00001?ooool00ol0
003oooooooooo`1Mooooo`004?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01[o
oooo0_l0000?ooooo`04o`000?ooooooooooo`0000Gooooo0_l0001Nooooo`004Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo0_l0000>ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool0GOooool0017ooooo00?o0000ooooooooool06?ooool2o`0001gooooo
0_l0000=ooooo`;o00001Oooool00ol0003oooooooooo`1Mooooo`004_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01cooooo0_l0000<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0GOooool001;ooooo00?o0000ooooooooool06_ooool2o`0001kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Mooooo`004oooool00ol0003oooooooooo`0Koooo
o`;o00007Oooool2o`0000oooooo00?o0000ooooooooool0GOooool001?ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Looooo`;o00003Oooool00ol0003oooooooooo`1Mooooo`00
5?ooool00ol0003oooooooooo`0Mooooo`;o00007_ooool3o`0000[ooooo00?o0000ooooooooool0
GOooool001Gooooo00?o0000ooooooooool07_ooool2o`0001oooooo0ol00007ooooo`03o`000?oo
oooooooo05gooooo000Eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool2
o`0000Gooooo00?o0000ooooooooool0GOooool001Kooooo00?o0000ooooooooool08?ooool2o`00
027ooooo0ol00002ooooo`03o`000?oooooooooo05gooooo000Gooooo`03o`000?oooooooooo027o
oooo0_l0000Rooooo`?o0000Goooool001Sooooo00?o0000ooooooooool08_ooool3o`00027ooooo
0_l0001Nooooo`006Oooool2o`0002Gooooo0ol0000Nooooo`03o`000?oooooo000000;o0000Fooo
ool001_ooooo00?o0000ooooooooool09Oooool2o`0001cooooo00?o0000ooooooooool00_ooool3
o`0005Sooooo000Looooo`03o`000?oooooooooo02Kooooo0ol0000Iooooo`03o`000?oooooooooo
00Gooooo0ol0001Eooooo`007Oooool00ol0003oooooooooo`0Xooooo`?o00005_ooool00ol0003o
ooooooooo`08ooooo`?o0000D_ooool001kooooo00?o0000ooooooooool0:_ooool3o`0001?ooooo
00?o0000ooooooooool02oooool3o`0004oooooo000Oooooo`03o`000?oooooooooo02cooooo0ol0
000@ooooo`03o`000?oooooooooo00kooooo0ol0001<ooooo`008?ooool2o`0002oooooo0ol0000=
ooooo`03o`000?oooooooooo017ooooo0ol00019ooooo`008_ooool2o`00033ooooo0ol0000:oooo
o`03o`000?oooooooooo01Cooooo0ol00016ooooo`009?ooool2o`00037ooooo1_l00004ooooo`03
o`000?oooooooooo01Oooooo0ol00013ooooo`009_ooool3o`00033ooooo1?l00004ooooo`03o`00
0?oooooooooo01[ooooo0ol00010ooooo`00:Oooool3o`0002Kooooo1Ol00003ooooo`03o`000?oo
oooooooo00?o000000?oooooo`000?ooool07_ooool3o`0003gooooo000/ooooo`;o0000;Oooool0
0ol0003oooooooooo`02ooooo`Co00008?ooool3o`0003[ooooo000^ooooo`?o00009oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?l0000Oooooo`?o0000=oooool0
037ooooo0ol0000Tooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04
ooooo`Ko00007?ooool3o`0003Cooooo000dooooo`?o00008_ooool3o`0000Gooooo00?o0000oooo
ooooool02_ooool5o`0001[ooooo1?l0000`ooooo`00=oooool3o`0002Oooooo00?o0000oooooooo
ool03oooool4o`0001[ooooo1?l0000/ooooo`00>_ooool4o`0002?ooooo00?o0000ooooooooool0
4oooool4o`0001[ooooo1?l0000Xooooo`00?_ooool4o`0001oooooo00?o0000ooooooooool05ooo
ool3o`0001_ooooo1?l0000Tooooo`00@_ooool6o`0001Wooooo00?o0000ooooooooool06_ooool6
o`0001Wooooo0ol0000Qooooo`00B?ooool8o`00017ooooo00?o0000ooooooooool08?ooool6o`00
01Kooooo0ol0000Nooooo`00D?ooool7o`0000[ooooo00?o0000ooooooooool09_ooool3o`0001Ko
oooo0_l0000Looooo`00Eoooool8o`0000;ooooo00?o0000ooooooooool0:Oooool6o`0001;ooooo
0_l0000Jooooo`00Goooool7o`0002gooooo1_l0000>ooooo`?o00005oooool0067ooooo00?o0000
ooooooooool00_ooool8o`0002_ooooo1?l0000=ooooo`?o00005?ooool000Oooooo0ol0000Uoooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00009?ooool00ol0003oooooooooo`0:oooo
o`Oo00004_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Sooooo1_l0000:oooo
o`?o00002_ooool3o`0000Cooooo0008ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool04Oooool8
o`0000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000gooooo
1Ol00008ooooo`?o00002?ooool00ol0003oooooooooo`03ooooo`001Ol00003ooooo`03o`000?oo
oooooooo01cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Iooooo`Oo00000_ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo013ooooo1?l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool000Sooooo00?o0000ooooooooool08oooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08?ooool?o`0000;ooooo00?o0000oooooooo
ool05?ooool4o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo0008ooooo`03o`00
0?oooooooooo02?ooooo00Co0000oooooooooooo00001oooool4o`0002Cooooo00?o0000oooooooo
ool08_ooool01?l0003oooooooooool00007ooooo`[o00005Oooool4o`0000;ooooo0_l00003oooo
o`03o`000?oooooooooo00?ooooo0007ooooo`;o00009Oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00Oooooo2?l0000Aooooo`;o00000_ooool01?l0003oooooo`000?l0
0005ooooo`002?ooool00ol0003oooooooooo`0Tooooo`;o00002?ooool5o`0002?ooooo00?o0000
ooooooooool08oooool2o`0000Sooooo1Ol0000=ooooo`Oo00003?ooool2o`000004ooooool0003o
ooooo`0000Gooooo001Qooooo`03o`000?oooooooooo04Kooooo2_l00004ooooo`?o00001_ooool0
067ooooo00?o0000ooooooooool0D?ooool5o`000003ooooool0003o000000Gooooo001Qooooo`03
o`000?oooooooooo05Gooooo0ol00005ooooo`0000?oooooo`000?l00000__l0000000Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`?o00001?ooool0067ooooo00?o0000
ooooooooool0D_ooool6o`0000Gooooo001Qooooo`03o`000?oooooooooo04_ooooo1ol00003oooo
o`?o00001Oooool0067ooooo00?o0000ooooooooool0AOooool6o`0000Oooooo0ol000000ooooooo
0000ooooo`05ooooo`00HOooool00ol0003oooooooooo`0fooooo`oo00002_ooool3o`000004oooo
ool0003o0000o`0000Oooooo001Qooooo`03o`000?oooooooooo02kooooo2?l0000Eooooo`Co0000
0_ooool2o`0000[ooooo001Qooooo`03o`000?oooooooooo02Oooooo1ol0000Iooooo`Co00001?oo
ool2o`0000cooooo001Qooooo`03o`000?oooooooooo01Sooooo3ol0000Looooo`Co00001oooool0
0ol0003oooooooooo`0<ooooo`00HOooool00ol0003oooooooooo`0@ooooo`So00009oooool4o`00
00Wooooo0_l0000?ooooo`00HOooool00ol0003oooooooooo`09ooooo`Oo0000;?ooool3o`0000_o
oooo0_l0000Aooooo`00HOooool01?l0003oooooooooooooool8o`0002gooooo1_l0000;ooooo`?o
00004oooool005kooooo1ol0000_ooooo`Ko00003Oooool4o`0001Kooooo001Fooooo`So00000ooo
ool00ol0003oooooooooo`0/ooooo`Co00004?ooool3o`0001[ooooo001?ooooo`Oo00002oooool0
0ol0003oooooooooo`0Wooooo`Go00004Oooool3o`0001gooooo0019ooooo`Ko00004_ooool00ol0
003oooooooooo`0Qooooo`Ko00005?ooool2o`00023ooooo0015ooooo`Co00006?ooool00ol0003o
ooooooooo`0Mooooo`Co00005oooool3o`0002;ooooo000oooooo`Ko00007?ooool00ol0003ooooo
ooooo`0Hooooo`Go00005oooool4o`0002Gooooo000iooooo`Ko00008_ooool00ol0003ooooooooo
o`0Booooo`Ko00006Oooool3o`0002Wooooo000fooooo`?o0000:?ooool00ol0003oooooooooo`0>
ooooo`Co00007?ooool3o`0002cooooo000cooooo`?o0000:oooool00ol0003oooooooooo`0:oooo
o`Co00007Oooool3o`0002oooooo000`ooooo`?o00009Oooool5o`0000Cooooo00?o0000oooooooo
ool01oooool3o`0001kooooo0ol0000booooo`00;Oooool3o`0002Wooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`03ooooo`Co00007_ooool3o`0003Gooooo000[ooooo`;o0000
;Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?o00007_ooool4o`0003Sooooo
000Xooooo`?o0000<?ooool01?l0003oooooooooooooool4o`0001kooooo1?l0000looooo`009Ooo
ool3o`00033ooooo00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo01[ooooo
0ol00010ooooo`008oooool2o`0003?ooooo1Ol00004ooooo`03o`000?oooooooooo01Oooooo0ol0
0013ooooo`008_ooool00ol0003oooooooooo`0_ooooo`Co000000Coooooo`000?l0003o00001Ooo
ool00ol0003oooooooooo`0Eooooo`;o0000A_ooool0027ooooo00?o0000ooooooooool0;?ooool4
o`0000gooooo00?o0000ooooooooool04_ooool3o`0004Sooooo000Oooooo`;o0000;?ooool3o`00
017ooooo00?o0000ooooooooool03_ooool4o`0004_ooooo000Nooooo`03o`000?oooooooooo02Wo
oooo0ol0000Dooooo`03o`000?oooooooooo00_ooooo0ol0001?ooooo`007Oooool00ol0003ooooo
ooooo`0Wooooo`?o00005oooool00ol0003oooooooooo`08ooooo`?o0000D_ooool001cooooo00?o
0000ooooooooool09Oooool3o`0001[ooooo00?o0000ooooooooool01_ooool2o`0005Gooooo000K
ooooo`03o`000?oooooooooo02Cooooo0_l0000Mooooo`03o`000?oooooooooo00?ooooo0ol0001G
ooooo`006_ooool00ol0003oooooooooo`0Sooooo`;o00007oooool00ol0003oooooo`000003o`00
05[ooooo000Iooooo`03o`000?oooooooooo02;ooooo0_l0000Pooooo`?o0000G_ooool001Sooooo
00?o0000ooooooooool08Oooool2o`0001oooooo0ol000000ooooooo0000ooooo`1Nooooo`005ooo
ool00ol0003oooooooooo`0Pooooo`;o00007oooool2o`0000Cooooo00?o0000ooooooooool0GOoo
ool001Kooooo00?o0000ooooooooool07oooool2o`0001oooooo0_l00006ooooo`03o`000?oooooo
oooo05gooooo000Eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool2o`00
00Sooooo00?o0000ooooooooool0GOooool001Gooooo00?o0000ooooooooool07Oooool2o`0001ko
oooo0_l0000:ooooo`03o`000?oooooooooo05gooooo000Dooooo`03o`000?oooooooooo01cooooo
0_l0000Nooooo`;o00003?ooool00ol0003oooooooooo`1Mooooo`004oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01cooooo0_l0000>ooooo`03o`000?oooooooooo05gooooo000C
ooooo`03o`000?oooooooooo01[ooooo0_l0000Looooo`?o00004?ooool00ol0003oooooooooo`1M
ooooo`004_ooool00ol0003oooooooooo`0Iooooo`;o00007?ooool2o`0001?ooooo00?o0000oooo
ooooool0GOooool001;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`;o
00003_ooool3o`0000Cooooo00?o0000ooooooooool0GOooool0017ooooo00?o0000ooooooooool0
5oooool2o`0001cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo05gooooo000Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_oo
ool2o`0000oooooo1Ol00004ooooo`;o0000G_ooool0013ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Iooooo`;o00004Oooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo05gooooo000@ooooo`03o`000?oooooooooo01Cooooo0_l0000Kooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1Mooooo`004?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo0_l0000Fooooo`;o00001Oooool00ol0
003oooooooooo`1Mooooo`003oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05go
oooo000?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06?ooool2o`00023ooooo
00?o0000ooooooooool0GOooool000kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Fooooo`;o00008_ooool00ol0003oooooooooo`1Mooooo`003_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1M
ooooo`003_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo0_l0000Uoooo
o`03o`000?oooooooooo05gooooo000>ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05gooooo000=ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo05gooooo000=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05gooooo000=ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo05gooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 270.5}, {247.062, 128.375}} -> {-1.92135, \
5.84251, 0.0109847, 0.0846363}}]
}, Open  ]],

Cell[TextData[StyleBox["When there is more than one solution formula",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
As a rule, DSolve attempts to return explicit solution formulas \
even when there is more than one of them. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
DE3 = y'[t] == t/y[t]
gensoln3 = DSolve[ DE3, y, t ]\
\>", "Input",
  CellLabel->"In[105]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(t\/y[t]\)}]], "Output",
  CellLabel->"Out[105]="],

Cell[BoxData[
    \({{y \[Rule] Function[{t}, \(-\@\(t\^2 + 2\ C[1]\)\)]}, {y \[Rule] 
          Function[{t}, \@\(t\^2 + 2\ C[1]\)]}}\)], "Output",
  CellLabel->"Out[106]="]
}, Open  ]],

Cell["\<\
When an initial condition is added, DSolve picks the appropriate \
formula. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
soln3 = DSolve[ {DE3, y[0]==1}, y, t ]
Plot[ y[t]/.soln3, {t,-3,3}, PlotRange->{0,4} ]\
\>", "Input",
  CellLabel->"In[111]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{\(DSolve::"bvnul"\), \(\(:\)\(\ \)\), "\<\"For some branches of \
the general solution, the given boundary conditions lead to an empty \
solution. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"DSolve::bvnul\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[111]:="],

Cell[BoxData[
    \({{y \[Rule] Function[{t}, \@\(1 + t\^2\)]}}\)], "Output",
  CellLabel->"Out[111]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0 0.154508 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -3 -9 ]
[.81746 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.4875 .07725 -18 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -6 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -18 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -6 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-3)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-2)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-1)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(1)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.5)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(1)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(1.5)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(2.5)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(3)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(3.5)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4886 m
.06244 .45308 L
.10458 .41476 L
.14415 .37928 L
.18221 .34578 L
.22272 .311 L
.26171 .2787 L
.30316 .24614 L
.34309 .21726 L
.3815 .19282 L
.40095 .18213 L
.42237 .172 L
.44268 .16427 L
.46172 .15894 L
.46668 .15788 L
.4721 .15688 L
.47687 .15614 L
.48196 .1555 L
.48456 .15524 L
.487 .15503 L
.48938 .15485 L
.49157 .15473 L
.49365 .15463 L
.49472 .15459 L
.49585 .15456 L
.497 .15454 L
.49806 .15452 L
.49933 .15451 L
.50049 .15451 L
.50167 .15452 L
.50277 .15453 L
.50399 .15456 L
.5053 .15459 L
.50659 .15464 L
.50796 .1547 L
.5104 .15484 L
.51478 .15518 L
.51957 .15568 L
.52477 .15638 L
.53033 .1573 L
.54033 .15942 L
.56168 .16576 L
.58183 .17383 L
.6203 .19387 L
.66122 .22023 L
.70062 .24902 L
.73851 .27888 L
.77885 .31233 L
.81767 .34567 L
.85895 .38204 L
Mistroke
.89871 .41773 L
.93695 .45253 L
.97619 .4886 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[111]:=",
  ImageSize->{255, 157.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003o0000WB000`400?l00000o`00003oooooool0
01Cooooo0ol0000Pooooo`Go00008?ooool3o`0004;ooooo0ol0000Pooooo`Go00008?ooool3o`00
01?ooooo000Cooooo`05o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool0000Q
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool0
000Oooooo`05o`000?ooooooooooooooool000004_ooool000gooooo1Ol00005ooooo`03o`000?oo
oooooooo01Oooooo1Ol00003ooooo`03o`000?oooooooooo01Wooooo1Ol00003ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo013ooooo000Eooooo`;o00008oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`;o00004oooool0
01Oooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo0000027ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool000008ooo
ool00ol0003oooooooooo`0@ooooo`004oooool01Ol0003ooooooooooooooooo000001oooooo00Go
0000ooooooooooooooooo`00000Pooooo`;o0000@oooool2o`00027ooooo00Go0000oooooooooooo
ooooo`00000Oooooo`05o`000?ooooooooooooooool000004_ooool001Cooooo0ol0000Qooooo`?o
00008_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo023ooooo0ol0000Qooooo`?o
00004oooool00?oooooo003oooooo`00ooooool00?oooooo000=ooooonCo00003_ooool001?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04Oooool007oooooo00?o0000ooooooooool0OOooool007oooooo0_l0001n
ooooo`00Ooooool00ol0003oooooooooo`1mooooo`00Ooooool00ol0003oooooooooo`1mooooo`00
Ooooool00ol0003oooooooooo`1mooooo`00Ooooool2o`0007kooooo001oooooo`03o`000?oooooo
oooo07gooooo001oooooo`03o`000?oooooooooo07gooooo001oooooo`;o0000O_ooool007oooooo
00?o0000ooooooooool0OOooool007oooooo00?o0000ooooooooool0OOooool007oooooo00?o0000
ooooooooool0OOooool007oooooo0_l0001nooooo`00K?ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0OOooool006_ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0OOooool006_o
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o0000O_ooool006_o
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
07gooooo001[ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo
07gooooo001[ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1mooooo`00K?ooool2o`0000Sooooo1Ol00004ooooo`;o0000O_ooool007oooooo
00?o0000ooooooooool0OOooool007oooooo00?o0000ooooooooool0OOooool007oooooo0_l0001n
ooooo`00Ooooool00ol0003oooooooooo`1mooooo`00Ooooool00ol0003oooooooooo`1mooooo`00
Ooooool00ol0003oooooooooo`1mooooo`00Ooooool2o`0007kooooo001oooooo`03o`000?oooooo
oooo07gooooo001oooooo`03o`000?oooooooooo07gooooo001oooooo`;o0000O_ooool007Oooooo
0ol00005ooooo`03o`000?oooooooooo07gooooo001hooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0OOooool007Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1m
ooooo`00N?ooool>o`0007Wooooo001dooooo`Go00001_ooool00ol0003oooooooooo`04ooooo`Ko
0000Loooool0077ooooo0ol00003ooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`?o0000
L?ooool006kooooo0ol00007ooooo`03o`000?oooooooooo00Cooooo0_l0000>ooooo`;o0000K_oo
ool006cooooo0_l0000Aooooo`03o`000?oooooooooo00oooooo0_l0001/ooooo`00JOooool3o`00
01?ooooo00?o0000ooooooooool04Oooool2o`0006[ooooo001Wooooo`;o00005_ooool00ol0003o
ooooooooo`0Cooooo`;o0000J?ooool006Kooooo00?o0000ooooooooool05_ooool2o`0001Kooooo
00?o0000ooooooooool0IOooool006Gooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Fooooo`;o0000IOooool006?ooooo0_l0000Jooooo`03o`000?oooooooooo01Sooooo0_l0001S
ooooo`00HOooool2o`0001cooooo0_l0000Kooooo`03o`000?oooooooooo063ooooo001Oooooo`;o
00007_ooool00ol0003oooooooooo`0Kooooo`;o0000H?ooool005kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05gooooo001Looooo`;o00008Ooo
ool00ol0003oooooooooo`0Nooooo`;o0000GOooool005[ooooo0_l0000Sooooo`;o00008Oooool0
0ol0003oooooooooo`1Jooooo`00FOooool00ol0003oooooooooo`0?ooooo`?o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0Qooooo`;o0000F_ooool005So
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05Oooooo001Fooooo`;o
00005?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l0000Uooooo`;o
0000Eoooool005Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Dooooo`00E?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03o`000?oo
oooooooo02Oooooo0_l0001Dooooo`00Doooool00ol0003oooooooooo`0Eooooo`;o00002Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0DOooool0
057ooooo0_l0000Iooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`;o0000:oooool2o`00
057ooooo001@ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`1>ooooo`00Coooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0COooool004gooooo0_l0000`ooooo`;o0000;oooool2o`0004gooooo001<
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1:
ooooo`00Boooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0BOooool004[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo04Sooooo0018ooooo`;o0000=Oooool2o`0003Cooooo0_l00018ooooo`00Aooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0AOoo
ool004Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo04Cooooo0014ooooo`;o0000>Oooool2o`0003Sooooo00?o0000ooooooooool0@oooool004?o
oooo00?o0000ooooooooool0<?ooool5o`0000Cooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`12ooooo`00@_ooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`11ooooo`00@Oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`10ooooo`00?oooool2o`0003Sooooo00?o0000ooooooooool00oooool2o`0003cooooo00?o
0000ooooooooool0?oooool003kooooo00?o0000ooooooooool0=Oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0??ooool2o`0003oooooo000mooooo`03o`000?oooooo
oooo03Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0??ooool003cooooo00?o0000ooooooooool0>?ooool3o`0000Gooooo0_l00010
ooooo`03o`000?oooooooooo03_ooooo000kooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool0@?ooool2o`0003_ooooo000jooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0hooooo`00>Oooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0=oooool003Sooooo00?o0000ooooooooool0A?oo
ool2o`0004Gooooo00?o0000ooooooooool0=_ooool003Kooooo0_l00017ooooo`03o`000?oooooo
oooo04Gooooo0_l0000fooooo`00=Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0<oooool003Cooooo00?o0000ooooooooool0B?ooool2o`0004Wo
oooo00?o0000ooooooooool0<_ooool003?ooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo037ooooo000booooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0;oooool0033ooooo00?o0000oooo
ooooool0C?ooool2o`0004gooooo00?o0000ooooooooool0;_ooool002oooooo00?o0000oooooooo
ool0>?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`0]ooooo`00;Oooool2o`0003cooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`0/ooooo`00;?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00_ooool2o`00053ooooo00?o0000ooooooooool0:oooool002_ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Zooooo`00:_ooool00ol0003ooooooooo
o`0mooooo`05o`000?ooooooooooooooool000001oooool4o`0000Gooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`0Yooooo`00:Oooool00ol0003oooooooooo`0nooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool0:?ooool002Sooooo00?o0000ooooooooool0@?ooool3o`0000Sooooo1Ol0
0004ooooo`;o0000E?ooool00ol0003oooooooooo`0Wooooo`009oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool09_ooool002Kooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Gooooo000Uooooo`03
o`000?oooooooooo05Oooooo0_l0001Gooooo`03o`000?oooooooooo02Cooooo000Tooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool0Eoooool2o`0002Cooooo000Sooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool08?ooool0
027ooooo00?o0000ooooooooool0Foooool2o`0005cooooo0_l0000Pooooo`008?ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool07Oooool001oooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01cooooo
000Nooooo`03o`000?oooooooooo05kooooo0_l0001Pooooo`03o`000?oooooooooo01_ooooo000M
ooooo`03o`000?oooooooooo05Oooooo0ol00005ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool06_ooool001_ooooo0_l0001Iooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
01Sooooo000Iooooo`03o`000?oooooooooo05cooooo0_l00005ooooo`;o0000I?ooool00ol0003o
ooooooooo`0Gooooo`006?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Fooooo`005oooool00ol0003ooooooooo
o`1Looooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo01Gooooo000Fooooo`03o`000?oooooooooo05kooooo0ol00005ooooo`;o0000Iooo
ool00ol0003oooooooooo`0Dooooo`005Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool04oooool001Cooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Aooooo`00Ooooool2o`0007kooooo
001oooooo`03o`000?oooooooooo07gooooo001oooooo`03o`000?oooooooooo07gooooo001ooooo
o`;o0000O_ooool007oooooo00?o0000ooooooooool0OOooool007oooooo00?o0000ooooooooool0
OOooool007oooooo00?o0000ooooooooool0OOooool007oooooo0_l0001nooooo`00Joooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0OOooool006[o
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1mooooo`00K_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00;ooooo0_l0001nooooo`00K?ooool2o`0000cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1mooooo`00K_ooool00ol0003oooooooooo`05ooooo`Co00001Oooool00ol0003ooooo
ooooo`1mooooo`00J_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1mooooo`00Joooool3o`0000Sooooo1Ol00004ooooo`;o0000O_oo
ool007oooooo00?o0000ooooooooool0OOooool007oooooo00?o0000ooooooooool0OOooool007oo
oooo0_l0001nooooo`00Ooooool00ol0003oooooooooo`1mooooo`00Ooooool00ol0003ooooooooo
o`1mooooo`00Ooooool00ol0003oooooooooo`1mooooo`00Ooooool2o`0007kooooo001oooooo`03
o`000?oooooooooo07gooooo001oooooo`03o`000?oooooooooo07gooooo001oooooo`;o0000O_oo
ool007Sooooo0ol00004ooooo`03o`000?oooooooooo07gooooo001iooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0OOooool007Kooooo1Ol00004ooooo`03o`000?oooooooooo07go
oooo001fooooo`04o`000?ooooooooooo`0000Gooooo0_l0001nooooo`00Moooool00ol0003ooooo
o`000025ooooo`00N?ooool2o`0008Gooooo001iooooo`03o`000?oooooooooo08?ooooo003ooooo
o`00\
\>"],
  ImageRangeCache->{{{77.875, 331.875}, {661, 504.5}} -> {-5.69954, 14.0596, \
0.0277789, 0.028538}}]
}, Open  ]],

Cell["\<\
This solution curve appears to be branch of a hyperbola. Several \
branches can be plotted by making a list of the initial conditions and then \
using the Table function to make solution formulas. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
inits = {y[0]==1, y[0]==-1, y[1]==0.1, y[1]==-0.1,y[-1]==0.1, \
y[-1]==-0.1};
solns = Evaluate[Table[ DSolve[ {DE3, inits[[k]]}, y, t], {k,6}]];
Plot[ Evaluate[Table[ y[t]/.solns[[k]], {k,6}]], {t,-3,3},
      PlotRange->{-3,3}, AspectRatio->1, PlotLabel->\"Six Solution Curves\" ]\
\
\>", "Input",
  CellLabel->"In[131]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.5 0.166667 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.18254 .4875 -6 -9 ]
[.18254 .4875 6 0 ]
[.34127 .4875 -6 -9 ]
[.34127 .4875 6 0 ]
[.65873 .4875 -3 -9 ]
[.65873 .4875 3 0 ]
[.81746 .4875 -3 -9 ]
[.81746 .4875 3 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.0125 -59 0 ]
[.5 1.0125 59 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-3)] .02381 .4875 0 1 Mshowa
.18254 .5 m
.18254 .50625 L
s
[(-2)] .18254 .4875 0 1 Mshowa
.34127 .5 m
.34127 .50625 L
s
[(-1)] .34127 .4875 0 1 Mshowa
.65873 .5 m
.65873 .50625 L
s
[(1)] .65873 .4875 0 1 Mshowa
.81746 .5 m
.81746 .50625 L
s
[(2)] .81746 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(3)] .97619 .4875 0 1 Mshowa
.125 Mabswid
.05556 .5 m
.05556 .50375 L
s
.0873 .5 m
.0873 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.15079 .5 m
.15079 .50375 L
s
.21429 .5 m
.21429 .50375 L
s
.24603 .5 m
.24603 .50375 L
s
.27778 .5 m
.27778 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.37302 .5 m
.37302 .50375 L
s
.40476 .5 m
.40476 .50375 L
s
.43651 .5 m
.43651 .50375 L
s
.46825 .5 m
.46825 .50375 L
s
.53175 .5 m
.53175 .50375 L
s
.56349 .5 m
.56349 .50375 L
s
.59524 .5 m
.59524 .50375 L
s
.62698 .5 m
.62698 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.72222 .5 m
.72222 .50375 L
s
.75397 .5 m
.75397 .50375 L
s
.78571 .5 m
.78571 .50375 L
s
.84921 .5 m
.84921 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.9127 .5 m
.9127 .50375 L
s
.94444 .5 m
.94444 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-2)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-1)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(1)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(2)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(3)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.0125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Six) show
87.000 13.000 moveto
(Solution) show
141.000 13.000 moveto
(Curves) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.05108 1 m
.06244 .98873 L
.10458 .94739 L
.14415 .90913 L
.18221 .87299 L
.22272 .83548 L
.26171 .80063 L
.30316 .76551 L
.34309 .73436 L
.3815 .70799 L
.40095 .69646 L
.42237 .68553 L
.44268 .6772 L
.46172 .67145 L
.46668 .6703 L
.4721 .66922 L
.47687 .66843 L
.48196 .66774 L
.48456 .66745 L
.487 .66722 L
.48938 .66704 L
.49157 .6669 L
.49365 .6668 L
.49472 .66676 L
.49585 .66672 L
.497 .6667 L
.49806 .66668 L
.49933 .66667 L
.50049 .66667 L
.50167 .66668 L
.50277 .66669 L
.50399 .66672 L
.5053 .66676 L
.50659 .66681 L
.50796 .66688 L
.5104 .66702 L
.51478 .66739 L
.51957 .66793 L
.52477 .66868 L
.53033 .66968 L
.54033 .67196 L
.56168 .67881 L
.58183 .68751 L
.6203 .70912 L
.66122 .73756 L
.70062 .76861 L
.73851 .80082 L
.77885 .8369 L
.81767 .87288 L
.85895 .9121 L
Mistroke
.89871 .9506 L
.93695 .98814 L
Mfstroke
.93695 .98814 m
.94892 1 L
s
.05108 0 m
.06244 .01127 L
.10458 .05261 L
.14415 .09087 L
.18221 .12701 L
.22272 .16452 L
.26171 .19937 L
.30316 .23449 L
.34309 .26564 L
.3815 .29201 L
.40095 .30354 L
.42237 .31447 L
.44268 .3228 L
.46172 .32855 L
.46668 .3297 L
.4721 .33078 L
.47687 .33157 L
.48196 .33226 L
.48456 .33255 L
.487 .33278 L
.48938 .33296 L
.49157 .3331 L
.49365 .3332 L
.49472 .33324 L
.49585 .33328 L
.497 .3333 L
.49806 .33332 L
.49933 .33333 L
.50049 .33333 L
.50167 .33332 L
.50277 .33331 L
.50399 .33328 L
.5053 .33324 L
.50659 .33319 L
.50796 .33312 L
.5104 .33298 L
.51478 .33261 L
.51957 .33207 L
.52477 .33132 L
.53033 .33032 L
.54033 .32804 L
.56168 .32119 L
.58183 .31249 L
.6203 .29088 L
.66122 .26244 L
.70062 .23139 L
.73851 .19918 L
.77885 .1631 L
.81767 .12712 L
.85895 .0879 L
Mistroke
.89871 .0494 L
.93695 .01186 L
Mfstroke
.93695 .01186 m
.94892 0 L
s
.02381 .9717 m
.06244 .92846 L
.10458 .88064 L
.14415 .83482 L
.18221 .78956 L
.22272 .7393 L
.26171 .68736 L
.30316 .62337 L
.3223 .58552 L
.32744 .57299 L
.33311 .55664 L
.33544 .54853 L
.33795 .5381 L
.33931 .53111 L
.3406 .52263 L
.3419 .50763 L
s
.65848 .51382 m
.65907 .51992 L
.66028 .5287 L
.66156 .53572 L
.66384 .54577 L
.66898 .5631 L
.67828 .58685 L
.69949 .62797 L
.7376 .68639 L
.77816 .74043 L
.81721 .78885 L
.85871 .83817 L
.89869 .88438 L
.93715 .92801 L
.97619 .9717 L
s
.02381 .0283 m
.06244 .07154 L
.10458 .11936 L
.14415 .16518 L
.18221 .21044 L
.22272 .2607 L
.26171 .31264 L
.30316 .37663 L
.3223 .41448 L
.32744 .42701 L
.33311 .44336 L
.33544 .45147 L
.33795 .4619 L
.33931 .46889 L
.3406 .47737 L
.3419 .49237 L
s
.65848 .48618 m
.65907 .48008 L
.66028 .4713 L
.66156 .46428 L
.66384 .45423 L
.66898 .4369 L
.67828 .41315 L
.69949 .37203 L
.7376 .31361 L
.77816 .25957 L
.81721 .21115 L
.85871 .16183 L
.89869 .11562 L
.93715 .07199 L
.97619 .0283 L
s
.02381 .9717 m
.06244 .92846 L
.10458 .88064 L
.14415 .83482 L
.18221 .78956 L
.22272 .7393 L
.26171 .68736 L
.30316 .62337 L
.3223 .58552 L
.32744 .57299 L
.33311 .55664 L
.33544 .54853 L
.33795 .5381 L
.33931 .53111 L
.3406 .52263 L
.3419 .50763 L
s
.65848 .51382 m
.65907 .51992 L
.66028 .5287 L
.66156 .53572 L
.66384 .54577 L
.66898 .5631 L
.67828 .58685 L
.69949 .62797 L
.7376 .68639 L
.77816 .74043 L
.81721 .78885 L
.85871 .83817 L
.89869 .88438 L
.93715 .92801 L
.97619 .9717 L
s
.02381 .0283 m
.06244 .07154 L
.10458 .11936 L
.14415 .16518 L
.18221 .21044 L
.22272 .2607 L
.26171 .31264 L
.30316 .37663 L
.3223 .41448 L
.32744 .42701 L
.33311 .44336 L
.33544 .45147 L
.33795 .4619 L
.33931 .46889 L
.3406 .47737 L
.3419 .49237 L
s
.65848 .48618 m
.65907 .48008 L
.66028 .4713 L
.66156 .46428 L
.66384 .45423 L
.66898 .4369 L
.67828 .41315 L
.69949 .37203 L
.7376 .31361 L
.77816 .25957 L
.81721 .21115 L
.85871 .16183 L
.89869 .11562 L
.93715 .07199 L
.97619 .0283 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[131]:=",
  ImageSize->{197, 197},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000350000aB000`400?l00000o`00003oaOooool0
0<Gooooo001Kooooo`?o0000Ioooool005[ooooo00Go0000ooooooooooooooooo`00001Vooooo`00
E?ooool5o`0000Gooooo00?o0000ooooooooool0I?ooool001?ooooo00?o0000ooooooooool0A_oo
ool2o`0000Cooooo0_l0001>ooooo`03o`000?oooooooooo013ooooo000Dooooo`03o`000?oooooo
oooo04Oooooo00Go0000ooooooooooooooooo`00001>ooooo`03o`000?oooooooooo017ooooo000E
ooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool0@_ooool3
o`0000Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`005oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool000ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`003_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo04Kooooo0_l00018ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02oooool000oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0<ooooo`004?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Aoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool001;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0?ooooo`004oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo013ooooo000Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@?oo
ool2o`0004;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`005Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo000Eooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04oooool001Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Dooooo`005oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo
000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool001Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0jooooo`;o0000??ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Oooooo000Jooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06?ooool001_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`00
7?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo000Looooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06_ooool001gooooo00?o0000ooooooooool02_ooool2
o`0003Kooooo00?o0000ooooooooool0=Oooool2o`0000_ooooo00?o0000ooooooooool06oooool0
01kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`;o0000=Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo000Oooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07Oooool0023ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Mooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo1Ol0
0003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Nooooo`008_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool07oooool002?ooooo00?o0000ooooooooool02oooool2o`00027ooooo1Ol00003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool2o`0000gooooo00?o0000
ooooooooool08?ooool002?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo0_l0000^ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08?ooool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Sooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool08Oooool002Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Rooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool08_ooool002Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Rooooo`?o00001?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool002Oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02Oooooo0_l0000Xooooo`;o00003oooool00ol0003oooooooooo`0Uooooo`00:Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo000Zooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool09oooool002[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Wooooo`00:oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo
000/ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool002gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`;o00008Oooool2o`00017ooooo00?o0000
ooooooooool0:_ooool002kooooo00?o0000ooooooooool03_ooool2o`00027ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo000^ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0:oooool002oooooo00?o0000ooooooooool0
4?ooool2o`0001kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo02cooooo000`ooooo`03o`000?oooooooooo017ooooo0_l0000Looooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0]ooooo`00<Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02kooooo000aooooo`03o`000?oooooooooo
01?ooooo0_l0000Iooooo`;o00006_ooool2o`0001Cooooo00?o0000ooooooooool0;_ooool003;o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`00<oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool2o`0001Gooooo
00?o0000ooooooooool0<?ooool003Cooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0`ooooo`00=Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo037ooooo000eoooo
o`03o`000?oooooooooo01Gooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo0_l0000Goooo
o`03o`000?oooooooooo03;ooooo000fooooo`03o`000?oooooooooo01Kooooo0_l0000Aooooo`;o
00004?ooool3o`0001Sooooo00?o0000ooooooooool0<oooool003Oooooo00?o0000ooooooooool0
5oooool2o`0000oooooo00?o0000ooooooooool03Oooool2o`0001_ooooo00?o0000ooooooooool0
<oooool003Sooooo00?o0000ooooooooool06?ooool2o`0000gooooo00?o0000ooooooooool02ooo
ool2o`0001cooooo00?o0000ooooooooool0=?ooool003Sooooo00?o0000ooooooooool06_ooool3
o`0000[ooooo00?o0000ooooooooool02Oooool2o`0001gooooo00?o0000ooooooooool0=Oooool0
03Wooooo00?o0000ooooooooool07?ooool6o`0000Cooooo00?o0000ooooooooool01oooool2o`00
01oooooo00?o0000ooooooooool0=Oooool003Wooooo00?o0000ooooooooool07oooool2o`0000Go
oooo00?o0000ooooooooool01?ooool3o`00023ooooo00?o0000ooooooooool0=_ooool003[ooooo
00?o0000ooooooooool05oooool5o`0000?ooooo3Ol0000Rooooo`03o`000?oooooooooo03Oooooo
000kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo03Oooooo000kooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo000loooo
o`03o`000?oooooooooo01cooooo0_l00005ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0>Oooool003cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool003gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo000nooooo`03o`000?oo
oooooooo027ooooo0_l0000Sooooo`03o`000?oooooooooo03_ooooo000nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00?oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool003oo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03go
oooo0010ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0mooooo`00@Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0?_ooool0047ooooo00?o0000ooooooooool07_ooool2o`0001oooooo00?o0000
ooooooooool0?oooool004;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo03oooooo0013ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`10ooooo`00@oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0@?ooool004Cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo0014ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`00A?ooool00ol0
003oooooooooo`0Kooooo`;o00007?ooool00ol0003oooooooooo`12ooooo`003oooool3o`0001So
oooo1Ol0000Fooooo`03o`000?oooooo000000;o00006?ooool00ol0003oooooooooo`0Hooooo`Co
00005oooool5o`0001Sooooo0ol0000=ooooo`003_ooool01Ol0003ooooooooooooooooo000001So
oooo00Co0000oooooooooooo00005_ooool01?l0003oooooooooool0000Iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooool000006?ooool01?l0003oooooooooool0000Gooooo`05o`000?oo
ooooooooooooool000003?ooool000Sooooo1Ol00005ooooo`03o`000?oooooooooo00oooooo1Ol0
0003ooooo`03o`000?oooooooooo017ooooo1_l00002ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06Oooool2o`0001[ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0:ooooo`004?ooool2o`0001_ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0
000Iooooo`03o`000?oooooooooo01Wooooo0_l0000Kooooo`03o`000?oooooooooo01Sooooo0_l0
000=ooooo`004_ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000005ooo
ool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo01Wooooo0_l0000Hooooo`05o`000?oo
ooooooooooooool000006oooool00ol0003oooooooooo`0:ooooo`003_ooool01Ol0003ooooooooo
oooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Gooooo`?o00006Oooool2o`0001Wo
oooo0ol0000Hooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo
000000cooooo000?ooooo`?o00006Oooool3o`0001Sooooo00?o0000ooooool000006Oooool00ol0
003oooooooooo`0Iooooo`;o00006Oooool3o`0001Wooooo0ol0000=ooooo`00A_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool004Kooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo
0016ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0H?ooool006;ooooo00?o0000
ooooooooool0H?ooool000[ooooo/_l00009ooooo`003_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`00
A_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
A?ooool004Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo04?ooooo0016ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`13ooooo`00A_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@oooool004Kooooo00?o0000ooooooooool06Oooool2o`0001_o
oooo00?o0000ooooooooool0@oooool004Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo04?ooooo0015ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`00AOooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool004Gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo0015ooooo`03
o`000?oooooooooo01[ooooo0_l0000Looooo`03o`000?oooooooooo04;ooooo0014ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`00A?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Ooo
ool004Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo047ooooo0013ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`10ooooo`00@oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0@?ooool004;ooooo00?o0000ooooooooool07Oooool2o`0001oooooo
00?o0000ooooooooool0?oooool004;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo03oooooo0011ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0nooooo`00@?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool0043ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo000oooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00?ooo
ool00ol0003oooooooooo`0Pooooo`;o00008_ooool00ol0003oooooooooo`0looooo`00?_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>oooool0
03gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
03[ooooo000mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0jooooo`00??ooool00ol0003oooooooooo`0Looooo`?o00001?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo03Wooooo000kooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo000k
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooool000002?l0000Sooooo`03o`000?oooooo
oooo03Sooooo000jooooo`03o`000?oooooooooo01gooooo1?l00004ooooo`03o`000?oooooooooo
00;ooooo1_l0000Nooooo`03o`000?oooooooooo03Oooooo000jooooo`03o`000?oooooooooo01[o
oooo0ol00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool2o`0001co
oooo00?o0000ooooooooool0=oooool003Wooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`;o00006oooool00ol0003ooooo
ooooo`0fooooo`00>?ooool00ol0003oooooooooo`0Hooooo`?o00001_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00cooooo0_l0000Jooooo`03o`000?oooooooooo03Gooooo000h
ooooo`03o`000?oooooooooo01Gooooo0ol0000?ooooo`03o`000?oooooooooo00kooooo0_l0000H
ooooo`03o`000?oooooooooo03Gooooo000gooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool04?ooool2o`00017ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0doooo
o`00=_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool2o`0001Oooooo00?o0000ooooooooool0<oooool003Gooooo00?o0000ooooooooool0
5?ooool2o`0001Cooooo00?o0000ooooooooool04oooool2o`0001Kooooo00?o0000ooooooooool0
<_ooool003Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0aooooo`00=?ooool0
0ol0003oooooooooo`0Booooo`;o00005oooool00ol0003oooooooooo`0Fooooo`;o00005?ooool0
0ol0003oooooooooo`0aooooo`00<oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
033ooooo000booooo`03o`000?oooooooooo017ooooo0_l0000Jooooo`;o00006_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02oooooo000aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`;o00004oooool00ol0003ooooo
ooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02kooooo000`
ooooo`03o`000?oooooooooo00oooooo0_l0000Nooooo`03o`000?oooooooooo01gooooo0_l0000A
ooooo`03o`000?oooooooooo02gooooo000_ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0;?ooool002kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0[ooooo`00
;Oooool00ol0003oooooooooo`0>ooooo`;o00008_ooool2o`0002;ooooo0_l0000@ooooo`03o`00
0?oooooooooo02[ooooo000]ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:_oo
ool002cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Yooooo`00:oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02Sooooo000Zooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool09oooool002[ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Wooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o0000:Oooool2o`0002Wooooo0_l0
000=ooooo`03o`000?oooooooooo02Kooooo000Xooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09Oooool002Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Toooo
o`009_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo1Ol00003ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Sooooo`00
9Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02;ooooo000Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`02ooooo`;o0000<?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo027ooooo000Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo023ooooo000Rooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0:?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo000Qooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0:_ooool3o`0000Cooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo000Pooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool07_ooool001oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Mooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Cooooo
0_l0000fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool001gooooo00?o
0000ooooooooool02Oooool2o`0003Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool06_ooool001cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Ioooo
o`006oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06?ooool001Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0kooooo`;o0000??ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Oooooo000Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool0
01Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`005oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Cooooo000Fooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04oooool001Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`10ooooo`;o0000@Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo000D
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool001?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0@ooooo`004_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00oooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`14ooooo`;o00002Oooool00ol0003oooooooooo`0>ooooo`004?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000?ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0A_ooool2o`0004Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00_ooooo000Gooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`0Dooooo`005_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool04oooool001Gooooo00?o0000ooooooooool0@oooool3o`0000Cooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`005?ooool00ol0003oooooooooo`13
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo017ooooo000Cooooo`03o`000?oooooooooo04Sooooo00Co0000oooooooooooooooo0_l0
001>ooooo`03o`000?oooooooooo013ooooo001Looooo`;o0000Ioooool005kooooo00?o0000oooo
ooooool0I?ooool005[ooooo00Go0000ooooooooooooooooo`00001Vooooo`00Foooool3o`0006Oo
oooo0035ooooo`00:_ooool3o`0000;ooooo1Ol000001?oooooo0000o`000?ooool2o`0000Sooooo
0ol00003ooooo`?o00000_ooool5o`0000?ooooo0_l000001?oooooo0000ooooooooool2o`0000;o
oooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l00005ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Co
0000;?ooool002[ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000Wooooo00Ko0000oooooooooooo0000ooooool00003ooooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooooooo
ool0:Oooool002gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00000_ooool5o`0000;ooooo0ol0000/ooooo`00:oooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`00000:ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo
0_l00004ooooo`03o`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
02oooooo000Zooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`;o000000?oooooo`000?l0
00002?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool01?l0003oooooooooooooool2o`00
0004ooooool0003o0000ooooo`Co00000_ooool3o`0000Cooooo0ol00002ooooo`Co00002?ooool0
0ol0003oooooooooo`03ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000;ooooo0ol00003ooooo`Co0000:oooool002[ooooo00Co
0000oooooooooooo00005?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06oooool01?l0003oooooooooool00019ooooo`00:oooool3o`0000?o
oooo00?o0000ooooooooool03oooool3o`0000Oooooo0ol0000:ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool05Oooool3o`0004Wooooo0035ooooo`00aOooool00001\
\>"],
  ImageRangeCache->{{{77.875, 273.875}, {318.875, 122.875}} -> {-6.28161, \
1.00629, 0.0355366, 0.0338443}}]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{664, 757},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->35,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "   Page  ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "   Page  ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 807, 19, 158, "Text"],
Cell[2564, 72, 159, 3, 23, "Text"],
Cell[2726, 77, 159, 3, 23, "Text"],
Cell[2888, 82, 126, 2, 23, "Text"],
Cell[3017, 86, 118, 2, 28, "Text"],
Cell[3138, 90, 614, 17, 88, "Text"],

Cell[CellGroupData[{
Cell[3777, 111, 69, 1, 31, "Input"],
Cell[3849, 114, 214, 6, 46, "Output"]
}, Open  ]],
Cell[4078, 123, 59, 0, 28, "Text"],
Cell[4140, 125, 227, 7, 60, "Text"],
Cell[4370, 134, 115, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[4510, 141, 96, 2, 31, "Input"],
Cell[4609, 145, 108, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4754, 152, 93, 2, 31, "Input"],
Cell[4850, 156, 131, 3, 32, "Output"]
}, Open  ]],
Cell[4996, 162, 617, 10, 120, "Text"],
Cell[5616, 174, 102, 2, 28, "Text"],
Cell[5721, 178, 88, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[5834, 185, 51, 1, 31, "Input"],
Cell[5888, 188, 65, 2, 18, "Output"]
}, Open  ]],
Cell[5968, 193, 164, 5, 22, "Text"],

Cell[CellGroupData[{
Cell[6157, 202, 76, 2, 31, "Input"],
Cell[6236, 206, 289, 8, 49, "Output"]
}, Open  ]],
Cell[6540, 217, 105, 2, 28, "Text"],
Cell[6648, 221, 240, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[6913, 230, 63, 1, 31, "Input"],
Cell[6979, 233, 113, 2, 32, "Output"]
}, Open  ]],
Cell[7107, 238, 266, 5, 68, "Text"],

Cell[CellGroupData[{
Cell[7398, 247, 118, 4, 51, "Input"],
Cell[7519, 253, 31151, 1470, 142, 20194, 1330, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[38685, 1726, 113, 2, 28, "Text"],
Cell[38801, 1730, 105, 3, 28, "Text"],
Cell[38909, 1735, 132, 6, 28, "Text"],
Cell[39044, 1743, 185, 4, 48, "Text"],
Cell[39232, 1749, 138, 3, 28, "Text"],
Cell[39373, 1754, 124, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[39522, 1761, 77, 1, 31, "Input"],
Cell[39602, 1764, 167, 5, 38, "Output"]
}, Open  ]],
Cell[39784, 1772, 70, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[39879, 1776, 58, 1, 31, "Input"],
Cell[39940, 1779, 62, 2, 27, "Output"]
}, Open  ]],
Cell[40017, 1784, 143, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[40185, 1791, 211, 6, 91, "Input"],
Cell[40399, 1799, 30139, 1483, 119, 20656, 1361, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[70553, 3285, 158, 3, 28, "Text"],
Cell[70714, 3290, 388, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[71127, 3302, 73, 4, 51, "Input"],
Cell[71203, 3308, 112, 2, 33, "Output"]
}, Open  ]],
Cell[71330, 3313, 185, 8, 28, "Text"],

Cell[CellGroupData[{
Cell[71540, 3325, 76, 1, 31, "Input"],
Cell[71619, 3328, 95, 2, 27, "Output"]
}, Open  ]],
Cell[71729, 3333, 45, 0, 28, "Text"],
Cell[71777, 3335, 300, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[72102, 3342, 55, 1, 31, "Input"],
Cell[72160, 3345, 62, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72259, 3352, 74, 2, 31, "Input"],
Cell[72336, 3356, 62, 2, 27, "Output"]
}, Open  ]],
Cell[72413, 3361, 136, 3, 28, "Text"],
Cell[72552, 3366, 180, 6, 28, "Text"],

Cell[CellGroupData[{
Cell[72757, 3376, 82, 1, 31, "Input"],
Cell[72842, 3379, 342, 6, 42, "Message"],
Cell[73187, 3387, 60, 2, 27, "Output"]
}, Open  ]],
Cell[73262, 3392, 116, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[73403, 3399, 70, 1, 31, "Input"],
Cell[73476, 3402, 130, 3, 32, "Output"]
}, Open  ]],
Cell[73621, 3408, 74, 0, 28, "Text"],
Cell[73698, 3410, 72, 1, 31, "Input"],
Cell[73773, 3413, 65, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[73863, 3417, 59, 4, 51, "Input"],
Cell[73925, 3423, 88, 2, 30, "Output"],
Cell[74016, 3427, 90, 2, 30, "Output"]
}, Open  ]],
Cell[74121, 3432, 128, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[74274, 3439, 59, 1, 31, "Input"],
Cell[74336, 3442, 101, 2, 30, "Output"]
}, Open  ]],
Cell[74452, 3447, 181, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[74658, 3455, 57, 1, 31, "Input"],
Cell[74718, 3458, 109, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74864, 3465, 81, 2, 29, "Input"],
Cell[74948, 3469, 106, 2, 30, "Output"]
}, Open  ]],
Cell[75069, 3474, 88, 3, 28, "Text"],
Cell[75160, 3479, 72, 1, 31, "Input"],
Cell[75235, 3482, 60, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[75320, 3486, 77, 2, 29, "Input"],
Cell[75400, 3490, 104, 2, 30, "Output"]
}, Open  ]],
Cell[75519, 3495, 93, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[75637, 3502, 80, 2, 29, "Input"],
Cell[75720, 3506, 61, 2, 27, "Output"]
}, Open  ]],
Cell[75796, 3511, 125, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[75946, 3518, 477, 11, 209, "Input"],
Cell[76426, 3531, 35875, 1765, 172, 17999, 1539, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[112316, 5299, 68, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[112409, 5303, 309, 7, 151, "Input"],
Cell[112721, 5312, 32541, 1749, 179, 18543, 1571, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[145277, 7064, 101, 2, 28, "Text"],
Cell[145381, 7068, 129, 3, 28, "Text"],
Cell[145513, 7073, 278, 15, 28, "Text"],
Cell[145794, 7090, 459, 16, 48, "Text"],
Cell[146256, 7108, 650, 24, 80, "Text"],

Cell[CellGroupData[{
Cell[146931, 7136, 96, 2, 29, "Input"],
Cell[147030, 7140, 220, 6, 46, "Output"]
}, Open  ]],
Cell[147265, 7149, 120, 3, 28, "Text"],
Cell[147388, 7154, 297, 15, 30, "Text"],
Cell[147688, 7171, 430, 15, 62, "Text"],

Cell[CellGroupData[{
Cell[148143, 7190, 96, 2, 29, "Input"],
Cell[148242, 7194, 140, 4, 54, "Output"]
}, Open  ]],
Cell[148397, 7201, 624, 17, 120, "Text"],

Cell[CellGroupData[{
Cell[149046, 7222, 135, 4, 71, "Input"],
Cell[149184, 7228, 33593, 1582, 147, 21859, 1432, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[182792, 8813, 142, 3, 48, "Text"],
Cell[182937, 8818, 245, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[183207, 8828, 129, 4, 51, "Input"],
Cell[183339, 8834, 35360, 1593, 143, 21309, 1414, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[218714, 10430, 788, 18, 164, "Text"],

Cell[CellGroupData[{
Cell[219527, 10452, 105, 2, 29, "Input"],
Cell[219635, 10456, 158, 4, 54, "Output"]
}, Open  ]],
Cell[219808, 10463, 166, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[219999, 10472, 115, 2, 29, "Input"],
Cell[220117, 10476, 11520, 355, 125, 3380, 249, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[231652, 10834, 185, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[231862, 10843, 156, 5, 71, "Input"],
Cell[232021, 10850, 187, 3, 27, "Output"],
Cell[232211, 10855, 32883, 1471, 128, 20105, 1308, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[265109, 12329, 125, 2, 28, "Text"],
Cell[265237, 12333, 132, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[265394, 12340, 128, 5, 47, "Input"],
Cell[265525, 12347, 205, 6, 48, "Output"],
Cell[265733, 12355, 174, 3, 41, "Output"]
}, Open  ]],
Cell[265922, 12361, 100, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[266047, 12368, 162, 5, 47, "Input"],
Cell[266212, 12375, 367, 6, 42, "Message"],
Cell[266582, 12383, 103, 2, 41, "Output"],
Cell[266688, 12387, 17302, 518, 166, 4709, 357, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[284005, 12908, 221, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[284251, 12916, 359, 9, 155, "Input"],
Cell[284613, 12927, 33642, 883, 205, 8344, 566, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

