(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    153407,       4915]*)
(*NotebookOutlinePosition[    155582,       4980]*)
(*  CellTagsIndexPosition[    155538,       4976]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part III. ", "Section"],
  StyleBox["First Order Ordinary Differential Equations", "Section"],
  "\n",
  StyleBox["Section 2. Working with Solutions: Modeling", "Subsection"],
  "\nA mathematical model often includes differential equations describing \
how one variable changes in relation to  another. Examples in this section \
show how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can be used to help in the analysis of differential equations  arising in \
the modeling process. "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Exponential models", "Subsubsection"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "When a bank compounds interest continuously the principal,  ",
  StyleBox["P",
    FontSlant->"Italic"],
  ", as a function of time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " (in years) grows  exponentially. The governing differential equation, \
given in terms of an annual interest rate  ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", is "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["P'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["r P",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Question: How long will it take $1000 to grow to $1500 at an annual \
interest rate of 4%? \
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
DE = P'[t] == 0.04*P[t]
soln = DSolve[ {DE, P[0]==1000}, P, t ]\
\>", "Input",
  CellLabel->"In[1]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["P", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(0.04`\ P[t]\)}]], "Output",
  CellLabel->"Out[1]="],

Cell[BoxData[
    \({{P \[Rule] 
          Function[{t}, 1000\ \[ExponentialE]\^\(0.04`\ t\)]}}\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
Make the solution into the function named g and solve g(t) = 15000.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
g := soln[[1,1,2]]
timesoln = FindRoot[ g[t]==1500, {t,1} ]\
\>", "Input",
  CellLabel->"In[3]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({t \[Rule] 10.13662770270411`}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "It will take about 10.14 years. Here is plot of the principal and the \
point when ",
  StyleBox["P",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = 1500."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[  ListPlot[ {{10.14,1500}}, PlotStyle->PointSize[0.03], 
                  DisplayFunction->Identity ],
       Plot[ g[t], {t,0,12}, DisplayFunction->Identity ],
       PlotRange->{0,1600}, DisplayFunction->$DisplayFunction]
\
\>", "Input",
  CellLabel->"In[11]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0793651 0 0.000386271 [
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .07725 -18 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -18 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -24 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .00625 L
s
[(2)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(4)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(8)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(12)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(200)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(400)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(600)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(800)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1000)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1200)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1400)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1600)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01931 m
.02756 .01931 L
s
.02381 .03863 m
.02756 .03863 L
s
.02381 .05794 m
.02756 .05794 L
s
.02381 .09657 m
.02756 .09657 L
s
.02381 .11588 m
.02756 .11588 L
s
.02381 .13519 m
.02756 .13519 L
s
.02381 .17382 m
.02756 .17382 L
s
.02381 .19314 m
.02756 .19314 L
s
.02381 .21245 m
.02756 .21245 L
s
.02381 .25108 m
.02756 .25108 L
s
.02381 .27039 m
.02756 .27039 L
s
.02381 .2897 m
.02756 .2897 L
s
.02381 .32833 m
.02756 .32833 L
s
.02381 .34764 m
.02756 .34764 L
s
.02381 .36696 m
.02756 .36696 L
s
.02381 .40558 m
.02756 .40558 L
s
.02381 .4249 m
.02756 .4249 L
s
.02381 .44421 m
.02756 .44421 L
s
.02381 .48284 m
.02756 .48284 L
s
.02381 .50215 m
.02756 .50215 L
s
.02381 .52147 m
.02756 .52147 L
s
.02381 .56009 m
.02756 .56009 L
s
.02381 .57941 m
.02756 .57941 L
s
.02381 .59872 m
.02756 .59872 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.03 w
.82857 .57941 Mdot
.5 Mabswid
.02381 .38627 m
.06244 .39387 L
.10458 .40232 L
.14415 .41042 L
.18221 .41837 L
.22272 .427 L
.26171 .43548 L
.30316 .44467 L
.34309 .45371 L
.3815 .46258 L
.42237 .4722 L
.46172 .48166 L
.49955 .49094 L
.53984 .50101 L
.57861 .51089 L
.61984 .52162 L
.65954 .53216 L
.69774 .54251 L
.73838 .55373 L
.77751 .56476 L
.81909 .57672 L
.85916 .58849 L
.89771 .60003 L
.93871 .61256 L
s
.93871 .61256 m
.95627 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[11]:=",
  ImageSize->{198.812, 122.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000360000NR000`400?l00000o`00003oa_ooool0
03?ooooo1Ol0000Hooooo`?o00005oooool3o`0001Wooooo0ol0000Eooooo`?o00001?ooool2o`00
01;ooooo0ol00002ooooo`Go00000oooool003Cooooo00Co0000oooooooooooo00006Oooool00ol0
003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooo
oooo000001Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Booooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool003Gooooo00?o0000ooooooooool0
5_ooool5o`0001Kooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`000?oooooooooooooo
ool000005Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`00=_ooool00ol0003oooooooooo`0Eoooo
o`04o`000?ooooooooooo`0001Oooooo1?l0000Iooooo`?o00005_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`00<oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooool000005ooo
ool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000005Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo007ooooo000cooooo`05o`000?ooooooooooooooool000006?ooool2o`00
01Sooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000001Cooooo0_l00004
ooooo`04o`000?ooooooooooo`00017ooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
0oooool003Cooooo0ol0000Jooooo`03o`000?oooooooooo01Oooooo0_l0000Iooooo`?o00005_oo
ool00ol0003oooooooooo`03ooooo`;o00004oooool00ol0003oooooooooo`02ooooo`?o00001?oo
ool00<Kooooo0036ooooo`00a_ooool001Oooooo[?l00003ooooo`006oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`05ooooo`006oooool00ol0003oooooooooo`2Xooooo`006oooool00ol0003oooooooooo`2Xoooo
o`006oooool00ol0003oooooooooo`2Xooooo`006oooool00ol0003oooooooooo`2Xooooo`006ooo
ool00ol0003oooooooooo`2Xooooo`006oooool00ol0003oooooooooo`2Xooooo`006oooool00ol0
003oooooooooo`2Xooooo`006oooool00ol0003oooooooooo`2Xooooo`006oooool00ol0003ooooo
ooooo`2Xooooo`001oooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool00ol0003ooooooooo
o`2Xooooo`002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2Xooooo`002Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2o`00
0:Wooooo000:ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`05o`000?ooooooooooooooool00000Z_ooool000Oooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`2Xooooo`001oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0:Sooooo0008oooo
o`?o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo0:Sooooo000Kooooo`03
o`000?oooooooooo0:Sooooo000Kooooo`03o`000?oooooooooo0:Sooooo000Kooooo`03o`000?oo
oooooooo0:Sooooo000Kooooo`03o`000?oooooooooo0:Sooooo000Kooooo`03o`000?oooooooooo
0:Sooooo000Kooooo`03o`000?oooooooooo0:Sooooo0009ooooo`?o00000oooool2o`0000Cooooo
0_l00004ooooo`03o`000?oooooooooo0:Sooooo000:ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000Z_ooool000Oo
oooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2
o`000:Wooooo0007ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0:Sooooo0008ooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo0:Sooooo0009ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Z?ooool000[ooooo00?o0000oooooooo
ool00_ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo0:Sooooo000Kooooo`03o`00
0?oooooooooo0:Sooooo000Kooooo`03o`000?oooooooooo0:Sooooo000Kooooo`03o`000?oooooo
oooo0:Sooooo000Kooooo`03o`000?oooooooooo0:Sooooo000Kooooo`03o`000?oooooooooo0:So
oooo000Kooooo`03o`000?oooooooooo0:Sooooo0008ooooo`?o00001?ooool2o`0000Cooooo0_l0
0004ooooo`03o`000?oooooooooo0:Sooooo0007ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool0Z?ooool000Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2Xooooo`001oooool4o`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`;o0000ZOoo
ool000Oooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0Z?ooool000Sooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool0Z?ooool000Wooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool0
Z?ooool001_ooooo00?o0000ooooooooool0Z?ooool001_ooooo00?o0000ooooooooool0Z?ooool0
01_ooooo00?o0000ooooooooool0Z?ooool001_ooooo00?o0000ooooooooool0Z?ooool001_ooooo
00?o0000ooooooooool0Z?ooool001_ooooo00?o0000ooooooooool0Z?ooool000Sooooo0ol00004
ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool0Z?ooool000Oooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`2Xooooo`001oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
0:Sooooo0008ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000?ooooo0_l0002Yooooo`001oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0:Sooooo
0007ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Z?ooool000Sooooo0ol00004ooooo`;o
00001?ooool2o`0000Cooooo00?o0000ooooooooool0Z?ooool001_ooooo00?o0000ooooooooool0
Z?ooool001_ooooo00?o0000ooooooooool0Z?ooool001_ooooo00?o0000ooooooooool0Z?ooool0
01_ooooo00?o0000ooooooooool0Z?ooool001_ooooo00?o0000ooooooooool0Z?ooool001_ooooo
00?o0000ooooooooool0Z?ooool001_ooooo00?o0000ooooooooool0Z?ooool000;ooooo0ol00004
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo0:Sooooo0003oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Z?ooool000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool4o`000:Oooooo0003ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooooooo1Ol0002Rooooo`000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Kooooo1?l0002Nooooo`000_ooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool02_ooool5o`0009Wooooo0003ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool03oooool5
o`0009Cooooo000Kooooo`03o`000?oooooooooo01Cooooo0ol0002Aooooo`006oooool00ol0003o
ooooooooo`0Gooooo`Ko0000Roooool001_ooooo00?o0000ooooooooool07Oooool5o`0008Kooooo
000Kooooo`03o`000?oooooooooo02;ooooo0ol00023ooooo`006oooool00ol0003oooooooooo`0U
ooooo`Ko0000OOooool001_ooooo00?o0000ooooooooool0:oooool5o`0007Sooooo0002ooooo`?o
00000_ooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`0`ooooo`?o
0000MOooool000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0c
ooooo`Go0000L?ooool000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2o`0003Wooooo1Ol0
001[ooooo`000oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000?oooool3o`0006So
oooo0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000012ooooo`Co0000I?oo
ool000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0A?ooool3o`00067o
oooo0003ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo
00?o0000ooooooooool0Aoooool5o`0005cooooo000Kooooo`03o`000?oooooooooo04cooooo1Ol0
001Gooooo`006oooool00ol0003oooooooooo`1Aooooo`?o0000E?ooool001_ooooo00?o0000oooo
ooooool0E?ooool4o`00053ooooo000Kooooo`03o`000?oooooooooo05Sooooo0ol0001=ooooo`00
6oooool00ol0003oooooooooo`1Kooooo`Ko0000Aoooool001_ooooo00?o0000ooooooooool0HOoo
ool5o`0004;ooooo0002ooooo`?o00001?ooool3o`0000?ooooo0_l00004ooooo`;o00001?ooool0
0ol0003oooooooooo`1Vooooo`?o0000?oooool000?ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000006_ooooo1?l0000kooooo`000oooool01?l0003oooooooooooooool5o`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
06gooooo0ol0000hooooo`000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo
0_l0001aooooo`?o0000=Oooool000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`1cooooo`?o0000<_ooool000;ooooo0_l00005ooooo`;o00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0M_ooool4o`00
02kooooo0003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0000Co
oooo0_l00004ooooo`03o`000?oooooooooo07[ooooo0ol0000[ooooo`006oooool00ol0003ooooo
ooooo`1mooooo`Co00001Oooool3o`0001oooooo000Kooooo`03o`000?oooooooooo087ooooo0ol0
00000ooooooo0000o`000003o`0001kooooo000Kooooo`03o`000?oooooooooo08Cooooo1_l0000N
ooooo`006oooool00ol0003oooooooooo`25ooooo`Ko00007Oooool001_ooooo00?o0000oooooooo
ool0Q_ooool3o`0000;ooooo1?l0000Iooooo`006oooool00ol0003oooooooooo`2?ooooo`?o0000
5_ooool000;ooooo0ol00003ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oo
oooooooo09;ooooo1?l0000Booooo`000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool00000V?ooool3o`0000oooooo0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooooooo
o`00002Kooooo`Co00002oooool000?ooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2o`0009kooooo00?o0000oooo
ooooool02?ooool000?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000[_ooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0002^ooooo`000ooo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l0002_ooooo`00a_ooool0
0001\
\>"],
  ImageRangeCache->{{{77.875, 275.688}, {636.625, 514.812}} -> {-7.70586, \
7590.68, 0.0733503, 15.0709}}]
}, Open  ]],

Cell[TextData[{
  "The exponent on ",
  StyleBox["e",
    FontSlant->"Italic"],
  " in the solution formula tells us that the principal will triple in a \
little over 25 years (the  multiplier for ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 25 would be ",
  StyleBox["e",
    FontSlant->"Italic"],
  ", which is 2.78). Recall that the doubling time is ",
  Cell[BoxData[
      \(TraditionalForm\`\(ln(2)\)\/r\)]],
  ". See Ledder, Chapter 1. See below."
}], "Text"],

Cell[CellGroupData[{

Cell["Log[2]/0.04*years", "Input",
  CellLabel->"In[12]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(17.328679513998633`\ years\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[StyleBox["A more interesting problem",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
Juanita's credit card bill is $2500, she pays an annual 9% interest \
rate, compounded continuously. She decides  to pay it off by transferring \
money from her savings account continuously at the rate of $100 per month.  \
Assuming she has $35,000 in savings, which accumulates interest at the annual \
rate of 2%, also compounded  continuously, how long will it take? What will \
her total payments be? How much money will she have in her  savings account \
when the debt is settled?\
\>", "Text"],

Cell[TextData[{
  " Let ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") be the amount that Juanita owes the creditor at time  ",
  StyleBox["t",
    FontSlant->"Italic"],
  " (in years), ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 2500. Since she reduces debt at  a constant yearly rate of $1200, \
the differential equation for ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") looks like this. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
DE2 = y'[t] == 0.09*y[t] - 1200
soln = DSolve[ {DE2, y[0]==2500}, y, t]\
\>", "Input",
  CellLabel->"In[13]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(\(-1200\) + 0.09`\ y[t]\)}]], "Output",
  CellLabel->"Out[13]="],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{t}, 
            2.718281828459045`\^\(\(-0.08999999999999998`\)\ t\)\ \
\((\(-10833.333333333332`\)\ 7.3890560989306495`\^\(0.08999999999999998`\ t\) \
+ 13333.333333333332`\ \[ExponentialE]\^\(0.08999999999999998`\ t\))\)]}}\)], \
"Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["\<\
Name the solution function g once more. The debt is liquidated when \
g(t) = 0.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
g := soln[[1,1,2]]
debtfree = FindRoot[ g[t]==0, {t,1}]\
\>", "Input",
  CellLabel->"In[16]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({t \[Rule] 2.3071040530916065`}\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell["Check the solution.", "Text"],

Cell[CellGroupData[{

Cell["g[t]/.debtfree", "Input",
  CellLabel->"In[18]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(0.`\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
It will take Juanita about 2.3 years to pay off the debt. This is \
between 27 and 28 months. \
\>", "Text"],

Cell[CellGroupData[{

Cell["(12*t/.debtfree)*months", "Input",
  CellLabel->"In[19]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(27.685248637099278`\ months\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[ g[t], {t,0,2.5}, AspectRatio->1/3 ]", "Input",
  CellLabel->"In[25]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.380952 0.0350541 0.000116137 [
[.21429 .02255 -9 -9 ]
[.21429 .02255 9 0 ]
[.40476 .02255 -3 -9 ]
[.40476 .02255 3 0 ]
[.59524 .02255 -9 -9 ]
[.59524 .02255 9 0 ]
[.78571 .02255 -3 -9 ]
[.78571 .02255 3 0 ]
[.97619 .02255 -9 -9 ]
[.97619 .02255 9 0 ]
[.01131 .09312 -18 -4.5 ]
[.01131 .09312 0 4.5 ]
[.01131 .15119 -24 -4.5 ]
[.01131 .15119 0 4.5 ]
[.01131 .20926 -24 -4.5 ]
[.01131 .20926 0 4.5 ]
[.01131 .26733 -24 -4.5 ]
[.01131 .26733 0 4.5 ]
[.01131 .3254 -24 -4.5 ]
[.01131 .3254 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .03505 m
.21429 .0413 L
s
[(0.5)] .21429 .02255 0 1 Mshowa
.40476 .03505 m
.40476 .0413 L
s
[(1)] .40476 .02255 0 1 Mshowa
.59524 .03505 m
.59524 .0413 L
s
[(1.5)] .59524 .02255 0 1 Mshowa
.78571 .03505 m
.78571 .0413 L
s
[(2)] .78571 .02255 0 1 Mshowa
.97619 .03505 m
.97619 .0413 L
s
[(2.5)] .97619 .02255 0 1 Mshowa
.125 Mabswid
.0619 .03505 m
.0619 .0388 L
s
.1 .03505 m
.1 .0388 L
s
.1381 .03505 m
.1381 .0388 L
s
.17619 .03505 m
.17619 .0388 L
s
.25238 .03505 m
.25238 .0388 L
s
.29048 .03505 m
.29048 .0388 L
s
.32857 .03505 m
.32857 .0388 L
s
.36667 .03505 m
.36667 .0388 L
s
.44286 .03505 m
.44286 .0388 L
s
.48095 .03505 m
.48095 .0388 L
s
.51905 .03505 m
.51905 .0388 L
s
.55714 .03505 m
.55714 .0388 L
s
.63333 .03505 m
.63333 .0388 L
s
.67143 .03505 m
.67143 .0388 L
s
.70952 .03505 m
.70952 .0388 L
s
.74762 .03505 m
.74762 .0388 L
s
.82381 .03505 m
.82381 .0388 L
s
.8619 .03505 m
.8619 .0388 L
s
.9 .03505 m
.9 .0388 L
s
.9381 .03505 m
.9381 .0388 L
s
.25 Mabswid
0 .03505 m
1 .03505 L
s
.02381 .09312 m
.03006 .09312 L
s
[(500)] .01131 .09312 1 0 Mshowa
.02381 .15119 m
.03006 .15119 L
s
[(1000)] .01131 .15119 1 0 Mshowa
.02381 .20926 m
.03006 .20926 L
s
[(1500)] .01131 .20926 1 0 Mshowa
.02381 .26733 m
.03006 .26733 L
s
[(2000)] .01131 .26733 1 0 Mshowa
.02381 .3254 m
.03006 .3254 L
s
[(2500)] .01131 .3254 1 0 Mshowa
.125 Mabswid
.02381 .04667 m
.02756 .04667 L
s
.02381 .05828 m
.02756 .05828 L
s
.02381 .0699 m
.02756 .0699 L
s
.02381 .08151 m
.02756 .08151 L
s
.02381 .10474 m
.02756 .10474 L
s
.02381 .11635 m
.02756 .11635 L
s
.02381 .12796 m
.02756 .12796 L
s
.02381 .13958 m
.02756 .13958 L
s
.02381 .1628 m
.02756 .1628 L
s
.02381 .17442 m
.02756 .17442 L
s
.02381 .18603 m
.02756 .18603 L
s
.02381 .19765 m
.02756 .19765 L
s
.02381 .22087 m
.02756 .22087 L
s
.02381 .23249 m
.02756 .23249 L
s
.02381 .2441 m
.02756 .2441 L
s
.02381 .25571 m
.02756 .25571 L
s
.02381 .27894 m
.02756 .27894 L
s
.02381 .29056 m
.02756 .29056 L
s
.02381 .30217 m
.02756 .30217 L
s
.02381 .31378 m
.02756 .31378 L
s
.02381 .02344 m
.02756 .02344 L
s
.02381 .01183 m
.02756 .01183 L
s
.02381 .00021 m
.02756 .00021 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.02381 .3254 m
.06244 .31386 L
.10458 .30116 L
.14415 .28911 L
.18221 .27742 L
.22272 .26486 L
.26171 .25266 L
.30316 .23956 L
.34309 .22683 L
.3815 .21446 L
.42237 .20117 L
.46172 .18826 L
.49955 .17573 L
.53984 .16227 L
.57861 .14919 L
.61984 .13516 L
.65954 .1215 L
.69774 .10825 L
.73838 .09402 L
.77751 .08018 L
.81909 .06534 L
.85916 .0509 L
.89771 .03688 L
.93871 .02182 L
.97619 .00794 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{314.688, 104.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000J2000`400?l00000o`00003ooooooolk
ooooo`00oooooolkooooo`00C?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0002ko
oooo0ol0000^ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000;_ooool5o`0002co
oooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`006oooool2o`0002kooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000;_ooool0
1?l0003oooooooooool0000]ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000002ooooo`006oooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000_o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_o
oooo0Ol00001ooooo`7ooooo000Kooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool02_ooool1o`00007ooooo0Oooool001_ooooo00?o0000ooooooooool0;Oooool01?l0003ooooo
ooooool00007ooooo`Co0000;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Oo
oooo1?l0000^ooooo`05o`000?ooooooooooooooool00000;?ooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00002ooooo`Co00000oooool001_ooooo0_l0000^ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool0;oooool2o`0002oooooo0_l00009ooooo`03o`000?oooooo
oooo02oooooo00Go0000ooooooooooooooooo`00000/ooooo`04o`000?ooooooooooooooo`Co0000
1?ooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0^ooooo`;o00002?oo
ool5o`0002kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`07ooooo`Go0000;_oo
ool3o`0002kooooo1?l00007ooooo`Go00000_ooool001_ooooo00?o0000ooooooooool0ooooool9
ooooo`?o00004Oooool001_ooooo0_l0003oooooo`Sooooo0_l0000Dooooo`006oooool00ol0003o
ooooooooo`3oooooo`Cooooo0ol0000Fooooo`006oooool00ol0003oooooooooo`3oooooo`7ooooo
0ol0000Iooooo`005?ooooooo`0002Go00000_ooool001_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`?o00002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06Oooool3o`00
01Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0m?ooool3o`0002Go
oooo000Kooooo`;o0000l_ooool3o`0002Sooooo000Kooooo`03o`000?oooooooooo0>oooooo0_l0
000[ooooo`006oooool00ol0003oooooooooo`3/ooooo`?o0000;Oooool001_ooooo0_l0003Zoooo
o`?o0000<?ooool001_ooooo00?o0000ooooooooool0i_ooool3o`0003?ooooo000Kooooo`03o`00
0?oooooooooo0>?ooooo0ol0000fooooo`006oooool00ol0003oooooooooo`3Pooooo`?o0000>Ooo
ool001_ooooo0_l0003Oooooo`;o0000??ooool001_ooooo00?o0000ooooooooool0g?ooool2o`00
03kooooo000Kooooo`03o`000?oooooooooo0=Wooooo0ol00010ooooo`006oooool2o`000=Sooooo
0_l00013ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003ooooooooo
o`3Dooooo`?o0000AOooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3Aooooo`?o
0000B?ooool000[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo0ol0003>ooooo`?o0000Boooool000[ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0c?ooool2o`0004kooooo0006ooooo`Co00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0bOooool3o`00053ooooo0006
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo0<Kooooo0ol0001Cooooo`001_ooool5o`0000?ooooo0_l0
0004ooooo`;o00001Oooool2o`000<Cooooo0ol0001Fooooo`006oooool00ol0003oooooooooo`30
ooooo`?o0000FOooool001_ooooo00?o0000ooooooooool0_Oooool3o`0005cooooo000Kooooo`;o
0000^oooool3o`0005oooooo000Kooooo`03o`000?oooooooooo0;Oooooo0ol0001Rooooo`006ooo
ool00ol0003oooooooooo`2eooooo`;o0000IOooool001_ooooo0_l0002cooooo`?o0000Ioooool0
01_ooooo00?o0000ooooooooool0[oooool3o`0006[ooooo000Kooooo`03o`000?oooooooooo0:co
oooo0ol0001]ooooo`006oooool00ol0003oooooooooo`2Zooooo`;o0000L?ooool001_ooooo0_l0
002Xooooo`?o0000L_ooool00004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0Y?ooool3o`0007Gooooo0002ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0XOooool3o`0007Sooooo0002ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo0ol0002Mooooo`Co0000Noooool000;ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`2Iooooo`Co0000Ooooool000;ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2Eooooo`Co0000Poooool00003
ooooool0003o000000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0T_ooool3o`0008Oooooo0002
ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l0002@
ooooo`?o0000R_ooool001_ooooo00?o0000ooooooooool0S?ooool3o`0008gooooo000Kooooo`03
o`000?oooooooooo08Wooooo0ol0002@ooooo`006oooool2o`0008Sooooo0_l0002Cooooo`006ooo
ool00ol0003oooooooooo`24ooooo`?o0000UOooool001_ooooo00?o0000ooooooooool0POooool3
o`0009Sooooo000Kooooo`;o0000Ooooool3o`0009_ooooo000Kooooo`03o`000?oooooooooo07co
oooo0_l0002Nooooo`006oooool00ol0003oooooooooo`1iooooo`?o0000X?ooool001_ooooo00?o
0000ooooooooool0M_ooool3o`000:?ooooo000Kooooo`;o0000M?ooool3o`000:Kooooo00001?oo
oooo0000o`000?l00003ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo073ooooo0ol0002Yooooo`000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0KOooool3o`000:cooooo0002ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo0ol0001Zooooo`?o0000[oooool000;ooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Wooooo`?o0000/_ooool000;ooooo00Co0000oooooooooooooooo1?l00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1Sooooo`Co0000]Oooool00003ooooool0003o000000?ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001Pooooo`Co0000
^Oooool000;ooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo
00?o0000ooooooooool0G?ooool3o`000;gooooo000Kooooo`03o`000?oooooooooo05Wooooo0ol0
0030ooooo`006oooool00ol0003oooooooooo`1Fooooo`?o0000`oooool001_ooooo0_l0001Doooo
o`?o0000a_ooool001_ooooo00?o0000ooooooooool0D?ooool3o`000<Wooooo000Kooooo`03o`00
0?oooooooooo04gooooo0ol0003<ooooo`006oooool2o`0004_ooooo0ol0003?ooooo`006oooool0
0ol0003oooooooooo`17ooooo`?o0000d_ooool001_ooooo00?o0000ooooooooool0A?ooool3o`00
0=Gooooo000Kooooo`03o`000?oooooooooo043ooooo1?l0003Hooooo`001Ol00003ooooo`;o0000
1?ooool2o`0000Cooooo0_l00005ooooo`;o0000?Oooool4o`000=cooooo00001Ooooooo0000oooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>Oooool3o`000>3ooooo0002oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=_ooool3o`000>?ooooo
0003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool3o`0003?ooooo0ol0003Voooo
o`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo033ooooo
0ol0003Yooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo02gooooo0ol0003/ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00004
ooooo`;o00001Oooool2o`0002[ooooo1?l0003_ooooo`006oooool00ol0003oooooooooo`0Uoooo
o`Co0000loooool001_ooooo00?o0000ooooooooool08_ooool3o`000?Oooooo000Kooooo`03o`00
0?oooooooooo01oooooo0ol0003jooooo`006oooool2o`0001gooooo0ol0003mooooo`006oooool0
0ol0003oooooooooo`0Iooooo`?o0000ooooool1ooooo`006oooool00ol0003oooooooooo`0Foooo
o`?o0000ooooool4ooooo`006oooool2o`0001Cooooo0ol0003oooooo`Oooooo000Kooooo`03o`00
0?oooooooooo013ooooo0ol0003oooooo`[ooooo000Kooooo`03o`000?oooooooooo00gooooo0ol0
003oooooo`gooooo000Kooooo`;o00002oooool3o`000?oooooo4?ooool000Go00000_ooool3o`00
00Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`Co0000oooooolCoooo
o`0000Ooooooo`000?ooooooooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool4o`000?oooooo5oooool000;ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000002o`000?oooooo6oooool000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool3o`00
0?oooooo7Oooool00006o`000?ooooooooooooooool0003ooooo1?l00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3ooooooagooooo
00001ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0oooooolMooooo`0000Coooooo`00
0?l0003o00000_ooool5o`0000?ooooo0_l00004ooooo`;o0000oooooolUooooo`00oooooolkoooo
o`00oooooolkooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 391.562}, {642.562, 538.688}} -> {-0.952113, \
15537.1, 0.00902369, 29.5995}}]
}, Open  ]],

Cell["\<\
Her total payment can be calculated as the product of the annual \
payment rate, 1200, and the time it took to  settle the debt. \
\>", "Text"],

Cell[CellGroupData[{

Cell["(1200*t/.debtfree)*dollars", "Input",
  CellLabel->"In[26]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(2768.5248637099276`\ dollars\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
  "To calculate the balance in Juanita's savings account, let  ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") denote the principal at time  ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(0) = 35000. The  differential equation for ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), and its solution are entered below. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
DE3 = x'[t] == 0.02*x[t] - 1200
savings = DSolve[ {DE3, x[0]==35000}, x, t ]\
\>", "Input",
  CellLabel->"In[31]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(\(-1200\) + 0.02`\ x[t]\)}]], "Output",
  CellLabel->"Out[31]="],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, 
            2.718281828459045`\^\(\(-0.02`\)\ t\)\ \((\(-25000.`\)\ \
7.3890560989306495`\^\(0.02`\ t\) + 
                  60000.`\ \[ExponentialE]\^\(0.02`\ t\))\)]}}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
The savings balance at time of payoff can be calculated as follows. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell["x[t]/.savings/.debtfree", "Input",
  CellLabel->"In[34]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({33819.420225744405`}\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell[TextData[StyleBox["Monthly payments",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
 It is unlikely that any bank would agree to make continuous \
payouts for Juanita. On the other hand, many  banks offer the service of \
regularly monthly payments. Let's compare the total payout calculated above \
with  the payout if Juanita has her bank send $100 to arrive to her creditor \
on day 30 of month 1 and $100 on day 30 of every month thereafter. Assume \
that each month has 30 days and a year has 360. 
Let  d[n] be Juanita's credit card debt on the first day of month n. Then  \
d[1] = 2500 and d[2], her debt on the first day of month 2, is given  by the \
following formula: \
\>", "Text"],

Cell[TextData[{
  "d[2] = 2500 ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(0.09\/12\)\)]],
  "- 100"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Remember that time is in years so one month is 1/12 years. \nThe function \
d can be defined recursively in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as follows."
}], "Text"],

Cell["\<\
d[1] = 2500;
d[n_] := d[n-1]*Exp[0.09/12] - 100\
\>", "Input",
  CellLabel->"In[48]:=",
  FormatType->InputForm],

Cell["\<\
At the beginning of the 27th month, Juanita has paid $2600 and owes \
d[27] dollars, $178.22. See below.\
\>", "Text"],

Cell[CellGroupData[{

Cell["d[27]", "Input",
  CellLabel->"In[47]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(178.21640542836093`\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell["\<\
One more month goes by, the 27th payment of $100 is made, and \
Juanita still owes the following amount. \
\>", "Text"],

Cell[CellGroupData[{

Cell["d[28]", "Input",
  CellLabel->"In[50]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(79.55805335984792`\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell["\<\
Assuming she pays it all off at that time, her total payout is \
$2779.56. This is about $10 more than it would be if the payouts were made \
continuously. See the exercises for this section.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["Heating and cooling",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell[TextData[{
  "Isaac Newton proposed a simple model for the temperature ",
  StyleBox["T",
    FontSlant->"Italic"],
  " of an object that cools or warms while immersed  in a medium of ambient \
temperature ",
  StyleBox["A",
    FontSlant->"Italic"],
  " (in the absence of convective effects). If  ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") denotes the object's  temperature at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and ",
  StyleBox["A",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") is the ambient temperature at the same time, then Newton's law of \
cooling is the  assumption that "
}], "Text"],

Cell[TextData[{
  StyleBox["T'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["k",
    FontSlant->"Italic"],
  " ( ",
  StyleBox["A",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") - ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "where ",
  StyleBox["k",
    FontSlant->"Italic"],
  " is a positive constant. An additional heating or cooling term can be \
added by changing the equation to"
}], "Text"],

Cell[TextData[{
  StyleBox["T'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["k",
    FontSlant->"Italic"],
  " ( ",
  StyleBox["A",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") - ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") )",
  " + ",
  StyleBox["H",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ")"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "If this equation is given to DSolve, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " outputs the solution as a textbook integral. (See Ledder's Variation of  \
Parameters formula, Chapter 4, page 260.)  The following input asks for the \
solution in form T[t] -> ... ."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
T'[t] == k*(A[t] - T[t]) + H[t]
DSolve[ %, T[t], t ]\
\>", "Input",
  CellLabel->"In[57]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(H[t] + k\ \((A[t] - T[t])\)\)}]], "Output",
  CellLabel->"Out[57]="],

Cell[BoxData[
    \({{T[
            t] \[Rule] \[ExponentialE]\^\(\(-k\)\ t\)\ C[
                1] + \[ExponentialE]\^\(\(-k\)\ t\)\ \(\[Integral]\_1\%t\( \
\[ExponentialE]\^\(k\ K$535\)\ \((k\ A[K$535] + 
                        H[K$535])\)\) \[DifferentialD]K$535\)}}\)], "Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["The strange looking integral",
    FontVariations->{"Underline"->True}],
  ". Mathematica has made the solution formula in terms of a definite \
integral and has chosen the symbol K$535 for the variable of integration. \
Send an e-mail to Mathematica and ask why."
}], "Note"],

Cell[TextData[{
  StyleBox["Constant ambient temperature, no heat",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell[TextData[{
  "If the ambient temperature is constant and there is no additional heating \
or cooling, the temperature ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") will  move towards the ambient temperature ",
  StyleBox["A",
    FontSlant->"Italic"],
  " exponentially. The number 1/",
  StyleBox["k",
    FontSlant->"Italic"],
  ", called the \"time constant\", tells us  how fast ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") approaches ",
  StyleBox["A",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
T'[t] == k*(A - T[t])
DSolve[ %, T[t], t ]\
\>", "Input",
  CellLabel->"In[59]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(k\ \((A - T[t])\)\)}]], "Output",
  CellLabel->"Out[59]="],

Cell[BoxData[
    \({{T[t] \[Rule] A + \[ExponentialE]\^\(\(-k\)\ t\)\ C[1]}}\)], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell[TextData[{
  "Observe that for every increase in ",
  StyleBox["t",
    FontSlant->"Italic"],
  " by 1/",
  StyleBox["k",
    FontSlant->"Italic"],
  " the difference between ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") and ",
  StyleBox["A",
    FontSlant->"Italic"],
  " will decrease by a factor of 1/",
  StyleBox["e",
    FontSlant->"Italic"],
  "  (about 1/3).This is useful for graphing purposes and making rough \
estimates. In a typical problem one knows  the initial temperature ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(0), the ambient temperature ",
  StyleBox["A",
    FontSlant->"Italic"],
  ", and the object's temperature at some later time, ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(t0). \n",
  StyleBox["Example. Joe is served a cup of coffee at",
    FontSlant->"Italic"],
  " 10 AM.",
  StyleBox[" Its temperature is ",
    FontSlant->"Italic"],
  "150 ",
  StyleBox["degrees F. Five minutes later the coffee  temperature has dropped \
to ",
    FontSlant->"Italic"],
  "110 ",
  StyleBox["degrees",
    FontSlant->"Italic"],
  ".",
  StyleBox[" If the room temperature is",
    FontSlant->"Italic"],
  " 66 ",
  StyleBox["degrees, when will the coffee  temperature be ",
    FontSlant->"Italic"],
  "100 ",
  StyleBox["degrees",
    FontSlant->"Italic"],
  "? "
}], "Text"],

Cell[TextData[{
  "Start with the differential equation and the solution to the IVP obtained \
using the initial condition ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(0) = 150.  (10 AM is taken as time 0.)  "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
DEcoffee = T'[t] == k*(66 - T[t])
soln = DSolve[ {DEcoffee, T[0]==150}, T, t ]\
\>", "Input",
  CellLabel->"In[72]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(k\ \((66 - T[t])\)\)}]], "Output",
  CellLabel->"Out[72]="],

Cell[BoxData[
    \({{T \[Rule] 
          Function[{t}, 
            6\ \[ExponentialE]\^\(\(-k\)\ t\)\ \((14 + 
                  11\ \[ExponentialE]\^\(k\ t\))\)]}}\)], "Output",
  CellLabel->"Out[73]="]
}, Open  ]],

Cell[TextData[{
  "Name the solution function g. The temperature at ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 5 is 110. This is used to find ",
  StyleBox["k",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
g := soln[[1,1,2]]
ksoln = Solve[ g[5] == 110, k ]\
\>", "Input",
  CellLabel->"In[74]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{\(Solve::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse functions are \
being used by \\!\\(Solve\\), so some solutions may not be found; use Reduce \
for complete solution information. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[74]:="],

Cell[BoxData[
    \({{k \[Rule] 1\/5\ Log[21\/11]}}\)], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell["\<\
The time constant is calculated first. The natural entry shown \
below seems to fail, N is not applied.\
\>", "Text"],

Cell[CellGroupData[{

Cell["N[1/k]/.ksoln", "Input",
  CellLabel->"In[76]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({5\/Log[21\/11]}\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell["\<\
The next entry illustrates an alternative way to apply N. Follow \
the calculation of 1/k with //N.\
\>", "Text"],

Cell[CellGroupData[{

Cell["1/k/.ksoln//N", "Input",
  CellLabel->"In[77]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({7.73243109973508`}\)], "Output",
  CellLabel->"Out[77]="]
}, Open  ]],

Cell[TextData[{
  "This tells us that if the coffee sits for 7.7 minutes, the difference (84 \
degrees) between ",
  StyleBox["g",
    FontSlant->"Italic"],
  "(0) and the ambient  temperature will decrease to about 1/3 of its value. \
That is, the difference will be about 30 degrees:  ",
  StyleBox["g",
    FontSlant->"Italic"],
  "(7.7) is  roughly 96. We will find out when g(t) = 100 using FindRoot but \
first let's give k the value described by ksoln. "
}], "Text"],

Cell[CellGroupData[{

Cell["k = k/.ksoln[[1,1]]", "Input",
  CellLabel->"In[81]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(1\/5\ Log[21\/11]\)], "Output",
  CellLabel->"Out[81]="]
}, Open  ]],

Cell[TextData[{
  "You might like to see the formula for g[t] now that ",
  StyleBox["k",
    FontSlant->"Italic"],
  " has its exact value."
}], "Text"],

Cell[CellGroupData[{

Cell["g[t]", "Input",
  CellLabel->"In[82]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(2\ \((11\/7)\)\^\(t/5\)\ 3\^\(1 - t\/5\)\ \((14 + 
          11\^\(1 - t\/5\)\ 21\^\(t/5\))\)\)], "Output",
  CellLabel->"Out[82]="]
}, Open  ]],

Cell["\<\
When is the coffee at 100 degrees? At about 7 minutes after \
10.\
\>", "Text"],

Cell[CellGroupData[{

Cell["FindRoot[ g[t]==100, {t,5} ]", "Input",
  CellLabel->"In[83]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({t \[Rule] 6.993645823184554`}\)], "Output",
  CellLabel->"Out[83]="]
}, Open  ]],

Cell["\<\
The next plot shows the graph of the temperature, g(t), the ambient \
temperature, 66, and dashed lines indicating when the coffee  reaches 100 \
degrees. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ ListPlot[ {{0,100},{6.99,100},{6.99,0}}, PlotJoined->True, 
                 PlotStyle->Dashing[{0.02,0.02}]],
      Plot[ {g[t],66}, {t,0,15}], PlotRange->{0,160} ]\
\>", "Input",
  CellLabel->"In[96]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0 0.00386271 [
[.15079 -0.0125 -3 -9 ]
[.15079 -0.0125 3 0 ]
[.27778 -0.0125 -3 -9 ]
[.27778 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.53175 -0.0125 -3 -9 ]
[.53175 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.9127 -0.0125 -6 -9 ]
[.9127 -0.0125 6 0 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 0 m
.15079 .00625 L
s
[(2)] .15079 -0.0125 0 1 Mshowa
.27778 0 m
.27778 .00625 L
s
[(4)] .27778 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(6)] .40476 -0.0125 0 1 Mshowa
.53175 0 m
.53175 .00625 L
s
[(8)] .53175 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(12)] .78571 -0.0125 0 1 Mshowa
.9127 0 m
.9127 .00625 L
s
[(14)] .9127 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.5 0 m
.5 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(20)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(40)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(60)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(80)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(100)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(120)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(140)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(160)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01931 m
.02756 .01931 L
s
.02381 .03863 m
.02756 .03863 L
s
.02381 .05794 m
.02756 .05794 L
s
.02381 .09657 m
.02756 .09657 L
s
.02381 .11588 m
.02756 .11588 L
s
.02381 .13519 m
.02756 .13519 L
s
.02381 .17382 m
.02756 .17382 L
s
.02381 .19314 m
.02756 .19314 L
s
.02381 .21245 m
.02756 .21245 L
s
.02381 .25108 m
.02756 .25108 L
s
.02381 .27039 m
.02756 .27039 L
s
.02381 .2897 m
.02756 .2897 L
s
.02381 .32833 m
.02756 .32833 L
s
.02381 .34764 m
.02756 .34764 L
s
.02381 .36696 m
.02756 .36696 L
s
.02381 .40558 m
.02756 .40558 L
s
.02381 .4249 m
.02756 .4249 L
s
.02381 .44421 m
.02756 .44421 L
s
.02381 .48284 m
.02756 .48284 L
s
.02381 .50215 m
.02756 .50215 L
s
.02381 .52147 m
.02756 .52147 L
s
.02381 .56009 m
.02756 .56009 L
s
.02381 .57941 m
.02756 .57941 L
s
.02381 .59872 m
.02756 .59872 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .38627 m
.46762 .38627 L
.46762 0 L
s
[ ] 0 setdash
.02381 .57941 m
.06244 .55485 L
.10458 .53019 L
.14415 .50887 L
.18221 .48993 L
.22272 .47132 L
.26171 .4548 L
.30316 .43862 L
.34309 .42427 L
.3815 .41153 L
.42237 .39902 L
.46172 .38792 L
.49955 .37806 L
.53984 .36836 L
.57861 .35975 L
.61984 .35131 L
.65954 .34382 L
.69774 .33717 L
.73838 .33063 L
.77751 .32483 L
.81909 .31916 L
.85916 .31412 L
.89771 .30966 L
.93871 .30527 L
.97619 .30157 L
s
.02381 .25494 m
.06244 .25494 L
.10458 .25494 L
.14415 .25494 L
.18221 .25494 L
.22272 .25494 L
.26171 .25494 L
.30316 .25494 L
.34309 .25494 L
.3815 .25494 L
.42237 .25494 L
.46172 .25494 L
.49955 .25494 L
.53984 .25494 L
.57861 .25494 L
.61984 .25494 L
.65954 .25494 L
.69774 .25494 L
.73838 .25494 L
.77751 .25494 L
.81909 .25494 L
.85916 .25494 L
.89771 .25494 L
.93871 .25494 L
.97619 .25494 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[96]:=",
  ImageSize->{196.812, 121.5},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000340000NB000`400?l00000o`00003oa?ooool0
02_ooooo1Ol0000Cooooo`?o00004Oooool3o`0001?ooooo0ol0000?ooooo`?o00001?ooool2o`00
00gooooo0ol00002ooooo`Go00002oooool3o`0000Cooooo0ol0000@ooooo`00;?ooool01?l0003o
ooooooooool0000Dooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000A
ooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000<ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool002gooooo00?o0000ooooooooool0
4Oooool5o`00013ooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?oooooooooooooo
ool000003oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooooooo`Go00004?oo
ool002kooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000Aooooo`Co00004ooo
ool3o`00013ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000=ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool03oooool002_ooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooo0000017ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000
00oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000=ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000004Oooool002_ooooo00Go0000ooooooooooooooooo`00000Cooooo`;o00004_oo
ool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool000003_ooool2o`0000Cooooo
00Co0000oooooooooooo00003?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`;o00001Oooool2o`00017ooooo000/ooooo`?o00005Oooool00ol0003oooooooooo`0Aooooo`;o
00004oooool3o`00013ooooo00?o0000ooooooooool00oooool2o`0000kooooo00?o0000oooooooo
ool00_ooool3o`0000gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`00
a?ooool00<Cooooo0034ooooo`005OoooonZo`0000Gooooo000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo000Iooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0GOooool001Wooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`1Mooooo`006Oooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo05gooooo000Iooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0GOooool001Wooooo00?o0000ooooooooool0Z?ooool001Wooooo00?o0000ooooooooool0
Z?ooool001Wooooo00?o0000ooooooooool0Z?ooool001Wooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`1Mooooo`006Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
05gooooo000;ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`1Mooooo`003?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Mooooo`003Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo0_l0002Yooooo`003_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00002Zooooo`002oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo05gooooo000;ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
GOooool000cooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo05gooooo000Iooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0GOooool0
01Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Mooooo`006Oooool00ol0003o
ooooooooo`2Xooooo`006Oooool00ol0003oooooooooo`2Xooooo`006Oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo05gooooo000Iooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0GOooool000gooooo0ol00003ooooo`;o00001?ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo05gooooo000>ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000004[ooooo00?o0000ooooooooool0GOooool000_ooooo1Ol00002oooo
o`04o`000?ooooooooooo`0000?ooooo0_l00019ooooo`03o`000?oooooooooo05gooooo000;oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`2Xooooo`003?ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool0Z?ooool000gooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`1Mooooo`003_ooool00ol0003oooooooooo`02
ooooo`;o00001?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05gooooo000Ioooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0GOooool001Wooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`1Mooooo`006Oooool00ol0003oooooooooo`2Xooooo`006Ooo
ool00ol0003oooooooooo`2Xooooo`006Oooool00ol0003oooooooooo`2Xooooo`006Oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo05gooooo000<ooooo`?o00001?ooool2o`0000Co
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Mooooo`002oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo05gooooo000;ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00003ooooo`;o0000BOooool00ol0003oooooooooo`1Mooooo`002oooool4o`00
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2Xooooo`002oooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Z?ooool0
00cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo0:Sooooo000=ooooo`;o00001?ooool2o`0000CoooooX_l00009ooooo`006Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo05gooooo000Iooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool0GOooool001Wooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`1Mooooo`006Oooool00ol0003oooooooooo`2Xooooo`006Oooool00ol0003oooooooooo`2Xoooo
o`006Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05gooooo000<ooooo`?o0000
1?ooool2o`0000Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Mooooo`002ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo053ooooo1?l00009ooooo`002oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo04[ooooo1_l0000=ooooo`003?ooool3o`0000?ooooo00Co0000oooooooo
oooo00000oooool2o`0004Wooooo00?o0000ooooooooool0??ooool>o`0001?ooooo000;ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo087ooooo1_l0000Qooooo`002oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`1jooooo`Oo00009oooool000cooooo0ol00004
ooooo`;o00001?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02Sooooo1ol0000^
ooooo`006Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo027ooooo1ol0000eoooo
o`006Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01cooooo1Ol0000looooo`00
6Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Wooooo0ol00011ooooo`006Ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Cooooo1Ol00014ooooo`006Oooool0
0ol0003oooooooooo`1Iooooo`Ko0000BOooool001Wooooo00?o0000ooooooooool0E_ooool3o`00
04oooooo0006ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool01_ooool5o`0005;ooooo0007ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
04Sooooo00Co0000oooooooooooooooo1Ol0001Gooooo`001oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`18ooooo`Co0000G?ooool000Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo1?l00002ooooo`Go00000_ooool5o`0000;ooooo
1?l00003ooooo`Co00000oooool4o`0000;ooooo1Ol00002ooooo`Go00000_ooool4o`0000?ooooo
1?l00003ooooo`So0000Goooool000Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0@_ooool3o`0006?o
oooo0006ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0?_ooool4o`0006Kooooo0007ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`0kooooo`?o0000J_ooool001Wooooo
00?o0000ooooooooool0>?ooool3o`0006gooooo000Iooooo`03o`000?oooooooooo03Gooooo0ol0
001`ooooo`006Oooool00ol0003oooooooooo`0booooo`?o0000Loooool001Wooooo00?o0000oooo
ooooool0;oooool3o`0007Kooooo000Iooooo`03o`000?oooooooooo02gooooo0_l0001iooooo`00
6Oooool00ol0003oooooooooo`0Zooooo`?o0000Noooool000Kooooo0ol00002ooooo`Go00000ooo
ool2o`0000Cooooo00?o0000ooooooooool09oooool3o`0007kooooo0007ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo02Cooooo0ol00021ooooo`001oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Qooooo`?o0000
Q?ooool000Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooooooo0_l0000Pooooo`;o0000Qoooool000Oooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00000O
ooooo`;o0000ROooool000Kooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo01_ooooo0_l0002;ooooo`001oooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool06Oooool2
o`0008gooooo000Iooooo`03o`000?oooooooooo01Oooooo0_l0002?ooooo`006Oooool00ol0003o
ooooooooo`0Dooooo`?o0000TOooool001Wooooo00?o0000ooooooooool04_ooool2o`0009Cooooo
000Iooooo`03o`000?oooooooooo013ooooo0_l0002Fooooo`006Oooool00ol0003oooooooooo`0>
ooooo`;o0000V?ooool001Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Hoooo
o`001_ooool3o`0000Cooooo0ol00003ooooo`;o00001?ooool00ol0003oooooooooo`0;ooooo`;o
0000Voooool000Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`00000;ooooo`;o0000WOooool000Oooooo00Co0000oooooooo
oooooooo1Ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool2
o`0009oooooo0007ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooooooo0_l00007ooooo`03o`000?oooooooooo09oooooo
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Cooooo0_l0002Rooooo`001_ooool2o`0000Gooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool2o`000:Cooooo
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00Go
0000ooooooooooooooooo`00002Vooooo`006Oooool01?l0003oooooo`000?l0002Wooooo`006Ooo
ool2o`000:Wooooo000Iooooo`03o`000?oooooooooo0:Sooooo000Iooooo`03o`000?oooooooooo
0:Sooooo000Iooooo`03o`000?oooooooooo0:Sooooo000Iooooo`03o`000?oooooooooo0:Sooooo
0006ooooo`?o00000oooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo0:Sooooo0007
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooooooool00000Z_ooool000Oooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00002Zooooo`001oooool01?l0
003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00000oooool2o`000:Wooooo0007
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0002^ooooo`001_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0002^ooooo`001ooo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`000:oooooo0034ooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 273.688}, {456.25, 335.75}} -> {-9.56095, \
495.245, 0.0928125, 1.52558}}]
}, Open  ]],

Cell[TextData[StyleBox["Variable ambient temperature, no heat",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "The next example considers the case where the ambient temperature changes \
linearly. The solution formula  shows that the temperature of the immersed \
object also approaches a straight line (same slope). \n",
  StyleBox["Example. Overnight the temperature in the house dropped to",
    FontSlant->"Italic"],
  " 45",
  StyleBox[" degrees. At sunrise ",
    FontSlant->"Italic"],
  "(7 AM)",
  StyleBox[" the outdoor  temperature was also ",
    FontSlant->"Italic"],
  "45",
  StyleBox[" degrees and increased linearly to ",
    FontSlant->"Italic"],
  "75 ",
  StyleBox["degrees at ",
    FontSlant->"Italic"],
  "12 ",
  StyleBox["noon",
    FontSlant->"Italic"],
  ". ",
  StyleBox["What is the temperature  inside the house at ",
    FontSlant->"Italic"],
  "12",
  StyleBox[" noon if it had increased to",
    FontSlant->"Italic"],
  " 50 ",
  StyleBox["degrees at",
    FontSlant->"Italic"],
  " 9 AM? ",
  StyleBox["The furnace in the house is turned off. ",
    FontSlant->"Italic"],
  "\nTake 7 AM to be time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0. The ambient temperature is given by the function  "
}], "Text"],

Cell[TextData[{
  StyleBox["A",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = 45 + 6 ",
  StyleBox["t",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["t",
    FontSlant->"Italic"],
  " measured in hours. The temperature ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") inside the house at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " satisfies ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(0) = 45 and ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(2) = 50. Here is  the differential equation and the solution to the IVP,  \
",
  StyleBox["T",
    FontSlant->"Italic"],
  "(0) = 45. We first clear the ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "variable",
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Clear[k]
DEhouse = T'[t] == k*(45 + 6*t - T[t])
soln = DSolve[ {DEhouse, T[0]==45}, T, t ]\
\>", "Input",
  CellLabel->"In[151]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(k\ \((45 + 6\ t - T[t])\)\)}]], "Output",
  CellLabel->"Out[152]="],

Cell[BoxData[
    \({{T \[Rule] 
          Function[{t}, \(3\ \[ExponentialE]\^\(\(-k\)\ t\)\ \((2 - 2\ \
\[ExponentialE]\^\(k\ t\) + 15\ \[ExponentialE]\^\(k\ t\)\ k + 2\ \
\[ExponentialE]\^\(k\ t\)\ k\ t)\)\)\/k]}}\)], "Output",
  CellLabel->"Out[153]="]
}, Open  ]],

Cell["\<\
Name the solution function h and find the value of k as we did \
above. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
h := soln[[1,1,2]]
ksoln = Solve[ h[2]==50, k ]\
\>", "Input",
  CellLabel->"In[154]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{\(InverseFunction::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse \
functions are being used. Values may be lost for multivalued inverses. \\!\\(\
\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"InverseFunction::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[154]:="],

Cell[BoxData[
    RowBox[{\(Solve::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse functions are \
being used by \\!\\(Solve\\), so some solutions may not be found; use Reduce \
for complete solution information. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[154]:="],

Cell[BoxData[
    \({{k \[Rule] 
          1\/14\ \((12 + 
                7\ ProductLog[\(-\(12\/\(7\ \[ExponentialE]\^\(12/7\)\)\)\)])\
\)}}\)], "Output",
  CellLabel->"Out[155]="]
}, Open  ]],

Cell[TextData[{
  "Let's assign ",
  StyleBox["k",
    FontSlant->"Italic"],
  " the value found above, but in floating point form, and check that h(2) = \
50. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
k = N[ksoln[[1,1,2]] ]
h[2]\
\>", "Input",
  CellLabel->"In[156]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(0.5978788370634334`\)], "Output",
  CellLabel->"Out[156]="],

Cell[BoxData[
    \(49.99999999999999`\)], "Output",
  CellLabel->"Out[157]="]
}, Open  ]],

Cell[TextData[{
  "It would also be wise to verify that there is only one ",
  StyleBox["k",
    FontSlant->"Italic"],
  " value that works (see the warning above). ",
  "You are asked to do that in the  exercises. \nThe next plot shows the \
ambient temperature (dashed) and the house temperature from 7 AM to 12 noon. \
"
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ {45+6*t,h[t]}, {t,0,5}, PlotRange->{40,75},
      PlotStyle->{Dashing[{0.02,0.02}],Dashing[{0,0}]}]\
\>", "Input",
  CellLabel->"In[158]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 -0.706325 0.0176581 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .08829 -12 -4.5 ]
[.01131 .08829 0 4.5 ]
[.01131 .17658 -12 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -12 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -12 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -12 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -12 -4.5 ]
[.01131 .52974 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .08829 m
.03006 .08829 L
s
[(45)] .01131 .08829 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(50)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(55)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(60)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(65)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(70)] .01131 .52974 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(75)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01766 m
.02756 .01766 L
s
.02381 .03532 m
.02756 .03532 L
s
.02381 .05297 m
.02756 .05297 L
s
.02381 .07063 m
.02756 .07063 L
s
.02381 .10595 m
.02756 .10595 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14126 m
.02756 .14126 L
s
.02381 .15892 m
.02756 .15892 L
s
.02381 .19424 m
.02756 .19424 L
s
.02381 .2119 m
.02756 .2119 L
s
.02381 .22956 m
.02756 .22956 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .28253 m
.02756 .28253 L
s
.02381 .30019 m
.02756 .30019 L
s
.02381 .31785 m
.02756 .31785 L
s
.02381 .3355 m
.02756 .3355 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .38848 m
.02756 .38848 L
s
.02381 .40614 m
.02756 .40614 L
s
.02381 .42379 m
.02756 .42379 L
s
.02381 .45911 m
.02756 .45911 L
s
.02381 .47677 m
.02756 .47677 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .51209 m
.02756 .51209 L
s
.02381 .5474 m
.02756 .5474 L
s
.02381 .56506 m
.02756 .56506 L
s
.02381 .58272 m
.02756 .58272 L
s
.02381 .60038 m
.02756 .60038 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .08829 m
.06244 .10978 L
.10458 .13322 L
.14415 .15523 L
.18221 .1764 L
.22272 .19893 L
.26171 .22062 L
.30316 .24367 L
.34309 .26588 L
.3815 .28725 L
.42237 .30998 L
.46172 .33187 L
.49955 .35291 L
.53984 .37532 L
.57861 .39689 L
.61984 .41982 L
.65954 .44191 L
.69774 .46315 L
.73838 .48576 L
.77751 .50752 L
.81909 .53065 L
.85916 .55294 L
.89771 .57438 L
.93871 .59719 L
.97619 .61803 L
s
[ ] 0 setdash
.02381 .08829 m
.02499 .08829 L
.02605 .08829 L
.02729 .0883 L
.02846 .08831 L
.03053 .08833 L
.03279 .08836 L
.03527 .0884 L
.0379 .08846 L
.04262 .08859 L
.05205 .08897 L
.06244 .08954 L
.07293 .09029 L
.0842 .09128 L
.10458 .09353 L
.1458 .09977 L
.18551 .1077 L
.22371 .11689 L
.26435 .12817 L
.30348 .14031 L
.34506 .15442 L
.38513 .16907 L
.42368 .18401 L
.46468 .20072 L
.50417 .21751 L
.54214 .23422 L
.58257 .25256 L
.62148 .27067 L
.66284 .29037 L
.70268 .30973 L
.74101 .32867 L
.78179 .34911 L
.82106 .36905 L
.85881 .38842 L
.89901 .40926 L
.9377 .42948 L
.97619 .44974 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[158]:=",
  ImageSize->{222.875, 137.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003N0000RB000`400?l00000o`00003og_ooool0
03Wooooo0ol0000Rooooo`Go00008Oooool3o`0002?ooooo0ol0000Qooooo`?o00003Oooool003[o
oooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0000Pooooo`05o`000?oooooooooo
ooooool000008oooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool000003?oo
ool003[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01kooooo1Ol0000Tooooo`03o`000?oooooooooo00[ooooo000jooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool08Oooool2o`00027ooooo00Co0000oooooooooooo00009Oooool0
0ol0003oooooooooo`0:ooooo`00>_ooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool000009?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo0000027ooooo1?l0000=
ooooo`00>Oooool2o`0002?ooooo00Go0000ooooooooooooooooo`00000Pooooo`05o`000?oooooo
ooooooooool000008_ooool2o`00027ooooo00?o0000ooooooooool03_ooool003[ooooo00?o0000
ooooooooool08_ooool3o`0002;ooooo0ol0000Tooooo`03o`000?oooooooooo01oooooo1Ol0000<
ooooo`00g_ooool00=kooooo003Nooooo`004_ooooo4o`0000Sooooo000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02oooool001Kooooo00?o0000ooooooooool0aOooool001Ko
oooo00?o0000ooooooooool0aOooool001Kooooo0_l00036ooooo`005_ooool00ol0003ooooooooo
o`35ooooo`005_ooool00ol0003oooooooooo`35ooooo`005_ooool2o`000<Kooooo000Fooooo`03
o`000?oooooooooo0<Gooooo000Fooooo`03o`000?oooooooooo0<Gooooo000Fooooo`03o`000?oo
oooooooo0<Gooooo000Fooooo`;o0000a_ooool001Kooooo00?o0000ooooooooool0aOooool001Ko
oooo00?o0000ooooooooool0aOooool001Kooooo0_l00036ooooo`002_ooool3o`0000;ooooo0ol0
0004ooooo`03o`000?oooooooooo0<Gooooo000;ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000037ooooo`002?ooool5o`0000Gooooo00Co0000oooooooooooooooo
1?l00034ooooo`002?ooool01?l0003oooooooooool00006ooooo`06o`000?ooooooooooooooool0
003ooooo4Ol0002eooooo`002Oooool00ol0003oooooo`000002ooooo`Co00001?ooool01Ol0003o
oooooooooooooooo000000kooooo1?l0002aooooo`002_ooool2o`0000;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Dooooo`Ko0000Zoooool000_ooooo00?o0000ooooooooool0
1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0Cooooo`Ko0000YOooool001Kooooo00?o
0000ooooooooool01Oooool2o`0001Wooooo0ol0002Rooooo`005_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Wooooo1?l0002Nooooo`005_ooool2o`0002Sooooo1?l0002Joooo
o`005_ooool00ol0003oooooooooo`0;ooooo`;o00007_ooool3o`0009Oooooo000Fooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool07_ooool3o`0009Cooooo000Fooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool08?ooool3o`00097ooooo000Fooooo`;o0000=Oooool3
o`0008kooooo000Fooooo`03o`000?oooooooooo01;ooooo0_l0000Sooooo`Co0000R_ooool001Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Tooooo`?o0000Qoooool001Kooooo
0_l0000Fooooo`03o`000?oooooooooo02Kooooo0ol00024ooooo`002Oooool3o`0000Cooooo0_l0
0004ooooo`03o`000?oooooooooo047ooooo0ol00021ooooo`002?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Iooooo`;o0000
:Oooool2o`0007oooooo000<ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`00000Mooooo`03o`000?oooooooooo02Sooooo0ol0001looooo`003?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooooooo`;o00007Oooool00ol0003oooooooooo`0Zoooo
o`;o0000N_ooool000Sooooo1?l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool07oooool2o`0002[ooooo0_l0001hooooo`002?ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool08Oooool2o`0002[ooooo0ol0001eoooo
o`002?ooool5o`0000?ooooo0_l00004ooooo`;o00009?ooool00ol0003oooooooooo`0Zooooo`?o
0000L_ooool001Kooooo00?o0000ooooooooool0Doooool2o`00073ooooo000Fooooo`03o`000?oo
oooooooo02Kooooo0_l0000]ooooo`;o0000K_ooool001Kooooo00?o0000ooooooooool0:?ooool2
o`0002gooooo0_l0001/ooooo`005_ooool2o`0002_ooooo00?o0000ooooooooool0;?ooool2o`00
06[ooooo000Fooooo`03o`000?oooooooooo05_ooooo0_l0001Xooooo`005_ooool00ol0003ooooo
ooooo`0]ooooo`;o0000;_ooool3o`0006Gooooo000Fooooo`;o0000<?ooool00ol0003ooooooooo
o`0^ooooo`?o0000H_ooool001Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`
ooooo`;o0000H?ooool001Kooooo00?o0000ooooooooool0IOooool2o`0005kooooo000Fooooo`03
o`000?oooooooooo03Cooooo0_l0000aooooo`03o`000?oooooooooo05_ooooo0009ooooo`?o0000
0oooool3o`0000Cooooo0_l0000gooooo`03o`000?oooooooooo02oooooo0_l0001Kooooo`002?oo
ool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003ooooooooooooooooo0000
03Wooooo00?o0000ooooooooool0<?ooool2o`0005Wooooo000<ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00001^ooooo`?o0000E_ooool000cooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooooooool2o`0003cooooo0_l0000booooo`?o0000Doooool000So
oooo1?l00002ooooo`Co00001?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03;o
oooo0_l0001Aooooo`002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0cooooo`;o0000Coooool000Sooooo1Ol0
00000ooooooo0000o`000003o`0000?ooooo0_l0001gooooo`;o0000COooool001Kooooo00?o0000
ooooooooool0@_ooool3o`0003?ooooo0_l0001;ooooo`005_ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo03;ooooo0_l00019ooooo`005_ooool00ol0003oooooooooo`1looooo`;o
0000Aoooool001Kooooo0_l00019ooooo`;o0000=?ooool2o`0004Gooooo000Fooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0<oooool2o`0004?ooooo000Fooooo`03o`000?oooooo
oooo04_ooooo0_l0000eooooo`;o0000@Oooool001Kooooo0_l00025ooooo`?o0000?_ooool001Ko
oooo00?o0000ooooooooool0Coooool2o`0003Kooooo0_l0000looooo`005_ooool00ol0003ooooo
ooooo`1Aooooo`;o0000=_ooool2o`0003[ooooo000Fooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0=Oooool2o`0003Sooooo000Fooooo`;o0000S_ooool2o`0003Kooooo0009oooo
o`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool0E_ooool2o`0003Oooooo0_l0000doooo
o`002?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo03Kooooo0_l0000booooo`002?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool2o`0005[ooooo00?o
0000ooooooooool0=oooool2o`00033ooooo0008ooooo`Co00000oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo09Gooooo0_l0000^ooooo`002?ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0GOooool2o`0003Sooooo0_l0
000/ooooo`002Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`0gooooo`;o0000:_ooool000[ooooo0_l00004
ooooo`;o00001?ooool2o`00067ooooo00?o0000ooooooooool0>?ooool2o`0002Sooooo000Foooo
o`03o`000?oooooooooo06Cooooo0_l0000gooooo`03o`000?oooooooooo02Gooooo000Fooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooooooool0=Oooool2o`0002Gooooo000Fooooo`;o0000
J?ooool00ol0003oooooooooo`0fooooo`;o00008oooool001Kooooo00?o0000ooooooooool0X_oo
ool2o`00027ooooo000Fooooo`03o`000?oooooooooo06_ooooo0_l0000gooooo`;o00007oooool0
01Kooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0fooooo`;o00007Oooool001Ko
oooo0_l0001_ooooo`03o`000?oooooooooo03Oooooo0_l0000Kooooo`005_ooool00ol0003ooooo
ooooo`2Zooooo`;o00006Oooool001Kooooo00?o0000ooooooooool0LOooool3o`0003Sooooo0_l0
000Gooooo`005_ooool2o`0007Gooooo00?o0000ooooooooool0=oooool2o`0001Gooooo0009oooo
o`?o00000oooool3o`0000Cooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0hoooo
o`;o00004oooool000Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Go0000
ooooooooooooooooo`00002dooooo`;o00004Oooool000Sooooo00Go0000ooooooooooooooooo`00
0005ooooo`04o`000?ooooooooooooooo`;o0000NOooool2o`0003[ooooo00?o0000ooooooooool0
3_ooool000Sooooo1?l00006ooooo`05o`000?ooooooooooooooool00000O?ooool2o`0003Wooooo
0_l0000>ooooo`002?ooool00ol0003oooooooooo`03ooooo`Co00001?ooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool000Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0<Gooooo000:oooo
o`;o00000_ooool5o`0000?ooooo0_l00020ooooo`;o0000A?ooool001Kooooo00?o0000oooooooo
ool0POooool00ol0003oooooooooo`11ooooo`005_ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo043ooooo000Fooooo`;o0000a_ooool001Kooooo00?o0000ooooooooool0Q_ooool3
o`0003cooooo000Fooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0>Oooool001Ko
oooo00?o0000ooooooooool0aOooool001Kooooo0_l0002>ooooo`;o0000=_ooool001Kooooo00?o
0000ooooooooool0Soooool00ol0003oooooooooo`0cooooo`005_ooool00ol0003oooooooooo`2@
ooooo`03o`000?oooooooooo03;ooooo000Fooooo`;o0000a_ooool000[ooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo00?o0000ooooooooool0U?ooool2o`0002oooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2Fooooo`03
o`000?oooooooooo02cooooo000;ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000009Wooooo00?o0000ooooooooool0:oooool000_ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooooooo`;o0000a_ooool000cooooo00Co0000oooo
oooooooo00000_ooool01Ol0003ooooooooooooooooo000009cooooo0_l0000Yooooo`002?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`2Looooo`;o00009oooool000Sooooo1Ol00003ooooo`;o00001?ooool2o`0009oooooo00?o
0000ooooooooool09?ooool001Kooooo00?o0000ooooooooool0aOooool001Kooooo00?o0000oooo
ooooool0XOooool2o`0002;ooooo000Fooooo`03o`000?oooooooooo0:?ooooo0_l0000Pooooo`00
5_ooool2o`000:Kooooo00?o0000ooooooooool07Oooool001Kooooo00?o0000ooooooooool0aOoo
ool001Kooooo00?o0000ooooooooool0Z?ooool3o`0001[ooooo000Fooooo`;o0000[?ooool00ol0
003oooooooooo`0Gooooo`005_ooool00ol0003oooooooooo`35ooooo`005_ooool00ol0003ooooo
ooooo`2_ooooo`03o`000?oooooooooo01?ooooo000Fooooo`03o`000?oooooooooo0;3ooooo0_l0
000Cooooo`002_ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`000;?ooooo00?o0000
ooooooooool04?ooool000[ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000aoooool000_ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo00000;Sooooo00?o0000ooooooooool03?ooool000_ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooooooool2o`000;Sooooo00?o0000ooooooooool02oooool000cooooo00?o0000
ooooool000000ol0003<ooooo`002?ooool01ol0003ooooooooooooooooo0000ooooool00000cooo
ool000Sooooo1Ol000000ooooooo0000o`000003o`000<_ooooo003Nooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 299.75}, {653.688, 516.938}} -> {-2.70269, \
186.452, 0.0268586, 0.28972}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[158]="]
}, Open  ]],

Cell["The temperature inside the house at noon is 65.5 degrees.", "Text"],

Cell[CellGroupData[{

Cell["h[5]", "Input",
  CellLabel->"In[113]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(65.46948615364798`\)], "Output",
  CellLabel->"Out[113]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Variable ambient temperature, variable heat",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell["\<\
Finally, suppose the same house, on the same day, has a furnace \
that cycles on and off providing just enough heat to cause the temperature to \
increase at the rate of 6 degrees per hour at its peak output. It cycles on \
and  off sinusoidally over a 2 hour period:\
\>", "Text"],

Cell[TextData[{
  StyleBox["H",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = 3 - 3 cos",
  Cell[BoxData[
      \(TraditionalForm\`\((\(2  \[Pi]\ t\)\/2)\)\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
H[t_] := 3 - 3*Cos[2*Pi*t/2]
Plot[ H[t], {t,0,5}, AspectRatio->1/3 ]\
\>", "Input",
  CellLabel->"In[116]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.00793651 0.0529101 [
[.21429 -0.00456 -3 -9 ]
[.21429 -0.00456 3 0 ]
[.40476 -0.00456 -3 -9 ]
[.40476 -0.00456 3 0 ]
[.59524 -0.00456 -3 -9 ]
[.59524 -0.00456 3 0 ]
[.78571 -0.00456 -3 -9 ]
[.78571 -0.00456 3 0 ]
[.97619 -0.00456 -3 -9 ]
[.97619 -0.00456 3 0 ]
[.01131 .06085 -6 -4.5 ]
[.01131 .06085 0 4.5 ]
[.01131 .11376 -6 -4.5 ]
[.01131 .11376 0 4.5 ]
[.01131 .16667 -6 -4.5 ]
[.01131 .16667 0 4.5 ]
[.01131 .21958 -6 -4.5 ]
[.01131 .21958 0 4.5 ]
[.01131 .27249 -6 -4.5 ]
[.01131 .27249 0 4.5 ]
[.01131 .3254 -6 -4.5 ]
[.01131 .3254 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .00794 m
.21429 .01419 L
s
[(1)] .21429 -0.00456 0 1 Mshowa
.40476 .00794 m
.40476 .01419 L
s
[(2)] .40476 -0.00456 0 1 Mshowa
.59524 .00794 m
.59524 .01419 L
s
[(3)] .59524 -0.00456 0 1 Mshowa
.78571 .00794 m
.78571 .01419 L
s
[(4)] .78571 -0.00456 0 1 Mshowa
.97619 .00794 m
.97619 .01419 L
s
[(5)] .97619 -0.00456 0 1 Mshowa
.125 Mabswid
.0619 .00794 m
.0619 .01169 L
s
.1 .00794 m
.1 .01169 L
s
.1381 .00794 m
.1381 .01169 L
s
.17619 .00794 m
.17619 .01169 L
s
.25238 .00794 m
.25238 .01169 L
s
.29048 .00794 m
.29048 .01169 L
s
.32857 .00794 m
.32857 .01169 L
s
.36667 .00794 m
.36667 .01169 L
s
.44286 .00794 m
.44286 .01169 L
s
.48095 .00794 m
.48095 .01169 L
s
.51905 .00794 m
.51905 .01169 L
s
.55714 .00794 m
.55714 .01169 L
s
.63333 .00794 m
.63333 .01169 L
s
.67143 .00794 m
.67143 .01169 L
s
.70952 .00794 m
.70952 .01169 L
s
.74762 .00794 m
.74762 .01169 L
s
.82381 .00794 m
.82381 .01169 L
s
.8619 .00794 m
.8619 .01169 L
s
.9 .00794 m
.9 .01169 L
s
.9381 .00794 m
.9381 .01169 L
s
.25 Mabswid
0 .00794 m
1 .00794 L
s
.02381 .06085 m
.03006 .06085 L
s
[(1)] .01131 .06085 1 0 Mshowa
.02381 .11376 m
.03006 .11376 L
s
[(2)] .01131 .11376 1 0 Mshowa
.02381 .16667 m
.03006 .16667 L
s
[(3)] .01131 .16667 1 0 Mshowa
.02381 .21958 m
.03006 .21958 L
s
[(4)] .01131 .21958 1 0 Mshowa
.02381 .27249 m
.03006 .27249 L
s
[(5)] .01131 .27249 1 0 Mshowa
.02381 .3254 m
.03006 .3254 L
s
[(6)] .01131 .3254 1 0 Mshowa
.125 Mabswid
.02381 .01852 m
.02756 .01852 L
s
.02381 .0291 m
.02756 .0291 L
s
.02381 .03968 m
.02756 .03968 L
s
.02381 .05026 m
.02756 .05026 L
s
.02381 .07143 m
.02756 .07143 L
s
.02381 .08201 m
.02756 .08201 L
s
.02381 .09259 m
.02756 .09259 L
s
.02381 .10317 m
.02756 .10317 L
s
.02381 .12434 m
.02756 .12434 L
s
.02381 .13492 m
.02756 .13492 L
s
.02381 .1455 m
.02756 .1455 L
s
.02381 .15608 m
.02756 .15608 L
s
.02381 .17725 m
.02756 .17725 L
s
.02381 .18783 m
.02756 .18783 L
s
.02381 .19841 m
.02756 .19841 L
s
.02381 .20899 m
.02756 .20899 L
s
.02381 .23016 m
.02756 .23016 L
s
.02381 .24074 m
.02756 .24074 L
s
.02381 .25132 m
.02756 .25132 L
s
.02381 .2619 m
.02756 .2619 L
s
.02381 .28307 m
.02756 .28307 L
s
.02381 .29365 m
.02756 .29365 L
s
.02381 .30423 m
.02756 .30423 L
s
.02381 .31481 m
.02756 .31481 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.02381 .00794 m
.02499 .00797 L
.02605 .00805 L
.02729 .0082 L
.02846 .0084 L
.03053 .00891 L
.03279 .00967 L
.03527 .01076 L
.0379 .0122 L
.04262 .01551 L
.05205 .02485 L
.06244 .03909 L
.0842 .08038 L
.10458 .12915 L
.14335 .2286 L
.16306 .27204 L
.17348 .29078 L
.18458 .30672 L
.19014 .31297 L
.19538 .31774 L
.20008 .32106 L
.20251 .32241 L
.20517 .32361 L
.20638 .32405 L
.20767 .32445 L
.20879 .32475 L
.21001 .325 L
.21072 .32512 L
.21138 .32521 L
.21268 .32534 L
.21387 .32539 L
.21512 .32538 L
.2162 .32532 L
.21737 .32519 L
.21847 .32502 L
.21948 .32482 L
.22182 .32417 L
.22428 .32324 L
.22929 .32056 L
.23383 .31722 L
.24403 .30668 L
.25347 .29338 L
.26239 .278 L
.30086 .18927 L
.32034 .13849 L
.34178 .08615 L
.35159 .06516 L
.36214 .04558 L
.37202 .03053 L
.38118 .01979 L
Mistroke
.38609 .01541 L
.39131 .01183 L
.3943 .01029 L
.39711 .0092 L
.39834 .00883 L
.39963 .0085 L
.40031 .00836 L
.40105 .00823 L
.40236 .00806 L
.403 .008 L
.40371 .00796 L
.40499 .00794 L
.40623 .00798 L
.40738 .00808 L
.40862 .00826 L
.40999 .00853 L
.41142 .00889 L
.41276 .00932 L
.41743 .01139 L
.42005 .01296 L
.42246 .01465 L
.43229 .02401 L
.44142 .03608 L
.46213 .07385 L
.50123 .16989 L
.52118 .221 L
.54278 .2696 L
.55291 .28826 L
.56362 .3043 L
.57277 .31462 L
.57796 .319 L
.58282 .32208 L
.58541 .32332 L
.58781 .32421 L
.58917 .3246 L
.59045 .3249 L
.59178 .32514 L
.59249 .32523 L
.59325 .32531 L
.59445 .32538 L
.59576 .32539 L
.59642 .32537 L
.59713 .32532 L
.59841 .32518 L
.59968 .32497 L
.60089 .32471 L
.60314 .32405 L
.60539 .32318 L
.60777 .32202 L
.61204 .31934 L
Mistroke
.61663 .31562 L
.62169 .31053 L
.63184 .29734 L
.64112 .28208 L
.662 .23851 L
.70173 .13738 L
.72177 .08832 L
.73994 .05106 L
.7494 .03557 L
.75963 .0224 L
.76526 .01689 L
.77043 .01295 L
.77538 .01024 L
.77787 .00926 L
.77929 .00883 L
.78061 .0085 L
.78183 .00826 L
.78312 .00808 L
.78442 .00797 L
.78516 .00794 L
.78585 .00794 L
.7871 .00798 L
.78824 .00807 L
.7895 .00825 L
.79082 .0085 L
.79313 .00912 L
.79527 .0099 L
.80013 .0124 L
.80543 .01626 L
.81025 .02075 L
.82105 .03414 L
.84025 .06793 L
.86105 .1155 L
.90199 .22065 L
.92236 .26685 L
.93232 .28563 L
.94141 .29999 L
.95002 .31084 L
.95818 .31845 L
.96266 .32146 L
.9668 .3235 L
.96919 .32434 L
.97135 .32489 L
.97255 .32511 L
.97384 .32528 L
.97507 .32537 L
.97619 .3254 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[116]:=",
  ImageSize->{252, 83.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003l0000Db000`400?l00000o`00003oo?ooool0
047ooooo0ol0000Tooooo`Go00009?ooool3o`0002Kooooo0ol0000Tooooo`?o00006?ooool004;o
oooo00?o0000ooooooooool09?ooool01?l0003oooooooooool0000Sooooo`05o`000?oooooooooo
ooooool000009_ooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000005ooo
ool004;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo027ooooo1Ol0000Wooooo`03o`000?oooooooooo01Gooooo0012ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09?ooool2o`0002Cooooo00Co0000oooooooooooo0000:?ooool0
0ol0003oooooooooo`0Eooooo`00@_ooool00ol0003oooooooooo`0Sooooo`05o`000?oooooooooo
ooooool000009oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo000002Cooooo1?l0000H
ooooo`00@Oooool2o`0002Gooooo00Go0000ooooooooooooooooo`00000Sooooo`05o`000?oooooo
ooooooooool000009Oooool2o`0002Cooooo00?o0000ooooooooool06Oooool004;ooooo00?o0000
ooooooooool09?ooool3o`0002Gooooo0ol0000Wooooo`03o`000?oooooooooo02;ooooo1Ol0000G
ooooo`00o?ooool00?cooooo000Kooooo`03o`000?oooooooooo0=kooooo000Fooooom?o00004ooo
ool001_ooooo1?l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_l00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool3o`000003ooooool0
003o000000;o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo000K
ooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`0Qooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000oooooooo
ool05_ooool001_ooooo0_l00003ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
>Oooool001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03Wooooo000Kooooo`;o00001?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03Sooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0gooooo`006oooool2o`0000Kooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0gooooo`006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0=_ooool001?ooooo0ol00005ooooo`;o00001oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03Kooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Gooooo000Doooo
o`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0=?ooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0=?ooool001Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
<oooool001?ooooo0_l00006ooooo`;o00002_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo03?ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03;ooooo000Kooooo`;o00002oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo03;ooooo000Kooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0aooooo`006oooool2o`0000cooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0aooooo`006oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<?ooool001;ooooo1Ol00004
ooooo`;o00003?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo033ooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02oooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02oooooo000Eooooo`03
o`000?oooooooooo00?ooooo0_l0000>ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0;_ooool001;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0^ooooo`004_ooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l0000>ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0;Oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0]ooooo`006oooool2o`0000oooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0]ooooo`006oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0;?ooool001_ooooo0_l0000@ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0;?ooool001_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo02cooooo000Cooooo`?o00001Oooool2o`00017ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0[ooooo`004_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo02_ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02_ooooo000Dooooo`;o00001Oooool2
o`0001;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Zooooo`005_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Zooooo`004_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000Coooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:Oooool001?ooooo0ol00005ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Yooooo`00
6oooool2o`0001?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`006ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?oo
ool001_ooooo0_l0000Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
02Sooooo000Dooooo`?o00001?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool09oooool001Gooooo00?o0000ooooooooool00oooool2o`0001Gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Wooooo`004_ooool5o`0000Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02Oooooo000B
ooooo`04o`000?ooooooooooo`0000Gooooo0_l0000Fooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool09_ooool001?ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool001Cooooo0_l00005oooo
o`;o00005oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Gooooo000Eooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo02Gooooo000Kooooo`;o00006?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02Gooooo000Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Tooooo`006oooool2o`0001Wooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Tooooo`006oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool08oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Sooooo`004_ooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l0000Jooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool08oooool001Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool08_ooool001Kooooo00?o0000ooooooooool00_oo
ool2o`0001_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Rooooo`004_ooool4
o`0000Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo027ooooo000Booooo`03o`000?oooooooooo00Kooooo0_l0000Looooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool08?ooool001;ooooo1Ol00004ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Oooooo`006oooool2o`0001gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Oooooo`006oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07_ooool001_ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo000Koooo
o`;o00008?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo000Cooooo`?o
00001Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool07?ooool001;ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00008_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo01_ooooo000Booooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0A_ooool2o`0000Cooooo0_l00018ooooo`;o00006oooool001;ooooo1?l00005ooooo`;o0000
9?ooool5o`0004_ooooo1Ol0001;ooooo`?o00006?ooool001;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3Nooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0=kooooo000Dooooo`;o0000i_ooool00?cooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 328.875}, {316.812, 234.062}} -> {-2.63284, \
20.0318, 0.0250153, 0.0900549}}]
}, Open  ]],

Cell[TextData[{
  "We assume that the value of ",
  StyleBox["k",
    FontSlant->"Italic"],
  " stays about the same,  ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 0.6. The number is entered exactly (no decimal) in order to have a nice \
looking solution formula."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
k = 6/10;
DEheatedhouse = T'[t] == k*(45+6*t-T[t])+H[t]
soln = DSolve[ {DEheatedhouse, T[0]==45}, T, t]\
\>", "Input",
  CellLabel->"In[135]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(3 - 3\ Cos[\[Pi]\ t] + 
        3\/5\ \((45 + 6\ t - T[t])\)\)}]], "Output",
  CellLabel->"Out[136]="],

Cell[BoxData[
    \({{T \[Rule] 
          Function[{t}, \(\(1\/\(9 + 
                  25\ \[Pi]\^2\)\)\((\[ExponentialE]\^\(\(\(-3\)\ t\)/5\)\ \
\((90 + 360\ \[ExponentialE]\^\(\(3\ t\)/5\) + 125\ \[Pi]\^2 + 
                    1000\ \[ExponentialE]\^\(\(3\ t\)/5\)\ \[Pi]\^2 + 
                    54\ \[ExponentialE]\^\(\(3\ t\)/5\)\ t + 
                    150\ \[ExponentialE]\^\(\(3\ t\)/5\)\ \[Pi]\^2\ t - 
                    45\ \[ExponentialE]\^\(\(3\ t\)/5\)\ Cos[\[Pi]\ t] - 
                    75\ \[ExponentialE]\^\(\(3\ t\)/5\)\ \[Pi]\ Sin[\[Pi]\ \
t])\))\)\)]}}\)], "Output",
  CellLabel->"Out[137]="]
}, Open  ]],

Cell["\<\
The next input defined the solution function as HH and displays a \
simplified formula. \
\>", "Text"],

Cell["\<\
Note that Simplify is applied to N[...] by entering \
N[...]//Simplify.\
\>", "Note"],

Cell[CellGroupData[{

Cell["\<\
HH := soln[[1,1,2]]
N[HH[t],3]//Simplify\
\>", "Input",
  CellLabel->"In[140]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(39.9999999999995794953`2.9999999999999973 + 
      5.175959883630277911`2.9999999999999973\ \
\[ExponentialE]\^\(\(-0.5999999999999999806`2.698970004336016\)\ t\) + 
      5.9999999999995727567`2.9999999999999973\ t - 
      0.1759598836303304741`2.9999999999999973\ Cos[
          3.1415926535897932385`3.0000000000000018\ t] - 
      0.9213237962326018914`2.9999999999999973\ Sin[
          3.1415926535897932385`3.0000000000000018\ t]\)], "Output",
  CellLabel->"Out[141]="]
}, Open  ]],

Cell["\<\
The solution has an exponentially decaying term, a linear term \
increasing at the same rate as the ambient  temperature, and a sinusiodal \
component that oscillates with the same period as the furnace. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ {45+6*t,HH[t]}, {t,0,5}, PlotRange->{40,75},
      PlotStyle->{Dashing[{0.02,0.02}],Dashing[{0,0}]}]\
\>", "Input",
  CellLabel->"In[144]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 -0.706325 0.0176581 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .08829 -12 -4.5 ]
[.01131 .08829 0 4.5 ]
[.01131 .17658 -12 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -12 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -12 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -12 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -12 -4.5 ]
[.01131 .52974 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .08829 m
.03006 .08829 L
s
[(45)] .01131 .08829 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(50)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(55)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(60)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(65)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(70)] .01131 .52974 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(75)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01766 m
.02756 .01766 L
s
.02381 .03532 m
.02756 .03532 L
s
.02381 .05297 m
.02756 .05297 L
s
.02381 .07063 m
.02756 .07063 L
s
.02381 .10595 m
.02756 .10595 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14126 m
.02756 .14126 L
s
.02381 .15892 m
.02756 .15892 L
s
.02381 .19424 m
.02756 .19424 L
s
.02381 .2119 m
.02756 .2119 L
s
.02381 .22956 m
.02756 .22956 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .28253 m
.02756 .28253 L
s
.02381 .30019 m
.02756 .30019 L
s
.02381 .31785 m
.02756 .31785 L
s
.02381 .3355 m
.02756 .3355 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .38848 m
.02756 .38848 L
s
.02381 .40614 m
.02756 .40614 L
s
.02381 .42379 m
.02756 .42379 L
s
.02381 .45911 m
.02756 .45911 L
s
.02381 .47677 m
.02756 .47677 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .51209 m
.02756 .51209 L
s
.02381 .5474 m
.02756 .5474 L
s
.02381 .56506 m
.02756 .56506 L
s
.02381 .58272 m
.02756 .58272 L
s
.02381 .60038 m
.02756 .60038 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .08829 m
.06244 .10978 L
.10458 .13322 L
.14415 .15523 L
.18221 .1764 L
.22272 .19893 L
.26171 .22062 L
.30316 .24367 L
.34309 .26588 L
.3815 .28725 L
.42237 .30998 L
.46172 .33187 L
.49955 .35291 L
.53984 .37532 L
.57861 .39689 L
.61984 .41982 L
.65954 .44191 L
.69774 .46315 L
.73838 .48576 L
.77751 .50752 L
.81909 .53065 L
.85916 .55294 L
.89771 .57438 L
.93871 .59719 L
.97619 .61803 L
s
[ ] 0 setdash
.02381 .08829 m
.02499 .08829 L
.02605 .0883 L
.02729 .0883 L
.02846 .08831 L
.02954 .08832 L
.03053 .08833 L
.03279 .08837 L
.03506 .08842 L
.03756 .08849 L
.04262 .08868 L
.04755 .08894 L
.05285 .08931 L
.06244 .09024 L
.06784 .09093 L
.07373 .09182 L
.08445 .09387 L
.10458 .09925 L
.12425 .10654 L
.14523 .11641 L
.18681 .14103 L
.22687 .16755 L
.26542 .19131 L
.28497 .20159 L
.30643 .21113 L
.34592 .22397 L
.36543 .22853 L
.38634 .23273 L
.40615 .2366 L
.4277 .24137 L
.46755 .25383 L
.48732 .26248 L
.50833 .27368 L
.54608 .29849 L
.58628 .32908 L
.62497 .35854 L
.66611 .38554 L
.68664 .39645 L
.70573 .40496 L
.74384 .41793 L
.78289 .42824 L
.8028 .43365 L
.82438 .44046 L
.86437 .45751 L
.90529 .48223 L
.94469 .51187 L
.97619 .5374 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[144]:=",
  ImageSize->{227, 140.188},
  ImageMargins->{{0, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003S0000S2000`400?l00000o`00003ohoooool0
03[ooooo0ol0000Rooooo`Go00008_ooool3o`0002Cooooo0ol0000Rooooo`?o00003_ooool003_o
oooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0000Qooooo`05o`000?oooooooooo
ooooool000009?ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000003Ooo
ool003_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01oooooo1Ol0000Uooooo`03o`000?oooooooooo00_ooooo000kooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool08_ooool2o`0002;ooooo00Co0000oooooooooooo00009_ooool0
0ol0003oooooooooo`0;ooooo`00>oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool000009Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo000002;ooooo1?l0000>
ooooo`00>_ooool2o`0002?ooooo00Go0000ooooooooooooooooo`00000Qooooo`05o`000?oooooo
ooooooooool000008oooool2o`0002;ooooo00?o0000ooooooooool03oooool003_ooooo00?o0000
ooooooooool08_ooool3o`0002?ooooo0ol0000Uooooo`03o`000?oooooooooo023ooooo1Ol0000=
ooooo`00hoooool00>?ooooo003Sooooo`00hoooool001;ooooob?l00009ooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo000Fooooo`03o`000?oooooooooo0<[o
oooo000Fooooo`;o0000boooool001Kooooo00?o0000ooooooooool0b_ooool001Kooooo00?o0000
ooooooooool0b_ooool001Kooooo00?o0000ooooooooool0b_ooool001Kooooo0_l0003;ooooo`00
5_ooool00ol0003oooooooooo`3:ooooo`005_ooool00ol0003oooooooooo`3:ooooo`005_ooool2
o`000<_ooooo000Fooooo`03o`000?oooooooooo0<[ooooo000Fooooo`03o`000?oooooooooo0<[o
oooo000Fooooo`03o`000?oooooooooo0<[ooooo000Fooooo`;o0000boooool000[ooooo0ol00002
ooooo`?o00001?ooool00ol0003oooooooooo`3:ooooo`002oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool00000c?ooool000Sooooo1Ol00005ooooo`04o`000?oooooo
ooooooooo`Go0000b?ooool000Sooooo00Co0000oooooooooooo00001_ooool01_l0003ooooooooo
oooooooo0000ooooo`;o000000?oooooo`000?l000001_l00030ooooo`002Oooool00ol0003ooooo
o`000002ooooo`Co00001?ooool01Ol0003ooooooooooooooooo000000Sooooo0ol0002mooooo`00
2_ooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`Co0000
^Oooool000_ooooo00?o0000ooooooooool01Ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`0:ooooo`;o0000]oooool001Kooooo00?o0000ooooooooool01Oooool3o`0000_ooooo0ol0002d
ooooo`005_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0_l0002boooo
o`005_ooool2o`0001Wooooo00?o0000ooooooooool0[oooool001Kooooo00?o0000ooooooooool0
2oooool3o`0000_ooooo0_l0002_ooooo`005_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00[ooooo0_l0002]ooooo`005_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0Z_ooool001Kooooo0_l0000Oooooo`;o0000Z_ooool001Ko
oooo00?o0000ooooooooool04_ooool2o`0000cooooo00?o0000ooooooooool0Yoooool001Kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`;o0000Yoooool001Kooooo0_l0
000Fooooo`;o00003?ooool2o`000:Gooooo000Fooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0X_ooool000Wooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`0Ioooo
o`;o00002oooool2o`000:;ooooo0008ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo01_ooooo0_l0000;ooooo`03o`000?oooooo
oooo09oooooo000<ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0ol0
000Mooooo`03o`000?oooooooooo00Wooooo0_l0002Oooooo`003?ooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool00000;Oooool2o`0009gooooo0008ooooo`Co00000ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo023ooooo0_l0000;ooooo`03o`00
0?oooooooooo09[ooooo0008ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0Rooooo`;o00002_ooool2o`0009[ooooo0008ooooo`Go00000ooo
ool2o`0000Cooooo0_l0000Uooooo`03o`000?oooooooooo00Wooooo0_l0002Hooooo`005_ooool0
0ol0003oooooooooo`0booooo`;o0000U_ooool001Kooooo00?o0000ooooooooool09oooool2o`00
00_ooooo0_l0002Dooooo`005_ooool2o`0002[ooooo0_l0000;ooooo`?o0000TOooool001Kooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`Co0000SOooool001Kooooo00?o
0000ooooooooool0?Oooool4o`0008Wooooo000Fooooo`03o`000?oooooooooo02kooooo0ol0000@
ooooo`Co0000QOooool001Kooooo0_l0000booooo`;o00004_ooool4o`00087ooooo000Fooooo`03
o`000?oooooooooo04Wooooo1?l0001mooooo`005_ooool00ol0003oooooooooo`0eooooo`;o0000
5_ooool4o`0007Wooooo000Fooooo`;o0000>?ooool2o`0001Sooooo1?l0001eooooo`002Oooool3
o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06Oooool3
o`0007;ooooo0008ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`05o`000?oo
ooooooooooooool00000F_ooool2o`00073ooooo000<ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`00000nooooo`03o`000?oooooooooo01_ooooo0_l0001^ooooo`003?oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`?o0000?Oooool3o`0001cooooo
0_l0001/ooooo`002?ooool4o`0000;ooooo1?l00004ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool06oooool2o`0006[ooooo0008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo06Oooooo0008oooo
o`Go000000?oooooo`000?l000000ol00003ooooo`;o0000A?ooool2o`0001cooooo0_l0001Woooo
o`005_ooool00ol0003oooooooooo`15ooooo`;o00007?ooool2o`0006Gooooo000Fooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Rooooo`005_oo
ool00ol0003oooooooooo`1Vooooo`;o0000H_ooool001Kooooo0_l0001;ooooo`;o00007?ooool0
0ol0003oooooooooo`1Oooooo`005_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0G_ooool001Kooooo00?o0000ooooooooool0COooool2o`0001_o
oooo0_l0001Nooooo`005_ooool2o`0006gooooo00?o0000ooooooooool0Foooool001Kooooo00?o
0000ooooooooool0DOooool2o`0001[ooooo00?o0000ooooooooool0F_ooool001Kooooo00?o0000
ooooooooool0Doooool2o`0001Wooooo0_l0001Jooooo`005_ooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Eoooool001Kooooo0_l0001booooo`03
o`000?oooooooooo05Kooooo0009ooooo`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool0
F?ooool2o`0001Sooooo00?o0000ooooooooool0EOooool000Sooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0F_ooool2o`0001Oo
oooo00?o0000ooooooooool0E?ooool000Sooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo0ol0001Looooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Doooool000Sooooo1?l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0MOooool2o`0005?ooooo0008ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`1Oooooo`;o00005_ooool00ol0003oooooooooo`1@oooo
o`002Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04oooooo000:ooooo`;o
00001?ooool2o`0000Cooooo0_l0001Sooooo`03o`000?oooooooooo01Cooooo0_l0001?ooooo`00
5_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo04cooooo000Fooooo`03o`000?oo
oooooooo06Kooooo0_l0000Dooooo`03o`000?oooooooooo04_ooooo000Fooooo`;o0000JOooool0
0ol0003oooooooooo`0Booooo`;o0000Boooool001Kooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`0Cooooo`?o0000B?ooool001Kooooo00?o0000ooooooooool0KOooool2o`0001?o
oooo0_l00016ooooo`005_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0@oooool001Kooooo0_l0001aooooo`03o`000?oooooooooo01;ooooo0ol0
0012ooooo`005_ooool00ol0003oooooooooo`28ooooo`Co0000?_ooool001Kooooo00?o0000oooo
ooooool0M?ooool2o`0001Kooooo1?l0000jooooo`005_ooool2o`0007Oooooo00?o0000oooooooo
ool05oooool4o`0003Kooooo0009ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`0Jooooo`Co0000<_ooool000Sooooo00Oo0000oooooooooooooooo
o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`00002Jooooo`?o0000;oooool000So
oooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000OOooool0
0ol0003oooooooooo`0Mooooo`;o0000;Oooool000Sooooo1?l00006ooooo`04o`000?oooooooooo
ooooo`?o0000O?ooool2o`0001oooooo0_l0000[ooooo`002?ooool00ol0003oooooooooo`03oooo
o`Co00001?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo01kooooo0ol0000Xoooo
o`002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0X_ooool3o`0002Gooooo000:ooooo`;o00000_ooool5o`0000?ooooo0_l00023ooooo`;o0000
8Oooool2o`0002?ooooo000Fooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Pooooo`005_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo023ooooo0_l0000Pooooo`005_ooool00ol0003oooooooooo`2Zooooo`;o00007_ooool001Ko
oooo0_l0002:ooooo`;o00008Oooool00ol0003oooooooooo`0Kooooo`005_ooool00ol0003ooooo
ooooo`2;ooooo`03o`000?oooooooooo01oooooo0_l0000Kooooo`005_ooool00ol0003ooooooooo
o`2<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06?ooool001Kooooo0_l0002a
ooooo`03o`000?oooooooooo01Oooooo000Fooooo`03o`000?oooooooooo093ooooo0_l0000Ooooo
o`;o00005oooool001Kooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01Cooooo000Fooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Cooooo`005_ooool2o`000;Kooooo0_l0000Cooooo`002_ooool0
0ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`2Gooooo`;o00007_ooool0
0ol0003oooooooooo`0@ooooo`002_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00oooooo000;ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooooooo
ool3o`0009[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`002oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00002looooo`03o`00
0?oooooooooo00gooooo000<ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`00002Pooooo`;o00006oooool00ol0003oooooooooo`0<ooooo`002?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2Poooo
o`03o`000?oooooooooo02Oooooo0008ooooo`Go00000oooool2o`0000Cooooo0_l0002Rooooo`03
o`000?oooooooooo02Kooooo000Fooooo`03o`000?oooooooooo0:Gooooo0_l0000Sooooo`005_oo
ool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo023ooooo000Fooooo`;o0000ZOooool0
0ol0003oooooooooo`0Oooooo`005_ooool00ol0003oooooooooo`3:ooooo`005_ooool00ol0003o
ooooooooo`2/ooooo`;o00007?ooool001Kooooo00?o0000ooooooooool0[_ooool00ol0003ooooo
ooooo`0Iooooo`005_ooool2o`000;3ooooo00?o0000ooooooooool06?ooool001Kooooo00?o0000
ooooooooool0b_ooool001Kooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0Doooo
o`005_ooool2o`000;Gooooo0_l0000Dooooo`002_ooool00ol0003oooooooooo`02ooooo`?o0000
1?ooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo017ooooo000:ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<cooooo000;ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00002looooo`03o`000?oooooooooo00go
oooo000;ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo0ol0002kooooo`03
o`000?oooooooooo00cooooo000<ooooo`03o`000?oooooo000000?o0000dOooool000Sooooo00Oo
0000ooooooooooooooooo`000?oooooo00000=Cooooo0008ooooo`Go000000?oooooo`000?l00000
0ol0003@ooooo`00hoooool00001\
\>"],
  ImageRangeCache->{{{77.875, 303.875}, {239.062, 99.875}} -> {-2.65554, \
65.1097, 0.0263377, 0.284102}}]
}, Open  ]],

Cell["At 12 noon the house has warmed up to 70.4 degrees. ", "Text"],

Cell[CellGroupData[{

Cell["HH[5]//N", "Input",
  CellLabel->"In[146]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(70.43365575222595`\)], "Output",
  CellLabel->"Out[146]="]
}, Open  ]],

Cell[TextData[{
  "The plot below shows the input heat function  ",
  StyleBox["H",
    FontSlant->"Italic"],
  "(t) and the sinusoidal component of the room temperature. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ {H[t],-0.176 Cos[3.14 t]-0.921 Sin[3.14 t]}, {t,0,5}, 
      PlotStyle->{RGBColor[1,0,0],RGBColor[0,0,1]}, AspectRatio->1/3]\
\>", \
"Input",
  CellLabel->"In[150]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.050843 0.045759 [
[.21429 .03834 -3 -9 ]
[.21429 .03834 3 0 ]
[.40476 .03834 -3 -9 ]
[.40476 .03834 3 0 ]
[.59524 .03834 -3 -9 ]
[.59524 .03834 3 0 ]
[.78571 .03834 -3 -9 ]
[.78571 .03834 3 0 ]
[.97619 .03834 -3 -9 ]
[.97619 .03834 3 0 ]
[.01131 .00508 -12 -4.5 ]
[.01131 .00508 0 4.5 ]
[.01131 .0966 -6 -4.5 ]
[.01131 .0966 0 4.5 ]
[.01131 .14236 -6 -4.5 ]
[.01131 .14236 0 4.5 ]
[.01131 .18812 -6 -4.5 ]
[.01131 .18812 0 4.5 ]
[.01131 .23388 -6 -4.5 ]
[.01131 .23388 0 4.5 ]
[.01131 .27964 -6 -4.5 ]
[.01131 .27964 0 4.5 ]
[.01131 .3254 -6 -4.5 ]
[.01131 .3254 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .05084 m
.21429 .05709 L
s
[(1)] .21429 .03834 0 1 Mshowa
.40476 .05084 m
.40476 .05709 L
s
[(2)] .40476 .03834 0 1 Mshowa
.59524 .05084 m
.59524 .05709 L
s
[(3)] .59524 .03834 0 1 Mshowa
.78571 .05084 m
.78571 .05709 L
s
[(4)] .78571 .03834 0 1 Mshowa
.97619 .05084 m
.97619 .05709 L
s
[(5)] .97619 .03834 0 1 Mshowa
.125 Mabswid
.0619 .05084 m
.0619 .05459 L
s
.1 .05084 m
.1 .05459 L
s
.1381 .05084 m
.1381 .05459 L
s
.17619 .05084 m
.17619 .05459 L
s
.25238 .05084 m
.25238 .05459 L
s
.29048 .05084 m
.29048 .05459 L
s
.32857 .05084 m
.32857 .05459 L
s
.36667 .05084 m
.36667 .05459 L
s
.44286 .05084 m
.44286 .05459 L
s
.48095 .05084 m
.48095 .05459 L
s
.51905 .05084 m
.51905 .05459 L
s
.55714 .05084 m
.55714 .05459 L
s
.63333 .05084 m
.63333 .05459 L
s
.67143 .05084 m
.67143 .05459 L
s
.70952 .05084 m
.70952 .05459 L
s
.74762 .05084 m
.74762 .05459 L
s
.82381 .05084 m
.82381 .05459 L
s
.8619 .05084 m
.8619 .05459 L
s
.9 .05084 m
.9 .05459 L
s
.9381 .05084 m
.9381 .05459 L
s
.25 Mabswid
0 .05084 m
1 .05084 L
s
.02381 .00508 m
.03006 .00508 L
s
[(-1)] .01131 .00508 1 0 Mshowa
.02381 .0966 m
.03006 .0966 L
s
[(1)] .01131 .0966 1 0 Mshowa
.02381 .14236 m
.03006 .14236 L
s
[(2)] .01131 .14236 1 0 Mshowa
.02381 .18812 m
.03006 .18812 L
s
[(3)] .01131 .18812 1 0 Mshowa
.02381 .23388 m
.03006 .23388 L
s
[(4)] .01131 .23388 1 0 Mshowa
.02381 .27964 m
.03006 .27964 L
s
[(5)] .01131 .27964 1 0 Mshowa
.02381 .3254 m
.03006 .3254 L
s
[(6)] .01131 .3254 1 0 Mshowa
.125 Mabswid
.02381 .01424 m
.02756 .01424 L
s
.02381 .02339 m
.02756 .02339 L
s
.02381 .03254 m
.02756 .03254 L
s
.02381 .04169 m
.02756 .04169 L
s
.02381 .05999 m
.02756 .05999 L
s
.02381 .06915 m
.02756 .06915 L
s
.02381 .0783 m
.02756 .0783 L
s
.02381 .08745 m
.02756 .08745 L
s
.02381 .10575 m
.02756 .10575 L
s
.02381 .11491 m
.02756 .11491 L
s
.02381 .12406 m
.02756 .12406 L
s
.02381 .13321 m
.02756 .13321 L
s
.02381 .15151 m
.02756 .15151 L
s
.02381 .16066 m
.02756 .16066 L
s
.02381 .16982 m
.02756 .16982 L
s
.02381 .17897 m
.02756 .17897 L
s
.02381 .19727 m
.02756 .19727 L
s
.02381 .20642 m
.02756 .20642 L
s
.02381 .21558 m
.02756 .21558 L
s
.02381 .22473 m
.02756 .22473 L
s
.02381 .24303 m
.02756 .24303 L
s
.02381 .25218 m
.02756 .25218 L
s
.02381 .26133 m
.02756 .26133 L
s
.02381 .27049 m
.02756 .27049 L
s
.02381 .28879 m
.02756 .28879 L
s
.02381 .29794 m
.02756 .29794 L
s
.02381 .30709 m
.02756 .30709 L
s
.02381 .31625 m
.02756 .31625 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .05084 m
.02499 .05087 L
.02605 .05094 L
.02729 .05107 L
.02846 .05125 L
.03053 .05169 L
.03279 .05234 L
.03527 .05329 L
.0379 .05453 L
.04262 .0574 L
.05205 .06547 L
.06244 .07778 L
.0842 .11349 L
.10458 .15567 L
.14335 .24169 L
.16306 .27925 L
.17348 .29546 L
.18458 .30924 L
.19014 .31465 L
.19538 .31877 L
.20008 .32165 L
.20251 .32281 L
.20517 .32385 L
.20638 .32423 L
.20767 .32458 L
.20879 .32483 L
.21001 .32506 L
.21072 .32516 L
.21138 .32524 L
.21268 .32535 L
.21387 .32539 L
.21512 .32538 L
.2162 .32533 L
.21737 .32522 L
.21847 .32507 L
.21948 .32489 L
.22182 .32434 L
.22428 .32353 L
.22929 .32122 L
.23383 .31833 L
.24403 .30921 L
.25347 .29771 L
.26239 .2844 L
.30086 .20767 L
.32034 .16375 L
.34178 .11849 L
.35159 .10033 L
.36214 .0834 L
.37202 .07038 L
.38118 .0611 L
Mistroke
.38609 .0573 L
.39131 .05421 L
.3943 .05288 L
.39711 .05194 L
.39834 .05161 L
.39963 .05133 L
.40031 .05121 L
.40105 .0511 L
.40236 .05095 L
.403 .0509 L
.40371 .05086 L
.40499 .05084 L
.40623 .05088 L
.40738 .05097 L
.40862 .05112 L
.40999 .05135 L
.41142 .05167 L
.41276 .05204 L
.41743 .05383 L
.42005 .05519 L
.42246 .05665 L
.43229 .06475 L
.44142 .07518 L
.46213 .10785 L
.50123 .19091 L
.52118 .23511 L
.54278 .27714 L
.55291 .29328 L
.56362 .30715 L
.57277 .31608 L
.57796 .31986 L
.58282 .32253 L
.58541 .3236 L
.58781 .32437 L
.58917 .32471 L
.59045 .32497 L
.59178 .32517 L
.59249 .32526 L
.59325 .32532 L
.59445 .32539 L
.59576 .32539 L
.59642 .32537 L
.59713 .32533 L
.59841 .32521 L
.59968 .32503 L
.60089 .3248 L
.60314 .32423 L
.60539 .32348 L
.60777 .32247 L
.61204 .32016 L
Mistroke
.61663 .31694 L
.62169 .31254 L
.63184 .30114 L
.64112 .28794 L
.662 .25025 L
.70173 .16279 L
.72177 .12036 L
.73994 .08814 L
.7494 .07474 L
.75963 .06335 L
.76526 .05858 L
.77043 .05518 L
.77538 .05283 L
.77787 .05199 L
.77929 .05161 L
.78061 .05133 L
.78183 .05113 L
.78312 .05097 L
.78442 .05087 L
.78516 .05085 L
.78585 .05084 L
.7871 .05088 L
.78824 .05096 L
.7895 .05111 L
.79082 .05133 L
.79313 .05187 L
.79527 .05254 L
.80013 .05471 L
.80543 .05804 L
.81025 .06193 L
.82105 .07351 L
.84025 .10273 L
.86105 .14387 L
.90199 .2348 L
.92236 .27476 L
.93232 .291 L
.94141 .30343 L
.95002 .31281 L
.95818 .31939 L
.96266 .32199 L
.9668 .32375 L
.96919 .32448 L
.97135 .32496 L
.97255 .32515 L
.97384 .32529 L
.97507 .32537 L
.97619 .3254 L
Mfstroke
0 0 1 r
.02381 .04279 m
.04262 .03032 L
.06244 .01931 L
.07286 .0148 L
.08255 .01155 L
.08813 .01014 L
.0932 .00915 L
.096 .00872 L
.09905 .00837 L
.10044 .00824 L
.10192 .00813 L
.10319 .00805 L
.10386 .00802 L
.10458 .00799 L
.10587 .00795 L
.10706 .00794 L
.1078 .00794 L
.10849 .00794 L
.10978 .00796 L
.11101 .008 L
.11215 .00805 L
.1134 .00813 L
.11472 .00823 L
.117 .00845 L
.11914 .0087 L
.12399 .00948 L
.12926 .01063 L
.13407 .01194 L
.14487 .01577 L
.16395 .02513 L
.18471 .03815 L
.22549 .06644 L
.24575 .07868 L
.25567 .08362 L
.26476 .08739 L
.27361 .09027 L
.27806 .0914 L
.28293 .09239 L
.28783 .09312 L
.29058 .09341 L
.29188 .09352 L
.29307 .0936 L
.2942 .09366 L
.2954 .0937 L
.29661 .09373 L
.29729 .09374 L
.29793 .09375 L
.29908 .09375 L
.30014 .09373 L
.30136 .09369 L
Mistroke
.30251 .09364 L
.30376 .09357 L
.30511 .09347 L
.30756 .09324 L
.30994 .09295 L
.31212 .09263 L
.3171 .09169 L
.32236 .0904 L
.33113 .08759 L
.34076 .08362 L
.36031 .07317 L
.38123 .05946 L
.40108 .04549 L
.42265 .03101 L
.44162 .02026 L
.45242 .01542 L
.45771 .01345 L
.46254 .01189 L
.4671 .01065 L
.47209 .00955 L
.47709 .00873 L
.47982 .0084 L
.48236 .00818 L
.48368 .00809 L
.48437 .00805 L
.4851 .00802 L
.48574 .00799 L
.48645 .00797 L
.48769 .00794 L
.4889 .00794 L
.49019 .00795 L
.49141 .00798 L
.49253 .00802 L
.49391 .00809 L
.49519 .00818 L
.4981 .00844 L
.50066 .00876 L
.50338 .00917 L
.50826 .01013 L
.51273 .01124 L
.52283 .01452 L
.5411 .02292 L
.58069 .04845 L
.61876 .07406 L
.63835 .08431 L
.64932 .0886 L
.65416 .0901 L
.65929 .09142 L
.66404 .09239 L
.66655 .0928 L
Mistroke
.66926 .09316 L
.67174 .09341 L
.67401 .09358 L
.6751 .09364 L
.67629 .09369 L
.67741 .09373 L
.67845 .09374 L
.67976 .09375 L
.6805 .09374 L
.68117 .09373 L
.68242 .0937 L
.68373 .09364 L
.68491 .09357 L
.68602 .09349 L
.68852 .09326 L
.69123 .09293 L
.6937 .09256 L
.69924 .09147 L
.70406 .09024 L
.70917 .08867 L
.71834 .08519 L
.73911 .07457 L
.77688 .04926 L
.79787 .03482 L
.8171 .02321 L
.83596 .01449 L
.84544 .01139 L
.85081 .01005 L
.85581 .00909 L
.85844 .0087 L
.86087 .00841 L
.86353 .00818 L
.86487 .00809 L
.86562 .00804 L
.86634 .00801 L
.86764 .00797 L
.86882 .00794 L
.87009 .00794 L
.87081 .00794 L
.87148 .00795 L
.8727 .00798 L
.87381 .00802 L
.87508 .00809 L
.87628 .00817 L
.87855 .00837 L
.88094 .00864 L
.88522 .00929 L
.88983 .01022 L
.89487 .01151 L
.90512 .01495 L
Mistroke
.91444 .01898 L
.93537 .03057 L
.97529 .05793 L
.97619 .05856 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[150]:=",
  ImageSize->{241, 80.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003a0000D2000`400?l00000o`00003olOooool0
0?7ooooo000<ooooo`?o0000h_ooool000gooooo00?o0000ooooooooool0hOooool000Gooooo1Ol0
0003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool3o`0002Gooooo1Ol0
000Vooooo`?o0000:?ooool3o`0002Kooooo0ol0000;ooooo`003Oooool00ol0003oooooooooo`04
ooooo`;o00003_ooool5o`00oaCooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0
000?ooooo`Go003o4Oooool01Ol0003ooooooooooooooooo000002Sooooo00?o0000ooooooooool0
3Oooool5o`00oa;ooooo00Go0000ooooooooooooooooo`00000:ooooo`003Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo1Ol00?l4ooooo`Go003o3oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00_ooooo1?l00?l4ooooo`Go003o4Oooool00ol0003ooooo
ooooo`0Sooooo`Go00002_ooool5o`00o`Cooooo1Ol00?lAooooo`03o`000?oooooooooo00Sooooo
000<ooooo`;o00001_ooool2o`0000Sooooo0_l00?l>ooooo`;o003o3Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00Oooooo0ol00?l=ooooo`;o003o3Oooool2o`0002Kooooo00Co
0000oooooooooooo00002Oooool2o`00o`kooooo0_l00?l?ooooo`03o`000?oooooooooo00Sooooo
000=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool3o`00oa;ooooo0ol0
0?l:ooooo`03o`000?oooooooooo02Cooooo00Go0000ooooooooooooooooo`000005ooooo`?o003o
4_ooool2o`00o`gooooo00?o0000ooooooooool09?ooool00ol0003oooooo`000007ooooo`;o003o
4_ooool2o`00o`Wooooo1?l0000;ooooo`005?ooool2o`0000?ooooo0_l00?lHooooo`;o003o1ooo
ool2o`0002Kooooo00Go0000ooooooooooooooooo`000003ooooo`;o003o5oooool2o`00o`Oooooo
00Go0000ooooooooooooooooo`00000Wooooo`;o00001Oooool2o`00oaKooooo0ol00?l6ooooo`03
o`000?oooooooooo00cooooo000Dooooo`03o`000?oooooooooo00;o003o7?ooool00ol00?oooooo
ooooo`05ooooo`03o`000?oooooooooo02Gooooo0ol00003ooooo`03o`00oooooooooooo01Wooooo
0_l00?l6ooooo`?o0000:Oooool01?l0003oooooooooooooool2o`00oa_ooooo0_l00?l4ooooo`Go
00002_ooool001Cooooo0_l000000ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo037ooooo
00?o003oooooooooool07?ooool2o`00oc;ooooo0_l00?lOooooo`03o`00oooooooooooo013ooooo
000Dooooo`03o`000?l00?oooooo023ooooo0_l00?l`ooooo`03o`00oooooooooooo01oooooo00?o
003oooooooooool0;Oooool2o`00ob;ooooo00?o003oooooooooool03oooool001Cooooo00?o003o
o`000?ooool08_ooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo027ooooo0_l00?l/
ooooo`03o`00oooooooooooo02?ooooo0_l00?l?ooooo`005?ooool00ol0003oooooooooo`0Soooo
o`;o003o:_ooool2o`00obKooooo0_l00?lXooooo`;o003o:?ooool00ol00?ooooooooooo`0<oooo
o`003oooool5o`0000?oo`009Ol000000ol00?oo0000o`00000Uo`0000;o003o1Ooo000Uo`000003
o`00ool0003o000002Co000000?o003oo`000?oo00001?oo000Uo`000003o`00ool0003o000000Go
00001_ooool001Cooooo00?o0000ooooooooool00_oo0003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l00?l7ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`06o`000?ooooooooooooooool00?ooo`000_ooool01Ol0003ooooooooooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooo`00o`;oo`000_ooool00ol0003oooooooooo`02ool000?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool2o`00o`_ooooo000Dooooo`;o00000oooool00ooo003oooooooooo`0Sooooo`03o`00oooooooo
oooo01oooooo0_l00?l9ooooo`03ool00?oooooooooo02?ooooo0_l00?lPooooo`;o003o00?oo`00
ooooooooool01oooool00ooo003oooooooooo`0^ooooo`005?ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo02?ooooo0_l00?lNooooo`03o`00oooo003ooooo00[ooooo00?oo`00oooo
ooooool09?ooool00ol00?ooooooooooo`0Looooo`03o`00ooooooooo`0000_ooooo00?oo`00oooo
ooooool0;Oooool001Cooooo0_l00004ooooo`03ool00?oooooooooo02Gooooo0_l00?lKooooo`03
o`00oooo003ooooo00cooooo00?oo`00ooooooooool09?ooool00ol00?ooooooooooo`0Jooooo`03
o`00ooooooooo`0000gooooo00?oo`00ooooooooool0;?ooool001Cooooo00?o0000ooooooooool0
1?ooool00ooo003oooooooooo`0Vooooo`03o`00oooooooooooo01Kooooo0_l00?l00oooooooo`00
ooooo`0=ooooo`03ool00?oooooooooo02Cooooo0_l00?lHooooo`;o003o00?oooooool00?ooool0
3_ooool00ooo003oooooooooo`0[ooooo`005?ooool2o`0000Kooooo00?oo`00ooooooooool09_oo
ool2o`00oa?ooooo0ol00?l2ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool09_oo
ool3o`00oa;ooooo0ol00?l3ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0:ooo
ool000cooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0:?ooool2
o`00o`oooooo0_l00?l4ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0:?ooool2
o`00o`kooooo0_l00?l5ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0:_ooool0
00gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?oo`00ooooooooool0:Oooool3o`00
o`Wooooo0ol00?l6ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0:Oooool2o`00
o`[ooooo0_l00?l6ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0:Oooool000go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo02_o
oooo2Ol00?l8ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0:_ooool:o`00o`So
oooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Yooooo`003Oooool00ol0003ooooo
ooooo`04ooooo`;o00002?ooool00ooo003oooooooooo`0looooo`03ool00?oooooooooo01;ooooo
00?oo`00ooooooooool0>oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo02Sooooo
000=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ooo003ooooooooo
o`0jooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0>_ooool00ooo003ooooooooo
o`0Dooooo`03ool00?oooooooooo02Oooooo000<ooooo`;o00001_ooool2o`0000Wooooo00?oo`00
ooooooooool0>_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo03Sooooo00?oo`00
ooooooooool05Oooool00ooo003oooooooooo`0Wooooo`003Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0>?ooool00ooo003oooooooooo`0Foooo
o`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Voooo
o`005?ooool2o`0000_ooooo00?oo`00ooooooooool0=oooool00ooo003oooooooooo`0Gooooo`03
ool00?oooooooooo03Kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Vooooo`00
5?ooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo03Kooooo00?oo`00ooooooooool0
6?ooool00ooo003oooooooooo`0eooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool0
9Oooool001Cooooo0_l0000<ooooo`03ool00?oooooooooo03Gooooo00?oo`00ooooooooool06Ooo
ool00ooo003oooooooooo`0dooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool09Ooo
ool000_ooooo1Ol00004ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0=?ooool0
0ooo003oooooooooo`0Jooooo`03ool00?oooooooooo03?ooooo00?oo`00ooooooooool06_ooool0
0ooo003oooooooooo`0Uooooo`003?ooool01?l0003oooooooooool00004ooooo`;o00003Oooool0
0ooo003oooooooooo`0cooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool0<_ooool0
0ooo003oooooooooo`0Kooooo`03ool00?oooooooooo02Cooooo000=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo
01cooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo
02Cooooo000>ooooo`03o`000?oooooooooo00?ooooo0_l0000>ooooo`03ool00?oooooooooo037o
oooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0`ooooo`03ool00?oooooooooo01go
oooo00?oo`00ooooooooool08oooool000_ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00kooooo00?oo`00ooooooooool0;oooool00ooo003oooooooooo`0Nooooo`03
ool00?oooooooooo033ooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0Sooooo`00
2oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000?ooooo`03ool00?oooooooooo02oo
oooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0^ooooo`03ool00?oooooooooo01oo
oooo00?oo`00ooooooooool08_ooool000cooooo0ol00005ooooo`03o`000?oooooooooo00oooooo
00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo02kooooo
00?oo`00ooooooooool07oooool00ooo003oooooooooo`0Rooooo`005?ooool2o`00013ooooo00?o
o`00ooooooooool0;Oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo02gooooo00?o
o`00ooooooooool08Oooool00ooo003oooooooooo`0Qooooo`005?ooool00ol0003oooooooooo`0@
ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`0/
ooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool08Oooool001Cooooo0_l0000Aoooo
o`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`0[oooo
o`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool08Oooool000cooooo0ol00005ooooo`03
o`000?oooooooooo013ooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`0Tooooo`03
ool00?oooooooooo02[ooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`0Pooooo`00
2oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000Booooo`03ool00?oooooooooo02Wo
oooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo02Co
oooo00?oo`00ooooooooool08?ooool000oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Aooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool09_ooool00ooo003ooooo
ooooo`0Xooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool07oooool000gooooo0_l0
0005ooooo`;o00004oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo02Kooooo00?o
o`00ooooooooool0:?ooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo000?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0W
ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`0W
ooooo`03ool00?oooooooooo01kooooo000;ooooo`05o`000?ooooooooooooooool000001?ooool2
o`0001Cooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooo
oooo02Kooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`0Nooooo`003?ooool3o`00
00Gooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo
02Wooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo
01gooooo000Dooooo`;o00005?ooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo02[o
oooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo01go
oooo000Dooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool08oooool00ooo003ooooo
ooooo`0[ooooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool0:oooool00ooo003ooooo
ooooo`0Looooo`005?ooool2o`0001Gooooo00?oo`00ooooooooool08_ooool00ooo003ooooooooo
o`0/ooooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool0:oooool00ooo003ooooooooo
o`0Looooo`003Oooool3o`0000Cooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0Q
ooooo`03ool00?oooooooooo02cooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0/
ooooo`03ool00?oooooooooo01cooooo000>ooooo`03o`000?oooooooooo00?ooooo0_l0000Foooo
o`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0;_ooool00ooo003oooooooooo`0Poooo
o`03ool00?oooooooooo02gooooo00?oo`00ooooooooool06oooool000_ooooo1Ol00004ooooo`03
o`000?oooooooooo01Kooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0^ooooo`03
ool00?oooooooooo01oooooo00?oo`00ooooooooool0;_ooool00ooo003oooooooooo`0Kooooo`00
2oooool01?l0003oooooooooool00005ooooo`;o00005oooool00ooo003oooooooooo`0Nooooo`03
ool00?oooooooooo033ooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`0_ooooo`03
ool00?oooooooooo01[ooooo000<ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
5_ooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool0
7_ooool00ooo003oooooooooo`0_ooooo`03ool00?oooooooooo01[ooooo000=ooooo`;o00001Ooo
ool2o`0001Sooooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`0booooo`03ool00?oo
oooooooo01cooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`0Iooooo`003_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool06oooool0
0ooo003oooooooooo`0cooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0<Oooool0
0ooo003oooooooooo`0Iooooo`005?ooool2o`0001Wooooo00?oo`00ooooooooool06_ooool00ooo
003oooooooooo`0dooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0<oooool00ooo
003oooooooooo`0Hooooo`005?ooool00ol0003oooooooooo`0Hooooo`03ool00?oooooooooo01Wo
oooo00?oo`00ooooooooool0=_ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo03Co
oooo00?oo`00ooooooooool05oooool001Cooooo0_l0000Jooooo`03ool00?oooooooooo01Sooooo
00?oo`00ooooooooool0=_ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo03Gooooo
00?oo`00ooooooooool05oooool000cooooo0ol00005ooooo`03o`000?oooooooooo01Wooooo00?o
o`00ooooooooool05oooool00ooo003oooooooooo`0hooooo`03ool00?oooooooooo01Kooooo00?o
o`00ooooooooool0=oooool00ooo003oooooooooo`0Fooooo`002oooool01Ol0003ooooooooooooo
oooo000000Cooooo0_l0000Kooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool0>?oo
ool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool05_oo
ool000oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooo
oooo01Gooooo00?oo`00ooooooooool0>_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooo
oooo03Wooooo00?oo`00ooooooooool05Oooool000oooooo00?o0000ooooooooool00_ooool2o`00
01cooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0jooooo`03ool00?oooooooooo
01Cooooo00?oo`00ooooooooool0>Oooool00ooo003oooooooooo`0Eooooo`002oooool4o`0000Go
oooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo03co
oooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo00Kooooo0_l0000Nooooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool0??ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo03gooooo
00?oo`00ooooooooool04oooool000_ooooo1Ol00004ooooo`03o`000?oooooooooo01kooooo00?o
o`00ooooooooool03oooool00ooo003oooooooooo`0nooooo`03ool00?oooooooooo013ooooo00?o
o`00ooooooooool0?Oooool00ooo003oooooooooo`0Cooooo`005?ooool2o`0001oooooo00?oo`00
ooooooooool03_ooool00ooo003oooooooooo`0oooooo`03ool00?oooooooooo00oooooo00?oo`00
ooooooooool0?oooool00ooo003oooooooooo`0Booooo`005?ooool00ol0003oooooooooo`0Ooooo
o`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0@Oooool00ooo003oooooooooo`0=oooo
o`03ool00?oooooooooo047ooooo00?oo`00ooooooooool04Oooool001Cooooo0_l0000Qooooo`03
ool00?oooooooooo00[ooooo00?oo`00ooooooooool0@oooool00ooo003oooooooooo`0;ooooo`03
ool00?oooooooooo04?ooooo00?oo`00ooooooooool04?ooool000cooooo0ol00005ooooo`03o`00
0?oooooooooo023ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`15ooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`0?ooooo`002ooo
ool01Ol0003ooooooooooooooooo000000Cooooo0_l0000Rooooo`03ool00?oooooooooo00Oooooo
00?oo`00ooooooooool0Aoooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo04Oooooo
00?oo`00ooooooooool03_ooool000_ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo02;ooooo0ooo0005ooooo`03ool00?oooooooooo04Wooooo0_oo0005ooooo`;oo`00
Boooool2ool000kooooo000;ooooo`Co00001Oooool2o`0002Kooooo1Ooo001>ooooo`Goo`00Cooo
ool3ool000_ooooo000;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0f_ooool0
00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Jooooo`003Oooool2o`000>;o
oooo003aooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 317.875}, {451.812, 372.562}} -> {-2.35083, \
35.6763, 0.0239388, 0.0996473}}]
}, Open  ]],

Cell["\<\
This picture confirms that the house temperature cycles up and down \
with the same period as the furnace.  However, the house temperature lags \
behind the heater by almost exactly a quarter cycle so that the room  \
temperature is increasing at its maximum rate at the same time that the \
furnace is putting out heat at its  maximum rate. \
\>", "Text"]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{658, 711},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->45,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "   Page  ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "   Page  ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 584, 14, 138, "Text"],
Cell[2341, 67, 118, 2, 28, "Text"],
Cell[2462, 71, 428, 14, 48, "Text"],
Cell[2893, 87, 171, 8, 28, "Text"],
Cell[3067, 97, 162, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[3254, 106, 137, 5, 51, "Input"],
Cell[3394, 113, 207, 6, 27, "Output"],
Cell[3604, 121, 133, 3, 32, "Output"]
}, Open  ]],
Cell[3752, 127, 93, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[3870, 134, 133, 5, 51, "Input"],
Cell[4006, 141, 88, 2, 27, "Output"]
}, Open  ]],
Cell[4109, 146, 221, 9, 28, "Text"],

Cell[CellGroupData[{
Cell[4355, 159, 305, 8, 171, "Input"],
Cell[4663, 169, 15362, 435, 131, 4055, 290, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[20040, 607, 472, 15, 53, "Text"],

Cell[CellGroupData[{
Cell[20537, 626, 84, 2, 29, "Input"],
Cell[20624, 630, 85, 2, 27, "Output"]
}, Open  ]],
Cell[20724, 635, 107, 2, 28, "Text"],
Cell[20834, 639, 509, 8, 108, "Text"],
Cell[21346, 649, 519, 21, 48, "Text"],

Cell[CellGroupData[{
Cell[21890, 674, 146, 5, 47, "Input"],
Cell[22039, 681, 220, 6, 27, "Output"],
Cell[22262, 689, 320, 7, 54, "Output"]
}, Open  ]],
Cell[22597, 699, 103, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[22725, 706, 130, 5, 47, "Input"],
Cell[22858, 713, 90, 2, 27, "Output"]
}, Open  ]],
Cell[22963, 718, 35, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[23023, 722, 81, 2, 29, "Input"],
Cell[23107, 726, 62, 2, 27, "Output"]
}, Open  ]],
Cell[23184, 731, 118, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[23327, 738, 90, 2, 29, "Input"],
Cell[23420, 742, 86, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23543, 749, 108, 2, 29, "Input"],
Cell[23654, 753, 14195, 400, 113, 3680, 265, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[37864, 1156, 153, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[38042, 1163, 93, 2, 29, "Input"],
Cell[38138, 1167, 87, 2, 27, "Output"]
}, Open  ]],
Cell[38240, 1172, 499, 20, 48, "Text"],

Cell[CellGroupData[{
Cell[38764, 1196, 151, 5, 47, "Input"],
Cell[38918, 1203, 220, 6, 27, "Output"],
Cell[39141, 1211, 266, 6, 32, "Output"]
}, Open  ]],
Cell[39422, 1220, 94, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[39541, 1227, 90, 2, 29, "Input"],
Cell[39634, 1231, 80, 2, 27, "Output"]
}, Open  ]],
Cell[39729, 1236, 97, 2, 28, "Text"],
Cell[39829, 1240, 619, 10, 140, "Text"],
Cell[40451, 1252, 166, 7, 31, "Text"],
Cell[40620, 1261, 210, 6, 60, "Text"],
Cell[40833, 1269, 122, 5, 47, "Input"],
Cell[40958, 1276, 128, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[41111, 1283, 72, 2, 29, "Input"],
Cell[41186, 1287, 78, 2, 27, "Output"]
}, Open  ]],
Cell[41279, 1292, 129, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[41433, 1299, 72, 2, 29, "Input"],
Cell[41508, 1303, 77, 2, 27, "Output"]
}, Open  ]],
Cell[41600, 1308, 217, 4, 48, "Text"],
Cell[41820, 1314, 117, 5, 28, "Text"],
Cell[41940, 1321, 710, 25, 88, "Text"],
Cell[42653, 1348, 379, 21, 28, "Text"],
Cell[43035, 1371, 191, 6, 28, "Text"],
Cell[43229, 1379, 486, 28, 28, "Text"],
Cell[43718, 1409, 311, 7, 48, "Text"],

Cell[CellGroupData[{
Cell[44054, 1420, 127, 5, 47, "Input"],
Cell[44184, 1427, 224, 6, 27, "Output"],
Cell[44411, 1435, 311, 6, 48, "Output"]
}, Open  ]],
Cell[44737, 1444, 304, 6, 54, "Note"],
Cell[45044, 1452, 135, 5, 28, "Text"],
Cell[45182, 1459, 614, 24, 68, "Text"],

Cell[CellGroupData[{
Cell[45821, 1487, 117, 5, 47, "Input"],
Cell[45941, 1494, 214, 6, 27, "Output"],
Cell[46158, 1502, 116, 2, 32, "Output"]
}, Open  ]],
Cell[46289, 1507, 1367, 52, 139, "Text"],
Cell[47659, 1561, 225, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[47909, 1571, 153, 5, 47, "Input"],
Cell[48065, 1578, 215, 6, 27, "Output"],
Cell[48283, 1586, 206, 5, 32, "Output"]
}, Open  ]],
Cell[48504, 1594, 212, 8, 28, "Text"],

Cell[CellGroupData[{
Cell[48741, 1606, 125, 5, 47, "Input"],
Cell[48869, 1613, 398, 7, 58, "Message"],
Cell[49270, 1622, 90, 2, 45, "Output"]
}, Open  ]],
Cell[49375, 1627, 127, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[49527, 1634, 80, 2, 29, "Input"],
Cell[49610, 1638, 75, 2, 54, "Output"]
}, Open  ]],
Cell[49700, 1643, 123, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[49848, 1650, 80, 2, 29, "Input"],
Cell[49931, 1654, 78, 2, 27, "Output"]
}, Open  ]],
Cell[50024, 1659, 473, 11, 68, "Text"],

Cell[CellGroupData[{
Cell[50522, 1674, 86, 2, 29, "Input"],
Cell[50611, 1678, 76, 2, 45, "Output"]
}, Open  ]],
Cell[50702, 1683, 153, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[50880, 1692, 71, 2, 29, "Input"],
Cell[50954, 1696, 152, 3, 46, "Output"]
}, Open  ]],
Cell[51121, 1702, 89, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[51235, 1709, 95, 2, 29, "Input"],
Cell[51333, 1713, 89, 2, 27, "Output"]
}, Open  ]],
Cell[51437, 1718, 179, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[51641, 1726, 246, 6, 83, "Input"],
Cell[51890, 1734, 16764, 492, 131, 4749, 339, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[68669, 2229, 118, 2, 28, "Text"],
Cell[68790, 2233, 1156, 37, 151, "Text"],
Cell[69949, 2272, 225, 11, 28, "Text"],
Cell[70177, 2285, 621, 27, 48, "Text"],

Cell[CellGroupData[{
Cell[70823, 2316, 166, 6, 65, "Input"],
Cell[70992, 2324, 223, 6, 27, "Output"],
Cell[71218, 2332, 256, 5, 50, "Output"]
}, Open  ]],
Cell[71489, 2340, 96, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[71610, 2347, 123, 5, 47, "Input"],
Cell[71736, 2354, 362, 6, 42, "Message"],
Cell[72101, 2362, 399, 7, 58, "Message"],
Cell[72503, 2371, 182, 5, 45, "Output"]
}, Open  ]],
Cell[72700, 2379, 173, 6, 28, "Text"],

Cell[CellGroupData[{
Cell[72898, 2389, 103, 5, 47, "Input"],
Cell[73004, 2396, 79, 2, 27, "Output"],
Cell[73086, 2400, 78, 2, 27, "Output"]
}, Open  ]],
Cell[73179, 2405, 335, 8, 80, "Text"],

Cell[CellGroupData[{
Cell[73539, 2417, 181, 5, 47, "Input"],
Cell[73723, 2424, 15397, 470, 146, 4598, 332, "GraphicsData", "PostScript", \
"Graphics"],
Cell[89123, 2896, 156, 4, 27, "Output"]
}, Open  ]],
Cell[89294, 2903, 73, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[89392, 2907, 72, 2, 29, "Input"],
Cell[89467, 2911, 78, 2, 27, "Output"]
}, Open  ]],
Cell[89560, 2916, 141, 5, 28, "Text"],
Cell[89704, 2923, 291, 5, 68, "Text"],
Cell[89998, 2930, 256, 11, 30, "Text"],

Cell[CellGroupData[{
Cell[90279, 2945, 144, 5, 47, "Input"],
Cell[90426, 2952, 19818, 576, 92, 5797, 398, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[110259, 3531, 282, 9, 48, "Text"],

Cell[CellGroupData[{
Cell[110566, 3544, 179, 6, 65, "Input"],
Cell[110748, 3552, 258, 7, 45, "Output"],
Cell[111009, 3561, 622, 11, 98, "Output"]
}, Open  ]],
Cell[111646, 3575, 112, 3, 28, "Text"],
Cell[111761, 3580, 95, 3, 39, "Note"],

Cell[CellGroupData[{
Cell[111881, 3587, 116, 5, 47, "Input"],
Cell[112000, 3594, 497, 9, 30, "Output"]
}, Open  ]],
Cell[112512, 3606, 228, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[112765, 3614, 157, 4, 51, "Input"],
Cell[112925, 3620, 16330, 490, 151, 4759, 342, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[129270, 4113, 68, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[129363, 4117, 76, 2, 29, "Input"],
Cell[129442, 4121, 78, 2, 27, "Output"]
}, Open  ]],
Cell[129535, 4126, 184, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[129744, 4135, 208, 6, 83, "Input"],
Cell[129955, 4143, 23067, 761, 89, 8511, 576, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[153037, 4907, 366, 6, 68, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

