(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    711357,      23592]*)
(*NotebookOutlinePosition[    713538,      23657]*)
(*  CellTagsIndexPosition[    713494,      23653]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part III. ", "Section"],
  StyleBox["First Order Ordinary Differential Equations", "Section"],
  "\n",
  StyleBox["Section 3. Slope Fields: ", "Subsection"],
  "\nA slope field (or direction field) for a first order ordinary \
differential equation of the form"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  " ",
  StyleBox["y'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  " )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "is an array of short line segments. At point ( ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ") the segment has slope ",
  StyleBox["f",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  " )",
  ". Since these are tangent lines to the solution curves determined by the \
equation, a slope field can provide a wealth of information about the \
qualitative behavior of the solutions.  "
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["The tool you need: PlotVectorField", \
"Subsubsection"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  " The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " procedure that creates vector fields is called PlotVectorField. A 2 \
dimensional vector field assigns a vector < ",
  StyleBox["u",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ",",
  StyleBox["y",
    FontSlant->"Italic"],
  "), ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ",",
  StyleBox["y",
    FontSlant->"Italic"],
  ") > to each point ( ",
  StyleBox["x",
    FontSlant->"Italic"],
  " , ",
  StyleBox["y",
    FontSlant->"Italic"],
  " ) ",
  "in the plane. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will plot these vectors with an entry of the form"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["PlotVectorField[ { u[x,y], v[x,y] }, {x,a,b}, {y,c,d} \
]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
This function must be loaded with a Graphics package called \
PlotField\
\>", "Text"],

Cell["<<Graphics`PlotField`", "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "Here, for example, is ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s rendition of the vector field < -",
  StyleBox["y",
    FontSlant->"Italic"],
  " , ",
  StyleBox["x",
    FontSlant->"Italic"],
  " > ."
}], "Text"],

Cell[CellGroupData[{

Cell["PlotVectorField[ {-y,x}, {x,-3,3}, {y,-3,3}, Axes->True ]", "Input",
  CellLabel->"In[34]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.144167 0.5 0.144167 [
[.0675 .4875 -6 -9 ]
[.0675 .4875 6 0 ]
[.21167 .4875 -6 -9 ]
[.21167 .4875 6 0 ]
[.35583 .4875 -6 -9 ]
[.35583 .4875 6 0 ]
[.64417 .4875 -3 -9 ]
[.64417 .4875 3 0 ]
[.78833 .4875 -3 -9 ]
[.78833 .4875 3 0 ]
[.9325 .4875 -3 -9 ]
[.9325 .4875 3 0 ]
[.4875 .0675 -12 -4.5 ]
[.4875 .0675 0 4.5 ]
[.4875 .21167 -12 -4.5 ]
[.4875 .21167 0 4.5 ]
[.4875 .35583 -12 -4.5 ]
[.4875 .35583 0 4.5 ]
[.4875 .64417 -6 -4.5 ]
[.4875 .64417 0 4.5 ]
[.4875 .78833 -6 -4.5 ]
[.4875 .78833 0 4.5 ]
[.4875 .9325 -6 -4.5 ]
[.4875 .9325 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0675 .5 m
.0675 .50625 L
s
[(-3)] .0675 .4875 0 1 Mshowa
.21167 .5 m
.21167 .50625 L
s
[(-2)] .21167 .4875 0 1 Mshowa
.35583 .5 m
.35583 .50625 L
s
[(-1)] .35583 .4875 0 1 Mshowa
.64417 .5 m
.64417 .50625 L
s
[(1)] .64417 .4875 0 1 Mshowa
.78833 .5 m
.78833 .50625 L
s
[(2)] .78833 .4875 0 1 Mshowa
.9325 .5 m
.9325 .50625 L
s
[(3)] .9325 .4875 0 1 Mshowa
.125 Mabswid
.09633 .5 m
.09633 .50375 L
s
.12517 .5 m
.12517 .50375 L
s
.154 .5 m
.154 .50375 L
s
.18283 .5 m
.18283 .50375 L
s
.2405 .5 m
.2405 .50375 L
s
.26933 .5 m
.26933 .50375 L
s
.29817 .5 m
.29817 .50375 L
s
.327 .5 m
.327 .50375 L
s
.38467 .5 m
.38467 .50375 L
s
.4135 .5 m
.4135 .50375 L
s
.44233 .5 m
.44233 .50375 L
s
.47117 .5 m
.47117 .50375 L
s
.52883 .5 m
.52883 .50375 L
s
.55767 .5 m
.55767 .50375 L
s
.5865 .5 m
.5865 .50375 L
s
.61533 .5 m
.61533 .50375 L
s
.673 .5 m
.673 .50375 L
s
.70183 .5 m
.70183 .50375 L
s
.73067 .5 m
.73067 .50375 L
s
.7595 .5 m
.7595 .50375 L
s
.81717 .5 m
.81717 .50375 L
s
.846 .5 m
.846 .50375 L
s
.87483 .5 m
.87483 .50375 L
s
.90367 .5 m
.90367 .50375 L
s
.03867 .5 m
.03867 .50375 L
s
.00983 .5 m
.00983 .50375 L
s
.96133 .5 m
.96133 .50375 L
s
.99017 .5 m
.99017 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .0675 m
.50625 .0675 L
s
[(-3)] .4875 .0675 1 0 Mshowa
.5 .21167 m
.50625 .21167 L
s
[(-2)] .4875 .21167 1 0 Mshowa
.5 .35583 m
.50625 .35583 L
s
[(-1)] .4875 .35583 1 0 Mshowa
.5 .64417 m
.50625 .64417 L
s
[(1)] .4875 .64417 1 0 Mshowa
.5 .78833 m
.50625 .78833 L
s
[(2)] .4875 .78833 1 0 Mshowa
.5 .9325 m
.50625 .9325 L
s
[(3)] .4875 .9325 1 0 Mshowa
.125 Mabswid
.5 .09633 m
.50375 .09633 L
s
.5 .12517 m
.50375 .12517 L
s
.5 .154 m
.50375 .154 L
s
.5 .18283 m
.50375 .18283 L
s
.5 .2405 m
.50375 .2405 L
s
.5 .26933 m
.50375 .26933 L
s
.5 .29817 m
.50375 .29817 L
s
.5 .327 m
.50375 .327 L
s
.5 .38467 m
.50375 .38467 L
s
.5 .4135 m
.50375 .4135 L
s
.5 .44233 m
.50375 .44233 L
s
.5 .47117 m
.50375 .47117 L
s
.5 .52883 m
.50375 .52883 L
s
.5 .55767 m
.50375 .55767 L
s
.5 .5865 m
.50375 .5865 L
s
.5 .61533 m
.50375 .61533 L
s
.5 .673 m
.50375 .673 L
s
.5 .70183 m
.50375 .70183 L
s
.5 .73067 m
.50375 .73067 L
s
.5 .7595 m
.50375 .7595 L
s
.5 .81717 m
.50375 .81717 L
s
.5 .846 m
.50375 .846 L
s
.5 .87483 m
.50375 .87483 L
s
.5 .90367 m
.50375 .90367 L
s
.5 .03867 m
.50375 .03867 L
s
.5 .00983 m
.50375 .00983 L
s
.5 .96133 m
.50375 .96133 L
s
.5 .99017 m
.50375 .99017 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.0675 .0675 m
.11119 .02381 L
s
% Start of user PostScript
-3. -3. -2.69695 -3.30305 MAarrowhead1
% End of user PostScript
.0675 .12928 m
.10495 .0856 L
s
% Start of user PostScript
-3. -2.57143 -2.74025 -2.87447 MAarrowhead1
% End of user PostScript
.0675 .19107 m
.09871 .14738 L
s
% Start of user PostScript
-3. -2.14286 -2.78354 -2.4459 MAarrowhead1
% End of user PostScript
.0675 .25286 m
.09246 .20917 L
s
% Start of user PostScript
-3. -1.71429 -2.82683 -2.01733 MAarrowhead1
% End of user PostScript
.0675 .31464 m
.08622 .27095 L
s
% Start of user PostScript
-3. -1.28571 -2.87012 -1.58876 MAarrowhead1
% End of user PostScript
.0675 .37643 m
.07998 .33274 L
s
% Start of user PostScript
-3. -0.857143 -2.91342 -1.16019 MAarrowhead1
% End of user PostScript
.0675 .43821 m
.07374 .39452 L
s
% Start of user PostScript
-3. -0.428571 -2.95671 -0.731617 MAarrowhead1
% End of user PostScript
.0675 .5 m
.0675 .45631 L
s
% Start of user PostScript
-3. 0 -3. -0.303046 MAarrowhead1
% End of user PostScript
.0675 .56179 m
.06126 .5181 L
s
% Start of user PostScript
-3. 0.428571 -3.04329 0.125526 MAarrowhead1
% End of user PostScript
.0675 .62357 m
.05502 .57988 L
s
% Start of user PostScript
-3. 0.857143 -3.08658 0.554097 MAarrowhead1
% End of user PostScript
.0675 .68536 m
.04877 .64167 L
s
% Start of user PostScript
-3. 1.28571 -3.12988 0.982669 MAarrowhead1
% End of user PostScript
.0675 .74714 m
.04253 .70345 L
s
% Start of user PostScript
-3. 1.71429 -3.17317 1.41124 MAarrowhead1
% End of user PostScript
.0675 .80893 m
.03629 .76524 L
s
% Start of user PostScript
-3. 2.14286 -3.21646 1.83981 MAarrowhead1
% End of user PostScript
.0675 .87072 m
.03005 .82703 L
s
% Start of user PostScript
-3. 2.57143 -3.25975 2.26838 MAarrowhead1
% End of user PostScript
.0675 .9325 m
.02381 .88881 L
s
% Start of user PostScript
-3. 3. -3.30305 2.69695 MAarrowhead1
% End of user PostScript
.12928 .0675 m
.17297 .03005 L
s
% Start of user PostScript
-2.57143 -3. -2.26838 -3.25975 MAarrowhead1
% End of user PostScript
.12928 .12928 m
.16673 .09184 L
s
% Start of user PostScript
-2.57143 -2.57143 -2.31168 -2.83118 MAarrowhead1
% End of user PostScript
.12928 .19107 m
.16049 .15362 L
s
% Start of user PostScript
-2.57143 -2.14286 -2.35497 -2.40261 MAarrowhead1
% End of user PostScript
.12928 .25286 m
.15425 .21541 L
s
% Start of user PostScript
-2.57143 -1.71429 -2.39826 -1.97404 MAarrowhead1
% End of user PostScript
.12928 .31464 m
.14801 .27719 L
s
% Start of user PostScript
-2.57143 -1.28571 -2.44155 -1.54547 MAarrowhead1
% End of user PostScript
.12928 .37643 m
.14177 .33898 L
s
% Start of user PostScript
-2.57143 -0.857143 -2.48484 -1.1169 MAarrowhead1
% End of user PostScript
.12928 .43821 m
.13553 .40077 L
s
% Start of user PostScript
-2.57143 -0.428571 -2.52814 -0.688325 MAarrowhead1
% End of user PostScript
.12928 .5 m
.12928 .46255 L
s
% Start of user PostScript
-2.57143 0 -2.57143 -0.259754 MAarrowhead1
% End of user PostScript
.12928 .56179 m
.12304 .52434 L
s
% Start of user PostScript
-2.57143 0.428571 -2.61472 0.168818 MAarrowhead1
% End of user PostScript
.12928 .62357 m
.1168 .58612 L
s
% Start of user PostScript
-2.57143 0.857143 -2.65801 0.597389 MAarrowhead1
% End of user PostScript
.12928 .68536 m
.11056 .64791 L
s
% Start of user PostScript
-2.57143 1.28571 -2.70131 1.02596 MAarrowhead1
% End of user PostScript
.12928 .74714 m
.10432 .7097 L
s
% Start of user PostScript
-2.57143 1.71429 -2.7446 1.45453 MAarrowhead1
% End of user PostScript
.12928 .80893 m
.09808 .77148 L
s
% Start of user PostScript
-2.57143 2.14286 -2.78789 1.8831 MAarrowhead1
% End of user PostScript
.12928 .87072 m
.09184 .83327 L
s
% Start of user PostScript
-2.57143 2.57143 -2.83118 2.31168 MAarrowhead1
% End of user PostScript
.12928 .9325 m
.0856 .89505 L
s
% Start of user PostScript
-2.57143 3. -2.87447 2.74025 MAarrowhead1
% End of user PostScript
.19107 .0675 m
.23476 .03629 L
s
% Start of user PostScript
-2.14286 -3. -1.83981 -3.21646 MAarrowhead1
% End of user PostScript
.19107 .12928 m
.22852 .09808 L
s
% Start of user PostScript
-2.14286 -2.57143 -1.8831 -2.78789 MAarrowhead1
% End of user PostScript
.19107 .19107 m
.22228 .15986 L
s
% Start of user PostScript
-2.14286 -2.14286 -1.9264 -2.35932 MAarrowhead1
% End of user PostScript
.19107 .25286 m
.21604 .22165 L
s
% Start of user PostScript
-2.14286 -1.71429 -1.96969 -1.93075 MAarrowhead1
% End of user PostScript
.19107 .31464 m
.20979 .28344 L
s
% Start of user PostScript
-2.14286 -1.28571 -2.01298 -1.50218 MAarrowhead1
% End of user PostScript
.19107 .37643 m
.20355 .34522 L
s
% Start of user PostScript
-2.14286 -0.857143 -2.05627 -1.0736 MAarrowhead1
% End of user PostScript
.19107 .43821 m
.19731 .40701 L
s
% Start of user PostScript
-2.14286 -0.428571 -2.09956 -0.645033 MAarrowhead1
% End of user PostScript
.19107 .5 m
.19107 .46879 L
s
% Start of user PostScript
-2.14286 0 -2.14286 -0.216461 MAarrowhead1
% End of user PostScript
.19107 .56179 m
.18483 .53058 L
s
% Start of user PostScript
-2.14286 0.428571 -2.18615 0.21211 MAarrowhead1
% End of user PostScript
.19107 .62357 m
.17859 .59237 L
s
% Start of user PostScript
-2.14286 0.857143 -2.22944 0.640682 MAarrowhead1
% End of user PostScript
.19107 .68536 m
.17235 .65415 L
s
% Start of user PostScript
-2.14286 1.28571 -2.27273 1.06925 MAarrowhead1
% End of user PostScript
.19107 .74714 m
.16611 .71594 L
s
% Start of user PostScript
-2.14286 1.71429 -2.31603 1.49782 MAarrowhead1
% End of user PostScript
.19107 .80893 m
.15986 .77772 L
s
% Start of user PostScript
-2.14286 2.14286 -2.35932 1.9264 MAarrowhead1
% End of user PostScript
.19107 .87072 m
.15362 .83951 L
s
% Start of user PostScript
-2.14286 2.57143 -2.40261 2.35497 MAarrowhead1
% End of user PostScript
.19107 .9325 m
.14738 .90129 L
s
% Start of user PostScript
-2.14286 3. -2.4459 2.78354 MAarrowhead1
% End of user PostScript
.25286 .0675 m
.29655 .04253 L
s
% Start of user PostScript
-1.71429 -3. -1.41124 -3.17317 MAarrowhead1
% End of user PostScript
.25286 .12928 m
.2903 .10432 L
s
% Start of user PostScript
-1.71429 -2.57143 -1.45453 -2.7446 MAarrowhead1
% End of user PostScript
.25286 .19107 m
.28406 .16611 L
s
% Start of user PostScript
-1.71429 -2.14286 -1.49782 -2.31603 MAarrowhead1
% End of user PostScript
.25286 .25286 m
.27782 .22789 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.54112 -1.88745 MAarrowhead1
% End of user PostScript
.25286 .31464 m
.27158 .28968 L
s
% Start of user PostScript
-1.71429 -1.28571 -1.58441 -1.45888 MAarrowhead1
% End of user PostScript
.25286 .37643 m
.26534 .35146 L
s
% Start of user PostScript
-1.71429 -0.857143 -1.6277 -1.03031 MAarrowhead1
% End of user PostScript
.25286 .43821 m
.2591 .41325 L
s
% Start of user PostScript
-1.71429 -0.428571 -1.67099 -0.60174 MAarrowhead1
% End of user PostScript
.25286 .5 m
.25286 .47503 L
s
% Start of user PostScript
-1.71429 0 -1.71429 -0.173169 MAarrowhead1
% End of user PostScript
.25286 .56179 m
.24662 .53682 L
s
% Start of user PostScript
-1.71429 0.428571 -1.75758 0.255402 MAarrowhead1
% End of user PostScript
.25286 .62357 m
.24037 .59861 L
s
% Start of user PostScript
-1.71429 0.857143 -1.80087 0.683974 MAarrowhead1
% End of user PostScript
.25286 .68536 m
.23413 .66039 L
s
% Start of user PostScript
-1.71429 1.28571 -1.84416 1.11255 MAarrowhead1
% End of user PostScript
.25286 .74714 m
.22789 .72218 L
s
% Start of user PostScript
-1.71429 1.71429 -1.88745 1.54112 MAarrowhead1
% End of user PostScript
.25286 .80893 m
.22165 .78396 L
s
% Start of user PostScript
-1.71429 2.14286 -1.93075 1.96969 MAarrowhead1
% End of user PostScript
.25286 .87072 m
.21541 .84575 L
s
% Start of user PostScript
-1.71429 2.57143 -1.97404 2.39826 MAarrowhead1
% End of user PostScript
.25286 .9325 m
.20917 .90754 L
s
% Start of user PostScript
-1.71429 3. -2.01733 2.82683 MAarrowhead1
% End of user PostScript
.31464 .0675 m
.35833 .04877 L
s
% Start of user PostScript
-1.28571 -3. -0.982669 -3.12988 MAarrowhead1
% End of user PostScript
.31464 .12928 m
.35209 .11056 L
s
% Start of user PostScript
-1.28571 -2.57143 -1.02596 -2.70131 MAarrowhead1
% End of user PostScript
.31464 .19107 m
.34585 .17235 L
s
% Start of user PostScript
-1.28571 -2.14286 -1.06925 -2.27273 MAarrowhead1
% End of user PostScript
.31464 .25286 m
.33961 .23413 L
s
% Start of user PostScript
-1.28571 -1.71429 -1.11255 -1.84416 MAarrowhead1
% End of user PostScript
.31464 .31464 m
.33337 .29592 L
s
% Start of user PostScript
-1.28571 -1.28571 -1.15584 -1.41559 MAarrowhead1
% End of user PostScript
.31464 .37643 m
.32712 .3577 L
s
% Start of user PostScript
-1.28571 -0.857143 -1.19913 -0.98702 MAarrowhead1
% End of user PostScript
.31464 .43821 m
.32088 .41949 L
s
% Start of user PostScript
-1.28571 -0.428571 -1.24242 -0.558448 MAarrowhead1
% End of user PostScript
.31464 .5 m
.31464 .48128 L
s
% Start of user PostScript
-1.28571 0 -1.28571 -0.129877 MAarrowhead1
% End of user PostScript
.31464 .56179 m
.3084 .54306 L
s
% Start of user PostScript
-1.28571 0.428571 -1.32901 0.298695 MAarrowhead1
% End of user PostScript
.31464 .62357 m
.30216 .60485 L
s
% Start of user PostScript
-1.28571 0.857143 -1.3723 0.727266 MAarrowhead1
% End of user PostScript
.31464 .68536 m
.29592 .66663 L
s
% Start of user PostScript
-1.28571 1.28571 -1.41559 1.15584 MAarrowhead1
% End of user PostScript
.31464 .74714 m
.28968 .72842 L
s
% Start of user PostScript
-1.28571 1.71429 -1.45888 1.58441 MAarrowhead1
% End of user PostScript
.31464 .80893 m
.28344 .79021 L
s
% Start of user PostScript
-1.28571 2.14286 -1.50218 2.01298 MAarrowhead1
% End of user PostScript
.31464 .87072 m
.27719 .85199 L
s
% Start of user PostScript
-1.28571 2.57143 -1.54547 2.44155 MAarrowhead1
% End of user PostScript
.31464 .9325 m
.27095 .91378 L
s
% Start of user PostScript
-1.28571 3. -1.58876 2.87012 MAarrowhead1
% End of user PostScript
.37643 .0675 m
.42012 .05502 L
s
% Start of user PostScript
-0.857143 -3. -0.554097 -3.08658 MAarrowhead1
% End of user PostScript
.37643 .12928 m
.41388 .1168 L
s
% Start of user PostScript
-0.857143 -2.57143 -0.597389 -2.65801 MAarrowhead1
% End of user PostScript
.37643 .19107 m
.40763 .17859 L
s
% Start of user PostScript
-0.857143 -2.14286 -0.640682 -2.22944 MAarrowhead1
% End of user PostScript
.37643 .25286 m
.40139 .24037 L
s
% Start of user PostScript
-0.857143 -1.71429 -0.683974 -1.80087 MAarrowhead1
% End of user PostScript
.37643 .31464 m
.39515 .30216 L
s
% Start of user PostScript
-0.857143 -1.28571 -0.727266 -1.3723 MAarrowhead1
% End of user PostScript
.37643 .37643 m
.38891 .36395 L
s
% Start of user PostScript
-0.857143 -0.857143 -0.770558 -0.943727 MAarrowhead1
% End of user PostScript
.37643 .43821 m
.38267 .42573 L
s
% Start of user PostScript
-0.857143 -0.428571 -0.813851 -0.515156 MAarrowhead1
% End of user PostScript
.37643 .5 m
.37643 .48752 L
s
% Start of user PostScript
-0.857143 0 -0.857143 -0.0865845 MAarrowhead1
% End of user PostScript
.37643 .56179 m
.37019 .5493 L
s
% Start of user PostScript
-0.857143 0.428571 -0.900435 0.341987 MAarrowhead1
% End of user PostScript
.37643 .62357 m
.36395 .61109 L
s
% Start of user PostScript
-0.857143 0.857143 -0.943727 0.770558 MAarrowhead1
% End of user PostScript
.37643 .68536 m
.3577 .67288 L
s
% Start of user PostScript
-0.857143 1.28571 -0.98702 1.19913 MAarrowhead1
% End of user PostScript
.37643 .74714 m
.35146 .73466 L
s
% Start of user PostScript
-0.857143 1.71429 -1.03031 1.6277 MAarrowhead1
% End of user PostScript
.37643 .80893 m
.34522 .79645 L
s
% Start of user PostScript
-0.857143 2.14286 -1.0736 2.05627 MAarrowhead1
% End of user PostScript
.37643 .87072 m
.33898 .85823 L
s
% Start of user PostScript
-0.857143 2.57143 -1.1169 2.48484 MAarrowhead1
% End of user PostScript
.37643 .9325 m
.33274 .92002 L
s
% Start of user PostScript
-0.857143 3. -1.16019 2.91342 MAarrowhead1
% End of user PostScript
.43821 .0675 m
.4819 .06126 L
s
% Start of user PostScript
-0.428571 -3. -0.125526 -3.04329 MAarrowhead1
% End of user PostScript
.43821 .12928 m
.47566 .12304 L
s
% Start of user PostScript
-0.428571 -2.57143 -0.168818 -2.61472 MAarrowhead1
% End of user PostScript
.43821 .19107 m
.46942 .18483 L
s
% Start of user PostScript
-0.428571 -2.14286 -0.21211 -2.18615 MAarrowhead1
% End of user PostScript
.43821 .25286 m
.46318 .24662 L
s
% Start of user PostScript
-0.428571 -1.71429 -0.255402 -1.75758 MAarrowhead1
% End of user PostScript
.43821 .31464 m
.45694 .3084 L
s
% Start of user PostScript
-0.428571 -1.28571 -0.298695 -1.32901 MAarrowhead1
% End of user PostScript
.43821 .37643 m
.4507 .37019 L
s
% Start of user PostScript
-0.428571 -0.857143 -0.341987 -0.900435 MAarrowhead1
% End of user PostScript
.43821 .43821 m
.44446 .43197 L
s
% Start of user PostScript
-0.428571 -0.428571 -0.385279 -0.471864 MAarrowhead1
% End of user PostScript
.43821 .5 m
.43821 .49376 L
s
% Start of user PostScript
-0.428571 0 -0.428571 -0.0432923 MAarrowhead1
% End of user PostScript
.43821 .56179 m
.43197 .55554 L
s
% Start of user PostScript
-0.428571 0.428571 -0.471864 0.385279 MAarrowhead1
% End of user PostScript
.43821 .62357 m
.42573 .61733 L
s
% Start of user PostScript
-0.428571 0.857143 -0.515156 0.813851 MAarrowhead1
% End of user PostScript
.43821 .68536 m
.41949 .67912 L
s
% Start of user PostScript
-0.428571 1.28571 -0.558448 1.24242 MAarrowhead1
% End of user PostScript
.43821 .74714 m
.41325 .7409 L
s
% Start of user PostScript
-0.428571 1.71429 -0.60174 1.67099 MAarrowhead1
% End of user PostScript
.43821 .80893 m
.40701 .80269 L
s
% Start of user PostScript
-0.428571 2.14286 -0.645033 2.09956 MAarrowhead1
% End of user PostScript
.43821 .87072 m
.40077 .86447 L
s
% Start of user PostScript
-0.428571 2.57143 -0.688325 2.52814 MAarrowhead1
% End of user PostScript
.43821 .9325 m
.39452 .92626 L
s
% Start of user PostScript
-0.428571 3. -0.731617 2.95671 MAarrowhead1
% End of user PostScript
.5 .0675 m
.54369 .0675 L
s
% Start of user PostScript
0 -3. 0.303046 -3. MAarrowhead1
% End of user PostScript
.5 .12928 m
.53745 .12928 L
s
% Start of user PostScript
0 -2.57143 0.259754 -2.57143 MAarrowhead1
% End of user PostScript
.5 .19107 m
.53121 .19107 L
s
% Start of user PostScript
0 -2.14286 0.216461 -2.14286 MAarrowhead1
% End of user PostScript
.5 .25286 m
.52497 .25286 L
s
% Start of user PostScript
0 -1.71429 0.173169 -1.71429 MAarrowhead1
% End of user PostScript
.5 .31464 m
.51872 .31464 L
s
% Start of user PostScript
0 -1.28571 0.129877 -1.28571 MAarrowhead1
% End of user PostScript
.5 .37643 m
.51248 .37643 L
s
% Start of user PostScript
0 -0.857143 0.0865845 -0.857143 MAarrowhead1
% End of user PostScript
.5 .43821 m
.50624 .43821 L
s
% Start of user PostScript
0 -0.428571 0.0432923 -0.428571 MAarrowhead1
% End of user PostScript
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .56179 m
.49376 .56179 L
s
% Start of user PostScript
0 0.428571 -0.0432923 0.428571 MAarrowhead1
% End of user PostScript
.5 .62357 m
.48752 .62357 L
s
% Start of user PostScript
0 0.857143 -0.0865845 0.857143 MAarrowhead1
% End of user PostScript
.5 .68536 m
.48128 .68536 L
s
% Start of user PostScript
0 1.28571 -0.129877 1.28571 MAarrowhead1
% End of user PostScript
.5 .74714 m
.47503 .74714 L
s
% Start of user PostScript
0 1.71429 -0.173169 1.71429 MAarrowhead1
% End of user PostScript
.5 .80893 m
.46879 .80893 L
s
% Start of user PostScript
0 2.14286 -0.216461 2.14286 MAarrowhead1
% End of user PostScript
.5 .87072 m
.46255 .87072 L
s
% Start of user PostScript
0 2.57143 -0.259754 2.57143 MAarrowhead1
% End of user PostScript
.5 .9325 m
.45631 .9325 L
s
% Start of user PostScript
0 3. -0.303046 3. MAarrowhead1
% End of user PostScript
.56179 .0675 m
.60548 .07374 L
s
% Start of user PostScript
0.428571 -3. 0.731617 -2.95671 MAarrowhead1
% End of user PostScript
.56179 .12928 m
.59923 .13553 L
s
% Start of user PostScript
0.428571 -2.57143 0.688325 -2.52814 MAarrowhead1
% End of user PostScript
.56179 .19107 m
.59299 .19731 L
s
% Start of user PostScript
0.428571 -2.14286 0.645033 -2.09956 MAarrowhead1
% End of user PostScript
.56179 .25286 m
.58675 .2591 L
s
% Start of user PostScript
0.428571 -1.71429 0.60174 -1.67099 MAarrowhead1
% End of user PostScript
.56179 .31464 m
.58051 .32088 L
s
% Start of user PostScript
0.428571 -1.28571 0.558448 -1.24242 MAarrowhead1
% End of user PostScript
.56179 .37643 m
.57427 .38267 L
s
% Start of user PostScript
0.428571 -0.857143 0.515156 -0.813851 MAarrowhead1
% End of user PostScript
.56179 .43821 m
.56803 .44446 L
s
% Start of user PostScript
0.428571 -0.428571 0.471864 -0.385279 MAarrowhead1
% End of user PostScript
.56179 .5 m
.56179 .50624 L
s
% Start of user PostScript
0.428571 0 0.428571 0.0432923 MAarrowhead1
% End of user PostScript
.56179 .56179 m
.55554 .56803 L
s
% Start of user PostScript
0.428571 0.428571 0.385279 0.471864 MAarrowhead1
% End of user PostScript
.56179 .62357 m
.5493 .62981 L
s
% Start of user PostScript
0.428571 0.857143 0.341987 0.900435 MAarrowhead1
% End of user PostScript
.56179 .68536 m
.54306 .6916 L
s
% Start of user PostScript
0.428571 1.28571 0.298695 1.32901 MAarrowhead1
% End of user PostScript
.56179 .74714 m
.53682 .75338 L
s
% Start of user PostScript
0.428571 1.71429 0.255402 1.75758 MAarrowhead1
% End of user PostScript
.56179 .80893 m
.53058 .81517 L
s
% Start of user PostScript
0.428571 2.14286 0.21211 2.18615 MAarrowhead1
% End of user PostScript
.56179 .87072 m
.52434 .87696 L
s
% Start of user PostScript
0.428571 2.57143 0.168818 2.61472 MAarrowhead1
% End of user PostScript
.56179 .9325 m
.5181 .93874 L
s
% Start of user PostScript
0.428571 3. 0.125526 3.04329 MAarrowhead1
% End of user PostScript
.62357 .0675 m
.66726 .07998 L
s
% Start of user PostScript
0.857143 -3. 1.16019 -2.91342 MAarrowhead1
% End of user PostScript
.62357 .12928 m
.66102 .14177 L
s
% Start of user PostScript
0.857143 -2.57143 1.1169 -2.48484 MAarrowhead1
% End of user PostScript
.62357 .19107 m
.65478 .20355 L
s
% Start of user PostScript
0.857143 -2.14286 1.0736 -2.05627 MAarrowhead1
% End of user PostScript
.62357 .25286 m
.64854 .26534 L
s
% Start of user PostScript
0.857143 -1.71429 1.03031 -1.6277 MAarrowhead1
% End of user PostScript
.62357 .31464 m
.6423 .32712 L
s
% Start of user PostScript
0.857143 -1.28571 0.98702 -1.19913 MAarrowhead1
% End of user PostScript
.62357 .37643 m
.63605 .38891 L
s
% Start of user PostScript
0.857143 -0.857143 0.943727 -0.770558 MAarrowhead1
% End of user PostScript
.62357 .43821 m
.62981 .4507 L
s
% Start of user PostScript
0.857143 -0.428571 0.900435 -0.341987 MAarrowhead1
% End of user PostScript
.62357 .5 m
.62357 .51248 L
s
% Start of user PostScript
0.857143 0 0.857143 0.0865845 MAarrowhead1
% End of user PostScript
.62357 .56179 m
.61733 .57427 L
s
% Start of user PostScript
0.857143 0.428571 0.813851 0.515156 MAarrowhead1
% End of user PostScript
.62357 .62357 m
.61109 .63605 L
s
% Start of user PostScript
0.857143 0.857143 0.770558 0.943727 MAarrowhead1
% End of user PostScript
.62357 .68536 m
.60485 .69784 L
s
% Start of user PostScript
0.857143 1.28571 0.727266 1.3723 MAarrowhead1
% End of user PostScript
.62357 .74714 m
.59861 .75963 L
s
% Start of user PostScript
0.857143 1.71429 0.683974 1.80087 MAarrowhead1
% End of user PostScript
.62357 .80893 m
.59237 .82141 L
s
% Start of user PostScript
0.857143 2.14286 0.640682 2.22944 MAarrowhead1
% End of user PostScript
.62357 .87072 m
.58612 .8832 L
s
% Start of user PostScript
0.857143 2.57143 0.597389 2.65801 MAarrowhead1
% End of user PostScript
.62357 .9325 m
.57988 .94498 L
s
% Start of user PostScript
0.857143 3. 0.554097 3.08658 MAarrowhead1
% End of user PostScript
.68536 .0675 m
.72905 .08622 L
s
% Start of user PostScript
1.28571 -3. 1.58876 -2.87012 MAarrowhead1
% End of user PostScript
.68536 .12928 m
.72281 .14801 L
s
% Start of user PostScript
1.28571 -2.57143 1.54547 -2.44155 MAarrowhead1
% End of user PostScript
.68536 .19107 m
.71656 .20979 L
s
% Start of user PostScript
1.28571 -2.14286 1.50218 -2.01298 MAarrowhead1
% End of user PostScript
.68536 .25286 m
.71032 .27158 L
s
% Start of user PostScript
1.28571 -1.71429 1.45888 -1.58441 MAarrowhead1
% End of user PostScript
.68536 .31464 m
.70408 .33337 L
s
% Start of user PostScript
1.28571 -1.28571 1.41559 -1.15584 MAarrowhead1
% End of user PostScript
.68536 .37643 m
.69784 .39515 L
s
% Start of user PostScript
1.28571 -0.857143 1.3723 -0.727266 MAarrowhead1
% End of user PostScript
.68536 .43821 m
.6916 .45694 L
s
% Start of user PostScript
1.28571 -0.428571 1.32901 -0.298695 MAarrowhead1
% End of user PostScript
.68536 .5 m
.68536 .51872 L
s
% Start of user PostScript
1.28571 0 1.28571 0.129877 MAarrowhead1
% End of user PostScript
.68536 .56179 m
.67912 .58051 L
s
% Start of user PostScript
1.28571 0.428571 1.24242 0.558448 MAarrowhead1
% End of user PostScript
.68536 .62357 m
.67288 .6423 L
s
% Start of user PostScript
1.28571 0.857143 1.19913 0.98702 MAarrowhead1
% End of user PostScript
.68536 .68536 m
.66663 .70408 L
s
% Start of user PostScript
1.28571 1.28571 1.15584 1.41559 MAarrowhead1
% End of user PostScript
.68536 .74714 m
.66039 .76587 L
s
% Start of user PostScript
1.28571 1.71429 1.11255 1.84416 MAarrowhead1
% End of user PostScript
.68536 .80893 m
.65415 .82765 L
s
% Start of user PostScript
1.28571 2.14286 1.06925 2.27273 MAarrowhead1
% End of user PostScript
.68536 .87072 m
.64791 .88944 L
s
% Start of user PostScript
1.28571 2.57143 1.02596 2.70131 MAarrowhead1
% End of user PostScript
.68536 .9325 m
.64167 .95123 L
s
% Start of user PostScript
1.28571 3. 0.982669 3.12988 MAarrowhead1
% End of user PostScript
.74714 .0675 m
.79083 .09246 L
s
% Start of user PostScript
1.71429 -3. 2.01733 -2.82683 MAarrowhead1
% End of user PostScript
.74714 .12928 m
.78459 .15425 L
s
% Start of user PostScript
1.71429 -2.57143 1.97404 -2.39826 MAarrowhead1
% End of user PostScript
.74714 .19107 m
.77835 .21604 L
s
% Start of user PostScript
1.71429 -2.14286 1.93075 -1.96969 MAarrowhead1
% End of user PostScript
.74714 .25286 m
.77211 .27782 L
s
% Start of user PostScript
1.71429 -1.71429 1.88745 -1.54112 MAarrowhead1
% End of user PostScript
.74714 .31464 m
.76587 .33961 L
s
% Start of user PostScript
1.71429 -1.28571 1.84416 -1.11255 MAarrowhead1
% End of user PostScript
.74714 .37643 m
.75963 .40139 L
s
% Start of user PostScript
1.71429 -0.857143 1.80087 -0.683974 MAarrowhead1
% End of user PostScript
.74714 .43821 m
.75338 .46318 L
s
% Start of user PostScript
1.71429 -0.428571 1.75758 -0.255402 MAarrowhead1
% End of user PostScript
.74714 .5 m
.74714 .52497 L
s
% Start of user PostScript
1.71429 0 1.71429 0.173169 MAarrowhead1
% End of user PostScript
.74714 .56179 m
.7409 .58675 L
s
% Start of user PostScript
1.71429 0.428571 1.67099 0.60174 MAarrowhead1
% End of user PostScript
.74714 .62357 m
.73466 .64854 L
s
% Start of user PostScript
1.71429 0.857143 1.6277 1.03031 MAarrowhead1
% End of user PostScript
.74714 .68536 m
.72842 .71032 L
s
% Start of user PostScript
1.71429 1.28571 1.58441 1.45888 MAarrowhead1
% End of user PostScript
.74714 .74714 m
.72218 .77211 L
s
% Start of user PostScript
1.71429 1.71429 1.54112 1.88745 MAarrowhead1
% End of user PostScript
.74714 .80893 m
.71594 .83389 L
s
% Start of user PostScript
1.71429 2.14286 1.49782 2.31603 MAarrowhead1
% End of user PostScript
.74714 .87072 m
.7097 .89568 L
s
% Start of user PostScript
1.71429 2.57143 1.45453 2.7446 MAarrowhead1
% End of user PostScript
.74714 .9325 m
.70345 .95747 L
s
% Start of user PostScript
1.71429 3. 1.41124 3.17317 MAarrowhead1
% End of user PostScript
.80893 .0675 m
.85262 .09871 L
s
% Start of user PostScript
2.14286 -3. 2.4459 -2.78354 MAarrowhead1
% End of user PostScript
.80893 .12928 m
.84638 .16049 L
s
% Start of user PostScript
2.14286 -2.57143 2.40261 -2.35497 MAarrowhead1
% End of user PostScript
.80893 .19107 m
.84014 .22228 L
s
% Start of user PostScript
2.14286 -2.14286 2.35932 -1.9264 MAarrowhead1
% End of user PostScript
.80893 .25286 m
.83389 .28406 L
s
% Start of user PostScript
2.14286 -1.71429 2.31603 -1.49782 MAarrowhead1
% End of user PostScript
.80893 .31464 m
.82765 .34585 L
s
% Start of user PostScript
2.14286 -1.28571 2.27273 -1.06925 MAarrowhead1
% End of user PostScript
.80893 .37643 m
.82141 .40763 L
s
% Start of user PostScript
2.14286 -0.857143 2.22944 -0.640682 MAarrowhead1
% End of user PostScript
.80893 .43821 m
.81517 .46942 L
s
% Start of user PostScript
2.14286 -0.428571 2.18615 -0.21211 MAarrowhead1
% End of user PostScript
.80893 .5 m
.80893 .53121 L
s
% Start of user PostScript
2.14286 0 2.14286 0.216461 MAarrowhead1
% End of user PostScript
.80893 .56179 m
.80269 .59299 L
s
% Start of user PostScript
2.14286 0.428571 2.09956 0.645033 MAarrowhead1
% End of user PostScript
.80893 .62357 m
.79645 .65478 L
s
% Start of user PostScript
2.14286 0.857143 2.05627 1.0736 MAarrowhead1
% End of user PostScript
.80893 .68536 m
.79021 .71656 L
s
% Start of user PostScript
2.14286 1.28571 2.01298 1.50218 MAarrowhead1
% End of user PostScript
.80893 .74714 m
.78396 .77835 L
s
% Start of user PostScript
2.14286 1.71429 1.96969 1.93075 MAarrowhead1
% End of user PostScript
.80893 .80893 m
.77772 .84014 L
s
% Start of user PostScript
2.14286 2.14286 1.9264 2.35932 MAarrowhead1
% End of user PostScript
.80893 .87072 m
.77148 .90192 L
s
% Start of user PostScript
2.14286 2.57143 1.8831 2.78789 MAarrowhead1
% End of user PostScript
.80893 .9325 m
.76524 .96371 L
s
% Start of user PostScript
2.14286 3. 1.83981 3.21646 MAarrowhead1
% End of user PostScript
.87072 .0675 m
.9144 .10495 L
s
% Start of user PostScript
2.57143 -3. 2.87447 -2.74025 MAarrowhead1
% End of user PostScript
.87072 .12928 m
.90816 .16673 L
s
% Start of user PostScript
2.57143 -2.57143 2.83118 -2.31168 MAarrowhead1
% End of user PostScript
.87072 .19107 m
.90192 .22852 L
s
% Start of user PostScript
2.57143 -2.14286 2.78789 -1.8831 MAarrowhead1
% End of user PostScript
.87072 .25286 m
.89568 .2903 L
s
% Start of user PostScript
2.57143 -1.71429 2.7446 -1.45453 MAarrowhead1
% End of user PostScript
.87072 .31464 m
.88944 .35209 L
s
% Start of user PostScript
2.57143 -1.28571 2.70131 -1.02596 MAarrowhead1
% End of user PostScript
.87072 .37643 m
.8832 .41388 L
s
% Start of user PostScript
2.57143 -0.857143 2.65801 -0.597389 MAarrowhead1
% End of user PostScript
.87072 .43821 m
.87696 .47566 L
s
% Start of user PostScript
2.57143 -0.428571 2.61472 -0.168818 MAarrowhead1
% End of user PostScript
.87072 .5 m
.87072 .53745 L
s
% Start of user PostScript
2.57143 0 2.57143 0.259754 MAarrowhead1
% End of user PostScript
.87072 .56179 m
.86447 .59923 L
s
% Start of user PostScript
2.57143 0.428571 2.52814 0.688325 MAarrowhead1
% End of user PostScript
.87072 .62357 m
.85823 .66102 L
s
% Start of user PostScript
2.57143 0.857143 2.48484 1.1169 MAarrowhead1
% End of user PostScript
.87072 .68536 m
.85199 .72281 L
s
% Start of user PostScript
2.57143 1.28571 2.44155 1.54547 MAarrowhead1
% End of user PostScript
.87072 .74714 m
.84575 .78459 L
s
% Start of user PostScript
2.57143 1.71429 2.39826 1.97404 MAarrowhead1
% End of user PostScript
.87072 .80893 m
.83951 .84638 L
s
% Start of user PostScript
2.57143 2.14286 2.35497 2.40261 MAarrowhead1
% End of user PostScript
.87072 .87072 m
.83327 .90816 L
s
% Start of user PostScript
2.57143 2.57143 2.31168 2.83118 MAarrowhead1
% End of user PostScript
.87072 .9325 m
.82703 .96995 L
s
% Start of user PostScript
2.57143 3. 2.26838 3.25975 MAarrowhead1
% End of user PostScript
.9325 .0675 m
.97619 .11119 L
s
% Start of user PostScript
3. -3. 3.30305 -2.69695 MAarrowhead1
% End of user PostScript
.9325 .12928 m
.96995 .17297 L
s
% Start of user PostScript
3. -2.57143 3.25975 -2.26838 MAarrowhead1
% End of user PostScript
.9325 .19107 m
.96371 .23476 L
s
% Start of user PostScript
3. -2.14286 3.21646 -1.83981 MAarrowhead1
% End of user PostScript
.9325 .25286 m
.95747 .29655 L
s
% Start of user PostScript
3. -1.71429 3.17317 -1.41124 MAarrowhead1
% End of user PostScript
.9325 .31464 m
.95123 .35833 L
s
% Start of user PostScript
3. -1.28571 3.12988 -0.982669 MAarrowhead1
% End of user PostScript
.9325 .37643 m
.94498 .42012 L
s
% Start of user PostScript
3. -0.857143 3.08658 -0.554097 MAarrowhead1
% End of user PostScript
.9325 .43821 m
.93874 .4819 L
s
% Start of user PostScript
3. -0.428571 3.04329 -0.125526 MAarrowhead1
% End of user PostScript
.9325 .5 m
.9325 .54369 L
s
% Start of user PostScript
3. 0 3. 0.303046 MAarrowhead1
% End of user PostScript
.9325 .56179 m
.92626 .60548 L
s
% Start of user PostScript
3. 0.428571 2.95671 0.731617 MAarrowhead1
% End of user PostScript
.9325 .62357 m
.92002 .66726 L
s
% Start of user PostScript
3. 0.857143 2.91342 1.16019 MAarrowhead1
% End of user PostScript
.9325 .68536 m
.91378 .72905 L
s
% Start of user PostScript
3. 1.28571 2.87012 1.58876 MAarrowhead1
% End of user PostScript
.9325 .74714 m
.90754 .79083 L
s
% Start of user PostScript
3. 1.71429 2.82683 2.01733 MAarrowhead1
% End of user PostScript
.9325 .80893 m
.90129 .85262 L
s
% Start of user PostScript
3. 2.14286 2.78354 2.4459 MAarrowhead1
% End of user PostScript
.9325 .87072 m
.89505 .9144 L
s
% Start of user PostScript
3. 2.57143 2.74025 2.87447 MAarrowhead1
% End of user PostScript
.9325 .9325 m
.88881 .97619 L
s
% Start of user PostScript
3. 3. 2.69695 3.30305 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{174, 174},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002^0000[R000`400?l00000o`00003oE_ooool0
0ol0003oooooooooo`1Eooooo`00E_ooool00ol0003oooooooooo`1Eooooo`00E_ooool2o`0005Ko
oooo001Fooooo`03o`000?oooooooooo05Gooooo001Fooooo`03o`000?oooooooooo05Gooooo000B
ooooo`;o0000@_ooool00ol0003oooooooooo`1Eooooo`004?ooool4o`0000Sooooo0_l0000hoooo
o`03o`000?oooooooooo05Gooooo000@ooooo`?o00001oooool4o`0000Wooooo0_l0000]ooooo`;o
0000E_ooool000oooooo00?o0000ooooool000002?ooool3o`0000Sooooo1?l00008ooooo`?o0000
8_ooool00ol0003oooooooooo`1Eooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooo000000Sooooo1?l00007ooooo`?o00002_ooool2o`0001Sooooo00?o0000ooooooooool0EOoo
ool000gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`0000Oooooo0ol00008ooooo`Co00002?ooool4o`0000Kooooo0ol00004ooooo`03o`000?oo
oooooooo05Gooooo000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`;o00002Oooool2o`0000;ooooo00?o0000ooooooooool01Oooool4
o`0000Oooooo1_l00002ooooo`04o`000?ooooooooooooooo`?o0000DOooool000_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o00000_ooool00ol0003oooooooooo`07
o`000004ooooool0003o0000o`0000?ooooo2Ol00002ooooo`Oo00000oooool3o`0000Sooooo0_l0
0009ooooo`;o00002?ooool2o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo00[ooooo001@
ooooo`;o00001?ooool01?l0003oooooooooooooool2o`0000Wooooo1?l00005ooooo`Go00001Ooo
ool5o`0000Kooooo0_l00008ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0:ooooo`00D_ooool01Ol0003ooooooooooooooooo000000kooooo0_l0
0008ooooo`Go00001oooool3o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`004Oooool2o`0003_ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo027ooooo1Ol00007ooooo`;o00001ooo
ool3o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`004?ooool3
o`0000Sooooo0_l0000booooo`?o00001?ooool00ol0003oooooooooo`0/ooooo`Co00001oooool2
o`0000Wooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo000?ooooo`?o00002?ooool3o`00
00Wooooo0_l0000^ooooo`;o0000>_ooool00ol0003oooooooooo`06ooooo`;o00002?ooool3o`00
00Kooooo000@ooooo`03o`000?oooooooooo00Kooooo0ol00009ooooo`?o0000;_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool3o`0000Ko
oooo000?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool3o`0000Wooooo
0ol0000Sooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01_ooool2o`0000Gooooo
000>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000Sooooo0ol0
0008ooooo`Co00006Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00?ooooo000=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`;o00002Oooool3o`0000Sooooo1?l0000>ooooo`03o`000?oooooooooo05Gooooo000<oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`;o00002Oooool2o`000003ooooool0003ooooo00Oooooo0ol00008ooooo`Go00000oooool2o`00
0004ooooool0003o0000o`0005;ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool2o`000003ooooool0003ooooo00Gooooo1Ol00006ooooo`Oo00001?ooool6o`00
00Cooooo0ol000000ooooooo0000o`000005ooooo`;o00002Oooool2o`0000Sooooo0_l00009oooo
o`;o00002Oooool00ol0003oooooooooo`0:ooooo`00E_ooool00ol0003oooooooooo`02o`0000Wo
oooo1?l00006ooooo`Co00001_ooool4o`0000Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool005Kooooo
00?o0000ooooooooool05Oooool5o`0000Kooooo1?l00007ooooo`;o00002?ooool3o`0000Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`004?ooool2o`0004Cooooo00?o
0000ooooooooool08oooool2o`0000Kooooo0ol00009ooooo`03o`000?oooooooooo00Oooooo0_l0
0007ooooo`03o`000?oooooooooo00Sooooo000?ooooo`?o00002?ooool2o`0003[ooooo0_l0000_
ooooo`03o`000?oooooooooo00Gooooo0ol00009ooooo`03o`000?oooooooooo00Kooooo0ol00007
ooooo`003_ooool3o`0000Sooooo0ol00009ooooo`;o0000;oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00Gooooo0ol00007ooooo`?o00001oooool000oooooo00?o0000oooooooo
ool01_ooool3o`0000Wooooo0ol00009ooooo`;o00009?ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo00Kooooo0_l00006ooooo`003_ooool00ol0003oooooooooo`08ooooo`;o0000
2?ooool3o`0000Sooooo0ol00009ooooo`;o00006_ooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo00Cooooo000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`06ooooo`?o00002?ooool4o`0000Sooooo0ol0000?ooooo`03o`000?oo
oooooooo05Gooooo000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`;o00002Oooool3o`0000Oooooo1?l00007ooooo`Go00001?ooool2
o`0005Kooooo000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002?ooool3o`00
00Sooooo0ol00006ooooo`03o`000?oooooo000000;o00002?ooool2o`0004Wooooo000;ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000007ooooo`?o
00002?ooool6o`0000Gooooo1Ol00005ooooo`Go00001_ooool2o`000003ooooool0003ooooo00Ko
oooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[o
oooo001>ooooo`Go00000oooool00ol0003oooooooooo`0:ooooo`Co00001_ooool4o`0000Oooooo
0_l00009ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02_ooool004oooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`0Gooooo`;o00001_ooool3o`0000Sooooo0_l00009ooooo`;o00002?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo000?ooooo`03o`000?oooooooooo03Kooooo1Ol0
0003ooooo`03o`000?oooooooooo00?ooooo0_l0000Sooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool2o`0000Wooooo0_l00008ooooo`03o`000?oooooooooo00Sooooo000>
ooooo`;o00002_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l00009
ooooo`;o00002?ooool000gooooo0_l0000:ooooo`;o00002Oooool2o`0002Sooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`?o00002?ooool000kooooo00?o0000ooooooooool01oooool2o`00
00Wooooo0ol00009ooooo`;o00007Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`06ooooo`;o00001oooool000gooooo00?o0000oooo
ooooool02?ooool2o`0000Sooooo0ol00008ooooo`Co00002?ooool2o`0001Cooooo0ol00004oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool01Oooool000cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo1?l00007ooooo`Co
00002?ooool3o`00013ooooo0_l0001Fooooo`003?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooo`000008ooooo`?o0000
1oooool3o`0000Sooooo1Ol00005ooooo`Co0000E?ooool000_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooo`000008ooooo`;o00002?ooool4o`0000Oooooo1Ol00006ooooo`Co00001_oo
ool4o`0000Oooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001<ooooo`03o`000?oooooo
oooo00Oooooo0ol00008ooooo`Go00001oooool3o`0000Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0:ooooo`00E_ooool00ol0003oooooooooo`0Cooooo`Go00001_ooool3o`00
00Sooooo0_l00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`003_ooool00ol0003oooooooooo`15ooooo`;o00008_ooool00ol0003o
ooooooooo`05ooooo`;o00002Oooool2o`0000Sooooo00?o0000ooooool000002?ooool00ol0003o
ooooooooo`09ooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`?o00002?ooool2o`0000Wooooo
0_l00009ooooo`003Oooool2o`0000[ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Wooooo0_l0
0009ooooo`003?ooool3o`0000Wooooo0_l00009ooooo`;o0000<Oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00002Oooool000gooooo0_l00008oooo
o`;o00002Oooool3o`0000Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo00Oooooo0_l00008ooooo`003?ooool00ol0003oooooooooo`08ooooo`;o
00002?ooool3o`0000Wooooo0_l00009ooooo`;o00007?ooool2o`0004gooooo00?o0000oooooooo
ool01_ooool000cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o0000
2?ooool2o`0000Wooooo0ol00008ooooo`?o00004Oooool00ol0003oooooooooo`1Eooooo`003?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool2o`0000Sooooo0ol00007ooooo`?o00002?ooool5o`0000Kooooo0ol00008ooooo`;o00002Ooo
ool00ol0003oooooooooo`0oooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`;o00002Oooool0
0ol0003oooooooooo`07ooooo`?o00002?ooool4o`0000Oooooo0ol00007ooooo`?o00002?ooool2
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool004_ooooo00?o0000ooooooooool02?ooool2o`00
00Sooooo1Ol00006ooooo`Co00001oooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00E_ooool2o`0001Ko
oooo0_l00008ooooo`03o`000?oooooooooo00Kooooo0ol00008ooooo`?o00002?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000=ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`;o00001oooool3o`0000Sooooo
0ol00008ooooo`03o`000?oooooooooo00Wooooo000=ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo0_l0
0007ooooo`?o00002Oooool00ol0003oooooooooo`08ooooo`003?ooool2o`0000[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`?o00001?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00002_ooool000cooooo0_l00009oooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Oooooo0_l00009oooo
o`003?ooool2o`0000Sooooo0ol00009ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00gooooo1Ol00003ooooo`03o`000?oooooooooo00?ooooo0_l0001<ooooo`03
o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o0000
2Oooool2o`0000Wooooo0_l00009ooooo`;o00003?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo05Gooooo000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`06ooooo`?o00002?ooool3o`0000Sooooo0ol0000<ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1;ooooo`002oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2
o`0000Oooooo0ol00008ooooo`?o00001oooool4o`000003ooooool0003o000000Cooooo0ol00008
ooooo`;o00002Oooool2o`00047ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0_l00008oooo
o`?o00001oooool3o`0000?ooooo00?o0000ooooooooool00_ooool4o`0000Kooooo1?l00007oooo
o`?o00002Oooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0047ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`;o00002_ooool2o`0000Sooooo0_l00008ooooo`;o
00002Oooool2o`0000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00[ooooo001Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1_ooool2o`0000Sooooo0_l00008ooooo`?o00002Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00[ooooo000<ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`07ooooo`;o00002?ooool2o`0000Sooooo0ol00009ooooo`03o`000?oo
oooooooo00Wooooo000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`?o00002?ooool3
o`0000[ooooo000;ooooo`?o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`;o00002?ooool3o`00
00[ooooo000;ooooo`?o00002?ooool2o`0000[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Wooooo`;o0000@?ooool00ol0003oooooooooo`07ooooo`;o00002_ooool000_ooooo
00?o0000ooooooooool01oooool3o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Sooooo
000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool3o`0000Sooooo0_l0
000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04_ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0000Wooooo0_l00008
ooooo`;o00001oooool3o`0000Wooooo00?o0000ooooooooool02?ooool2o`00047ooooo000;oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`;o00002?ooool3o`0000Sooooo0ol00007ooooo`?o00001oooool4o`0000Oooooo0ol00008oooo
o`?o00002Oooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool000cooooo0ol0000Eooooo`Go
00003_ooool00ol0003oooooooooo`04ooooo`Co00001oooool3o`0000Sooooo1?l0000:ooooo`03
o`000?oooooooooo00Kooooo1Ol00005ooooo`?o00002Oooool2o`0000;ooooo1Ol000000ooooooo
0000ooooo`09ooooo`03o`000?oooooooooo00Kooooo0ol0000<ooooo`002oooool01Ol0003ooooo
oooooooooooo000001Gooooo00Co0000oooooooooooo00005_ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003oooooo`000006oooo
o`?o00002?ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02o`0000_ooooo0005ooooo`Go000000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`Go00000oooool00ol0003oooooooooo`0>oooo
o`Go00000oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01Oooool2o`0000Sooooo0ol00004ooooo`04o`000?ooooooooooooooo`?o00002?ooool2
o`0000Wooooo0_l0000;ooooo`002oooool01?l0003oooooo`000?l0000Hooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool2o`0000Gooooo00?o0000ooooooooool00ol00008
ooooo`;o00002?ooool3o`0000_ooooo000;ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;o00002?ooool2o`0000Wooooo0_l0000;ooooo`002_oo
ool3o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool04oooool2o`0001Kooooo0_l0000Eooooo`;o0000
5_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;o00002oooool000[ooooo1Ol00006ooooo`?o0000
2Oooool01?l0003oooooooooooooool3o`0000?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool3o`0000ko
oooo00?o0000ooooooooool01Oooool4o`0000_ooooo000;ooooo`03o`000?oooooooooo00Oooooo
0ol00008ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`09ooooo`002oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`?o00002Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool3o`0004_ooooo000;
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`?o00002?ooool3o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo0ol00008ooooo`;o0000@Oooool00:ko000000000ooooooo
0000ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03o`0000Cooooo00?o0000ooooooooool00ol00004ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0003o
ooooooooo`02ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`Co000000?oooooo`000?oo
ool00oooool00ol0003oooooo`000003o`0000Cooooo00Ko0000oooooooooooo0000ooooool00004
ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool1o`00007ooooo0Oooool004[ooooo0ol00009
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`?o00002?ooool2o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`002_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`;o00002?ooool3o`0000Wooooo00?o0000oooo
ooooool02_ooool000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`?o
00002?ooool3o`0000_ooooo000:ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Cooooo0_l0000cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool3o`0000_ooooo000:ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00Oooooo0ol0000;ooooo`002_ooool00ol0003oooooooooo`07ooooo`?o00002?ooool2
o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool02_ooool000_ooooo00?o0000ooooooooool01_ooool3o`00
00Sooooo0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool02_ooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`?o00002?ooool2o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool02?ooool2o`0000Sooooo0_l00011ooooo`002oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool3o`0000Sooooo
0_l00009ooooo`;o00002?ooool3o`0000Wooooo0ol00008ooooo`?o00001oooool3o`0000Oooooo
0_l0000gooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`?o00002?ooool3o`0000Oooooo1?l0
0007ooooo`Co00001oooool2o`0000Wooooo0_l00008ooooo`?o00002?ooool2o`0000Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0010
ooooo`03o`000?oooooooooo00Sooooo0ol00008ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool01oooool2o`0000Wooooo0ol00008ooooo`;o00002Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo0_l00009oooo
o`;o00002?ooool3o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`002Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`?o00002?ooool2o`0000[ooooo00?o0000oooooooo
ool02_ooool000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0oooooo`;o0000
:?ooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0000Sooooo0ol0000<ooooo`002Ooo
ool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`?o00003?oo
ool000Wooooo0ol00008ooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00_ooooo000:ooooo`03o`000?oooooooooo00Oooooo0ol00007ooooo`;o00002Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0;ooooo`002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`;o00005_ooool00ol0003o
ooooooooo`1Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
0_l00009ooooo`;o00002?ooool2o`0000Sooooo0ol00008ooooo`?o00002_ooool2o`0000Wooooo
00?o0000ooooooooool0B_ooool000_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`;o00002?ooool3o`0000Sooooo1?l0
0006ooooo`Co00002?ooool2o`0000Wooooo00?o0000ooooooooool01oooool2o`0000[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool003Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`0000Oooooo1?l00008ooooo`;o00002?oo
ool3o`0000Oooooo0ol00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0:ooooo`00C?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`;o00002?ooool3o`0000Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001@
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08
ooooo`;o00002Oooool3o`0000Sooooo0_l00008ooooo`;o00002_ooool00ol0003oooooooooo`0;
ooooo`002?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00?ooooo0_l0000Loooo
o`03o`000?oooooooooo00Sooooo0_l00009ooooo`;o00002?ooool3o`0000Sooooo0_l0000=oooo
o`002?ooool2o`0000Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool2o`0000Wooooo0ol00008ooooo`;o
00003Oooool000Sooooo0ol00008ooooo`;o00002?ooool2o`00033ooooo0_l00005ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0000Wooooo0_l0000=ooooo`002?oo
ool2o`0000Wooooo0ol00007ooooo`?o00002?ooool2o`0002Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?oo
ool000[ooooo00?o0000ooooooooool01_ooool2o`0000Wooooo0ol00007ooooo`?o00002?ooool2
o`00027ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0<ooooo`002_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`?o00001oooool3o`00
00Oooooo0ol0000Fooooo`;o0000E_ooool000[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`?o00001oooool4o`0000Ko
oooo1Ol00008ooooo`;o00002?ooool2o`0004gooooo000;ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooool000002?ooool3o`0000Sooooo0ol00006ooooo`Co00001oooool4o`0000Sooooo
0_l00009ooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00@?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool5o`0000Oooooo0ol0
0009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool005Kooooo00?o0000
ooooooooool03oooool2o`0000[ooooo0ol00008ooooo`;o00002?ooool2o`0000[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`001oooool00ol0003oooooooooo`1<oooo
o`;o00006oooool2o`0000Wooooo0_l00009ooooo`?o00002?ooool2o`0000[ooooo00?o0000oooo
ooooool02oooool000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool2o`0000[ooooo0_l00008ooooo`?o
00003Oooool000Oooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo0_l00008ooooo`?o0000
3Oooool000Sooooo0_l00008ooooo`;o00002?ooool2o`0000Wooooo0_l0000]ooooo`03o`000?oo
oooooooo03[ooooo0_l00009ooooo`?o00003Oooool000Sooooo0_l00009ooooo`;o00002?ooool2
o`0000Sooooo0ol0000/ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool2
o`0000kooooo0009ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`?o00002?ooool3o`00
00Oooooo0ol0000Qooooo`;o0000A_ooool00ol0003oooooooooo`0=ooooo`002_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`?o00002?ooool3o`0000Ko
oooo1Ol0000Eooooo`03o`000?oooooooooo05Gooooo000:ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`;o00002Oooool2o`0000Sooooo
0ol00006ooooo`Go00002?ooool3o`0000Oooooo0_l0001>ooooo`002oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000002?ooool2o`0000Kooooo1Ol0
0006ooooo`Go00001oooool3o`0000Sooooo0ol00009ooooo`;o00002Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool005Gooooo0_l00005
ooooo`Go00001oooool3o`0000Wooooo00?o0000ooooooooool01oooool2o`0000_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001Foooo
o`;o00003oooool2o`0000[ooooo0ol00008ooooo`;o00002Oooool2o`0000[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0;ooooo`001_ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo01Wooooo0_l00009ooooo`03o`000?oooooooooo00Wooooo0_l00008ooooo`;o
00002oooool00ol0003oooooooooo`0;ooooo`001_ooool2o`0000Sooooo0_l0000looooo`Go0000
0oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool2o`0000Sooooo0ol0000>ooooo`001oooool2o`0000Oooooo0ol00008ooooo`;o0000<_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
2?ooool2o`0000Wooooo0ol0000>ooooo`001oooool2o`0000Sooooo0ol00007ooooo`?o00002?oo
ool2o`0002Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00Sooooo0_l0000?ooooo`002Oooool00ol0003oooooooooo`06ooooo`;o00002?ooool3
o`0000Oooooo0ol00008ooooo`?o00007Oooool00ol0003oooooooooo`02ooooo`;o0000AOooool0
0ol0003oooooooooo`0>ooooo`002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooool000001oooool3o`0000Oooooo1?l00006ooooo`?o00004?ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0EOooool000[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ool000001oooool4o`0000Oooooo1?l00005ooooo`Co00001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool0EOooool000_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Kooooo1?l00003ooooo`So00001_oo
ool2o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0019
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000001Oooool4o`0000Sooooo0_l00009
ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00E_ooool2o`0000?ooooo1Ol00007oooo
o`?o00002Oooool00ol0003oooooooooo`07ooooo`;o00002oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool005Kooooo00?o0000oooooooo
ool03Oooool2o`0000[ooooo0ol00008ooooo`?o00002?ooool2o`0000[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0<ooooo`001Oooool2o`0004oooooo00?o0000ooooooooool0
6?ooool2o`0000Wooooo0_l0000:ooooo`;o00002?ooool2o`0000[ooooo00?o0000ooooooooool0
3Oooool000Gooooo0ol00007ooooo`;o0000AOooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02?ooool3o`0000Sooooo0_l0000?ooooo`001_ooool3
o`0000Kooooo0ol00008ooooo`?o0000>Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Sooooo0_l0000:ooooo`;o00003oooool000Kooooo0_l00008ooooo`?o00001oooool4o`00
00Oooooo0ol0000^ooooo`;o0000>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00oooooo0008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001oooool4o`0000Oo
oooo0ol00006ooooo`?o00009?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo013o
oooo0009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00007ooooo`?o00001oooool3o`0000Kooooo1Ol0000Gooooo`03o`000?oooooooooo05Go
oooo000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o00001_ooool4o`0000Go
oooo1?l00009ooooo`;o00000_ooool00ol0003oooooooooo`1Eooooo`002oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_l00005ooooo`Go0000
1?ooool7o`0000Gooooo1_l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Wooooo
0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0:ooooo`00B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o00000_oo
ool4o`0000Sooooo1?l00008ooooo`?o00002Oooool2o`0000[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001Fooooo`03o`000?oooooo
oooo00Cooooo0_l00006ooooo`Co00002?ooool2o`0000Wooooo0_l0000;ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`001?ooool2o`00
053ooooo00?o0000ooooooooool05oooool4o`0000Oooooo1?l00008ooooo`;o00002oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo0004ooooo`?o00001oooool2o`0004Ko
oooo00?o0000ooooooooool08Oooool2o`0000_ooooo0_l00008ooooo`?o00002_ooool00ol0003o
ooooooooo`0=ooooo`001Oooool3o`0000Kooooo0ol00008ooooo`;o0000>oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Sooooo0ol00008ooooo`;o00004?ooool000Gooooo0_l0
0008ooooo`?o00001oooool3o`0003[ooooo0_l0000]ooooo`03o`000?oooooooooo00Sooooo0_l0
000:ooooo`;o00004?ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000007
ooooo`?o00001oooool3o`0002oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo013ooooo0008ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01Oooool01?l0003oooooo`000?l00006ooooo`?o00001_ooool5o`0001cooooo0ol00004
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool04Oooool000Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ool000001oooool3o`0000Kooooo1Ol00008ooooo`;o00001_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool0EOooool000[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`03o`000?oooooo0000
00;o00001_ooool4o`0000Cooooo1Ol00007ooooo`?o00000oooool00ol0003oooooooooo`1Eoooo
o`002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`03
o`000?oooooo000000;o00000_ooool:o`0000?ooooo1ol00004ooooo`;o000000Coooooo`000?l0
003o00002Oooool2o`0000Wooooo0_l00008ooooo`;o00002Oooool2o`0000Wooooo0_l0000<oooo
o`00DOooool2o`0000?ooooo00?o0000ooooooooool01Ol00007ooooo`Co00002?ooool4o`0000Wo
oooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0<ooooo`00C_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool02oooool4o`0000Sooooo0_l00009ooooo`?o00002Oooool2o`0000[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0=ooooo`00Coooool3o`0000Cooooo00?o0000ooooooooool0
5_ooool4o`0000Oooooo1?l00008ooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`03o`00
0?oooooooooo00kooooo001Fooooo`03o`000?oooooooooo023ooooo0_l0000:ooooo`?o00002Ooo
ool00ol0003oooooooooo`07ooooo`;o00004Oooool005Kooooo0_l0000/ooooo`;o00002_ooool3
o`0000Sooooo00?o0000ooooooooool04?ooool005Kooooo00?o0000ooooooooool0=_ooool2o`00
00Wooooo0ol0000Aooooo`00E_ooool00ol0003oooooooooo`10ooooo`;o00004oooool005Kooooo
00?o0000ooooooooool0EOooool005Kooooo00?o0000ooooooooool0EOooool005Kooooo0_l0001F
ooooo`00E_ooool00ol0003oooooooooo`1Eooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 250.875}, {571.875, 398.875}} -> {-6.59065, \
12.5247, 0.0400952, 0.0400952}}]
}, Open  ]],

Cell["\<\
Observe that 15 arrows are plotted horizontally and 15 vertically. \
This can be controlled by setting\
\>", "Text"],

Cell[TextData[StyleBox["PlotPoints -> n",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "which instructs PlotVectorField to plot n vectors in each direction (total \
= ",
  Cell[BoxData[
      \(TraditionalForm\`n\^2\)]],
  "). Here is the same vector field with 9 arrows in each direction."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
PlotVectorField[ {-y,x}, {x,-3,3}, {y,-3,3}, Axes->True, PlotPoints\
\[Rule]9 ]\
\>", "Input",
  CellLabel->"In[37]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.134886 0.5 0.134886 [
[.09534 .4875 -6 -9 ]
[.09534 .4875 6 0 ]
[.23023 .4875 -6 -9 ]
[.23023 .4875 6 0 ]
[.36511 .4875 -6 -9 ]
[.36511 .4875 6 0 ]
[.63489 .4875 -3 -9 ]
[.63489 .4875 3 0 ]
[.76977 .4875 -3 -9 ]
[.76977 .4875 3 0 ]
[.90466 .4875 -3 -9 ]
[.90466 .4875 3 0 ]
[.4875 .09534 -12 -4.5 ]
[.4875 .09534 0 4.5 ]
[.4875 .23023 -12 -4.5 ]
[.4875 .23023 0 4.5 ]
[.4875 .36511 -12 -4.5 ]
[.4875 .36511 0 4.5 ]
[.4875 .63489 -6 -4.5 ]
[.4875 .63489 0 4.5 ]
[.4875 .76977 -6 -4.5 ]
[.4875 .76977 0 4.5 ]
[.4875 .90466 -6 -4.5 ]
[.4875 .90466 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09534 .5 m
.09534 .50625 L
s
[(-3)] .09534 .4875 0 1 Mshowa
.23023 .5 m
.23023 .50625 L
s
[(-2)] .23023 .4875 0 1 Mshowa
.36511 .5 m
.36511 .50625 L
s
[(-1)] .36511 .4875 0 1 Mshowa
.63489 .5 m
.63489 .50625 L
s
[(1)] .63489 .4875 0 1 Mshowa
.76977 .5 m
.76977 .50625 L
s
[(2)] .76977 .4875 0 1 Mshowa
.90466 .5 m
.90466 .50625 L
s
[(3)] .90466 .4875 0 1 Mshowa
.125 Mabswid
.12232 .5 m
.12232 .50375 L
s
.1493 .5 m
.1493 .50375 L
s
.17627 .5 m
.17627 .50375 L
s
.20325 .5 m
.20325 .50375 L
s
.25721 .5 m
.25721 .50375 L
s
.28418 .5 m
.28418 .50375 L
s
.31116 .5 m
.31116 .50375 L
s
.33814 .5 m
.33814 .50375 L
s
.39209 .5 m
.39209 .50375 L
s
.41907 .5 m
.41907 .50375 L
s
.44605 .5 m
.44605 .50375 L
s
.47302 .5 m
.47302 .50375 L
s
.52698 .5 m
.52698 .50375 L
s
.55395 .5 m
.55395 .50375 L
s
.58093 .5 m
.58093 .50375 L
s
.60791 .5 m
.60791 .50375 L
s
.66186 .5 m
.66186 .50375 L
s
.68884 .5 m
.68884 .50375 L
s
.71582 .5 m
.71582 .50375 L
s
.74279 .5 m
.74279 .50375 L
s
.79675 .5 m
.79675 .50375 L
s
.82373 .5 m
.82373 .50375 L
s
.8507 .5 m
.8507 .50375 L
s
.87768 .5 m
.87768 .50375 L
s
.06837 .5 m
.06837 .50375 L
s
.04139 .5 m
.04139 .50375 L
s
.01441 .5 m
.01441 .50375 L
s
.93163 .5 m
.93163 .50375 L
s
.95861 .5 m
.95861 .50375 L
s
.98559 .5 m
.98559 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .09534 m
.50625 .09534 L
s
[(-3)] .4875 .09534 1 0 Mshowa
.5 .23023 m
.50625 .23023 L
s
[(-2)] .4875 .23023 1 0 Mshowa
.5 .36511 m
.50625 .36511 L
s
[(-1)] .4875 .36511 1 0 Mshowa
.5 .63489 m
.50625 .63489 L
s
[(1)] .4875 .63489 1 0 Mshowa
.5 .76977 m
.50625 .76977 L
s
[(2)] .4875 .76977 1 0 Mshowa
.5 .90466 m
.50625 .90466 L
s
[(3)] .4875 .90466 1 0 Mshowa
.125 Mabswid
.5 .12232 m
.50375 .12232 L
s
.5 .1493 m
.50375 .1493 L
s
.5 .17627 m
.50375 .17627 L
s
.5 .20325 m
.50375 .20325 L
s
.5 .25721 m
.50375 .25721 L
s
.5 .28418 m
.50375 .28418 L
s
.5 .31116 m
.50375 .31116 L
s
.5 .33814 m
.50375 .33814 L
s
.5 .39209 m
.50375 .39209 L
s
.5 .41907 m
.50375 .41907 L
s
.5 .44605 m
.50375 .44605 L
s
.5 .47302 m
.50375 .47302 L
s
.5 .52698 m
.50375 .52698 L
s
.5 .55395 m
.50375 .55395 L
s
.5 .58093 m
.50375 .58093 L
s
.5 .60791 m
.50375 .60791 L
s
.5 .66186 m
.50375 .66186 L
s
.5 .68884 m
.50375 .68884 L
s
.5 .71582 m
.50375 .71582 L
s
.5 .74279 m
.50375 .74279 L
s
.5 .79675 m
.50375 .79675 L
s
.5 .82373 m
.50375 .82373 L
s
.5 .8507 m
.50375 .8507 L
s
.5 .87768 m
.50375 .87768 L
s
.5 .06837 m
.50375 .06837 L
s
.5 .04139 m
.50375 .04139 L
s
.5 .01441 m
.50375 .01441 L
s
.5 .93163 m
.50375 .93163 L
s
.5 .95861 m
.50375 .95861 L
s
.5 .98559 m
.50375 .98559 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.09534 .09534 m
.16688 .02381 L
s
% Start of user PostScript
-3. -3. -2.46967 -3.53033 MAarrowhead1
% End of user PostScript
.09534 .19651 m
.14899 .12497 L
s
% Start of user PostScript
-3. -2.25 -2.60225 -2.78033 MAarrowhead1
% End of user PostScript
.09534 .29767 m
.13111 .22614 L
s
% Start of user PostScript
-3. -1.5 -2.73483 -2.03033 MAarrowhead1
% End of user PostScript
.09534 .39884 m
.11323 .3273 L
s
% Start of user PostScript
-3. -0.75 -2.86742 -1.28033 MAarrowhead1
% End of user PostScript
.09534 .5 m
.09534 .42847 L
s
% Start of user PostScript
-3. 0 -3. -0.53033 MAarrowhead1
% End of user PostScript
.09534 .60116 m
.07746 .52963 L
s
% Start of user PostScript
-3. 0.75 -3.13258 0.21967 MAarrowhead1
% End of user PostScript
.09534 .70233 m
.05958 .63079 L
s
% Start of user PostScript
-3. 1.5 -3.26517 0.96967 MAarrowhead1
% End of user PostScript
.09534 .80349 m
.04169 .73196 L
s
% Start of user PostScript
-3. 2.25 -3.39775 1.71967 MAarrowhead1
% End of user PostScript
.09534 .90466 m
.02381 .83312 L
s
% Start of user PostScript
-3. 3. -3.53033 2.46967 MAarrowhead1
% End of user PostScript
.19651 .09534 m
.26804 .04169 L
s
% Start of user PostScript
-2.25 -3. -1.71967 -3.39775 MAarrowhead1
% End of user PostScript
.19651 .19651 m
.25016 .14286 L
s
% Start of user PostScript
-2.25 -2.25 -1.85225 -2.64775 MAarrowhead1
% End of user PostScript
.19651 .29767 m
.23227 .24402 L
s
% Start of user PostScript
-2.25 -1.5 -1.98483 -1.89775 MAarrowhead1
% End of user PostScript
.19651 .39884 m
.21439 .34519 L
s
% Start of user PostScript
-2.25 -0.75 -2.11742 -1.14775 MAarrowhead1
% End of user PostScript
.19651 .5 m
.19651 .44635 L
s
% Start of user PostScript
-2.25 0 -2.25 -0.397748 MAarrowhead1
% End of user PostScript
.19651 .60116 m
.17862 .54751 L
s
% Start of user PostScript
-2.25 0.75 -2.38258 0.352252 MAarrowhead1
% End of user PostScript
.19651 .70233 m
.16074 .64868 L
s
% Start of user PostScript
-2.25 1.5 -2.51517 1.10225 MAarrowhead1
% End of user PostScript
.19651 .80349 m
.14286 .74984 L
s
% Start of user PostScript
-2.25 2.25 -2.64775 1.85225 MAarrowhead1
% End of user PostScript
.19651 .90466 m
.12497 .85101 L
s
% Start of user PostScript
-2.25 3. -2.78033 2.60225 MAarrowhead1
% End of user PostScript
.29767 .09534 m
.36921 .05958 L
s
% Start of user PostScript
-1.5 -3. -0.96967 -3.26517 MAarrowhead1
% End of user PostScript
.29767 .19651 m
.35132 .16074 L
s
% Start of user PostScript
-1.5 -2.25 -1.10225 -2.51517 MAarrowhead1
% End of user PostScript
.29767 .29767 m
.33344 .2619 L
s
% Start of user PostScript
-1.5 -1.5 -1.23483 -1.76517 MAarrowhead1
% End of user PostScript
.29767 .39884 m
.31556 .36307 L
s
% Start of user PostScript
-1.5 -0.75 -1.36742 -1.01517 MAarrowhead1
% End of user PostScript
.29767 .5 m
.29767 .46423 L
s
% Start of user PostScript
-1.5 0 -1.5 -0.265165 MAarrowhead1
% End of user PostScript
.29767 .60116 m
.27979 .5654 L
s
% Start of user PostScript
-1.5 0.75 -1.63258 0.484835 MAarrowhead1
% End of user PostScript
.29767 .70233 m
.2619 .66656 L
s
% Start of user PostScript
-1.5 1.5 -1.76517 1.23483 MAarrowhead1
% End of user PostScript
.29767 .80349 m
.24402 .76773 L
s
% Start of user PostScript
-1.5 2.25 -1.89775 1.98483 MAarrowhead1
% End of user PostScript
.29767 .90466 m
.22614 .86889 L
s
% Start of user PostScript
-1.5 3. -2.03033 2.73483 MAarrowhead1
% End of user PostScript
.39884 .09534 m
.47037 .07746 L
s
% Start of user PostScript
-0.75 -3. -0.21967 -3.13258 MAarrowhead1
% End of user PostScript
.39884 .19651 m
.45249 .17862 L
s
% Start of user PostScript
-0.75 -2.25 -0.352252 -2.38258 MAarrowhead1
% End of user PostScript
.39884 .29767 m
.4346 .27979 L
s
% Start of user PostScript
-0.75 -1.5 -0.484835 -1.63258 MAarrowhead1
% End of user PostScript
.39884 .39884 m
.41672 .38095 L
s
% Start of user PostScript
-0.75 -0.75 -0.617417 -0.882583 MAarrowhead1
% End of user PostScript
.39884 .5 m
.39884 .48212 L
s
% Start of user PostScript
-0.75 0 -0.75 -0.132583 MAarrowhead1
% End of user PostScript
.39884 .60116 m
.38095 .58328 L
s
% Start of user PostScript
-0.75 0.75 -0.882583 0.617417 MAarrowhead1
% End of user PostScript
.39884 .70233 m
.36307 .68444 L
s
% Start of user PostScript
-0.75 1.5 -1.01517 1.36742 MAarrowhead1
% End of user PostScript
.39884 .80349 m
.34519 .78561 L
s
% Start of user PostScript
-0.75 2.25 -1.14775 2.11742 MAarrowhead1
% End of user PostScript
.39884 .90466 m
.3273 .88677 L
s
% Start of user PostScript
-0.75 3. -1.28033 2.86742 MAarrowhead1
% End of user PostScript
.5 .09534 m
.57153 .09534 L
s
% Start of user PostScript
0 -3. 0.53033 -3. MAarrowhead1
% End of user PostScript
.5 .19651 m
.55365 .19651 L
s
% Start of user PostScript
0 -2.25 0.397748 -2.25 MAarrowhead1
% End of user PostScript
.5 .29767 m
.53577 .29767 L
s
% Start of user PostScript
0 -1.5 0.265165 -1.5 MAarrowhead1
% End of user PostScript
.5 .39884 m
.51788 .39884 L
s
% Start of user PostScript
0 -0.75 0.132583 -0.75 MAarrowhead1
% End of user PostScript
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .60116 m
.48212 .60116 L
s
% Start of user PostScript
0 0.75 -0.132583 0.75 MAarrowhead1
% End of user PostScript
.5 .70233 m
.46423 .70233 L
s
% Start of user PostScript
0 1.5 -0.265165 1.5 MAarrowhead1
% End of user PostScript
.5 .80349 m
.44635 .80349 L
s
% Start of user PostScript
0 2.25 -0.397748 2.25 MAarrowhead1
% End of user PostScript
.5 .90466 m
.42847 .90466 L
s
% Start of user PostScript
0 3. -0.53033 3. MAarrowhead1
% End of user PostScript
.60116 .09534 m
.6727 .11323 L
s
% Start of user PostScript
0.75 -3. 1.28033 -2.86742 MAarrowhead1
% End of user PostScript
.60116 .19651 m
.65481 .21439 L
s
% Start of user PostScript
0.75 -2.25 1.14775 -2.11742 MAarrowhead1
% End of user PostScript
.60116 .29767 m
.63693 .31556 L
s
% Start of user PostScript
0.75 -1.5 1.01517 -1.36742 MAarrowhead1
% End of user PostScript
.60116 .39884 m
.61905 .41672 L
s
% Start of user PostScript
0.75 -0.75 0.882583 -0.617417 MAarrowhead1
% End of user PostScript
.60116 .5 m
.60116 .51788 L
s
% Start of user PostScript
0.75 0 0.75 0.132583 MAarrowhead1
% End of user PostScript
.60116 .60116 m
.58328 .61905 L
s
% Start of user PostScript
0.75 0.75 0.617417 0.882583 MAarrowhead1
% End of user PostScript
.60116 .70233 m
.5654 .72021 L
s
% Start of user PostScript
0.75 1.5 0.484835 1.63258 MAarrowhead1
% End of user PostScript
.60116 .80349 m
.54751 .82138 L
s
% Start of user PostScript
0.75 2.25 0.352252 2.38258 MAarrowhead1
% End of user PostScript
.60116 .90466 m
.52963 .92254 L
s
% Start of user PostScript
0.75 3. 0.21967 3.13258 MAarrowhead1
% End of user PostScript
.70233 .09534 m
.77386 .13111 L
s
% Start of user PostScript
1.5 -3. 2.03033 -2.73483 MAarrowhead1
% End of user PostScript
.70233 .19651 m
.75598 .23227 L
s
% Start of user PostScript
1.5 -2.25 1.89775 -1.98483 MAarrowhead1
% End of user PostScript
.70233 .29767 m
.7381 .33344 L
s
% Start of user PostScript
1.5 -1.5 1.76517 -1.23483 MAarrowhead1
% End of user PostScript
.70233 .39884 m
.72021 .4346 L
s
% Start of user PostScript
1.5 -0.75 1.63258 -0.484835 MAarrowhead1
% End of user PostScript
.70233 .5 m
.70233 .53577 L
s
% Start of user PostScript
1.5 0 1.5 0.265165 MAarrowhead1
% End of user PostScript
.70233 .60116 m
.68444 .63693 L
s
% Start of user PostScript
1.5 0.75 1.36742 1.01517 MAarrowhead1
% End of user PostScript
.70233 .70233 m
.66656 .7381 L
s
% Start of user PostScript
1.5 1.5 1.23483 1.76517 MAarrowhead1
% End of user PostScript
.70233 .80349 m
.64868 .83926 L
s
% Start of user PostScript
1.5 2.25 1.10225 2.51517 MAarrowhead1
% End of user PostScript
.70233 .90466 m
.63079 .94042 L
s
% Start of user PostScript
1.5 3. 0.96967 3.26517 MAarrowhead1
% End of user PostScript
.80349 .09534 m
.87503 .14899 L
s
% Start of user PostScript
2.25 -3. 2.78033 -2.60225 MAarrowhead1
% End of user PostScript
.80349 .19651 m
.85714 .25016 L
s
% Start of user PostScript
2.25 -2.25 2.64775 -1.85225 MAarrowhead1
% End of user PostScript
.80349 .29767 m
.83926 .35132 L
s
% Start of user PostScript
2.25 -1.5 2.51517 -1.10225 MAarrowhead1
% End of user PostScript
.80349 .39884 m
.82138 .45249 L
s
% Start of user PostScript
2.25 -0.75 2.38258 -0.352252 MAarrowhead1
% End of user PostScript
.80349 .5 m
.80349 .55365 L
s
% Start of user PostScript
2.25 0 2.25 0.397748 MAarrowhead1
% End of user PostScript
.80349 .60116 m
.78561 .65481 L
s
% Start of user PostScript
2.25 0.75 2.11742 1.14775 MAarrowhead1
% End of user PostScript
.80349 .70233 m
.76773 .75598 L
s
% Start of user PostScript
2.25 1.5 1.98483 1.89775 MAarrowhead1
% End of user PostScript
.80349 .80349 m
.74984 .85714 L
s
% Start of user PostScript
2.25 2.25 1.85225 2.64775 MAarrowhead1
% End of user PostScript
.80349 .90466 m
.73196 .95831 L
s
% Start of user PostScript
2.25 3. 1.71967 3.39775 MAarrowhead1
% End of user PostScript
.90466 .09534 m
.97619 .16688 L
s
% Start of user PostScript
3. -3. 3.53033 -2.46967 MAarrowhead1
% End of user PostScript
.90466 .19651 m
.95831 .26804 L
s
% Start of user PostScript
3. -2.25 3.39775 -1.71967 MAarrowhead1
% End of user PostScript
.90466 .29767 m
.94042 .36921 L
s
% Start of user PostScript
3. -1.5 3.26517 -0.96967 MAarrowhead1
% End of user PostScript
.90466 .39884 m
.92254 .47037 L
s
% Start of user PostScript
3. -0.75 3.13258 -0.21967 MAarrowhead1
% End of user PostScript
.90466 .5 m
.90466 .57153 L
s
% Start of user PostScript
3. 0 3. 0.53033 MAarrowhead1
% End of user PostScript
.90466 .60116 m
.88677 .6727 L
s
% Start of user PostScript
3. 0.75 2.86742 1.28033 MAarrowhead1
% End of user PostScript
.90466 .70233 m
.86889 .77386 L
s
% Start of user PostScript
3. 1.5 2.73483 2.03033 MAarrowhead1
% End of user PostScript
.90466 .80349 m
.85101 .87503 L
s
% Start of user PostScript
3. 2.25 2.60225 2.78033 MAarrowhead1
% End of user PostScript
.90466 .90466 m
.83312 .97619 L
s
% Start of user PostScript
3. 3. 2.46967 3.53033 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{189, 189},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002m0000_B000`400?l00000o`00003oG_ooool0
0ol0003oooooooooo`1Looooo`00G_ooool00ol0003oooooooooo`1Looooo`00G_ooool00ol0003o
ooooooooo`1Looooo`00G_ooool00ol0003oooooooooo`1Looooo`00G_ooool00ol0003ooooooooo
o`1Looooo`007_ooool2o`0003kooooo00?o0000ooooooooool0G?ooool001gooooo0ol0000noooo
o`03o`000?oooooooooo05cooooo000Looooo`?o0000?oooool00ol0003oooooooooo`1Looooo`00
6oooool00ol0003oooooo`00000Cooooo`;o0000:oooool00ol0003oooooooooo`1Looooo`006_oo
ool00ol0003oooooooooo`0Booooo`?o0000;?ooool00ol0003oooooooooo`1Looooo`006Oooool0
0ol0003oooooooooo`0Booooo`?o0000;Oooool00ol0003oooooooooo`1Looooo`006?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooo000002kooooo00?o0000ooooooooool0G?ooool001Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`?o00006?ooool00ol0003o
ooooooooo`1Looooo`005_ooool00ol0003oooooooooo`0Aooooo`;o00005Oooool3o`0001[ooooo
00?o0000ooooooooool0G?ooool001Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Cooooo`;o000000?oooooo`000?ooool06_ooool00ol0003oooooooooo`1Looooo`005?ooool0
0ol0003oooooooooo`0@ooooo`;o00005?ooool2o`0001Gooooo1Ol00005ooooo`03o`000?oooooo
oooo05cooooo000Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool3o`00
01Cooooo2?l00005ooooo`03o`000?oooooooooo05cooooo000Booooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool2o`0001;ooooo1Ol00003ooooo`;o00000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo0ol0001Cooooo`004Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool2o`0000?ooooo
1Ol00005ooooo`03o`000?oooooooooo00;ooooo3_l00005ooooo`?o00004?ooool2o`00017ooooo
0_l0000Aooooo`03o`000?oooooooooo013ooooo001Gooooo`;o00001Oooool00ol0003ooooooooo
o`06ooooo`;o00002oooool3o`0000oooooo0_l0000Aooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool04?ooool005Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0F
ooooo`?o000000?oooooo`000?l000002oooool2o`00013ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`00EOooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool06Oooool4o`0000cooooo0_l0000?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool005Kooooo0ol00005ooooo`03o`000?oooooooooo01Wooooo1Ol0000=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=oooo
o`00G_ooool00ol0003oooooooooo`0/ooooo`?o00003Oooool2o`0000oooooo00?o0000oooooooo
ool03?ooool001_ooooo0_l00011ooooo`03o`000?oooooooooo02cooooo1?l0000>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool001Wooooo1?l00011ooooo`03o`000?oo
oooooooo02oooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_oo
ool001Sooooo1?l00012ooooo`03o`000?oooooooooo043ooooo0_l0000>ooooo`03o`000?oooooo
oooo00Wooooo000Iooooo`?o00004_ooool2o`0002kooooo00?o0000ooooooooool0?oooool3o`00
00oooooo00?o0000ooooooooool02?ooool001Wooooo0_l0000Aooooo`Co0000;_ooool00ol0003o
ooooooooo`11ooooo`;o00003oooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003ooooo
ooooo`0@ooooo`Co0000;oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00gooooo
0_l00007ooooo`005oooool00ol0003oooooooooo`0Aooooo`Co0000;oooool00ol0003ooooooooo
o`1Cooooo`;o00001oooool001Kooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0
000Booooo`?o00006oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Cooooo000F
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool4o`0001cooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`03ooooo`005Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01;ooooo1?l0000Mooooo`03o`000?oooooooooo05cooooo000Dooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000Aoooo
o`Go00002?ooool00ol0003oooooooooo`1Looooo`004oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo0_l0000Cooooo`Go00002_ooool00ol0003oooooooooo`1Looooo`00
4_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo0_l0000Booooo`?o0000
0_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05cooooo000Aooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`;o00004_oo
ool;o`0000Sooooo0_l0000Aooooo`;o00004Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo001Nooooo`03o`000?oooooooooo00?ooooo0_l0000=ooooo`?o00004?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
05kooooo00?o0000ooooooooool05Oooool3o`0000kooooo0_l0000?ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool005kooooo00?o0000ooooooooool05_ooool4o`0000ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo001Eooooo`Go00001?ooool00ol0003oooooooooo`0Fooooo`Go00003_ooool2o`0000kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`00E_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02[ooooo0_l0000>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03Oooool001Sooooo00?o0000ooooooooool0=?ooool5o`0000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`Co00003_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00cooooo000Hooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool00oooool2o`0002gooooo0_l0000>ooooo`03o`000?oooooo000000oooooo00?o0000
ooooooooool02oooool001Oooooo0_l0000looooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0mooooo`;o00003oooool00ol0003oooooooooo`0;ooooo`005_ooool2o`00
01?ooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0??ooool4o`0000oooooo00?o0000ooooooooool02_ooool001Kooooo0_l0000Boooo
o`;o0000:_ooool3o`0000Gooooo00?o0000ooooooooool0?_ooool2o`00013ooooo0_l0000:oooo
o`005_ooool00ol0003oooooooooo`0@ooooo`?o0000<_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo00gooooo0_l0000:ooooo`005Oooool00ol0003oooooooooo`0@ooooo`?o0000
<oooool00ol0003oooooooooo`1Aooooo`;o00002Oooool001Cooooo00?o0000ooooooooool04_oo
ool2o`0001;ooooo0_l0000Oooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01ooo
ool001Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`?o00007oooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Kooooo000Cooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool3o`00023ooooo00?o0000ooooooooool0G?ooool001?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000001;o
oooo0ol0000<ooooo`03o`000?oooooooooo05cooooo000Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`Co00003Oooool00ol0003ooooo
ooooo`1Looooo`004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool5o`0000kooooo00?o0000ooooooooool0G?ooool0017ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00Go0000
ooooooooooooooooo`00000?ooooo`Oo00003?ooool2o`00017ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo001Nooooo`04o`000?oooooo
0000o`00017ooooo0_l0000?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`00G_ooool00ol0003oooooooooo`0Cooooo`;o00003oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
05kooooo00?o0000ooooooooool04_ooool4o`0000oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo001Nooooo`03o`000?oooooooooo01Go
oooo0_l0000?ooooo`;o00004?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo001Nooooo`03o`000?oooooooooo02Kooooo0_l0000@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03_ooool001Gooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`005Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool03_ooool2o`00013ooooo00?o0000ooooooooool03Oooool001Cooooo0_l00018oooo
o`03o`000?oooooooooo03Wooooo0ol0000@ooooo`03o`000?oooooooooo00gooooo000Cooooo`?o
00004_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03[ooooo0_l0000Aooooo`03
o`000?oooooooooo00cooooo000Dooooo`;o00004_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo03_ooooo0_l0000@ooooo`;o00003Oooool001Cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo0ol00005ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03_oo
ool2o`0000gooooo000Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04gooooo0_l0000=ooooo`004oooool00ol0
003oooooooooo`0@ooooo`;o00004oooool00ol0003oooooooooo`0Aooooo`Go00000oooool00ol0
003oooooooooo`04ooooo`;o0000Coooool2o`0000cooooo000Cooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool2o`0001_ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo00[ooooo000Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04?ooool3o`0001_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Looooo`004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo0ol0
000Booooo`;o00001oooool2o`0000Kooooo00?o0000ooooooooool0G?ooool001;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`;o00004?ooool4o`0000Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Looooo`004Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool4o`00013ooooo00?o0000oooo
ooooool0G?ooool0017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooool000004?ooool5o`0000oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool005gooooo0_l0000Booooo`;o00004Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool005kooooo00?o0000ooooooooool04?oo
ool2o`0001;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo001Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool2
o`00017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`00G_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo0ol0000Aooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool005kooooo00?o0000ooooooooool09?ooool2o`00017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`004Oooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo02Gooooo0_l0000Aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool0017ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00kooooo0ol0000@ooooo`03o`000?oooooooooo00oooooo000A
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0=oooool3o`00017ooooo00?o0000
ooooooooool03_ooool0013ooooo1Ol0000?ooooo`03o`000?oooooooooo00Cooooo1Ol0000Eoooo
o`?o00005_ooool00ol0003oooooooooo`0Dooooo`?o00005Oooool5o`0000Oooooo0_l0000=oooo
o`?o000000?oooooo`000?ooool03oooool0013ooooo0ol00002ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`04o`000?oooooooooo
o`0000Oooooo0_l0000<ooooo`04o`000?ooooooooooooooo`?o00003oooool000_ooooo1Ol00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo1_l00003ooooo`03o`000?oooooo
oooo00kooooo1Ol00003ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool3
o`0000oooooo000Aooooo`04o`000?oooooo0000o`0000kooooo0ol00008ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool05_ooool5o`0000oooooo000Aooooo`05o`000?oooooooooo
ooooool000003Oooool3o`0000Gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01Cooooo00Go0000ooooooooooooooooo`00000Iooooo`?o00003oooool0017ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00_ooooo0_l0000Gooooo`03o`000?oooooooooo01Co
oooo0_l0000Fooooo`05o`000?ooooooooooooooool000005Oooool01ol0003ooooooooooooooooo
0000ooooool000003oooool0017ooooo1?l0000?ooooo`03o`000?oooooooooo00Gooooo0ol00008
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01Gooooo0ol0000Gooooo`?o00004_ooool0017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`?o00004Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo05cooooo000Aooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03oooool3o`00017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Looooo`00
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05cooooo002mo`0000000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Ko0000
oooooooooooo0000ooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00oooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool005kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`;o00004_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo001Nooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool2o`0001;ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`00G_ooool00ol0003oooooooooo`0Rooooo`;o00004_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo000>ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool000kooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00oooooo0_l0000Booooo`03o`000?oooooooooo013ooooo000>
ooooo`;o0000C_ooool00ol0003oooooooooo`0eooooo`;o00004_ooool00ol0003oooooooooo`0@
ooooo`003_ooool2o`00017ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0eoooo
o`;o00004_ooool00ol0003oooooooooo`0@ooooo`003_ooool3o`00013ooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo0ol0000Aooooo`00
3oooool00ol0003oooooooooo`0?ooooo`;o0000>oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00oooooo0ol0000Aooooo`003oooool00ol0003oooooooooo`0?ooooo`;o0000>ooo
ool00ol0003oooooooooo`18ooooo`?o00004Oooool000oooooo00?o0000ooooooooool03oooool3
o`00013ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo013ooooo000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool2o`00
02Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0@ooooo`004?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00kooooo0ol0000Wooooo`03o`000?oooooooooo05co
oooo000@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool3o`0000oooooo
0_l0000Eooooo`03o`000?oooooooooo05cooooo000@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03oooool2o`00013ooooo0ol0000Dooooo`03o`000?oooooooooo05cooooo000@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?
ooooo`?o00004oooool00ol0003oooooooooo`1Looooo`004Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool3o`00017ooooo0ol0001Noooo
o`004Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03oooool2o`0000oooooo1Ol0000@ooooo`?o00004_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool005gooooo0_l0000@ooooo`;o0000
4oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool005kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`?o00004_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo001Fooooo`?o00001Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo0ol0000Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04Oooool005Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Pooooo`;o00004oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
017ooooo000;ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Oooooo`;o00004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo000;ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01?ooool2o`00023ooooo
00?o0000ooooooooool04?ooool3o`0001;ooooo00?o0000ooooooooool04_ooool000_ooooo0_l0
001:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool3o`0001;ooooo00?o
0000ooooooooool04_ooool000cooooo0_l0000@ooooo`03o`000?oooooooooo03Gooooo0_l00006
ooooo`03o`000?oooooooooo03;ooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo000<oooo
o`;o00004?ooool2o`0003Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0boooo
o`;o00004Oooool2o`0001Gooooo000=ooooo`03o`000?oooooooooo00kooooo0ol0000mooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool3o`0001Cooooo000=ooooo`03o`00
0?oooooooooo00oooooo0ol0000looooo`03o`000?oooooooooo04Gooooo0ol0000Dooooo`003_oo
ool00ol0003oooooooooo`0>ooooo`;o00004?ooool2o`0002_ooooo00?o0000ooooooooool0AOoo
ool2o`0001Gooooo000>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool3
o`0002[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`003oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo0ol0000Yooooo`03o`000?oooooooooo
05cooooo000?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`?o00005oooool00ol0003oooooooooo`1Looooo`004?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool4o`0001Gooooo
00?o0000ooooooooool0G?ooool0013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00kooooo0ol0000Eooooo`03o`000?oooooooooo05cooooo000@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooo000000oooooo0ol00002ooooo`03o`000?oooooooooo05cooooo000Aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00[ooooo2?l0000>ooooo`03o`000?oooooooooo00;o00004Oooool2o`00
01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`00F_ooool2o`0000;o
oooo00?o0000ooooooooool02oooool4o`0001;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo001Nooooo`03o`000?oooooooooo00[ooooo
1?l0000Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Aooooo`00G_ooool00ol0003oooooooooo`09ooooo`;o00004oooool2o`0001Cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`00G_ooool00ol0003oooooooooo`0N
ooooo`;o00005?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0007oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool000Oooooo0_l0001Eooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool3o`0001?ooooo00?o0000oooooooo
ool04oooool000Sooooo0_l0001Dooooo`03o`000?oooooooooo033ooooo0ol0000Booooo`03o`00
0?oooooooooo01Cooooo0008ooooo`?o00003oooool2o`0004;ooooo00?o0000ooooooooool0<?oo
ool2o`0001?ooooo00?o0000ooooooooool05?ooool000Wooooo0_l0000?ooooo`Co0000@?ooool0
0ol0003oooooooooo`0_ooooo`;o00004_ooool2o`0001Oooooo000:ooooo`03o`000?oooooooooo
00kooooo1?l0000fooooo`Go00001?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
017ooooo0_l0000Gooooo`002oooool00ol0003oooooooooo`0=ooooo`?o0000>?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo04?ooooo0_l0000Gooooo`003?ooool00ol0003o
ooooooooo`0=ooooo`;o00003oooool3o`0002Oooooo00?o0000ooooooooool01?ooool2o`0004?o
oooo0_l0000Hooooo`003?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo
1?l0000Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Gooooo`003Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0ol0
000Sooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Looooo`003_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000003Ooo
ool3o`0001;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05cooooo
000?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0<ooooo`?o00004Oooool3o`0000Gooooo00?o0000ooooooooool0G?ooool000oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`;o00003_ooool3o`0001Oooooo00?o0000
ooooooooool0G?ooool0013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00kooooo0ol0000;ooooo`?o00001_ooool00ol0003oooooooooo`1Loooo
o`004Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`06ooooo`co00004?ooool3o`00017ooooo0_l0000Aooooo`;o
00004_ooool00ol0003oooooooooo`0@ooooo`00E_ooool2o`0000Kooooo00?o0000ooooooooool0
2?ooool6o`0001;ooooo0_l0000Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4?ooool005kooooo00?o0000ooooooooool01_ooool4o`0001Cooooo0_l0000Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool005kooooo00?o0000ooooooooool01Oooool5
o`00017ooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo001Nooooo`03o`000?oooooooooo01[ooooo0ol0000Dooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04oooool000Cooooo0_l0001Hooooo`03o`000?oooooooooo01Wo
oooo1?l0000Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool000Cooooo
0ol0001Gooooo`03o`000?oooooooooo01Sooooo0_l0000Cooooo`03o`000?oooooo000001Cooooo
00?o0000ooooooooool05Oooool000Gooooo0ol0001Fooooo`03o`000?oooooooooo02gooooo0_l0
000Dooooo`03o`000?oooooooooo01Kooooo0006ooooo`03o`000?oooooooooo00kooooo0_l00015
ooooo`03o`000?oooooooooo02cooooo1?l0000Cooooo`03o`000?oooooooooo01Kooooo0007oooo
o`03o`000?oooooooooo00gooooo1?l00013ooooo`03o`000?oooooooooo02cooooo0_l0000Boooo
o`03o`000?oooooo000001Wooooo0008ooooo`03o`000?oooooooooo00gooooo1?l00012ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool04_ooool2o`0001[ooooo0009ooooo`03o`00
0?oooooooooo00cooooo1?l00012ooooo`03o`000?oooooooooo03oooooo0ol0000Jooooo`002_oo
ool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000gooooo0ol0000aooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool06_ooool000_ooooo00?o0000ooooooooool03ooo
ool2o`0000gooooo0ol0000_ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool06ooo
ool000cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`?o0000;_ooool0
0ol0003oooooooooo`1Looooo`003Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00gooooo0_l0000;ooooo`Go00007?ooool00ol0003oooooooooo`1Looooo`003_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool4o`0001?o
oooo0ol00005ooooo`03o`000?oooooooooo05cooooo000?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03_ooool2o`0000_ooooo00?o0000ooooooooool00ol0000?ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Looooo`004?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00oooooo0_l0000?ooooo`?o00002Oooool3o`0000Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Looooo`004Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool2o`0000Gooooo4?l0
000?ooooo`?o00004Oooool2o`00017ooooo0_l0000Aooooo`;o00004_ooool005?ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo1Ol0000A
ooooo`?o00004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo001Eoooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`Ko00005?ooool2
o`0001?ooooo0_l0000Booooo`03o`000?oooooooooo01?ooooo001Fooooo`?o00001Oooool00ol0
003oooooooooo`02ooooo`Go00005?ooool2o`0001Cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`00G_ooool00ol0003oooooooooo`0Gooooo`Co00005Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo001Nooooo`03o`000?oooooooooo01Kooooo
1?l0000Dooooo`;o00004oooool00ol0003oooooooooo`0Fooooo`00G_ooool00ol0003ooooooooo
o`0Eooooo`;o00005_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo001N
ooooo`03o`000?oooooooooo02_ooooo0_l0000Dooooo`03o`000?oooooooooo01Sooooo001Noooo
o`03o`000?oooooooooo02[ooooo0ol0000Cooooo`03o`000?oooooooooo01Wooooo001Nooooo`03
o`000?oooooooooo02Wooooo0_l0000Dooooo`03o`000?oooooooooo01[ooooo001Nooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool04_ooool2o`0001gooooo001Nooooo`03o`000?oo
oooooooo03gooooo0_l0000Mooooo`00G_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo01gooooo001Nooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07_ooool005ko
oooo00?o0000ooooooooool0G?ooool005kooooo00?o0000ooooooooool0G?ooool005kooooo00?o
0000ooooooooool0G?ooool005kooooo00?o0000ooooooooool0G?ooool00001\
\>"],
  ImageRangeCache->{{{77.875, 265.875}, {273.375, 85.375}} -> {-6.77786, \
-0.340125, 0.0394348, 0.0394348}}]
}, Open  ]],

Cell["\<\
Each arrow is plotted with a length that is proportional to its \
true length. In the example above this makes for very short arrows near the \
origin. If the arrows are scaled to the same length, then the vector field is \
called a direction field. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
PlotVectorField[ {-y,x}/Sqrt[x^2+y^2], {x,-3,3}, {y,-3,3}, \
Axes->True, 
                 PlotPoints\[Rule]9, PlotLabel->\"A direction field\" ]\
\>", \
"Input",
  CellLabel->"In[40]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.134886 0.5 0.134886 [
[.09534 .4875 -6 -9 ]
[.09534 .4875 6 0 ]
[.23023 .4875 -6 -9 ]
[.23023 .4875 6 0 ]
[.36511 .4875 -6 -9 ]
[.36511 .4875 6 0 ]
[.63489 .4875 -3 -9 ]
[.63489 .4875 3 0 ]
[.76977 .4875 -3 -9 ]
[.76977 .4875 3 0 ]
[.90466 .4875 -3 -9 ]
[.90466 .4875 3 0 ]
[.4875 .09534 -12 -4.5 ]
[.4875 .09534 0 4.5 ]
[.4875 .23023 -12 -4.5 ]
[.4875 .23023 0 4.5 ]
[.4875 .36511 -12 -4.5 ]
[.4875 .36511 0 4.5 ]
[.4875 .63489 -6 -4.5 ]
[.4875 .63489 0 4.5 ]
[.4875 .76977 -6 -4.5 ]
[.4875 .76977 0 4.5 ]
[.4875 .90466 -6 -4.5 ]
[.4875 .90466 0 4.5 ]
[.5 1.0125 -53.0312 0 ]
[.5 1.0125 53.0312 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09534 .5 m
.09534 .50625 L
s
[(-3)] .09534 .4875 0 1 Mshowa
.23023 .5 m
.23023 .50625 L
s
[(-2)] .23023 .4875 0 1 Mshowa
.36511 .5 m
.36511 .50625 L
s
[(-1)] .36511 .4875 0 1 Mshowa
.63489 .5 m
.63489 .50625 L
s
[(1)] .63489 .4875 0 1 Mshowa
.76977 .5 m
.76977 .50625 L
s
[(2)] .76977 .4875 0 1 Mshowa
.90466 .5 m
.90466 .50625 L
s
[(3)] .90466 .4875 0 1 Mshowa
.125 Mabswid
.12232 .5 m
.12232 .50375 L
s
.1493 .5 m
.1493 .50375 L
s
.17627 .5 m
.17627 .50375 L
s
.20325 .5 m
.20325 .50375 L
s
.25721 .5 m
.25721 .50375 L
s
.28418 .5 m
.28418 .50375 L
s
.31116 .5 m
.31116 .50375 L
s
.33814 .5 m
.33814 .50375 L
s
.39209 .5 m
.39209 .50375 L
s
.41907 .5 m
.41907 .50375 L
s
.44605 .5 m
.44605 .50375 L
s
.47302 .5 m
.47302 .50375 L
s
.52698 .5 m
.52698 .50375 L
s
.55395 .5 m
.55395 .50375 L
s
.58093 .5 m
.58093 .50375 L
s
.60791 .5 m
.60791 .50375 L
s
.66186 .5 m
.66186 .50375 L
s
.68884 .5 m
.68884 .50375 L
s
.71582 .5 m
.71582 .50375 L
s
.74279 .5 m
.74279 .50375 L
s
.79675 .5 m
.79675 .50375 L
s
.82373 .5 m
.82373 .50375 L
s
.8507 .5 m
.8507 .50375 L
s
.87768 .5 m
.87768 .50375 L
s
.06837 .5 m
.06837 .50375 L
s
.04139 .5 m
.04139 .50375 L
s
.01441 .5 m
.01441 .50375 L
s
.93163 .5 m
.93163 .50375 L
s
.95861 .5 m
.95861 .50375 L
s
.98559 .5 m
.98559 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .09534 m
.50625 .09534 L
s
[(-3)] .4875 .09534 1 0 Mshowa
.5 .23023 m
.50625 .23023 L
s
[(-2)] .4875 .23023 1 0 Mshowa
.5 .36511 m
.50625 .36511 L
s
[(-1)] .4875 .36511 1 0 Mshowa
.5 .63489 m
.50625 .63489 L
s
[(1)] .4875 .63489 1 0 Mshowa
.5 .76977 m
.50625 .76977 L
s
[(2)] .4875 .76977 1 0 Mshowa
.5 .90466 m
.50625 .90466 L
s
[(3)] .4875 .90466 1 0 Mshowa
.125 Mabswid
.5 .12232 m
.50375 .12232 L
s
.5 .1493 m
.50375 .1493 L
s
.5 .17627 m
.50375 .17627 L
s
.5 .20325 m
.50375 .20325 L
s
.5 .25721 m
.50375 .25721 L
s
.5 .28418 m
.50375 .28418 L
s
.5 .31116 m
.50375 .31116 L
s
.5 .33814 m
.50375 .33814 L
s
.5 .39209 m
.50375 .39209 L
s
.5 .41907 m
.50375 .41907 L
s
.5 .44605 m
.50375 .44605 L
s
.5 .47302 m
.50375 .47302 L
s
.5 .52698 m
.50375 .52698 L
s
.5 .55395 m
.50375 .55395 L
s
.5 .58093 m
.50375 .58093 L
s
.5 .60791 m
.50375 .60791 L
s
.5 .66186 m
.50375 .66186 L
s
.5 .68884 m
.50375 .68884 L
s
.5 .71582 m
.50375 .71582 L
s
.5 .74279 m
.50375 .74279 L
s
.5 .79675 m
.50375 .79675 L
s
.5 .82373 m
.50375 .82373 L
s
.5 .8507 m
.50375 .8507 L
s
.5 .87768 m
.50375 .87768 L
s
.5 .06837 m
.50375 .06837 L
s
.5 .04139 m
.50375 .04139 L
s
.5 .01441 m
.50375 .01441 L
s
.5 .93163 m
.50375 .93163 L
s
.5 .95861 m
.50375 .95861 L
s
.5 .98559 m
.50375 .98559 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.0125 -114.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
75.062 13.000 moveto
(direction) show
135.062 13.000 moveto
(field) show
165.062 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
.09534 .09534 m
.16688 .02381 L
s
% Start of user PostScript
-3. -3. -2.46967 -3.53033 MAarrowhead1
% End of user PostScript
.09534 .19651 m
.15604 .11558 L
s
% Start of user PostScript
-3. -2.25 -2.55 -2.85 MAarrowhead1
% End of user PostScript
.09534 .29767 m
.14059 .20719 L
s
% Start of user PostScript
-3. -1.5 -2.66459 -2.17082 MAarrowhead1
% End of user PostScript
.09534 .39884 m
.11988 .30069 L
s
% Start of user PostScript
-3. -0.75 -2.8181 -1.47761 MAarrowhead1
% End of user PostScript
.09534 .5 m
.09534 .39884 L
s
% Start of user PostScript
-3. 0 -3. -0.75 MAarrowhead1
% End of user PostScript
.09534 .60116 m
.07081 .50302 L
s
% Start of user PostScript
-3. 0.75 -3.1819 0.0223931 MAarrowhead1
% End of user PostScript
.09534 .70233 m
.0501 .61184 L
s
% Start of user PostScript
-3. 1.5 -3.33541 0.82918 MAarrowhead1
% End of user PostScript
.09534 .80349 m
.03464 .72256 L
s
% Start of user PostScript
-3. 2.25 -3.45 1.65 MAarrowhead1
% End of user PostScript
.09534 .90466 m
.02381 .83312 L
s
% Start of user PostScript
-3. 3. -3.53033 2.46967 MAarrowhead1
% End of user PostScript
.19651 .09534 m
.27744 .03464 L
s
% Start of user PostScript
-2.25 -3. -1.65 -3.45 MAarrowhead1
% End of user PostScript
.19651 .19651 m
.26804 .12497 L
s
% Start of user PostScript
-2.25 -2.25 -1.71967 -2.78033 MAarrowhead1
% End of user PostScript
.19651 .29767 m
.25262 .2135 L
s
% Start of user PostScript
-2.25 -1.5 -1.83397 -2.12404 MAarrowhead1
% End of user PostScript
.19651 .39884 m
.2285 .30286 L
s
% Start of user PostScript
-2.25 -0.75 -2.01283 -1.46151 MAarrowhead1
% End of user PostScript
.19651 .5 m
.19651 .39884 L
s
% Start of user PostScript
-2.25 0 -2.25 -0.75 MAarrowhead1
% End of user PostScript
.19651 .60116 m
.16452 .50519 L
s
% Start of user PostScript
-2.25 0.75 -2.48717 0.0384875 MAarrowhead1
% End of user PostScript
.19651 .70233 m
.14039 .61815 L
s
% Start of user PostScript
-2.25 1.5 -2.66603 0.875962 MAarrowhead1
% End of user PostScript
.19651 .80349 m
.12497 .73196 L
s
% Start of user PostScript
-2.25 2.25 -2.78033 1.71967 MAarrowhead1
% End of user PostScript
.19651 .90466 m
.11558 .84396 L
s
% Start of user PostScript
-2.25 3. -2.85 2.55 MAarrowhead1
% End of user PostScript
.29767 .09534 m
.38816 .0501 L
s
% Start of user PostScript
-1.5 -3. -0.82918 -3.33541 MAarrowhead1
% End of user PostScript
.29767 .19651 m
.38185 .14039 L
s
% Start of user PostScript
-1.5 -2.25 -0.875962 -2.66603 MAarrowhead1
% End of user PostScript
.29767 .29767 m
.36921 .22614 L
s
% Start of user PostScript
-1.5 -1.5 -0.96967 -2.03033 MAarrowhead1
% End of user PostScript
.29767 .39884 m
.34291 .30835 L
s
% Start of user PostScript
-1.5 -0.75 -1.16459 -1.42082 MAarrowhead1
% End of user PostScript
.29767 .5 m
.29767 .39884 L
s
% Start of user PostScript
-1.5 0 -1.5 -0.75 MAarrowhead1
% End of user PostScript
.29767 .60116 m
.25243 .51068 L
s
% Start of user PostScript
-1.5 0.75 -1.83541 0.0791796 MAarrowhead1
% End of user PostScript
.29767 .70233 m
.22614 .63079 L
s
% Start of user PostScript
-1.5 1.5 -2.03033 0.96967 MAarrowhead1
% End of user PostScript
.29767 .80349 m
.2135 .74738 L
s
% Start of user PostScript
-1.5 2.25 -2.12404 1.83397 MAarrowhead1
% End of user PostScript
.29767 .90466 m
.20719 .85941 L
s
% Start of user PostScript
-1.5 3. -2.17082 2.66459 MAarrowhead1
% End of user PostScript
.39884 .09534 m
.49698 .07081 L
s
% Start of user PostScript
-0.75 -3. -0.0223931 -3.1819 MAarrowhead1
% End of user PostScript
.39884 .19651 m
.49481 .16452 L
s
% Start of user PostScript
-0.75 -2.25 -0.0384875 -2.48717 MAarrowhead1
% End of user PostScript
.39884 .29767 m
.48932 .25243 L
s
% Start of user PostScript
-0.75 -1.5 -0.0791796 -1.83541 MAarrowhead1
% End of user PostScript
.39884 .39884 m
.47037 .3273 L
s
% Start of user PostScript
-0.75 -0.75 -0.21967 -1.28033 MAarrowhead1
% End of user PostScript
.39884 .5 m
.39884 .39884 L
s
% Start of user PostScript
-0.75 0 -0.75 -0.75 MAarrowhead1
% End of user PostScript
.39884 .60116 m
.3273 .52963 L
s
% Start of user PostScript
-0.75 0.75 -1.28033 0.21967 MAarrowhead1
% End of user PostScript
.39884 .70233 m
.30835 .65709 L
s
% Start of user PostScript
-0.75 1.5 -1.42082 1.16459 MAarrowhead1
% End of user PostScript
.39884 .80349 m
.30286 .7715 L
s
% Start of user PostScript
-0.75 2.25 -1.46151 2.01283 MAarrowhead1
% End of user PostScript
.39884 .90466 m
.30069 .88012 L
s
% Start of user PostScript
-0.75 3. -1.47761 2.8181 MAarrowhead1
% End of user PostScript
.5 .09534 m
.60116 .09534 L
s
% Start of user PostScript
0 -3. 0.75 -3. MAarrowhead1
% End of user PostScript
.5 .19651 m
.60116 .19651 L
s
% Start of user PostScript
0 -2.25 0.75 -2.25 MAarrowhead1
% End of user PostScript
.5 .29767 m
.60116 .29767 L
s
% Start of user PostScript
0 -1.5 0.75 -1.5 MAarrowhead1
% End of user PostScript
.5 .39884 m
.60116 .39884 L
s
% Start of user PostScript
0 -0.75 0.75 -0.75 MAarrowhead1
% End of user PostScript
.5 .60116 m
.39884 .60116 L
s
% Start of user PostScript
0 0.75 -0.75 0.75 MAarrowhead1
% End of user PostScript
.5 .70233 m
.39884 .70233 L
s
% Start of user PostScript
0 1.5 -0.75 1.5 MAarrowhead1
% End of user PostScript
.5 .80349 m
.39884 .80349 L
s
% Start of user PostScript
0 2.25 -0.75 2.25 MAarrowhead1
% End of user PostScript
.5 .90466 m
.39884 .90466 L
s
% Start of user PostScript
0 3. -0.75 3. MAarrowhead1
% End of user PostScript
.60116 .09534 m
.69931 .11988 L
s
% Start of user PostScript
0.75 -3. 1.47761 -2.8181 MAarrowhead1
% End of user PostScript
.60116 .19651 m
.69714 .2285 L
s
% Start of user PostScript
0.75 -2.25 1.46151 -2.01283 MAarrowhead1
% End of user PostScript
.60116 .29767 m
.69165 .34291 L
s
% Start of user PostScript
0.75 -1.5 1.42082 -1.16459 MAarrowhead1
% End of user PostScript
.60116 .39884 m
.6727 .47037 L
s
% Start of user PostScript
0.75 -0.75 1.28033 -0.21967 MAarrowhead1
% End of user PostScript
.60116 .5 m
.60116 .60116 L
s
% Start of user PostScript
0.75 0 0.75 0.75 MAarrowhead1
% End of user PostScript
.60116 .60116 m
.52963 .6727 L
s
% Start of user PostScript
0.75 0.75 0.21967 1.28033 MAarrowhead1
% End of user PostScript
.60116 .70233 m
.51068 .74757 L
s
% Start of user PostScript
0.75 1.5 0.0791796 1.83541 MAarrowhead1
% End of user PostScript
.60116 .80349 m
.50519 .83548 L
s
% Start of user PostScript
0.75 2.25 0.0384875 2.48717 MAarrowhead1
% End of user PostScript
.60116 .90466 m
.50302 .92919 L
s
% Start of user PostScript
0.75 3. 0.0223931 3.1819 MAarrowhead1
% End of user PostScript
.70233 .09534 m
.79281 .14059 L
s
% Start of user PostScript
1.5 -3. 2.17082 -2.66459 MAarrowhead1
% End of user PostScript
.70233 .19651 m
.7865 .25262 L
s
% Start of user PostScript
1.5 -2.25 2.12404 -1.83397 MAarrowhead1
% End of user PostScript
.70233 .29767 m
.77386 .36921 L
s
% Start of user PostScript
1.5 -1.5 2.03033 -0.96967 MAarrowhead1
% End of user PostScript
.70233 .39884 m
.74757 .48932 L
s
% Start of user PostScript
1.5 -0.75 1.83541 -0.0791796 MAarrowhead1
% End of user PostScript
.70233 .5 m
.70233 .60116 L
s
% Start of user PostScript
1.5 0 1.5 0.75 MAarrowhead1
% End of user PostScript
.70233 .60116 m
.65709 .69165 L
s
% Start of user PostScript
1.5 0.75 1.16459 1.42082 MAarrowhead1
% End of user PostScript
.70233 .70233 m
.63079 .77386 L
s
% Start of user PostScript
1.5 1.5 0.96967 2.03033 MAarrowhead1
% End of user PostScript
.70233 .80349 m
.61815 .85961 L
s
% Start of user PostScript
1.5 2.25 0.875962 2.66603 MAarrowhead1
% End of user PostScript
.70233 .90466 m
.61184 .9499 L
s
% Start of user PostScript
1.5 3. 0.82918 3.33541 MAarrowhead1
% End of user PostScript
.80349 .09534 m
.88442 .15604 L
s
% Start of user PostScript
2.25 -3. 2.85 -2.55 MAarrowhead1
% End of user PostScript
.80349 .19651 m
.87503 .26804 L
s
% Start of user PostScript
2.25 -2.25 2.78033 -1.71967 MAarrowhead1
% End of user PostScript
.80349 .29767 m
.85961 .38185 L
s
% Start of user PostScript
2.25 -1.5 2.66603 -0.875962 MAarrowhead1
% End of user PostScript
.80349 .39884 m
.83548 .49481 L
s
% Start of user PostScript
2.25 -0.75 2.48717 -0.0384875 MAarrowhead1
% End of user PostScript
.80349 .5 m
.80349 .60116 L
s
% Start of user PostScript
2.25 0 2.25 0.75 MAarrowhead1
% End of user PostScript
.80349 .60116 m
.7715 .69714 L
s
% Start of user PostScript
2.25 0.75 2.01283 1.46151 MAarrowhead1
% End of user PostScript
.80349 .70233 m
.74738 .7865 L
s
% Start of user PostScript
2.25 1.5 1.83397 2.12404 MAarrowhead1
% End of user PostScript
.80349 .80349 m
.73196 .87503 L
s
% Start of user PostScript
2.25 2.25 1.71967 2.78033 MAarrowhead1
% End of user PostScript
.80349 .90466 m
.72256 .96536 L
s
% Start of user PostScript
2.25 3. 1.65 3.45 MAarrowhead1
% End of user PostScript
.90466 .09534 m
.97619 .16688 L
s
% Start of user PostScript
3. -3. 3.53033 -2.46967 MAarrowhead1
% End of user PostScript
.90466 .19651 m
.96536 .27744 L
s
% Start of user PostScript
3. -2.25 3.45 -1.65 MAarrowhead1
% End of user PostScript
.90466 .29767 m
.9499 .38816 L
s
% Start of user PostScript
3. -1.5 3.33541 -0.82918 MAarrowhead1
% End of user PostScript
.90466 .39884 m
.92919 .49698 L
s
% Start of user PostScript
3. -0.75 3.1819 -0.0223931 MAarrowhead1
% End of user PostScript
.90466 .5 m
.90466 .60116 L
s
% Start of user PostScript
3. 0 3. 0.75 MAarrowhead1
% End of user PostScript
.90466 .60116 m
.88012 .69931 L
s
% Start of user PostScript
3. 0.75 2.8181 1.47761 MAarrowhead1
% End of user PostScript
.90466 .70233 m
.85941 .79281 L
s
% Start of user PostScript
3. 1.5 2.66459 2.17082 MAarrowhead1
% End of user PostScript
.90466 .80349 m
.84396 .88442 L
s
% Start of user PostScript
3. 2.25 2.55 2.85 MAarrowhead1
% End of user PostScript
.90466 .90466 m
.83312 .97619 L
s
% Start of user PostScript
3. 3. 2.46967 3.53033 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{183, 183},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002g0000]b000`400?l00000o`00003oFoooool0
0ol0003oooooooooo`1Iooooo`00Foooool00ol0003oooooooooo`1Iooooo`00Foooool00ol0003o
ooooooooo`1Iooooo`00Foooool00ol0003oooooooooo`1Iooooo`008_ooool2o`0003Oooooo00?o
0000ooooooooool0FOooool0027ooooo0ol0000gooooo`03o`000?oooooooooo05Wooooo000Poooo
o`?o00004Oooool2o`0002Gooooo00?o0000ooooooooool0FOooool0027ooooo00?o0000oooooooo
ool03oooool3o`0002Gooooo00?o0000ooooooooool0FOooool0023ooooo00?o0000ooooooooool0
3oooool3o`0002Kooooo00?o0000ooooooooool0FOooool001oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooo`00000Booooo`?o00004_ooool00ol0003oooooooooo`1Iooooo`007_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo0ol0000Dooooo`03o`000?oooooo
oooo05Wooooo000Mooooo`03o`000?oooooooooo00kooooo0_l0000Cooooo`?o00005Oooool00ol0
003oooooooooo`1Iooooo`007?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017o
oooo0_l0000Cooooo`Ko0000Foooool001_ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo1?l00002ooooo`03o`000?oooooooooo05Wooooo
000Jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool2o`0001;ooooo1?l0
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo05Wooooo000Iooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool2o`00017ooooo1?l00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0FOooool001Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`;o00004?ooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`?o0000C?ooool001Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo0_l00008ooooo`;o00001OoooolCo`0000ko
oooo0_l0000?ooooo`;o00003oooool00ol0003oooooooooo`0Fooooo`00E_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo013ooooo1?l0000<ooooo`;o00003oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01Gooooo001Booooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0Dooooo`Go00000_ooool2o`0000Gooooo0ol0000=ooooo`;o0000
3_ooool00ol0003oooooooooo`0Dooooo`008?ooool2o`00037ooooo0ol00005ooooo`03o`000?oo
oooooooo01Wooooo1Ol00007ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01?ooooo000Oooooo`?o00004Oooool2o`0002Kooooo00?o0000ooooooooool06_ooool5
o`0000Sooooo0_l0000<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool0
01kooooo0ol0000Aooooo`?o00009_ooool00ol0003oooooooooo`0Yooooo`Co00002Oooool2o`00
00gooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool03oooool3o`0002Oo
oooo00?o0000ooooooooool0:_ooool4o`0000[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0@ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00004_ooool3o`0001?ooooo
00?o0000ooooooooool0;Oooool2o`0000[ooooo0ol0000;ooooo`03o`000?oooooooooo00oooooo
000Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool4o`0001Cooooo00?o
0000ooooooooool0>_ooool2o`0000cooooo00?o0000ooooooooool03_ooool001gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Aooooo`?o00005Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00[ooooo0ol0000=ooooo`007?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooool000005_ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Wooooo0ol0000=ooooo`006oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo013ooooo0_l0000Dooooo`Ko0000COooool2o`0000cooooo000Jooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03oooool2o`0001Gooooo1?l00002ooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo0ol00002ooooo`05o`000?oo
ooooooooooooool00000Foooool001Wooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`;o00004_ooool3o`0000Wooooo00?o0000ooooooooool0FOooool001Sooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo0ol0000<
ooooo`03o`000?oooooooooo05Wooooo000Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`;o00003ooooolBo`0000oooooo0_l0000?oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool005_ooooo00?o0000oooooooo
ool02_ooool2o`0000?ooooo0ol0000>ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Fooooo`007_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo01;ooooo0ol0000<ooooo`;o00003Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01Gooooo000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Eooooo`?o00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool05?ooool001gooooo0_l0000Aooooo`;o00008?ooool5
o`0000Cooooo00?o0000ooooooooool06?ooool5o`0000Oooooo0_l0000<ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool04oooool001cooooo0_l0000Aooooo`?o00004_ooool2o`00
00gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Kooooo`?o00002?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool0
01cooooo0_l0000@ooooo`?o00004_ooool3o`0000Kooooo1Ol00003ooooo`03o`000?oooooooooo
00Cooooo0_l0000Kooooo`Go00002?ooool2o`0000_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Booooo`007?ooool00ol0003oooooooooo`0@ooooo`;o00004Oooool3o`00013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`;o00002_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo017ooooo000Kooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04Oooool2o`0000kooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo02[ooooo0_l0000:ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool04?ooool001_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Wo
oooo1?l0000:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool001[ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
0ol000001_oooooo0000o`000?l0003oooooo`0002kooooo0_l0000:ooooo`?o00003?ooool00ol0
003oooooooooo`0?ooooo`006_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04oooool3o`0000?ooooo00?o0000ooooooooool0>?ooool3o`0000go
oooo0_l0000?ooooo`006_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04oooool3o`0000Cooooo00?o0000ooooooooool0>_ooool2o`0000cooooo
0_l0000?ooooo`006Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04Oooool3o`0000Oooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo000Iooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0@ooooo`;o00002_ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo00_ooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`;o00003?ooool00ol0003oooooooooo`1Ioooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool2o`0000kooooo00?o0000ooooooooool0FOooool001Oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_oooolBo`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01Kooooo000Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0:ooooo`;o00000oooool2o`0000kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo017ooooo0_l0000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Eooooo`006_ooool2o`00013ooooo0_l0000Booooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool04oooool2o`0000cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo000Iooooo`?o00003oooool3o`00017o
oooo0_l0000Jooooo`03o`000?oooooooooo01Gooooo0_l0000;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003ooooo
ooooo`0?ooooo`;o00004?ooool2o`0001Gooooo0_l00004ooooo`03o`000?oooooooooo01Oooooo
0_l0000:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Dooooo`006_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo0_l0
000Dooooo`?o00001?ooool00ol0003oooooooooo`0Iooooo`?o00002?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool001[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0ol00005
ooooo`03o`000?oooooooooo01Wooooo1?l00008ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`006Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool2o`0000Kooooo00?o0000oooo
ooooool07?ooool2o`0000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Booooo`Co00001Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`00
6Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02Sooooo0_l0000;ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool001Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo1Ol00003ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09oooool3o`0000cooooo0ol0000<ooooo`03o`00
0?oooooooooo017ooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool2o`0002_ooooo00?o0000ooooooooool02Oooool3o`0000gooooo0_l0000Aooooo`006?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool2
o`0000gooooo0_l0000Aooooo`006?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`;o00001_ooool00ol0
003oooooooooo`0hooooo`;o00003?ooool2o`00017ooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo0_l0000@ooooo`005oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oooolAo`00013ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo000G
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool2o`0000;ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool05_ooool001Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Kooooo000Fooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o
00004?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo000Fooooo`;o0000
3oooool2o`0000oooooo0_l0000?ooooo`;o00004?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01Gooooo000Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Eooooo`005oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05?ooool001Oooooo1?l0000=ooooo`03o`000?oooooooooo
00;ooooo1Ol00007ooooo`03o`000?oooooooooo00Wooooo0ol00002ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04Oooool4o`0000cooooo00?o0000ooooooooool00oooool5o`00
00Gooooo00?o0000ooooooooool02_ooool3o`000003ooooool0003ooooo01Gooooo000Gooooo`05
o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o
0000ooooooooool04_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooooooo
o`;o00005_ooool0017ooooo1Ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo1Ol00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool5o`0000?o
oooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo01;ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooo000001Gooooo000Gooooo`04o`000?oooooo0000
o`0000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool00_ooool2o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo0_l00002ooooo`03o`000?oooooooooo01?ooooo000G
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool0
00004?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooooooo`?o00002_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooo000001Gooooo000Gooooo`05o`000?ooooooooooooooool000003?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`09ooooo`;o00000oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo0_l0
0006ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool01ol0003ooooooooooooooooo0000ooooool0
00005Oooool001Oooooo1?l0000=ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`03o`00
0?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03oooool2o`0000;ooooo0ol00008ooooo`?o00002?ooool3o`0000?o
oooo00?o0000ooooooooool04_ooool001Oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Tooooo`;o00003Oooool3o`0000gooooo0ol0000Cooooo`005oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02Gooooo0_l0000<ooooo`?o00003Oooool3o`0001?ooooo000G
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;
ooooo`;o00003_ooool2o`0001?ooooo0007ooooojSo00002?ooool000Wooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?oooooo0000ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oo
ooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:
ooooo`004_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo000Booooo`;o
00003_ooool2o`0000gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Kooooo000Booooo`?o00003Oooool3o`0000cooooo0_l0000Xooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool05_ooool001?ooooo00?o0000ooooooooool03?oo
ool2o`0000kooooo0_l0000:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Fooooo`004oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00_ooooo0_l0000:ooooo`;o00006oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01Kooooo000Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`09ooooo`;o00006_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Kooooo000Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Fooooo`005?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool05_ooool001Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Kooooo000Eooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`005Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool001Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo000Fooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool03Oooool2o`0000oooooo0_l0000?ooooo`;o0000
3oooool2o`0001Oooooo000Fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Ooo
ool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0001Oooooo000Gooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`005oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oooolBo`00
00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool05_ooool004gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo000?ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`003oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Gooooo`003oooool2o`0000gooooo0_l0000cooooo`?o00001Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01Oooooo000@ooooo`;o00003?ooool3o`0000cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool05oooool0013ooooo0_l0000=ooooo`?o00002oooool2o`0002Gooooo00?o0000oooooooo
ool01?ooool2o`0000Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool0017ooooo00?o0000ooooooooool0
2oooool00ol0003oooooo`00000<ooooo`;o00009?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool06?ooool001;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000002?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo000Booooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`;o00001_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo000Cooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`?o00005oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool001Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo0ol0000Looooo`03o`000?oooooooooo00;ooooo0ol0000Dooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`005?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool4o`0001[ooooo
00Co0000oooooooooooooooo0_l0000Eooooo`;o00004_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Wooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`09ooooo`;o00006?ooool00ol0003oooooooooo`0Hooooo`;o0000
4?ooool2o`00013ooooo0_l0000Kooooo`005Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool2o`0001Kooooo00?o0000ooooooooool06?oo
ool2o`00013ooooo0ol0000?ooooo`?o00006_ooool001Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo0ol0000Cooooo`03o`000?oooooo
oooo01Oooooo0_l0000Aooooo`?o00003oooool3o`0001[ooooo000Fooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`;o00004Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo013ooooo0_l0000@ooooo`;o00006oooool001Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00ko
oooo4_l0000>ooooo`;o00004?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000001Sooooo001=ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool2o`00017ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo001Kooooo`03o`00
0?oooooooooo00Sooooo0_l0000Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Gooooo`00Foooool00ol0003oooooooooo`06ooooo`;o00004ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05ooo
ool000cooooo0_l0001=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?ooool0
00cooooo0ol0000=ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool00oooool2o`00
01Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Sooooo000=ooooo`?o00003?ooool2o`0003gooooo00?o0000ooooooooool00ol0000Eooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`00
3_ooool00ol0003oooooooooo`0<ooooo`;o0000??ooool00ol0003oooooo`000003o`0001Cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo
000?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000002_ooool3o`0002kooooo0ol0
000Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Iooooo`004?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo1?l0000S
ooooo`Go00001?ooool00ol0003oooooooooo`0Dooooo`;o00005?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02?ooool3o`0002Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0J
ooooo`004_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00Co0000oooo
ool0003o00008oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo0ol0000A
ooooo`?o00004Oooool00ol0003oooooooooo`0Kooooo`004_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00_ooooo0_l00006ooooo`Go00005oooool00ol0003oooooooooo`03oooo
o`;o00004oooool2o`0001?ooooo0ol0000@ooooo`;o00007Oooool001?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1?l0000Cooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Wooooo`;o00004Oooool2o`00
01gooooo000Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool2o`0000Ko
oooo00?o0000ooooooooool01?l0000?ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0Vooooo`;o00004_ooool2o`0001gooooo000Eooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool2o`0000_ooooo0ol0000=ooooo`?o00001Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo0_l0000Nooooo`005_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool3o`0001;ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Mooooo`005oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03OoooolCo`0000kooooo0_l0
000?ooooo`;o00004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo001=
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool3o`00013ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo001Koooo
o`03o`000?oooooooooo00Kooooo0ol0000Aooooo`;o00004Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Oooooo001Kooooo`03o`000?oooooooooo00Cooooo0_l0000Cooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`00
Foooool00ol0003oooooo`000004o`0001Cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Wooooo000;ooooo`03o`000?oooooooooo04gooooo1?l0
000Eooooo`;o00004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo000;
ooooo`;o0000C_ooool5o`0001?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01[ooooo000<ooooo`;o00003?ooool2o`0003oooooo00?o0000oooo
ooooool04oooool2o`0001?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Koooo
o`003?ooool00ol0003oooooo`00000;ooooo`?o0000?_ooool00ol0003oooooooooo`0Booooo`;o
00004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01_ooooo000?ooooo`03o`00
0?oooooooooo00Wooooo1?l0000looooo`03o`000?oooooooooo017ooooo1?l0000@ooooo`;o0000
4oooool00ol0003oooooooooo`0Looooo`004?ooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0000Wooooo0ol0000_ooooo`03o`000?oooooooooo013ooooo0_l0000Cooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool07Oooool0017ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`08ooooo`?o0000;Oooool00ol0003oooooooooo`0Tooooo`?o00004Ooo
ool00ol0003oooooooooo`0Nooooo`004_ooool00ol0003oooooooooo`0<ooooo`;o00002Oooool4
o`0002_ooooo00?o0000ooooooooool08oooool2o`0001?ooooo0_l0000Oooooo`004oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l00007ooooo`Co00007_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo01oooooo000Dooooo`03o`000?oooooooooo00go
oooo0_l0000<ooooo`;o00001oooool5o`0001_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Pooooo`005Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo
0ol00005ooooo`04o`000?ooooooooooooooo`Go00003_ooool3o`0000Gooooo00?o0000oooooooo
ool0FOooool001Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`;o0000
3?ooool4o`0000Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05Wo
oooo000Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=oooooaCo00003?ooool3o`0000oooooo0_l0000?ooooo`;o00004?ooool00ol0003ooooo
ooooo`0Fooooo`00COooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003ooooooooo
o`08ooooo`?o00004?ooool2o`00013ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Gooooo`00E_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0ol0000A
ooooo`;o00004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo001Boooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003oooooo`000?l0003ooooo00?o00004_oo
ool2o`0001;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`00Doooool3
o`0000Gooooo1Ol0000Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Jooooo`00Foooool4o`0001?ooooo0_l0000Booooo`;o00004Oooool00ol0
003oooooooooo`0Kooooo`00Foooool00ol0003oooooooooo`0Aooooo`?o00004oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01cooooo001Kooooo`03o`000?oooooooooo013ooooo
1?l0000Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool005_ooooo00?o
0000ooooooooool03oooool2o`0001?ooooo0_l0000Booooo`03o`000?oooooooooo01kooooo001K
ooooo`03o`000?oooooooooo02Cooooo0_l0000@ooooo`;o00008Oooool005_ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo001Kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool04?ooool3o`00027ooooo001Kooooo`03o`00
0?oooooooooo03Cooooo0_l0000Sooooo`00Foooool00ol0003oooooooooo`1Iooooo`00Foooool0
0ol0003oooooooooo`1Iooooo`00Foooool00ol0003oooooooooo`1Iooooo`00Foooool00ol0003o
ooooooooo`1Iooooo`00]oooool00;Oooooo002gooooo`00]oooool00;Oooooo000Xooooo`;o0000
00Coooooo`000?l0003o00001oooool4o`000003ooooool0003o000000?o000000Coooooo`000?l0
003o00001?ooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002oooo
o`?o000000?oooooo`000?l000001_ooool5o`000003ooooool0003o000000?o00000_ooool3o`00
00;ooooo1Ol00002ooooo`Co0000:_ooool002Sooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0:Ooo
ool002Sooooo1Ol00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`Go000000?oooooo`000?ooool01Oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool5o`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo02Wooooo000Yoooo
o`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooo`;o00000oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01?l0003ooooo
ooooool00006ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0002_o
oooo000Yooooo`03o`000?oooooo000000Wooooo0ol00002ooooo`?o00000oooool2o`000003oooo
ool0003o000000;ooooo0ol00003ooooo`?o00000_ooool4o`0000;ooooo0ol00004ooooo`?o0000
0_ooool4o`0000Wooooo1?l000001?oooooo0000o`000?l00004ooooo`?o00001?ooool00ol0003o
ooooooooo`02ooooo`?o0000:oooool002[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Wooooo000Yooooo`;o00002oooool2o`0000Cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo0_l0
0003ooooo`03o`000?oooooooooo00Oooooo0ol00005ooooo`;o0000:oooool00;Oooooo002goooo
o`00\
\>"],
  ImageRangeCache->{{{77.875, 259.875}, {553.375, 371.375}} -> {-7.45674, \
12.6913, 0.0441554, 0.0441554}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["The slope field for y' = f",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Bold"],
  StyleBox[" t, y ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "The slope field for the first order differential equation ",
  StyleBox["y'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  " ( ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  " ) can be obtained by applying PlotVectorField to the vector field < 1 , \
",
  StyleBox["f",
    FontSlant->"Italic"],
  " ( ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  " ) > (normalized to unit length). The following entry produces the \
direction field for the differential equation"
}], "Text"],

Cell[TextData[{
  StyleBox["y'",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`y\/\(t\^2 + 1\)\)],
    TextAlignment->Center,
    TextJustification->0]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
u = 1; v = y/(t^2+1);
PlotVectorField[ {u,v}/Sqrt[u^2+v^2], {t,-3,3}, {y,-3,3}, Axes->True, 
                 PlotLabel->\"A slope field\" ]\
\>", "Input",
  CellLabel->"In[174]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05982 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.468254 0.148148 0.529912 0.148148 [
[.02381 .51741 -6 -9 ]
[.02381 .51741 6 0 ]
[.17196 .51741 -6 -9 ]
[.17196 .51741 6 0 ]
[.32011 .51741 -6 -9 ]
[.32011 .51741 6 0 ]
[.6164 .51741 -3 -9 ]
[.6164 .51741 3 0 ]
[.76455 .51741 -3 -9 ]
[.76455 .51741 3 0 ]
[.9127 .51741 -3 -9 ]
[.9127 .51741 3 0 ]
[.45575 .08547 -12 -4.5 ]
[.45575 .08547 0 4.5 ]
[.45575 .23362 -12 -4.5 ]
[.45575 .23362 0 4.5 ]
[.45575 .38176 -12 -4.5 ]
[.45575 .38176 0 4.5 ]
[.45575 .67806 -6 -4.5 ]
[.45575 .67806 0 4.5 ]
[.45575 .82621 -6 -4.5 ]
[.45575 .82621 0 4.5 ]
[.45575 .97436 -6 -4.5 ]
[.45575 .97436 0 4.5 ]
[.5 1.07232 -41.0312 0 ]
[.5 1.07232 41.0312 12 ]
[ 0 0 0 0 ]
[ 1 1.05982 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .52991 m
.02381 .53616 L
s
[(-3)] .02381 .51741 0 1 Mshowa
.17196 .52991 m
.17196 .53616 L
s
[(-2)] .17196 .51741 0 1 Mshowa
.32011 .52991 m
.32011 .53616 L
s
[(-1)] .32011 .51741 0 1 Mshowa
.6164 .52991 m
.6164 .53616 L
s
[(1)] .6164 .51741 0 1 Mshowa
.76455 .52991 m
.76455 .53616 L
s
[(2)] .76455 .51741 0 1 Mshowa
.9127 .52991 m
.9127 .53616 L
s
[(3)] .9127 .51741 0 1 Mshowa
.125 Mabswid
.05344 .52991 m
.05344 .53366 L
s
.08307 .52991 m
.08307 .53366 L
s
.1127 .52991 m
.1127 .53366 L
s
.14233 .52991 m
.14233 .53366 L
s
.20159 .52991 m
.20159 .53366 L
s
.23122 .52991 m
.23122 .53366 L
s
.26085 .52991 m
.26085 .53366 L
s
.29048 .52991 m
.29048 .53366 L
s
.34974 .52991 m
.34974 .53366 L
s
.37937 .52991 m
.37937 .53366 L
s
.40899 .52991 m
.40899 .53366 L
s
.43862 .52991 m
.43862 .53366 L
s
.49788 .52991 m
.49788 .53366 L
s
.52751 .52991 m
.52751 .53366 L
s
.55714 .52991 m
.55714 .53366 L
s
.58677 .52991 m
.58677 .53366 L
s
.64603 .52991 m
.64603 .53366 L
s
.67566 .52991 m
.67566 .53366 L
s
.70529 .52991 m
.70529 .53366 L
s
.73492 .52991 m
.73492 .53366 L
s
.79418 .52991 m
.79418 .53366 L
s
.82381 .52991 m
.82381 .53366 L
s
.85344 .52991 m
.85344 .53366 L
s
.88307 .52991 m
.88307 .53366 L
s
.94233 .52991 m
.94233 .53366 L
s
.97196 .52991 m
.97196 .53366 L
s
.25 Mabswid
0 .52991 m
1 .52991 L
s
.46825 .08547 m
.4745 .08547 L
s
[(-3)] .45575 .08547 1 0 Mshowa
.46825 .23362 m
.4745 .23362 L
s
[(-2)] .45575 .23362 1 0 Mshowa
.46825 .38176 m
.4745 .38176 L
s
[(-1)] .45575 .38176 1 0 Mshowa
.46825 .67806 m
.4745 .67806 L
s
[(1)] .45575 .67806 1 0 Mshowa
.46825 .82621 m
.4745 .82621 L
s
[(2)] .45575 .82621 1 0 Mshowa
.46825 .97436 m
.4745 .97436 L
s
[(3)] .45575 .97436 1 0 Mshowa
.125 Mabswid
.46825 .1151 m
.472 .1151 L
s
.46825 .14473 m
.472 .14473 L
s
.46825 .17436 m
.472 .17436 L
s
.46825 .20399 m
.472 .20399 L
s
.46825 .26325 m
.472 .26325 L
s
.46825 .29288 m
.472 .29288 L
s
.46825 .3225 m
.472 .3225 L
s
.46825 .35213 m
.472 .35213 L
s
.46825 .41139 m
.472 .41139 L
s
.46825 .44102 m
.472 .44102 L
s
.46825 .47065 m
.472 .47065 L
s
.46825 .50028 m
.472 .50028 L
s
.46825 .55954 m
.472 .55954 L
s
.46825 .58917 m
.472 .58917 L
s
.46825 .6188 m
.472 .6188 L
s
.46825 .64843 m
.472 .64843 L
s
.46825 .70769 m
.472 .70769 L
s
.46825 .73732 m
.472 .73732 L
s
.46825 .76695 m
.472 .76695 L
s
.46825 .79658 m
.472 .79658 L
s
.46825 .85584 m
.472 .85584 L
s
.46825 .88547 m
.472 .88547 L
s
.46825 .9151 m
.472 .9151 L
s
.46825 .94473 m
.472 .94473 L
s
.46825 .05584 m
.472 .05584 L
s
.46825 .02621 m
.472 .02621 L
s
.46825 1.00399 m
.472 1.00399 L
s
.46825 1.03362 m
.472 1.03362 L
s
.25 Mabswid
.46825 0 m
.46825 1.05982 L
s
gsave
.5 1.07232 -102.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
75.062 13.000 moveto
(slope) show
111.062 13.000 moveto
(field) show
141.062 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
.02381 .08547 m
.08462 .06722 L
s
% Start of user PostScript
-3. -3. -2.5895 -3.12315 MAarrowhead1
% End of user PostScript
.02381 .14896 m
.0853 .13315 L
s
% Start of user PostScript
-3. -2.57143 -2.58493 -2.67816 MAarrowhead1
% End of user PostScript
.02381 .21245 m
.08589 .19915 L
s
% Start of user PostScript
-3. -2.14286 -2.58094 -2.23266 MAarrowhead1
% End of user PostScript
.02381 .27594 m
.08639 .26522 L
s
% Start of user PostScript
-3. -1.71429 -2.57759 -1.7867 MAarrowhead1
% End of user PostScript
.02381 .33944 m
.08678 .33134 L
s
% Start of user PostScript
-3. -1.28571 -2.57493 -1.34037 MAarrowhead1
% End of user PostScript
.02381 .40293 m
.08707 .39751 L
s
% Start of user PostScript
-3. -0.857143 -2.57299 -0.893743 MAarrowhead1
% End of user PostScript
.02381 .46642 m
.08724 .4637 L
s
% Start of user PostScript
-3. -0.428571 -2.57182 -0.446922 MAarrowhead1
% End of user PostScript
.02381 .52991 m
.0873 .52991 L
s
% Start of user PostScript
-3. 0 -2.57143 0 MAarrowhead1
% End of user PostScript
.02381 .5934 m
.08724 .59612 L
s
% Start of user PostScript
-3. 0.428571 -2.57182 0.446922 MAarrowhead1
% End of user PostScript
.02381 .6569 m
.08707 .66232 L
s
% Start of user PostScript
-3. 0.857143 -2.57299 0.893743 MAarrowhead1
% End of user PostScript
.02381 .72039 m
.08678 .72849 L
s
% Start of user PostScript
-3. 1.28571 -2.57493 1.34037 MAarrowhead1
% End of user PostScript
.02381 .78388 m
.08639 .79461 L
s
% Start of user PostScript
-3. 1.71429 -2.57759 1.7867 MAarrowhead1
% End of user PostScript
.02381 .84737 m
.08589 .86068 L
s
% Start of user PostScript
-3. 2.14286 -2.58094 2.23266 MAarrowhead1
% End of user PostScript
.02381 .91086 m
.0853 .92668 L
s
% Start of user PostScript
-3. 2.57143 -2.58493 2.67816 MAarrowhead1
% End of user PostScript
.02381 .97436 m
.08462 .9926 L
s
% Start of user PostScript
-3. 3. -2.5895 3.12315 MAarrowhead1
% End of user PostScript
.0873 .08547 m
.14637 .06219 L
s
% Start of user PostScript
-2.57143 -3. -2.1727 -3.15714 MAarrowhead1
% End of user PostScript
.0873 .14896 m
.14745 .12864 L
s
% Start of user PostScript
-2.57143 -2.57143 -2.1654 -2.70859 MAarrowhead1
% End of user PostScript
.0873 .21245 m
.14842 .19525 L
s
% Start of user PostScript
-2.57143 -2.14286 -2.15889 -2.25899 MAarrowhead1
% End of user PostScript
.0873 .27594 m
.14924 .26199 L
s
% Start of user PostScript
-2.57143 -1.71429 -2.15333 -1.80844 MAarrowhead1
% End of user PostScript
.0873 .33944 m
.14991 .32886 L
s
% Start of user PostScript
-2.57143 -1.28571 -2.14884 -1.35709 MAarrowhead1
% End of user PostScript
.0873 .40293 m
.15039 .39582 L
s
% Start of user PostScript
-2.57143 -0.857143 -2.14555 -0.905097 MAarrowhead1
% End of user PostScript
.0873 .46642 m
.15069 .46285 L
s
% Start of user PostScript
-2.57143 -0.428571 -2.14353 -0.452662 MAarrowhead1
% End of user PostScript
.0873 .52991 m
.15079 .52991 L
s
% Start of user PostScript
-2.57143 0 -2.14286 0 MAarrowhead1
% End of user PostScript
.0873 .5934 m
.15069 .59697 L
s
% Start of user PostScript
-2.57143 0.428571 -2.14353 0.452662 MAarrowhead1
% End of user PostScript
.0873 .6569 m
.15039 .664 L
s
% Start of user PostScript
-2.57143 0.857143 -2.14555 0.905097 MAarrowhead1
% End of user PostScript
.0873 .72039 m
.14991 .73096 L
s
% Start of user PostScript
-2.57143 1.28571 -2.14884 1.35709 MAarrowhead1
% End of user PostScript
.0873 .78388 m
.14924 .79783 L
s
% Start of user PostScript
-2.57143 1.71429 -2.15333 1.80844 MAarrowhead1
% End of user PostScript
.0873 .84737 m
.14842 .86458 L
s
% Start of user PostScript
-2.57143 2.14286 -2.15889 2.25899 MAarrowhead1
% End of user PostScript
.0873 .91086 m
.14745 .93118 L
s
% Start of user PostScript
-2.57143 2.57143 -2.1654 2.70859 MAarrowhead1
% End of user PostScript
.0873 .97436 m
.14637 .99764 L
s
% Start of user PostScript
-2.57143 3. -2.1727 3.15714 MAarrowhead1
% End of user PostScript
.15079 .08547 m
.20674 .05545 L
s
% Start of user PostScript
-2.14286 -3. -1.7652 -3.20261 MAarrowhead1
% End of user PostScript
.15079 .14896 m
.20848 .12243 L
s
% Start of user PostScript
-2.14286 -2.57143 -1.75348 -2.75048 MAarrowhead1
% End of user PostScript
.15079 .21245 m
.21008 .18973 L
s
% Start of user PostScript
-2.14286 -2.14286 -1.74266 -2.29622 MAarrowhead1
% End of user PostScript
.15079 .27594 m
.2115 .25733 L
s
% Start of user PostScript
-2.14286 -1.71429 -1.73311 -1.8399 MAarrowhead1
% End of user PostScript
.15079 .33944 m
.21267 .32521 L
s
% Start of user PostScript
-2.14286 -1.28571 -1.72518 -1.38175 MAarrowhead1
% End of user PostScript
.15079 .40293 m
.21355 .39331 L
s
% Start of user PostScript
-2.14286 -0.857143 -1.71923 -0.922078 MAarrowhead1
% End of user PostScript
.15079 .46642 m
.2141 .46157 L
s
% Start of user PostScript
-2.14286 -0.428571 -1.71554 -0.461322 MAarrowhead1
% End of user PostScript
.15079 .52991 m
.21429 .52991 L
s
% Start of user PostScript
-2.14286 0 -1.71429 0 MAarrowhead1
% End of user PostScript
.15079 .5934 m
.2141 .59826 L
s
% Start of user PostScript
-2.14286 0.428571 -1.71554 0.461322 MAarrowhead1
% End of user PostScript
.15079 .6569 m
.21355 .66652 L
s
% Start of user PostScript
-2.14286 0.857143 -1.71923 0.922078 MAarrowhead1
% End of user PostScript
.15079 .72039 m
.21267 .73462 L
s
% Start of user PostScript
-2.14286 1.28571 -1.72518 1.38175 MAarrowhead1
% End of user PostScript
.15079 .78388 m
.2115 .80249 L
s
% Start of user PostScript
-2.14286 1.71429 -1.73311 1.8399 MAarrowhead1
% End of user PostScript
.15079 .84737 m
.21008 .87009 L
s
% Start of user PostScript
-2.14286 2.14286 -1.74266 2.29622 MAarrowhead1
% End of user PostScript
.15079 .91086 m
.20848 .93739 L
s
% Start of user PostScript
-2.14286 2.57143 -1.75348 2.75048 MAarrowhead1
% End of user PostScript
.15079 .97436 m
.20674 1.00437 L
s
% Start of user PostScript
-2.14286 3. -1.7652 3.20261 MAarrowhead1
% End of user PostScript
.21429 .08547 m
.2648 .047 L
s
% Start of user PostScript
-1.71429 -3. -1.37335 -3.25968 MAarrowhead1
% End of user PostScript
.21429 .14896 m
.26745 .11425 L
s
% Start of user PostScript
-1.71429 -2.57143 -1.35542 -2.80571 MAarrowhead1
% End of user PostScript
.21429 .21245 m
.27006 .18211 L
s
% Start of user PostScript
-1.71429 -2.14286 -1.33782 -2.34767 MAarrowhead1
% End of user PostScript
.21429 .27594 m
.2725 .25061 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.32132 -1.88532 MAarrowhead1
% End of user PostScript
.21429 .33944 m
.27464 .31973 L
s
% Start of user PostScript
-1.71429 -1.28571 -1.30687 -1.4187 MAarrowhead1
% End of user PostScript
.21429 .40293 m
.27633 .38943 L
s
% Start of user PostScript
-1.71429 -0.857143 -1.29552 -0.948274 MAarrowhead1
% End of user PostScript
.21429 .46642 m
.27741 .45955 L
s
% Start of user PostScript
-1.71429 -0.428571 -1.28823 -0.47493 MAarrowhead1
% End of user PostScript
.21429 .52991 m
.27778 .52991 L
s
% Start of user PostScript
-1.71429 0 -1.28571 0 MAarrowhead1
% End of user PostScript
.21429 .5934 m
.27741 .60027 L
s
% Start of user PostScript
-1.71429 0.428571 -1.28823 0.47493 MAarrowhead1
% End of user PostScript
.21429 .6569 m
.27633 .6704 L
s
% Start of user PostScript
-1.71429 0.857143 -1.29552 0.948274 MAarrowhead1
% End of user PostScript
.21429 .72039 m
.27464 .74009 L
s
% Start of user PostScript
-1.71429 1.28571 -1.30687 1.4187 MAarrowhead1
% End of user PostScript
.21429 .78388 m
.2725 .80922 L
s
% Start of user PostScript
-1.71429 1.71429 -1.32132 1.88532 MAarrowhead1
% End of user PostScript
.21429 .84737 m
.27006 .87772 L
s
% Start of user PostScript
-1.71429 2.14286 -1.33782 2.34767 MAarrowhead1
% End of user PostScript
.21429 .91086 m
.26745 .94557 L
s
% Start of user PostScript
-1.71429 2.57143 -1.35542 2.80571 MAarrowhead1
% End of user PostScript
.21429 .97436 m
.2648 1.01283 L
s
% Start of user PostScript
-1.71429 3. -1.37335 3.25968 MAarrowhead1
% End of user PostScript
.27778 .08547 m
.31984 .03791 L
s
% Start of user PostScript
-1.28571 -3. -1.0018 -3.32104 MAarrowhead1
% End of user PostScript
.27778 .14896 m
.32337 .10477 L
s
% Start of user PostScript
-1.28571 -2.57143 -0.977971 -2.8697 MAarrowhead1
% End of user PostScript
.27778 .21245 m
.32717 .17256 L
s
% Start of user PostScript
-1.28571 -2.14286 -0.952311 -2.41214 MAarrowhead1
% End of user PostScript
.27778 .27594 m
.33111 .24149 L
s
% Start of user PostScript
-1.28571 -1.71429 -0.92575 -1.94688 MAarrowhead1
% End of user PostScript
.27778 .33944 m
.33491 .31175 L
s
% Start of user PostScript
-1.28571 -1.28571 -0.900044 -1.47262 MAarrowhead1
% End of user PostScript
.27778 .40293 m
.33819 .38341 L
s
% Start of user PostScript
-1.28571 -0.857143 -0.877898 -0.988899 MAarrowhead1
% End of user PostScript
.27778 .46642 m
.34046 .4563 L
s
% Start of user PostScript
-1.28571 -0.428571 -0.862627 -0.496916 MAarrowhead1
% End of user PostScript
.27778 .52991 m
.34127 .52991 L
s
% Start of user PostScript
-1.28571 0 -0.857143 0 MAarrowhead1
% End of user PostScript
.27778 .5934 m
.34046 .60353 L
s
% Start of user PostScript
-1.28571 0.428571 -0.862627 0.496916 MAarrowhead1
% End of user PostScript
.27778 .6569 m
.33819 .67642 L
s
% Start of user PostScript
-1.28571 0.857143 -0.877898 0.988899 MAarrowhead1
% End of user PostScript
.27778 .72039 m
.33491 .74808 L
s
% Start of user PostScript
-1.28571 1.28571 -0.900044 1.47262 MAarrowhead1
% End of user PostScript
.27778 .78388 m
.33111 .81834 L
s
% Start of user PostScript
-1.28571 1.71429 -0.92575 1.94688 MAarrowhead1
% End of user PostScript
.27778 .84737 m
.32717 .88727 L
s
% Start of user PostScript
-1.28571 2.14286 -0.952311 2.41214 MAarrowhead1
% End of user PostScript
.27778 .91086 m
.32337 .95505 L
s
% Start of user PostScript
-1.28571 2.57143 -0.977971 2.8697 MAarrowhead1
% End of user PostScript
.27778 .97436 m
.31984 1.02192 L
s
% Start of user PostScript
-1.28571 3. -1.0018 3.32104 MAarrowhead1
% End of user PostScript
.34127 .08547 m
.37305 .0305 L
s
% Start of user PostScript
-0.857143 -3. -0.642612 -3.37101 MAarrowhead1
% End of user PostScript
.34127 .14896 m
.37678 .09632 L
s
% Start of user PostScript
-0.857143 -2.57143 -0.617466 -2.92671 MAarrowhead1
% End of user PostScript
.34127 .21245 m
.38122 .1631 L
s
% Start of user PostScript
-0.857143 -2.14286 -0.587486 -2.47596 MAarrowhead1
% End of user PostScript
.34127 .27594 m
.38643 .23131 L
s
% Start of user PostScript
-0.857143 -1.71429 -0.552309 -2.01553 MAarrowhead1
% End of user PostScript
.34127 .33944 m
.39228 .30163 L
s
% Start of user PostScript
-0.857143 -1.28571 -0.512833 -1.54091 MAarrowhead1
% End of user PostScript
.34127 .40293 m
.39819 .3748 L
s
% Start of user PostScript
-0.857143 -0.857143 -0.472917 -1.047 MAarrowhead1
% End of user PostScript
.34127 .46642 m
.40291 .45119 L
s
% Start of user PostScript
-0.857143 -0.428571 -0.441081 -0.531363 MAarrowhead1
% End of user PostScript
.34127 .52991 m
.40476 .52991 L
s
% Start of user PostScript
-0.857143 0 -0.428571 0 MAarrowhead1
% End of user PostScript
.34127 .5934 m
.40291 .60863 L
s
% Start of user PostScript
-0.857143 0.428571 -0.441081 0.531363 MAarrowhead1
% End of user PostScript
.34127 .6569 m
.39819 .68502 L
s
% Start of user PostScript
-0.857143 0.857143 -0.472917 1.047 MAarrowhead1
% End of user PostScript
.34127 .72039 m
.39228 .75819 L
s
% Start of user PostScript
-0.857143 1.28571 -0.512833 1.54091 MAarrowhead1
% End of user PostScript
.34127 .78388 m
.38643 .82851 L
s
% Start of user PostScript
-0.857143 1.71429 -0.552309 2.01553 MAarrowhead1
% End of user PostScript
.34127 .84737 m
.38122 .89672 L
s
% Start of user PostScript
-0.857143 2.14286 -0.587486 2.47596 MAarrowhead1
% End of user PostScript
.34127 .91086 m
.37678 .9635 L
s
% Start of user PostScript
-0.857143 2.57143 -0.617466 2.92671 MAarrowhead1
% End of user PostScript
.34127 .97436 m
.37305 1.02932 L
s
% Start of user PostScript
-0.857143 3. -0.642612 3.37101 MAarrowhead1
% End of user PostScript
.40476 .08547 m
.42806 .02641 L
s
% Start of user PostScript
-0.428571 -3. -0.271276 -3.39866 MAarrowhead1
% End of user PostScript
.40476 .14896 m
.43131 .09128 L
s
% Start of user PostScript
-0.428571 -2.57143 -0.249367 -2.96073 MAarrowhead1
% End of user PostScript
.40476 .21245 m
.43546 .15688 L
s
% Start of user PostScript
-0.428571 -2.14286 -0.221349 -2.518 MAarrowhead1
% End of user PostScript
.40476 .27594 m
.44084 .2237 L
s
% Start of user PostScript
-0.428571 -1.71429 -0.185061 -2.06696 MAarrowhead1
% End of user PostScript
.40476 .33944 m
.44777 .29273 L
s
% Start of user PostScript
-0.428571 -1.28571 -0.138296 -1.60101 MAarrowhead1
% End of user PostScript
.40476 .40293 m
.45619 .36569 L
s
% Start of user PostScript
-0.428571 -0.857143 -0.0814534 -1.1085 MAarrowhead1
% End of user PostScript
.40476 .46642 m
.46446 .4448 L
s
% Start of user PostScript
-0.428571 -0.428571 -0.0256004 -0.574475 MAarrowhead1
% End of user PostScript
.40476 .52991 m
.46825 .52991 L
s
% Start of user PostScript
-0.428571 0 0 0 MAarrowhead1
% End of user PostScript
.40476 .5934 m
.46446 .61502 L
s
% Start of user PostScript
-0.428571 0.428571 -0.0256004 0.574475 MAarrowhead1
% End of user PostScript
.40476 .6569 m
.45619 .69414 L
s
% Start of user PostScript
-0.428571 0.857143 -0.0814534 1.1085 MAarrowhead1
% End of user PostScript
.40476 .72039 m
.44777 .7671 L
s
% Start of user PostScript
-0.428571 1.28571 -0.138296 1.60101 MAarrowhead1
% End of user PostScript
.40476 .78388 m
.44084 .83613 L
s
% Start of user PostScript
-0.428571 1.71429 -0.185061 2.06696 MAarrowhead1
% End of user PostScript
.40476 .84737 m
.43546 .90295 L
s
% Start of user PostScript
-0.428571 2.14286 -0.221349 2.518 MAarrowhead1
% End of user PostScript
.40476 .91086 m
.43131 .96854 L
s
% Start of user PostScript
-0.428571 2.57143 -0.249367 2.96073 MAarrowhead1
% End of user PostScript
.40476 .97436 m
.42806 1.03342 L
s
% Start of user PostScript
-0.428571 3. -0.271276 3.39866 MAarrowhead1
% End of user PostScript
.46825 .08547 m
.48833 .02523 L
s
% Start of user PostScript
0 -3. 0.135526 -3.40658 MAarrowhead1
% End of user PostScript
.46825 .14896 m
.49127 .08978 L
s
% Start of user PostScript
0 -2.57143 0.155334 -2.97086 MAarrowhead1
% End of user PostScript
.46825 .21245 m
.4951 .15492 L
s
% Start of user PostScript
0 -2.14286 0.181237 -2.53122 MAarrowhead1
% End of user PostScript
.46825 .27594 m
.50025 .2211 L
s
% Start of user PostScript
0 -1.71429 0.215945 -2.08448 MAarrowhead1
% End of user PostScript
.46825 .33944 m
.50723 .28932 L
s
% Start of user PostScript
0 -1.28571 0.263117 -1.62401 MAarrowhead1
% End of user PostScript
.46825 .40293 m
.51646 .36161 L
s
% Start of user PostScript
0 -0.857143 0.325396 -1.13605 MAarrowhead1
% End of user PostScript
.46825 .46642 m
.52661 .44141 L
s
% Start of user PostScript
0 -0.428571 0.393919 -0.597394 MAarrowhead1
% End of user PostScript
.46825 .52991 m
.53175 .52991 L
s
% Start of user PostScript
0 0 0.428571 0 MAarrowhead1
% End of user PostScript
.46825 .5934 m
.52661 .61842 L
s
% Start of user PostScript
0 0.428571 0.393919 0.597394 MAarrowhead1
% End of user PostScript
.46825 .6569 m
.51646 .69822 L
s
% Start of user PostScript
0 0.857143 0.325396 1.13605 MAarrowhead1
% End of user PostScript
.46825 .72039 m
.50723 .77051 L
s
% Start of user PostScript
0 1.28571 0.263117 1.62401 MAarrowhead1
% End of user PostScript
.46825 .78388 m
.50025 .83872 L
s
% Start of user PostScript
0 1.71429 0.215945 2.08448 MAarrowhead1
% End of user PostScript
.46825 .84737 m
.4951 .90491 L
s
% Start of user PostScript
0 2.14286 0.181237 2.53122 MAarrowhead1
% End of user PostScript
.46825 .91086 m
.49127 .97004 L
s
% Start of user PostScript
0 2.57143 0.155334 2.97086 MAarrowhead1
% End of user PostScript
.46825 .97436 m
.48833 1.03459 L
s
% Start of user PostScript
0 3. 0.135526 3.40658 MAarrowhead1
% End of user PostScript
.53175 .08547 m
.55505 .02641 L
s
% Start of user PostScript
0.428571 -3. 0.585867 -3.39866 MAarrowhead1
% End of user PostScript
.53175 .14896 m
.55829 .09128 L
s
% Start of user PostScript
0.428571 -2.57143 0.607776 -2.96073 MAarrowhead1
% End of user PostScript
.53175 .21245 m
.56245 .15688 L
s
% Start of user PostScript
0.428571 -2.14286 0.635793 -2.518 MAarrowhead1
% End of user PostScript
.53175 .27594 m
.56782 .2237 L
s
% Start of user PostScript
0.428571 -1.71429 0.672082 -2.06696 MAarrowhead1
% End of user PostScript
.53175 .33944 m
.57475 .29273 L
s
% Start of user PostScript
0.428571 -1.28571 0.718847 -1.60101 MAarrowhead1
% End of user PostScript
.53175 .40293 m
.58317 .36569 L
s
% Start of user PostScript
0.428571 -0.857143 0.775689 -1.1085 MAarrowhead1
% End of user PostScript
.53175 .46642 m
.59145 .4448 L
s
% Start of user PostScript
0.428571 -0.428571 0.831543 -0.574475 MAarrowhead1
% End of user PostScript
.53175 .52991 m
.59524 .52991 L
s
% Start of user PostScript
0.428571 0 0.857143 0 MAarrowhead1
% End of user PostScript
.53175 .5934 m
.59145 .61502 L
s
% Start of user PostScript
0.428571 0.428571 0.831543 0.574475 MAarrowhead1
% End of user PostScript
.53175 .6569 m
.58317 .69414 L
s
% Start of user PostScript
0.428571 0.857143 0.775689 1.1085 MAarrowhead1
% End of user PostScript
.53175 .72039 m
.57475 .7671 L
s
% Start of user PostScript
0.428571 1.28571 0.718847 1.60101 MAarrowhead1
% End of user PostScript
.53175 .78388 m
.56782 .83613 L
s
% Start of user PostScript
0.428571 1.71429 0.672082 2.06696 MAarrowhead1
% End of user PostScript
.53175 .84737 m
.56245 .90295 L
s
% Start of user PostScript
0.428571 2.14286 0.635793 2.518 MAarrowhead1
% End of user PostScript
.53175 .91086 m
.55829 .96854 L
s
% Start of user PostScript
0.428571 2.57143 0.607776 2.96073 MAarrowhead1
% End of user PostScript
.53175 .97436 m
.55505 1.03342 L
s
% Start of user PostScript
0.428571 3. 0.585867 3.39866 MAarrowhead1
% End of user PostScript
.59524 .08547 m
.62702 .0305 L
s
% Start of user PostScript
0.857143 -3. 1.07167 -3.37101 MAarrowhead1
% End of user PostScript
.59524 .14896 m
.63075 .09632 L
s
% Start of user PostScript
0.857143 -2.57143 1.09682 -2.92671 MAarrowhead1
% End of user PostScript
.59524 .21245 m
.63519 .1631 L
s
% Start of user PostScript
0.857143 -2.14286 1.1268 -2.47596 MAarrowhead1
% End of user PostScript
.59524 .27594 m
.6404 .23131 L
s
% Start of user PostScript
0.857143 -1.71429 1.16198 -2.01553 MAarrowhead1
% End of user PostScript
.59524 .33944 m
.64625 .30163 L
s
% Start of user PostScript
0.857143 -1.28571 1.20145 -1.54091 MAarrowhead1
% End of user PostScript
.59524 .40293 m
.65216 .3748 L
s
% Start of user PostScript
0.857143 -0.857143 1.24137 -1.047 MAarrowhead1
% End of user PostScript
.59524 .46642 m
.65688 .45119 L
s
% Start of user PostScript
0.857143 -0.428571 1.2732 -0.531363 MAarrowhead1
% End of user PostScript
.59524 .52991 m
.65873 .52991 L
s
% Start of user PostScript
0.857143 0 1.28571 0 MAarrowhead1
% End of user PostScript
.59524 .5934 m
.65688 .60863 L
s
% Start of user PostScript
0.857143 0.428571 1.2732 0.531363 MAarrowhead1
% End of user PostScript
.59524 .6569 m
.65216 .68502 L
s
% Start of user PostScript
0.857143 0.857143 1.24137 1.047 MAarrowhead1
% End of user PostScript
.59524 .72039 m
.64625 .75819 L
s
% Start of user PostScript
0.857143 1.28571 1.20145 1.54091 MAarrowhead1
% End of user PostScript
.59524 .78388 m
.6404 .82851 L
s
% Start of user PostScript
0.857143 1.71429 1.16198 2.01553 MAarrowhead1
% End of user PostScript
.59524 .84737 m
.63519 .89672 L
s
% Start of user PostScript
0.857143 2.14286 1.1268 2.47596 MAarrowhead1
% End of user PostScript
.59524 .91086 m
.63075 .9635 L
s
% Start of user PostScript
0.857143 2.57143 1.09682 2.92671 MAarrowhead1
% End of user PostScript
.59524 .97436 m
.62702 1.02932 L
s
% Start of user PostScript
0.857143 3. 1.07167 3.37101 MAarrowhead1
% End of user PostScript
.65873 .08547 m
.70079 .03791 L
s
% Start of user PostScript
1.28571 -3. 1.56963 -3.32104 MAarrowhead1
% End of user PostScript
.65873 .14896 m
.70432 .10477 L
s
% Start of user PostScript
1.28571 -2.57143 1.59346 -2.8697 MAarrowhead1
% End of user PostScript
.65873 .21245 m
.70812 .17256 L
s
% Start of user PostScript
1.28571 -2.14286 1.61912 -2.41214 MAarrowhead1
% End of user PostScript
.65873 .27594 m
.71206 .24149 L
s
% Start of user PostScript
1.28571 -1.71429 1.64568 -1.94688 MAarrowhead1
% End of user PostScript
.65873 .33944 m
.71587 .31175 L
s
% Start of user PostScript
1.28571 -1.28571 1.67138 -1.47262 MAarrowhead1
% End of user PostScript
.65873 .40293 m
.71915 .38341 L
s
% Start of user PostScript
1.28571 -0.857143 1.69353 -0.988899 MAarrowhead1
% End of user PostScript
.65873 .46642 m
.72141 .4563 L
s
% Start of user PostScript
1.28571 -0.428571 1.7088 -0.496916 MAarrowhead1
% End of user PostScript
.65873 .52991 m
.72222 .52991 L
s
% Start of user PostScript
1.28571 0 1.71429 0 MAarrowhead1
% End of user PostScript
.65873 .5934 m
.72141 .60353 L
s
% Start of user PostScript
1.28571 0.428571 1.7088 0.496916 MAarrowhead1
% End of user PostScript
.65873 .6569 m
.71915 .67642 L
s
% Start of user PostScript
1.28571 0.857143 1.69353 0.988899 MAarrowhead1
% End of user PostScript
.65873 .72039 m
.71587 .74808 L
s
% Start of user PostScript
1.28571 1.28571 1.67138 1.47262 MAarrowhead1
% End of user PostScript
.65873 .78388 m
.71206 .81834 L
s
% Start of user PostScript
1.28571 1.71429 1.64568 1.94688 MAarrowhead1
% End of user PostScript
.65873 .84737 m
.70812 .88727 L
s
% Start of user PostScript
1.28571 2.14286 1.61912 2.41214 MAarrowhead1
% End of user PostScript
.65873 .91086 m
.70432 .95505 L
s
% Start of user PostScript
1.28571 2.57143 1.59346 2.8697 MAarrowhead1
% End of user PostScript
.65873 .97436 m
.70079 1.02192 L
s
% Start of user PostScript
1.28571 3. 1.56963 3.32104 MAarrowhead1
% End of user PostScript
.72222 .08547 m
.77273 .047 L
s
% Start of user PostScript
1.71429 -3. 2.05523 -3.25968 MAarrowhead1
% End of user PostScript
.72222 .14896 m
.77539 .11425 L
s
% Start of user PostScript
1.71429 -2.57143 2.07315 -2.80571 MAarrowhead1
% End of user PostScript
.72222 .21245 m
.77799 .18211 L
s
% Start of user PostScript
1.71429 -2.14286 2.09075 -2.34767 MAarrowhead1
% End of user PostScript
.72222 .27594 m
.78044 .25061 L
s
% Start of user PostScript
1.71429 -1.71429 2.10725 -1.88532 MAarrowhead1
% End of user PostScript
.72222 .33944 m
.78258 .31973 L
s
% Start of user PostScript
1.71429 -1.28571 2.1217 -1.4187 MAarrowhead1
% End of user PostScript
.72222 .40293 m
.78426 .38943 L
s
% Start of user PostScript
1.71429 -0.857143 2.13306 -0.948274 MAarrowhead1
% End of user PostScript
.72222 .46642 m
.78534 .45955 L
s
% Start of user PostScript
1.71429 -0.428571 2.14034 -0.47493 MAarrowhead1
% End of user PostScript
.72222 .52991 m
.78571 .52991 L
s
% Start of user PostScript
1.71429 0 2.14286 0 MAarrowhead1
% End of user PostScript
.72222 .5934 m
.78534 .60027 L
s
% Start of user PostScript
1.71429 0.428571 2.14034 0.47493 MAarrowhead1
% End of user PostScript
.72222 .6569 m
.78426 .6704 L
s
% Start of user PostScript
1.71429 0.857143 2.13306 0.948274 MAarrowhead1
% End of user PostScript
.72222 .72039 m
.78258 .74009 L
s
% Start of user PostScript
1.71429 1.28571 2.1217 1.4187 MAarrowhead1
% End of user PostScript
.72222 .78388 m
.78044 .80922 L
s
% Start of user PostScript
1.71429 1.71429 2.10725 1.88532 MAarrowhead1
% End of user PostScript
.72222 .84737 m
.77799 .87772 L
s
% Start of user PostScript
1.71429 2.14286 2.09075 2.34767 MAarrowhead1
% End of user PostScript
.72222 .91086 m
.77539 .94557 L
s
% Start of user PostScript
1.71429 2.57143 2.07315 2.80571 MAarrowhead1
% End of user PostScript
.72222 .97436 m
.77273 1.01283 L
s
% Start of user PostScript
1.71429 3. 2.05523 3.25968 MAarrowhead1
% End of user PostScript
.78571 .08547 m
.84166 .05545 L
s
% Start of user PostScript
2.14286 -3. 2.52051 -3.20261 MAarrowhead1
% End of user PostScript
.78571 .14896 m
.8434 .12243 L
s
% Start of user PostScript
2.14286 -2.57143 2.53223 -2.75048 MAarrowhead1
% End of user PostScript
.78571 .21245 m
.845 .18973 L
s
% Start of user PostScript
2.14286 -2.14286 2.54305 -2.29622 MAarrowhead1
% End of user PostScript
.78571 .27594 m
.84642 .25733 L
s
% Start of user PostScript
2.14286 -1.71429 2.55261 -1.8399 MAarrowhead1
% End of user PostScript
.78571 .33944 m
.84759 .32521 L
s
% Start of user PostScript
2.14286 -1.28571 2.56053 -1.38175 MAarrowhead1
% End of user PostScript
.78571 .40293 m
.84847 .39331 L
s
% Start of user PostScript
2.14286 -0.857143 2.56648 -0.922078 MAarrowhead1
% End of user PostScript
.78571 .46642 m
.84902 .46157 L
s
% Start of user PostScript
2.14286 -0.428571 2.57018 -0.461322 MAarrowhead1
% End of user PostScript
.78571 .52991 m
.84921 .52991 L
s
% Start of user PostScript
2.14286 0 2.57143 0 MAarrowhead1
% End of user PostScript
.78571 .5934 m
.84902 .59826 L
s
% Start of user PostScript
2.14286 0.428571 2.57018 0.461322 MAarrowhead1
% End of user PostScript
.78571 .6569 m
.84847 .66652 L
s
% Start of user PostScript
2.14286 0.857143 2.56648 0.922078 MAarrowhead1
% End of user PostScript
.78571 .72039 m
.84759 .73462 L
s
% Start of user PostScript
2.14286 1.28571 2.56053 1.38175 MAarrowhead1
% End of user PostScript
.78571 .78388 m
.84642 .80249 L
s
% Start of user PostScript
2.14286 1.71429 2.55261 1.8399 MAarrowhead1
% End of user PostScript
.78571 .84737 m
.845 .87009 L
s
% Start of user PostScript
2.14286 2.14286 2.54305 2.29622 MAarrowhead1
% End of user PostScript
.78571 .91086 m
.8434 .93739 L
s
% Start of user PostScript
2.14286 2.57143 2.53223 2.75048 MAarrowhead1
% End of user PostScript
.78571 .97436 m
.84166 1.00437 L
s
% Start of user PostScript
2.14286 3. 2.52051 3.20261 MAarrowhead1
% End of user PostScript
.84921 .08547 m
.90828 .06219 L
s
% Start of user PostScript
2.57143 -3. 2.97015 -3.15714 MAarrowhead1
% End of user PostScript
.84921 .14896 m
.90936 .12864 L
s
% Start of user PostScript
2.57143 -2.57143 2.97746 -2.70859 MAarrowhead1
% End of user PostScript
.84921 .21245 m
.91032 .19525 L
s
% Start of user PostScript
2.57143 -2.14286 2.98397 -2.25899 MAarrowhead1
% End of user PostScript
.84921 .27594 m
.91115 .26199 L
s
% Start of user PostScript
2.57143 -1.71429 2.98953 -1.80844 MAarrowhead1
% End of user PostScript
.84921 .33944 m
.91181 .32886 L
s
% Start of user PostScript
2.57143 -1.28571 2.99401 -1.35709 MAarrowhead1
% End of user PostScript
.84921 .40293 m
.9123 .39582 L
s
% Start of user PostScript
2.57143 -0.857143 2.99731 -0.905097 MAarrowhead1
% End of user PostScript
.84921 .46642 m
.9126 .46285 L
s
% Start of user PostScript
2.57143 -0.428571 2.99932 -0.452662 MAarrowhead1
% End of user PostScript
.84921 .52991 m
.9127 .52991 L
s
% Start of user PostScript
2.57143 0 3. 0 MAarrowhead1
% End of user PostScript
.84921 .5934 m
.9126 .59697 L
s
% Start of user PostScript
2.57143 0.428571 2.99932 0.452662 MAarrowhead1
% End of user PostScript
.84921 .6569 m
.9123 .664 L
s
% Start of user PostScript
2.57143 0.857143 2.99731 0.905097 MAarrowhead1
% End of user PostScript
.84921 .72039 m
.91181 .73096 L
s
% Start of user PostScript
2.57143 1.28571 2.99401 1.35709 MAarrowhead1
% End of user PostScript
.84921 .78388 m
.91115 .79783 L
s
% Start of user PostScript
2.57143 1.71429 2.98953 1.80844 MAarrowhead1
% End of user PostScript
.84921 .84737 m
.91032 .86458 L
s
% Start of user PostScript
2.57143 2.14286 2.98397 2.25899 MAarrowhead1
% End of user PostScript
.84921 .91086 m
.90936 .93118 L
s
% Start of user PostScript
2.57143 2.57143 2.97746 2.70859 MAarrowhead1
% End of user PostScript
.84921 .97436 m
.90828 .99764 L
s
% Start of user PostScript
2.57143 3. 2.97015 3.15714 MAarrowhead1
% End of user PostScript
.9127 .08547 m
.97351 .06722 L
s
% Start of user PostScript
3. -3. 3.4105 -3.12315 MAarrowhead1
% End of user PostScript
.9127 .14896 m
.97419 .13315 L
s
% Start of user PostScript
3. -2.57143 3.41507 -2.67816 MAarrowhead1
% End of user PostScript
.9127 .21245 m
.97478 .19915 L
s
% Start of user PostScript
3. -2.14286 3.41906 -2.23266 MAarrowhead1
% End of user PostScript
.9127 .27594 m
.97528 .26522 L
s
% Start of user PostScript
3. -1.71429 3.42241 -1.7867 MAarrowhead1
% End of user PostScript
.9127 .33944 m
.97567 .33134 L
s
% Start of user PostScript
3. -1.28571 3.42507 -1.34037 MAarrowhead1
% End of user PostScript
.9127 .40293 m
.97596 .39751 L
s
% Start of user PostScript
3. -0.857143 3.42701 -0.893743 MAarrowhead1
% End of user PostScript
.9127 .46642 m
.97613 .4637 L
s
% Start of user PostScript
3. -0.428571 3.42818 -0.446922 MAarrowhead1
% End of user PostScript
.9127 .52991 m
.97619 .52991 L
s
% Start of user PostScript
3. 0 3.42857 0 MAarrowhead1
% End of user PostScript
.9127 .5934 m
.97613 .59612 L
s
% Start of user PostScript
3. 0.428571 3.42818 0.446922 MAarrowhead1
% End of user PostScript
.9127 .6569 m
.97596 .66232 L
s
% Start of user PostScript
3. 0.857143 3.42701 0.893743 MAarrowhead1
% End of user PostScript
.9127 .72039 m
.97567 .72849 L
s
% Start of user PostScript
3. 1.28571 3.42507 1.34037 MAarrowhead1
% End of user PostScript
.9127 .78388 m
.97528 .79461 L
s
% Start of user PostScript
3. 1.71429 3.42241 1.7867 MAarrowhead1
% End of user PostScript
.9127 .84737 m
.97478 .86068 L
s
% Start of user PostScript
3. 2.14286 3.41906 2.23266 MAarrowhead1
% End of user PostScript
.9127 .91086 m
.97419 .92668 L
s
% Start of user PostScript
3. 2.57143 3.41507 2.67816 MAarrowhead1
% End of user PostScript
.9127 .97436 m
.97351 .9926 L
s
% Start of user PostScript
3. 3. 3.4105 3.12315 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1.05982 L
0 1.05982 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[174]:=",
  ImageSize->{168.938, 179},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003C0000gb000`400?l00000o`00003oI?ooool0
0ol0003oooooooooo`1/ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?ooool00ol0003o
ooooooooo`1/ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?ooool00ol0003ooooooooo
o`1/ooooo`00G?ooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo05_ooooo001Aooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000=ooooo`03o`000?oooooo
oooo04gooooo0016ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`;o00001oooool00ol0
003oooooooooo`02o`0000[ooooo0ol0000<ooooo`;o00003?ooool2o`00047ooooo0015ooooo`?o
00002?ooool2o`0000Sooooo0ol00007ooooo`04o`000?oooooo0000o`0000[ooooo0ol0000<oooo
o`;o00003?ooool3o`00047ooooo000kooooo`;o00001oooool3o`0000Sooooo0_l0000:ooooo`;o
00001oooool01?l0003oooooooooool0000;ooooo`;o00002oooool3o`0000_ooooo0ol0000<oooo
o`?o0000<oooool002oooooo0ol00007ooooo`Co00001oooool3o`0000Sooooo0_l00009ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo0ol0000:ooooo`Co00002oooool3o`0002Kooooo000]ooooo`Co0000
2?ooool3o`0000Sooooo0_l00008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1oooool3o`0000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`;o0000
2oooool3o`0000[ooooo1?l0000Wooooo`008Oooool5o`0000Kooooo1?l00007ooooo`;o000000?o
ooooo`000?ooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000[ooooo1?l0
000:ooooo`Go00006Oooool001Kooooo1Ol00006ooooo`?o00001oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00Co
0000oooooooooooo00002oooool3o`0000[ooooo1Ol0000<ooooo`005?ooool5o`0000Gooooo0ol0
00000ooooooo0000ooooo`05ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool01_l0003oV9RHoa0@4?l0003o<S8bolc<c0Go
oooo0_l0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`;o00002oooool2o`0000cooooo0ol000000ooooooo0000ooooo`08ooooo`Go
00003_ooool0013ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo0ol00009ooooo`;o0000
2oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool01_l0003o410@okZj^_ooooooMgMgoc8b<PGooooo0_l0000;ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo0_l0000;ooooo`?o00002_ooool4o`0000;ooooo00?o0000ooooooooool03_ooool000ko
oooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool7o`0000Go
oooo00?o0000ooooooooool00oooool2o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l0000Gooooo`00GOooool00ol0003o410@
ooooo`04ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`1Kooooo`00
D_ooool00ol0003oooooooooo`07ooooo`03oa0@4?l0003o^[Zj00Gooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0COooool0057ooooo
0_l00009ooooo`;o000000?o8B4Qooooooooool00oooool00ol0003oooooooooo`02o`0000_ooooo
0_l0000<ooooo`;o0000Coooool004Oooooo0_l00007ooooo`?o00001oooool01Ol@413o0000o`00
0?nj^[[o000000Gooooo00?o0000ooooool000000_l0000;ooooo`;o00002oooool3o`0000gooooo
0_l00010ooooo`00AOooool4o`0000Kooooo0ol00008ooooo`?o000000?o410@ojVYZOooool01?oo
ool00ol0003oooooooooo`02o`0000[ooooo0ol0000:ooooo`?o00003?ooool3o`00047ooooo000k
ooooo`?o00001_ooool4o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo0ol0000<
ooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`?o00003Oooool2o`0003?ooooo000`oooo
o`?o00001_ooool4o`0000Sooooo0_l00008ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0:ooooo`Co00002oooool3o`0002Gooooo000^ooooo`?o
00002?ooool3o`0000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool4o`0000[ooooo0ol0000Wooooo`00
8_ooool5o`0000Kooooo0ol00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo0_l0000<ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooo`0000[ooooo0ol0000:ooooo`Go00006Oooool001Kooooo1Ol00007ooooo`?o0000
1_ooool2o`000003ooooool0003ooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool2o`0000_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00[ooooo0ol0000:ooooo`Go0000
3?ooool001Cooooo1?l00007ooooo`Co00001_ooool2o`0000[ooooo0_l0000:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00002ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool2o`0000_ooooo0_l0000<ooooo`?o000000?oooooo`000?ooool02?ooool4o`0000oooooo000@
ooooo`Co00002?ooool3o`0000Sooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0_l0000;
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`?o00002_ooool4o`0001?ooooo000>oooo
o`;o00002_ooool2o`0000[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo0_l0000Gooooo`00G_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Jooooo`00
Doooool00ol0003oooooooooo`07ooooo`;o00001Oooool01?l0003oooooooooooooool2o`0000_o
oooo0_l0000=ooooo`03o`000?oooooooooo04cooooo001Booooo`;o00002?ooool2o`0000Kooooo
00?o0000ooooooooool00ol0000:ooooo`?o00003?ooool2o`0004kooooo0018ooooo`;o00001ooo
ool2o`0000Sooooo0ol00006ooooo`03o`000?oooooo000000;o00002_ooool3o`0000cooooo0ol0
000<ooooo`;o0000@?ooool004Kooooo0ol00007ooooo`?o00002Oooool00ol0003oooooooooo`05
ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo0ol0000<ooooo`?o0000@?ooool0
03cooooo0_l00007ooooo`?o00002?ooool2o`0000[ooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000002oooool3
o`0000cooooo0ol0000booooo`00>_ooool3o`0000Sooooo0_l00008ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000;ooooo`Co0000<oooool002ko
oooo1Ol00006ooooo`?o00001oooool2o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo1?l0000:ooooo`Go00009Oooool001Kooooo
1Ol00007ooooo`Go00001oooool3o`0000Kooooo0_l000000ooooooo0000ooooo`06ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooo000000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooo00002oooool3o`0000[ooooo1Ol00007ooooo`Go
00003?ooool001Cooooo1Ol00007ooooo`Go00001_ooool3o`000003ooooool0003ooooo00Cooooo
0_l0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`;o00002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool2o`0000cooooo0ol000000ooooooo0000ooooo`08ooooo`Go0000
1oooool5o`0000kooooo000@ooooo`Co00000_ooool00ol0003oooooooooo`03ooooo`Co00000_oo
ool00ol0003oooooooooo`03ooooo`?o00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`;o00002ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool2o`0000_ooooo0ol0000:ooooo`Co00000_ooool00ol0003oooooooooo`03ooooo`Co00000_oo
ool00ol0003oooooooooo`0>ooooo`003_ooool2o`0000[ooooo0_l0000:ooooo`;o00002oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2
o`0000_ooooo0_l0000:ooooo`;o00005oooool006Cooooo00?o0000ooooooooool0K?ooool005[o
oooo1_l00004ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`03o`000?oooooooooo05Wo
oooo001Jooooo`04oiRHV?lQ8B7ok^k^ooooo`;o00001?ooool01?l0003oooooooooooooool3o`00
00_ooooo0_l0001Kooooo`00D_ooool6o`0000?ooooo00CoV9RHob4Q8Ol0003o00001Oooool2o`00
0004ooooool0003o0000o`0000_ooooo0ol0000<ooooo`;o0000COooool005;ooooo0ol00007oooo
o`?o00001Oooool01?l0003oooooooooooooool2o`0000[ooooo0ol0000<ooooo`?o0000COooool0
04Oooooo0ol00007ooooo`?o00002Oooool00ol0003oIVIVooooo`04ooooo`05o`000?oooooooooo
ooooool000003?ooool2o`0000_ooooo0ol0000<ooooo`?o0000?oooool003cooooo0ol00006oooo
o`Co00001oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Gooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000_ooooo0ol0000<
ooooo`?o0000<_ooool003[ooooo1?l00007ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool02?ooool2o`000003oooooonHV9So410@00Gooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`Co0000<oooool0
02;ooooo0ol00009ooooo`Go00001Oooool5o`0000Kooooo0_l00009ooooo`03o`000?oooooooooo
00Wooooo00Go0000oa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooo000000_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`;o00002oooool5o`0000[ooooo1Ol00008
ooooo`?o00006_ooool001Kooooo1Ol00007ooooo`Go00001Oooool5o`0000Gooooo0_l00003oooo
o`03o`000?oooooooooo00?ooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01oooool2o`0000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`;o00002oooool2o`0000?ooooo00?o0000ooooooooool01oooool5o`0000[ooooo1Ol00007oooo
o`Go00003?ooool0017ooooo2?l00004ooooo`Oo00001?ooool4o`0000?ooooo00?o0000oooooooo
ool00_ooool2o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`;o00002oooool4o`0000?ooooo00?o0000oooooooo
ool01?ooool7o`0000Gooooo2?l0000>ooooo`003_ooool3o`0000Gooooo00Co0000oooooooooooo
oooo0ol00009ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool2o`0000_ooooo0ol00009ooooo`?o00001Oooool00ol0003o
ooooooooo`0>ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?ooool00ol0003ooooooooo
o`1/ooooo`00H?ooool01?l0003oooooooooooooool2o`0000Cooooo0_l0000<ooooo`03o`000?oo
oooooooo05Sooooo001Oooooo`;o00000oooool00ol0003oooooooooo`02ooooo`?o00002oooool2
o`0005[ooooo001Dooooo`;o00002?ooool2o`0000Cooooo00Co0000oooooooooooooooo0ol0000;
ooooo`?o00003?ooool2o`0004cooooo001Booooo`Co00001oooool3o`0000Cooooo00?o0000oooo
ooooool00_ooool2o`0000[ooooo0ol0000<ooooo`?o0000C?ooool004Sooooo0ol00006ooooo`Co
00002?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooo000000_ooooo0ol0000<ooooo`?o0000?_ooool004Kooooo1?l00007ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000_o
oooo00?o0000ooooooooool02oooool00ol0003oooooo`00000;ooooo`Co0000?oooool003[ooooo
1Ol00006ooooo`Co00001_ooool2o`0000_ooooo00?o0000ooooooooool01Oooool2o`000003oooo
ool0003ooooo00_ooooo00?o0000ooooooooool02Oooool2o`0000gooooo1?l0000:ooooo`Go0000
<Oooool002;ooooo1Ol00007ooooo`Go00001oooool3o`0000Oooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000
3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo
00002oooool3o`0000Wooooo1Ol00008ooooo`Go00006?ooool001Kooooo1Ol00005ooooo`Go0000
1oooool5o`0000Kooooo0ol000000ooooooo0000ooooo`05ooooo`;o00002Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`Co00002Oooool5o`0000Sooooo
1Ol00009ooooo`Go00003?ooool0017ooooo1ol00004ooooo`Co00000_ooool00ol0003ooooooooo
o`03ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00002Oooool2o`0000[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`;o00002oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`?o00002Oooool4o`0000?ooooo00?o
0000ooooooooool00oooool4o`0000;ooooo00?o0000ooooooooool01?ooool7o`0000oooooo000>
ooooo`?o00002Oooool2o`0000[ooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool2o`0000[ooooo0_l0000;ooooo`;o00002_ooool3o`0001Kooooo001Toooo
o`03o`000?oooooooooo06cooooo001Tooooo`;o0000KOooool006Cooooo00?o0000ooooooooool0
K?ooool006Cooooo00?o0000ooooooooool01Oooool2o`0006Gooooo001Kooooo`Co000000Ko410@
o`000?l0003o0000ooooool00006ooooo`?o00002_ooool3o`0005Sooooo001Dooooo`?o00001_oo
ool5o`0000;ooooo00?o0000ooooooooool00oooool3o`0000Wooooo1?l0000<ooooo`;o0000Booo
ool005;ooooo1_l00005ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000[ooooo0ol0000;ooooo`?o0000C?ooool004Oooooo1Ol00005ooooo`Co00002?ooool00ol0
003oooooo`000004ooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo0000
00[ooooo1?l0000:ooooo`Go0000?_ooool003_ooooo1Ol00007ooooo`?o00001_ooool01?l0003o
ooooooooool00008ooooo`;o00001_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00002oooool3o`0000[ooooo1Ol0000aooooo`005_ooool3
o`0000Wooooo1Ol00008ooooo`Go00001Oooool5o`0000Kooooo1?l00006ooooo`;o00002_ooool2
o`000003ooooool0003ooooo00Gooooo00?o0000ooooool000002oooool2o`0000_ooooo0_l0000<
ooooo`?o000000?oooooo`000?ooool02?ooool5o`0000[ooooo1Ol00007ooooo`Go00001oooool3
o`0000kooooo000Dooooo`Oo00000_ooool8o`0000Cooooo2Ol00003ooooo`Co00000_ooool00ol0
003oooooooooo`03ooooo`?o00002?ooool2o`0000_ooooo00Go0000ooooooooooooooooo`000006
ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`;o00002oooool3o`0000[ooooo1?l00002
ooooo`03o`000?oooooooooo00Cooooo2Ol00004ooooo`So00001oooool7o`0000cooooo000>oooo
o`Ko00000_ooool2o`0000;ooooo0ol00006ooooo`03o`000?oooooooooo00?o00001_ooool01?l0
003oooooooooooooool2o`0000[ooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo00Ko0000
ooooooooooooEEEEofIVI_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`?o0000
1_ooool01?l0003oooooooooooooool3o`0000Gooooo00Co0000oooooooooooooooo1_l00002oooo
o`;o00003oooool006Cooooo0_l0001]ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?oo
ool00ol0003oooooooooo`1/ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?ooool00ol0
003oooooooooo`1/ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?ooool2o`0000Oooooo
0ol0001Sooooo`00Goooool6o`0000Kooooo1?l00009ooooo`Go0000E_ooool005?ooooo1Ol00007
ooooo`?o00000_ooool00ol0003oooooooooo`02ooooo`Go00002_ooool3o`0000Wooooo1Ol0001:
ooooo`00>oooool3o`0000Wooooo1Ol00005ooooo`Go00001_ooool3o`000003ooooool0003ooooo
00;ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Kooooo1?l00009oooo
o`Go00002_ooool5o`0000Oooooo0ol0000cooooo`005_ooool3o`0000Oooooo1ol00006ooooo`Oo
00001Oooool7o`0000;ooooo2?l00003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o
00002?ooool3o`0000_ooooo0ol00009ooooo`Co00000oooool00ol0003oooooooooo`04ooooo`So
00001oooool7o`0000Kooooo1ol00005ooooo`Oo00001oooool3o`0000kooooo000>oooooa;o0000
0_ooool3o`000003ooooool0003o000000Go00000_ooool2o`0000;ooooo1_l00002ooooo`;o0000
0_ooool3o`0000Gooooo00Co0000oooooooooooooooo0_l0000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool2o`0000[ooooo0_l0000;ooooo`?o00001Oooool01?l0003o
ooooooooooooool6o`0000?ooooo0_l000000ooooooo0000o`000005o`0000;ooooo0_l00002oooo
o`Ko00000_ooool3o`000003ooooool0003o000000_o00003?ooool000oooooo00GoV9RHoa0@4?l0
003o<S8bolc<c002ooooo`;o00002_ooool00ol0003oooooooooo`06ooooo`Go00006Oooool4o`00
0003oa0@4?oooooooooo01Cooooo0_l0000Iooooo`Co000000?o410@ooooooooool05?ooool5o`00
01Oooooo00Ko0000oiRHV?l@413o0000oc8b<_o<c<`6ooooo`;o00003oooool000oooooo00Go410@
okZj^_ooooooMgMgoc8b<P0Gooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool01OnHV9So8B4Q
onk^k_ooooooA4A401Sooooo00Go410@okZj^_ooooooMgMgoc8b<P0Gooooo`001oooool6o`0000Ko
oooo00?o0000ooooooooool03Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool6o`0000Go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oo
oooo00?oV9RHob4Q8Oo^k^h07Oooool00ol0003oooooooooo`0Eooooo`004_ooool00onYZJWo410@
ooooo`0Hooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Sooooo00?oV9RHob4Q8Oo^k^h06oooool00onYZJWo410@
ooooo`0Fooooo`004Oooool00ol@413o0000okZj^P0Jooooo`03ogMgMomVIVKooooo01[ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
MgMgofIVI_ooool06Oooool00ol@413o0000okZj^P0Gooooo`004_ooool00onj^[[o8B4Qooooo`0J
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00onj^[[o8B4Qooooo`0F
ooooo`003oooool01Ol@413oV9RHoooooonj^[[o000001Oooooo00Go0000okZj^_ooooooV9RHoa0@
400Kooooo`03o`000?oooooooooo01Kooooo0_l0000Kooooo`03o`000?oooooooooo01Kooooo00Go
0000okZj^_ooooooV9RHoa0@400Hooooo`05oa0@4?nHV9SooooookZj^_l000005oooool000oooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@0Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06Oooool00omE
EEGoIVIVo`00000Hooooo`03o`000?oooooooooo01Sooooo00?oEEEEofIVI_l000006?ooool01OnH
V9So410@o`000?lQ8B7oc<c<01Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Gooooo`00I?ooool0
0ol0003oooooooooo`1/ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`005_ooool3o`0000Wo
oooo0ol0000:ooooo`?o00002Oooool3o`0000Wooooo0ol0000:ooooo`?o00002Oooool3o`000003
ooooool0003ooooo00Kooooo0ol0000:ooooo`?o00002Oooool3o`0000Wooooo0ol00009ooooo`?o
00002_ooool3o`0000Wooooo0ol00009ooooo`?o00003_ooool000Wooooo`ol00007ooooo`003_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool01?oo
ool00ol0003oooooooooo`02o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool00_oo
ool2o`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooool0003o
0000ooooool00005ooooo`04o`000?ooooooooooooooo`?o00001Oooool01?l0003ooooooooooooo
ool2o`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooool0003o
0000ooooool0000=ooooo`003_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`00I?ooool00ol0003ooooo
ooooo`1/ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?ooool00ol0003oooooooooo`1/
ooooo`00I?ooool2o`0006gooooo001Tooooo`03o`000?oooooooooo06cooooo001Tooooo`03o`00
0?oooooooooo06cooooo001Tooooo`03o`000?oooooooooo06cooooo001Tooooo`03o`000?oooooo
oooo06cooooo001Tooooo`03o`000?oooooooooo06cooooo000Fooooo`?o00002Oooool3o`0000[o
oooo0_l0000cooooo`;o0000A?ooool2o`0000[ooooo0ol00009ooooo`?o00003_ooool000kooooo
8?l000000ooooooo0000o`000009o`000005ooooool0003o0000o`000?ooool01?l00004ooooo`;o
00000_ooool3o`0000[ooooo0_l0000:ooooo`;o00002_ooool3o`0000Wooooo0ol0000:ooooo`Co
00001?ooool2o`0000;ooooo1ol00002ooooo`_o000000?oooooo`000?l000006ol0000<ooooo`00
5_ooool2o`0000[ooooo0_l0000:ooooo`Ko00001_ooool6o`0000?ooooo2?l00003ooooo`Co0000
0_ooool2o`0000Cooooo0ol00007ooooo`04o`000?oooooo0000o`0000_ooooo0ol00009ooooo`Co
00000_ooool2o`0000Kooooo2?l00007ooooo`Ko00001oooool6o`0000Oooooo0_l0000:ooooo`;o
00003oooool003_ooooo0_l0000:ooooo`Go00001_ooool5o`0000Kooooo1Ol00002ooooo`04o`00
0?ooooooooooooooo`?o000000?oooooo`000?ooool02?ooool4o`0000Wooooo1Ol00009ooooo`Go
00001oooool2o`0003Cooooo001Cooooo`Go00002?ooool3o`000003ooooool0003ooooo00Gooooo
0ol0000:ooooo`Co00002?ooool5o`0004[ooooo001Oooooo`Ko00001_ooool4o`0000Wooooo1Ol0
001Fooooo`00I?ooool2o`0000Sooooo0_l0001Sooooo`00I?ooool00ol0003oooooooooo`1/oooo
o`00I?ooool00ol0003oooooooooo`1/ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?oo
ool00ol0003oooooooooo`1/ooooo`00I?ooool2o`0006gooooo001Tooooo`03o`000?oooooooooo
06cooooo000>ooooo`Oo000000Goooooo`000?l0003o0000ooooo`07o`0000;ooooo1ol00005oooo
o`;o00000_ooool3o`0000Wooooo0ol00009ooooo`;o00002oooool2o`0000[ooooo0_l0000:oooo
o`;o00002_ooool2o`0000_ooooo0_l0000:ooooo`?o00002Oooool4o`0000Gooooo0_l00002oooo
o`Oo000000Goooooo`000?l0003o0000ooooo`07o`000004ooooool0003o0000o`0000kooooo000E
ooooo`Ko00001_ooool6o`0000?ooooo2Ol00003ooooo`Co000000?oooooo`000?l000001Oooool3
o`0000Sooooo0_l0000;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002oooool0
0ol0003oooooooooo`09ooooo`;o00002oooool3o`0000[ooooo1?l000000ooooooo0000o`000006
ooooo`Wo00001oooool6o`0000Kooooo1_l0000<ooooo`005_ooool2o`0000[ooooo0_l0000;oooo
o`Go00001_ooool5o`0000Kooooo1?l00006ooooo`?o00002Oooool4o`000003oa0@4?oooooooooo
00;ooooo00Co0000oooooooooooo00002oooool2o`0000_ooooo0ol0000;ooooo`Go00002Oooool5
o`0000Wooooo1Ol00007ooooo`;o00002_ooool2o`0000oooooo000kooooo`Go00001oooool4o`00
00Oooooo0ol00008ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000<
ooooo`03o`000?oooooooooo00_ooooo0ol0000;ooooo`?o00002Oooool5o`00037ooooo0017oooo
o`Go00001oooool3o`0000Oooooo0ol00004ooooo`;o00000oooool00ol0003oooooooooo`0:oooo
o`;o00003?ooool3o`0000Wooooo1Ol0000nooooo`00D_ooool5o`0000Kooooo00Co0000ooooool0
003o00000oooool00ol0003oooooooooo`03ooooo`;o00002oooool2o`0000_ooooo1?l0001;oooo
o`00GOooool5o`0000;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo1?l0001Iooooo`00
GOooool01?l0003oooooooooooooool2o`000003ooooool0003ooooo00Kooooo00?o0000oooooooo
ool02_ooool2o`0005Sooooo001Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Sooooo`00Foooool00omEEEGoIVIVo`000006ooooo`03o`000?oo
oooooooo06cooooo001Tooooo`;o0000KOooool006Cooooo00?o0000ooooooooool0K?ooool000ko
oooo1?l00004ooooo`;o00000_ooool4o`0000Sooooo0ol0000:ooooo`;o00002_ooool2o`0000[o
oooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`;o00002oooool2o`0000[ooooo0ol00009ooooo`?o00002_ooool4o`0000So
oooo1?l00004ooooo`;o00003oooool001;ooooo2?l00004ooooo`Oo00001?ooool4o`0000;ooooo
0_l00004ooooo`?o00002Oooool2o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`;o00002oooool3o`0000Wooooo1?l00002ooooo`;o00001_ooool7o`0000Gooooo
2?l0000=ooooo`005_ooool5o`0000Oooooo1Ol00006ooooo`Go00001_ooool5o`0000Kooooo0_l0
0009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`;o00003?ooool4o`0000Wooooo1Ol0
0009ooooo`Go00001oooool5o`0000cooooo000Rooooo`;o00002_ooool5o`0000Sooooo0ol00007
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooo000000_ooooo1?l00008ooooo`Go00002?ooool2o`0001_ooooo000joooo
o`Go00001oooool3o`0000Oooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo0ol0000<oooo
o`03o`000?oooooooooo00_ooooo0_l0000=ooooo`?o00002_ooool5o`00037ooooo0016ooooo`Co
00002?ooool2o`0000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000<oooo
o`03o`000?oooooooooo00cooooo0_l0000;ooooo`Co0000?oooool004Wooooo0_l00006ooooo`?o
00002Oooool2o`0000Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000[ooooo0ol0000;
ooooo`;o00003_ooool2o`0003kooooo001Cooooo`;o00002?ooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool2o`0000[ooooo0ol0000=ooooo`03o`000?oooooooooo04_ooooo001Eooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`00
00cooooo0_l0000=ooooo`03o`000?oooooooooo04[ooooo001Pooooo`04o`000?oooooooooooooo
o`;o00001?ooool2o`0000cooooo00?o0000ooooooooool0F?ooool006Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Uooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?oo
ool00ol0003oooooooooo`1/ooooo`003_ooool4o`0000Cooooo0_l00002ooooo`Co00002?ooool3
o`0000[ooooo0_l0000:ooooo`;o00002_ooool2o`0000_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`;o00002_ooool2
o`0000[ooooo0ol0000:ooooo`Co00002?ooool4o`0000Cooooo0_l0000?ooooo`004_ooool8o`00
00Cooooo1ol00004ooooo`Co00000_ooool2o`0000Cooooo0_l0000:ooooo`;o00002_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`;o00002oooool4o`00
00;ooooo0_l00006ooooo`Oo00001Oooool8o`0000gooooo000Fooooo`Go00001oooool5o`0000Ko
oooo1Ol00005ooooo`?o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo0ol000000ooooooo
0000ooooo`09ooooo`Go00002Oooool5o`0000Oooooo1Ol0000<ooooo`00;_ooool5o`0000Oooooo
0ol00007ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo0ol0000;ooooo`?o00002_ooool5o`0002Gooooo000jooooo`Co00002?oo
ool2o`0000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooo000000_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`;o00002_oo
ool4o`0003?ooooo000mooooo`;o00001_ooool4o`0000Sooooo0_l00007ooooo`Go00001Oooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`Co00003?oo
ool2o`0003;ooooo0018ooooo`;o00001oooool2o`0000Oooooo00GoV9RHob4Q8Ol0003o0000odA4
A005ooooo`03o`000?oooooooooo00?o00002_ooool3o`0000_ooooo0_l0000>ooooo`;o0000?ooo
ool005?ooooo00?o0000ooooooooool01Oooool00onHV9So0000o`000006ooooo`03o`000?oooooo
oooo00?o00002_ooool3o`0000gooooo00?o0000ooooooooool0C?ooool005Cooooo00?o0000oooo
ooooool01Oooool00onHV9So0000o`000005ooooo`;o00000_ooool2o`0000_ooooo0_l0000>oooo
o`03o`000?oooooooooo04_ooooo001Mooooo`03ogMgMol0003ooooo00Cooooo00?o0000oooooooo
ool00_ooool2o`0000_ooooo0_l0001Kooooo`00G_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Wooooo001Jooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`1/ooooo`003_ooool4o`0000Sooooo0ol0
0009ooooo`?o00002_ooool2o`0000[ooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo00Oo
0000oooooonHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`;o00002_ooool3o`0000[o
oooo0ol00009ooooo`Co00005Oooool001;ooooo1ol00004ooooo`Co000000?oooooo`000?l00000
1Oooool3o`0000Wooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`?o0000
2_ooool4o`000003ooooool0003o000000Kooooo1ol0000>ooooo`005_ooool5o`0000Kooooo1Ol0
0006ooooo`Go00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`;o00002oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool2o`0000cooooo1Ol0
0009ooooo`Go00002?ooool5o`0000cooooo000Fooooo`;o00002_ooool5o`0000Sooooo0ol00006
ooooo`?o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool2o`0000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003?ooool3o`0000Wooooo1Ol00007
ooooo`;o00003oooool002kooooo1Ol00007ooooo`;o00002?ooool3o`0000Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000000_ooooo0ol0000:oooo
o`Go00009Oooool003[ooooo0ol00009ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`;o00002oooool4o`0003?ooooo000mooooo`03o`00
0?oooooooooo00Gooooo0ol00008ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool02oooool3o`0000_ooooo0ol0000=ooooo`;o
0000<_ooool004Oooooo0_l00007ooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000_ooooo0ol0000=ooooo`03o`000?oooooooooo03oooooo
0019ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2o`0000Oooooo00?o
0000ooooool000000_l0000:ooooo`?o00003Oooool2o`0000gooooo00?o0000ooooooooool0?_oo
ool005?ooooo00?o0000ooooooooool01_ooool2o`0000Kooooo00?o0000ooooooooool00_l0000;
ooooo`;o00003_ooool00ol0003oooooooooo`1<ooooo`00GOooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooooooo`;o00002oooool2o`0005cooooo001Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05[ooooo000>ooooo`?o00002Oooool3o`0000Wooooo0_l0000;ooooo`;o00002_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`;o00002_ooool2o`0000_ooooo0_l0000:ooooo`?o00005_ooool0017ooooo
1?l000000ooooooo0000o`000005ooooo`?o00002?ooool3o`0000[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool2o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool3o`0000[ooooo0ol0000:ooooo`Co0000
00?oooooo`000?l000003oooool001Gooooo1Ol00006ooooo`Co00001oooool2o`0000Wooooo0_l0
0009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`08ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool2o`0000cooooo0_l0000;ooooo`Go00002Oooool5o`0000gooooo000F
ooooo`Go00001oooool4o`0000Oooooo0ol00008ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l0000;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo0ol0000;ooooo`?o00002Oooool5o`0000cooooo000Roooo
o`Go00001oooool4o`0000Oooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`07ooooo`;o00003?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000;oooo
o`Co00002?ooool5o`0001Wooooo000^ooooo`Go00001oooool2o`0000Sooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool0
00002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo0_l0000<ooooo`;o
00002oooool5o`0002Gooooo000iooooo`Co00002?ooool2o`0000Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo0ol0000dooooo`00??oo
ool2o`0000Kooooo1?l00008ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`?o00003?oo
ool00ol0003oooooooooo`0;ooooo`;o00002oooool3o`0000kooooo00?o0000ooooooooool0<Ooo
ool004Kooooo0_l00007ooooo`?o00002?ooool3o`0000Oooooo00?o0000ooooool000000_l0000:
ooooo`?o00002_ooool3o`0000gooooo0_l00011ooooo`00B?ooool00ol0003oooooooooo`06oooo
o`;o00002?ooool2o`0000Oooooo00?o0000ooooool000000_l0000:ooooo`?o00003?ooool2o`00
00kooooo00?o0000ooooooooool0?_ooool005;ooooo00?o0000ooooooooool01Oooool01OnHV9So
410@o`000?l0003oc<c<00Gooooo00?o0000ooooooooool00_l0000;ooooo`;o00003Oooool00ol0
003oooooooooo`1=ooooo`00F_ooool01Ol@413o^[Zjooooool0003o<S8b00Gooooo00?o0000oooo
ooooool00_l0000<ooooo`03o`000?oooooooooo05_ooooo001Nooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00001Zooooo`003_ooool3o`0000Wooooo0_l0000:ooooo`;o
00002oooool2o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo00?oZJVYoa0@4?ooool01?ooool2o`0000[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`;o
00002oooool2o`0000[ooooo0ol0000Fooooo`004Oooool4o`000003ooooool0003o000000Cooooo
0ol00009ooooo`;o00002oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool01ol0003ooooooooooooooooo410@o`000?nj^[X01Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`?o00002_ooool4o`00
0003ooooool0003o000000oooooo000Eooooo`Go00001Oooool5o`0000Kooooo0ol00009ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`06
o`000?oooooooooooooooonj^[[o8B4Q1Oooool2o`0000_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`?o00002oooool5
o`0000Wooooo1Ol0000=ooooo`005_ooool5o`0000Oooooo0ol00008ooooo`?o00001oooool2o`00
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`06o`000?l@413oV9RH
oooooonj^[[o00001Oooool2o`0000_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool3o`0000_ooooo0ol0
0009ooooo`Go00003?ooool0027ooooo1Ol00007ooooo`Co00002?ooool2o`0000Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`06o`000?nYZJWo410@o`000?l@413oZJVY
1Oooool2o`0000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo0_l0000;ooooo`Co00002Oooool5o`0001Wooooo000`ooooo`;o00001ooo
ool2o`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Oooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooo`00000;ooooo`?o00003Oooool2o`0002Kooooo000kooooo`03o`000?oooooo
oooo00Kooooo0_l00008ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooo`00000<ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`;o00003Oooool2
o`0003Cooooo000looooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00002Oooool3o`00
00Oooooo00Co0000ooooool0003o00002oooool2o`0000_ooooo0_l0000=ooooo`;o00003_ooool0
0ol0003oooooooooo`0aooooo`00A_ooool00ol0003oooooooooo`06ooooo`;o00002Oooool3o`00
00Oooooo00Co0000ooooool0003o00002_ooool3o`0000cooooo0_l0000=ooooo`03o`000?oooooo
oooo043ooooo0017ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`?o00001oooool01?l0
003oooooo`000?l0000;ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03oooooo001Aooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`03o`000?oooooooooo
00;o00002oooool2o`0000gooooo00?o0000ooooooooool0COooool005cooooo00?o0000oooooooo
ool01Oooool2o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Kooooo`00
I?ooool00ol0003oooooooooo`1/ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?ooool0
0ol0003oooooooooo`1/ooooo`00I?ooool00ol0003oooooooooo`1/ooooo`00I?ooool00ol0003o
ooooooooo`1/ooooo`00doooool00=?ooooo003Cooooo`00HOooool01?l@413o0000o`000?l0001^
ooooo`00H_ooool00ol0003oooooooooo`1^ooooo`00H_ooool00ol0003oooooooooo`1^ooooo`00
>Oooool3o`0000;ooooo0ol00008ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool5o`00
00?ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h3ooooo`09o`000?mgMgOo0000o`000?mEEEGo
k^k^ooooooo^k^koEEEE00;o000000?oA4A4okZj^_ooool01_ooool00ol@413o0000o`000002o`00
0004oa0@4?ooooooooooooooo`Go00000_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo
1Ol00003ooooo`07onk^k_mEEEGo0000o`000?nHV9So0000oa0@400fooooo`00>Oooool00oo^k^ko
0000onk^kP03ooooo`03o`000?oMgMgooooo00Oooooo00Ko0000ojVYZOoooooooooookZj^_l00004
ooooo`03o`000?oooooooooo00?ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`0=o`00
0?mEEEGok^k^oooooomgMgOoEEEEoooooomEEEGoMgMgooooooo^k^koMgMgoa0@4009ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@
40Cooooo00?o0000ooooooooool00oooool01_mEEEGoMgMgooooooo^k^koEEEEo`0003Oooooo000j
ooooo`03oeEEEOl0003o000000;o000000?oA4A4ooooooooool02?ooool01Onj^[[oQhN7ofIVI_mV
IVKo410@00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooooooool0003ok^k^0oooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o
oooo00Ko0000ooooooooooooooooonk^k_l0000gooooo`00>_ooool01_nYZJWoA4A4oooooooooooo
A4A4oiRHV0Wooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h4ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000onk^kP?ooooo00?o0000
ooooool000001Ol00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool6
o`0000Cooooo00?o0000ooooooooool00oooool01_l0003oooooooooooooooook^k^o`0003Oooooo
000kooooo`04o`000?o^k^kok^k^o`0000[ooooo00Ko0000okZj^_ooooook^k^ogMgMol00004oooo
o`03o`000?oooooooooo00?ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`0=o`000?mE
EEGok^k^oooooomgMgOoIVIVoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCo
oooo00?o0000ooooooooool00oooool01_mVIVKoMgMgooooooo^k^koEEEEo`0003Oooooo000koooo
o`04ofIVI_nHV9SoQhN7ofIVIP[ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00004ooooo`03o`00
0?oooooooooo00?ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`03oa0@4?l0003oMgMg
00;o000000GoIVIVonk^k_ooooook^k^oeEEE@02o`000003odA4A?o^k^kooooo00Kooooo00?o410@
o`000?l000000ol00003ooooo`03oa0@4?l0003o000000Cooooo00Kok^k^oeEEEOl0003o0000odA4
A?o^k^h4ooooo`03o`000?oooooooooo00?ooooo00Kok^k^oeEEEOl0003o410@olc<c?l0000goooo
o`00>oooool01?o<c<coA4A4ob4Q8OoMgMdDooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo000jooooo`04
oa0@4?l0003o0000oc8b<QGooooo00?o0000ooooooooool08_ooool00ol@413o^[Zjooooo`06oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0eoooo
o`00DOooool00ol@413o0000o`00000Tooooo`04okZj^_l@413o0000oa0@40Gooooo00?o410@oooo
ooooool02_ooool00ol@413o0000o`000009ooooo`;o0000=oooool00=?ooooo003Cooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 245.812}, {288.375, 110.375}} -> {-6.89318, \
1.23583, 0.0436039, 0.0436039}}]
}, Open  ]],

Cell["\<\
We name the slope field S so we can show it with some solution \
curves below.\
\>", "Text"],

Cell["S = %", "Input",
  CellLabel->"In[176]:=",
  FormatType->InputForm],

Cell["Solution curves can be found using Table as follows.", "Text"],

Cell[CellGroupData[{

Cell["\<\
DE = y'[t] == y[t]/(t^2+1)
solns = Table[ DSolve[ {DE, y[0]==k}, y, t], {k,-3,3}];\
\>", "Input",
  CellLabel->"In[170]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(y[t]\/\(1 + t\^2\)\)}]], "Output",
  CellLabel->"Out[170]="]
}, Open  ]],

Cell["\<\
Using the solutions we use Table again to make the plots, then use \
Show to display them along with the slope field created above.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ S, Table[ Plot[ y[t]/.solns[[k]], {t,-3,3}, 
                PlotStyle->Thickness[0.01], DisplayFunction->Identity ], 
                {k,7} ], PlotRange->{{-3,3},{-3,3}}, 
                DisplayFunction->$DisplayFunction, 
                PlotLabel->\"Slope field and solution curves\"]\
\>", "Input",\

  CellLabel->"In[173]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.5 0.166667 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.0125 -95 0 ]
[.5 1.0125 95 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-3)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-2)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-1)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(1)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(2)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(3)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-2)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-1)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(1)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(2)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(3)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.0125 -156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Slope) show
99.000 13.000 moveto
(field) show
135.000 13.000 moveto
(and) show
159.000 13.000 moveto
(solution) show
213.000 13.000 moveto
(curves) show
249.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
0 0 m
0 0 rlineto s
% Start of user PostScript
-3. -3. -2.5895 -3.12315 MAarrowhead1
% End of user PostScript
0 .07143 m
.06918 .05364 L
s
% Start of user PostScript
-3. -2.57143 -2.58493 -2.67816 MAarrowhead1
% End of user PostScript
0 .14286 m
.06984 .12789 L
s
% Start of user PostScript
-3. -2.14286 -2.58094 -2.23266 MAarrowhead1
% End of user PostScript
0 .21429 m
.0704 .20222 L
s
% Start of user PostScript
-3. -1.71429 -2.57759 -1.7867 MAarrowhead1
% End of user PostScript
0 .28571 m
.07085 .27661 L
s
% Start of user PostScript
-3. -1.28571 -2.57493 -1.34037 MAarrowhead1
% End of user PostScript
0 .35714 m
.07117 .35104 L
s
% Start of user PostScript
-3. -0.857143 -2.57299 -0.893743 MAarrowhead1
% End of user PostScript
0 .42857 m
.07136 .42551 L
s
% Start of user PostScript
-3. -0.428571 -2.57182 -0.446922 MAarrowhead1
% End of user PostScript
0 .5 m
.07143 .5 L
s
% Start of user PostScript
-3. 0 -2.57143 0 MAarrowhead1
% End of user PostScript
0 .57143 m
.07136 .57449 L
s
% Start of user PostScript
-3. 0.428571 -2.57182 0.446922 MAarrowhead1
% End of user PostScript
0 .64286 m
.07117 .64896 L
s
% Start of user PostScript
-3. 0.857143 -2.57299 0.893743 MAarrowhead1
% End of user PostScript
0 .71429 m
.07085 .72339 L
s
% Start of user PostScript
-3. 1.28571 -2.57493 1.34037 MAarrowhead1
% End of user PostScript
0 .78571 m
.0704 .79778 L
s
% Start of user PostScript
-3. 1.71429 -2.57759 1.7867 MAarrowhead1
% End of user PostScript
0 .85714 m
.06984 .87211 L
s
% Start of user PostScript
-3. 2.14286 -2.58094 2.23266 MAarrowhead1
% End of user PostScript
0 .92857 m
.06918 .94636 L
s
% Start of user PostScript
-3. 2.57143 -2.58493 2.67816 MAarrowhead1
% End of user PostScript
0 1 m
0 0 rlineto s
0 1 m
0 1 L
s
% Start of user PostScript
-3. 3. -2.5895 3.12315 MAarrowhead1
% End of user PostScript
.07143 0 m
0 0 rlineto s
% Start of user PostScript
-2.57143 -3. -2.1727 -3.15714 MAarrowhead1
% End of user PostScript
.07143 .07143 m
.1391 .04857 L
s
% Start of user PostScript
-2.57143 -2.57143 -2.1654 -2.70859 MAarrowhead1
% End of user PostScript
.07143 .14286 m
.14018 .1235 L
s
% Start of user PostScript
-2.57143 -2.14286 -2.15889 -2.25899 MAarrowhead1
% End of user PostScript
.07143 .21429 m
.14111 .19859 L
s
% Start of user PostScript
-2.57143 -1.71429 -2.15333 -1.80844 MAarrowhead1
% End of user PostScript
.07143 .28571 m
.14186 .27382 L
s
% Start of user PostScript
-2.57143 -1.28571 -2.14884 -1.35709 MAarrowhead1
% End of user PostScript
.07143 .35714 m
.14241 .34915 L
s
% Start of user PostScript
-2.57143 -0.857143 -2.14555 -0.905097 MAarrowhead1
% End of user PostScript
.07143 .42857 m
.14274 .42456 L
s
% Start of user PostScript
-2.57143 -0.428571 -2.14353 -0.452662 MAarrowhead1
% End of user PostScript
.07143 .5 m
.14286 .5 L
s
% Start of user PostScript
-2.57143 0 -2.14286 0 MAarrowhead1
% End of user PostScript
.07143 .57143 m
.14274 .57544 L
s
% Start of user PostScript
-2.57143 0.428571 -2.14353 0.452662 MAarrowhead1
% End of user PostScript
.07143 .64286 m
.14241 .65085 L
s
% Start of user PostScript
-2.57143 0.857143 -2.14555 0.905097 MAarrowhead1
% End of user PostScript
.07143 .71429 m
.14186 .72618 L
s
% Start of user PostScript
-2.57143 1.28571 -2.14884 1.35709 MAarrowhead1
% End of user PostScript
.07143 .78571 m
.14111 .80141 L
s
% Start of user PostScript
-2.57143 1.71429 -2.15333 1.80844 MAarrowhead1
% End of user PostScript
.07143 .85714 m
.14018 .8765 L
s
% Start of user PostScript
-2.57143 2.14286 -2.15889 2.25899 MAarrowhead1
% End of user PostScript
.07143 .92857 m
.1391 .95143 L
s
% Start of user PostScript
-2.57143 2.57143 -2.1654 2.70859 MAarrowhead1
% End of user PostScript
.07143 1 m
0 0 rlineto s
.07143 1 m
.07143 1 L
s
% Start of user PostScript
-2.57143 3. -2.1727 3.15714 MAarrowhead1
% End of user PostScript
.14286 0 m
0 0 rlineto s
% Start of user PostScript
-2.14286 -3. -1.7652 -3.20261 MAarrowhead1
% End of user PostScript
.14286 .07143 m
.20775 .04159 L
s
% Start of user PostScript
-2.14286 -2.57143 -1.75348 -2.75048 MAarrowhead1
% End of user PostScript
.14286 .14286 m
.20956 .1173 L
s
% Start of user PostScript
-2.14286 -2.14286 -1.74266 -2.29622 MAarrowhead1
% End of user PostScript
.14286 .21429 m
.21115 .19335 L
s
% Start of user PostScript
-2.14286 -1.71429 -1.73311 -1.8399 MAarrowhead1
% End of user PostScript
.14286 .28571 m
.21247 .26971 L
s
% Start of user PostScript
-2.14286 -1.28571 -1.72518 -1.38175 MAarrowhead1
% End of user PostScript
.14286 .35714 m
.21346 .34632 L
s
% Start of user PostScript
-2.14286 -0.857143 -1.71923 -0.922078 MAarrowhead1
% End of user PostScript
.14286 .42857 m
.21408 .42311 L
s
% Start of user PostScript
-2.14286 -0.428571 -1.71554 -0.461322 MAarrowhead1
% End of user PostScript
.14286 .5 m
.21429 .5 L
s
% Start of user PostScript
-2.14286 0 -1.71429 0 MAarrowhead1
% End of user PostScript
.14286 .57143 m
.21408 .57689 L
s
% Start of user PostScript
-2.14286 0.428571 -1.71554 0.461322 MAarrowhead1
% End of user PostScript
.14286 .64286 m
.21346 .65368 L
s
% Start of user PostScript
-2.14286 0.857143 -1.71923 0.922078 MAarrowhead1
% End of user PostScript
.14286 .71429 m
.21247 .73029 L
s
% Start of user PostScript
-2.14286 1.28571 -1.72518 1.38175 MAarrowhead1
% End of user PostScript
.14286 .78571 m
.21115 .80665 L
s
% Start of user PostScript
-2.14286 1.71429 -1.73311 1.8399 MAarrowhead1
% End of user PostScript
.14286 .85714 m
.20956 .8827 L
s
% Start of user PostScript
-2.14286 2.14286 -1.74266 2.29622 MAarrowhead1
% End of user PostScript
.14286 .92857 m
.20775 .95841 L
s
% Start of user PostScript
-2.14286 2.57143 -1.75348 2.75048 MAarrowhead1
% End of user PostScript
.14286 1 m
0 0 rlineto s
.14286 1 m
.14286 1 L
s
% Start of user PostScript
-2.14286 3. -1.7652 3.20261 MAarrowhead1
% End of user PostScript
.21429 0 m
0 0 rlineto s
% Start of user PostScript
-1.71429 -3. -1.37335 -3.25968 MAarrowhead1
% End of user PostScript
.21429 .07143 m
.2741 .03238 L
s
% Start of user PostScript
-1.71429 -2.57143 -1.35542 -2.80571 MAarrowhead1
% End of user PostScript
.21429 .14286 m
.27703 .10872 L
s
% Start of user PostScript
-1.71429 -2.14286 -1.33782 -2.34767 MAarrowhead1
% End of user PostScript
.21429 .21429 m
.27978 .18578 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.32132 -1.88532 MAarrowhead1
% End of user PostScript
.21429 .28571 m
.28219 .26355 L
s
% Start of user PostScript
-1.71429 -1.28571 -1.30687 -1.4187 MAarrowhead1
% End of user PostScript
.21429 .35714 m
.28408 .34195 L
s
% Start of user PostScript
-1.71429 -0.857143 -1.29552 -0.948274 MAarrowhead1
% End of user PostScript
.21429 .42857 m
.2853 .42085 L
s
% Start of user PostScript
-1.71429 -0.428571 -1.28823 -0.47493 MAarrowhead1
% End of user PostScript
.21429 .5 m
.28571 .5 L
s
% Start of user PostScript
-1.71429 0 -1.28571 0 MAarrowhead1
% End of user PostScript
.21429 .57143 m
.2853 .57915 L
s
% Start of user PostScript
-1.71429 0.428571 -1.28823 0.47493 MAarrowhead1
% End of user PostScript
.21429 .64286 m
.28408 .65805 L
s
% Start of user PostScript
-1.71429 0.857143 -1.29552 0.948274 MAarrowhead1
% End of user PostScript
.21429 .71429 m
.28219 .73645 L
s
% Start of user PostScript
-1.71429 1.28571 -1.30687 1.4187 MAarrowhead1
% End of user PostScript
.21429 .78571 m
.27978 .81422 L
s
% Start of user PostScript
-1.71429 1.71429 -1.32132 1.88532 MAarrowhead1
% End of user PostScript
.21429 .85714 m
.27703 .89128 L
s
% Start of user PostScript
-1.71429 2.14286 -1.33782 2.34767 MAarrowhead1
% End of user PostScript
.21429 .92857 m
.2741 .96762 L
s
% Start of user PostScript
-1.71429 2.57143 -1.35542 2.80571 MAarrowhead1
% End of user PostScript
.21429 1 m
0 0 rlineto s
.21429 1 m
.21429 1 L
s
% Start of user PostScript
-1.71429 3. -1.37335 3.25968 MAarrowhead1
% End of user PostScript
.28571 0 m
0 0 rlineto s
% Start of user PostScript
-1.28571 -3. -1.0018 -3.32104 MAarrowhead1
% End of user PostScript
.28571 .07143 m
.337 .02172 L
s
% Start of user PostScript
-1.28571 -2.57143 -0.977971 -2.8697 MAarrowhead1
% End of user PostScript
.28571 .14286 m
.34128 .09798 L
s
% Start of user PostScript
-1.28571 -2.14286 -0.952311 -2.41214 MAarrowhead1
% End of user PostScript
.28571 .21429 m
.34571 .17552 L
s
% Start of user PostScript
-1.28571 -1.71429 -0.92575 -1.94688 MAarrowhead1
% End of user PostScript
.28571 .28571 m
.34999 .25456 L
s
% Start of user PostScript
-1.28571 -1.28571 -0.900044 -1.47262 MAarrowhead1
% End of user PostScript
.28571 .35714 m
.35368 .33518 L
s
% Start of user PostScript
-1.28571 -0.857143 -0.877898 -0.988899 MAarrowhead1
% End of user PostScript
.28571 .42857 m
.35623 .41718 L
s
% Start of user PostScript
-1.28571 -0.428571 -0.862627 -0.496916 MAarrowhead1
% End of user PostScript
.28571 .5 m
.35714 .5 L
s
% Start of user PostScript
-1.28571 0 -0.857143 0 MAarrowhead1
% End of user PostScript
.28571 .57143 m
.35623 .58282 L
s
% Start of user PostScript
-1.28571 0.428571 -0.862627 0.496916 MAarrowhead1
% End of user PostScript
.28571 .64286 m
.35368 .66482 L
s
% Start of user PostScript
-1.28571 0.857143 -0.877898 0.988899 MAarrowhead1
% End of user PostScript
.28571 .71429 m
.34999 .74544 L
s
% Start of user PostScript
-1.28571 1.28571 -0.900044 1.47262 MAarrowhead1
% End of user PostScript
.28571 .78571 m
.34571 .82448 L
s
% Start of user PostScript
-1.28571 1.71429 -0.92575 1.94688 MAarrowhead1
% End of user PostScript
.28571 .85714 m
.34128 .90202 L
s
% Start of user PostScript
-1.28571 2.14286 -0.952311 2.41214 MAarrowhead1
% End of user PostScript
.28571 .92857 m
.337 .97828 L
s
% Start of user PostScript
-1.28571 2.57143 -0.977971 2.8697 MAarrowhead1
% End of user PostScript
.28571 1 m
0 0 rlineto s
.28571 1 m
.28571 1 L
s
% Start of user PostScript
-1.28571 3. -1.0018 3.32104 MAarrowhead1
% End of user PostScript
.35714 0 m
0 0 rlineto s
% Start of user PostScript
-0.857143 -3. -0.642612 -3.37101 MAarrowhead1
% End of user PostScript
.35714 .07143 m
.39709 .01221 L
s
% Start of user PostScript
-0.857143 -2.57143 -0.617466 -2.92671 MAarrowhead1
% End of user PostScript
.35714 .14286 m
.40209 .08734 L
s
% Start of user PostScript
-0.857143 -2.14286 -0.587486 -2.47596 MAarrowhead1
% End of user PostScript
.35714 .21429 m
.40795 .16408 L
s
% Start of user PostScript
-0.857143 -1.71429 -0.552309 -2.01553 MAarrowhead1
% End of user PostScript
.35714 .28571 m
.41453 .24318 L
s
% Start of user PostScript
-0.857143 -1.28571 -0.512833 -1.54091 MAarrowhead1
% End of user PostScript
.35714 .35714 m
.42118 .3255 L
s
% Start of user PostScript
-0.857143 -0.857143 -0.472917 -1.047 MAarrowhead1
% End of user PostScript
.35714 .42857 m
.42649 .41144 L
s
% Start of user PostScript
-0.857143 -0.428571 -0.441081 -0.531363 MAarrowhead1
% End of user PostScript
.35714 .5 m
.42857 .5 L
s
% Start of user PostScript
-0.857143 0 -0.428571 0 MAarrowhead1
% End of user PostScript
.35714 .57143 m
.42649 .58856 L
s
% Start of user PostScript
-0.857143 0.428571 -0.441081 0.531363 MAarrowhead1
% End of user PostScript
.35714 .64286 m
.42118 .6745 L
s
% Start of user PostScript
-0.857143 0.857143 -0.472917 1.047 MAarrowhead1
% End of user PostScript
.35714 .71429 m
.41453 .75682 L
s
% Start of user PostScript
-0.857143 1.28571 -0.512833 1.54091 MAarrowhead1
% End of user PostScript
.35714 .78571 m
.40795 .83592 L
s
% Start of user PostScript
-0.857143 1.71429 -0.552309 2.01553 MAarrowhead1
% End of user PostScript
.35714 .85714 m
.40209 .91266 L
s
% Start of user PostScript
-0.857143 2.14286 -0.587486 2.47596 MAarrowhead1
% End of user PostScript
.35714 .92857 m
.39709 .98779 L
s
% Start of user PostScript
-0.857143 2.57143 -0.617466 2.92671 MAarrowhead1
% End of user PostScript
.35714 1 m
0 0 rlineto s
.35714 1 m
.35714 1 L
s
% Start of user PostScript
-0.857143 3. -0.642612 3.37101 MAarrowhead1
% End of user PostScript
.42857 0 m
0 0 rlineto s
% Start of user PostScript
-0.428571 -3. -0.271276 -3.39866 MAarrowhead1
% End of user PostScript
.42857 .07143 m
.45844 .00654 L
s
% Start of user PostScript
-0.428571 -2.57143 -0.249367 -2.96073 MAarrowhead1
% End of user PostScript
.42857 .14286 m
.46311 .08033 L
s
% Start of user PostScript
-0.428571 -2.14286 -0.221349 -2.518 MAarrowhead1
% End of user PostScript
.42857 .21429 m
.46916 .15551 L
s
% Start of user PostScript
-0.428571 -1.71429 -0.185061 -2.06696 MAarrowhead1
% End of user PostScript
.42857 .28571 m
.47695 .23316 L
s
% Start of user PostScript
-0.428571 -1.28571 -0.138296 -1.60101 MAarrowhead1
% End of user PostScript
.42857 .35714 m
.48642 .31525 L
s
% Start of user PostScript
-0.428571 -0.857143 -0.0814534 -1.1085 MAarrowhead1
% End of user PostScript
.42857 .42857 m
.49573 .40425 L
s
% Start of user PostScript
-0.428571 -0.428571 -0.0256004 -0.574475 MAarrowhead1
% End of user PostScript
.42857 .5 m
.5 .5 L
s
% Start of user PostScript
-0.428571 0 0 0 MAarrowhead1
% End of user PostScript
.42857 .57143 m
.49573 .59575 L
s
% Start of user PostScript
-0.428571 0.428571 -0.0256004 0.574475 MAarrowhead1
% End of user PostScript
.42857 .64286 m
.48642 .68475 L
s
% Start of user PostScript
-0.428571 0.857143 -0.0814534 1.1085 MAarrowhead1
% End of user PostScript
.42857 .71429 m
.47695 .76684 L
s
% Start of user PostScript
-0.428571 1.28571 -0.138296 1.60101 MAarrowhead1
% End of user PostScript
.42857 .78571 m
.46916 .84449 L
s
% Start of user PostScript
-0.428571 1.71429 -0.185061 2.06696 MAarrowhead1
% End of user PostScript
.42857 .85714 m
.46311 .91967 L
s
% Start of user PostScript
-0.428571 2.14286 -0.221349 2.518 MAarrowhead1
% End of user PostScript
.42857 .92857 m
.45844 .99346 L
s
% Start of user PostScript
-0.428571 2.57143 -0.249367 2.96073 MAarrowhead1
% End of user PostScript
.42857 1 m
0 0 rlineto s
.42857 1 m
.42857 1 L
s
% Start of user PostScript
-0.428571 3. -0.271276 3.39866 MAarrowhead1
% End of user PostScript
.5 0 m
0 0 rlineto s
% Start of user PostScript
0 -3. 0.135526 -3.40658 MAarrowhead1
% End of user PostScript
.5 .07143 m
.52589 .00486 L
s
% Start of user PostScript
0 -2.57143 0.155334 -2.97086 MAarrowhead1
% End of user PostScript
.5 .14286 m
.53021 .07813 L
s
% Start of user PostScript
0 -2.14286 0.181237 -2.53122 MAarrowhead1
% End of user PostScript
.5 .21429 m
.53599 .15259 L
s
% Start of user PostScript
0 -1.71429 0.215945 -2.08448 MAarrowhead1
% End of user PostScript
.5 .28571 m
.54385 .22933 L
s
% Start of user PostScript
0 -1.28571 0.263117 -1.62401 MAarrowhead1
% End of user PostScript
.5 .35714 m
.55423 .31066 L
s
% Start of user PostScript
0 -0.857143 0.325396 -1.13605 MAarrowhead1
% End of user PostScript
.5 .42857 m
.56565 .40043 L
s
% Start of user PostScript
0 -0.428571 0.393919 -0.597394 MAarrowhead1
% End of user PostScript
.5 .5 m
.57143 .5 L
s
% Start of user PostScript
0 0 0.428571 0 MAarrowhead1
% End of user PostScript
.5 .57143 m
.56565 .59957 L
s
% Start of user PostScript
0 0.428571 0.393919 0.597394 MAarrowhead1
% End of user PostScript
.5 .64286 m
.55423 .68934 L
s
% Start of user PostScript
0 0.857143 0.325396 1.13605 MAarrowhead1
% End of user PostScript
.5 .71429 m
.54385 .77067 L
s
% Start of user PostScript
0 1.28571 0.263117 1.62401 MAarrowhead1
% End of user PostScript
.5 .78571 m
.53599 .84741 L
s
% Start of user PostScript
0 1.71429 0.215945 2.08448 MAarrowhead1
% End of user PostScript
.5 .85714 m
.53021 .92187 L
s
% Start of user PostScript
0 2.14286 0.181237 2.53122 MAarrowhead1
% End of user PostScript
.5 .92857 m
.52589 .99514 L
s
% Start of user PostScript
0 2.57143 0.155334 2.97086 MAarrowhead1
% End of user PostScript
.5 1 m
0 0 rlineto s
.5 1 m
.5 1 L
s
% Start of user PostScript
0 3. 0.135526 3.40658 MAarrowhead1
% End of user PostScript
.57143 0 m
0 0 rlineto s
% Start of user PostScript
0.428571 -3. 0.585867 -3.39866 MAarrowhead1
% End of user PostScript
.57143 .07143 m
.6013 .00654 L
s
% Start of user PostScript
0.428571 -2.57143 0.607776 -2.96073 MAarrowhead1
% End of user PostScript
.57143 .14286 m
.60597 .08033 L
s
% Start of user PostScript
0.428571 -2.14286 0.635793 -2.518 MAarrowhead1
% End of user PostScript
.57143 .21429 m
.61201 .15551 L
s
% Start of user PostScript
0.428571 -1.71429 0.672082 -2.06696 MAarrowhead1
% End of user PostScript
.57143 .28571 m
.61981 .23316 L
s
% Start of user PostScript
0.428571 -1.28571 0.718847 -1.60101 MAarrowhead1
% End of user PostScript
.57143 .35714 m
.62928 .31525 L
s
% Start of user PostScript
0.428571 -0.857143 0.775689 -1.1085 MAarrowhead1
% End of user PostScript
.57143 .42857 m
.63859 .40425 L
s
% Start of user PostScript
0.428571 -0.428571 0.831543 -0.574475 MAarrowhead1
% End of user PostScript
.57143 .5 m
.64286 .5 L
s
% Start of user PostScript
0.428571 0 0.857143 0 MAarrowhead1
% End of user PostScript
.57143 .57143 m
.63859 .59575 L
s
% Start of user PostScript
0.428571 0.428571 0.831543 0.574475 MAarrowhead1
% End of user PostScript
.57143 .64286 m
.62928 .68475 L
s
% Start of user PostScript
0.428571 0.857143 0.775689 1.1085 MAarrowhead1
% End of user PostScript
.57143 .71429 m
.61981 .76684 L
s
% Start of user PostScript
0.428571 1.28571 0.718847 1.60101 MAarrowhead1
% End of user PostScript
.57143 .78571 m
.61201 .84449 L
s
% Start of user PostScript
0.428571 1.71429 0.672082 2.06696 MAarrowhead1
% End of user PostScript
.57143 .85714 m
.60597 .91967 L
s
% Start of user PostScript
0.428571 2.14286 0.635793 2.518 MAarrowhead1
% End of user PostScript
.57143 .92857 m
.6013 .99346 L
s
% Start of user PostScript
0.428571 2.57143 0.607776 2.96073 MAarrowhead1
% End of user PostScript
.57143 1 m
0 0 rlineto s
.57143 1 m
.57143 1 L
s
% Start of user PostScript
0.428571 3. 0.585867 3.39866 MAarrowhead1
% End of user PostScript
.64286 0 m
0 0 rlineto s
% Start of user PostScript
0.857143 -3. 1.07167 -3.37101 MAarrowhead1
% End of user PostScript
.64286 .07143 m
.6828 .01221 L
s
% Start of user PostScript
0.857143 -2.57143 1.09682 -2.92671 MAarrowhead1
% End of user PostScript
.64286 .14286 m
.6878 .08734 L
s
% Start of user PostScript
0.857143 -2.14286 1.1268 -2.47596 MAarrowhead1
% End of user PostScript
.64286 .21429 m
.69366 .16408 L
s
% Start of user PostScript
0.857143 -1.71429 1.16198 -2.01553 MAarrowhead1
% End of user PostScript
.64286 .28571 m
.70024 .24318 L
s
% Start of user PostScript
0.857143 -1.28571 1.20145 -1.54091 MAarrowhead1
% End of user PostScript
.64286 .35714 m
.70689 .3255 L
s
% Start of user PostScript
0.857143 -0.857143 1.24137 -1.047 MAarrowhead1
% End of user PostScript
.64286 .42857 m
.7122 .41144 L
s
% Start of user PostScript
0.857143 -0.428571 1.2732 -0.531363 MAarrowhead1
% End of user PostScript
.64286 .5 m
.71429 .5 L
s
% Start of user PostScript
0.857143 0 1.28571 0 MAarrowhead1
% End of user PostScript
.64286 .57143 m
.7122 .58856 L
s
% Start of user PostScript
0.857143 0.428571 1.2732 0.531363 MAarrowhead1
% End of user PostScript
.64286 .64286 m
.70689 .6745 L
s
% Start of user PostScript
0.857143 0.857143 1.24137 1.047 MAarrowhead1
% End of user PostScript
.64286 .71429 m
.70024 .75682 L
s
% Start of user PostScript
0.857143 1.28571 1.20145 1.54091 MAarrowhead1
% End of user PostScript
.64286 .78571 m
.69366 .83592 L
s
% Start of user PostScript
0.857143 1.71429 1.16198 2.01553 MAarrowhead1
% End of user PostScript
.64286 .85714 m
.6878 .91266 L
s
% Start of user PostScript
0.857143 2.14286 1.1268 2.47596 MAarrowhead1
% End of user PostScript
.64286 .92857 m
.6828 .98779 L
s
% Start of user PostScript
0.857143 2.57143 1.09682 2.92671 MAarrowhead1
% End of user PostScript
.64286 1 m
0 0 rlineto s
.64286 1 m
.64286 1 L
s
% Start of user PostScript
0.857143 3. 1.07167 3.37101 MAarrowhead1
% End of user PostScript
.71429 0 m
0 0 rlineto s
% Start of user PostScript
1.28571 -3. 1.56963 -3.32104 MAarrowhead1
% End of user PostScript
.71429 .07143 m
.76558 .02172 L
s
% Start of user PostScript
1.28571 -2.57143 1.59346 -2.8697 MAarrowhead1
% End of user PostScript
.71429 .14286 m
.76985 .09798 L
s
% Start of user PostScript
1.28571 -2.14286 1.61912 -2.41214 MAarrowhead1
% End of user PostScript
.71429 .21429 m
.77428 .17552 L
s
% Start of user PostScript
1.28571 -1.71429 1.64568 -1.94688 MAarrowhead1
% End of user PostScript
.71429 .28571 m
.77856 .25456 L
s
% Start of user PostScript
1.28571 -1.28571 1.67138 -1.47262 MAarrowhead1
% End of user PostScript
.71429 .35714 m
.78226 .33518 L
s
% Start of user PostScript
1.28571 -0.857143 1.69353 -0.988899 MAarrowhead1
% End of user PostScript
.71429 .42857 m
.7848 .41718 L
s
% Start of user PostScript
1.28571 -0.428571 1.7088 -0.496916 MAarrowhead1
% End of user PostScript
.71429 .5 m
.78571 .5 L
s
% Start of user PostScript
1.28571 0 1.71429 0 MAarrowhead1
% End of user PostScript
.71429 .57143 m
.7848 .58282 L
s
% Start of user PostScript
1.28571 0.428571 1.7088 0.496916 MAarrowhead1
% End of user PostScript
.71429 .64286 m
.78226 .66482 L
s
% Start of user PostScript
1.28571 0.857143 1.69353 0.988899 MAarrowhead1
% End of user PostScript
.71429 .71429 m
.77856 .74544 L
s
% Start of user PostScript
1.28571 1.28571 1.67138 1.47262 MAarrowhead1
% End of user PostScript
.71429 .78571 m
.77428 .82448 L
s
% Start of user PostScript
1.28571 1.71429 1.64568 1.94688 MAarrowhead1
% End of user PostScript
.71429 .85714 m
.76985 .90202 L
s
% Start of user PostScript
1.28571 2.14286 1.61912 2.41214 MAarrowhead1
% End of user PostScript
.71429 .92857 m
.76558 .97828 L
s
% Start of user PostScript
1.28571 2.57143 1.59346 2.8697 MAarrowhead1
% End of user PostScript
.71429 1 m
0 0 rlineto s
.71429 1 m
.71429 1 L
s
% Start of user PostScript
1.28571 3. 1.56963 3.32104 MAarrowhead1
% End of user PostScript
.78571 0 m
0 0 rlineto s
% Start of user PostScript
1.71429 -3. 2.05523 -3.25968 MAarrowhead1
% End of user PostScript
.78571 .07143 m
.84553 .03238 L
s
% Start of user PostScript
1.71429 -2.57143 2.07315 -2.80571 MAarrowhead1
% End of user PostScript
.78571 .14286 m
.84846 .10872 L
s
% Start of user PostScript
1.71429 -2.14286 2.09075 -2.34767 MAarrowhead1
% End of user PostScript
.78571 .21429 m
.85121 .18578 L
s
% Start of user PostScript
1.71429 -1.71429 2.10725 -1.88532 MAarrowhead1
% End of user PostScript
.78571 .28571 m
.85362 .26355 L
s
% Start of user PostScript
1.71429 -1.28571 2.1217 -1.4187 MAarrowhead1
% End of user PostScript
.78571 .35714 m
.85551 .34195 L
s
% Start of user PostScript
1.71429 -0.857143 2.13306 -0.948274 MAarrowhead1
% End of user PostScript
.78571 .42857 m
.85672 .42085 L
s
% Start of user PostScript
1.71429 -0.428571 2.14034 -0.47493 MAarrowhead1
% End of user PostScript
.78571 .5 m
.85714 .5 L
s
% Start of user PostScript
1.71429 0 2.14286 0 MAarrowhead1
% End of user PostScript
.78571 .57143 m
.85672 .57915 L
s
% Start of user PostScript
1.71429 0.428571 2.14034 0.47493 MAarrowhead1
% End of user PostScript
.78571 .64286 m
.85551 .65805 L
s
% Start of user PostScript
1.71429 0.857143 2.13306 0.948274 MAarrowhead1
% End of user PostScript
.78571 .71429 m
.85362 .73645 L
s
% Start of user PostScript
1.71429 1.28571 2.1217 1.4187 MAarrowhead1
% End of user PostScript
.78571 .78571 m
.85121 .81422 L
s
% Start of user PostScript
1.71429 1.71429 2.10725 1.88532 MAarrowhead1
% End of user PostScript
.78571 .85714 m
.84846 .89128 L
s
% Start of user PostScript
1.71429 2.14286 2.09075 2.34767 MAarrowhead1
% End of user PostScript
.78571 .92857 m
.84553 .96762 L
s
% Start of user PostScript
1.71429 2.57143 2.07315 2.80571 MAarrowhead1
% End of user PostScript
.78571 1 m
0 0 rlineto s
.78571 1 m
.78571 1 L
s
% Start of user PostScript
1.71429 3. 2.05523 3.25968 MAarrowhead1
% End of user PostScript
.85714 0 m
0 0 rlineto s
% Start of user PostScript
2.14286 -3. 2.52051 -3.20261 MAarrowhead1
% End of user PostScript
.85714 .07143 m
.92204 .04159 L
s
% Start of user PostScript
2.14286 -2.57143 2.53223 -2.75048 MAarrowhead1
% End of user PostScript
.85714 .14286 m
.92384 .1173 L
s
% Start of user PostScript
2.14286 -2.14286 2.54305 -2.29622 MAarrowhead1
% End of user PostScript
.85714 .21429 m
.92543 .19335 L
s
% Start of user PostScript
2.14286 -1.71429 2.55261 -1.8399 MAarrowhead1
% End of user PostScript
.85714 .28571 m
.92676 .26971 L
s
% Start of user PostScript
2.14286 -1.28571 2.56053 -1.38175 MAarrowhead1
% End of user PostScript
.85714 .35714 m
.92775 .34632 L
s
% Start of user PostScript
2.14286 -0.857143 2.56648 -0.922078 MAarrowhead1
% End of user PostScript
.85714 .42857 m
.92836 .42311 L
s
% Start of user PostScript
2.14286 -0.428571 2.57018 -0.461322 MAarrowhead1
% End of user PostScript
.85714 .5 m
.92857 .5 L
s
% Start of user PostScript
2.14286 0 2.57143 0 MAarrowhead1
% End of user PostScript
.85714 .57143 m
.92836 .57689 L
s
% Start of user PostScript
2.14286 0.428571 2.57018 0.461322 MAarrowhead1
% End of user PostScript
.85714 .64286 m
.92775 .65368 L
s
% Start of user PostScript
2.14286 0.857143 2.56648 0.922078 MAarrowhead1
% End of user PostScript
.85714 .71429 m
.92676 .73029 L
s
% Start of user PostScript
2.14286 1.28571 2.56053 1.38175 MAarrowhead1
% End of user PostScript
.85714 .78571 m
.92543 .80665 L
s
% Start of user PostScript
2.14286 1.71429 2.55261 1.8399 MAarrowhead1
% End of user PostScript
.85714 .85714 m
.92384 .8827 L
s
% Start of user PostScript
2.14286 2.14286 2.54305 2.29622 MAarrowhead1
% End of user PostScript
.85714 .92857 m
.92204 .95841 L
s
% Start of user PostScript
2.14286 2.57143 2.53223 2.75048 MAarrowhead1
% End of user PostScript
.85714 1 m
0 0 rlineto s
.85714 1 m
.85714 1 L
s
% Start of user PostScript
2.14286 3. 2.52051 3.20261 MAarrowhead1
% End of user PostScript
.92857 0 m
0 0 rlineto s
% Start of user PostScript
2.57143 -3. 2.97015 -3.15714 MAarrowhead1
% End of user PostScript
.92857 .07143 m
.99624 .04857 L
s
% Start of user PostScript
2.57143 -2.57143 2.97746 -2.70859 MAarrowhead1
% End of user PostScript
.92857 .14286 m
.99733 .1235 L
s
% Start of user PostScript
2.57143 -2.14286 2.98397 -2.25899 MAarrowhead1
% End of user PostScript
.92857 .21429 m
.99825 .19859 L
s
% Start of user PostScript
2.57143 -1.71429 2.98953 -1.80844 MAarrowhead1
% End of user PostScript
.92857 .28571 m
.999 .27382 L
s
% Start of user PostScript
2.57143 -1.28571 2.99401 -1.35709 MAarrowhead1
% End of user PostScript
.92857 .35714 m
.99955 .34915 L
s
% Start of user PostScript
2.57143 -0.857143 2.99731 -0.905097 MAarrowhead1
% End of user PostScript
.92857 .42857 m
.99989 .42456 L
s
% Start of user PostScript
2.57143 -0.428571 2.99932 -0.452662 MAarrowhead1
% End of user PostScript
.92857 .5 m
1 .5 L
s
% Start of user PostScript
2.57143 0 3. 0 MAarrowhead1
% End of user PostScript
.92857 .57143 m
.99989 .57544 L
s
% Start of user PostScript
2.57143 0.428571 2.99932 0.452662 MAarrowhead1
% End of user PostScript
.92857 .64286 m
.99955 .65085 L
s
% Start of user PostScript
2.57143 0.857143 2.99731 0.905097 MAarrowhead1
% End of user PostScript
.92857 .71429 m
.999 .72618 L
s
% Start of user PostScript
2.57143 1.28571 2.99401 1.35709 MAarrowhead1
% End of user PostScript
.92857 .78571 m
.99825 .80141 L
s
% Start of user PostScript
2.57143 1.71429 2.98953 1.80844 MAarrowhead1
% End of user PostScript
.92857 .85714 m
.99733 .8765 L
s
% Start of user PostScript
2.57143 2.14286 2.98397 2.25899 MAarrowhead1
% End of user PostScript
.92857 .92857 m
.99624 .95143 L
s
% Start of user PostScript
2.57143 2.57143 2.97746 2.70859 MAarrowhead1
% End of user PostScript
.92857 1 m
0 0 rlineto s
.92857 1 m
.92857 1 L
s
% Start of user PostScript
2.57143 3. 2.97015 3.15714 MAarrowhead1
% End of user PostScript
1 0 m
0 0 rlineto s
% Start of user PostScript
3. -3. 3.4105 -3.12315 MAarrowhead1
% End of user PostScript
1 .07143 m
0 0 rlineto s
1 .07143 m
1 .07143 L
s
% Start of user PostScript
3. -2.57143 3.41507 -2.67816 MAarrowhead1
% End of user PostScript
1 .14286 m
0 0 rlineto s
1 .14286 m
1 .14286 L
s
% Start of user PostScript
3. -2.14286 3.41906 -2.23266 MAarrowhead1
% End of user PostScript
1 .21429 m
0 0 rlineto s
1 .21429 m
1 .21429 L
s
% Start of user PostScript
3. -1.71429 3.42241 -1.7867 MAarrowhead1
% End of user PostScript
1 .28571 m
0 0 rlineto s
1 .28571 m
1 .28571 L
s
% Start of user PostScript
3. -1.28571 3.42507 -1.34037 MAarrowhead1
% End of user PostScript
1 .35714 m
0 0 rlineto s
1 .35714 m
1 .35714 L
s
% Start of user PostScript
3. -0.857143 3.42701 -0.893743 MAarrowhead1
% End of user PostScript
1 .42857 m
0 0 rlineto s
1 .42857 m
1 .42857 L
s
% Start of user PostScript
3. -0.428571 3.42818 -0.446922 MAarrowhead1
% End of user PostScript
1 .5 m
0 0 rlineto s
1 .5 m
1 .5 L
s
% Start of user PostScript
3. 0 3.42857 0 MAarrowhead1
% End of user PostScript
1 .57143 m
0 0 rlineto s
1 .57143 m
1 .57143 L
s
% Start of user PostScript
3. 0.428571 3.42818 0.446922 MAarrowhead1
% End of user PostScript
1 .64286 m
0 0 rlineto s
1 .64286 m
1 .64286 L
s
% Start of user PostScript
3. 0.857143 3.42701 0.893743 MAarrowhead1
% End of user PostScript
1 .71429 m
0 0 rlineto s
1 .71429 m
1 .71429 L
s
% Start of user PostScript
3. 1.28571 3.42507 1.34037 MAarrowhead1
% End of user PostScript
1 .78571 m
0 0 rlineto s
1 .78571 m
1 .78571 L
s
% Start of user PostScript
3. 1.71429 3.42241 1.7867 MAarrowhead1
% End of user PostScript
1 .85714 m
0 0 rlineto s
1 .85714 m
1 .85714 L
s
% Start of user PostScript
3. 2.14286 3.41906 2.23266 MAarrowhead1
% End of user PostScript
1 .92857 m
0 0 rlineto s
1 .92857 m
1 .92857 L
s
% Start of user PostScript
3. 2.57143 3.41507 2.67816 MAarrowhead1
% End of user PostScript
1 1 m
0 0 rlineto s
1 1 m
1 1 L
s
% Start of user PostScript
3. 3. 3.4105 3.12315 MAarrowhead1
% End of user PostScript
.01 w
0 .35661 m
.04057 .3528 L
.08481 .34775 L
.12636 .34188 L
.16632 .33482 L
.20885 .32519 L
.2498 .31294 L
.27066 .30515 L
.29331 .29512 L
.33524 .27072 L
.35607 .25475 L
.37815 .23405 L
.41788 .18367 L
.43826 .14934 L
.46018 .10453 L
s
.46018 .10453 m
.49951 0 L
s
0 .40441 m
.04057 .40186 L
.08481 .3985 L
.12636 .39458 L
.16632 .38988 L
.20885 .38346 L
.2498 .37529 L
.27066 .3701 L
.29331 .36341 L
.33524 .34714 L
.35607 .3365 L
.37815 .3227 L
.41788 .28911 L
.43826 .26623 L
.46018 .23635 L
.50346 .15967 L
.54516 .0657 L
s
.54516 .0657 m
.57136 0 L
s
0 .4522 m
.04057 .45093 L
.08481 .44925 L
.12636 .44729 L
.16632 .44494 L
.20885 .44173 L
.2498 .43765 L
.27066 .43505 L
.29331 .43171 L
.33524 .42357 L
.35607 .41825 L
.37815 .41135 L
.41788 .39456 L
.43826 .38311 L
.46018 .36818 L
.50346 .32983 L
.54516 .28285 L
.58526 .23257 L
.62794 .17924 L
.66902 .13188 L
.71269 .08755 L
.75476 .05081 L
.79523 .02044 L
s
.79523 .02044 m
.82701 0 L
s
0 .5 m
.00123 .5 L
.00236 .5 L
.00365 .5 L
.00488 .5 L
.00601 .5 L
.00706 .5 L
.00821 .5 L
.00942 .5 L
.01065 .5 L
.01196 .5 L
.0132 .5 L
.01434 .5 L
.01566 .5 L
.01641 .5 L
.01711 .5 L
.01839 .5 L
.01975 .5 L
.02043 .5 L
.02115 .5 L
.02245 .5 L
.02317 .5 L
.02384 .5 L
.02458 .5 L
.02537 .5 L
.02605 .5 L
.02679 .5 L
.02814 .5 L
.02945 .5 L
.03067 .5 L
.03184 .5 L
.03295 .5 L
.03416 .5 L
.03547 .5 L
.03676 .5 L
.03813 .5 L
.03929 .5 L
.04057 .5 L
.04131 .5 L
.042 .5 L
.04275 .5 L
.04355 .5 L
.0449 .5 L
.04566 .5 L
.04637 .5 L
.0477 .5 L
.04892 .5 L
.04959 .5 L
.05032 .5 L
.05165 .5 L
Mistroke
.05245 .5 L
.05321 .5 L
.05389 .5 L
.05462 .5 L
.05543 .5 L
.05627 .5 L
.057 .5 L
.05779 .5 L
.05854 .5 L
.05921 .5 L
.06 .5 L
.06074 .5 L
.06205 .5 L
.0628 .5 L
.06349 .5 L
.06471 .5 L
.06603 .5 L
.06727 .5 L
.06841 .5 L
.06967 .5 L
.07105 .5 L
.07175 .5 L
.07249 .5 L
.07383 .5 L
.07457 .5 L
.07525 .5 L
.076 .5 L
.07679 .5 L
.07812 .5 L
.07888 .5 L
.07959 .5 L
.0809 .5 L
.08211 .5 L
.08349 .5 L
.08481 .5 L
.086 .5 L
.08729 .5 L
.0885 .5 L
.08962 .5 L
.09085 .5 L
.0922 .5 L
.09289 .5 L
.09361 .5 L
.09493 .5 L
.09565 .5 L
.09632 .5 L
.09705 .5 L
.09783 .5 L
.09913 .5 L
.09987 .5 L
Mistroke
.10056 .5 L
.10185 .5 L
.10303 .5 L
.10439 .5 L
.10569 .5 L
.10691 .5 L
.10801 .5 L
.10928 .5 L
.11048 .5 L
.1116 .5 L
.11262 .5 L
.11375 .5 L
.11493 .5 L
.11613 .5 L
.11742 .5 L
.11864 .5 L
.11974 .5 L
.12104 .5 L
.12178 .5 L
.12245 .5 L
.1237 .5 L
.12502 .5 L
.12622 .5 L
.12753 .5 L
.12889 .5 L
.13016 .5 L
.13135 .5 L
.13244 .5 L
.13369 .5 L
.13487 .5 L
.13616 .5 L
.13752 .5 L
.13868 .5 L
.13996 .5 L
.14134 .5 L
.14211 .5 L
.14281 .5 L
.14418 .5 L
.14548 .5 L
.14669 .5 L
.14779 .5 L
.14906 .5 L
.15025 .5 L
.15136 .5 L
.15237 .5 L
.15349 .5 L
.15467 .5 L
.15586 .5 L
.15714 .5 L
.15835 .5 L
Mistroke
.15945 .5 L
.16074 .5 L
.16146 .5 L
.16214 .5 L
.16337 .5 L
.16468 .5 L
.16594 .5 L
.16732 .5 L
.16863 .5 L
.16984 .5 L
.17103 .5 L
.17212 .5 L
.17337 .5 L
.17456 .5 L
.17585 .5 L
.17721 .5 L
.17838 .5 L
.17966 .5 L
.18104 .5 L
.18181 .5 L
.18251 .5 L
.18388 .5 L
.18518 .5 L
.18628 .5 L
.1875 .5 L
.18877 .5 L
.18996 .5 L
.19107 .5 L
.19209 .5 L
.19321 .5 L
.19438 .5 L
.19558 .5 L
.19686 .5 L
.19807 .5 L
.19916 .5 L
.20045 .5 L
.20118 .5 L
.20185 .5 L
.20309 .5 L
.20439 .5 L
.20566 .5 L
.20705 .5 L
.20835 .5 L
.20957 .5 L
.21077 .5 L
.21186 .5 L
.21311 .5 L
.2143 .5 L
.21559 .5 L
.21696 .5 L
Mistroke
.21813 .5 L
.21941 .5 L
.22079 .5 L
.22157 .5 L
.22227 .5 L
.22364 .5 L
.22494 .5 L
.22604 .5 L
.22726 .5 L
.22853 .5 L
.22973 .5 L
.23084 .5 L
.23186 .5 L
.23297 .5 L
.23415 .5 L
.23535 .5 L
.23663 .5 L
.23784 .5 L
.23893 .5 L
.24023 .5 L
.24095 .5 L
.24163 .5 L
.24286 .5 L
.24416 .5 L
.24544 .5 L
.24683 .5 L
.24814 .5 L
.24935 .5 L
.25044 .5 L
.25165 .5 L
.25291 .5 L
.25409 .5 L
.25539 .5 L
.25676 .5 L
.25793 .5 L
.25922 .5 L
.2606 .5 L
.26137 .5 L
.26208 .5 L
.26345 .5 L
.26475 .5 L
.26586 .5 L
.26708 .5 L
.26835 .5 L
.26954 .5 L
.27066 .5 L
.27168 .5 L
.27286 .5 L
.27397 .5 L
.27518 .5 L
Mistroke
.27646 .5 L
.27767 .5 L
.27876 .5 L
.28005 .5 L
.28078 .5 L
.28145 .5 L
.28268 .5 L
.28399 .5 L
.28527 .5 L
.28599 .5 L
.28666 .5 L
.28789 .5 L
.28919 .5 L
.29036 .5 L
.29145 .5 L
.29265 .5 L
.29394 .5 L
.29524 .5 L
.29597 .5 L
.29665 .5 L
.29803 .5 L
.29881 .5 L
.29951 .5 L
.30077 .5 L
.30213 .5 L
.30342 .5 L
.30461 .5 L
.30572 .5 L
.30691 .5 L
.30804 .5 L
.30907 .5 L
.31027 .5 L
.31158 .5 L
.31282 .5 L
.31396 .5 L
.31526 .5 L
.31648 .5 L
.31758 .5 L
.31876 .5 L
.32005 .5 L
.32142 .5 L
.32259 .5 L
.32386 .5 L
.32524 .5 L
.32651 .5 L
.32718 .5 L
.32791 .5 L
.32867 .5 L
.32939 .5 L
.3307 .5 L
Mistroke
.3319 .5 L
.33329 .5 L
.33461 .5 L
.33578 .5 L
.33704 .5 L
.33822 .5 L
.33929 .5 L
.34055 .5 L
.34192 .5 L
.34321 .5 L
.3444 .5 L
.34567 .5 L
.34703 .5 L
.34831 .5 L
.34949 .5 L
.35086 .5 L
.35164 .5 L
.35236 .5 L
.35368 .5 L
.35434 .5 L
.35508 .5 L
.35579 .5 L
.35654 .5 L
.35788 .5 L
.35863 .5 L
.35932 .5 L
.36009 .5 L
.3609 .5 L
.36161 .5 L
.36238 .5 L
.3631 .5 L
.36377 .5 L
.36503 .5 L
.36637 .5 L
.36764 .5 L
.36902 .5 L
.37033 .5 L
.37154 .5 L
.37274 .5 L
.37383 .5 L
.37509 .5 L
.37627 .5 L
.37756 .5 L
.37893 .5 L
.3801 .5 L
.38138 .5 L
.38276 .5 L
.38353 .5 L
.38424 .5 L
.38561 .5 L
Mistroke
.38691 .5 L
.38801 .5 L
.38923 .5 L
.3905 .5 L
.39169 .5 L
.3928 .5 L
.39382 .5 L
.39494 .5 L
.39612 .5 L
.39732 .5 L
.3986 .5 L
.3998 .5 L
.4009 .5 L
.40219 .5 L
.40292 .5 L
.40359 .5 L
.40482 .5 L
.40613 .5 L
.4074 .5 L
.40879 .5 L
.4101 .5 L
.41132 .5 L
.41252 .5 L
.41361 .5 L
.41487 .5 L
.41605 .5 L
.41735 .5 L
.41872 .5 L
.41989 .5 L
.42117 .5 L
.42256 .5 L
.42333 .5 L
.42404 .5 L
.42541 .5 L
.4267 .5 L
.42781 .5 L
.42903 .5 L
.43031 .5 L
.4315 .5 L
.43261 .5 L
.43363 .5 L
.43481 .5 L
.43593 .5 L
.43713 .5 L
.43841 .5 L
.43962 .5 L
.44071 .5 L
.44201 .5 L
.44273 .5 L
.4434 .5 L
Mistroke
.44464 .5 L
.44594 .5 L
.44722 .5 L
.44794 .5 L
.44861 .5 L
.44984 .5 L
.45114 .5 L
.45231 .5 L
.4534 .5 L
.4546 .5 L
.45589 .5 L
.45718 .5 L
.45792 .5 L
.4586 .5 L
.45998 .5 L
.46075 .5 L
.46145 .5 L
.46271 .5 L
.46408 .5 L
.46537 .5 L
.46656 .5 L
.46766 .5 L
.46886 .5 L
.46998 .5 L
.47101 .5 L
.47221 .5 L
.47352 .5 L
.47476 .5 L
.4759 .5 L
.4772 .5 L
.47842 .5 L
.47952 .5 L
.4807 .5 L
.48199 .5 L
.48336 .5 L
.48453 .5 L
.4858 .5 L
.48718 .5 L
.48845 .5 L
.48911 .5 L
.48984 .5 L
.49061 .5 L
.49132 .5 L
.49264 .5 L
.49384 .5 L
.49516 .5 L
.49655 .5 L
.49772 .5 L
.49897 .5 L
.50015 .5 L
Mistroke
.50122 .5 L
.50248 .5 L
.50385 .5 L
.50514 .5 L
.50633 .5 L
.5076 .5 L
.50896 .5 L
.51024 .5 L
.51142 .5 L
.51279 .5 L
.51357 .5 L
.51429 .5 L
.5156 .5 L
.51627 .5 L
.51701 .5 L
.51772 .5 L
.51847 .5 L
.51981 .5 L
.52055 .5 L
.52125 .5 L
.52201 .5 L
.52283 .5 L
.52354 .5 L
.5243 .5 L
.52503 .5 L
.52569 .5 L
.52696 .5 L
.5283 .5 L
.52957 .5 L
.53095 .5 L
.53225 .5 L
.53347 .5 L
.53467 .5 L
.53575 .5 L
.53701 .5 L
.53819 .5 L
.53948 .5 L
.54085 .5 L
.54202 .5 L
.5433 .5 L
.54468 .5 L
.54545 .5 L
.54616 .5 L
.54753 .5 L
.54882 .5 L
.54993 .5 L
.55114 .5 L
.55241 .5 L
.55361 .5 L
.55472 .5 L
Mistroke
.55574 .5 L
.55685 .5 L
.55803 .5 L
.55923 .5 L
.56051 .5 L
.56172 .5 L
.56281 .5 L
.5641 .5 L
.56483 .5 L
.5655 .5 L
.56674 .5 L
.56804 .5 L
.56932 .5 L
.5707 .5 L
.57201 .5 L
.57323 .5 L
.57443 .5 L
.57552 .5 L
.57678 .5 L
.57796 .5 L
.57926 .5 L
.58063 .5 L
.5818 .5 L
.58308 .5 L
.58446 .5 L
.58524 .5 L
.58594 .5 L
.58731 .5 L
.58861 .5 L
.58971 .5 L
.59093 .5 L
.59221 .5 L
.5934 .5 L
.59451 .5 L
.59553 .5 L
.59671 .5 L
.59783 .5 L
.59903 .5 L
.60031 .5 L
.60152 .5 L
.60261 .5 L
.60391 .5 L
.60463 .5 L
.6053 .5 L
.60654 .5 L
.60784 .5 L
.60912 .5 L
.60984 .5 L
.61051 .5 L
.61174 .5 L
Mistroke
.61304 .5 L
.6142 .5 L
.61529 .5 L
.61649 .5 L
.61778 .5 L
.61908 .5 L
.61981 .5 L
.62049 .5 L
.62187 .5 L
.62264 .5 L
.62335 .5 L
.6246 .5 L
.62597 .5 L
.62726 .5 L
.62845 .5 L
.62955 .5 L
.63075 .5 L
.63187 .5 L
.6329 .5 L
.6341 .5 L
.63541 .5 L
.63665 .5 L
.63779 .5 L
.63909 .5 L
.64031 .5 L
.6414 .5 L
.64259 .5 L
.64388 .5 L
.64525 .5 L
.64641 .5 L
.64769 .5 L
.64907 .5 L
.65034 .5 L
.651 .5 L
.65173 .5 L
.65249 .5 L
.65321 .5 L
.65452 .5 L
.65572 .5 L
.65704 .5 L
.65843 .5 L
.6596 .5 L
.66085 .5 L
.66203 .5 L
.6631 .5 L
.66436 .5 L
.66573 .5 L
.66702 .5 L
.66821 .5 L
.66947 .5 L
Mistroke
.67083 .5 L
.67212 .5 L
.67329 .5 L
.67467 .5 L
.67544 .5 L
.67616 .5 L
.67748 .5 L
.67815 .5 L
.67888 .5 L
.67959 .5 L
.68034 .5 L
.68168 .5 L
.68243 .5 L
.68312 .5 L
.68389 .5 L
.6847 .5 L
.68541 .5 L
.68618 .5 L
.6869 .5 L
.68757 .5 L
.68883 .5 L
.69018 .5 L
.69144 .5 L
.69282 .5 L
.69413 .5 L
.69534 .5 L
.69654 .5 L
.69762 .5 L
.69888 .5 L
.70006 .5 L
.70135 .5 L
.70272 .5 L
.70388 .5 L
.70517 .5 L
.70654 .5 L
.70732 .5 L
.70802 .5 L
.70939 .5 L
.71069 .5 L
.71179 .5 L
.71301 .5 L
.71428 .5 L
.71547 .5 L
.71658 .5 L
.7176 .5 L
.71872 .5 L
.71989 .5 L
.72109 .5 L
.72237 .5 L
.72358 .5 L
Mistroke
.72468 .5 L
.72597 .5 L
.72669 .5 L
.72737 .5 L
.7286 .5 L
.72991 .5 L
.73118 .5 L
.73256 .5 L
.73387 .5 L
.73508 .5 L
.73629 .5 L
.73738 .5 L
.73863 .5 L
.73982 .5 L
.74111 .5 L
.74248 .5 L
.74365 .5 L
.74493 .5 L
.74631 .5 L
.74709 .5 L
.74779 .5 L
.74916 .5 L
.75046 .5 L
.75157 .5 L
.75279 .5 L
.75406 .5 L
.75525 .5 L
.75636 .5 L
.75738 .5 L
.7585 .5 L
.75968 .5 L
.76088 .5 L
.76216 .5 L
.76337 .5 L
.76446 .5 L
.76575 .5 L
.76648 .5 L
.76715 .5 L
.76839 .5 L
.76969 .5 L
.77097 .5 L
.77169 .5 L
.77236 .5 L
.77358 .5 L
.77489 .5 L
.77605 .5 L
.77714 .5 L
.77834 .5 L
.77963 .5 L
.78092 .5 L
Mistroke
.78165 .5 L
.78233 .5 L
.78371 .5 L
.78448 .5 L
.78519 .5 L
.78644 .5 L
.78781 .5 L
.7891 .5 L
.79029 .5 L
.79139 .5 L
.79258 .5 L
.79371 .5 L
.79473 .5 L
.79593 .5 L
.79724 .5 L
.79848 .5 L
.79963 .5 L
.80093 .5 L
.80214 .5 L
.80324 .5 L
.80442 .5 L
.80572 .5 L
.80708 .5 L
.80825 .5 L
.80953 .5 L
.8109 .5 L
.81217 .5 L
.81283 .5 L
.81356 .5 L
.81432 .5 L
.81504 .5 L
.81635 .5 L
.81755 .5 L
.81887 .5 L
.82026 .5 L
.82143 .5 L
.82268 .5 L
.82386 .5 L
.82493 .5 L
.82619 .5 L
.82755 .5 L
.82884 .5 L
.83003 .5 L
.8313 .5 L
.83266 .5 L
.83394 .5 L
.83512 .5 L
.83649 .5 L
.83727 .5 L
.83798 .5 L
Mistroke
.8393 .5 L
.84004 .5 L
.84071 .5 L
.84142 .5 L
.84216 .5 L
.8435 .5 L
.84425 .5 L
.84495 .5 L
.84571 .5 L
.84653 .5 L
.84723 .5 L
.848 .5 L
.84872 .5 L
.84939 .5 L
.85066 .5 L
.852 .5 L
.85326 .5 L
.85464 .5 L
.85595 .5 L
.85716 .5 L
.85835 .5 L
.85944 .5 L
.86069 .5 L
.86188 .5 L
.86317 .5 L
.86453 .5 L
.8657 .5 L
.86698 .5 L
.86836 .5 L
.86913 .5 L
.86984 .5 L
.87121 .5 L
.8725 .5 L
.8736 .5 L
.87482 .5 L
.87609 .5 L
.87728 .5 L
.87839 .5 L
.87941 .5 L
.88053 .5 L
.8817 .5 L
.8829 .5 L
.88418 .5 L
.88539 .5 L
.88649 .5 L
.88778 .5 L
.8885 .5 L
.88918 .5 L
.89041 .5 L
.89172 .5 L
Mistroke
.89299 .5 L
.89437 .5 L
.89568 .5 L
.89689 .5 L
.89809 .5 L
.89918 .5 L
.90044 .5 L
.90162 .5 L
.90292 .5 L
.90428 .5 L
.90545 .5 L
.90673 .5 L
.90812 .5 L
.90889 .5 L
.90959 .5 L
.91096 .5 L
.91226 .5 L
.91337 .5 L
.91458 .5 L
.91586 .5 L
.91705 .5 L
.91816 .5 L
.91918 .5 L
.9203 .5 L
.92148 .5 L
.92268 .5 L
.92396 .5 L
.92516 .5 L
.92626 .5 L
.92755 .5 L
.92828 .5 L
.92895 .5 L
.93018 .5 L
.93149 .5 L
.93276 .5 L
.93348 .5 L
.93415 .5 L
.93538 .5 L
.93668 .5 L
.93784 .5 L
.93893 .5 L
.94013 .5 L
.94142 .5 L
.94271 .5 L
.94344 .5 L
.94412 .5 L
.9455 .5 L
.94627 .5 L
.94697 .5 L
.94823 .5 L
Mistroke
.9496 .5 L
.95089 .5 L
.95207 .5 L
.95318 .5 L
.95437 .5 L
.95549 .5 L
.95652 .5 L
.95772 .5 L
.95903 .5 L
.96027 .5 L
.96141 .5 L
.96271 .5 L
.96393 .5 L
.96502 .5 L
.96621 .5 L
.9675 .5 L
.96887 .5 L
.97003 .5 L
.97131 .5 L
.97224 .5 L
.9731 .5 L
.97404 .5 L
.97503 .5 L
.9759 .5 L
.97671 .5 L
.9776 .5 L
.97856 .5 L
.97936 .5 L
.98024 .5 L
.98115 .5 L
.982 .5 L
.9828 .5 L
.98353 .5 L
.98437 .5 L
.98516 .5 L
.98602 .5 L
.98696 .5 L
.98795 .5 L
.98887 .5 L
.98973 .5 L
.99051 .5 L
.99142 .5 L
.99228 .5 L
.99321 .5 L
.9942 .5 L
.99513 .5 L
.99598 .5 L
.99697 .5 L
.99805 .5 L
.99907 .5 L
Mistroke
1 .5 L
Mfstroke
0 .5478 m
.04057 .54907 L
.08481 .55075 L
.12636 .55271 L
.16632 .55506 L
.20885 .55827 L
.2498 .56235 L
.27066 .56495 L
.29331 .56829 L
.33524 .57643 L
.35607 .58175 L
.37815 .58865 L
.41788 .60544 L
.43826 .61689 L
.46018 .63182 L
.50346 .67017 L
.54516 .71715 L
.58526 .76743 L
.62794 .82076 L
.66902 .86812 L
.71269 .91245 L
.75476 .94919 L
.79523 .97956 L
s
.79523 .97956 m
.82701 1 L
s
0 .59559 m
.04057 .59814 L
.08481 .6015 L
.12636 .60542 L
.16632 .61012 L
.20885 .61654 L
.2498 .62471 L
.27066 .6299 L
.29331 .63659 L
.33524 .65286 L
.35607 .6635 L
.37815 .6773 L
.41788 .71089 L
.43826 .73377 L
.46018 .76365 L
.50346 .84033 L
.54516 .9343 L
s
.54516 .9343 m
.57136 1 L
s
0 .64339 m
.04057 .6472 L
.08481 .65225 L
.12636 .65812 L
.16632 .66518 L
.20885 .67481 L
.2498 .68706 L
.27066 .69485 L
.29331 .70488 L
.33524 .72928 L
.35607 .74525 L
.37815 .76595 L
.41788 .81633 L
.43826 .85066 L
.46018 .89547 L
s
.46018 .89547 m
.49951 1 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[173]:=",
  ImageSize->{184, 184},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003V0000iR000`400?l00000o`00003oi_ooool0
0>Kooooo003Vooooo`00i_ooool006Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c01iooooo`00J?oo
ool01Ol@413o^[ZjoooooomgMgOo<S8b07Wooooo000;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`Ko00001_ooool00ol0003ooooooooo
o`02ooooo`?o00003?ooool2o`0000gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`00Joooool00onYZJWo410@ooooo`03
ooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`;o0000<?ooool4o`00033ooooo001Yoooo
o`04o`000?l@413o0000okZj^P?ooooo0ol00004ooooo`03o`000?oooooooooo00Gooooo0ol00005
ooooo`03o`000?oooooooooo02Kooooo1?l0000booooo`00GOooool00ol0003oooooooooo`09oooo
o`04o`000?oooooo^[Zjob4Q8@?ooooo0ol00003ooooo`;o00001oooool2o`0000Gooooo0_l0000?
ooooo`;o00005_ooool4o`0003?ooooo001Looooo`;o00002_ooool2o`000003oooooonj^[[o0000
00?ooooo0ol00003ooooo`;o00001_ooool3o`0000Cooooo0ol0000>ooooo`?o00005?ooool4o`00
03Gooooo001@ooooo`;o00002Oooool2o`0000[ooooo1?l000001?l@413oZJVYooooooooool4o`00
00;ooooo0ol00006ooooo`;o00001?ooool3o`0000kooooo0ol0000@ooooo`;o00000_ooool4o`00
03Kooooo001>ooooo`?o00002Oooool3o`0000[ooooo00?o0000ooooool000001Oooool2o`000007
ooooool0003oooooooooool0003oooooo`000006ooooo`;o00001Oooool2o`0000gooooo1?l0000>
ooooo`?o00000_ooool3o`0003Sooooo0012ooooo`?o00002?ooool3o`0000_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`;o000000Goooooo`000?l0003oooooo`000007
ooooo`?o00001Oooool00ol0003oooooooooo`0=ooooo`;o00003_ooool3o`000003ooooool0003o
000000;o00002_ooool3o`0002cooooo0010ooooo`Co00002Oooool2o`0000_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`?o000000Goooooo`000?ooooooooooo`000007
ooooo`;o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo0_l00000
0ooooooo0000o`000002o`0000Wooooo1?l0000]ooooo`00=?ooool3o`0000Wooooo0ol00009oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`;o00000_ooool00ol0003oooooo`000007ooooo`?o00001Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00ol0000;ooooo`?o00003oooool3o`00
01cooooo000Vooooo`?o00002Oooool4o`0000Sooooo0_l000000ooooooo0000ooooo`08ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`;o
00000_ooool00ol0003oooooo`000007ooooo`;o00001_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00ol0000;ooooo`03o`000?oooooo000000ko
oooo0ol0000>ooooo`?o00003Oooool001Gooooo1Ol0000:ooooo`?o00002_ooool4o`0000Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01Oooool3o`0000;ooooo00?o0000ooooool000001_ooool3o`0000Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000?o0000
2_ooool2o`0000oooooo1?l0000=ooooo`?o00003oooool001Cooooo1?l00009ooooo`Go00002?oo
ool3o`0000;ooooo00?o0000ooooooooool01Oooool2o`0000cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`;o00001ooo
ool2o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000?o00002_ooool00ol0003oooooooooo`0=ooooo`;o00000_ooool00ol0003ooooooooo
o`09ooooo`Go00004?ooool0013ooooo1?l00002ooooo`03o`000?oooooooooo00Gooooo0ol00003
ooooo`03o`000?oooooooooo00Gooooo0_l0000;ooooo`;o00003Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool3o`0000?ooooo0_l00007
ooooo`;o00001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooool000000_l0000:ooooo`;o00003Oooool3o`0000gooooo0ol00003ooooo`03o`000?oooooo
oooo00oooooo000=ooooo`?o00002oooool3o`0000cooooo0_l0000<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Gooooo0_l00004ooooo`;o00001_ooool3o`0000Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooo000000;o00002_ooool00ol0003oooooooooo`0;oooo
o`;o00003Oooool3o`0001Sooooo000;ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2o`0000Cooooo00?o0000oooooooo
ool01Oooool2o`0000Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooo000000;o00002_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`00Joooool3o`0000Cooooo
00?o0000ooooooooool00oooool4o`0002?ooooo0ol00014ooooo`00J_ooool3o`0000Gooooo00?o
0000ooooooooool00oooool3o`0000gooooo00?o0000ooooooooool04oooool3o`0004Gooooo001M
ooooo`;o00002_ooool4o`0000Gooooo00?o0000ooooooooool00_ooool4o`0000cooooo0_l0000?
ooooo`;o00000oooool3o`0004Kooooo001Looooo`?o00002Oooool5o`0000Gooooo00?o0000oooo
ooooool00_ooool4o`0000_ooooo0ol0000>ooooo`?o00000_ooool3o`0004Oooooo001@ooooo`;o
00002Oooool3o`0000Wooooo1Ol00006ooooo`04o`000?ooooooooooooooo`Co00002oooool3o`00
00kooooo0ol00002ooooo`?o00002_ooool2o`0003cooooo001?ooooo`?o00002?ooool4o`0000[o
oooo1?l00006ooooo`;o00000_ooool4o`0000cooooo0_l0000=ooooo`Co000000Coooooo`000?l0
003o00002_ooool3o`0003cooooo001>ooooo`?o00002_ooool2o`0000_ooooo1?l00006ooooo`04
o`000?ooooooooooooooo`?o00003Oooool00ol0003oooooooooo`0=ooooo`;o000000Coooooo`00
0?l0003o00002_ooool3o`0003gooooo0012ooooo`?o00002?ooool4o`0000[ooooo00?o0000oooo
ooooool02Oooool01?l0003oooooo`000?l00007ooooo`03o`000?oooooooooo00Co00003?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?o00002_ooool4o`0000oooooo0ol0000[
ooooo`00=?ooool3o`0000Wooooo1?l00008ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooo`000002o`0000Oooooo00?o0000ooooooooool00ol0000<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00ol0000:ooooo`04o`000?oooooo
ooooo`0000gooooo1?l0000>ooooo`?o00007?ooool003;ooooo1?l00009ooooo`Co00002?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00Co0000ooooool0003o00002?oo
ool01?l0003oooooo`000?ooool2o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
o`000002o`0000[ooooo00?o0000ooooooooool03oooool3o`0000gooooo1?l0000Mooooo`005Ooo
ool4o`0000_ooooo1Ol00008ooooo`Co00002?ooool2o`0000;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000000_l0
0008ooooo`03o`000?oooooo000000?o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooo000000;o00002_ooool00ol0003oooooooooo`0>ooooo`;o000000?oooooo`000?ooool02ooo
ool5o`0000cooooo1Ol0000=ooooo`005Oooool6o`0000Sooooo1?l00007ooooo`?o00000_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`Co00002Oooool2o`000003ooooool0003o000000cooooo00?o0000
ooooooooool03?ooool00ol0003oooooo`000002o`0000[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0<ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co00003oooool0
01?ooooo1Ol00007ooooo`Co000000?oooooo`000?ooool01_ooool2o`0000cooooo0_l0000<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool01?l0003oooooo`000?l0000:
ooooo`Go00002oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o00002_ooool0
0ol0003oooooooooo`0=ooooo`;o00003?ooool3o`0000kooooo1?l00002ooooo`03o`000?oooooo
oooo00kooooo000>ooooo`Go00002Oooool3o`0000_ooooo0_l0000<ooooo`;o00003Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo1?l0000:ooooo`Co00003?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?o00002Oooool00ol0003oooooooooo`0<oooo
o`;o00003?ooool2o`0000kooooo0ol0000Gooooo`002oooool3o`0000cooooo0_l0000=ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00Co0000ooooool0003o00002oooool4o`0000_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`03o`0000Wooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`03o`000?oooooooooo
00[ooooo001Tooooo`?o00002oooool3o`0001cooooo0ol0001Booooo`00I?ooool2o`0000;ooooo
1Ol00005ooooo`?o00001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo
0ol0001Cooooo`00Hoooool3o`0000;ooooo00?oV9RHob4Q8Ol000000_l00005ooooo`?o00000ooo
ool2o`0000kooooo0_l00005ooooo`?o0000E?ooool005kooooo2?l00003ooooo`?o00001_ooool2
o`0000?ooooo0ol0000=ooooo`?o00001?ooool3o`0000Sooooo0_l0001;ooooo`00G?ooool4o`00
00;ooooo0ol00003ooooo`Co000000?ok^k^ooooooooool00_ooool3o`0000;ooooo0ol0000=oooo
o`?o00001?ooool3o`0000Oooooo1?l0001;ooooo`00DOooool2o`0000Sooooo1?l00002ooooo`?o
00001Oooool2o`000003ogMgMomVIVKooooo00?ooooo0_l00004ooooo`;o00003_ooool2o`0000?o
oooo0ol00007ooooo`Co00003oooool2o`0003_ooooo001?ooooo`?o00002_ooool3o`0000;ooooo
0_l00006ooooo`04o`000?ooooooooooo`0000?ooooo0ol00003ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00_ooool3o`0000Sooooo1?l0000=ooooo`?o0000??ooool004?ooooo
0ol00008ooooo`?o00002_ooool00ol0003oooooo`000002ooooo`?o00001Oooool01Ol0003o^[Zj
oooooonHV9So410@00;ooooo1?l00003ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00oooool2o`0000Sooooo00Co0000oooooooooooo00003Oooool3o`0000oooooo0ol0000[oooo
o`00@Oooool3o`0000Wooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`03ooooo`;o
00001Oooool01_l0003oV9RHoa0@4?l0003o8B4Qolc<c0;ooooo0_l000001Ooooooo0000oooooooo
oooo000000oooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooo`00000>ooooo`Co0000;?ooool003;ooooo1_l00007ooooo`Co00002?ooool2
o`0000cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool01Oooool3
o`000005ooooool0003oooooooooool000003_ooool00ol0003oooooooooo`02ooooo`?o00001ooo
ool00ol0003oooooooooo`0=ooooo`;o00004?ooool4o`0000cooooo1Ol0000Looooo`009?ooool5
o`0000Wooooo1?l00007ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool3o`0000Gooooo00?o0000ooooooooool01Oooool2
o`0000;ooooo0ol0000>ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool3o`0000;ooooo00?o0000ooooooooool02_ooool4
o`0000cooooo1Ol0000=ooooo`005Oooool6o`0000Kooooo1_l00007ooooo`Co000000?oooooo`00
0?ooool01Oooool3o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo00?ooooo0ol00005oooo
o`03o`000?oooooooooo00Gooooo0ol00002ooooo`;o00003oooool00ol0003oooooooooo`02oooo
o`;o00001oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool2o`0000kooooo1?l00002oooo
o`03o`000?oooooooooo00Sooooo1_l0000?ooooo`003oooool:o`0000?ooooo1Ol00003ooooo`03
o`000?oooooooooo00Cooooo0ol0000:ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`;o
00003_ooool00ol0003oooooooooo`02ooooo`?o00001_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo0_l0000=ooooo`?o00003?ooool5o`0000Cooooo00?o0000oooooooo
ool03_ooool000_ooooo1?l00007ooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`0000co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo0_l00005ooooo`03o`000?oooooooooo00Kooooo0ol00003ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`;o00003Oooool00ol0003o
ooooooooo`0:ooooo`00Foooool3o`0000kooooo0_l00004ooooo`03o`000?oooooooooo017ooooo
0_l0001Nooooo`00F_ooool3o`0000kooooo0ol00004ooooo`03o`000?oooooooooo013ooooo0ol0
001Nooooo`00FOooool3o`0000kooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool3o`0005oooooo001Hooooo`?o00003oooool2o`000003ooooool0003ooooo
00?ooooo0_l00006ooooo`;o00001oooool3o`0000Cooooo0_l0001Jooooo`00Eoooool3o`0000oo
oooo1Ol00004ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`;o00001?ooool3o`0005[o
oooo001Fooooo`?o00001_ooool2o`0000Sooooo1?l00005ooooo`03o`000?oooooooooo00?ooooo
0ol00007ooooo`?o00000oooool3o`0000oooooo0_l0001:ooooo`00EOooool3o`0000Kooooo0ol0
0007ooooo`Go00001Oooool00ol0003oooooooooo`03ooooo`;o00001oooool3o`0000?ooooo1?l0
000=ooooo`Co0000B_ooool005Cooooo0ol00006ooooo`?o00001oooool5o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`?o00001Oooool2o`0000gooooo1?l0001;
ooooo`00Coooool7o`0000Kooooo1?l00006ooooo`Co00002?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo0ol00005ooooo`03o`000?oooooooooo00cooooo1?l0000=oooo
o`Go0000>_ooool004?ooooo0ol00009ooooo`Ko00001Oooool2o`0000;ooooo00?o0000oooooooo
ool01?ooool4o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`?o00001Oooool00ol0
003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000kooooo0ol0000?ooooo`?o0000:_ooool0
047ooooo1?l00009ooooo`Go00001_ooool00ol0003oooooooooo`08ooooo`Co00002_ooool2o`00
0003ooooool0003ooooo00Kooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03oooool3o`0000gooooo1?l0000/ooooo`009?ooool3o`0000cooooo1Ol00006ooooo`Ko
00001oooool7o`0000Kooooo00?o0000ooooooooool02Oooool3o`0000_ooooo00Co0000oooooooo
oooo00001_ooool3o`0000Gooooo00?o0000ooooooooool02oooool2o`0000oooooo0ol0000>oooo
o`Go00003?ooool6o`0000Wooooo1?l0000>ooooo`005_ooool5o`0000Wooooo1Ol00007ooooo`Ko
00001Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool2o`0000;ooooo1?l00006ooooo`03
o`000?oooooooooo00Wooooo0ol0000<ooooo`03o`000?oooooo000000Kooooo0ol00005ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool2o`0000kooooo0ol00003ooooo`03
o`000?oooooooooo00Wooooo1_l0000;ooooo`Ko00003?ooool000oooooo2_l00005ooooo`So0000
1Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000cooooo0_l00002ooooo`Co0000
1oooool00ol0003oooooooooo`09ooooo`?o00003Oooool2o`0000Kooooo0ol00005ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool2o`0000gooooo0ol0000=ooooo`Go0000
0oooool00ol0003oooooooooo`05ooooo`Wo00003oooool000_ooooo1?l00007ooooo`04o`000?oo
ooooooooooooo`Co00002oooool2o`0000cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`05o`0000Oooooo00?o0000ooooooooool02Oooool3o`0000kooooo00?o0000ooooooooool0
1Oooool2o`0000Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool3o`0000cooooo1?l0000;ooooo`03o`00
0?oooooooooo00[ooooo0018ooooo`Co00004oooool4o`0000oooooo00?o0000ooooooooool01?oo
ool3o`0006[ooooo0016ooooo`Co00005?ooool4o`00013ooooo00?o0000ooooooooool00oooool3
o`0006_ooooo0013ooooo`Ko00005?ooool3o`0001;ooooo0_l00003ooooo`?o0000K?ooool0047o
oooo1_l0000Eooooo`?o00004oooool01?l0003oooooooooooooool3o`0006gooooo000oooooo`Go
00005oooool3o`0001Cooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000J?ooool003co
oooo1_l0000Hooooo`?o00004Oooool2o`0000;ooooo00?o0000ooooooooool00ol00002ooooo`Co
00003_ooool2o`0005Sooooo000gooooo`Wo00006Oooool3o`0000gooooo1_l00003ooooo`03o`00
0?oooooo000000;o00000_ooool4o`0000gooooo0ol0001Iooooo`00<oooool:o`0001[ooooo1?l0
0005ooooo`?o00002?ooool3o`0000Cooooo1?l00003ooooo`Co00003?ooool3o`0000oooooo0ol0
0018ooooo`00;_ooool:o`0001cooooo1_l00004ooooo`So00001?ooool3o`0000Cooooo1?l00003
ooooo`04o`000?ooooooooooo`0000cooooo0ol0000=ooooo`Co0000B_ooool002[ooooo2_l0000L
ooooo`So00001Oooool4o`0000Sooooo00?o0000ooooool000001?ooool4o`0000?ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`?o00003Oooool5o`0003Wooooo000Voooo
o`Wo00004_ooool4o`0000_ooooo1Ol00006ooooo`;o00000_ooool00ol0003oooooooooo`06oooo
o`04o`000?ooooooooooo`0000?ooooo1?l00003ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool2o`000003ooooool0003ooooo00gooooo0ol0000<ooooo`?o0000;?ooool0
023ooooo2ol00008ooooo`Go00002Oooool6o`0000Kooooo1_l00007ooooo`03o`000?oooooooooo
00Wooooo0_l00003ooooo`03o`000?oooooooooo00?o000000Goooooo`000?ooooooooooo`00000>
ooooo`;o00003_ooool2o`0000oooooo1?l0000>ooooo`Go00002_ooool5o`0000Wooooo1?l0000>
ooooo`005_oooolDo`0000Kooooo1_l00009ooooo`Go00001_ooool3o`000003ooooool0003o0000
00;o00001_ooool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002o`00
00;ooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`00
00oooooo1Ol0000:ooooo`Ko00002oooool6o`0000cooooo000?oooooaWo00000oooool5o`0000?o
oooo00?o0000ooooooooool01?ooool5o`0000Sooooo0ol000000ooooooo0000o`000004o`0000Go
oooo0_l0000<ooooo`03o`000?oooooooooo00;ooooo00?oEEEEofIVI_l000000ol00003ooooo`;o
00003_ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool3o`0000gooooo1Ol0000:ooooo`Go
00000oooool00ol0003oooooooooo`05ooooo`[o00003_ooool000_ooooo3_l000000ooooooo0000
o`000002o`0000Oooooo00Co0000oooooooooooooooo0_l0000<ooooo`?o00003?ooool00ol0003o
ooooo`000006o`0000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`?o
00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`;o00003?ooool3o`0000cooooo1?l00007ooooo`05
o`000?ooooooooooooooool000003?ooool000_ooooo1Ol0000eooooo`Oo00007_ooool3o`0000Go
oooo00?o0000ooooooooool0LOooool0043ooooo2Ol0000Oooooo`Co00001_ooool2o`0007;ooooo
000looooo`[o00008?ooool5o`0000Oooooo00?o0000ooooooooool0LOooool003Oooooo2_l0000T
ooooo`Co00002Oooool00ol0003oooooooooo`1aooooo`00<Oooool<o`0002Kooooo1?l0000;oooo
o`03o`000?oooooooooo077ooooo000Xoooooa3o0000:Oooool5o`0000cooooo00?o0000oooooooo
ool0LOooool0023ooooo4_l0000]ooooo`Go00003_ooool00ol0003oooooooooo`1aooooo`006?oo
oolAo`0003Cooooo1Ol0000@ooooo`;o0000L_ooool000_ooooo5_l0000jooooo`Go00003oooool4
o`0000Sooooo1Ol0000<ooooo`?o0000Eoooool000_ooooo3_l00010ooooo`Go00003oooool4o`00
0003ooooool0003ooooo00Oooooo0ol0000<ooooo`Co0000F?ooool005Kooooo1_l00003ooooo`Go
00001_ooool6o`0000;ooooo00?o0000ooooooooool00oooool3o`000003ooooool0003ooooo00Wo
oooo1_l0000<ooooo`Ko0000Aoooool004;ooooo0ol0000;ooooo`[o00000_ooool6o`0000Gooooo
0ol00004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000gooooo0_l00004ooooo`03
o`000?oooooooooo00Wooooo1_l0000;ooooo`Ko00002Oooool3o`0002cooooo000Fooooo`?o0000
2oooool4o`0000Sooooo2?l00007ooooo`So00000ooooolBo`0000?ooooo00?o0000ooooooooool0
0_ooool3o`0000_ooooo1?l0000<ooooo`?o00003Oooool5o`0000?ooooo00?o0000ooooooooool0
1Oooool:o`0000Sooooo2?l00007ooooo`So00002_ooool3o`0000kooooo000;ooooobGo00000ooo
ool3o`000003ooooool0003o000000Ko00000oooool2o`0000;ooooo3?l00003ooooo`;o00003?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool3o`0000cooooo1?l00007ooooo`04o`000?ooooooooooooooo`Oo00000oooool2o`0000;ooooo
2?l00003ooooo`?o000000?oooooo`000?l000003_l0000<ooooo`005_ooool2o`0000gooooo0_l0
000<ooooo`03o`000?oooooooooo00oooooo2Ol0000Tooooo`;o0000D_ooool00ol0003ooooooooo
o`0<ooooo`;o00003oooool003[ooooo4?l0000Xooooo`03o`000?oooooooooo077ooooo000<oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`07_oooolGo`0000cooooo1?l000000ol@413oooooooooo`0I
ooooo`03o`000?oooooooooo01gooooo1?l000000ol@413oooooooooo`0Kooooo`Go00007Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00_ooooo000<ooooo`05oa0@4?nj^[[oooooogMgMolb<S803ooo
oolKo`0001Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01gooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Mooooo`05oa0@4?nj^[[oooooogMgMolb
<S802oooool000Cooooo1_l000000ooooooo0000o`00000Uo`000003onk^k_oooooooooo01Cooooo
1_l00005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Nooooo`03oiRHV?lQ8B7ok^k^02;ooooo00?o0000ooooooooool02Oooool000_ooooo5_l0
000@ooooo`03oiRHV?lQ8B7ok^k^023ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01oooooo00?oV9RHob4Q8Oo^k^h08?ooool00onYZJWo410@oooo
o`0:ooooo`003_ooool00ol@413o0000okZj^P0Qooooo`03ogMgMomVIVKooooo01oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo023ooooo00?oMgMg
ofIVI_ooool07_ooool00ol@413o0000okZj^P0;ooooo`003oooool00onj^[[o8B4Qooooo`0Qoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool06oooool2o`00023ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Nooooo`03okZj^_lQ8B7ooooo00[ooooo000<ooooo`05
oa0@4?nHV9SooooookZj^_l000007_ooool01Ol0003o^[ZjoooooonHV9So410@023ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01gooooo00Go0000
okZj^_ooooooV9RHoa0@400Mooooo`05oa0@4?nHV9SooooookZj^_l000002oooool000cooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@0Nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`07_ooool00omEEEGo
IVIVo`00000Mooooo`03o`000?oooooooooo01gooooo00?oEEEEofIVI_l000007oooool01OnHV9So
410@o`000?lQ8B7oc<c<01gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0;ooooo`00L_ooool00ol0
003oooooooooo`1aooooo`00L_ooool00ol0003oooooooooo`1aooooo`00L_ooool00ol0003ooooo
ooooo`1aooooo`005_ooool3o`0000_ooooo1?l0000;ooooo`?o00003?ooool3o`0000cooooo0ol0
000;ooooo`?o00003?ooool3o`000003ooooool0003ooooo00Wooooo0ol0000;ooooo`?o00003?oo
ool3o`0000cooooo0ol0000;ooooo`?o00003?ooool3o`0000cooooo0ol0000>ooooo`002oooooo?
o`0000cooooo000;oooooloo00003?ooool007;ooooo00?o0000ooooooooool0LOooool007;ooooo
00?o0000ooooooooool0LOooool007;ooooo00?o0000ooooooooool0LOooool007;ooooo00?o0000
ooooooooool0LOooool007;ooooo00?o0000ooooooooool0LOooool007;ooooo0_l0001booooo`00
L_ooool00ol0003oooooooooo`1aooooo`00L_ooool00ol0003oooooooooo`1aooooo`002ooooolG
o`00053ooooo00?o0000ooooooooool0LOooool000_ooooo:?l0000oooooo`03o`000?oooooooooo
077ooooo000Qoooooa_o0000=_ooool00ol0003oooooooooo`1aooooo`00<_oooolEo`0002_ooooo
00?o0000ooooooooool0LOooool001Kooooo0ol0000<ooooo`;o00005?ooool@o`0002Oooooo0_l0
001Qooooo`;o00003oooool000_ooooo6?l00002ooooo`co00000_ooool3o`000003ooooool0003o
000000Oo00000_ooool3o`000003ooooool0003o000000Oo00000_ooool2o`0000;ooooo0ol0000;
ooooo`;o00003Oooool2o`0000gooooo0_l0000<ooooo`Co00002oooool5o`0000Kooooo0_l00002
ooooo`So00000_ooool3o`000003ooooool0003o000000Oo00000_ooool3o`000003ooooool0003o
000000Oo00000_ooool5o`0000cooooo000Fooooo`;o00002oooool7o`0000Oooooo1ol00008oooo
o`Oo00000oooool:o`0000Cooooo1Ol00002ooooo`;o00001?ooool3o`0000[ooooo00?o0000oooo
ool000000_l0000<ooooo`?o00003Oooool5o`0000;ooooo0_l00007ooooo`[o00002?ooool7o`00
00Sooooo1ol00008ooooo`Oo00003?ooool003?ooooo0_l0000=ooooo`;o00002_ooool:o`0000Go
oooo1_l00005ooooo`?o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0ol0000<oooo
o`?o00000_ooool00ol0003oooooooooo`0:ooooo`Ko00002_ooool6o`0000Wooooo0_l0000=oooo
o`;o00007_ooool005;ooooo2Ol00004ooooo`Go00001oooool5o`0000;ooooo00?o0000oooooooo
ool01Oooool4o`0000_ooooo1?l0000<ooooo`Ko0000Aoooool005Oooooo1_l0000@ooooo`Co0000
00?oooooo`000?ooool02?ooool3o`0000_ooooo1?l0001Hooooo`002oooool?o`00043ooooo1Ol0
000Aooooo`?o00002?ooool5o`0000gooooo0_l0001Gooooo`002ooooolGo`0003[ooooo1Ol0000A
ooooo`;o0000L_ooool001Wooooo4Ol0000dooooo`Go00003oooool00ol0003oooooooooo`1aoooo
o`008OoooolBo`0002gooooo1Ol0000=ooooo`03o`000?oooooooooo077ooooo000Yoooooa3o0000
:Oooool5o`0000_ooooo00?o0000ooooooooool0LOooool003;ooooo3?l0000Vooooo`Go00002Ooo
ool00ol0003oooooooooo`1aooooo`00>?ooool:o`0002Cooooo1?l00008ooooo`03o`000?oooooo
oooo077ooooo000mooooo`[o00008Oooool4o`0000Kooooo0_l0001booooo`00@Oooool9o`0001oo
oooo1?l00005ooooo`03o`000?oooooooooo077ooooo000;ooooo`Ko00001Oooool2o`0000;ooooo
1Ol0000:ooooo`?o00002oooool3o`0000cooooo1ol00008ooooo`;o00003?ooool2o`0000Kooooo
0ol00004ooooo`;o00003Oooool2o`0000cooooo0_l0000=ooooo`;o00003Oooool3o`0000_ooooo
1?l0000;ooooo`Go00002_ooool00ol0003oooooooooo`0:ooooo`002oooool?o`0000Gooooo2Ol0
0004ooooo`Go00000_ooool2o`0000Gooooo1?l0000:ooooo`So00001oooool2o`0000cooooo00?o
0000ooooooooool01?ooool3o`0000?ooooo00?o0000ooooool000003_ooool00ol0003ooooooooo
o`0;ooooo`;o00003Oooool3o`0000gooooo0ol0000<ooooo`Go00000_ooool2o`0000Oooooo2Ol0
000>ooooo`004?ooool@o`0000Gooooo1Ol00007ooooo`Ko00001oooool3o`000003ooooool0003o
000000Oooooo1ol00007ooooo`;o00002oooool00ol0003oooooooooo`04ooooo`?o00000_ooool0
1?l0003oooooooooool0000>ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003Ooo
ool6o`0000_ooooo1_l0000;ooooo`Go00003?ooool001Wooooo3_l0000<ooooo`Go00002Oooool5
o`0000Sooooo1Ol00008ooooo`;o00002_ooool6o`000006oa0@4?l0003o0000o`000?oooooo0000
0oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool2o`0000oooooo1?l0000=ooooo`Co0000
2oooool5o`0000Wooooo0ol0000?ooooo`007oooool;o`0001Oooooo1_l00009ooooo`Co00002Ooo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo000000?ooooo1?l00004ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool4o`0000gooooo1?l0000;ooooo`Go0000:_oo
ool002?ooooo3Ol0000Pooooo`Ko00002?ooool3o`0000Wooooo0_l00004ooooo`Co00001?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo0ol0000<ooooo`Go0000>Oooool0
02Wooooo3?l0000Nooooo`Ko00001Oooool4o`0000Wooooo0_l00004ooooo`?o00001Oooool00ol0
003oooooo`00000=ooooo`;o00003Oooool5o`0004Wooooo000_ooooo`[o00007?ooool6o`0000Ko
oooo0_l00008ooooo`?o00001?ooool2o`0000Kooooo0_l0000=ooooo`?o00004?ooool2o`0004So
oooo000dooooo`[o00006_ooool4o`0000oooooo00Co0000ooooool0003o00000oooool3o`0000Co
oooo1?l0000>ooooo`;o0000FOooool003Sooooo2Ol0000Iooooo`?o00003_ooool01Ol0003ooooo
oooooooooooo000000;ooooo1?l00005ooooo`;o00004?ooool00ol0003oooooooooo`1Fooooo`00
?Oooool6o`0001Sooooo0ol0000;ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooool00000
0_l00006ooooo`03o`000?oooooooooo06Kooooo0010ooooo`Go00005oooool3o`0001?ooooo00?o
0000ooooooooool00ol0001^ooooo`00@_ooool6o`0001Gooooo0ol0000Booooo`;o00000_ooool2
o`0006kooooo0014ooooo`Ko00005?ooool3o`00017ooooo00Co0000oooooooooooooooo0ol0001]
ooooo`00Aoooool4o`0001Cooooo0ol0000@ooooo`03o`000?oooooooooo00;ooooo0ol0001/oooo
o`002oooool5o`0000Kooooo0_l00002ooooo`?o00003?ooool3o`0000_ooooo0_l0000=ooooo`;o
000000?oooooo`000?l000000_l00008ooooo`;o00002Oooool2o`000003ooooool0003ooooo00go
oooo00?o0000ooooooooool00oooool3o`0000Kooooo00?o0000ooooooooool02oooool2o`0000go
oooo0_l0000=ooooo`;o00003?ooool4o`0000_ooooo1?l0000;ooooo`03o`000?oooooooooo00[o
oooo000@ooooo`[o00000oooool5o`0000?ooooo0_l00005ooooo`Go00000_ooool2o`0000Cooooo
0ol0000<ooooo`Oo00002?ooool00ol0003oooooooooo`06ooooo`Co00003_ooool00ol0003ooooo
ooooo`04ooooo`?o00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
0_l0000=ooooo`?o00003Oooool5o`0000;ooooo0_l00006ooooo`Go00000_ooool2o`0000oooooo
000Fooooo`Go00001oooool6o`0000Wooooo1_l00005ooooo`?o00000oooool00ol0003ooooooooo
o`05ooooo`Ko00002?ooool00ol0003oooooooooo`06ooooo`Co00003Oooool2o`0000Kooooo0_l0
0006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000kooooo0ol0
0002ooooo`;o00002oooool6o`0000Wooooo1_l0000=ooooo`009?ooool5o`0000[ooooo1Ol00007
ooooo`Go00002?ooool6o`0000Oooooo00?o0000ooooooooool01_ooool4o`0000cooooo00?o0000
ooooool000001Oooool3o`0000Kooooo00?o0000ooooooooool03Oooool2o`0000oooooo0ol0000>
ooooo`Go00002oooool6o`0000Wooooo1_l0000<ooooo`00@Oooool4o`0000[ooooo1?l00007oooo
o`;o00001oooool4o`0000_ooooo0_l000000ooooooo0000ooooo`04ooooo`?o00001_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo0ol0000<ooooo`Go0000:oooool004Co
oooo0_l0000:ooooo`Co00002?ooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?oo
ool02Oooool01?l0003oooooooooool00006ooooo`?o00001_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo0ol0000?ooooo`;o0000:_ooool004oooooo1_l00008ooooo`;o
00001Oooool3o`000003ooooool0003ooooo00Sooooo00Go0000ooooooooooooooooo`000006oooo
o`?o00001_ooool00ol0003oooooooooo`0>ooooo`;o00003_ooool5o`0003[ooooo001Cooooo`?o
00001oooool2o`0000Kooooo0ol000001?oooooo0000ooooool00006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooool000003Oooool3o`00
04cooooo001Dooooo`?o00002?ooool00ol0003oooooooooo`04ooooo`?o000000?oooooo`000?l0
00001_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool3o`0000Kooooo0_l0000?ooooo`;o
0000Boooool005Gooooo0ol00008ooooo`03o`000?oooooooooo00Cooooo1_l00005ooooo`03o`00
0?oooooooooo00?ooooo0_l00006ooooo`?o00001?ooool4o`00013ooooo00?o0000ooooooooool0
B?ooool005Kooooo0ol0000?ooooo`?o000000?oooooo`000?ooool01?ooool00ol0003ooooooooo
o`04ooooo`;o00001_ooool3o`0000Gooooo0_l0001Kooooo`00Eoooool3o`0000oooooo0_l00002
ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo0ol00006
ooooo`03o`000?oooooooooo05Sooooo001Hooooo`;o00003oooool3o`0000Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`;o0000HOooool005Sooooo0ol0000?ooooo`;o
00001_ooool00ol0003oooooooooo`0>ooooo`?o0000H?ooool005Wooooo0ol0000>ooooo`?o0000
1Oooool00ol0003oooooooooo`0?ooooo`?o0000Goooool000_ooooo1Ol0000:ooooo`?o00003?oo
ool3o`0000_ooooo0_l0000=ooooo`;o00003Oooool00ol0003oooooooooo`02ooooo`?o00001_oo
ool00ol0003oooooooooo`05ooooo`?o00001?ooool00ol0003oooooooooo`0<ooooo`04o`000?oo
ooooooooooooo`?o00001oooool2o`0000gooooo0_l0000=ooooo`;o00003?ooool3o`0000cooooo
0ol0000<ooooo`03o`000?oooooooooo00[ooooo000@ooooo`Wo00001?ooool5o`0000;ooooo0_l0
0006ooooo`?o00002_ooool3o`0000cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool2o`0000gooooo0ol0000<ooooo`Go00000oooool2o`0000oooooo000F
ooooo`Go00001oooool6o`0000Oooooo1_l00007ooooo`;o00002oooool2o`0000cooooo00?o0000
ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool01Oooool3o`0000?ooooo0_l0000>
ooooo`04o`000?ooooooooooooooo`?o00002Oooool00ol0003oooooooooo`0<ooooo`;o00003_oo
ool2o`0000kooooo1?l000000ooooooo0000o`00000:ooooo`Ko00003_ooool001Gooooo0ol0000<
ooooo`Go00002_ooool4o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooooooo0ol00006ooooo`03o`000?oooooooooo00Gooooo0_l0
0003ooooo`;o00003oooool01?l0003oooooooooooooool3o`0000Wooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`?o000000?oooooo`000?ooool03?ooool4o`0000_ooooo
1Ol0000=ooooo`00<_ooool6o`0000Sooooo1?l00008ooooo`;o00002oooool01?l0003ooooooooo
ooooool3o`0000Kooooo00?o0000ooooooooool01?ooool3o`0000;ooooo00?o0000ooooool00000
3_ooool00ol0003oooooooooo`02ooooo`;o00002_ooool00ol0003oooooooooo`0=ooooo`;o0000
4?ooool3o`0000cooooo1Ol0000Looooo`00@Oooool4o`0000Wooooo0_l0000:ooooo`04o`000?oo
ooooooooooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool01?l0003ooooo
ooooool0000>ooooo`04o`000?ooooooooooooooo`?o00002_ooool00ol0003oooooooooo`0>oooo
o`;o00003_ooool4o`0002cooooo0014ooooo`;o00002?ooool3o`0000[ooooo00Co0000ooooool0
003ooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo0ol000001Ooooooo0000oooooooooooo
000000oooooo00Co0000oooooooooooooooo0ol0000:ooooo`03o`000?oooooo000000gooooo0ol0
000@ooooo`;o0000:oooool0053ooooo0_l0000:ooooo`;o00000_ooool2o`0000Kooooo1Ol00002
ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo0ol0000:ooooo`;o00003oooool2o`0003cooooo001Booooo`03o`000?oooooooooo
00Kooooo1?l000001?oooooo0000o`000?l00005ooooo`05oiRHV?l0003o0000oooooom4A4@00_oo
ool4o`0000?ooooo0ol0000=ooooo`?o00000_ooool2o`0000Wooooo1?l0000@ooooo`03o`000?oo
oooooooo03Wooooo001Mooooo`;o00000_ooool2o`0000Gooooo0ol000000oo^k^koooooooooo`02
ooooo`?o00000oooool3o`0000gooooo0ol00002ooooo`?o00002_ooool2o`0004cooooo001Ooooo
o`03o`000?oooooo000000;o00001_ooool2o`000003onk^k_oooooooooo00;ooooo0ol00003oooo
o`;o00003_ooool2o`0000?ooooo0ol0000;ooooo`03o`000?oooooooooo04Wooooo001Rooooo`?o
00001_ooool00ol0003oIVIVooooo`03ooooo`?o00001?ooool2o`0000kooooo0_l00003ooooo`?o
0000E_ooool006?ooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool3o`0005Gooooo001Sooooo`?o00000_oo
ool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0ol0000Jooooo`?o0000E?ooool000_ooooo1?l0
000;ooooo`?o00003?ooool2o`0000cooooo0_l0000=ooooo`;o00003Oooool00ol0003ooooooooo
o`0;ooooo`?o00000_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo0ol0000<ooooo`03o`00
0?oooooooooo00_ooooo1?l0000;ooooo`;o00003Oooool2o`0000cooooo0_l0000=ooooo`?o0000
3?ooool00ol0003oooooooooo`0:ooooo`003oooool5o`0000Wooooo0ol0000;ooooo`;o00003?oo
ool2o`0000gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`Co00002ooo
ool3o`0000cooooo00?o0000ooooooooool02oooool00ol0003oooooo`000002o`0000cooooo00?o
0000ooooooooool03?ooool2o`0000cooooo0ol0000=ooooo`?o00005_ooool001Cooooo1Ol00007
ooooo`Ko00001oooool2o`0000cooooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool3o`0000_ooooo1?l0000<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooool000000_l0000<ooooo`03o`000?oooooooooo00gooooo0_l0000=ooooo`;o00003_ooool4
o`000003ooooool0003o000000oooooo000Fooooo`Go00002Oooool4o`0000Oooooo0ol000000ooo
oooo0000ooooo`08ooooo`;o00002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo1?l0000:ooooo`Co00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo0000
00;o00003?ooool00ol0003oooooooooo`0>ooooo`;o00003Oooool2o`0000;ooooo00?o0000oooo
ooooool02oooool4o`0000kooooo000Eooooo`?o00003?ooool5o`0000Wooooo0ol0000:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`Co
00002Oooool00ol0003oooooo`000002o`0000cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooo`000002o`0000cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`Co
00003?ooool5o`0000gooooo000booooo`Co00002_ooool3o`0000Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo0000o`0000Wooooo00?o0000ooooool0
00000_l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000000_l0000<ooooo`03
o`000?oooooooooo00oooooo0_l0000=ooooo`Co00007Oooool003Gooooo0_l00009ooooo`Co0000
2Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00[ooooo1?l00008ooooo`03o`00
0?oooooo000000?o00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000;o0000
3?ooool00ol0003oooooo`00000=ooooo`Go00003_ooool2o`0001cooooo0013ooooo`;o00002Ooo
ool2o`0000[ooooo00?o0000ooooooooool02_ooool3o`0000Sooooo00?o0000ooooooooool00ol0
000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00ol0000<ooooo`;o00004Ooo
ool2o`0002_ooooo001>ooooo`?o00002_ooool2o`0000[ooooo1?l00007ooooo`03o`000?oooooo
oooo00?o00003Oooool00ol0003oooooooooo`0=ooooo`Ko00002oooool3o`0003gooooo001@oooo
o`03o`000?oooooooooo00Oooooo0ol0000;ooooo`?o00001oooool2o`0000;ooooo0ol0000=oooo
o`;o00003Oooool3o`000004ooooool0003o0000o`0000cooooo00?o0000ooooooooool0>oooool0
057ooooo00?o0000ooooooooool02?ooool2o`0000Wooooo1Ol00006ooooo`04o`000?oooooooooo
ooooo`?o00003?ooool3o`0000oooooo0_l000001?oooooo0000o`000?l0000<ooooo`03o`000?oo
oooooooo03[ooooo001Mooooo`03o`000?oooooooooo00Sooooo1?l00006ooooo`04o`000?oooooo
ooooooooo`Co00003?ooool2o`00013ooooo00?o0000ooooooooool00ol00018ooooo`00G_ooool0
0ol0003oooooooooo`08ooooo`?o00001_ooool00ol0003oooooooooo`02ooooo`?o00003Oooool2
o`00013ooooo00?o0000ooooooooool01?l00016ooooo`00J_ooool3o`0000Gooooo00?o0000oooo
ooooool00_ooool4o`0000gooooo00?o0000ooooooooool04_ooool4o`0004Gooooo001[ooooo`;o
00001Oooool00ol0003oooooooooo`03ooooo`?o00009?ooool3o`0004Cooooo000;ooooo`?o0000
3?ooool2o`0000gooooo0_l0000<ooooo`;o00003Oooool2o`0000gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`;o0000
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo1Ol0000:ooooo`;o0000
3?ooool2o`0000gooooo0_l0000=ooooo`03o`000?oooooooooo00[ooooo000>ooooo`?o00002ooo
ool3o`0000cooooo0_l0000<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0ol00004ooooo`;o00001Ooo
ool3o`0000Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`Co00002ooo
ool00ol0003oooooooooo`0;ooooo`?o00003?ooool3o`0001Oooooo000Aooooo`Co000000?ooooo
o`000?l000001oooool3o`0000_ooooo0_l0000;ooooo`;o00003Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool2o`0000Cooooo0_l00006
ooooo`;o00001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo1?l0000;
ooooo`;o00003_ooool2o`0000gooooo0ol0000Dooooo`005Oooool4o`0000Wooooo1?l00009oooo
o`?o00002_ooool2o`0000cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo0_l00004ooooo`;o00001_ooool3o`0000Gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0>ooooo`Co00003?ooool00ol0003oooooooooo`0=oooo
o`;o00003_ooool4o`00013ooooo000Eooooo`Go00002_ooool4o`0000[ooooo0ol00009ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Cooooo0ol00003ooooo`;o00001oooool2o`0000Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0>ooooo`Go00002oooool2o`0000oooooo0ol0000=ooooo`Co
00003_ooool002Oooooo0_l00009ooooo`Co00002Oooool3o`0000[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`03o`00
0?oooooo000000Kooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3oooool5o`0000cooooo0_l0000>ooooo`Co00003_ooool2o`0000gooooo000eooooo`;o00002_oo
ool2o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Cooooo0ol00002ooooo`03o`000?oooooo000000Oooooo0_l00006ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03oooool00ol0003oooooo`000002o`0000cooooo0_l0
000@ooooo`;o00007?ooool0043ooooo1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooo`000007
ooooo`;o00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooool000000ol00009ooooo`Co0000;Oooool004?ooooo0_l00008ooooo`?o00002_ooool2o`00
00[ooooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l000000ooooooo0000ooooo`05oooo
o`?o00001Oooool00ol0003oooooooooo`0>ooooo`;o00003_ooool3o`000003ooooool0003o0000
00;o00002oooool2o`0002cooooo001?ooooo`;o00002Oooool2o`0000_ooooo0ol00004ooooo`?o
000000Goooooo`000?ooooooooooo`000007ooooo`;o00001_ooool2o`0000gooooo0ol0000@oooo
o`;o00000_ooool3o`0003Sooooo001Aooooo`03o`000?oooooooooo00Oooooo0_l0000:ooooo`?o
00001Oooool2o`000004ooooool0003oooooooooo`?o00001Oooool3o`0000Cooooo0ol0000?oooo
o`;o00004Oooool00ol0003oooooooooo`03o`0003Oooooo001Looooo`03o`000?oooooooooo00So
oooo0ol00005ooooo`;o000000Coooooo`000?oooooooooo0ol00006ooooo`;o00001Oooool2o`00
013ooooo00?o0000ooooooooool04oooool4o`0003Gooooo001Mooooo`03o`000?oooooooooo00So
oooo0ol000001?lb<S;oc<c<ooooooooool4o`0000?ooooo0_l00006ooooo`?o00001Oooool2o`00
013ooooo00?o0000ooooooooool04oooool4o`0003Cooooo001Xooooo`05oa0@4?l0003oooooogMg
Molb<S800oooool3o`0000?ooooo0_l00007ooooo`;o00001_ooool00ol0003oooooooooo`0Voooo
o`Co0000<_ooool006cooooo00Co0000oooooooooooooooo0ol00004ooooo`03o`000?oooooooooo
00Gooooo0_l0000`ooooo`Co0000<Oooool000_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00onYZJWo
410@ooooo`02ooooo`Co00002oooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`00J_ooool00ol@413o0000
okZj^P1iooooo`00Joooool00onj^[[o8B4Qooooo`1hooooo`00J?ooool01Ol@413oV9RHoooooonj
^[[o000007Wooooo000Gooooo`04oa0@4?l0003o0000o`0004gooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@1iooooo`006?ooool00ol0003oooooooooo`3;ooooo`006?ooool00ol0003oooooooooo`3;
ooooo`0000Go8B4Qo`000?l0003oA4A4omgMg@02ooooo`Go00000oooool01_o^k^koEEEEo`000?l0
003oEEEEonk^kP?ooooo00Wo0000ogMgMol0003o0000oeEEEOo^k^koooooonk^k_mEEED00_l00000
0om4A4Co^[Zjooooo`06ooooo`03oa0@4?l0003o000000;o000000Co410@oooooooooooooooo1Ol0
0002ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool5o`0000?ooooo00Ook^k^oeEEEOl0
003o0000oiRHV?l0003o410@00Kooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`04oa0@
4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000onHV9So0000oa0@4007oooo
o`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;o
oooo1Ol00004ooooo`06oiRHV?l0003o0000ogMgMol0003o410@0_ooool01OnHV9So0000o`000?m4
A4Co^[Zj00?ooooo1Ol00002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00GoIVIVo`000?l0003oA4A4olc<c003
ooooo`05oiRHV?l0003o0000ogMgMol000000_l@4105o`0000Gooooo00?o8B4Qoc8b<_ooool00ooo
ool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00?o410@oc8b<_l000000Ol000000005ohN7
QoooooooooooohN7QolQ8B401?ooool00ol0003oooooooooo`03ooooo`06oeEEEOmgMgOooooooooo
oomgMgOoEEEE0oooool03Ol0003oEEEEonk^k_ooooooMgMgoeEEEOooooooEEEEogMgMoooooook^k^
ogMgMol@41002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00KoEEEE
ogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo00?ooooo00KoEEEEogMgMooooooo
k^k^oeEEEOl00007ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00008ooooo`06o`000?nYZJWooooooooo
oonj^[[o00000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool0
1?ooool01Ol0003oZJVYoooooon7QhOo000000?ooooo00Go410@okZj^_o^k^koMgMgoa0@4005oooo
o`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`05o`000?oo
ooooooooooooool000001Oooool01_mVIVKoMgMgooooooooooooQhN7oa0@40?ooooo00Go0000ojVY
ZOooooooQhN7o`000003ooooo`03o`000?oooooooooo00Gooooo00CoV9RHoc8b<_l@413o^[Zj0ooo
ool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00?o0000ojVYZOooool00Oooool000?ooooo
00?ok^k^o`000?ooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Ko0000ooooooooooooooooo`000?o^k^h3ooooo`03o`000?oooooo000000kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00oooool01_l0003oooooooooooooooook^k^o`0000Oooooo00Go410@ohN7Qoooooook^k^
o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooooooooook^k^
o`0000Wooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05oooo
o`04oa0@4?nj^[[oV9RHoc8b<P?ooooo00?o0000ooooooooool01_ooool1okZj^P7oQhN70OmVIVH0
0005omgMgOnHV9SoMgMgoa0@4?mVIVH01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Ko0000ooooooooooooooooo`000?o^k^h3ooooo`03o`000?oooooo000000Go0000
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo1_l00004ooooo`03o`00
0?oooooooooo00?ooooo00Ko0000ooooooooooooooooonk^k_l00007ooooo`03okZj^_l@413o0000
00;o00001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^
k_l00008ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool01_nHV9So<S8boooooooooooo410@okZj^P;ooooo1_l00002ooooo`03oc8b<_lQ8B7oMgMg
007oMgMg00001?l@413oEEEEohN7Qonj^[X5ooooo`03o`000?oooooooooo00?ooooo00KoEEEEogMg
MoooooooooooogMgMomEEED3ooooo`0=o`000?mEEEGok^k^oooooomgMgOoIVIVoooooomEEEGoQhN7
onk^k_ooooooQhN7oc8b<P09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000ooooooooool00oooool01_mVIVKo
MgMgooooooo^k^koEEEEo`0000[ooooo00?oc<c<o`000?ooool00oooool01Ol0003oQhN7oooooonY
ZJWo000000;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00008ooooo`06o`000?nj^[[oooooonk^
k_mgMgOo00000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol0003oQhN7oooooonY
ZJWo000000Gooooo00KoIVIVogMgMoooooooooooohN7Qol00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003o<S8bomgMg@03ooooo`03onk^k_l0003ogMgM00;ooooo00[oV9RHoc8b
<_oooooooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool00ol0003o^[Zjooooo`01onk^kP00
00Gok^k^ooooooooooooc<c<o`000004ooooo`03o`000?oooooooooo00?ooooo00Kok^k^oeEEEOl0
003o0000oeEEEOo^k^h2ooooo`03oa0@4?l0003oMgMg00;o000000GoIVIVonk^k_ooooook^k^oeEE
E@02o`000003odA4A?o^k^kooooo00Kooooo00?o410@o`000?l000000ol00003ooooo`03oa0@4?l0
003o000000Cooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo00?o
oooo00Kok^k^oeEEEOl0003o410@olc<c?l00008ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o
410@o`000?mgMgL00_l000002OnHV9Soooooooooooo^k^koEEEEo`000?l@413oc<c<o`000008oooo
o`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCo
oooo00?o0000ooooooooool00oooool01?l@413o0000ooooooooool2o`000003ooooool@413o0000
00Co00001?ooool00ol@413o0000o`000004ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_oo
ool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00?ooooo00Kok^k^ofIVI_l0003o0000
odA4A?l00002ooooo`04oa0@4?l0003oooooooooo`;o00000_ooool2o`000006ojVYZOlQ8B7o0000
ob4Q8Ooooooo410@0_l00002ooooo`?o000000?oooooonk^k_mEEED00_l000001_m4A4Cok^k^oooo
ooooooooZJVYob4Q8@;o000000001On7QhOoooooonk^k_mVIVKo000000Cooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0Boooool00005odA4A?l0003o0000oc8b<_l@41001?ooool00ol0003oooooooooo`0Rooooo`03
oa0@4?nj^[[ooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0@Oooool000Oooooo00?o410@o`000?l00000
9?ooool01?nj^[[o410@o`000?l@4105ooooo`03oa0@4?oooooooooo00[ooooo00?o410@o`000?l0
00002Oooool2o`0001_ooooo0_l0000Hooooo`03oa0@4?l0003o000001Sooooo00?o410@oooooooo
ool0@Oooool00>Kooooo003Vooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 260.875}, {318.375, 135.375}} -> {-6.1967, \
1.77989, 0.0365857, 0.0365857}}]
}, Open  ]],

Cell["\<\
Compare this picture to the first one displayed in Section 1. \
\
\>", "Text"],

Cell[TextData[{
  StyleBox["Keep your eye on  f ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Bold"],
  StyleBox[" t , y",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" )",
    FontWeight->"Bold"],
  " "
}], "Text"],

Cell[TextData[{
  "In general most points (",
  StyleBox["t, y",
    FontSlant->"Italic"],
  ") in a direction field will have a locally unique solution curve passing \
through them.  \"Locally unique\" means the only solution through the point \
and lying within a small disc centered at ( ",
  StyleBox["t, y",
    FontSlant->"Italic"],
  ").  However, special attention must be  paid to \"bad points\" where \
either the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  " or its ",
  StyleBox["y",
    FontSlant->"Italic"],
  " partial derivative is discontinuous. The equation named DE2 in  Section \
1, and DE2 below, have lots of bad points (officially known as \
\"singularities\").  "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
DE2 = y'[t] == y[t]/(t^2 - 1)
u = 1; v = y/(t^2 - 1);
S=PlotVectorField[ {u,v}/Sqrt[u^2+v^2], {t,-3,3}, {y,-3,3}, Axes->True \
]\
\>", "Input",
  CellLabel->"In[157]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(y[t]\/\(\(-1\) + t\^2\)\)}]], "Output",
  CellLabel->"Out[157]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.06362 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.468254 0.148148 0.531808 0.148148 [
[.02381 .51931 -6 -9 ]
[.02381 .51931 6 0 ]
[.17196 .51931 -6 -9 ]
[.17196 .51931 6 0 ]
[.32011 .51931 -6 -9 ]
[.32011 .51931 6 0 ]
[.6164 .51931 -3 -9 ]
[.6164 .51931 3 0 ]
[.76455 .51931 -3 -9 ]
[.76455 .51931 3 0 ]
[.9127 .51931 -3 -9 ]
[.9127 .51931 3 0 ]
[.45575 .08736 -12 -4.5 ]
[.45575 .08736 0 4.5 ]
[.45575 .23551 -12 -4.5 ]
[.45575 .23551 0 4.5 ]
[.45575 .38366 -12 -4.5 ]
[.45575 .38366 0 4.5 ]
[.45575 .67996 -6 -4.5 ]
[.45575 .67996 0 4.5 ]
[.45575 .8281 -6 -4.5 ]
[.45575 .8281 0 4.5 ]
[.45575 .97625 -6 -4.5 ]
[.45575 .97625 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.06362 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .53181 m
.02381 .53806 L
s
[(-3)] .02381 .51931 0 1 Mshowa
.17196 .53181 m
.17196 .53806 L
s
[(-2)] .17196 .51931 0 1 Mshowa
.32011 .53181 m
.32011 .53806 L
s
[(-1)] .32011 .51931 0 1 Mshowa
.6164 .53181 m
.6164 .53806 L
s
[(1)] .6164 .51931 0 1 Mshowa
.76455 .53181 m
.76455 .53806 L
s
[(2)] .76455 .51931 0 1 Mshowa
.9127 .53181 m
.9127 .53806 L
s
[(3)] .9127 .51931 0 1 Mshowa
.125 Mabswid
.05344 .53181 m
.05344 .53556 L
s
.08307 .53181 m
.08307 .53556 L
s
.1127 .53181 m
.1127 .53556 L
s
.14233 .53181 m
.14233 .53556 L
s
.20159 .53181 m
.20159 .53556 L
s
.23122 .53181 m
.23122 .53556 L
s
.26085 .53181 m
.26085 .53556 L
s
.29048 .53181 m
.29048 .53556 L
s
.34974 .53181 m
.34974 .53556 L
s
.37937 .53181 m
.37937 .53556 L
s
.40899 .53181 m
.40899 .53556 L
s
.43862 .53181 m
.43862 .53556 L
s
.49788 .53181 m
.49788 .53556 L
s
.52751 .53181 m
.52751 .53556 L
s
.55714 .53181 m
.55714 .53556 L
s
.58677 .53181 m
.58677 .53556 L
s
.64603 .53181 m
.64603 .53556 L
s
.67566 .53181 m
.67566 .53556 L
s
.70529 .53181 m
.70529 .53556 L
s
.73492 .53181 m
.73492 .53556 L
s
.79418 .53181 m
.79418 .53556 L
s
.82381 .53181 m
.82381 .53556 L
s
.85344 .53181 m
.85344 .53556 L
s
.88307 .53181 m
.88307 .53556 L
s
.94233 .53181 m
.94233 .53556 L
s
.97196 .53181 m
.97196 .53556 L
s
.25 Mabswid
0 .53181 m
1 .53181 L
s
.46825 .08736 m
.4745 .08736 L
s
[(-3)] .45575 .08736 1 0 Mshowa
.46825 .23551 m
.4745 .23551 L
s
[(-2)] .45575 .23551 1 0 Mshowa
.46825 .38366 m
.4745 .38366 L
s
[(-1)] .45575 .38366 1 0 Mshowa
.46825 .67996 m
.4745 .67996 L
s
[(1)] .45575 .67996 1 0 Mshowa
.46825 .8281 m
.4745 .8281 L
s
[(2)] .45575 .8281 1 0 Mshowa
.46825 .97625 m
.4745 .97625 L
s
[(3)] .45575 .97625 1 0 Mshowa
.125 Mabswid
.46825 .11699 m
.472 .11699 L
s
.46825 .14662 m
.472 .14662 L
s
.46825 .17625 m
.472 .17625 L
s
.46825 .20588 m
.472 .20588 L
s
.46825 .26514 m
.472 .26514 L
s
.46825 .29477 m
.472 .29477 L
s
.46825 .3244 m
.472 .3244 L
s
.46825 .35403 m
.472 .35403 L
s
.46825 .41329 m
.472 .41329 L
s
.46825 .44292 m
.472 .44292 L
s
.46825 .47255 m
.472 .47255 L
s
.46825 .50218 m
.472 .50218 L
s
.46825 .56144 m
.472 .56144 L
s
.46825 .59107 m
.472 .59107 L
s
.46825 .6207 m
.472 .6207 L
s
.46825 .65033 m
.472 .65033 L
s
.46825 .70959 m
.472 .70959 L
s
.46825 .73922 m
.472 .73922 L
s
.46825 .76884 m
.472 .76884 L
s
.46825 .79847 m
.472 .79847 L
s
.46825 .85773 m
.472 .85773 L
s
.46825 .88736 m
.472 .88736 L
s
.46825 .91699 m
.472 .91699 L
s
.46825 .94662 m
.472 .94662 L
s
.46825 .05773 m
.472 .05773 L
s
.46825 .0281 m
.472 .0281 L
s
.46825 1.00588 m
.472 1.00588 L
s
.46825 1.03551 m
.472 1.03551 L
s
.25 Mabswid
.46825 0 m
.46825 1.06362 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
.02381 .08736 m
.08326 .06507 L
s
% Start of user PostScript
-3. -3. -2.59872 -3.15048 MAarrowhead1
% End of user PostScript
.02381 .15086 m
.08426 .13143 L
s
% Start of user PostScript
-3. -2.57143 -2.59199 -2.70258 MAarrowhead1
% End of user PostScript
.02381 .21435 m
.08514 .19792 L
s
% Start of user PostScript
-3. -2.14286 -2.58602 -2.25374 MAarrowhead1
% End of user PostScript
.02381 .27784 m
.08589 .26454 L
s
% Start of user PostScript
-3. -1.71429 -2.58094 -1.80408 MAarrowhead1
% End of user PostScript
.02381 .34133 m
.0865 .33126 L
s
% Start of user PostScript
-3. -1.28571 -2.57686 -1.35372 MAarrowhead1
% End of user PostScript
.02381 .40482 m
.08694 .39806 L
s
% Start of user PostScript
-3. -0.857143 -2.57387 -0.9028 MAarrowhead1
% End of user PostScript
.02381 .46832 m
.08721 .46492 L
s
% Start of user PostScript
-3. -0.428571 -2.57204 -0.451498 MAarrowhead1
% End of user PostScript
.02381 .53181 m
.0873 .53181 L
s
% Start of user PostScript
-3. 0 -2.57143 0 MAarrowhead1
% End of user PostScript
.02381 .5953 m
.08721 .5987 L
s
% Start of user PostScript
-3. 0.428571 -2.57204 0.451498 MAarrowhead1
% End of user PostScript
.02381 .65879 m
.08694 .66556 L
s
% Start of user PostScript
-3. 0.857143 -2.57387 0.9028 MAarrowhead1
% End of user PostScript
.02381 .72228 m
.0865 .73236 L
s
% Start of user PostScript
-3. 1.28571 -2.57686 1.35372 MAarrowhead1
% End of user PostScript
.02381 .78578 m
.08589 .79908 L
s
% Start of user PostScript
-3. 1.71429 -2.58094 1.80408 MAarrowhead1
% End of user PostScript
.02381 .84927 m
.08514 .8657 L
s
% Start of user PostScript
-3. 2.14286 -2.58602 2.25374 MAarrowhead1
% End of user PostScript
.02381 .91276 m
.08426 .93219 L
s
% Start of user PostScript
-3. 2.57143 -2.59199 2.70258 MAarrowhead1
% End of user PostScript
.02381 .97625 m
.08326 .99855 L
s
% Start of user PostScript
-3. 3. -2.59872 3.15048 MAarrowhead1
% End of user PostScript
.0873 .08736 m
.1433 .05743 L
s
% Start of user PostScript
-2.57143 -3. -2.19347 -3.20204 MAarrowhead1
% End of user PostScript
.0873 .15086 m
.14502 .12441 L
s
% Start of user PostScript
-2.57143 -2.57143 -2.18181 -2.74995 MAarrowhead1
% End of user PostScript
.0873 .21435 m
.14662 .1917 L
s
% Start of user PostScript
-2.57143 -2.14286 -2.17105 -2.29573 MAarrowhead1
% End of user PostScript
.0873 .27784 m
.14802 .25929 L
s
% Start of user PostScript
-2.57143 -1.71429 -2.16155 -1.83948 MAarrowhead1
% End of user PostScript
.0873 .34133 m
.14919 .32715 L
s
% Start of user PostScript
-2.57143 -1.28571 -2.15368 -1.38142 MAarrowhead1
% End of user PostScript
.0873 .40482 m
.15007 .39524 L
s
% Start of user PostScript
-2.57143 -0.857143 -2.14777 -0.921847 MAarrowhead1
% End of user PostScript
.0873 .46832 m
.15061 .46348 L
s
% Start of user PostScript
-2.57143 -0.428571 -2.1441 -0.461204 MAarrowhead1
% End of user PostScript
.0873 .53181 m
.15079 .53181 L
s
% Start of user PostScript
-2.57143 0 -2.14286 0 MAarrowhead1
% End of user PostScript
.0873 .5953 m
.15061 .60013 L
s
% Start of user PostScript
-2.57143 0.428571 -2.1441 0.461204 MAarrowhead1
% End of user PostScript
.0873 .65879 m
.15007 .66838 L
s
% Start of user PostScript
-2.57143 0.857143 -2.14777 0.921847 MAarrowhead1
% End of user PostScript
.0873 .72228 m
.14919 .73646 L
s
% Start of user PostScript
-2.57143 1.28571 -2.15368 1.38142 MAarrowhead1
% End of user PostScript
.0873 .78578 m
.14802 .80432 L
s
% Start of user PostScript
-2.57143 1.71429 -2.16155 1.83948 MAarrowhead1
% End of user PostScript
.0873 .84927 m
.14662 .87192 L
s
% Start of user PostScript
-2.57143 2.14286 -2.17105 2.29573 MAarrowhead1
% End of user PostScript
.0873 .91276 m
.14502 .93921 L
s
% Start of user PostScript
-2.57143 2.57143 -2.18181 2.74995 MAarrowhead1
% End of user PostScript
.0873 .97625 m
.1433 1.00618 L
s
% Start of user PostScript
-2.57143 3. -2.19347 3.20204 MAarrowhead1
% End of user PostScript
.15079 .08736 m
.19952 .04666 L
s
% Start of user PostScript
-2.14286 -3. -1.81393 -3.27473 MAarrowhead1
% End of user PostScript
.15079 .15086 m
.20242 .1139 L
s
% Start of user PostScript
-2.14286 -2.57143 -1.79438 -2.82091 MAarrowhead1
% End of user PostScript
.15079 .21435 m
.20532 .18182 L
s
% Start of user PostScript
-2.14286 -2.14286 -1.77481 -2.36243 MAarrowhead1
% End of user PostScript
.15079 .27784 m
.20809 .25049 L
s
% Start of user PostScript
-2.14286 -1.71429 -1.75608 -1.89888 MAarrowhead1
% End of user PostScript
.15079 .34133 m
.21057 .31993 L
s
% Start of user PostScript
-2.14286 -1.28571 -1.73936 -1.43015 MAarrowhead1
% End of user PostScript
.15079 .40482 m
.21255 .39009 L
s
% Start of user PostScript
-2.14286 -0.857143 -1.72599 -0.956622 MAarrowhead1
% End of user PostScript
.15079 .46832 m
.21384 .46079 L
s
% Start of user PostScript
-2.14286 -0.428571 -1.7173 -0.479348 MAarrowhead1
% End of user PostScript
.15079 .53181 m
.21429 .53181 L
s
% Start of user PostScript
-2.14286 0 -1.71429 0 MAarrowhead1
% End of user PostScript
.15079 .5953 m
.21384 .60282 L
s
% Start of user PostScript
-2.14286 0.428571 -1.7173 0.479348 MAarrowhead1
% End of user PostScript
.15079 .65879 m
.21255 .67353 L
s
% Start of user PostScript
-2.14286 0.857143 -1.72599 0.956622 MAarrowhead1
% End of user PostScript
.15079 .72228 m
.21057 .74368 L
s
% Start of user PostScript
-2.14286 1.28571 -1.73936 1.43015 MAarrowhead1
% End of user PostScript
.15079 .78578 m
.20809 .81312 L
s
% Start of user PostScript
-2.14286 1.71429 -1.75608 1.89888 MAarrowhead1
% End of user PostScript
.15079 .84927 m
.20532 .8818 L
s
% Start of user PostScript
-2.14286 2.14286 -1.77481 2.36243 MAarrowhead1
% End of user PostScript
.15079 .91276 m
.20242 .94972 L
s
% Start of user PostScript
-2.14286 2.57143 -1.79438 2.82091 MAarrowhead1
% End of user PostScript
.15079 .97625 m
.19952 1.01695 L
s
% Start of user PostScript
-2.14286 3. -1.81393 3.27473 MAarrowhead1
% End of user PostScript
.21429 .08736 m
.24875 .03404 L
s
% Start of user PostScript
-1.71429 -3. -1.48167 -3.35995 MAarrowhead1
% End of user PostScript
.21429 .15086 m
.25251 .10016 L
s
% Start of user PostScript
-1.71429 -2.57143 -1.45627 -2.91363 MAarrowhead1
% End of user PostScript
.21429 .21435 m
.25688 .16727 L
s
% Start of user PostScript
-1.71429 -2.14286 -1.42675 -2.46066 MAarrowhead1
% End of user PostScript
.21429 .27784 m
.26185 .23578 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.39322 -1.99817 MAarrowhead1
% End of user PostScript
.21429 .34133 m
.2672 .30624 L
s
% Start of user PostScript
-1.71429 -1.28571 -1.35712 -1.52257 MAarrowhead1
% End of user PostScript
.21429 .40482 m
.27236 .37915 L
s
% Start of user PostScript
-1.71429 -0.857143 -1.32231 -1.03044 MAarrowhead1
% End of user PostScript
.21429 .46832 m
.27628 .45461 L
s
% Start of user PostScript
-1.71429 -0.428571 -1.29582 -0.521075 MAarrowhead1
% End of user PostScript
.21429 .53181 m
.27778 .53181 L
s
% Start of user PostScript
-1.71429 0 -1.28571 0 MAarrowhead1
% End of user PostScript
.21429 .5953 m
.27628 .609 L
s
% Start of user PostScript
-1.71429 0.428571 -1.29582 0.521075 MAarrowhead1
% End of user PostScript
.21429 .65879 m
.27236 .68446 L
s
% Start of user PostScript
-1.71429 0.857143 -1.32231 1.03044 MAarrowhead1
% End of user PostScript
.21429 .72228 m
.2672 .75737 L
s
% Start of user PostScript
-1.71429 1.28571 -1.35712 1.52257 MAarrowhead1
% End of user PostScript
.21429 .78578 m
.26185 .82783 L
s
% Start of user PostScript
-1.71429 1.71429 -1.39322 1.99817 MAarrowhead1
% End of user PostScript
.21429 .84927 m
.25688 .89635 L
s
% Start of user PostScript
-1.71429 2.14286 -1.42675 2.46066 MAarrowhead1
% End of user PostScript
.21429 .91276 m
.25251 .96346 L
s
% Start of user PostScript
-1.71429 2.57143 -1.45627 2.91363 MAarrowhead1
% End of user PostScript
.21429 .97625 m
.24875 1.02958 L
s
% Start of user PostScript
-1.71429 3. -1.48167 3.35995 MAarrowhead1
% End of user PostScript
.27778 .08736 m
.29128 .02532 L
s
% Start of user PostScript
-1.28571 -3. -1.19455 -3.41876 MAarrowhead1
% End of user PostScript
.27778 .15086 m
.29341 .08932 L
s
% Start of user PostScript
-1.28571 -2.57143 -1.18022 -2.98681 MAarrowhead1
% End of user PostScript
.27778 .21435 m
.29629 .15361 L
s
% Start of user PostScript
-1.28571 -2.14286 -1.16078 -2.55281 MAarrowhead1
% End of user PostScript
.27778 .27784 m
.30038 .21851 L
s
% Start of user PostScript
-1.28571 -1.71429 -1.13314 -2.11478 MAarrowhead1
% End of user PostScript
.27778 .34133 m
.30653 .28472 L
s
% Start of user PostScript
-1.28571 -1.28571 -1.09163 -1.66782 MAarrowhead1
% End of user PostScript
.27778 .40482 m
.31626 .35432 L
s
% Start of user PostScript
-1.28571 -0.857143 -1.02598 -1.19804 MAarrowhead1
% End of user PostScript
.27778 .46832 m
.33086 .43348 L
s
% Start of user PostScript
-1.28571 -0.428571 -0.927408 -0.66371 MAarrowhead1
% End of user PostScript
.27778 .53181 m
.34127 .53181 L
s
% Start of user PostScript
-1.28571 0 -0.857143 0 MAarrowhead1
% End of user PostScript
.27778 .5953 m
.33086 .63014 L
s
% Start of user PostScript
-1.28571 0.428571 -0.927408 0.66371 MAarrowhead1
% End of user PostScript
.27778 .65879 m
.31626 .7093 L
s
% Start of user PostScript
-1.28571 0.857143 -1.02598 1.19804 MAarrowhead1
% End of user PostScript
.27778 .72228 m
.30653 .77889 L
s
% Start of user PostScript
-1.28571 1.28571 -1.09163 1.66782 MAarrowhead1
% End of user PostScript
.27778 .78578 m
.30038 .84511 L
s
% Start of user PostScript
-1.28571 1.71429 -1.13314 2.11478 MAarrowhead1
% End of user PostScript
.27778 .84927 m
.29629 .91 L
s
% Start of user PostScript
-1.28571 2.14286 -1.16078 2.55281 MAarrowhead1
% End of user PostScript
.27778 .91276 m
.29341 .9743 L
s
% Start of user PostScript
-1.28571 2.57143 -1.18022 2.98681 MAarrowhead1
% End of user PostScript
.27778 .97625 m
.29128 1.03829 L
s
% Start of user PostScript
-1.28571 3. -1.19455 3.41876 MAarrowhead1
% End of user PostScript
.34127 .08736 m
.34686 .15061 L
s
% Start of user PostScript
-0.857143 -3. -0.819389 -2.57309 MAarrowhead1
% End of user PostScript
.34127 .15086 m
.34779 .21401 L
s
% Start of user PostScript
-0.857143 -2.57143 -0.813159 -2.14512 MAarrowhead1
% End of user PostScript
.34127 .21435 m
.34907 .27736 L
s
% Start of user PostScript
-0.857143 -2.14286 -0.804484 -1.71753 MAarrowhead1
% End of user PostScript
.34127 .27784 m
.35098 .34058 L
s
% Start of user PostScript
-0.857143 -1.71429 -0.791597 -1.29076 MAarrowhead1
% End of user PostScript
.34127 .34133 m
.3541 .40351 L
s
% Start of user PostScript
-0.857143 -1.28571 -0.770532 -0.865986 MAarrowhead1
% End of user PostScript
.34127 .40482 m
.36004 .46548 L
s
% Start of user PostScript
-0.857143 -0.857143 -0.730421 -0.447735 MAarrowhead1
% End of user PostScript
.34127 .46832 m
.37469 .5223 L
s
% Start of user PostScript
-0.857143 -0.428571 -0.631562 -0.0641721 MAarrowhead1
% End of user PostScript
.34127 .53181 m
.40476 .53181 L
s
% Start of user PostScript
-0.857143 0 -0.428571 0 MAarrowhead1
% End of user PostScript
.34127 .5953 m
.37469 .54131 L
s
% Start of user PostScript
-0.857143 0.428571 -0.631562 0.0641721 MAarrowhead1
% End of user PostScript
.34127 .65879 m
.36004 .59814 L
s
% Start of user PostScript
-0.857143 0.857143 -0.730421 0.447735 MAarrowhead1
% End of user PostScript
.34127 .72228 m
.3541 .6601 L
s
% Start of user PostScript
-0.857143 1.28571 -0.770532 0.865986 MAarrowhead1
% End of user PostScript
.34127 .78578 m
.35098 .72303 L
s
% Start of user PostScript
-0.857143 1.71429 -0.791597 1.29076 MAarrowhead1
% End of user PostScript
.34127 .84927 m
.34907 .78626 L
s
% Start of user PostScript
-0.857143 2.14286 -0.804484 1.71753 MAarrowhead1
% End of user PostScript
.34127 .91276 m
.34779 .8496 L
s
% Start of user PostScript
-0.857143 2.57143 -0.813159 2.14512 MAarrowhead1
% End of user PostScript
.34127 .97625 m
.34686 .91301 L
s
% Start of user PostScript
-0.857143 3. -0.819389 2.57309 MAarrowhead1
% End of user PostScript
.40476 .08736 m
.42143 .14863 L
s
% Start of user PostScript
-0.428571 -3. -0.316045 -2.58646 MAarrowhead1
% End of user PostScript
.40476 .15086 m
.42397 .21137 L
s
% Start of user PostScript
-0.428571 -2.57143 -0.298895 -2.16295 MAarrowhead1
% End of user PostScript
.40476 .21435 m
.42736 .27368 L
s
% Start of user PostScript
-0.428571 -2.14286 -0.276002 -1.74236 MAarrowhead1
% End of user PostScript
.40476 .27784 m
.43206 .33516 L
s
% Start of user PostScript
-0.428571 -1.71429 -0.244314 -1.32735 MAarrowhead1
% End of user PostScript
.40476 .34133 m
.43879 .39493 L
s
% Start of user PostScript
-0.428571 -1.28571 -0.198854 -0.923909 MAarrowhead1
% End of user PostScript
.40476 .40482 m
.44855 .4508 L
s
% Start of user PostScript
-0.428571 -0.857143 -0.133005 -0.546798 MAarrowhead1
% End of user PostScript
.40476 .46832 m
.46098 .49783 L
s
% Start of user PostScript
-0.428571 -0.428571 -0.0491152 -0.229357 MAarrowhead1
% End of user PostScript
.40476 .53181 m
.46825 .53181 L
s
% Start of user PostScript
-0.428571 0 0 0 MAarrowhead1
% End of user PostScript
.40476 .5953 m
.46098 .56579 L
s
% Start of user PostScript
-0.428571 0.428571 -0.0491152 0.229357 MAarrowhead1
% End of user PostScript
.40476 .65879 m
.44855 .61281 L
s
% Start of user PostScript
-0.428571 0.857143 -0.133005 0.546798 MAarrowhead1
% End of user PostScript
.40476 .72228 m
.43879 .66868 L
s
% Start of user PostScript
-0.428571 1.28571 -0.198854 0.923909 MAarrowhead1
% End of user PostScript
.40476 .78578 m
.43206 .72845 L
s
% Start of user PostScript
-0.428571 1.71429 -0.244314 1.32735 MAarrowhead1
% End of user PostScript
.40476 .84927 m
.42736 .78994 L
s
% Start of user PostScript
-0.428571 2.14286 -0.276002 1.74236 MAarrowhead1
% End of user PostScript
.40476 .91276 m
.42397 .85224 L
s
% Start of user PostScript
-0.428571 2.57143 -0.298895 2.16295 MAarrowhead1
% End of user PostScript
.40476 .97625 m
.42143 .91499 L
s
% Start of user PostScript
-0.428571 3. -0.316045 2.58646 MAarrowhead1
% End of user PostScript
.46825 .08736 m
.48833 .1476 L
s
% Start of user PostScript
0 -3. 0.135526 -2.59342 MAarrowhead1
% End of user PostScript
.46825 .15086 m
.49127 .21003 L
s
% Start of user PostScript
0 -2.57143 0.155334 -2.172 MAarrowhead1
% End of user PostScript
.46825 .21435 m
.4951 .27188 L
s
% Start of user PostScript
0 -2.14286 0.181237 -1.75449 MAarrowhead1
% End of user PostScript
.46825 .27784 m
.50025 .33268 L
s
% Start of user PostScript
0 -1.71429 0.215945 -1.34409 MAarrowhead1
% End of user PostScript
.46825 .34133 m
.50723 .39145 L
s
% Start of user PostScript
0 -1.28571 0.263117 -0.94742 MAarrowhead1
% End of user PostScript
.46825 .40482 m
.51646 .44614 L
s
% Start of user PostScript
0 -0.857143 0.325396 -0.578232 MAarrowhead1
% End of user PostScript
.46825 .46832 m
.52661 .49333 L
s
% Start of user PostScript
0 -0.428571 0.393919 -0.259749 MAarrowhead1
% End of user PostScript
.46825 .53181 m
.53175 .53181 L
s
% Start of user PostScript
0 0 0.428571 0 MAarrowhead1
% End of user PostScript
.46825 .5953 m
.52661 .57029 L
s
% Start of user PostScript
0 0.428571 0.393919 0.259749 MAarrowhead1
% End of user PostScript
.46825 .65879 m
.51646 .61747 L
s
% Start of user PostScript
0 0.857143 0.325396 0.578232 MAarrowhead1
% End of user PostScript
.46825 .72228 m
.50723 .67217 L
s
% Start of user PostScript
0 1.28571 0.263117 0.94742 MAarrowhead1
% End of user PostScript
.46825 .78578 m
.50025 .73093 L
s
% Start of user PostScript
0 1.71429 0.215945 1.34409 MAarrowhead1
% End of user PostScript
.46825 .84927 m
.4951 .79173 L
s
% Start of user PostScript
0 2.14286 0.181237 1.75449 MAarrowhead1
% End of user PostScript
.46825 .91276 m
.49127 .85359 L
s
% Start of user PostScript
0 2.57143 0.155334 2.172 MAarrowhead1
% End of user PostScript
.46825 .97625 m
.48833 .91602 L
s
% Start of user PostScript
0 3. 0.135526 2.59342 MAarrowhead1
% End of user PostScript
.53175 .08736 m
.54842 .14863 L
s
% Start of user PostScript
0.428571 -3. 0.541098 -2.58646 MAarrowhead1
% End of user PostScript
.53175 .15086 m
.55096 .21137 L
s
% Start of user PostScript
0.428571 -2.57143 0.558248 -2.16295 MAarrowhead1
% End of user PostScript
.53175 .21435 m
.55435 .27368 L
s
% Start of user PostScript
0.428571 -2.14286 0.581141 -1.74236 MAarrowhead1
% End of user PostScript
.53175 .27784 m
.55904 .33516 L
s
% Start of user PostScript
0.428571 -1.71429 0.612829 -1.32735 MAarrowhead1
% End of user PostScript
.53175 .34133 m
.56578 .39493 L
s
% Start of user PostScript
0.428571 -1.28571 0.658289 -0.923909 MAarrowhead1
% End of user PostScript
.53175 .40482 m
.57553 .4508 L
s
% Start of user PostScript
0.428571 -0.857143 0.724138 -0.546798 MAarrowhead1
% End of user PostScript
.53175 .46832 m
.58796 .49783 L
s
% Start of user PostScript
0.428571 -0.428571 0.808028 -0.229357 MAarrowhead1
% End of user PostScript
.53175 .53181 m
.59524 .53181 L
s
% Start of user PostScript
0.428571 0 0.857143 0 MAarrowhead1
% End of user PostScript
.53175 .5953 m
.58796 .56579 L
s
% Start of user PostScript
0.428571 0.428571 0.808028 0.229357 MAarrowhead1
% End of user PostScript
.53175 .65879 m
.57553 .61281 L
s
% Start of user PostScript
0.428571 0.857143 0.724138 0.546798 MAarrowhead1
% End of user PostScript
.53175 .72228 m
.56578 .66868 L
s
% Start of user PostScript
0.428571 1.28571 0.658289 0.923909 MAarrowhead1
% End of user PostScript
.53175 .78578 m
.55904 .72845 L
s
% Start of user PostScript
0.428571 1.71429 0.612829 1.32735 MAarrowhead1
% End of user PostScript
.53175 .84927 m
.55435 .78994 L
s
% Start of user PostScript
0.428571 2.14286 0.581141 1.74236 MAarrowhead1
% End of user PostScript
.53175 .91276 m
.55096 .85224 L
s
% Start of user PostScript
0.428571 2.57143 0.558248 2.16295 MAarrowhead1
% End of user PostScript
.53175 .97625 m
.54842 .91499 L
s
% Start of user PostScript
0.428571 3. 0.541098 2.58646 MAarrowhead1
% End of user PostScript
.59524 .08736 m
.60083 .15061 L
s
% Start of user PostScript
0.857143 -3. 0.894896 -2.57309 MAarrowhead1
% End of user PostScript
.59524 .15086 m
.60175 .21401 L
s
% Start of user PostScript
0.857143 -2.57143 0.901127 -2.14512 MAarrowhead1
% End of user PostScript
.59524 .21435 m
.60304 .27736 L
s
% Start of user PostScript
0.857143 -2.14286 0.909802 -1.71753 MAarrowhead1
% End of user PostScript
.59524 .27784 m
.60495 .34058 L
s
% Start of user PostScript
0.857143 -1.71429 0.922689 -1.29076 MAarrowhead1
% End of user PostScript
.59524 .34133 m
.60807 .40351 L
s
% Start of user PostScript
0.857143 -1.28571 0.943754 -0.865986 MAarrowhead1
% End of user PostScript
.59524 .40482 m
.61401 .46548 L
s
% Start of user PostScript
0.857143 -0.857143 0.983864 -0.447735 MAarrowhead1
% End of user PostScript
.59524 .46832 m
.62866 .5223 L
s
% Start of user PostScript
0.857143 -0.428571 1.08272 -0.0641721 MAarrowhead1
% End of user PostScript
.59524 .53181 m
.65873 .53181 L
s
% Start of user PostScript
0.857143 0 1.28571 0 MAarrowhead1
% End of user PostScript
.59524 .5953 m
.62866 .54131 L
s
% Start of user PostScript
0.857143 0.428571 1.08272 0.0641721 MAarrowhead1
% End of user PostScript
.59524 .65879 m
.61401 .59814 L
s
% Start of user PostScript
0.857143 0.857143 0.983864 0.447735 MAarrowhead1
% End of user PostScript
.59524 .72228 m
.60807 .6601 L
s
% Start of user PostScript
0.857143 1.28571 0.943754 0.865986 MAarrowhead1
% End of user PostScript
.59524 .78578 m
.60495 .72303 L
s
% Start of user PostScript
0.857143 1.71429 0.922689 1.29076 MAarrowhead1
% End of user PostScript
.59524 .84927 m
.60304 .78626 L
s
% Start of user PostScript
0.857143 2.14286 0.909802 1.71753 MAarrowhead1
% End of user PostScript
.59524 .91276 m
.60175 .8496 L
s
% Start of user PostScript
0.857143 2.57143 0.901127 2.14512 MAarrowhead1
% End of user PostScript
.59524 .97625 m
.60083 .91301 L
s
% Start of user PostScript
0.857143 3. 0.894896 2.57309 MAarrowhead1
% End of user PostScript
.65873 .08736 m
.67224 .02532 L
s
% Start of user PostScript
1.28571 -3. 1.37687 -3.41876 MAarrowhead1
% End of user PostScript
.65873 .15086 m
.67436 .08932 L
s
% Start of user PostScript
1.28571 -2.57143 1.39121 -2.98681 MAarrowhead1
% End of user PostScript
.65873 .21435 m
.67724 .15361 L
s
% Start of user PostScript
1.28571 -2.14286 1.41065 -2.55281 MAarrowhead1
% End of user PostScript
.65873 .27784 m
.68133 .21851 L
s
% Start of user PostScript
1.28571 -1.71429 1.43828 -2.11478 MAarrowhead1
% End of user PostScript
.65873 .34133 m
.68748 .28472 L
s
% Start of user PostScript
1.28571 -1.28571 1.4798 -1.66782 MAarrowhead1
% End of user PostScript
.65873 .40482 m
.69721 .35432 L
s
% Start of user PostScript
1.28571 -0.857143 1.54545 -1.19804 MAarrowhead1
% End of user PostScript
.65873 .46832 m
.71181 .43348 L
s
% Start of user PostScript
1.28571 -0.428571 1.64402 -0.66371 MAarrowhead1
% End of user PostScript
.65873 .53181 m
.72222 .53181 L
s
% Start of user PostScript
1.28571 0 1.71429 0 MAarrowhead1
% End of user PostScript
.65873 .5953 m
.71181 .63014 L
s
% Start of user PostScript
1.28571 0.428571 1.64402 0.66371 MAarrowhead1
% End of user PostScript
.65873 .65879 m
.69721 .7093 L
s
% Start of user PostScript
1.28571 0.857143 1.54545 1.19804 MAarrowhead1
% End of user PostScript
.65873 .72228 m
.68748 .77889 L
s
% Start of user PostScript
1.28571 1.28571 1.4798 1.66782 MAarrowhead1
% End of user PostScript
.65873 .78578 m
.68133 .84511 L
s
% Start of user PostScript
1.28571 1.71429 1.43828 2.11478 MAarrowhead1
% End of user PostScript
.65873 .84927 m
.67724 .91 L
s
% Start of user PostScript
1.28571 2.14286 1.41065 2.55281 MAarrowhead1
% End of user PostScript
.65873 .91276 m
.67436 .9743 L
s
% Start of user PostScript
1.28571 2.57143 1.39121 2.98681 MAarrowhead1
% End of user PostScript
.65873 .97625 m
.67224 1.03829 L
s
% Start of user PostScript
1.28571 3. 1.37687 3.41876 MAarrowhead1
% End of user PostScript
.72222 .08736 m
.75668 .03404 L
s
% Start of user PostScript
1.71429 -3. 1.9469 -3.35995 MAarrowhead1
% End of user PostScript
.72222 .15086 m
.76045 .10016 L
s
% Start of user PostScript
1.71429 -2.57143 1.9723 -2.91363 MAarrowhead1
% End of user PostScript
.72222 .21435 m
.76482 .16727 L
s
% Start of user PostScript
1.71429 -2.14286 2.00182 -2.46066 MAarrowhead1
% End of user PostScript
.72222 .27784 m
.76979 .23578 L
s
% Start of user PostScript
1.71429 -1.71429 2.03535 -1.99817 MAarrowhead1
% End of user PostScript
.72222 .34133 m
.77514 .30624 L
s
% Start of user PostScript
1.71429 -1.28571 2.07146 -1.52257 MAarrowhead1
% End of user PostScript
.72222 .40482 m
.78029 .37915 L
s
% Start of user PostScript
1.71429 -0.857143 2.10626 -1.03044 MAarrowhead1
% End of user PostScript
.72222 .46832 m
.78422 .45461 L
s
% Start of user PostScript
1.71429 -0.428571 2.13275 -0.521075 MAarrowhead1
% End of user PostScript
.72222 .53181 m
.78571 .53181 L
s
% Start of user PostScript
1.71429 0 2.14286 0 MAarrowhead1
% End of user PostScript
.72222 .5953 m
.78422 .609 L
s
% Start of user PostScript
1.71429 0.428571 2.13275 0.521075 MAarrowhead1
% End of user PostScript
.72222 .65879 m
.78029 .68446 L
s
% Start of user PostScript
1.71429 0.857143 2.10626 1.03044 MAarrowhead1
% End of user PostScript
.72222 .72228 m
.77514 .75737 L
s
% Start of user PostScript
1.71429 1.28571 2.07146 1.52257 MAarrowhead1
% End of user PostScript
.72222 .78578 m
.76979 .82783 L
s
% Start of user PostScript
1.71429 1.71429 2.03535 1.99817 MAarrowhead1
% End of user PostScript
.72222 .84927 m
.76482 .89635 L
s
% Start of user PostScript
1.71429 2.14286 2.00182 2.46066 MAarrowhead1
% End of user PostScript
.72222 .91276 m
.76045 .96346 L
s
% Start of user PostScript
1.71429 2.57143 1.9723 2.91363 MAarrowhead1
% End of user PostScript
.72222 .97625 m
.75668 1.02958 L
s
% Start of user PostScript
1.71429 3. 1.9469 3.35995 MAarrowhead1
% End of user PostScript
.78571 .08736 m
.83444 .04666 L
s
% Start of user PostScript
2.14286 -3. 2.47179 -3.27473 MAarrowhead1
% End of user PostScript
.78571 .15086 m
.83734 .1139 L
s
% Start of user PostScript
2.14286 -2.57143 2.49133 -2.82091 MAarrowhead1
% End of user PostScript
.78571 .21435 m
.84024 .18182 L
s
% Start of user PostScript
2.14286 -2.14286 2.51091 -2.36243 MAarrowhead1
% End of user PostScript
.78571 .27784 m
.84301 .25049 L
s
% Start of user PostScript
2.14286 -1.71429 2.52963 -1.89888 MAarrowhead1
% End of user PostScript
.78571 .34133 m
.84549 .31993 L
s
% Start of user PostScript
2.14286 -1.28571 2.54636 -1.43015 MAarrowhead1
% End of user PostScript
.78571 .40482 m
.84747 .39009 L
s
% Start of user PostScript
2.14286 -0.857143 2.55972 -0.956622 MAarrowhead1
% End of user PostScript
.78571 .46832 m
.84876 .46079 L
s
% Start of user PostScript
2.14286 -0.428571 2.56841 -0.479348 MAarrowhead1
% End of user PostScript
.78571 .53181 m
.84921 .53181 L
s
% Start of user PostScript
2.14286 0 2.57143 0 MAarrowhead1
% End of user PostScript
.78571 .5953 m
.84876 .60282 L
s
% Start of user PostScript
2.14286 0.428571 2.56841 0.479348 MAarrowhead1
% End of user PostScript
.78571 .65879 m
.84747 .67353 L
s
% Start of user PostScript
2.14286 0.857143 2.55972 0.956622 MAarrowhead1
% End of user PostScript
.78571 .72228 m
.84549 .74368 L
s
% Start of user PostScript
2.14286 1.28571 2.54636 1.43015 MAarrowhead1
% End of user PostScript
.78571 .78578 m
.84301 .81312 L
s
% Start of user PostScript
2.14286 1.71429 2.52963 1.89888 MAarrowhead1
% End of user PostScript
.78571 .84927 m
.84024 .8818 L
s
% Start of user PostScript
2.14286 2.14286 2.51091 2.36243 MAarrowhead1
% End of user PostScript
.78571 .91276 m
.83734 .94972 L
s
% Start of user PostScript
2.14286 2.57143 2.49133 2.82091 MAarrowhead1
% End of user PostScript
.78571 .97625 m
.83444 1.01695 L
s
% Start of user PostScript
2.14286 3. 2.47179 3.27473 MAarrowhead1
% End of user PostScript
.84921 .08736 m
.9052 .05743 L
s
% Start of user PostScript
2.57143 -3. 2.94939 -3.20204 MAarrowhead1
% End of user PostScript
.84921 .15086 m
.90693 .12441 L
s
% Start of user PostScript
2.57143 -2.57143 2.96105 -2.74995 MAarrowhead1
% End of user PostScript
.84921 .21435 m
.90852 .1917 L
s
% Start of user PostScript
2.57143 -2.14286 2.97181 -2.29573 MAarrowhead1
% End of user PostScript
.84921 .27784 m
.90993 .25929 L
s
% Start of user PostScript
2.57143 -1.71429 2.98131 -1.83948 MAarrowhead1
% End of user PostScript
.84921 .34133 m
.9111 .32715 L
s
% Start of user PostScript
2.57143 -1.28571 2.98918 -1.38142 MAarrowhead1
% End of user PostScript
.84921 .40482 m
.91197 .39524 L
s
% Start of user PostScript
2.57143 -0.857143 2.99509 -0.921847 MAarrowhead1
% End of user PostScript
.84921 .46832 m
.91251 .46348 L
s
% Start of user PostScript
2.57143 -0.428571 2.99876 -0.461204 MAarrowhead1
% End of user PostScript
.84921 .53181 m
.9127 .53181 L
s
% Start of user PostScript
2.57143 0 3. 0 MAarrowhead1
% End of user PostScript
.84921 .5953 m
.91251 .60013 L
s
% Start of user PostScript
2.57143 0.428571 2.99876 0.461204 MAarrowhead1
% End of user PostScript
.84921 .65879 m
.91197 .66838 L
s
% Start of user PostScript
2.57143 0.857143 2.99509 0.921847 MAarrowhead1
% End of user PostScript
.84921 .72228 m
.9111 .73646 L
s
% Start of user PostScript
2.57143 1.28571 2.98918 1.38142 MAarrowhead1
% End of user PostScript
.84921 .78578 m
.90993 .80432 L
s
% Start of user PostScript
2.57143 1.71429 2.98131 1.83948 MAarrowhead1
% End of user PostScript
.84921 .84927 m
.90852 .87192 L
s
% Start of user PostScript
2.57143 2.14286 2.97181 2.29573 MAarrowhead1
% End of user PostScript
.84921 .91276 m
.90693 .93921 L
s
% Start of user PostScript
2.57143 2.57143 2.96105 2.74995 MAarrowhead1
% End of user PostScript
.84921 .97625 m
.9052 1.00618 L
s
% Start of user PostScript
2.57143 3. 2.94939 3.20204 MAarrowhead1
% End of user PostScript
.9127 .08736 m
.97215 .06507 L
s
% Start of user PostScript
3. -3. 3.40128 -3.15048 MAarrowhead1
% End of user PostScript
.9127 .15086 m
.97314 .13143 L
s
% Start of user PostScript
3. -2.57143 3.40801 -2.70258 MAarrowhead1
% End of user PostScript
.9127 .21435 m
.97403 .19792 L
s
% Start of user PostScript
3. -2.14286 3.41398 -2.25374 MAarrowhead1
% End of user PostScript
.9127 .27784 m
.97478 .26454 L
s
% Start of user PostScript
3. -1.71429 3.41906 -1.80408 MAarrowhead1
% End of user PostScript
.9127 .34133 m
.97539 .33126 L
s
% Start of user PostScript
3. -1.28571 3.42314 -1.35372 MAarrowhead1
% End of user PostScript
.9127 .40482 m
.97583 .39806 L
s
% Start of user PostScript
3. -0.857143 3.42613 -0.9028 MAarrowhead1
% End of user PostScript
.9127 .46832 m
.9761 .46492 L
s
% Start of user PostScript
3. -0.428571 3.42796 -0.451498 MAarrowhead1
% End of user PostScript
.9127 .53181 m
.97619 .53181 L
s
% Start of user PostScript
3. 0 3.42857 0 MAarrowhead1
% End of user PostScript
.9127 .5953 m
.9761 .5987 L
s
% Start of user PostScript
3. 0.428571 3.42796 0.451498 MAarrowhead1
% End of user PostScript
.9127 .65879 m
.97583 .66556 L
s
% Start of user PostScript
3. 0.857143 3.42613 0.9028 MAarrowhead1
% End of user PostScript
.9127 .72228 m
.97539 .73236 L
s
% Start of user PostScript
3. 1.28571 3.42314 1.35372 MAarrowhead1
% End of user PostScript
.9127 .78578 m
.97478 .79908 L
s
% Start of user PostScript
3. 1.71429 3.41906 1.80408 MAarrowhead1
% End of user PostScript
.9127 .84927 m
.97403 .8657 L
s
% Start of user PostScript
3. 2.14286 3.41398 2.25374 MAarrowhead1
% End of user PostScript
.9127 .91276 m
.97314 .93219 L
s
% Start of user PostScript
3. 2.57143 3.40801 2.70258 MAarrowhead1
% End of user PostScript
.9127 .97625 m
.97215 .99855 L
s
% Start of user PostScript
3. 3. 3.40128 3.15048 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1.06362 L
0 1.06362 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[157]:=",
  ImageSize->{182.75, 194.375},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002f0000`R000`400?l00000o`00003o]_ooool0
05Kooooo00?o0000ooooooooool0GOooool005Kooooo00?o0000ooooooooool0GOooool005Kooooo
00?o0000ooooooooool0GOooool005Kooooo00?o0000ooooooooool0GOooool005Kooooo00?o0000
ooooooooool0GOooool003Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03Wooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0:_ooool002gooooo0_l00006ooooo`;o00007oooool00ol0003oooooooooo`0Pooooo`;o0000
3_ooool00ol0003oooooooooo`0Zooooo`009?ooool2o`0000Kooooo0ol00005ooooo`?o00007ooo
ool00ol0003oooooooooo`0Pooooo`;o00003Oooool2o`0000cooooo0_l0000Nooooo`008oooool3
o`0000Gooooo0ol00007ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0;ooooo`;o00003?ooool3o`0001kooooo000Iooooo`?o00001_ooool3o`00
00Oooooo0_l00007ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0;ooooo`;o00002oooool3o`0000cooooo0_l0000Aooooo`005oooool4o`0000Ko
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo0_l0000;ooooo`?o00004_ooool000gooooo1?l00006ooooo`?o00001_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`?o00002_ooool4o`0000Gooooo000<ooooo`?o00001_ooool2o`000003ooooool0
003ooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Oooooo0ol00005ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000oooo
o`09ooooo`?o00001oooool000[ooooo0_l000000ooooooo0000ooooo`04ooooo`;o00002Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool2o`0000cooooo0_l0
00000ooooooo0000ooooo`07ooooo`001oooool3o`0000Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool5
o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo0ol0000<ooooo`001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool2
o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03Oooool003Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0hooooo`00;_ooool2o`0000Gooooo0_l00008ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool2
o`0002_ooooo000]ooooo`?o00001?ooool3o`0000Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`03o`0000Gooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool3o`0000cooooo0ol0000[ooooo`00;?ooool3o`0000Kooooo0_l00008ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool2o`0000[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0;ooooo`;o00002oooool4o`0002_ooooo000Tooooo`?o0000
1Oooool3o`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`;o00003?ooool3o`0001gooooo000Jooooo`;o00001_oo
ool3o`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000002_oo
ool4o`0000_ooooo0_l0000Aooooo`006?ooool3o`0000Oooooo0_l00007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`;o00002?ooool0
1?l0003oooooo`000?l00009ooooo`;o00002?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool3o`0000[ooooo1?l0000Aooooo`003Oooool4
o`0000Gooooo1?l00006ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo0ol0000:ooooo`?o00002?ooool4o`0000Sooooo0ol00007ooooo`?o00002_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool5
o`0000Wooooo1?l00005ooooo`002oooool4o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo
00?ooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool3o`00
00[ooooo0ol00008ooooo`Co00002?ooool3o`0000Oooooo0ol0000:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool2o`0000[ooooo0_l00003ooooo`03o`000?oooooooooo
00Kooooo1?l00007ooooo`002?ooool3o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wo
oooo0_l0000;ooooo`;o00002?ooool01?l0003oooooo`000?l00009ooooo`;o00002?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`;o00002oooool3o`0000;ooooo00?o0000ooooooooool01_ooool000Ko
oooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l00009ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`;o00002_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`;o00003_ooool003Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>?ooool0
03Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0hooooo`00;_ooool2o`0000Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02oooool2o`0000kooooo0_l0000Zooooo`00;Oooool3o`0000Gooooo
0_l00008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool2o`0000[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`?o00003Oooool3o`0002[ooooo
000/ooooo`?o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`?o0000:oooool002Gooooo0_l00006
ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01oooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000M
ooooo`008oooool3o`0000Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo0_l00008ooooo`04o`000?oooooo0000o`0000Wooooo0_l00008
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:
ooooo`?o00007_ooool001Sooooo1Ol00005ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`;o00002oooool2o`0000Sooooo1?l00008oooo
o`?o00001oooool3o`0000[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`?o00002_ooool5o`00013ooooo000=ooooo`Go00001_ooool3o`0000Gooooo0_l00009ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool2o`0000_ooooo0_l00008ooooo`04
o`000?oooooo0000o`0000Sooooo0ol00007ooooo`?o00002_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool3o`0000Wooooo1Ol00004oooo
o`002oooool5o`0000Gooooo0ol000000ooooooo0000ooooo`03ooooo`;o00002_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`;o00001oooool00ol0003o
ooooooooo`02o`0000Sooooo0_l00008ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo0_l0000;ooooo`?o000000?oooooo`000?ooool01oooool5o`0000Ko
oooo0008ooooo`?o00000_ooool00ol0003oooooooooo`02ooooo`?o00002?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo00Kooooo0_l00009ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`?o00002_ooool3o`0000;ooooo00?o0000oooooooo
ool01_ooool000Kooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l0000>oooo
o`00=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03Oooooo000fooooo`;o00001oooool00ol0003ooooo
ooooo`09ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0000[o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`;o0000>Oooool003Gooooo
0ol00007ooooo`03o`000?oooooooooo00Gooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo
0_l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool2o`0003[ooooo
000_ooooo`;o00001Oooool2o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`?o0000:Oooool002gooooo1?l00004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool2o`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`Go0000:Oooool002Gooooo0ol00005oooo
o`?o00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_l00008ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`?o00002oooool3o`00
01cooooo000Sooooo`Co00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool5o`0000Gooooo00?o0000ooooool000000_l00008ooooo`?o
00001oooool2o`0000_ooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00Wo
oooo1?l0000Mooooo`006?ooool5o`0000Cooooo1Ol00005ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool2o`0000_ooooo0ol00007ooooo`03o`000?oooooo000000;o0000
2?ooool3o`0000Kooooo0ol0000:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool4o`0000Wooooo1Ol0000@ooooo`003Oooool5o`0000Cooooo1Ol00004ooooo`;o00000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool2o`0000cooooo0_l00007ooooo`03o`000?oooooooooo00;o00002Oooool2o`0000Kooooo0ol0
000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool2o`0000;ooooo00?o
0000ooooooooool01_ooool5o`0000Wooooo1Ol00004ooooo`002Oooool6o`0000Cooooo0ol00003
ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`05ooooo`;o00002_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`?o00000oooool00ol0003ooooo
ooooo`04ooooo`Ko00001oooool000Kooooo0ol00008ooooo`;o00002Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool2o`0000Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool2o`0000[ooooo0ol0000=ooooo`00>?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0f
ooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool2o`0000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03Kooooo000gooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool2o`0003Sooooo000fooooo`?o00001_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00_ooooo0_l0000iooooo`00<?ooool2o`0000Cooooo00?o0000ooooool000001_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo0_l0000>ooooo`?o0000:?oo
ool002kooooo1?l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o00002Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool4o`0002Wooooo000^oooo
o`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0_l00007oooo
o`03o`000?oooooooooo00;o00002Oooool2o`0000Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0<ooooo`?o0000:_ooool002?ooooo1Ol00004ooooo`;o000000?oooooo`000?oo
ool01?ooool00ol0003oooooooooo`07ooooo`?o00002oooool2o`0000Oooooo00?o0000oooooooo
ool00_l00008ooooo`?o00001oooool2o`0000_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooo`00000;ooooo`Co00007?ooool000gooooo0ol00008ooooo`Go00001_ooool3o`0000Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`?o00003?ooool2o`0000Kooooo
00Co0000oooooooooooooooo0_l00009ooooo`;o00001_ooool2o`0000_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`?o00002Oooool5o`0000Oooooo0ol00006ooooo`00
3Oooool5o`0000Cooooo1Ol00005ooooo`?o000000?oooooo`000?ooool01?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool2o`0000cooooo
0_l000000ooooooo0000ooooo`07ooooo`Go00002Oooool5o`0000Cooooo0009ooooo`Ko00001?oo
ool3o`0000?ooooo00Co0000oooooooooooooooo0ol00009ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo
0ol00009ooooo`?o00000oooool00ol0003oooooooooo`04ooooo`Ko00001oooool000Kooooo0ol0
0008ooooo`;o00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l0
000:ooooo`?o00003Oooool003oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`17
ooooo`00>Oooool2o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0000foooo
o`00>?ooool3o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooo000000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`?o
0000=_ooool003Oooooo0ol00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03?ooool3o`0003Oooooo000hooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`Co0000
1Oooool01?l0003oooooooooooooool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo000aooooo`;o00001?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00_ooooo0_l00006ooooo`04o`000?ooooooooooooooo`;o
00002Oooool2o`0000Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`?o
00009oooool002oooooo0ol00004ooooo`03o`000?oooooooooo00Kooooo0ol00005ooooo`Go0000
00Coooooo`000?l0003o00001_ooool2o`0000?ooooo0_l00007ooooo`?o00001_ooool3o`0000_o
oooo00?o0000ooooooooool03?ooool4o`0002Sooooo000Tooooo`Co00001Oooool4o`0000Gooooo
00?o0000ooooooooool01_ooool3o`0000gooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool2o`0000Gooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo
1Ol00009ooooo`Go00006oooool000gooooo0ol00008ooooo`Go00001?ooool5o`0000Gooooo0_l0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool2o`0000gooooo0_l0
0005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`04ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`;o00000oooool00ol0003ooooooooo
o`06ooooo`Go00002Oooool4o`0000Oooooo0ol00006ooooo`003?ooool6o`0000;ooooo1ol00003
ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003oooooooooo`09
ooooo`;o00003?ooool2o`0000Kooooo00?o0000ooooooooool05Oooool2o`0000Wooooo00?o0000
ooooooooool02?ooool2o`0000_ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo1ol00008
ooooo`Ko00001?ooool000Kooooo1_l000000ooooooo0000o`000002ooooo`?o00001Oooool00ol0
003oooooooooo`02o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`;o00002Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`;o00002Oooool3o`0000Gooooo00Co0000
oooooooooooooooo1_l000000ooooooo0000o`000007ooooo`00?oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04Oooooo000oooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0A_ooool0043ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04Kooooo0010ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Kooooo000kooooo`?o00000_ooool00ol0003oooooooooo`0<ooooo`;o00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`03o`000?oooooooooo00oo
oooo0_l0000dooooo`00>Oooool4o`0000Cooooo00?o0000ooooooooool02oooool2o`0000Gooooo
00?o0000ooooooooool00_ooool3o`0000Sooooo0_l00006ooooo`03o`000?oooooooooo00gooooo
1?l0000dooooo`00>Oooool3o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0
000<ooooo`Co0000=Oooool003Oooooo0_l000000ooooooo0000ooooo`04ooooo`?o00003oooool0
1Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool00_ooool3o`0000_ooooo00Co
0000oooooooooooo0000=_ooool002oooooo1Ol000000ooooooo0000o`000009ooooo`?o00004ooo
ool00ol0003oooooooooo`0Eooooo`?o00002Oooool2o`0000oooooo1?l0000Wooooo`003Oooool3
o`0000Wooooo0ol00006ooooo`Oo00000_ooool7o`0000;ooooo00?o0000ooooooooool02_ooool2
o`0001?ooooo00?o0000ooooooooool05_ooool2o`0000Sooooo00?o0000ooooooooool02_ooool7
o`0000Sooooo1_l00007ooooo`?o00002?ooool3o`0000Kooooo0006oooooaco00000_ooool2o`00
00;ooooo0ol00005ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooo00001ooo
ool2o`0000[ooooo0_l00009ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool02?ooool3o`0000Gooooo00Co0000oooooooooooooooo1_l00002ooooo`;o
000000?oooooo`000?l000005_l00004ooooo`003Oooool2o`0000[ooooo0_l0000Tooooo`03o`00
0?oooooooooo00[ooooo0_l00008ooooo`04o`000?oooooo0000o`0000Wooooo0_l00007ooooo`03
o`000?oooooooooo03?ooooo0_l00009ooooo`;o00001oooool000Oooooo0ol0000Fooooo`Go0000
5oooool3o`000003ooooool0003ooooo00cooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooooooool2o`0000Wooooo00?o0000ooooooooool01Oooool4o`0001Oooooo1Ol0000Gooooo`?o
00003oooool000Kooooo00Go0000ooooooooooooooooo`00000Fooooo`04o`000?ooooooooooo`00
01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`?o00001?ooool00ol0003oooooooooo`03
ooooo`?o00001oooool3o`0000Gooooo0_l0000Iooooo`04o`000?ooooooooooo`0001Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`001Ol00005ooooo`03o`000?oooooooooo00gooooo1Ol0
0003ooooo`03o`000?oooooooooo013ooooo1Ol00003ooooo`05o`000?ooooooooooooooool00000
3oooool2o`0000?ooooo00?o0000ooooooooool00oooool4o`0000Sooooo0_l00004ooooo`;o0000
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo0008ooooo`;o00006Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?oo
ool3o`0000;ooooo00?o0000ooooooooool01_ooool2o`0000Kooooo1?l00004ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool05oooool2o`0000oooooo000:ooooo`03o`000?oooooo
oooo01?ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03oooool00ol0003oooooo`00000Cooooo`;o00000oooool00ol0003ooooooooo
o`0Fooooo`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`0<ooooo`001_oo
ool01Ol0003ooooooooooooooooo000001Gooooo00Go0000ooooooooooooooooo`00000Gooooo`;o
00001Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo1?l0000Fooooo`05
o`000?ooooooooooooooool000005_ooool01Ol0003ooooooooooooooooo000000kooooo0007oooo
o`?o00005oooool3o`0001Wooooo00?o0000ooooooooool00_ooool3o`00017ooooo00?o0000oooo
ooooool05_ooool3o`0001Oooooo0ol0000Hooooo`?o00003oooool004Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Hooooo`;o0000@oooool004Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo047ooooo000=ooooo`?o00002Ooo
ool3o`0000Sooooo0ol00009ooooo`?o00002?ooool3o`0000Sooooo0ol00009ooooo`?o000000?o
ooooo`000?ooool01Oooool3o`0000Wooooo0ol00008ooooo`?o00002Oooool3o`0000Sooooo0ol0
0008ooooo`?o00002Oooool3o`0000Sooooo0ol00006ooooo`0000?oooooo`000?l00000/ol00000
00Kooooo00?o0000ooooooooool01?ooool2o`0000[ooooo0_l00005ooooo`04o`000?oooooooooo
ooooo`;o00002_ooool2o`0000Wooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo00?o0000
ooooooooool01?ooool2o`0000[ooooo0_l00005ooooo`04o`000?ooooooooooooooo`;o00002_oo
ool2o`0000Wooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo00?o0000ooooooooool01?oo
ool2o`0000Oooooo0014ooooo`;o00004?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo047ooooo0013ooooo`?o00004?ooool00ol0003oooooooooo`0Hooooo`;o0000@oooool004;o
oooo0ol0000Aooooo`03o`000?oooooooooo01Oooooo0_l00014ooooo`00@oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Oooooo0_l00014ooooo`00@oooool00ol0003ooooooooo
o`0=ooooo`;o000000?oooooo`000?ooool04Oooool3o`0000Cooooo00?o0000ooooooooool0@ooo
ool004;ooooo00?o0000ooooooooool03?ooool2o`0000?ooooo00?o0000ooooooooool00oooool5
o`0000Kooooo0ol00005ooooo`03o`000?oooooooooo04Cooooo0011ooooo`03o`000?oooooooooo
00_ooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`?o00001Oooool00ol0
003oooooooooo`15ooooo`00@Oooool00ol0003oooooooooo`09ooooo`;o00001oooool01?l0003o
ooooooooooooool2o`000003ooooool0003ooooo00Gooooo0_l00008ooooo`03o`000?oooooooooo
04Gooooo0010ooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`Co00002?ooool2o`0000Wo
oooo00?o0000ooooooooool0A_ooool000Kooooo2_l000000ooooooo0000o`000005o`000003oooo
ool0003o000000Go00001?ooool2o`0000;ooooo0ol00008ooooo`;o00002_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l00009ooooo`?o00002Oooool4o`0000Cooooo
0_l000000ooooooo0000o`000005o`000005ooooool0003o0000o`000?ooool02_l00006ooooo`00
3Oooool5o`0000Kooooo1Ol00003ooooo`So00000oooool4o`000003ooooool0003o000000?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`Co000000?oooooo`000?l00000
1_ooool7o`0000Oooooo1_l00006ooooo`Go00001?ooool000gooooo0_l0000:ooooo`;o00002Ooo
ool5o`0000Kooooo1?l00003ooooo`;o00002_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`Co00002?oo
ool5o`0000Oooooo0_l00009ooooo`;o00001oooool002oooooo1Ol00004ooooo`03o`000?oooooo
oooo00Kooooo0_l0000>ooooo`;o00000oooool00ol0003oooooooooo`0?ooooo`;o00001Oooool2
o`0000_ooooo0_l0000=ooooo`Co00009oooool003Wooooo0_l00005ooooo`?o00003Oooool3o`00
00?ooooo00?o0000ooooooooool01?ooool2o`0000Sooooo0ol00004ooooo`?o00003Oooool2o`00
03Kooooo000iooooo`?o00001Oooool2o`0000cooooo0ol00004ooooo`03o`000?oooooooooo00?o
oooo0ol00007ooooo`?o00001_ooool2o`0000gooooo0_l0000fooooo`00>oooool2o`0000Cooooo
00?o0000ooooooooool02oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Sooooo
0ol00005ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool003gooooo00Co
0000oooooooooooo00003_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Wooooo
0_l00006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool0043ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Gooooo0010ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0A_ooool0043ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`16ooooo`00?oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo0_l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0A_ooool0
00Kooooo2_l000000ooooooo0000o`000005o`000003ooooool0003o000000Go00002?ooool2o`00
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool02?ooool2o`0000[ooooo1?l00007ooooo`Oo000000Gooooo
o`000?l0003o0000ooooo`0:o`0000Kooooo000=ooooo`Go00001_ooool5o`0000?ooooo1ol00003
ooooo`?o00001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0ol00005
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`Ko00002?ooool5o`0000Oooooo1Ol00004
ooooo`006?ooool2o`0000[ooooo1?l00005ooooo`Co00000oooool00ol0003oooooooooo`09oooo
o`;o00003Oooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Sooooo0_l00006oooo
o`;o00002Oooool00ol0003oooooooooo`0<ooooo`Go00002Oooool5o`0000Oooooo0_l0000Boooo
o`00;oooool3o`0000?ooooo00?o0000ooooooooool01oooool3o`0000cooooo0ol00005ooooo`;o
00000oooool3o`0000Oooooo0ol00005ooooo`?o00002_ooool00ol0003oooooooooo`0>ooooo`?o
0000:?ooool002oooooo1?l00003ooooo`03o`000?oooooooooo00Oooooo0_l0000;ooooo`?o0000
1_ooool01?l0003oooooooooooooool3o`0000Oooooo0ol00007ooooo`;o00002oooool00ol0003o
ooooooooo`0<ooooo`Go00009oooool003Oooooo0ol00006ooooo`03o`000?oooooooooo00_ooooo
0_l00006ooooo`04o`000?ooooooooooooooo`?o00002?ooool2o`0000Oooooo00?o0000oooooooo
ool02oooool2o`0003Sooooo000gooooo`?o00001_ooool00ol0003oooooooooo`0:ooooo`?o0000
1_ooool01?l0003oooooooooooooool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0<ooooo`;o0000>?ooool003Sooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooool000001_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool2o`0003Oooooo000iooooo`;o00001Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool003[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooool000002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0=?ooool003oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Oooooo0006
ooooo`Co00000oooool2o`0000;ooooo0ol00008ooooo`;o00002_ooool2o`0000Wooooo00?o0000
ooooooooool02Oooool2o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`08
ooooo`;o00002_ooool2o`0000Wooooo0ol00009ooooo`Co00000oooool2o`0000Oooooo000:oooo
o`Oo00000oooool4o`000003ooooool0003o000000?ooooo0ol00009ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool2o`0000[ooooo0ol00009ooooo`Co000000?oooooo`00
0?l000001_ooool7o`0000Gooooo000=ooooo`Go00001_ooool4o`0000Gooooo1Ol00005ooooo`;o
00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`Co
00002Oooool4o`0000Sooooo1Ol00004ooooo`006?ooool5o`0000Oooooo0ol00006ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool3o`0000cooooo0_l00006ooooo`04o`00
0?ooooooooooooooo`;o00002?ooool3o`0000Kooooo0_l0000:ooooo`03o`000?oooooooooo00co
oooo0_l0000<ooooo`?o00002?ooool5o`00013ooooo000Sooooo`Go00001_ooool2o`0000Gooooo
00?o0000ooooooooool01oooool3o`0000_ooooo0_l00007ooooo`03o`000?oooooooooo00;o0000
2?ooool3o`0000Oooooo0_l0000;ooooo`03o`000?oooooooooo00gooooo0_l0000:ooooo`Co0000
7?ooool002kooooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool2o`0000Oooooo00Go0000ooooooooooooooooo`000009ooooo`;o00001oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00cooooo1?l0000Yooooo`00<Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00kooooo0_l0000Xooooo`00=_ooool3o`0000Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`;o0000>Oooool003Kooooo0ol0
0006ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooo`00
000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool2o`0003Wooooo000g
ooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooool000002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo0_l0000h
ooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool2o`0000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03Kooooo000oooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool2o`0000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17ooooo`00
1_ooool4o`0000?ooooo0_l00002ooooo`?o00002?ooool2o`0000[ooooo0_l00009ooooo`03o`00
0?oooooooooo00Wooooo0_l00009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00Sooooo0_l0000:ooooo`;o00002Oooool3o`0000Wooooo1?l00003oooo
o`;o00001oooool000[ooooo1ol00003ooooo`Co000000?oooooo`000?l000000oooool3o`0000Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool3o`0000Wooooo1?l000000ooooooo0000o`000006ooooo`Oo00001Oooool000go
oooo1Ol00006ooooo`Co00001Oooool5o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`;o00003?ooool2o`0000Oooooo00Go0000ooooooooooooooooo`000009oooo
o`;o00001oooool2o`0000[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`Co00002Oooool4o`0000Sooooo1Ol00004ooooo`006?ooool5o`0000Oooooo0ol00005ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool2o`0000_ooooo0ol00007ooooo`03
o`000?oooooooooo00;o00002?ooool3o`0000Kooooo0ol0000:ooooo`03o`000?oooooooooo00_o
oooo0_l0000=ooooo`?o00002?ooool5o`00013ooooo000Sooooo`Go00001Oooool2o`0000Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`;o00001oooool00ol0003ooooo
o`000002o`0000Wooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3Oooool2o`0000[ooooo1Ol0000Looooo`00;Oooool2o`0000Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`Ko00001?ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`?o0000
:oooool002oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo000000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00gooooo0_l0000Zooooo`00<?ooool00ol0003oooooooooo`02ooooo`?o00001oooool0
0ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Kooooo0ol0000:ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool2o`00013ooooo00?o0000ooooooooool09ooo
ool003Gooooo0ol00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo0_l0000jooooo`00=_ooool2o`0000Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03?ooool2o`0003Wooooo000gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;o
oooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0gooooo`001_ooool3o`0000Sooooo0_l00009ooooo`;o00002_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l00009ooooo`04o`000?ooooooooooooooo`?o
00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l00009oooo
o`;o00002_ooool3o`0000gooooo0009ooooo`Ko00001?ooool3o`0000Sooooo0_l00008ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool3o`0000[ooooo1_l00007ooooo`003Oooool4o`0000Go
oooo1Ol00005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo0_l00007ooooo`03o`000?oooooooooo00;o
00002?ooool2o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool2o`0000_ooooo1Ol00009ooooo`Co00001Oooool000gooooo1Ol00007ooooo`?o0000
1Oooool2o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`;o00003?ooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0000Wo
oooo0_l00008ooooo`;o00002_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooool000002oooool3o`0000Sooooo1Ol00004ooooo`006?ooool5o`0000Kooooo
0_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool2o`0000_ooooo
0_l00008ooooo`Co00002?ooool3o`0000Oooooo0ol0000:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool2o`0000[ooooo1Ol0000@ooooo`008oooool3o`0000Kooooo0ol0
0006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`07ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`?o00007_ooool002Kooooo00?o
0000ooooooooool00oooool3o`0000Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool2o`0000kooooo00?o
0000ooooooooool06oooool002kooooo0_l00005ooooo`;o00002?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo0_l0000>ooooo`03o`000?oooooooooo02Wooooo000_oooo
o`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool2o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`?o00003oooool00ol0003oooooooooo`0Xooooo`00=Oooool2o`0000Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00[ooooo0ol0000jooooo`00=_ooool2o`0000Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00_ooooo0_l0000jooooo`001_ooool2o`0000Wooooo0_l00009ooooo`;o00002_oo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
0_l0000:ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02Oooool2o`0000Wo
oooo0_l0000:ooooo`;o00003_ooool000Sooooo0ol00008ooooo`;o00002Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`?o00002oooool000_ooooo
1?l00006ooooo`;o00002?ooool2o`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`;o00003?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`;o00002oooool4o`0000Oo
oooo000=ooooo`?o00001oooool3o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`;o00002?ooool01?l0003ooooo
o`000?l00009ooooo`;o00001oooool3o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0;ooooo`;o00002oooool3o`0000[ooooo0ol00006ooooo`003Oooool4o`0000Oooooo
0ol00007ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
0ol0000:ooooo`?o00002?ooool4o`0000Sooooo0ol00007ooooo`?o00002_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00gooooo0_l0000;ooooo`;o00002Oooool4o`0000Gooooo
000Hooooo`Co00001oooool2o`0000Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo0_l00008ooooo`04o`000?oooooo0000o`0000Wooooo
0_l00008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0<ooooo`;o00002_ooool4o`00017ooooo000Rooooo`Co00001_ooool2o`0000Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooool000002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool3o`0000[ooooo1?l0000Nooooo`009Oooool2o`0000Gooooo0_l00007
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool3o`0000gooooo0_l0000Mooooo`00;Oooool2o`0000Gooooo0ol00008oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool2o`0000[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`?o00003?ooool2o`0002cooooo000^ooooo`03
o`000?oooooooooo00?ooooo0ol00008ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00ol00005ooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[o
oooo0ol0000=ooooo`;o0000:oooool002oooooo00?o0000ooooooooool00oooool2o`0000Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
0_l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool2o`0000kooooo
00?o0000ooooooooool0:Oooool003Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0hooooo`001_ooool2o`0000Wooooo0_l00009ooooo`;o00002_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`;o00001Oooool2o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool2o`0000Wooooo0_l0000:
ooooo`;o00003_ooool000Sooooo0ol00008ooooo`;o00002Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo0_l0000:ooooo`?o00002oooool000_ooooo1?l00006ooooo`;o
00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool2o`00
00_ooooo1?l00007ooooo`003Oooool3o`0000Oooooo0ol00006ooooo`;o00002?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Oooooo0ol00005ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[o
oooo0ol0000:ooooo`?o00001_ooool0013ooooo00?o0000ooooooooool01?ooool4o`0000Oooooo
0_l00006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool2o`0000_ooooo
0ol0000<ooooo`03o`000?oooooooooo00?ooooo000Jooooo`;o00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00oooooo000Rooooo`?o00001oooool2o`0000Oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo0_l0000;
ooooo`?o00007oooool002Gooooo00?o0000ooooooooool00oooool3o`0000Oooooo0_l0000Ooooo
o`03o`000?oooooooooo023ooooo0_l0000<ooooo`;o00003_ooool00ol0003oooooooooo`0Loooo
o`00;Oooool2o`0000Gooooo0ol0000Oooooo`03o`000?oooooooooo023ooooo0_l0000=ooooo`;o
0000;?ooool002kooooo00?o0000ooooooooool00oooool3o`0001oooooo00?o0000ooooooooool0
8?ooool2o`0000kooooo00?o0000ooooooooool0:_ooool003Gooooo0_l0000Oooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0>Oooool003Kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Wooooo001Fooooo`03o`000?oooooooooo
05gooooo001Fooooo`03o`000?oooooooooo05gooooo001Fooooo`03o`000?oooooooooo05gooooo
001Fooooo`03o`000?oooooooooo05gooooo001Fooooo`03o`000?oooooooooo05gooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 259.625}, {331.25, 137.875}} -> {-6.14474, \
1.54425, 0.0374928, 0.0374928}}]
}, Open  ]],

Cell[TextData[{
  "There are potential problems for any solution curve as it approaches the \
lines  ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 1 or ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = -1. This is not  surprising because the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  " is not defined at any point on either of these lines, all these points \
are singular  points for DE2: "
}], "Text"],

Cell[TextData[{
  " ",
  StyleBox["f",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  " ) = ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\/\(t\^2 - 1\)\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
The next picture displays the slope field and several solution \
curves.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["The entries below are edited versions of the input \
used above to create the first picture of a slope field and solution \
curves.", "Note"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
DE = y'[t] == y[t]/(t^2-1)
solns1 = Table[ DSolve[ {DE, y[0]==k}, y, t], {k,-3,3}];
solns2 = Table[ DSolve[ {DE, y[-2]==k}, y, t], {k,-3,3}];
solns3 = Table[ DSolve[ {DE, y[3]==k}, y, t], {k,-3,3}];
solns = Join[solns1,solns2,solns3];
Show[ S, Table[ Plot[ y[t]/.solns[[k]], {t,-3,3}, 
                PlotStyle->Thickness[0.01], DisplayFunction->Identity ], 
                {k,21} ], PlotRange->{{-3,3},{-3,3}}, 
                DisplayFunction->$DisplayFunction, 
                PlotLabel->\"Slope field and solution curves\"]\
\>", "Input",\

  CellLabel->"In[160]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(y[t]\/\(\(-1\) + t\^2\)\)}]], "Output",
  CellLabel->"Out[160]=",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.5 0.166667 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.0125 -95 0 ]
[.5 1.0125 95 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-3)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-2)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-1)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(1)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(2)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(3)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-2)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-1)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(1)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(2)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(3)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.0125 -156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Slope) show
99.000 13.000 moveto
(field) show
135.000 13.000 moveto
(and) show
159.000 13.000 moveto
(solution) show
213.000 13.000 moveto
(curves) show
249.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
0 0 m
0 0 rlineto s
% Start of user PostScript
-3. -3. -2.59872 -3.15048 MAarrowhead1
% End of user PostScript
0 .07143 m
.068 .04957 L
s
% Start of user PostScript
-3. -2.57143 -2.59199 -2.70258 MAarrowhead1
% End of user PostScript
0 .14286 m
.069 .12438 L
s
% Start of user PostScript
-3. -2.14286 -2.58602 -2.25374 MAarrowhead1
% End of user PostScript
0 .21429 m
.06984 .19932 L
s
% Start of user PostScript
-3. -1.71429 -2.58094 -1.80408 MAarrowhead1
% End of user PostScript
0 .28571 m
.07052 .27438 L
s
% Start of user PostScript
-3. -1.28571 -2.57686 -1.35372 MAarrowhead1
% End of user PostScript
0 .35714 m
.07102 .34953 L
s
% Start of user PostScript
-3. -0.857143 -2.57387 -0.9028 MAarrowhead1
% End of user PostScript
0 .42857 m
.07133 .42475 L
s
% Start of user PostScript
-3. -0.428571 -2.57204 -0.451498 MAarrowhead1
% End of user PostScript
0 .5 m
.07143 .5 L
s
% Start of user PostScript
-3. 0 -2.57143 0 MAarrowhead1
% End of user PostScript
0 .57143 m
.07133 .57525 L
s
% Start of user PostScript
-3. 0.428571 -2.57204 0.451498 MAarrowhead1
% End of user PostScript
0 .64286 m
.07102 .65047 L
s
% Start of user PostScript
-3. 0.857143 -2.57387 0.9028 MAarrowhead1
% End of user PostScript
0 .71429 m
.07052 .72562 L
s
% Start of user PostScript
-3. 1.28571 -2.57686 1.35372 MAarrowhead1
% End of user PostScript
0 .78571 m
.06984 .80068 L
s
% Start of user PostScript
-3. 1.71429 -2.58094 1.80408 MAarrowhead1
% End of user PostScript
0 .85714 m
.069 .87562 L
s
% Start of user PostScript
-3. 2.14286 -2.58602 2.25374 MAarrowhead1
% End of user PostScript
0 .92857 m
.068 .95043 L
s
% Start of user PostScript
-3. 2.57143 -2.59199 2.70258 MAarrowhead1
% End of user PostScript
0 1 m
0 0 rlineto s
0 1 m
0 1 L
s
% Start of user PostScript
-3. 3. -2.59872 3.15048 MAarrowhead1
% End of user PostScript
.07143 0 m
0 0 rlineto s
% Start of user PostScript
-2.57143 -3. -2.19347 -3.20204 MAarrowhead1
% End of user PostScript
.07143 .07143 m
.13637 .04168 L
s
% Start of user PostScript
-2.57143 -2.57143 -2.18181 -2.74995 MAarrowhead1
% End of user PostScript
.07143 .14286 m
.13816 .11738 L
s
% Start of user PostScript
-2.57143 -2.14286 -2.17105 -2.29573 MAarrowhead1
% End of user PostScript
.07143 .21429 m
.13974 .19342 L
s
% Start of user PostScript
-2.57143 -1.71429 -2.16155 -1.83948 MAarrowhead1
% End of user PostScript
.07143 .28571 m
.14105 .26976 L
s
% Start of user PostScript
-2.57143 -1.28571 -2.15368 -1.38142 MAarrowhead1
% End of user PostScript
.07143 .35714 m
.14204 .34636 L
s
% Start of user PostScript
-2.57143 -0.857143 -2.14777 -0.921847 MAarrowhead1
% End of user PostScript
.07143 .42857 m
.14265 .42313 L
s
% Start of user PostScript
-2.57143 -0.428571 -2.1441 -0.461204 MAarrowhead1
% End of user PostScript
.07143 .5 m
.14286 .5 L
s
% Start of user PostScript
-2.57143 0 -2.14286 0 MAarrowhead1
% End of user PostScript
.07143 .57143 m
.14265 .57687 L
s
% Start of user PostScript
-2.57143 0.428571 -2.1441 0.461204 MAarrowhead1
% End of user PostScript
.07143 .64286 m
.14204 .65364 L
s
% Start of user PostScript
-2.57143 0.857143 -2.14777 0.921847 MAarrowhead1
% End of user PostScript
.07143 .71429 m
.14105 .73024 L
s
% Start of user PostScript
-2.57143 1.28571 -2.15368 1.38142 MAarrowhead1
% End of user PostScript
.07143 .78571 m
.13974 .80658 L
s
% Start of user PostScript
-2.57143 1.71429 -2.16155 1.83948 MAarrowhead1
% End of user PostScript
.07143 .85714 m
.13816 .88262 L
s
% Start of user PostScript
-2.57143 2.14286 -2.17105 2.29573 MAarrowhead1
% End of user PostScript
.07143 .92857 m
.13637 .95832 L
s
% Start of user PostScript
-2.57143 2.57143 -2.18181 2.74995 MAarrowhead1
% End of user PostScript
.07143 1 m
0 0 rlineto s
.07143 1 m
.07143 1 L
s
% Start of user PostScript
-2.57143 3. -2.19347 3.20204 MAarrowhead1
% End of user PostScript
.14286 0 m
0 0 rlineto s
% Start of user PostScript
-2.14286 -3. -1.81393 -3.27473 MAarrowhead1
% End of user PostScript
.14286 .07143 m
.20094 .02985 L
s
% Start of user PostScript
-2.14286 -2.57143 -1.79438 -2.82091 MAarrowhead1
% End of user PostScript
.14286 .14286 m
.2042 .10626 L
s
% Start of user PostScript
-2.14286 -2.14286 -1.77481 -2.36243 MAarrowhead1
% End of user PostScript
.14286 .21429 m
.20732 .18352 L
s
% Start of user PostScript
-2.14286 -1.71429 -1.75608 -1.89888 MAarrowhead1
% End of user PostScript
.14286 .28571 m
.21011 .26164 L
s
% Start of user PostScript
-2.14286 -1.28571 -1.73936 -1.43015 MAarrowhead1
% End of user PostScript
.14286 .35714 m
.21233 .34056 L
s
% Start of user PostScript
-2.14286 -0.857143 -1.72599 -0.956622 MAarrowhead1
% End of user PostScript
.14286 .42857 m
.21378 .42011 L
s
% Start of user PostScript
-2.14286 -0.428571 -1.7173 -0.479348 MAarrowhead1
% End of user PostScript
.14286 .5 m
.21429 .5 L
s
% Start of user PostScript
-2.14286 0 -1.71429 0 MAarrowhead1
% End of user PostScript
.14286 .57143 m
.21378 .57989 L
s
% Start of user PostScript
-2.14286 0.428571 -1.7173 0.479348 MAarrowhead1
% End of user PostScript
.14286 .64286 m
.21233 .65944 L
s
% Start of user PostScript
-2.14286 0.857143 -1.72599 0.956622 MAarrowhead1
% End of user PostScript
.14286 .71429 m
.21011 .73836 L
s
% Start of user PostScript
-2.14286 1.28571 -1.73936 1.43015 MAarrowhead1
% End of user PostScript
.14286 .78571 m
.20732 .81648 L
s
% Start of user PostScript
-2.14286 1.71429 -1.75608 1.89888 MAarrowhead1
% End of user PostScript
.14286 .85714 m
.2042 .89374 L
s
% Start of user PostScript
-2.14286 2.14286 -1.77481 2.36243 MAarrowhead1
% End of user PostScript
.14286 .92857 m
.20094 .97015 L
s
% Start of user PostScript
-2.14286 2.57143 -1.79438 2.82091 MAarrowhead1
% End of user PostScript
.14286 1 m
0 0 rlineto s
.14286 1 m
.14286 1 L
s
% Start of user PostScript
-2.14286 3. -1.81393 3.27473 MAarrowhead1
% End of user PostScript
.21429 0 m
0 0 rlineto s
% Start of user PostScript
-1.71429 -3. -1.48167 -3.35995 MAarrowhead1
% End of user PostScript
.21429 .07143 m
.25729 .01439 L
s
% Start of user PostScript
-1.71429 -2.57143 -1.45627 -2.91363 MAarrowhead1
% End of user PostScript
.21429 .14286 m
.26221 .08989 L
s
% Start of user PostScript
-1.71429 -2.14286 -1.42675 -2.46066 MAarrowhead1
% End of user PostScript
.21429 .21429 m
.2678 .16697 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.39322 -1.99817 MAarrowhead1
% End of user PostScript
.21429 .28571 m
.27381 .24624 L
s
% Start of user PostScript
-1.71429 -1.28571 -1.35712 -1.52257 MAarrowhead1
% End of user PostScript
.21429 .35714 m
.27961 .32826 L
s
% Start of user PostScript
-1.71429 -0.857143 -1.32231 -1.03044 MAarrowhead1
% End of user PostScript
.21429 .42857 m
.28403 .41315 L
s
% Start of user PostScript
-1.71429 -0.428571 -1.29582 -0.521075 MAarrowhead1
% End of user PostScript
.21429 .5 m
.28571 .5 L
s
% Start of user PostScript
-1.71429 0 -1.28571 0 MAarrowhead1
% End of user PostScript
.21429 .57143 m
.28403 .58685 L
s
% Start of user PostScript
-1.71429 0.428571 -1.29582 0.521075 MAarrowhead1
% End of user PostScript
.21429 .64286 m
.27961 .67174 L
s
% Start of user PostScript
-1.71429 0.857143 -1.32231 1.03044 MAarrowhead1
% End of user PostScript
.21429 .71429 m
.27381 .75376 L
s
% Start of user PostScript
-1.71429 1.28571 -1.35712 1.52257 MAarrowhead1
% End of user PostScript
.21429 .78571 m
.2678 .83303 L
s
% Start of user PostScript
-1.71429 1.71429 -1.39322 1.99817 MAarrowhead1
% End of user PostScript
.21429 .85714 m
.26221 .91011 L
s
% Start of user PostScript
-1.71429 2.14286 -1.42675 2.46066 MAarrowhead1
% End of user PostScript
.21429 .92857 m
.25729 .98561 L
s
% Start of user PostScript
-1.71429 2.57143 -1.45627 2.91363 MAarrowhead1
% End of user PostScript
.21429 1 m
0 0 rlineto s
.21429 1 m
.21429 1 L
s
% Start of user PostScript
-1.71429 3. -1.48167 3.35995 MAarrowhead1
% End of user PostScript
.28571 0 m
0 0 rlineto s
% Start of user PostScript
-1.28571 -3. -1.19455 -3.41876 MAarrowhead1
% End of user PostScript
.28571 .07143 m
.3033 .0022 L
s
% Start of user PostScript
-1.28571 -2.57143 -1.18022 -2.98681 MAarrowhead1
% End of user PostScript
.28571 .14286 m
.30654 .07453 L
s
% Start of user PostScript
-1.28571 -2.14286 -1.16078 -2.55281 MAarrowhead1
% End of user PostScript
.28571 .21429 m
.31114 .14754 L
s
% Start of user PostScript
-1.28571 -1.71429 -1.13314 -2.11478 MAarrowhead1
% End of user PostScript
.28571 .28571 m
.31806 .22203 L
s
% Start of user PostScript
-1.28571 -1.28571 -1.09163 -1.66782 MAarrowhead1
% End of user PostScript
.28571 .35714 m
.329 .30033 L
s
% Start of user PostScript
-1.28571 -0.857143 -1.02598 -1.19804 MAarrowhead1
% End of user PostScript
.28571 .42857 m
.34543 .38938 L
s
% Start of user PostScript
-1.28571 -0.428571 -0.927408 -0.66371 MAarrowhead1
% End of user PostScript
.28571 .5 m
.35714 .5 L
s
% Start of user PostScript
-1.28571 0 -0.857143 0 MAarrowhead1
% End of user PostScript
.28571 .57143 m
.34543 .61062 L
s
% Start of user PostScript
-1.28571 0.428571 -0.927408 0.66371 MAarrowhead1
% End of user PostScript
.28571 .64286 m
.329 .69967 L
s
% Start of user PostScript
-1.28571 0.857143 -1.02598 1.19804 MAarrowhead1
% End of user PostScript
.28571 .71429 m
.31806 .77797 L
s
% Start of user PostScript
-1.28571 1.28571 -1.09163 1.66782 MAarrowhead1
% End of user PostScript
.28571 .78571 m
.31114 .85246 L
s
% Start of user PostScript
-1.28571 1.71429 -1.13314 2.11478 MAarrowhead1
% End of user PostScript
.28571 .85714 m
.30654 .92547 L
s
% Start of user PostScript
-1.28571 2.14286 -1.16078 2.55281 MAarrowhead1
% End of user PostScript
.28571 .92857 m
.3033 .9978 L
s
% Start of user PostScript
-1.28571 2.57143 -1.18022 2.98681 MAarrowhead1
% End of user PostScript
.28571 1 m
0 0 rlineto s
.28571 1 m
.28571 1 L
s
% Start of user PostScript
-1.28571 3. -1.19455 3.41876 MAarrowhead1
% End of user PostScript
.35714 0 m
.36344 .07115 L
s
% Start of user PostScript
-0.857143 -3. -0.819389 -2.57309 MAarrowhead1
% End of user PostScript
.35714 .07143 m
.36447 .14248 L
s
% Start of user PostScript
-0.857143 -2.57143 -0.813159 -2.14512 MAarrowhead1
% End of user PostScript
.35714 .14286 m
.36592 .21374 L
s
% Start of user PostScript
-0.857143 -2.14286 -0.804484 -1.71753 MAarrowhead1
% End of user PostScript
.35714 .21429 m
.36807 .28487 L
s
% Start of user PostScript
-0.857143 -1.71429 -0.791597 -1.29076 MAarrowhead1
% End of user PostScript
.35714 .28571 m
.37158 .35567 L
s
% Start of user PostScript
-0.857143 -1.28571 -0.770532 -0.865986 MAarrowhead1
% End of user PostScript
.35714 .35714 m
.37826 .42538 L
s
% Start of user PostScript
-0.857143 -0.857143 -0.730421 -0.447735 MAarrowhead1
% End of user PostScript
.35714 .42857 m
.39474 .4893 L
s
% Start of user PostScript
-0.857143 -0.428571 -0.631562 -0.0641721 MAarrowhead1
% End of user PostScript
.35714 .5 m
.42857 .5 L
s
% Start of user PostScript
-0.857143 0 -0.428571 0 MAarrowhead1
% End of user PostScript
.35714 .57143 m
.39474 .5107 L
s
% Start of user PostScript
-0.857143 0.428571 -0.631562 0.0641721 MAarrowhead1
% End of user PostScript
.35714 .64286 m
.37826 .57462 L
s
% Start of user PostScript
-0.857143 0.857143 -0.730421 0.447735 MAarrowhead1
% End of user PostScript
.35714 .71429 m
.37158 .64433 L
s
% Start of user PostScript
-0.857143 1.28571 -0.770532 0.865986 MAarrowhead1
% End of user PostScript
.35714 .78571 m
.36807 .71513 L
s
% Start of user PostScript
-0.857143 1.71429 -0.791597 1.29076 MAarrowhead1
% End of user PostScript
.35714 .85714 m
.36592 .78626 L
s
% Start of user PostScript
-0.857143 2.14286 -0.804484 1.71753 MAarrowhead1
% End of user PostScript
.35714 .92857 m
.36447 .85752 L
s
% Start of user PostScript
-0.857143 2.57143 -0.813159 2.14512 MAarrowhead1
% End of user PostScript
.35714 1 m
.36344 .92885 L
s
% Start of user PostScript
-0.857143 3. -0.819389 2.57309 MAarrowhead1
% End of user PostScript
.42857 0 m
.44733 .06892 L
s
% Start of user PostScript
-0.428571 -3. -0.316045 -2.58646 MAarrowhead1
% End of user PostScript
.42857 .07143 m
.45018 .13951 L
s
% Start of user PostScript
-0.428571 -2.57143 -0.298895 -2.16295 MAarrowhead1
% End of user PostScript
.42857 .14286 m
.454 .20961 L
s
% Start of user PostScript
-0.428571 -2.14286 -0.276002 -1.74236 MAarrowhead1
% End of user PostScript
.42857 .21429 m
.45928 .27878 L
s
% Start of user PostScript
-0.428571 -1.71429 -0.244314 -1.32735 MAarrowhead1
% End of user PostScript
.42857 .28571 m
.46686 .34602 L
s
% Start of user PostScript
-0.428571 -1.28571 -0.198854 -0.923909 MAarrowhead1
% End of user PostScript
.42857 .35714 m
.47783 .40887 L
s
% Start of user PostScript
-0.428571 -0.857143 -0.133005 -0.546798 MAarrowhead1
% End of user PostScript
.42857 .42857 m
.49181 .46177 L
s
% Start of user PostScript
-0.428571 -0.428571 -0.0491152 -0.229357 MAarrowhead1
% End of user PostScript
.42857 .5 m
.5 .5 L
s
% Start of user PostScript
-0.428571 0 0 0 MAarrowhead1
% End of user PostScript
.42857 .57143 m
.49181 .53823 L
s
% Start of user PostScript
-0.428571 0.428571 -0.0491152 0.229357 MAarrowhead1
% End of user PostScript
.42857 .64286 m
.47783 .59113 L
s
% Start of user PostScript
-0.428571 0.857143 -0.133005 0.546798 MAarrowhead1
% End of user PostScript
.42857 .71429 m
.46686 .65398 L
s
% Start of user PostScript
-0.428571 1.28571 -0.198854 0.923909 MAarrowhead1
% End of user PostScript
.42857 .78571 m
.45928 .72122 L
s
% Start of user PostScript
-0.428571 1.71429 -0.244314 1.32735 MAarrowhead1
% End of user PostScript
.42857 .85714 m
.454 .79039 L
s
% Start of user PostScript
-0.428571 2.14286 -0.276002 1.74236 MAarrowhead1
% End of user PostScript
.42857 .92857 m
.45018 .86049 L
s
% Start of user PostScript
-0.428571 2.57143 -0.298895 2.16295 MAarrowhead1
% End of user PostScript
.42857 1 m
.44733 .93108 L
s
% Start of user PostScript
-0.428571 3. -0.316045 2.58646 MAarrowhead1
% End of user PostScript
.5 0 m
.52259 .06776 L
s
% Start of user PostScript
0 -3. 0.135526 -2.59342 MAarrowhead1
% End of user PostScript
.5 .07143 m
.52589 .138 L
s
% Start of user PostScript
0 -2.57143 0.155334 -2.172 MAarrowhead1
% End of user PostScript
.5 .14286 m
.53021 .20758 L
s
% Start of user PostScript
0 -2.14286 0.181237 -1.75449 MAarrowhead1
% End of user PostScript
.5 .21429 m
.53599 .27598 L
s
% Start of user PostScript
0 -1.71429 0.215945 -1.34409 MAarrowhead1
% End of user PostScript
.5 .28571 m
.54385 .3421 L
s
% Start of user PostScript
0 -1.28571 0.263117 -0.94742 MAarrowhead1
% End of user PostScript
.5 .35714 m
.55423 .40363 L
s
% Start of user PostScript
0 -0.857143 0.325396 -0.578232 MAarrowhead1
% End of user PostScript
.5 .42857 m
.56565 .45671 L
s
% Start of user PostScript
0 -0.428571 0.393919 -0.259749 MAarrowhead1
% End of user PostScript
.5 .5 m
.57143 .5 L
s
% Start of user PostScript
0 0 0.428571 0 MAarrowhead1
% End of user PostScript
.5 .57143 m
.56565 .54329 L
s
% Start of user PostScript
0 0.428571 0.393919 0.259749 MAarrowhead1
% End of user PostScript
.5 .64286 m
.55423 .59637 L
s
% Start of user PostScript
0 0.857143 0.325396 0.578232 MAarrowhead1
% End of user PostScript
.5 .71429 m
.54385 .6579 L
s
% Start of user PostScript
0 1.28571 0.263117 0.94742 MAarrowhead1
% End of user PostScript
.5 .78571 m
.53599 .72402 L
s
% Start of user PostScript
0 1.71429 0.215945 1.34409 MAarrowhead1
% End of user PostScript
.5 .85714 m
.53021 .79242 L
s
% Start of user PostScript
0 2.14286 0.181237 1.75449 MAarrowhead1
% End of user PostScript
.5 .92857 m
.52589 .862 L
s
% Start of user PostScript
0 2.57143 0.155334 2.172 MAarrowhead1
% End of user PostScript
.5 1 m
.52259 .93224 L
s
% Start of user PostScript
0 3. 0.135526 2.59342 MAarrowhead1
% End of user PostScript
.57143 0 m
.59018 .06892 L
s
% Start of user PostScript
0.428571 -3. 0.541098 -2.58646 MAarrowhead1
% End of user PostScript
.57143 .07143 m
.59304 .13951 L
s
% Start of user PostScript
0.428571 -2.57143 0.558248 -2.16295 MAarrowhead1
% End of user PostScript
.57143 .14286 m
.59686 .20961 L
s
% Start of user PostScript
0.428571 -2.14286 0.581141 -1.74236 MAarrowhead1
% End of user PostScript
.57143 .21429 m
.60214 .27878 L
s
% Start of user PostScript
0.428571 -1.71429 0.612829 -1.32735 MAarrowhead1
% End of user PostScript
.57143 .28571 m
.60971 .34602 L
s
% Start of user PostScript
0.428571 -1.28571 0.658289 -0.923909 MAarrowhead1
% End of user PostScript
.57143 .35714 m
.62069 .40887 L
s
% Start of user PostScript
0.428571 -0.857143 0.724138 -0.546798 MAarrowhead1
% End of user PostScript
.57143 .42857 m
.63467 .46177 L
s
% Start of user PostScript
0.428571 -0.428571 0.808028 -0.229357 MAarrowhead1
% End of user PostScript
.57143 .5 m
.64286 .5 L
s
% Start of user PostScript
0.428571 0 0.857143 0 MAarrowhead1
% End of user PostScript
.57143 .57143 m
.63467 .53823 L
s
% Start of user PostScript
0.428571 0.428571 0.808028 0.229357 MAarrowhead1
% End of user PostScript
.57143 .64286 m
.62069 .59113 L
s
% Start of user PostScript
0.428571 0.857143 0.724138 0.546798 MAarrowhead1
% End of user PostScript
.57143 .71429 m
.60971 .65398 L
s
% Start of user PostScript
0.428571 1.28571 0.658289 0.923909 MAarrowhead1
% End of user PostScript
.57143 .78571 m
.60214 .72122 L
s
% Start of user PostScript
0.428571 1.71429 0.612829 1.32735 MAarrowhead1
% End of user PostScript
.57143 .85714 m
.59686 .79039 L
s
% Start of user PostScript
0.428571 2.14286 0.581141 1.74236 MAarrowhead1
% End of user PostScript
.57143 .92857 m
.59304 .86049 L
s
% Start of user PostScript
0.428571 2.57143 0.558248 2.16295 MAarrowhead1
% End of user PostScript
.57143 1 m
.59018 .93108 L
s
% Start of user PostScript
0.428571 3. 0.541098 2.58646 MAarrowhead1
% End of user PostScript
.64286 0 m
.64915 .07115 L
s
% Start of user PostScript
0.857143 -3. 0.894896 -2.57309 MAarrowhead1
% End of user PostScript
.64286 .07143 m
.65019 .14248 L
s
% Start of user PostScript
0.857143 -2.57143 0.901127 -2.14512 MAarrowhead1
% End of user PostScript
.64286 .14286 m
.65163 .21374 L
s
% Start of user PostScript
0.857143 -2.14286 0.909802 -1.71753 MAarrowhead1
% End of user PostScript
.64286 .21429 m
.65378 .28487 L
s
% Start of user PostScript
0.857143 -1.71429 0.922689 -1.29076 MAarrowhead1
% End of user PostScript
.64286 .28571 m
.65729 .35567 L
s
% Start of user PostScript
0.857143 -1.28571 0.943754 -0.865986 MAarrowhead1
% End of user PostScript
.64286 .35714 m
.66398 .42538 L
s
% Start of user PostScript
0.857143 -0.857143 0.983864 -0.447735 MAarrowhead1
% End of user PostScript
.64286 .42857 m
.68045 .4893 L
s
% Start of user PostScript
0.857143 -0.428571 1.08272 -0.0641721 MAarrowhead1
% End of user PostScript
.64286 .5 m
.71429 .5 L
s
% Start of user PostScript
0.857143 0 1.28571 0 MAarrowhead1
% End of user PostScript
.64286 .57143 m
.68045 .5107 L
s
% Start of user PostScript
0.857143 0.428571 1.08272 0.0641721 MAarrowhead1
% End of user PostScript
.64286 .64286 m
.66398 .57462 L
s
% Start of user PostScript
0.857143 0.857143 0.983864 0.447735 MAarrowhead1
% End of user PostScript
.64286 .71429 m
.65729 .64433 L
s
% Start of user PostScript
0.857143 1.28571 0.943754 0.865986 MAarrowhead1
% End of user PostScript
.64286 .78571 m
.65378 .71513 L
s
% Start of user PostScript
0.857143 1.71429 0.922689 1.29076 MAarrowhead1
% End of user PostScript
.64286 .85714 m
.65163 .78626 L
s
% Start of user PostScript
0.857143 2.14286 0.909802 1.71753 MAarrowhead1
% End of user PostScript
.64286 .92857 m
.65019 .85752 L
s
% Start of user PostScript
0.857143 2.57143 0.901127 2.14512 MAarrowhead1
% End of user PostScript
.64286 1 m
.64915 .92885 L
s
% Start of user PostScript
0.857143 3. 0.894896 2.57309 MAarrowhead1
% End of user PostScript
.71429 0 m
0 0 rlineto s
% Start of user PostScript
1.28571 -3. 1.37687 -3.41876 MAarrowhead1
% End of user PostScript
.71429 .07143 m
.73187 .0022 L
s
% Start of user PostScript
1.28571 -2.57143 1.39121 -2.98681 MAarrowhead1
% End of user PostScript
.71429 .14286 m
.73511 .07453 L
s
% Start of user PostScript
1.28571 -2.14286 1.41065 -2.55281 MAarrowhead1
% End of user PostScript
.71429 .21429 m
.73971 .14754 L
s
% Start of user PostScript
1.28571 -1.71429 1.43828 -2.11478 MAarrowhead1
% End of user PostScript
.71429 .28571 m
.74663 .22203 L
s
% Start of user PostScript
1.28571 -1.28571 1.4798 -1.66782 MAarrowhead1
% End of user PostScript
.71429 .35714 m
.75757 .30033 L
s
% Start of user PostScript
1.28571 -0.857143 1.54545 -1.19804 MAarrowhead1
% End of user PostScript
.71429 .42857 m
.774 .38938 L
s
% Start of user PostScript
1.28571 -0.428571 1.64402 -0.66371 MAarrowhead1
% End of user PostScript
.71429 .5 m
.78571 .5 L
s
% Start of user PostScript
1.28571 0 1.71429 0 MAarrowhead1
% End of user PostScript
.71429 .57143 m
.774 .61062 L
s
% Start of user PostScript
1.28571 0.428571 1.64402 0.66371 MAarrowhead1
% End of user PostScript
.71429 .64286 m
.75757 .69967 L
s
% Start of user PostScript
1.28571 0.857143 1.54545 1.19804 MAarrowhead1
% End of user PostScript
.71429 .71429 m
.74663 .77797 L
s
% Start of user PostScript
1.28571 1.28571 1.4798 1.66782 MAarrowhead1
% End of user PostScript
.71429 .78571 m
.73971 .85246 L
s
% Start of user PostScript
1.28571 1.71429 1.43828 2.11478 MAarrowhead1
% End of user PostScript
.71429 .85714 m
.73511 .92547 L
s
% Start of user PostScript
1.28571 2.14286 1.41065 2.55281 MAarrowhead1
% End of user PostScript
.71429 .92857 m
.73187 .9978 L
s
% Start of user PostScript
1.28571 2.57143 1.39121 2.98681 MAarrowhead1
% End of user PostScript
.71429 1 m
0 0 rlineto s
.71429 1 m
.71429 1 L
s
% Start of user PostScript
1.28571 3. 1.37687 3.41876 MAarrowhead1
% End of user PostScript
.78571 0 m
0 0 rlineto s
% Start of user PostScript
1.71429 -3. 1.9469 -3.35995 MAarrowhead1
% End of user PostScript
.78571 .07143 m
.82872 .01439 L
s
% Start of user PostScript
1.71429 -2.57143 1.9723 -2.91363 MAarrowhead1
% End of user PostScript
.78571 .14286 m
.83364 .08989 L
s
% Start of user PostScript
1.71429 -2.14286 2.00182 -2.46066 MAarrowhead1
% End of user PostScript
.78571 .21429 m
.83922 .16697 L
s
% Start of user PostScript
1.71429 -1.71429 2.03535 -1.99817 MAarrowhead1
% End of user PostScript
.78571 .28571 m
.84524 .24624 L
s
% Start of user PostScript
1.71429 -1.28571 2.07146 -1.52257 MAarrowhead1
% End of user PostScript
.78571 .35714 m
.85104 .32826 L
s
% Start of user PostScript
1.71429 -0.857143 2.10626 -1.03044 MAarrowhead1
% End of user PostScript
.78571 .42857 m
.85546 .41315 L
s
% Start of user PostScript
1.71429 -0.428571 2.13275 -0.521075 MAarrowhead1
% End of user PostScript
.78571 .5 m
.85714 .5 L
s
% Start of user PostScript
1.71429 0 2.14286 0 MAarrowhead1
% End of user PostScript
.78571 .57143 m
.85546 .58685 L
s
% Start of user PostScript
1.71429 0.428571 2.13275 0.521075 MAarrowhead1
% End of user PostScript
.78571 .64286 m
.85104 .67174 L
s
% Start of user PostScript
1.71429 0.857143 2.10626 1.03044 MAarrowhead1
% End of user PostScript
.78571 .71429 m
.84524 .75376 L
s
% Start of user PostScript
1.71429 1.28571 2.07146 1.52257 MAarrowhead1
% End of user PostScript
.78571 .78571 m
.83922 .83303 L
s
% Start of user PostScript
1.71429 1.71429 2.03535 1.99817 MAarrowhead1
% End of user PostScript
.78571 .85714 m
.83364 .91011 L
s
% Start of user PostScript
1.71429 2.14286 2.00182 2.46066 MAarrowhead1
% End of user PostScript
.78571 .92857 m
.82872 .98561 L
s
% Start of user PostScript
1.71429 2.57143 1.9723 2.91363 MAarrowhead1
% End of user PostScript
.78571 1 m
0 0 rlineto s
.78571 1 m
.78571 1 L
s
% Start of user PostScript
1.71429 3. 1.9469 3.35995 MAarrowhead1
% End of user PostScript
.85714 0 m
0 0 rlineto s
% Start of user PostScript
2.14286 -3. 2.47179 -3.27473 MAarrowhead1
% End of user PostScript
.85714 .07143 m
.91522 .02985 L
s
% Start of user PostScript
2.14286 -2.57143 2.49133 -2.82091 MAarrowhead1
% End of user PostScript
.85714 .14286 m
.91848 .10626 L
s
% Start of user PostScript
2.14286 -2.14286 2.51091 -2.36243 MAarrowhead1
% End of user PostScript
.85714 .21429 m
.92161 .18352 L
s
% Start of user PostScript
2.14286 -1.71429 2.52963 -1.89888 MAarrowhead1
% End of user PostScript
.85714 .28571 m
.92439 .26164 L
s
% Start of user PostScript
2.14286 -1.28571 2.54636 -1.43015 MAarrowhead1
% End of user PostScript
.85714 .35714 m
.92662 .34056 L
s
% Start of user PostScript
2.14286 -0.857143 2.55972 -0.956622 MAarrowhead1
% End of user PostScript
.85714 .42857 m
.92807 .42011 L
s
% Start of user PostScript
2.14286 -0.428571 2.56841 -0.479348 MAarrowhead1
% End of user PostScript
.85714 .5 m
.92857 .5 L
s
% Start of user PostScript
2.14286 0 2.57143 0 MAarrowhead1
% End of user PostScript
.85714 .57143 m
.92807 .57989 L
s
% Start of user PostScript
2.14286 0.428571 2.56841 0.479348 MAarrowhead1
% End of user PostScript
.85714 .64286 m
.92662 .65944 L
s
% Start of user PostScript
2.14286 0.857143 2.55972 0.956622 MAarrowhead1
% End of user PostScript
.85714 .71429 m
.92439 .73836 L
s
% Start of user PostScript
2.14286 1.28571 2.54636 1.43015 MAarrowhead1
% End of user PostScript
.85714 .78571 m
.92161 .81648 L
s
% Start of user PostScript
2.14286 1.71429 2.52963 1.89888 MAarrowhead1
% End of user PostScript
.85714 .85714 m
.91848 .89374 L
s
% Start of user PostScript
2.14286 2.14286 2.51091 2.36243 MAarrowhead1
% End of user PostScript
.85714 .92857 m
.91522 .97015 L
s
% Start of user PostScript
2.14286 2.57143 2.49133 2.82091 MAarrowhead1
% End of user PostScript
.85714 1 m
0 0 rlineto s
.85714 1 m
.85714 1 L
s
% Start of user PostScript
2.14286 3. 2.47179 3.27473 MAarrowhead1
% End of user PostScript
.92857 0 m
0 0 rlineto s
% Start of user PostScript
2.57143 -3. 2.94939 -3.20204 MAarrowhead1
% End of user PostScript
.92857 .07143 m
.99351 .04168 L
s
% Start of user PostScript
2.57143 -2.57143 2.96105 -2.74995 MAarrowhead1
% End of user PostScript
.92857 .14286 m
.9953 .11738 L
s
% Start of user PostScript
2.57143 -2.14286 2.97181 -2.29573 MAarrowhead1
% End of user PostScript
.92857 .21429 m
.99688 .19342 L
s
% Start of user PostScript
2.57143 -1.71429 2.98131 -1.83948 MAarrowhead1
% End of user PostScript
.92857 .28571 m
.9982 .26976 L
s
% Start of user PostScript
2.57143 -1.28571 2.98918 -1.38142 MAarrowhead1
% End of user PostScript
.92857 .35714 m
.99918 .34636 L
s
% Start of user PostScript
2.57143 -0.857143 2.99509 -0.921847 MAarrowhead1
% End of user PostScript
.92857 .42857 m
.99979 .42313 L
s
% Start of user PostScript
2.57143 -0.428571 2.99876 -0.461204 MAarrowhead1
% End of user PostScript
.92857 .5 m
1 .5 L
s
% Start of user PostScript
2.57143 0 3. 0 MAarrowhead1
% End of user PostScript
.92857 .57143 m
.99979 .57687 L
s
% Start of user PostScript
2.57143 0.428571 2.99876 0.461204 MAarrowhead1
% End of user PostScript
.92857 .64286 m
.99918 .65364 L
s
% Start of user PostScript
2.57143 0.857143 2.99509 0.921847 MAarrowhead1
% End of user PostScript
.92857 .71429 m
.9982 .73024 L
s
% Start of user PostScript
2.57143 1.28571 2.98918 1.38142 MAarrowhead1
% End of user PostScript
.92857 .78571 m
.99688 .80658 L
s
% Start of user PostScript
2.57143 1.71429 2.98131 1.83948 MAarrowhead1
% End of user PostScript
.92857 .85714 m
.9953 .88262 L
s
% Start of user PostScript
2.57143 2.14286 2.97181 2.29573 MAarrowhead1
% End of user PostScript
.92857 .92857 m
.99351 .95832 L
s
% Start of user PostScript
2.57143 2.57143 2.96105 2.74995 MAarrowhead1
% End of user PostScript
.92857 1 m
0 0 rlineto s
.92857 1 m
.92857 1 L
s
% Start of user PostScript
2.57143 3. 2.94939 3.20204 MAarrowhead1
% End of user PostScript
1 0 m
0 0 rlineto s
% Start of user PostScript
3. -3. 3.40128 -3.15048 MAarrowhead1
% End of user PostScript
1 .07143 m
0 0 rlineto s
1 .07143 m
1 .07143 L
s
% Start of user PostScript
3. -2.57143 3.40801 -2.70258 MAarrowhead1
% End of user PostScript
1 .14286 m
0 0 rlineto s
1 .14286 m
1 .14286 L
s
% Start of user PostScript
3. -2.14286 3.41398 -2.25374 MAarrowhead1
% End of user PostScript
1 .21429 m
0 0 rlineto s
1 .21429 m
1 .21429 L
s
% Start of user PostScript
3. -1.71429 3.41906 -1.80408 MAarrowhead1
% End of user PostScript
1 .28571 m
0 0 rlineto s
1 .28571 m
1 .28571 L
s
% Start of user PostScript
3. -1.28571 3.42314 -1.35372 MAarrowhead1
% End of user PostScript
1 .35714 m
0 0 rlineto s
1 .35714 m
1 .35714 L
s
% Start of user PostScript
3. -0.857143 3.42613 -0.9028 MAarrowhead1
% End of user PostScript
1 .42857 m
0 0 rlineto s
1 .42857 m
1 .42857 L
s
% Start of user PostScript
3. -0.428571 3.42796 -0.451498 MAarrowhead1
% End of user PostScript
1 .5 m
0 0 rlineto s
1 .5 m
1 .5 L
s
% Start of user PostScript
3. 0 3.42857 0 MAarrowhead1
% End of user PostScript
1 .57143 m
0 0 rlineto s
1 .57143 m
1 .57143 L
s
% Start of user PostScript
3. 0.428571 3.42796 0.451498 MAarrowhead1
% End of user PostScript
1 .64286 m
0 0 rlineto s
1 .64286 m
1 .64286 L
s
% Start of user PostScript
3. 0.857143 3.42613 0.9028 MAarrowhead1
% End of user PostScript
1 .71429 m
0 0 rlineto s
1 .71429 m
1 .71429 L
s
% Start of user PostScript
3. 1.28571 3.42314 1.35372 MAarrowhead1
% End of user PostScript
1 .78571 m
0 0 rlineto s
1 .78571 m
1 .78571 L
s
% Start of user PostScript
3. 1.71429 3.41906 1.80408 MAarrowhead1
% End of user PostScript
1 .85714 m
0 0 rlineto s
1 .85714 m
1 .85714 L
s
% Start of user PostScript
3. 2.14286 3.41398 2.25374 MAarrowhead1
% End of user PostScript
1 .92857 m
0 0 rlineto s
1 .92857 m
1 .92857 L
s
% Start of user PostScript
3. 2.57143 3.40801 2.70258 MAarrowhead1
% End of user PostScript
1 1 m
0 0 rlineto s
1 1 m
1 1 L
s
% Start of user PostScript
3. 3. 3.40128 3.15048 MAarrowhead1
% End of user PostScript
.01 w
.50012 0 m
.5411 .1113 L
.58172 .2076 L
.60235 .25553 L
.62492 .31081 L
.63534 .33897 L
.64647 .37303 L
.65188 .39226 L
.65698 .41349 L
.66156 .43763 L
.66281 .44593 L
.66414 .45633 L
.66528 .46765 L
.66652 .48968 L
s
.43606 0 m
.43719 .00452 L
.45925 .07218 L
.49889 .16443 L
.5411 .24086 L
.58172 .30507 L
.60235 .33702 L
.62492 .37387 L
.63534 .39264 L
.64647 .41535 L
.65188 .42817 L
.65698 .44233 L
.66156 .45842 L
.66281 .46396 L
.66414 .47088 L
.66528 .47843 L
.66652 .49312 L
s
.36689 0 m
.37557 .06248 L
.38083 .09114 L
.38655 .11761 L
.39694 .1568 L
.41643 .21077 L
.43719 .25226 L
.45925 .28609 L
.49889 .33222 L
.5411 .37043 L
.58172 .40253 L
.60235 .41851 L
.62492 .43694 L
.63534 .44632 L
.64647 .45768 L
.65188 .46409 L
.65698 .47116 L
.66156 .47921 L
.66281 .48198 L
.66414 .48544 L
.66528 .48922 L
.66652 .49656 L
s
0 .5 m
.00123 .5 L
.00236 .5 L
.00365 .5 L
.00488 .5 L
.00601 .5 L
.00706 .5 L
.00821 .5 L
.00942 .5 L
.01065 .5 L
.01196 .5 L
.0132 .5 L
.01434 .5 L
.01566 .5 L
.01641 .5 L
.01711 .5 L
.01839 .5 L
.01975 .5 L
.02043 .5 L
.02115 .5 L
.02245 .5 L
.02317 .5 L
.02384 .5 L
.02458 .5 L
.02537 .5 L
.02605 .5 L
.02679 .5 L
.02814 .5 L
.02945 .5 L
.03067 .5 L
.03184 .5 L
.03295 .5 L
.03416 .5 L
.03547 .5 L
.03676 .5 L
.03813 .5 L
.03929 .5 L
.04057 .5 L
.04131 .5 L
.042 .5 L
.04275 .5 L
.04355 .5 L
.0449 .5 L
.04566 .5 L
.04637 .5 L
.0477 .5 L
.04892 .5 L
.04959 .5 L
.05032 .5 L
.05165 .5 L
Mistroke
.05245 .5 L
.05321 .5 L
.05389 .5 L
.05462 .5 L
.05543 .5 L
.05627 .5 L
.057 .5 L
.05779 .5 L
.05854 .5 L
.05921 .5 L
.06 .5 L
.06074 .5 L
.06205 .5 L
.0628 .5 L
.06349 .5 L
.06471 .5 L
.06603 .5 L
.06727 .5 L
.06841 .5 L
.06967 .5 L
.07105 .5 L
.07175 .5 L
.07249 .5 L
.07383 .5 L
.07457 .5 L
.07525 .5 L
.076 .5 L
.07679 .5 L
.07812 .5 L
.07888 .5 L
.07959 .5 L
.0809 .5 L
.08211 .5 L
.08349 .5 L
.08481 .5 L
.086 .5 L
.08729 .5 L
.0885 .5 L
.08962 .5 L
.09085 .5 L
.0922 .5 L
.09289 .5 L
.09361 .5 L
.09493 .5 L
.09565 .5 L
.09632 .5 L
.09705 .5 L
.09783 .5 L
.09913 .5 L
.09987 .5 L
Mistroke
.10056 .5 L
.10185 .5 L
.10303 .5 L
.10439 .5 L
.10569 .5 L
.10691 .5 L
.10801 .5 L
.10928 .5 L
.11048 .5 L
.1116 .5 L
.11262 .5 L
.11375 .5 L
.11493 .5 L
.11613 .5 L
.11742 .5 L
.11864 .5 L
.11974 .5 L
.12104 .5 L
.12178 .5 L
.12245 .5 L
.1237 .5 L
.12502 .5 L
.12622 .5 L
.12753 .5 L
.12889 .5 L
.13016 .5 L
.13135 .5 L
.13244 .5 L
.13369 .5 L
.13487 .5 L
.13616 .5 L
.13752 .5 L
.13868 .5 L
.13996 .5 L
.14134 .5 L
.14211 .5 L
.14281 .5 L
.14418 .5 L
.14548 .5 L
.14669 .5 L
.14779 .5 L
.14906 .5 L
.15025 .5 L
.15136 .5 L
.15237 .5 L
.15349 .5 L
.15467 .5 L
.15586 .5 L
.15714 .5 L
.15835 .5 L
Mistroke
.15945 .5 L
.16074 .5 L
.16146 .5 L
.16214 .5 L
.16337 .5 L
.16468 .5 L
.16594 .5 L
.16732 .5 L
.16863 .5 L
.16984 .5 L
.17103 .5 L
.17212 .5 L
.17337 .5 L
.17456 .5 L
.17585 .5 L
.17721 .5 L
.17838 .5 L
.17966 .5 L
.18104 .5 L
.18181 .5 L
.18251 .5 L
.18388 .5 L
.18518 .5 L
.18628 .5 L
.1875 .5 L
.18877 .5 L
.18996 .5 L
.19107 .5 L
.19209 .5 L
.19321 .5 L
.19438 .5 L
.19558 .5 L
.19686 .5 L
.19807 .5 L
.19916 .5 L
.20045 .5 L
.20118 .5 L
.20185 .5 L
.20309 .5 L
.20439 .5 L
.20566 .5 L
.20705 .5 L
.20835 .5 L
.20957 .5 L
.21077 .5 L
.21186 .5 L
.21311 .5 L
.2143 .5 L
.21559 .5 L
.21696 .5 L
Mistroke
.21813 .5 L
.21941 .5 L
.22079 .5 L
.22157 .5 L
.22227 .5 L
.22364 .5 L
.22494 .5 L
.22604 .5 L
.22726 .5 L
.22853 .5 L
.22973 .5 L
.23084 .5 L
.23186 .5 L
.23297 .5 L
.23415 .5 L
.23535 .5 L
.23663 .5 L
.23784 .5 L
.23893 .5 L
.24023 .5 L
.24095 .5 L
.24163 .5 L
.24286 .5 L
.24416 .5 L
.24544 .5 L
.24683 .5 L
.24814 .5 L
.24935 .5 L
.25044 .5 L
.25165 .5 L
.25291 .5 L
.25409 .5 L
.25539 .5 L
.25676 .5 L
.25793 .5 L
.25922 .5 L
.2606 .5 L
.26137 .5 L
.26208 .5 L
.26345 .5 L
.26475 .5 L
.26586 .5 L
.26708 .5 L
.26835 .5 L
.26954 .5 L
.27066 .5 L
.27168 .5 L
.27286 .5 L
.27397 .5 L
.27518 .5 L
Mistroke
.27646 .5 L
.27767 .5 L
.27876 .5 L
.28005 .5 L
.28078 .5 L
.28145 .5 L
.28268 .5 L
.28399 .5 L
.28527 .5 L
.28599 .5 L
.28666 .5 L
.28789 .5 L
.28919 .5 L
.29036 .5 L
.29145 .5 L
.29265 .5 L
.29394 .5 L
.29524 .5 L
.29597 .5 L
.29665 .5 L
.29803 .5 L
.29881 .5 L
.29951 .5 L
.30077 .5 L
.30213 .5 L
.30342 .5 L
.30461 .5 L
.30572 .5 L
.30691 .5 L
.30804 .5 L
.30907 .5 L
.31027 .5 L
.31158 .5 L
.31282 .5 L
.31396 .5 L
.31526 .5 L
.31648 .5 L
.31758 .5 L
.31876 .5 L
.32005 .5 L
.32142 .5 L
.32259 .5 L
.32386 .5 L
.32524 .5 L
.32651 .5 L
.32718 .5 L
.32791 .5 L
.32867 .5 L
.32939 .5 L
.3307 .5 L
Mistroke
.3319 .5 L
.33329 .5 L
.33461 .5 L
.33578 .5 L
.33704 .5 L
.33822 .5 L
.33929 .5 L
.34055 .5 L
.34192 .5 L
.34321 .5 L
.3444 .5 L
.34567 .5 L
.34703 .5 L
.34831 .5 L
.34949 .5 L
.35086 .5 L
.35164 .5 L
.35236 .5 L
.35368 .5 L
.35434 .5 L
.35508 .5 L
.35579 .5 L
.35654 .5 L
.35788 .5 L
.35863 .5 L
.35932 .5 L
.36009 .5 L
.3609 .5 L
.36161 .5 L
.36238 .5 L
.3631 .5 L
.36377 .5 L
.36503 .5 L
.36637 .5 L
.36764 .5 L
.36902 .5 L
.37033 .5 L
.37154 .5 L
.37274 .5 L
.37383 .5 L
.37509 .5 L
.37627 .5 L
.37756 .5 L
.37893 .5 L
.3801 .5 L
.38138 .5 L
.38276 .5 L
.38353 .5 L
.38424 .5 L
.38561 .5 L
Mistroke
.38691 .5 L
.38801 .5 L
.38923 .5 L
.3905 .5 L
.39169 .5 L
.3928 .5 L
.39382 .5 L
.39494 .5 L
.39612 .5 L
.39732 .5 L
.3986 .5 L
.3998 .5 L
.4009 .5 L
.40219 .5 L
.40292 .5 L
.40359 .5 L
.40482 .5 L
.40613 .5 L
.4074 .5 L
.40879 .5 L
.4101 .5 L
.41132 .5 L
.41252 .5 L
.41361 .5 L
.41487 .5 L
.41605 .5 L
.41735 .5 L
.41872 .5 L
.41989 .5 L
.42117 .5 L
.42256 .5 L
.42333 .5 L
.42404 .5 L
.42541 .5 L
.4267 .5 L
.42781 .5 L
.42903 .5 L
.43031 .5 L
.4315 .5 L
.43261 .5 L
.43363 .5 L
.43481 .5 L
.43593 .5 L
.43713 .5 L
.43841 .5 L
.43962 .5 L
.44071 .5 L
.44201 .5 L
.44273 .5 L
.4434 .5 L
Mistroke
.44464 .5 L
.44594 .5 L
.44722 .5 L
.44794 .5 L
.44861 .5 L
.44984 .5 L
.45114 .5 L
.45231 .5 L
.4534 .5 L
.4546 .5 L
.45589 .5 L
.45718 .5 L
.45792 .5 L
.4586 .5 L
.45998 .5 L
.46075 .5 L
.46145 .5 L
.46271 .5 L
.46408 .5 L
.46537 .5 L
.46656 .5 L
.46766 .5 L
.46886 .5 L
.46998 .5 L
.47101 .5 L
.47221 .5 L
.47352 .5 L
.47476 .5 L
.4759 .5 L
.4772 .5 L
.47842 .5 L
.47952 .5 L
.4807 .5 L
.48199 .5 L
.48336 .5 L
.48453 .5 L
.4858 .5 L
.48718 .5 L
.48845 .5 L
.48911 .5 L
.48984 .5 L
.49061 .5 L
.49132 .5 L
.49264 .5 L
.49384 .5 L
.49516 .5 L
.49655 .5 L
.49772 .5 L
.49897 .5 L
.50015 .5 L
Mistroke
.50122 .5 L
.50248 .5 L
.50385 .5 L
.50514 .5 L
.50633 .5 L
.5076 .5 L
.50896 .5 L
.51024 .5 L
.51142 .5 L
.51279 .5 L
.51357 .5 L
.51429 .5 L
.5156 .5 L
.51627 .5 L
.51701 .5 L
.51772 .5 L
.51847 .5 L
.51981 .5 L
.52055 .5 L
.52125 .5 L
.52201 .5 L
.52283 .5 L
.52354 .5 L
.5243 .5 L
.52503 .5 L
.52569 .5 L
.52696 .5 L
.5283 .5 L
.52957 .5 L
.53095 .5 L
.53225 .5 L
.53347 .5 L
.53467 .5 L
.53575 .5 L
.53701 .5 L
.53819 .5 L
.53948 .5 L
.54085 .5 L
.54202 .5 L
.5433 .5 L
.54468 .5 L
.54545 .5 L
.54616 .5 L
.54753 .5 L
.54882 .5 L
.54993 .5 L
.55114 .5 L
.55241 .5 L
.55361 .5 L
.55472 .5 L
Mistroke
.55574 .5 L
.55685 .5 L
.55803 .5 L
.55923 .5 L
.56051 .5 L
.56172 .5 L
.56281 .5 L
.5641 .5 L
.56483 .5 L
.5655 .5 L
.56674 .5 L
.56804 .5 L
.56932 .5 L
.5707 .5 L
.57201 .5 L
.57323 .5 L
.57443 .5 L
.57552 .5 L
.57678 .5 L
.57796 .5 L
.57926 .5 L
.58063 .5 L
.5818 .5 L
.58308 .5 L
.58446 .5 L
.58524 .5 L
.58594 .5 L
.58731 .5 L
.58861 .5 L
.58971 .5 L
.59093 .5 L
.59221 .5 L
.5934 .5 L
.59451 .5 L
.59553 .5 L
.59671 .5 L
.59783 .5 L
.59903 .5 L
.60031 .5 L
.60152 .5 L
.60261 .5 L
.60391 .5 L
.60463 .5 L
.6053 .5 L
.60654 .5 L
.60784 .5 L
.60912 .5 L
.60984 .5 L
.61051 .5 L
.61174 .5 L
Mistroke
.61304 .5 L
.6142 .5 L
.61529 .5 L
.61649 .5 L
.61778 .5 L
.61908 .5 L
.61981 .5 L
.62049 .5 L
.62187 .5 L
.62264 .5 L
.62335 .5 L
.6246 .5 L
.62597 .5 L
.62726 .5 L
.62845 .5 L
.62955 .5 L
.63075 .5 L
.63187 .5 L
.6329 .5 L
.6341 .5 L
.63541 .5 L
.63665 .5 L
.63779 .5 L
.63909 .5 L
.64031 .5 L
.6414 .5 L
.64259 .5 L
.64388 .5 L
.64525 .5 L
.64641 .5 L
.64769 .5 L
.64907 .5 L
.65034 .5 L
.651 .5 L
.65173 .5 L
.65249 .5 L
.65321 .5 L
.65452 .5 L
.65572 .5 L
.65704 .5 L
.65843 .5 L
.6596 .5 L
.66085 .5 L
.66203 .5 L
.6631 .5 L
.66436 .5 L
.66573 .5 L
.66702 .5 L
.66821 .5 L
.66947 .5 L
Mistroke
.67083 .5 L
.67212 .5 L
.67329 .5 L
.67467 .5 L
.67544 .5 L
.67616 .5 L
.67748 .5 L
.67815 .5 L
.67888 .5 L
.67959 .5 L
.68034 .5 L
.68168 .5 L
.68243 .5 L
.68312 .5 L
.68389 .5 L
.6847 .5 L
.68541 .5 L
.68618 .5 L
.6869 .5 L
.68757 .5 L
.68883 .5 L
.69018 .5 L
.69144 .5 L
.69282 .5 L
.69413 .5 L
.69534 .5 L
.69654 .5 L
.69762 .5 L
.69888 .5 L
.70006 .5 L
.70135 .5 L
.70272 .5 L
.70388 .5 L
.70517 .5 L
.70654 .5 L
.70732 .5 L
.70802 .5 L
.70939 .5 L
.71069 .5 L
.71179 .5 L
.71301 .5 L
.71428 .5 L
.71547 .5 L
.71658 .5 L
.7176 .5 L
.71872 .5 L
.71989 .5 L
.72109 .5 L
.72237 .5 L
.72358 .5 L
Mistroke
.72468 .5 L
.72597 .5 L
.72669 .5 L
.72737 .5 L
.7286 .5 L
.72991 .5 L
.73118 .5 L
.73256 .5 L
.73387 .5 L
.73508 .5 L
.73629 .5 L
.73738 .5 L
.73863 .5 L
.73982 .5 L
.74111 .5 L
.74248 .5 L
.74365 .5 L
.74493 .5 L
.74631 .5 L
.74709 .5 L
.74779 .5 L
.74916 .5 L
.75046 .5 L
.75157 .5 L
.75279 .5 L
.75406 .5 L
.75525 .5 L
.75636 .5 L
.75738 .5 L
.7585 .5 L
.75968 .5 L
.76088 .5 L
.76216 .5 L
.76337 .5 L
.76446 .5 L
.76575 .5 L
.76648 .5 L
.76715 .5 L
.76839 .5 L
.76969 .5 L
.77097 .5 L
.77169 .5 L
.77236 .5 L
.77358 .5 L
.77489 .5 L
.77605 .5 L
.77714 .5 L
.77834 .5 L
.77963 .5 L
.78092 .5 L
Mistroke
.78165 .5 L
.78233 .5 L
.78371 .5 L
.78448 .5 L
.78519 .5 L
.78644 .5 L
.78781 .5 L
.7891 .5 L
.79029 .5 L
.79139 .5 L
.79258 .5 L
.79371 .5 L
.79473 .5 L
.79593 .5 L
.79724 .5 L
.79848 .5 L
.79963 .5 L
.80093 .5 L
.80214 .5 L
.80324 .5 L
.80442 .5 L
.80572 .5 L
.80708 .5 L
.80825 .5 L
.80953 .5 L
.8109 .5 L
.81217 .5 L
.81283 .5 L
.81356 .5 L
.81432 .5 L
.81504 .5 L
.81635 .5 L
.81755 .5 L
.81887 .5 L
.82026 .5 L
.82143 .5 L
.82268 .5 L
.82386 .5 L
.82493 .5 L
.82619 .5 L
.82755 .5 L
.82884 .5 L
.83003 .5 L
.8313 .5 L
.83266 .5 L
.83394 .5 L
.83512 .5 L
.83649 .5 L
.83727 .5 L
.83798 .5 L
Mistroke
.8393 .5 L
.84004 .5 L
.84071 .5 L
.84142 .5 L
.84216 .5 L
.8435 .5 L
.84425 .5 L
.84495 .5 L
.84571 .5 L
.84653 .5 L
.84723 .5 L
.848 .5 L
.84872 .5 L
.84939 .5 L
.85066 .5 L
.852 .5 L
.85326 .5 L
.85464 .5 L
.85595 .5 L
.85716 .5 L
.85835 .5 L
.85944 .5 L
.86069 .5 L
.86188 .5 L
.86317 .5 L
.86453 .5 L
.8657 .5 L
.86698 .5 L
.86836 .5 L
.86913 .5 L
.86984 .5 L
.87121 .5 L
.8725 .5 L
.8736 .5 L
.87482 .5 L
.87609 .5 L
.87728 .5 L
.87839 .5 L
.87941 .5 L
.88053 .5 L
.8817 .5 L
.8829 .5 L
.88418 .5 L
.88539 .5 L
.88649 .5 L
.88778 .5 L
.8885 .5 L
.88918 .5 L
.89041 .5 L
.89172 .5 L
Mistroke
.89299 .5 L
.89437 .5 L
.89568 .5 L
.89689 .5 L
.89809 .5 L
.89918 .5 L
.90044 .5 L
.90162 .5 L
.90292 .5 L
.90428 .5 L
.90545 .5 L
.90673 .5 L
.90812 .5 L
.90889 .5 L
.90959 .5 L
.91096 .5 L
.91226 .5 L
.91337 .5 L
.91458 .5 L
.91586 .5 L
.91705 .5 L
.91816 .5 L
.91918 .5 L
.9203 .5 L
.92148 .5 L
.92268 .5 L
.92396 .5 L
.92516 .5 L
.92626 .5 L
.92755 .5 L
.92828 .5 L
.92895 .5 L
.93018 .5 L
.93149 .5 L
.93276 .5 L
.93348 .5 L
.93415 .5 L
.93538 .5 L
.93668 .5 L
.93784 .5 L
.93893 .5 L
.94013 .5 L
.94142 .5 L
.94271 .5 L
.94344 .5 L
.94412 .5 L
.9455 .5 L
.94627 .5 L
.94697 .5 L
.94823 .5 L
Mistroke
.9496 .5 L
.95089 .5 L
.95207 .5 L
.95318 .5 L
.95437 .5 L
.95549 .5 L
.95652 .5 L
.95772 .5 L
.95903 .5 L
.96027 .5 L
.96141 .5 L
.96271 .5 L
.96393 .5 L
.96502 .5 L
.96621 .5 L
.9675 .5 L
.96887 .5 L
.97003 .5 L
.97131 .5 L
.97224 .5 L
.9731 .5 L
.97404 .5 L
.97503 .5 L
.9759 .5 L
.97671 .5 L
.9776 .5 L
.97856 .5 L
.97936 .5 L
.98024 .5 L
.98115 .5 L
.982 .5 L
.9828 .5 L
.98353 .5 L
.98437 .5 L
.98516 .5 L
.98602 .5 L
.98696 .5 L
.98795 .5 L
.98887 .5 L
.98973 .5 L
.99051 .5 L
.99142 .5 L
.99228 .5 L
.99321 .5 L
.9942 .5 L
.99513 .5 L
.99598 .5 L
.99697 .5 L
.99805 .5 L
.99907 .5 L
Mistroke
1 .5 L
Mfstroke
.36689 1 m
.37557 .93752 L
.38083 .90886 L
.38655 .88239 L
.39694 .8432 L
.41643 .78923 L
.43719 .74774 L
.45925 .71391 L
.49889 .66778 L
.5411 .62957 L
.58172 .59747 L
.60235 .58149 L
.62492 .56306 L
.63534 .55368 L
.64647 .54232 L
.65188 .53591 L
.65698 .52884 L
.66156 .52079 L
.66281 .51802 L
.66414 .51456 L
.66528 .51078 L
.66652 .50344 L
s
.43606 1 m
.43719 .99548 L
.45925 .92782 L
.49889 .83557 L
.5411 .75914 L
.58172 .69493 L
.60235 .66298 L
.62492 .62613 L
.63534 .60736 L
.64647 .58465 L
.65188 .57183 L
.65698 .55767 L
.66156 .54158 L
.66281 .53604 L
.66414 .52912 L
.66528 .52157 L
.66652 .50688 L
s
.50012 1 m
.5411 .8887 L
.58172 .7924 L
.60235 .74447 L
.62492 .68919 L
.63534 .66103 L
.64647 .62697 L
.65188 .60774 L
.65698 .58651 L
.66156 .56237 L
.66281 .55407 L
.66414 .54367 L
.66528 .53235 L
.66652 .51032 L
s
0 .09175 m
.04057 .07785 L
.08481 .05829 L
.12636 .03359 L
.16632 .00035 L
s
.16632 .00035 m
.16663 0 L
s
.66752 .48544 m
.66887 .47661 L
.67014 .47066 L
.67131 .46616 L
.67687 .45025 L
.68263 .43829 L
.6881 .42904 L
.70824 .40387 L
.72756 .38654 L
.74863 .37176 L
.79136 .34938 L
.8325 .33361 L
.87622 .32065 L
.91834 .31066 L
.95888 .3027 L
1 .29588 L
s
0 .22783 m
.04057 .21856 L
.08481 .20553 L
.12636 .18906 L
.16632 .1669 L
.18687 .15168 L
.20885 .13093 L
.23122 .10258 L
.24149 .08593 L
.25237 .06466 L
.26235 .04069 L
.27334 .00722 L
s
.27334 .00722 m
.27514 0 L
s
.66752 .49029 m
.66887 .48441 L
.67014 .48044 L
.67131 .47744 L
.67687 .46684 L
.68263 .45886 L
.6881 .4527 L
.70824 .43591 L
.72756 .42436 L
.74863 .4145 L
.79136 .39959 L
.8325 .38907 L
.87622 .38043 L
.91834 .37377 L
.95888 .36847 L
1 .36392 L
s
0 .36392 m
.04057 .35928 L
.08481 .35276 L
.12636 .34453 L
.16632 .33345 L
.18687 .32584 L
.20885 .31546 L
.23122 .30129 L
.24149 .29296 L
.25237 .28233 L
.26235 .27035 L
.27334 .25361 L
.28334 .23355 L
.29271 .20806 L
.29792 .18951 L
.3036 .16373 L
.30898 .13125 L
.31155 .11152 L
.31396 .08938 L
.31634 .06314 L
.3189 .02763 L
s
.3189 .02763 m
.32044 0 L
s
.66752 .49515 m
.66887 .4922 L
.67014 .49022 L
.67131 .48872 L
.67687 .48342 L
.68263 .47943 L
.6881 .47635 L
.70824 .46796 L
.72756 .46218 L
.74863 .45725 L
.79136 .44979 L
.8325 .44454 L
.87622 .44022 L
.91834 .43689 L
.95888 .43423 L
1 .43196 L
s
0 .5 m
.00123 .5 L
.00236 .5 L
.00365 .5 L
.00488 .5 L
.00601 .5 L
.00706 .5 L
.00821 .5 L
.00942 .5 L
.01065 .5 L
.01196 .5 L
.0132 .5 L
.01434 .5 L
.01566 .5 L
.01641 .5 L
.01711 .5 L
.01839 .5 L
.01975 .5 L
.02043 .5 L
.02115 .5 L
.02245 .5 L
.02317 .5 L
.02384 .5 L
.02458 .5 L
.02537 .5 L
.02605 .5 L
.02679 .5 L
.02814 .5 L
.02945 .5 L
.03067 .5 L
.03184 .5 L
.03295 .5 L
.03416 .5 L
.03547 .5 L
.03676 .5 L
.03813 .5 L
.03929 .5 L
.04057 .5 L
.04131 .5 L
.042 .5 L
.04275 .5 L
.04355 .5 L
.0449 .5 L
.04566 .5 L
.04637 .5 L
.0477 .5 L
.04892 .5 L
.04959 .5 L
.05032 .5 L
.05165 .5 L
Mistroke
.05245 .5 L
.05321 .5 L
.05389 .5 L
.05462 .5 L
.05543 .5 L
.05627 .5 L
.057 .5 L
.05779 .5 L
.05854 .5 L
.05921 .5 L
.06 .5 L
.06074 .5 L
.06205 .5 L
.0628 .5 L
.06349 .5 L
.06471 .5 L
.06603 .5 L
.06727 .5 L
.06841 .5 L
.06967 .5 L
.07105 .5 L
.07175 .5 L
.07249 .5 L
.07383 .5 L
.07457 .5 L
.07525 .5 L
.076 .5 L
.07679 .5 L
.07812 .5 L
.07888 .5 L
.07959 .5 L
.0809 .5 L
.08211 .5 L
.08349 .5 L
.08481 .5 L
.086 .5 L
.08729 .5 L
.0885 .5 L
.08962 .5 L
.09085 .5 L
.0922 .5 L
.09289 .5 L
.09361 .5 L
.09493 .5 L
.09565 .5 L
.09632 .5 L
.09705 .5 L
.09783 .5 L
.09913 .5 L
.09987 .5 L
Mistroke
.10056 .5 L
.10185 .5 L
.10303 .5 L
.10439 .5 L
.10569 .5 L
.10691 .5 L
.10801 .5 L
.10928 .5 L
.11048 .5 L
.1116 .5 L
.11262 .5 L
.11375 .5 L
.11493 .5 L
.11613 .5 L
.11742 .5 L
.11864 .5 L
.11974 .5 L
.12104 .5 L
.12178 .5 L
.12245 .5 L
.1237 .5 L
.12502 .5 L
.12622 .5 L
.12753 .5 L
.12889 .5 L
.13016 .5 L
.13135 .5 L
.13244 .5 L
.13369 .5 L
.13487 .5 L
.13616 .5 L
.13752 .5 L
.13868 .5 L
.13996 .5 L
.14134 .5 L
.14211 .5 L
.14281 .5 L
.14418 .5 L
.14548 .5 L
.14669 .5 L
.14779 .5 L
.14906 .5 L
.15025 .5 L
.15136 .5 L
.15237 .5 L
.15349 .5 L
.15467 .5 L
.15586 .5 L
.15714 .5 L
.15835 .5 L
Mistroke
.15945 .5 L
.16074 .5 L
.16146 .5 L
.16214 .5 L
.16337 .5 L
.16468 .5 L
.16594 .5 L
.16732 .5 L
.16863 .5 L
.16984 .5 L
.17103 .5 L
.17212 .5 L
.17337 .5 L
.17456 .5 L
.17585 .5 L
.17721 .5 L
.17838 .5 L
.17966 .5 L
.18104 .5 L
.18181 .5 L
.18251 .5 L
.18388 .5 L
.18518 .5 L
.18628 .5 L
.1875 .5 L
.18877 .5 L
.18996 .5 L
.19107 .5 L
.19209 .5 L
.19321 .5 L
.19438 .5 L
.19558 .5 L
.19686 .5 L
.19807 .5 L
.19916 .5 L
.20045 .5 L
.20118 .5 L
.20185 .5 L
.20309 .5 L
.20439 .5 L
.20566 .5 L
.20705 .5 L
.20835 .5 L
.20957 .5 L
.21077 .5 L
.21186 .5 L
.21311 .5 L
.2143 .5 L
.21559 .5 L
.21696 .5 L
Mistroke
.21813 .5 L
.21941 .5 L
.22079 .5 L
.22157 .5 L
.22227 .5 L
.22364 .5 L
.22494 .5 L
.22604 .5 L
.22726 .5 L
.22853 .5 L
.22973 .5 L
.23084 .5 L
.23186 .5 L
.23297 .5 L
.23415 .5 L
.23535 .5 L
.23663 .5 L
.23784 .5 L
.23893 .5 L
.24023 .5 L
.24095 .5 L
.24163 .5 L
.24286 .5 L
.24416 .5 L
.24544 .5 L
.24683 .5 L
.24814 .5 L
.24935 .5 L
.25044 .5 L
.25165 .5 L
.25291 .5 L
.25409 .5 L
.25539 .5 L
.25676 .5 L
.25793 .5 L
.25922 .5 L
.2606 .5 L
.26137 .5 L
.26208 .5 L
.26345 .5 L
.26475 .5 L
.26586 .5 L
.26708 .5 L
.26835 .5 L
.26954 .5 L
.27066 .5 L
.27168 .5 L
.27286 .5 L
.27397 .5 L
.27518 .5 L
Mistroke
.27646 .5 L
.27767 .5 L
.27876 .5 L
.28005 .5 L
.28078 .5 L
.28145 .5 L
.28268 .5 L
.28399 .5 L
.28527 .5 L
.28599 .5 L
.28666 .5 L
.28789 .5 L
.28919 .5 L
.29036 .5 L
.29145 .5 L
.29265 .5 L
.29394 .5 L
.29524 .5 L
.29597 .5 L
.29665 .5 L
.29803 .5 L
.29881 .5 L
.29951 .5 L
.30077 .5 L
.30213 .5 L
.30342 .5 L
.30461 .5 L
.30572 .5 L
.30691 .5 L
.30804 .5 L
.30907 .5 L
.31027 .5 L
.31158 .5 L
.31282 .5 L
.31396 .5 L
.31526 .5 L
.31648 .5 L
.31758 .5 L
.31876 .5 L
.32005 .5 L
.32142 .5 L
.32259 .5 L
.32386 .5 L
.32524 .5 L
.32651 .5 L
.32718 .5 L
.32791 .5 L
.32867 .5 L
.32939 .5 L
.3307 .5 L
Mistroke
.3319 .5 L
.33329 .5 L
.33461 .5 L
.33578 .5 L
.33704 .5 L
.33822 .5 L
.33929 .5 L
.34055 .5 L
.34192 .5 L
.34321 .5 L
.3444 .5 L
.34567 .5 L
.34703 .5 L
.34831 .5 L
.34949 .5 L
.35086 .5 L
.35164 .5 L
.35236 .5 L
.35368 .5 L
.35434 .5 L
.35508 .5 L
.35579 .5 L
.35654 .5 L
.35788 .5 L
.35863 .5 L
.35932 .5 L
.36009 .5 L
.3609 .5 L
.36161 .5 L
.36238 .5 L
.3631 .5 L
.36377 .5 L
.36503 .5 L
.36637 .5 L
.36764 .5 L
.36902 .5 L
.37033 .5 L
.37154 .5 L
.37274 .5 L
.37383 .5 L
.37509 .5 L
.37627 .5 L
.37756 .5 L
.37893 .5 L
.3801 .5 L
.38138 .5 L
.38276 .5 L
.38353 .5 L
.38424 .5 L
.38561 .5 L
Mistroke
.38691 .5 L
.38801 .5 L
.38923 .5 L
.3905 .5 L
.39169 .5 L
.3928 .5 L
.39382 .5 L
.39494 .5 L
.39612 .5 L
.39732 .5 L
.3986 .5 L
.3998 .5 L
.4009 .5 L
.40219 .5 L
.40292 .5 L
.40359 .5 L
.40482 .5 L
.40613 .5 L
.4074 .5 L
.40879 .5 L
.4101 .5 L
.41132 .5 L
.41252 .5 L
.41361 .5 L
.41487 .5 L
.41605 .5 L
.41735 .5 L
.41872 .5 L
.41989 .5 L
.42117 .5 L
.42256 .5 L
.42333 .5 L
.42404 .5 L
.42541 .5 L
.4267 .5 L
.42781 .5 L
.42903 .5 L
.43031 .5 L
.4315 .5 L
.43261 .5 L
.43363 .5 L
.43481 .5 L
.43593 .5 L
.43713 .5 L
.43841 .5 L
.43962 .5 L
.44071 .5 L
.44201 .5 L
.44273 .5 L
.4434 .5 L
Mistroke
.44464 .5 L
.44594 .5 L
.44722 .5 L
.44794 .5 L
.44861 .5 L
.44984 .5 L
.45114 .5 L
.45231 .5 L
.4534 .5 L
.4546 .5 L
.45589 .5 L
.45718 .5 L
.45792 .5 L
.4586 .5 L
.45998 .5 L
.46075 .5 L
.46145 .5 L
.46271 .5 L
.46408 .5 L
.46537 .5 L
.46656 .5 L
.46766 .5 L
.46886 .5 L
.46998 .5 L
.47101 .5 L
.47221 .5 L
.47352 .5 L
.47476 .5 L
.4759 .5 L
.4772 .5 L
.47842 .5 L
.47952 .5 L
.4807 .5 L
.48199 .5 L
.48336 .5 L
.48453 .5 L
.4858 .5 L
.48718 .5 L
.48845 .5 L
.48911 .5 L
.48984 .5 L
.49061 .5 L
.49132 .5 L
.49264 .5 L
.49384 .5 L
.49516 .5 L
.49655 .5 L
.49772 .5 L
.49897 .5 L
.50015 .5 L
Mistroke
.50122 .5 L
.50248 .5 L
.50385 .5 L
.50514 .5 L
.50633 .5 L
.5076 .5 L
.50896 .5 L
.51024 .5 L
.51142 .5 L
.51279 .5 L
.51357 .5 L
.51429 .5 L
.5156 .5 L
.51627 .5 L
.51701 .5 L
.51772 .5 L
.51847 .5 L
.51981 .5 L
.52055 .5 L
.52125 .5 L
.52201 .5 L
.52283 .5 L
.52354 .5 L
.5243 .5 L
.52503 .5 L
.52569 .5 L
.52696 .5 L
.5283 .5 L
.52957 .5 L
.53095 .5 L
.53225 .5 L
.53347 .5 L
.53467 .5 L
.53575 .5 L
.53701 .5 L
.53819 .5 L
.53948 .5 L
.54085 .5 L
.54202 .5 L
.5433 .5 L
.54468 .5 L
.54545 .5 L
.54616 .5 L
.54753 .5 L
.54882 .5 L
.54993 .5 L
.55114 .5 L
.55241 .5 L
.55361 .5 L
.55472 .5 L
Mistroke
.55574 .5 L
.55685 .5 L
.55803 .5 L
.55923 .5 L
.56051 .5 L
.56172 .5 L
.56281 .5 L
.5641 .5 L
.56483 .5 L
.5655 .5 L
.56674 .5 L
.56804 .5 L
.56932 .5 L
.5707 .5 L
.57201 .5 L
.57323 .5 L
.57443 .5 L
.57552 .5 L
.57678 .5 L
.57796 .5 L
.57926 .5 L
.58063 .5 L
.5818 .5 L
.58308 .5 L
.58446 .5 L
.58524 .5 L
.58594 .5 L
.58731 .5 L
.58861 .5 L
.58971 .5 L
.59093 .5 L
.59221 .5 L
.5934 .5 L
.59451 .5 L
.59553 .5 L
.59671 .5 L
.59783 .5 L
.59903 .5 L
.60031 .5 L
.60152 .5 L
.60261 .5 L
.60391 .5 L
.60463 .5 L
.6053 .5 L
.60654 .5 L
.60784 .5 L
.60912 .5 L
.60984 .5 L
.61051 .5 L
.61174 .5 L
Mistroke
.61304 .5 L
.6142 .5 L
.61529 .5 L
.61649 .5 L
.61778 .5 L
.61908 .5 L
.61981 .5 L
.62049 .5 L
.62187 .5 L
.62264 .5 L
.62335 .5 L
.6246 .5 L
.62597 .5 L
.62726 .5 L
.62845 .5 L
.62955 .5 L
.63075 .5 L
.63187 .5 L
.6329 .5 L
.6341 .5 L
.63541 .5 L
.63665 .5 L
.63779 .5 L
.63909 .5 L
.64031 .5 L
.6414 .5 L
.64259 .5 L
.64388 .5 L
.64525 .5 L
.64641 .5 L
.64769 .5 L
.64907 .5 L
.65034 .5 L
.651 .5 L
.65173 .5 L
.65249 .5 L
.65321 .5 L
.65452 .5 L
.65572 .5 L
.65704 .5 L
.65843 .5 L
.6596 .5 L
.66085 .5 L
.66203 .5 L
.6631 .5 L
.66436 .5 L
.66573 .5 L
.66702 .5 L
.66821 .5 L
.66947 .5 L
Mistroke
.67083 .5 L
.67212 .5 L
.67329 .5 L
.67467 .5 L
.67544 .5 L
.67616 .5 L
.67748 .5 L
.67815 .5 L
.67888 .5 L
.67959 .5 L
.68034 .5 L
.68168 .5 L
.68243 .5 L
.68312 .5 L
.68389 .5 L
.6847 .5 L
.68541 .5 L
.68618 .5 L
.6869 .5 L
.68757 .5 L
.68883 .5 L
.69018 .5 L
.69144 .5 L
.69282 .5 L
.69413 .5 L
.69534 .5 L
.69654 .5 L
.69762 .5 L
.69888 .5 L
.70006 .5 L
.70135 .5 L
.70272 .5 L
.70388 .5 L
.70517 .5 L
.70654 .5 L
.70732 .5 L
.70802 .5 L
.70939 .5 L
.71069 .5 L
.71179 .5 L
.71301 .5 L
.71428 .5 L
.71547 .5 L
.71658 .5 L
.7176 .5 L
.71872 .5 L
.71989 .5 L
.72109 .5 L
.72237 .5 L
.72358 .5 L
Mistroke
.72468 .5 L
.72597 .5 L
.72669 .5 L
.72737 .5 L
.7286 .5 L
.72991 .5 L
.73118 .5 L
.73256 .5 L
.73387 .5 L
.73508 .5 L
.73629 .5 L
.73738 .5 L
.73863 .5 L
.73982 .5 L
.74111 .5 L
.74248 .5 L
.74365 .5 L
.74493 .5 L
.74631 .5 L
.74709 .5 L
.74779 .5 L
.74916 .5 L
.75046 .5 L
.75157 .5 L
.75279 .5 L
.75406 .5 L
.75525 .5 L
.75636 .5 L
.75738 .5 L
.7585 .5 L
.75968 .5 L
.76088 .5 L
.76216 .5 L
.76337 .5 L
.76446 .5 L
.76575 .5 L
.76648 .5 L
.76715 .5 L
.76839 .5 L
.76969 .5 L
.77097 .5 L
.77169 .5 L
.77236 .5 L
.77358 .5 L
.77489 .5 L
.77605 .5 L
.77714 .5 L
.77834 .5 L
.77963 .5 L
.78092 .5 L
Mistroke
.78165 .5 L
.78233 .5 L
.78371 .5 L
.78448 .5 L
.78519 .5 L
.78644 .5 L
.78781 .5 L
.7891 .5 L
.79029 .5 L
.79139 .5 L
.79258 .5 L
.79371 .5 L
.79473 .5 L
.79593 .5 L
.79724 .5 L
.79848 .5 L
.79963 .5 L
.80093 .5 L
.80214 .5 L
.80324 .5 L
.80442 .5 L
.80572 .5 L
.80708 .5 L
.80825 .5 L
.80953 .5 L
.8109 .5 L
.81217 .5 L
.81283 .5 L
.81356 .5 L
.81432 .5 L
.81504 .5 L
.81635 .5 L
.81755 .5 L
.81887 .5 L
.82026 .5 L
.82143 .5 L
.82268 .5 L
.82386 .5 L
.82493 .5 L
.82619 .5 L
.82755 .5 L
.82884 .5 L
.83003 .5 L
.8313 .5 L
.83266 .5 L
.83394 .5 L
.83512 .5 L
.83649 .5 L
.83727 .5 L
.83798 .5 L
Mistroke
.8393 .5 L
.84004 .5 L
.84071 .5 L
.84142 .5 L
.84216 .5 L
.8435 .5 L
.84425 .5 L
.84495 .5 L
.84571 .5 L
.84653 .5 L
.84723 .5 L
.848 .5 L
.84872 .5 L
.84939 .5 L
.85066 .5 L
.852 .5 L
.85326 .5 L
.85464 .5 L
.85595 .5 L
.85716 .5 L
.85835 .5 L
.85944 .5 L
.86069 .5 L
.86188 .5 L
.86317 .5 L
.86453 .5 L
.8657 .5 L
.86698 .5 L
.86836 .5 L
.86913 .5 L
.86984 .5 L
.87121 .5 L
.8725 .5 L
.8736 .5 L
.87482 .5 L
.87609 .5 L
.87728 .5 L
.87839 .5 L
.87941 .5 L
.88053 .5 L
.8817 .5 L
.8829 .5 L
.88418 .5 L
.88539 .5 L
.88649 .5 L
.88778 .5 L
.8885 .5 L
.88918 .5 L
.89041 .5 L
.89172 .5 L
Mistroke
.89299 .5 L
.89437 .5 L
.89568 .5 L
.89689 .5 L
.89809 .5 L
.89918 .5 L
.90044 .5 L
.90162 .5 L
.90292 .5 L
.90428 .5 L
.90545 .5 L
.90673 .5 L
.90812 .5 L
.90889 .5 L
.90959 .5 L
.91096 .5 L
.91226 .5 L
.91337 .5 L
.91458 .5 L
.91586 .5 L
.91705 .5 L
.91816 .5 L
.91918 .5 L
.9203 .5 L
.92148 .5 L
.92268 .5 L
.92396 .5 L
.92516 .5 L
.92626 .5 L
.92755 .5 L
.92828 .5 L
.92895 .5 L
.93018 .5 L
.93149 .5 L
.93276 .5 L
.93348 .5 L
.93415 .5 L
.93538 .5 L
.93668 .5 L
.93784 .5 L
.93893 .5 L
.94013 .5 L
.94142 .5 L
.94271 .5 L
.94344 .5 L
.94412 .5 L
.9455 .5 L
.94627 .5 L
.94697 .5 L
.94823 .5 L
Mistroke
.9496 .5 L
.95089 .5 L
.95207 .5 L
.95318 .5 L
.95437 .5 L
.95549 .5 L
.95652 .5 L
.95772 .5 L
.95903 .5 L
.96027 .5 L
.96141 .5 L
.96271 .5 L
.96393 .5 L
.96502 .5 L
.96621 .5 L
.9675 .5 L
.96887 .5 L
.97003 .5 L
.97131 .5 L
.97224 .5 L
.9731 .5 L
.97404 .5 L
.97503 .5 L
.9759 .5 L
.97671 .5 L
.9776 .5 L
.97856 .5 L
.97936 .5 L
.98024 .5 L
.98115 .5 L
.982 .5 L
.9828 .5 L
.98353 .5 L
.98437 .5 L
.98516 .5 L
.98602 .5 L
.98696 .5 L
.98795 .5 L
.98887 .5 L
.98973 .5 L
.99051 .5 L
.99142 .5 L
.99228 .5 L
.99321 .5 L
.9942 .5 L
.99513 .5 L
.99598 .5 L
.99697 .5 L
.99805 .5 L
.99907 .5 L
Mistroke
1 .5 L
Mfstroke
0 .63608 m
.04057 .64072 L
.08481 .64724 L
.12636 .65547 L
.16632 .66655 L
.18687 .67416 L
.20885 .68454 L
.23122 .69871 L
.24149 .70704 L
.25237 .71767 L
.26235 .72965 L
.27334 .74639 L
.28334 .76645 L
.29271 .79194 L
.29792 .81049 L
.3036 .83627 L
.30898 .86875 L
.31155 .88848 L
.31396 .91062 L
.31634 .93686 L
.3189 .97237 L
s
.3189 .97237 m
.32044 1 L
s
.66752 .50485 m
.66887 .5078 L
.67014 .50978 L
.67131 .51128 L
.67687 .51658 L
.68263 .52057 L
.6881 .52365 L
.70824 .53204 L
.72756 .53782 L
.74863 .54275 L
.79136 .55021 L
.8325 .55546 L
.87622 .55978 L
.91834 .56311 L
.95888 .56577 L
1 .56804 L
s
0 .77217 m
.04057 .78144 L
.08481 .79447 L
.12636 .81094 L
.16632 .8331 L
.18687 .84832 L
.20885 .86907 L
.23122 .89742 L
.24149 .91407 L
.25237 .93534 L
.26235 .95931 L
.27334 .99278 L
s
.27334 .99278 m
.27514 1 L
s
.66752 .50971 m
.66887 .51559 L
.67014 .51956 L
.67131 .52256 L
.67687 .53316 L
.68263 .54114 L
.6881 .5473 L
.70824 .56409 L
.72756 .57564 L
.74863 .5855 L
.79136 .60041 L
.8325 .61093 L
.87622 .61957 L
.91834 .62623 L
.95888 .63153 L
1 .63608 L
s
0 .90825 m
.04057 .92215 L
.08481 .94171 L
.12636 .96641 L
.16632 .99965 L
s
.16632 .99965 m
.16663 1 L
s
.66752 .51456 m
.66887 .52339 L
.67014 .52934 L
.67131 .53384 L
.67687 .54975 L
.68263 .56171 L
.6881 .57096 L
.70824 .59613 L
.72756 .61346 L
.74863 .62824 L
.79136 .65062 L
.8325 .66639 L
.87622 .67935 L
.91834 .68934 L
.95888 .6973 L
1 .70412 L
s
.66752 .46433 m
.66887 .44272 L
.67014 .42814 L
.67131 .41711 L
.67687 .37815 L
.68263 .34883 L
.6881 .32619 L
.70824 .26453 L
.72756 .22209 L
.74863 .18587 L
.79136 .13105 L
.8325 .09243 L
.87622 .06068 L
.91834 .03621 L
.95888 .01671 L
1 0 L
s
.66752 .47622 m
.66887 .46181 L
.67014 .4521 L
.67131 .44474 L
.67687 .41877 L
.68263 .39922 L
.6881 .38413 L
.70824 .34302 L
.72756 .31472 L
.74863 .29058 L
.79136 .25404 L
.8325 .22829 L
.87622 .20712 L
.91834 .1908 L
.95888 .17781 L
1 .16667 L
s
0 .16667 m
.04057 .15531 L
.08481 .13935 L
.12636 .11917 L
.16632 .09204 L
.18687 .07339 L
.20885 .04798 L
.23122 .01326 L
s
.23122 .01326 m
.2379 0 L
s
.66752 .48811 m
.66887 .48091 L
.67014 .47605 L
.67131 .47237 L
.67687 .45938 L
.68263 .44961 L
.6881 .44206 L
.70824 .42151 L
.72756 .40736 L
.74863 .39529 L
.79136 .37702 L
.8325 .36414 L
.87622 .35356 L
.91834 .3454 L
.95888 .3389 L
1 .33333 L
s
0 .5 m
.00123 .5 L
.00236 .5 L
.00365 .5 L
.00488 .5 L
.00601 .5 L
.00706 .5 L
.00821 .5 L
.00942 .5 L
.01065 .5 L
.01196 .5 L
.0132 .5 L
.01434 .5 L
.01566 .5 L
.01641 .5 L
.01711 .5 L
.01839 .5 L
.01975 .5 L
.02043 .5 L
.02115 .5 L
.02245 .5 L
.02317 .5 L
.02384 .5 L
.02458 .5 L
.02537 .5 L
.02605 .5 L
.02679 .5 L
.02814 .5 L
.02945 .5 L
.03067 .5 L
.03184 .5 L
.03295 .5 L
.03416 .5 L
.03547 .5 L
.03676 .5 L
.03813 .5 L
.03929 .5 L
.04057 .5 L
.04131 .5 L
.042 .5 L
.04275 .5 L
.04355 .5 L
.0449 .5 L
.04566 .5 L
.04637 .5 L
.0477 .5 L
.04892 .5 L
.04959 .5 L
.05032 .5 L
.05165 .5 L
Mistroke
.05245 .5 L
.05321 .5 L
.05389 .5 L
.05462 .5 L
.05543 .5 L
.05627 .5 L
.057 .5 L
.05779 .5 L
.05854 .5 L
.05921 .5 L
.06 .5 L
.06074 .5 L
.06205 .5 L
.0628 .5 L
.06349 .5 L
.06471 .5 L
.06603 .5 L
.06727 .5 L
.06841 .5 L
.06967 .5 L
.07105 .5 L
.07175 .5 L
.07249 .5 L
.07383 .5 L
.07457 .5 L
.07525 .5 L
.076 .5 L
.07679 .5 L
.07812 .5 L
.07888 .5 L
.07959 .5 L
.0809 .5 L
.08211 .5 L
.08349 .5 L
.08481 .5 L
.086 .5 L
.08729 .5 L
.0885 .5 L
.08962 .5 L
.09085 .5 L
.0922 .5 L
.09289 .5 L
.09361 .5 L
.09493 .5 L
.09565 .5 L
.09632 .5 L
.09705 .5 L
.09783 .5 L
.09913 .5 L
.09987 .5 L
Mistroke
.10056 .5 L
.10185 .5 L
.10303 .5 L
.10439 .5 L
.10569 .5 L
.10691 .5 L
.10801 .5 L
.10928 .5 L
.11048 .5 L
.1116 .5 L
.11262 .5 L
.11375 .5 L
.11493 .5 L
.11613 .5 L
.11742 .5 L
.11864 .5 L
.11974 .5 L
.12104 .5 L
.12178 .5 L
.12245 .5 L
.1237 .5 L
.12502 .5 L
.12622 .5 L
.12753 .5 L
.12889 .5 L
.13016 .5 L
.13135 .5 L
.13244 .5 L
.13369 .5 L
.13487 .5 L
.13616 .5 L
.13752 .5 L
.13868 .5 L
.13996 .5 L
.14134 .5 L
.14211 .5 L
.14281 .5 L
.14418 .5 L
.14548 .5 L
.14669 .5 L
.14779 .5 L
.14906 .5 L
.15025 .5 L
.15136 .5 L
.15237 .5 L
.15349 .5 L
.15467 .5 L
.15586 .5 L
.15714 .5 L
.15835 .5 L
Mistroke
.15945 .5 L
.16074 .5 L
.16146 .5 L
.16214 .5 L
.16337 .5 L
.16468 .5 L
.16594 .5 L
.16732 .5 L
.16863 .5 L
.16984 .5 L
.17103 .5 L
.17212 .5 L
.17337 .5 L
.17456 .5 L
.17585 .5 L
.17721 .5 L
.17838 .5 L
.17966 .5 L
.18104 .5 L
.18181 .5 L
.18251 .5 L
.18388 .5 L
.18518 .5 L
.18628 .5 L
.1875 .5 L
.18877 .5 L
.18996 .5 L
.19107 .5 L
.19209 .5 L
.19321 .5 L
.19438 .5 L
.19558 .5 L
.19686 .5 L
.19807 .5 L
.19916 .5 L
.20045 .5 L
.20118 .5 L
.20185 .5 L
.20309 .5 L
.20439 .5 L
.20566 .5 L
.20705 .5 L
.20835 .5 L
.20957 .5 L
.21077 .5 L
.21186 .5 L
.21311 .5 L
.2143 .5 L
.21559 .5 L
.21696 .5 L
Mistroke
.21813 .5 L
.21941 .5 L
.22079 .5 L
.22157 .5 L
.22227 .5 L
.22364 .5 L
.22494 .5 L
.22604 .5 L
.22726 .5 L
.22853 .5 L
.22973 .5 L
.23084 .5 L
.23186 .5 L
.23297 .5 L
.23415 .5 L
.23535 .5 L
.23663 .5 L
.23784 .5 L
.23893 .5 L
.24023 .5 L
.24095 .5 L
.24163 .5 L
.24286 .5 L
.24416 .5 L
.24544 .5 L
.24683 .5 L
.24814 .5 L
.24935 .5 L
.25044 .5 L
.25165 .5 L
.25291 .5 L
.25409 .5 L
.25539 .5 L
.25676 .5 L
.25793 .5 L
.25922 .5 L
.2606 .5 L
.26137 .5 L
.26208 .5 L
.26345 .5 L
.26475 .5 L
.26586 .5 L
.26708 .5 L
.26835 .5 L
.26954 .5 L
.27066 .5 L
.27168 .5 L
.27286 .5 L
.27397 .5 L
.27518 .5 L
Mistroke
.27646 .5 L
.27767 .5 L
.27876 .5 L
.28005 .5 L
.28078 .5 L
.28145 .5 L
.28268 .5 L
.28399 .5 L
.28527 .5 L
.28599 .5 L
.28666 .5 L
.28789 .5 L
.28919 .5 L
.29036 .5 L
.29145 .5 L
.29265 .5 L
.29394 .5 L
.29524 .5 L
.29597 .5 L
.29665 .5 L
.29803 .5 L
.29881 .5 L
.29951 .5 L
.30077 .5 L
.30213 .5 L
.30342 .5 L
.30461 .5 L
.30572 .5 L
.30691 .5 L
.30804 .5 L
.30907 .5 L
.31027 .5 L
.31158 .5 L
.31282 .5 L
.31396 .5 L
.31526 .5 L
.31648 .5 L
.31758 .5 L
.31876 .5 L
.32005 .5 L
.32142 .5 L
.32259 .5 L
.32386 .5 L
.32524 .5 L
.32651 .5 L
.32718 .5 L
.32791 .5 L
.32867 .5 L
.32939 .5 L
.3307 .5 L
Mistroke
.3319 .5 L
.33329 .5 L
.33461 .5 L
.33578 .5 L
.33704 .5 L
.33822 .5 L
.33929 .5 L
.34055 .5 L
.34192 .5 L
.34321 .5 L
.3444 .5 L
.34567 .5 L
.34703 .5 L
.34831 .5 L
.34949 .5 L
.35086 .5 L
.35164 .5 L
.35236 .5 L
.35368 .5 L
.35434 .5 L
.35508 .5 L
.35579 .5 L
.35654 .5 L
.35788 .5 L
.35863 .5 L
.35932 .5 L
.36009 .5 L
.3609 .5 L
.36161 .5 L
.36238 .5 L
.3631 .5 L
.36377 .5 L
.36503 .5 L
.36637 .5 L
.36764 .5 L
.36902 .5 L
.37033 .5 L
.37154 .5 L
.37274 .5 L
.37383 .5 L
.37509 .5 L
.37627 .5 L
.37756 .5 L
.37893 .5 L
.3801 .5 L
.38138 .5 L
.38276 .5 L
.38353 .5 L
.38424 .5 L
.38561 .5 L
Mistroke
.38691 .5 L
.38801 .5 L
.38923 .5 L
.3905 .5 L
.39169 .5 L
.3928 .5 L
.39382 .5 L
.39494 .5 L
.39612 .5 L
.39732 .5 L
.3986 .5 L
.3998 .5 L
.4009 .5 L
.40219 .5 L
.40292 .5 L
.40359 .5 L
.40482 .5 L
.40613 .5 L
.4074 .5 L
.40879 .5 L
.4101 .5 L
.41132 .5 L
.41252 .5 L
.41361 .5 L
.41487 .5 L
.41605 .5 L
.41735 .5 L
.41872 .5 L
.41989 .5 L
.42117 .5 L
.42256 .5 L
.42333 .5 L
.42404 .5 L
.42541 .5 L
.4267 .5 L
.42781 .5 L
.42903 .5 L
.43031 .5 L
.4315 .5 L
.43261 .5 L
.43363 .5 L
.43481 .5 L
.43593 .5 L
.43713 .5 L
.43841 .5 L
.43962 .5 L
.44071 .5 L
.44201 .5 L
.44273 .5 L
.4434 .5 L
Mistroke
.44464 .5 L
.44594 .5 L
.44722 .5 L
.44794 .5 L
.44861 .5 L
.44984 .5 L
.45114 .5 L
.45231 .5 L
.4534 .5 L
.4546 .5 L
.45589 .5 L
.45718 .5 L
.45792 .5 L
.4586 .5 L
.45998 .5 L
.46075 .5 L
.46145 .5 L
.46271 .5 L
.46408 .5 L
.46537 .5 L
.46656 .5 L
.46766 .5 L
.46886 .5 L
.46998 .5 L
.47101 .5 L
.47221 .5 L
.47352 .5 L
.47476 .5 L
.4759 .5 L
.4772 .5 L
.47842 .5 L
.47952 .5 L
.4807 .5 L
.48199 .5 L
.48336 .5 L
.48453 .5 L
.4858 .5 L
.48718 .5 L
.48845 .5 L
.48911 .5 L
.48984 .5 L
.49061 .5 L
.49132 .5 L
.49264 .5 L
.49384 .5 L
.49516 .5 L
.49655 .5 L
.49772 .5 L
.49897 .5 L
.50015 .5 L
Mistroke
.50122 .5 L
.50248 .5 L
.50385 .5 L
.50514 .5 L
.50633 .5 L
.5076 .5 L
.50896 .5 L
.51024 .5 L
.51142 .5 L
.51279 .5 L
.51357 .5 L
.51429 .5 L
.5156 .5 L
.51627 .5 L
.51701 .5 L
.51772 .5 L
.51847 .5 L
.51981 .5 L
.52055 .5 L
.52125 .5 L
.52201 .5 L
.52283 .5 L
.52354 .5 L
.5243 .5 L
.52503 .5 L
.52569 .5 L
.52696 .5 L
.5283 .5 L
.52957 .5 L
.53095 .5 L
.53225 .5 L
.53347 .5 L
.53467 .5 L
.53575 .5 L
.53701 .5 L
.53819 .5 L
.53948 .5 L
.54085 .5 L
.54202 .5 L
.5433 .5 L
.54468 .5 L
.54545 .5 L
.54616 .5 L
.54753 .5 L
.54882 .5 L
.54993 .5 L
.55114 .5 L
.55241 .5 L
.55361 .5 L
.55472 .5 L
Mistroke
.55574 .5 L
.55685 .5 L
.55803 .5 L
.55923 .5 L
.56051 .5 L
.56172 .5 L
.56281 .5 L
.5641 .5 L
.56483 .5 L
.5655 .5 L
.56674 .5 L
.56804 .5 L
.56932 .5 L
.5707 .5 L
.57201 .5 L
.57323 .5 L
.57443 .5 L
.57552 .5 L
.57678 .5 L
.57796 .5 L
.57926 .5 L
.58063 .5 L
.5818 .5 L
.58308 .5 L
.58446 .5 L
.58524 .5 L
.58594 .5 L
.58731 .5 L
.58861 .5 L
.58971 .5 L
.59093 .5 L
.59221 .5 L
.5934 .5 L
.59451 .5 L
.59553 .5 L
.59671 .5 L
.59783 .5 L
.59903 .5 L
.60031 .5 L
.60152 .5 L
.60261 .5 L
.60391 .5 L
.60463 .5 L
.6053 .5 L
.60654 .5 L
.60784 .5 L
.60912 .5 L
.60984 .5 L
.61051 .5 L
.61174 .5 L
Mistroke
.61304 .5 L
.6142 .5 L
.61529 .5 L
.61649 .5 L
.61778 .5 L
.61908 .5 L
.61981 .5 L
.62049 .5 L
.62187 .5 L
.62264 .5 L
.62335 .5 L
.6246 .5 L
.62597 .5 L
.62726 .5 L
.62845 .5 L
.62955 .5 L
.63075 .5 L
.63187 .5 L
.6329 .5 L
.6341 .5 L
.63541 .5 L
.63665 .5 L
.63779 .5 L
.63909 .5 L
.64031 .5 L
.6414 .5 L
.64259 .5 L
.64388 .5 L
.64525 .5 L
.64641 .5 L
.64769 .5 L
.64907 .5 L
.65034 .5 L
.651 .5 L
.65173 .5 L
.65249 .5 L
.65321 .5 L
.65452 .5 L
.65572 .5 L
.65704 .5 L
.65843 .5 L
.6596 .5 L
.66085 .5 L
.66203 .5 L
.6631 .5 L
.66436 .5 L
.66573 .5 L
.66702 .5 L
.66821 .5 L
.66947 .5 L
Mistroke
.67083 .5 L
.67212 .5 L
.67329 .5 L
.67467 .5 L
.67544 .5 L
.67616 .5 L
.67748 .5 L
.67815 .5 L
.67888 .5 L
.67959 .5 L
.68034 .5 L
.68168 .5 L
.68243 .5 L
.68312 .5 L
.68389 .5 L
.6847 .5 L
.68541 .5 L
.68618 .5 L
.6869 .5 L
.68757 .5 L
.68883 .5 L
.69018 .5 L
.69144 .5 L
.69282 .5 L
.69413 .5 L
.69534 .5 L
.69654 .5 L
.69762 .5 L
.69888 .5 L
.70006 .5 L
.70135 .5 L
.70272 .5 L
.70388 .5 L
.70517 .5 L
.70654 .5 L
.70732 .5 L
.70802 .5 L
.70939 .5 L
.71069 .5 L
.71179 .5 L
.71301 .5 L
.71428 .5 L
.71547 .5 L
.71658 .5 L
.7176 .5 L
.71872 .5 L
.71989 .5 L
.72109 .5 L
.72237 .5 L
.72358 .5 L
Mistroke
.72468 .5 L
.72597 .5 L
.72669 .5 L
.72737 .5 L
.7286 .5 L
.72991 .5 L
.73118 .5 L
.73256 .5 L
.73387 .5 L
.73508 .5 L
.73629 .5 L
.73738 .5 L
.73863 .5 L
.73982 .5 L
.74111 .5 L
.74248 .5 L
.74365 .5 L
.74493 .5 L
.74631 .5 L
.74709 .5 L
.74779 .5 L
.74916 .5 L
.75046 .5 L
.75157 .5 L
.75279 .5 L
.75406 .5 L
.75525 .5 L
.75636 .5 L
.75738 .5 L
.7585 .5 L
.75968 .5 L
.76088 .5 L
.76216 .5 L
.76337 .5 L
.76446 .5 L
.76575 .5 L
.76648 .5 L
.76715 .5 L
.76839 .5 L
.76969 .5 L
.77097 .5 L
.77169 .5 L
.77236 .5 L
.77358 .5 L
.77489 .5 L
.77605 .5 L
.77714 .5 L
.77834 .5 L
.77963 .5 L
.78092 .5 L
Mistroke
.78165 .5 L
.78233 .5 L
.78371 .5 L
.78448 .5 L
.78519 .5 L
.78644 .5 L
.78781 .5 L
.7891 .5 L
.79029 .5 L
.79139 .5 L
.79258 .5 L
.79371 .5 L
.79473 .5 L
.79593 .5 L
.79724 .5 L
.79848 .5 L
.79963 .5 L
.80093 .5 L
.80214 .5 L
.80324 .5 L
.80442 .5 L
.80572 .5 L
.80708 .5 L
.80825 .5 L
.80953 .5 L
.8109 .5 L
.81217 .5 L
.81283 .5 L
.81356 .5 L
.81432 .5 L
.81504 .5 L
.81635 .5 L
.81755 .5 L
.81887 .5 L
.82026 .5 L
.82143 .5 L
.82268 .5 L
.82386 .5 L
.82493 .5 L
.82619 .5 L
.82755 .5 L
.82884 .5 L
.83003 .5 L
.8313 .5 L
.83266 .5 L
.83394 .5 L
.83512 .5 L
.83649 .5 L
.83727 .5 L
.83798 .5 L
Mistroke
.8393 .5 L
.84004 .5 L
.84071 .5 L
.84142 .5 L
.84216 .5 L
.8435 .5 L
.84425 .5 L
.84495 .5 L
.84571 .5 L
.84653 .5 L
.84723 .5 L
.848 .5 L
.84872 .5 L
.84939 .5 L
.85066 .5 L
.852 .5 L
.85326 .5 L
.85464 .5 L
.85595 .5 L
.85716 .5 L
.85835 .5 L
.85944 .5 L
.86069 .5 L
.86188 .5 L
.86317 .5 L
.86453 .5 L
.8657 .5 L
.86698 .5 L
.86836 .5 L
.86913 .5 L
.86984 .5 L
.87121 .5 L
.8725 .5 L
.8736 .5 L
.87482 .5 L
.87609 .5 L
.87728 .5 L
.87839 .5 L
.87941 .5 L
.88053 .5 L
.8817 .5 L
.8829 .5 L
.88418 .5 L
.88539 .5 L
.88649 .5 L
.88778 .5 L
.8885 .5 L
.88918 .5 L
.89041 .5 L
.89172 .5 L
Mistroke
.89299 .5 L
.89437 .5 L
.89568 .5 L
.89689 .5 L
.89809 .5 L
.89918 .5 L
.90044 .5 L
.90162 .5 L
.90292 .5 L
.90428 .5 L
.90545 .5 L
.90673 .5 L
.90812 .5 L
.90889 .5 L
.90959 .5 L
.91096 .5 L
.91226 .5 L
.91337 .5 L
.91458 .5 L
.91586 .5 L
.91705 .5 L
.91816 .5 L
.91918 .5 L
.9203 .5 L
.92148 .5 L
.92268 .5 L
.92396 .5 L
.92516 .5 L
.92626 .5 L
.92755 .5 L
.92828 .5 L
.92895 .5 L
.93018 .5 L
.93149 .5 L
.93276 .5 L
.93348 .5 L
.93415 .5 L
.93538 .5 L
.93668 .5 L
.93784 .5 L
.93893 .5 L
.94013 .5 L
.94142 .5 L
.94271 .5 L
.94344 .5 L
.94412 .5 L
.9455 .5 L
.94627 .5 L
.94697 .5 L
.94823 .5 L
Mistroke
.9496 .5 L
.95089 .5 L
.95207 .5 L
.95318 .5 L
.95437 .5 L
.95549 .5 L
.95652 .5 L
.95772 .5 L
.95903 .5 L
.96027 .5 L
.96141 .5 L
.96271 .5 L
.96393 .5 L
.96502 .5 L
.96621 .5 L
.9675 .5 L
.96887 .5 L
.97003 .5 L
.97131 .5 L
.97224 .5 L
.9731 .5 L
.97404 .5 L
.97503 .5 L
.9759 .5 L
.97671 .5 L
.9776 .5 L
.97856 .5 L
.97936 .5 L
.98024 .5 L
.98115 .5 L
.982 .5 L
.9828 .5 L
.98353 .5 L
.98437 .5 L
.98516 .5 L
.98602 .5 L
.98696 .5 L
.98795 .5 L
.98887 .5 L
.98973 .5 L
.99051 .5 L
.99142 .5 L
.99228 .5 L
.99321 .5 L
.9942 .5 L
.99513 .5 L
.99598 .5 L
.99697 .5 L
.99805 .5 L
.99907 .5 L
Mistroke
1 .5 L
Mfstroke
0 .83333 m
.04057 .84469 L
.08481 .86065 L
.12636 .88083 L
.16632 .90796 L
.18687 .92661 L
.20885 .95202 L
.23122 .98674 L
s
.23122 .98674 m
.2379 1 L
s
.66752 .51189 m
.66887 .51909 L
.67014 .52395 L
.67131 .52763 L
.67687 .54062 L
.68263 .55039 L
.6881 .55794 L
.70824 .57849 L
.72756 .59264 L
.74863 .60471 L
.79136 .62298 L
.8325 .63586 L
.87622 .64644 L
.91834 .6546 L
.95888 .6611 L
1 .66667 L
s
.66752 .52378 m
.66887 .53819 L
.67014 .5479 L
.67131 .55526 L
.67687 .58123 L
.68263 .60078 L
.6881 .61587 L
.70824 .65698 L
.72756 .68528 L
.74863 .70942 L
.79136 .74596 L
.8325 .77171 L
.87622 .79288 L
.91834 .8092 L
.95888 .82219 L
1 .83333 L
s
.66752 .53567 m
.66887 .55728 L
.67014 .57186 L
.67131 .58289 L
.67687 .62185 L
.68263 .65117 L
.6881 .67381 L
.70824 .73547 L
.72756 .77791 L
.74863 .81413 L
.79136 .86895 L
.8325 .90757 L
.87622 .93932 L
.91834 .96379 L
.95888 .98329 L
1 1 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[160]:=",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{186, 186},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002j0000^R000`400?l00000o`00003o^_ooool0
0;[ooooo001Eooooo`?o0000H_ooool005Cooooo00Go0000ooooooooooooooooo`00001Qooooo`00
C_ooool5o`0000Gooooo00?o0000ooooooooool0Goooool000Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o00001_ooool01Ol0003ooooooooo
oooooooo000000Kooooo0_l00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool0
00002Oooool2o`0000Cooooo0_l00004ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool2o`0000[ooooo000Sooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooool000002Oooool00ol0003oooooo`000005oooo
o`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool09Oooool3o`0000cooooo000Rooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`;o00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Wooooo00Go0000ooooool0003oooooo`000003
ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo0_l0000?ooooo`03o`000?oooooooooo01?ooooo0_l0000?ooooo`008Oooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`?o00001?ooool2o`0000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooo`00000:ooooo`;o00000_ooool3o`0000Cooooo0_l0
000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool3o`0000kooooo0_l0
000Cooooo`;o00004Oooool0023ooooo00?o0000ooooooooool02oooool01?l0003ooooooooooooo
ool2o`000003ooooool0003ooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000002_ooool00ol0003oooooo`000008ooooo`;o00002oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`;o00004_ooool2o`0001?ooooo000O
ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`03o`000?oooooooooo00?o000000?ooooo
o`000?ooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool000002_oo
ool00ol0003oooooo`000008ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0ol0000=ooooo`;o000000?o
ooooo`000?l000005Oooool001gooooo0_l00008ooooo`Co00000_ooool01?l0003ooooooooooooo
ool2o`000003ooooool0003ooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`0000[ooooo0_l00008ooooo`?o00002oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`Go
00005oooool001_ooooo0_l000000ooooooo0000o`000007ooooo`?o00000oooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool000001oooool00ol0003o
ooooo`00000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo1?l0000<ooooo`;o00002oooool0017ooooo
1?l00005ooooo`03o`000?oooooo000000;o00001_ooool2o`000003ooooool0003ooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`?o00002_ooool3o`0000Oooooo00Co0000ooooool0
003o00002_ooool2o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00Co0000ooooool0003o00002oooool2o`0000gooooo000@oooo
o`?o00001Oooool4o`000003ooooool0003ooooo00Gooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Kooooo1?l0000:ooooo`?o00001oooool01?l0003oooooo`000?l00009ooooo`?o0000
2?ooool2o`0000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`?o0000
2_ooool4o`0000kooooo000=ooooo`?o000000?oooooo`000?ooool00oooool4o`0000Wooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Kooooo1?l0000:ooooo`?o00001oooool00ol0003o
ooooooooo`02o`0000Wooooo0_l00008ooooo`;o00002oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo0ol0000:ooooo`;o00004_ooool000[ooooo0ol00006ooooo`Go0000
2_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`00000;ooooo`03o`000?oooooo000000Kooooo0_l00002ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02?ooool2o`0000[ooooo0_l0000Dooooo`002Oooool00ol0003ooooo
ooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooooooool2o`0000Kooooo0_l000000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool02Oooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`08
ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000>oooo
o`?o00005Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo0_l00006oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`;o00008oooool0
00_ooooo0ol0000Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool3o`00
00Kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool2o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00_ooooo0_l0000@ooooo`03o`000?oooooooooo02?ooooo0009oooo
o`;o00006?ooool2o`0000cooooo00Co0000oooooooooooo00001Oooool4o`0000Kooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo0ol0000?ooooo`;o00009Oooool002;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`02o`0000Kooooo0ol00006ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`;o00003_oo
ool3o`0002Gooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_l00006
ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool3o`0002Kooooo000Pooooo`03o`000?oooooooooo00Kooooo0ol00003ooooo`03o`000?oo
oooooooo00;o00001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`07o`000?ooooooooooooooool0
003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003Oooool3o`00
01Oooooo000Oooooo`03o`000?oooooooooo00Gooooo0ol00004ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00oooool01ol0003ooooooooooooooooo0000ooooool000001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000000cooooo0ol0000Iooooo`007?ooool5o`0000Kooooo
0_l00004ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`;o00000_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool01Ol0003oooooooooool0003o
oooo00?o00000_ooool00ol0003oooooooooo`04ooooo`;o00002Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000003?ooool3o`0000_ooooo1?l0000;
ooooo`004Oooool4o`0000Gooooo1Ol00006ooooo`;o00001_ooool00ol0003oooooo`000009oooo
o`04o`000?ooooooooooo`0000Oooooo0ol00002ooooo`03o`000?oooooooooo00Kooooo0_l00005
ooooo`05o`000?ooooooooooo`000?ooool00ol00003ooooo`03o`000?oooooooooo00?ooooo0_l0
0008ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000cooooo00?o
0000ooooooooool02oooool4o`0000cooooo000>ooooo`Go00001Oooool4o`000003ooooool0003o
oooo00Cooooo0_l00006ooooo`;o000000?oooooo`000?ooool02Oooool01?l0003oooooooooool0
0007ooooo`?o00000oooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0003ooooooooo
o`02o`000003ooooool0003o000000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`;o00002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000_ooooo0_l0
000;ooooo`?o00000_ooool00ol0003oooooooooo`0;ooooo`002oooool3o`0000Sooooo0ol00009
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo0_l0000:ooooo`;o00002_ooool3o`0001?ooooo0009ooooo`;o00002?oo
ool3o`0000_ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000;ooooo`05o`00
0?ooooooooooooooool000001oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002oooool2o`00
00[ooooo00?o0000ooooooooool02?ooool2o`0000[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000Aooooo`;o00005?ooool2o`0001;o
oooo00?o0000ooooool000001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo1Ol00002ooooo`;o00002?ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]
ooooo`003_ooool3o`0001Gooooo00?o0000ooooooooool04_ooool3o`0000Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`03o`0000Sooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`0<ooooo`;o00001?ooool00ol0003oooooooooo`0^ooooo`002oooool3o`0001Oooooo00?o0000
ooooooooool04oooool2o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
o`0000?ooooo00?o0000ooooooooool00oooool2o`0000Sooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooooooo`0;ooooo`;o00001?ooool00ol0003oooooooooo`0_ooooo`002Oooool2
o`0001Sooooo0_l0000?ooooo`;o00001Oooool2o`0000Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3
o`0000Sooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02?ooool2o`0001Sooooo0ol0000:ooooo`008Oooool2o`00
00oooooo1?l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooooooo0ol00008
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooo
oooooooo000000Wooooo1?l0000Eooooo`?o00003Oooool001oooooo0_l0000Aooooo`?o00001Ooo
ool2o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`07ooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000[o
oooo0ol0000Cooooo`?o00004?ooool001gooooo0_l00009ooooo`Co00001Oooool00ol0003ooooo
o`000006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?o00001?ooool00ol0003oooooo`000002o`0000Oooooo
00?o0000ooooool000002_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000_o
oooo0_l0000<ooooo`Co000000Coooooo`000?l0003o00004oooool001[ooooo1ol00007ooooo`?o
00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0ol00006ooooo`03
o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooo000000;o00001oooool00ol0003o
ooooo`000002o`0000Oooooo0ol0000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool03?ooool5o`0000Oooooo1Ol0000:ooooo`004Oooool4o`0000?ooooo0_l00002ooooo`?o
00001oooool2o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`?o00001_ooool00ol0003oooooooooo`02ooooo`?o00001oooool2o`000003
ooooool0003o000000Sooooo1?l00007ooooo`?o00002_ooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00[ooooo1?l0000;ooooo`?o00003?ooool000kooooo1Ol00002ooooo`?o
000000Koooooo`000?l0003o0000ooooool00006ooooo`;o00002?ooool00ol0003oooooooooo`08
ooooo`;o00002_ooool2o`0000Oooooo00?o0000ooooooooool00_ooool2o`0000Oooooo00Co0000
oooooooooooooooo0_l00007ooooo`04o`000?oooooo0000o`0000Oooooo0ol0000:ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool02Oooool3o`0000_ooooo0ol000000ooooooo
0000ooooo`0<ooooo`002oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00009ooooo`;o
00002Oooool00ol0003oooooooooo`09ooooo`;o00002_ooool2o`0000Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o00002?ooool00ol0
003oooooo`000008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`08ooooo`;o00002oooool3o`0001;ooooo0009ooooo`;o00000oooool4o`0000?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000002Oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Wo
oooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01oooool2o`00
00_ooooo0_l0000:ooooo`03o`000?oooooooooo00Sooooo000;ooooo`?o0000:oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool2o`0000_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000>ooooo`;o00009?ooool0
00Wooooo0_l0000^ooooo`04o`000?ooooooooooooooo`;o00001Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooo000000[ooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooool000002?ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000cooooo0_l0
000Vooooo`00>?ooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool02Ooo
ool2o`0000[ooooo0ol00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000_ooooo0_l0000Xooooo`00>?oo
ool00ol0003oooooooooo`03o`0000Oooooo00?o0000ooooooooool02Oooool2o`0000Wooooo00?o
0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Sooooo00?o
0000ooooooooool02Oooool01?l0003oooooo`000?l0000:ooooo`03o`000?oooooooooo02Sooooo
000eooooo`?o00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo0_l0
0009ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002Oooool2o`0000Go
oooo0_l0000Tooooo`00<oooool4o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0:ooooo`;o00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Co
oooo0_l00008ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00001oooool2o`00
00Gooooo1?l0000Tooooo`00<_ooool5o`0000Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0:ooooo`Co00001_ooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000oooo
ooooool00oooool3o`0000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000007oooo
o`03o`000?oooooooooo00Gooooo0ol0000Uooooo`00:?ooool5o`0000Cooooo00?o0000oooooooo
ool00_l00004ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`?o00001_ooool2o`0000;o
oooo0_l00003ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`?o00002?ooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000ooooo`0:oooo
o`Go00005_ooool0017ooooo0ol00009ooooo`Co00001oooool3o`0000Gooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`?o00001_ooool00ol0
003oooooooooo`02ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`?o00001Oooool3o`00
00Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00gooooo0ol00009ooooo`Go00002_ooool0017ooooo1Ol00004ooooo`Go00001_ooool3o`00
00Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool2o`0000Kooooo0_l00007ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`?o00002_ooool5
o`0000cooooo000<ooooo`Oo00001?ooool3o`0000Sooooo0ol00008ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`?o00002Oooool4
o`00017ooooo0009ooooo`?o00002Oooool2o`0000[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`;o00002_ooool2o`0000[ooooo00?o0000ooooooooool02?ooool0033o
oooo0_l0000Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Tooooo`Co00002_ooool002kooooo0_l0000?ooooo`;o00000oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000_ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool01?ooool01?l0003oooooo`000?l0000Oooooo`Go00003_ooool002gooooo00?o0000oooooooo
ool03_ooool3o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`07
o`000?ooooooooooooooool0003oooooo`00000;ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l0
000Looooo`?o00004oooool002_ooooo0_l0000@ooooo`?o00001Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000_l0000Hooooo`Go00005_ooool002Wooooo0_l0
000Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooo`00
0002o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00005?ooool5o`0001_ooooo000Vooooo`?o00005?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00[ooooo00Co0000ooooool0003o00001?ooool2o`0000?o
oooo00?o0000ooooool000002?ooool3o`0000Cooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0001;ooooo0ol0000Pooooo`008oooool3o`00
00kooooo1?l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool5o`00
0004ooooool0003o0000o`0000Gooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000oooooo
1?l0000Eooooo`Co00002_ooool0023ooooo0ol0000@ooooo`Co00001?ooool00ol0003ooooooooo
o`07ooooo`?o00003?ooool3o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo00Co
0000ooooool0003o00001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000go
oooo1Ol0000?ooooo`Oo00003_ooool001cooooo1?l00009ooooo`Co00000oooool3o`0000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`?o00003Oooool2o`0000Gooooo
00?o0000ooooool000001?ooool00ol0003oooooooooo`07ooooo`;o00001?ooool01?l0003ooooo
o`000?l00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002oooool4o`00
00;ooooo00?o0000ooooooooool02Oooool5o`0000Oooooo0ol0000;ooooo`003oooool7o`0000?o
oooo2?l00003ooooo`Oo00000_ooool3o`0000Wooooo00?o0000ooooooooool02_ooool2o`0000go
oooo0_l00005ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002Oooool5
o`0000[ooooo2?l00007ooooo`Oo00002_ooool000Wooooo1_l00002ooooo`;o000000?oooooo`00
0?l000001Ol00002ooooo`;o00000_ooool3o`0000Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`02ooooo`07o`000?oo
ooooooooooooool0003oooooo`000008ooooo`;o000000?oooooo`000?ooool02Oooool6o`0000Ko
oooo1_l00003ooooo`;o000000?oooooo`000?ooool02Oooool000gooooo1ol0000`ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00[o
oooo1?l0000Qooooo`002Oooool4o`0003Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`;o000000Goooooo`000?ooooooooooo`000006ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000002?ooool2
o`0000Wooooo1?l0000@ooooo`_o00002_ooool004Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000oooooooooooo00001ooo
ool2o`0000Sooooo0ol0000>ooooo`Ko00005Oooool004Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool01Oooool3o`0000_ooooo1_l0000Kooooo`00A_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool2o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00?ooooo0ol0000:ooooo`Co0000
8Oooool0047ooooo0_l00003ooooo`03o`000?oooooooooo00cooooo0ol00004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00001?oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00_oo
ool5o`0000Gooooo1Ol0000Uooooo`00?oooool3o`0000Cooooo00?o0000ooooooooool03?ooool3
o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00Co0000oooooooooooooooo0_l0
0004ooooo`04o`000?oooooo0000o`0000;ooooo0_l00005ooooo`04o`000?ooooooooooooooo`Go
00000_ooool5o`0002[ooooo000nooooo`03o`000?oooooo000000Kooooo0_l0000>ooooo`;o0000
0oooool2o`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`06o`00
0?ooooooooooooooool0003ooooo0ol000000ooooooo0000o`000004ooooo`05o`000?oooooooooo
ooooool000000_ooool5o`0002oooooo000looooo`;o00002?ooool3o`0000oooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo1?l0
00000ooooooo0000o`000003ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000000_l0
000booooo`00=Oooool4o`000003ooooool0003o000000[ooooo0ol0000Cooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool4o`000003ooooool0003ooooo00;ooooo00Go0000
oooooooooooo0000ooooo`04o`0000kooooo1?l0000Rooooo`004Oooool3o`0000Oooooo1ol00005
ooooo`Ko00000_ooool8o`0000;ooooo00?o0000ooooooooool02oooool2o`0001?ooooo00?o0000
ooooooooool03_ooool2o`0000Gooooo00Ko0000ooooool0003o0000ooooool00002ooooo`08o`00
0?ooooooooooo`000?oooooo0000ooooool0000;ooooo`Oo00001oooool7o`0000Gooooo1ol0000:
ooooo`002OoooolBo`0000;ooooo0ol000000ooooooo0000o`000004o`0000;ooooo0_l000001?oo
oooo0000o`000?l00009ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`;o00002_ooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo1_l0
00001_oooooo0000oooooooooooo0000ooooo`?o00002Oooool3o`0000Sooooo1_l00003ooooo`;o
000000?oooooo`000?l000001?l00003ooooo`;o000000?oooooo`000?ooool02Oooool0017ooooo
0_l0000:ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02oooool2o`0000Sooooo
1?l0000:ooooo`;o00001?ooool01?l0003oooooooooooooool2o`000008ooooool0003o0000o`00
0?oooooo0000ooooool00002ooooo`03o`000?oooooooooo02;ooooo2ol0000:ooooo`002_ooool3
o`0001Sooooo1Ol0000Gooooo`?o000000?oooooo`000?ooool03Oooool2o`0000Kooooo00Co0000
oooooooooooooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`Ko000000?o
ooooo`000?ooool00_l0000@ooooo`Go00000_ooool>o`0000Sooooo0ol0000:ooooo`002Oooool0
1Ol0003ooooooooooooooooo000001Sooooo00Co0000oooooooooooo00006?ooool01Ol0003ooooo
oooooooooooo000000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`?o
00001oooool2o`0000Cooooo00?o0000ooooooooool02?l0000Booooo`Oo00005Oooool01Ol0003o
oooooooooooooooo000000Wooooo0003ooooo`Go00001Oooool00ol0003oooooooooo`0?ooooo`Go
00000oooool00ol0003oooooooooo`0@ooooo`Go00000oooool01Ol0003ooooooooooooooooo0000
013ooooo0ol00002ooooo`03o`000?oooooooooo00Gooooo0ol00008ooooo`;o00000_ooool00ol0
003oooooooooo`06o`0000gooooo1ol00002ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool01oooool000_ooooo0_l0000Kooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0=ooooo`Co000000?oooooo`000?ooool01Oooool5o`0000Oo
oooo0ol00002ooooo`03o`000?oooooooooo00Co00002Oooool5o`0000[ooooo00?o0000oooooooo
ool06?ooool2o`0000[ooooo000=ooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooo
ooooo`00000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool3o`0001Go
oooo00Go0000oooooooooooo0000ooooo`04o`0000Kooooo0ol0000<ooooo`05o`000?oooooooooo
ooooool000006oooool00ol0003oooooooooo`07ooooo`002Oooool01Ol0003ooooooooooooooooo
000001Oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o00001Oooool2o`0001;ooooo0_l0
000Hooooo`Co00000oooool4o`0000oooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`00
0?ooooooooooooooool000002Oooool000[ooooo0ol0000Iooooo`?o00006Oooool00ol0003ooooo
ooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`0Gooooo`Co000000?oooooo`000?l00000
5?ooool3o`0001Wooooo0ol0000:ooooo`00BOooool2o`00017ooooo00?o0000ooooooooool06?oo
ool4o`0003oooooo001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool4
o`0003oooooo000Aooooo`?o00002Oooool3o`0000Wooooo0ol00009ooooo`?o00002Oooool3o`00
00Wooooo0ol00009ooooo`Co00002?ooool3o`0000Sooooo0ol00005ooooo`04o`000?oooooooooo
ooooo`?o00002Oooool3o`0000Wooooo0ol00009ooooo`?o00002Oooool3o`0000_ooooo0009oooo
ojOo00002_ooool000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`000003
ooooool0003ooooo00?ooooo00Co0000oooooooooooooooo0ol00005ooooo`04o`000?oooooooooo
ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00Cooooo00?o
0000ooooooooool00ol00005ooooo`03o`000?oooooooooo00?o00001Oooool01?l0003ooooooooo
ooooool2o`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0000?ooooo00?o0000ooooooooool00oooool3o`0000;ooooo00?o0000ooooooooool0
0oooool01_l0003oooooo`000?l0003oooooo`0000[ooooo001:ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool06Oooool3o`0003oooooo0019ooooo`;o00004Oooool00ol0003ooooo
ooooo`0Hooooo`Co0000?oooool004Sooooo0_l0000Booooo`03o`000?oooooooooo01Sooooo1_l0
000mooooo`00B?ooool2o`0001;ooooo00?o0000ooooooooool05oooool4o`0000?ooooo0_l0000k
ooooo`00B?ooool00ol0003oooooooooo`0Aooooo`;o00005oooool00ol0003oooooo`000002o`00
00Gooooo0ol0000hooooo`00Aoooool00ol0003oooooooooo`0=ooooo`Ko00002?ooool3o`0000Oo
oooo1?l000001?oooooo0000ooooooooool4o`0000Oooooo1_l0000booooo`00Aoooool00ol0003o
ooooooooo`0=ooooo`?o00000_ooool00ol0003oooooooooo`04ooooo`Co00002?ooool3o`0000;o
oooo00?o0000ooooooooool00ol000000ooooooo0000o`00000;ooooo`?o0000;oooool004Kooooo
00?o0000ooooooooool03?ooool4o`0000?ooooo00?o0000ooooooooool00_ooool5o`0000Oooooo
0_l000001Ooooooo0000oooooooooooo000000;ooooo1Ol00002ooooo`03o`000?oooooooooo00_o
oooo3Ol0000Rooooo`00AOooool00ol0003oooooooooo`0;ooooo`;o00001oooool00ol0003ooooo
ooooo`02o`0000?ooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool0
2?l000000ooooooo0000ooooo`0Hooooo`So00006_ooool004Gooooo00?o0000ooooooooool02Ooo
ool2o`0000Wooooo0ol0000:ooooo`;o00001Oooool2o`0000?ooooo1_l00002ooooo`04o`000?oo
oooo0000o`0001oooooo3Ol0000=ooooo`002Oooool7o`000005ooooool0003o0000o`000?ooool0
1ol000001Ooooooo0000o`000?l0003ooooo00Co00001?ooool2o`000004ooooool0003o0000o`00
00Wooooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`00
0006ooooool0003o0000o`000?oooooo00000_ooool01?l0003oooooo`000?l0000:ooooo`?o0000
2?ooool4o`0000Gooooo0_l000000ooooooo0000o`000005o`0000;ooooo1?l0000:ooooo`004?oo
ool6o`0000Kooooo1_l00003ooooo`Oo00000oooool4o`0000;ooooo0_l00003ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000000_l00002ooooo`04o`000?ooooooooooo`0000;ooooo
0ol0000:ooooo`Co000000?oooooo`000?l000001Oooool8o`0000Oooooo1_l0000:ooooo`007Ooo
ool2o`0000[ooooo1?l00006ooooo`Go00000oooool2o`0000_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0=ooooo`;o00001_ooool01_l0003oooooo`000?l0003oooooo`0000?o
oooo00Co0000oooooooooooo00000_ooool4o`0000cooooo1?l00009ooooo`Co00002?ooool2o`00
00cooooo000eooooo`Co00001?ooool00ol0003oooooooooo`07ooooo`;o00003_ooool2o`0000?o
oooo00?o0000ooooooooool03?ooool01?l0003oooooooooooooool2o`0000?ooooo00Ko0000oooo
ool0003o0000ooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool00000
0_l0000:ooooo`Co00008_ooool003kooooo00?o0000ooooool000001Oooool3o`0000gooooo0ol0
0003ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`;o00000oooool3o`0000?ooooo1?l0
00000ooooooo0000o`000004ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l0
000^ooooo`00?oooool2o`0000Kooooo00?o0000ooooooooool02oooool3o`0000Cooooo0_l00005
ooooo`?o00000_ooool00ol0003oooooooooo`02ooooo`?o00000oooool01?l0003oooooo`000?l0
0002ooooo`;o00001Oooool01_l0003ooooooooooooooooo0000ooooo`?o00000oooool3o`0002_o
oooo0011ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo0_l00006ooooo`04o`000?oooooooooooooo
o`;o000000?oooooo`000?l000001Oooool3o`0002Sooooo0012ooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000000oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l00007oooo
o`Ko00008_ooool004Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00Co0000ooooool0003o00000oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo00Cooooo0_l0000<ooooo`So00006_ooool004Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Gooooo0ol0000Aooooo`Ko00005?ooool004Gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`07ooooo`?o00000oooool2o`0000Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000oooooooooooo00002?oo
ool2o`0000Sooooo0ol0000Dooooo`Oo00003Oooool000Wooooo1Ol0000gooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooooooo
ool00009ooooo`?o00002?ooool4o`0001Oooooo0ol0000:ooooo`002Oooool@o`0000Cooooo0_l0
0002ooooo`?o00002?ooool2o`0000[ooooo00?o0000ooooooooool02Oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`07
o`000?ooooooooooooooool0003oooooo`000009ooooo`Co00002?ooool4o`0000Wooooo1?l00005
ooooo`;o000000?oooooo`000?ooool02Oooool0013ooooo4?l00004ooooo`Co000000?oooooo`00
0?l000000oooool2o`0000Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`?o00001?ooool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000002oooool4o`0000[ooooo
2?l00005ooooo`So00002oooool0017ooooo0_l00009ooooo`Go00001oooool4o`0000Cooooo0ol0
0006ooooo`03o`000?oooooooooo00[ooooo0_l0000>ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co
0000ooooool0003o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000cooooo
1?l0000<ooooo`So00001_ooool4o`0000[ooooo000Qooooo`?o00001Oooool4o`0000Kooooo0ol0
0004ooooo`03o`000?oooooooooo00Sooooo0ol0000=ooooo`;o00001Oooool2o`0000Gooooo00?o
0000ooooooooool01oooool2o`0000Cooooo00Co0000ooooool0003o00000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000kooooo1?l0000;ooooo`Co00000_ooool7o`0000go
oooo000Tooooo`?o00003Oooool3o`0000Cooooo00?o0000ooooooooool02?ooool2o`0000cooooo
0ol00005ooooo`;o00001?ooool2o`0000Sooooo0_l00005ooooo`04o`000?oooooo0000o`0000Co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000?ooooo`?o00005oooool3o`00
00[ooooo000Wooooo`?o00003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02oooool3o`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo0_l00004ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool0000Aooooo`Co00008?ooool002[ooooo0_l0000Aooooo`;o00001oooool00ol0
003oooooooooo`0;ooooo`?o00001?ooool2o`0000Cooooo0_l00009ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;o00005?ooool4o`0001cooooo000/ooooo`;o00003oooool2o`0000Kooooo00?o0000oooo
ooooool02oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool00oooool01?l0003oooooo`000?l0000Hooooo`?o00006Oooool002kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000001[ooooo1Ol0000Dooooo`00;oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooooooo`?o00002oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000007_ooool7o`0000gooooo000`ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000002_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool09_ooool3o`0000[ooooo000aooooo`;o00004Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2
o`0000_ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool01Oooool2o`0003?ooooo0009ooooo`Co00001?ooool2o`0000;ooooo0ol00009
ooooo`;o00002Oooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`02
ooooo`;o00002Oooool3o`0000Wooooo0ol00009ooooo`03o`000?oooooooooo00Sooooo000=oooo
o`So00000oooool4o`000003ooooool0003o000000Cooooo0ol00008ooooo`;o00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool3o`00
00Wooooo1?l00002ooooo`;o00003?ooool0017ooooo1Ol00006ooooo`Co00001_ooool5o`0000Go
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Wooooo0_l0000=oooo
o`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000005ooooo`;o00001oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00?ooooo0_l0000<ooooo`Go00002?ooool5o`0000_ooooo000Moooo
o`Co00002?ooool3o`0000Gooooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo
00Sooooo0_l0000<ooooo`?o00001_ooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001Oooool3o`0000Sooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo0ol00008ooooo`Go00002_ooool002So
oooo1Ol00006ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_o
oooo0ol00006ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`03oooo
o`;o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool01?ooool2o`0000_ooooo1Ol0000Fooooo`00<oooool4o`00
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o00002?ooool01?l0
003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool2o`0000Cooooo0ol0000U
ooooo`00=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool2o`0000Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`0000[ooooo0_l00005ooooo`03o`000?oooooooooo02;ooooo000gooooo`03o`000?oooooo
oooo00;ooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo0_l00009ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000008ooooo`03o`000?oo
oooooooo00Wooooo00Co0000ooooool0003o00002oooool00ol0003oooooooooo`0Wooooo`00=ooo
ool01?l0003oooooooooooooool3o`0000Oooooo00?o0000ooooooooool02Oooool2o`0000Wooooo
00?o0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooooooool02Oooool01?l0003oooooo`000?l0000<ooooo`;o00009oooool003Sooooo
00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
o`000009ooooo`?o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`02o`0000gooooo0_l0000Uooooo`002Ooo
ool5o`0002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooool000002_ooool2o`0000Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000
3oooool2o`0002?ooooo000>ooooo`Go00009_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooool000002_ooool2o`0000?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_oo
ool2o`00027ooooo0009ooooo`Co00001_ooool5o`0000Wooooo0_l00009ooooo`;o00002_ooool2
o`0000[ooooo00?o0000ooooool000001oooool00ol0003oooooo`00000;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00008ooooo`;o00002_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Sooooo1?l00008ooooo`?o0000
2Oooool00ol0003oooooooooo`08ooooo`003Oooool7o`0000;ooooo1_l000000ooooooo0000o`00
0004ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooooooo0_l00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
2?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Wooooo1?l00009ooooo`Co
00000_ooool2o`0000cooooo000Aooooo`Co00001?ooool7o`0000Gooooo0_l00008ooooo`03o`00
0?oooooooooo00Oooooo0_l0000:ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`;o0000
1oooool2o`000004ooooool0003oooooo`0000Sooooo0ol00007ooooo`?o00002_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00[ooooo1Ol0000:ooooo`Go00002oooool001co
oooo1Ol00006ooooo`?o00001_ooool00ol0003oooooooooo`06ooooo`;o00002Oooool3o`0000Ko
oooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool00_l00008ooooo`Co
00001oooool3o`0000[ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0<oooo
o`Co00002Oooool5o`0000[ooooo000Nooooo`;o00002?ooool3o`0000Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool2o`0000Oooooo00?o0000ooooool000000_l00008ooooo`04o`000?oooooo0000o`00
00Sooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool03?ooool6o`0001Gooooo000Pooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01?ooool2o`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo1_l00003ooooo`04o`000?oooooo0000o`0000Sooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000_ooooo
0_l0000?ooooo`03o`000?oooooooooo00?o00004_ooool0027ooooo0_l0000?ooooo`;o00001_oo
ool2o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`07ooooo`03
o`000?oooooo000000[ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
00[ooooo0_l0000Eooooo`?o00003oooool002?ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`?o00002Oooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00_ooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05Oooool3o`0000cooooo0009ooooo`?o00006?ooool2o`0000oooooo00?o0000oooooooo
ool00oooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool3o`0000Sooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`0;ooooo`;o00000oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Oooooo0_l0000:ooooo`003?ooool3o`0001Oooooo0_l0000Cooooo`;o
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00000oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003oooooo`00
000:ooooo`03o`000?oooooooooo00_ooooo0_l00004ooooo`03o`000?oooooooooo02oooooo000?
ooooo`Co00005Oooool00ol0003oooooooooo`0@ooooo`?o00001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03o`0000Sooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0<ooooo`;o0000
1?ooool00ol0003oooooooooo`0^ooooo`004oooool3o`0001?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool3o`0000?ooooo0ol00008ooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02go
oooo0009ooooo`?o00002Oooool4o`0000Sooooo0_l00007ooooo`03o`000?oooooo000000_ooooo
00Go0000ooooooooooooooooo`000007ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`;o00002_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooo000000[ooooo0_l0000:ooooo`;o00002_ooool0
0ol0003oooooooooo`08ooooo`003?ooool4o`000003ooooool0003o000000Cooooo1?l00008oooo
o`;o00001_ooool00ol0003oooooo`00000:ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool0
1?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooo`00000;ooooo`;o00002_ooool3o`0001;ooooo000@ooooo`Co00001_ooool5
o`0000Kooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000:ooooo`04o`000?oooooo
ooooo`0000Oooooo0ol00003ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o0000
2_ooool00ol0003oooooooooo`09ooooo`?o00003?ooool2o`0000_ooooo0ol000000ooooooo0000
ooooo`0<ooooo`004Oooool4o`0000Oooooo1?l00006ooooo`?o00000oooool01?l0003ooooooooo
ool00009ooooo`04o`000?ooooooooooo`0000Oooooo0ol00002ooooo`03o`000?oooooooooo00Ko
oooo0_l00005ooooo`05o`000?ooooooooooo`000?ooool00ol00003ooooo`03o`000?oooooooooo
00?ooooo0_l00008ooooo`;o00002oooool00ol0003oooooooooo`0:ooooo`;o00003Oooool00ol0
003oooooo`00000;ooooo`?o00003?ooool001cooooo1Ol00007ooooo`;o00000oooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00003ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02oooool2o`0000gooooo0ol0000:ooooo`Co00002oooool0023ooooo00?o
0000ooooooooool01?ooool4o`0000?ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3?ooool3o`0000_ooooo1?l0000Hooooo`008Oooool2o`0000Oooooo0_l00003ooooo`03o`000?oo
oooooooo00;o00001_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`03ooooo`07o`000?ooooooooooooooool0003oooooo`000004
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`;o00005oooool002?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`03o`0000Gooooo00Co0000oooooooooooo00001_ooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`?o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`?o00009_ooool000Wooooo0ol0000H
ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Gooooo1?l00006ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
0_l00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0:ooooo`?o00003oooool2o`0002Gooooo000<ooooo`?o00005oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo1?l00006ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`?o0000
4Oooool00ol0003oooooooooo`0Rooooo`003oooool3o`0001Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`?o00001_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o00000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool2o`0001;ooooo
0_l0000Rooooo`004_ooool2o`0001Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`;o00001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo
0_l0000Pooooo`002Oooool3o`0000Sooooo0ol0000:ooooo`;o00001_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`;o000000?oooooo`000?ooool01oooool01_l0003oooooooooool0003oooooo`00
00Kooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002?ooool2
o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o000000?ooooo
o`000?ooool01oooool2o`0000[ooooo00?o0000ooooooooool02?ooool000cooooo1?l000000ooo
oooo0000o`000002ooooo`Go00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000002oooool00ol0003oooooo`000006ooooo`05o`000?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`Co00002?ooool3o`0001;ooooo000@oooo
o`Co00000oooool2o`000005ooooool0003o0000ooooool000001_ooool2o`0000Gooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool4o`0000[ooooo0ol00007ooooo`03o`000?oooooooooo00;o00002Oooool2
o`0000Sooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool0
1?l0003oooooo`000?l00009ooooo`Go00003Oooool0017ooooo1?l00004ooooo`;o000000Cooooo
o`000?l0003o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo1?l0000:ooooo`?o0000
1oooool01?l0003oooooo`000?l00009ooooo`?o00002?ooool2o`0000_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`;o000000?oooooo`000?ooool02_ooool3o`0000co
oooo000Kooooo`Go00001oooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00000:oooo
o`03o`000?oooooo000000Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`Co00002Oooool4o`0000_ooooo000Looooo`;o00002Oooool3o`0000?ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Oooooo00Co0000
ooooool0003o00002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o000000?oooooo`000?l000005_oo
ool001kooooo0_l0000:ooooo`04o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000oooo
o`04ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooo000000Sooooo0ol0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`;o00003oooool01?l0003oooooooooool0000Eoooo
o`008?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooo`00000:oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0001?ooooo0_l0000Coooo
o`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
00001?ooool2o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000:ooooo`03
o`000?oooooo000000Sooooo0_l0000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool3o`0000kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`00
8_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000[ooooo00Co0000ooooool0003o
oooo0ol00004ooooo`;o00002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[o
oooo0ol0000?ooooo`03o`000?oooooooooo01;ooooo0ol0000?ooooo`008oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooo000000Wooooo00Go0000ooooool0003oooooo`000003oooo
o`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00_ooooo0_l0000Wooooo`?o00003?ooool000Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;o00001_ooool01Ol0003ooooooooooooooooo
000000Kooooo0_l00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000002Ooo
ool3o`0000Gooooo00Co0000oooooooooooooooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00002_ooool005Kooooo
0_l0001Rooooo`00F?ooool00ol0003oooooooooo`1Oooooo`00E?ooool01Ol0003ooooooooooooo
oooo0000067ooooo000Aooooo`?o0000@Oooool3o`0006;ooooo000Booooo`03o`000?oooooooooo
0:Gooooo0003o`0000;ooooo1Ol00002ooooo`?o00000oooool3o`0000?ooooo0ol00008ooooo`Go
000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool5o`0000;ooooo1?l00008ooooo`Co
000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o00001oooool4o`00
00?ooooo0ol00002ooooo`Go00000oooool2o`000004ooooool0003oooooooooo`;o00000_ooool5
o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000001oooool3o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0000Gooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1?l00003
ooooo`0000Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000000oooool01Ol0003ooooo
oooooooooooo000000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Wooooo0Ol00001
ooooo`7ooooo0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000oooooooooooo0000ooooo`05o`0000Wooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooooooool5o`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Oooooo0ol00003ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool00ol0003oooooooooo`07ooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000002ooooo`Go00000_ooool3o`0000?ooooo0000
0ooooooo0000o`000004ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo0_l00004ooooo`03o`000?oooooo0000
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00000ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Co00000oooool3o`0000Wooooo1?l00000
1?oooooo0000o`000?l00004ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00002Ooo
ool2o`0000?ooooo1?l00003ooooo`?o00002Oooool4o`0000;ooooo0ol00004ooooo`04o`000?oo
ooooooooooooo`;o000000Coooooo`000?l0003ooooo1?l00002ooooo`?o00001?ooool3o`0000;o
oooo1?l00009ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000002ooooo`?o00000oooool4o`0000;ooooo00001?l0
003oooooooooool00003ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03oooooo00001Ooooooo0000o`000?l0003o
oooo00?o00007_ooool2o`0000?ooooo00?o0000ooooooooool01oooool3o`0000Gooooo0_l0000F
ooooo`;o00005?ooool3o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0h
ooooo`00^_ooool00;[ooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 262.875}, {409.375, 224.375}} -> {-6.14265, \
4.92728, 0.0360537, 0.0360537}}]
}, Open  ]],

Cell["\<\
Finally, we make a slope field, solution curve picture for the last \
differential equation in Section 1.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
u = 1; v = t/y;
S=PlotVectorField[ {u,v}/Sqrt[u^2+v^2], {t,-3,3}, {y,-3,3}, Axes->True \
]\
\>", "Input",
  CellLabel->"In[112]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.04808 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.477105 0.151099 0.52404 0.151099 [
[.02381 .51154 -6 -9 ]
[.02381 .51154 6 0 ]
[.17491 .51154 -6 -9 ]
[.17491 .51154 6 0 ]
[.32601 .51154 -6 -9 ]
[.32601 .51154 6 0 ]
[.6282 .51154 -3 -9 ]
[.6282 .51154 3 0 ]
[.7793 .51154 -3 -9 ]
[.7793 .51154 3 0 ]
[.9304 .51154 -3 -9 ]
[.9304 .51154 3 0 ]
[.46461 .07074 -12 -4.5 ]
[.46461 .07074 0 4.5 ]
[.46461 .22184 -12 -4.5 ]
[.46461 .22184 0 4.5 ]
[.46461 .37294 -12 -4.5 ]
[.46461 .37294 0 4.5 ]
[.46461 .67514 -6 -4.5 ]
[.46461 .67514 0 4.5 ]
[.46461 .82624 -6 -4.5 ]
[.46461 .82624 0 4.5 ]
[.46461 .97734 -6 -4.5 ]
[.46461 .97734 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.04808 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .52404 m
.02381 .53029 L
s
[(-3)] .02381 .51154 0 1 Mshowa
.17491 .52404 m
.17491 .53029 L
s
[(-2)] .17491 .51154 0 1 Mshowa
.32601 .52404 m
.32601 .53029 L
s
[(-1)] .32601 .51154 0 1 Mshowa
.6282 .52404 m
.6282 .53029 L
s
[(1)] .6282 .51154 0 1 Mshowa
.7793 .52404 m
.7793 .53029 L
s
[(2)] .7793 .51154 0 1 Mshowa
.9304 .52404 m
.9304 .53029 L
s
[(3)] .9304 .51154 0 1 Mshowa
.125 Mabswid
.05403 .52404 m
.05403 .52779 L
s
.08425 .52404 m
.08425 .52779 L
s
.11447 .52404 m
.11447 .52779 L
s
.14469 .52404 m
.14469 .52779 L
s
.20513 .52404 m
.20513 .52779 L
s
.23535 .52404 m
.23535 .52779 L
s
.26557 .52404 m
.26557 .52779 L
s
.29579 .52404 m
.29579 .52779 L
s
.35623 .52404 m
.35623 .52779 L
s
.38645 .52404 m
.38645 .52779 L
s
.41667 .52404 m
.41667 .52779 L
s
.44689 .52404 m
.44689 .52779 L
s
.50732 .52404 m
.50732 .52779 L
s
.53754 .52404 m
.53754 .52779 L
s
.56776 .52404 m
.56776 .52779 L
s
.59798 .52404 m
.59798 .52779 L
s
.65842 .52404 m
.65842 .52779 L
s
.68864 .52404 m
.68864 .52779 L
s
.71886 .52404 m
.71886 .52779 L
s
.74908 .52404 m
.74908 .52779 L
s
.80952 .52404 m
.80952 .52779 L
s
.83974 .52404 m
.83974 .52779 L
s
.86996 .52404 m
.86996 .52779 L
s
.90018 .52404 m
.90018 .52779 L
s
.96062 .52404 m
.96062 .52779 L
s
.99084 .52404 m
.99084 .52779 L
s
.25 Mabswid
0 .52404 m
1 .52404 L
s
.47711 .07074 m
.48336 .07074 L
s
[(-3)] .46461 .07074 1 0 Mshowa
.47711 .22184 m
.48336 .22184 L
s
[(-2)] .46461 .22184 1 0 Mshowa
.47711 .37294 m
.48336 .37294 L
s
[(-1)] .46461 .37294 1 0 Mshowa
.47711 .67514 m
.48336 .67514 L
s
[(1)] .46461 .67514 1 0 Mshowa
.47711 .82624 m
.48336 .82624 L
s
[(2)] .46461 .82624 1 0 Mshowa
.47711 .97734 m
.48336 .97734 L
s
[(3)] .46461 .97734 1 0 Mshowa
.125 Mabswid
.47711 .10096 m
.48086 .10096 L
s
.47711 .13118 m
.48086 .13118 L
s
.47711 .1614 m
.48086 .1614 L
s
.47711 .19162 m
.48086 .19162 L
s
.47711 .25206 m
.48086 .25206 L
s
.47711 .28228 m
.48086 .28228 L
s
.47711 .3125 m
.48086 .3125 L
s
.47711 .34272 m
.48086 .34272 L
s
.47711 .40316 m
.48086 .40316 L
s
.47711 .43338 m
.48086 .43338 L
s
.47711 .4636 m
.48086 .4636 L
s
.47711 .49382 m
.48086 .49382 L
s
.47711 .55426 m
.48086 .55426 L
s
.47711 .58448 m
.48086 .58448 L
s
.47711 .6147 m
.48086 .6147 L
s
.47711 .64492 m
.48086 .64492 L
s
.47711 .70536 m
.48086 .70536 L
s
.47711 .73558 m
.48086 .73558 L
s
.47711 .7658 m
.48086 .7658 L
s
.47711 .79602 m
.48086 .79602 L
s
.47711 .85646 m
.48086 .85646 L
s
.47711 .88668 m
.48086 .88668 L
s
.47711 .9169 m
.48086 .9169 L
s
.47711 .94712 m
.48086 .94712 L
s
.47711 .04052 m
.48086 .04052 L
s
.47711 .0103 m
.48086 .0103 L
s
.47711 1.00755 m
.48086 1.00755 L
s
.47711 1.03777 m
.48086 1.03777 L
s
.25 Mabswid
.47711 0 m
.47711 1.04808 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
.02381 .07074 m
.0696 .11653 L
s
% Start of user PostScript
-3. -3. -2.69695 -2.69695 MAarrowhead1
% End of user PostScript
.02381 .1355 m
.06595 .18467 L
s
% Start of user PostScript
-3. -2.57143 -2.72109 -2.24603 MAarrowhead1
% End of user PostScript
.02381 .20026 m
.06145 .25295 L
s
% Start of user PostScript
-3. -2.14286 -2.7509 -1.79411 MAarrowhead1
% End of user PostScript
.02381 .26501 m
.05594 .32124 L
s
% Start of user PostScript
-3. -1.71429 -2.78737 -1.34218 MAarrowhead1
% End of user PostScript
.02381 .32977 m
.04932 .38929 L
s
% Start of user PostScript
-3. -1.28571 -2.83118 -0.891795 MAarrowhead1
% End of user PostScript
.02381 .39453 m
.0416 .45679 L
s
% Start of user PostScript
-3. -0.857143 -2.88226 -0.445061 MAarrowhead1
% End of user PostScript
.02381 .45928 m
.03297 .52339 L
s
% Start of user PostScript
-3. -0.428571 -2.93939 -0.00430736 MAarrowhead1
% End of user PostScript
.02381 .5888 m
.03297 .52469 L
s
% Start of user PostScript
-3. 0.428571 -2.93939 0.00430736 MAarrowhead1
% End of user PostScript
.02381 .65355 m
.0416 .59129 L
s
% Start of user PostScript
-3. 0.857143 -2.88226 0.445061 MAarrowhead1
% End of user PostScript
.02381 .71831 m
.04932 .65879 L
s
% Start of user PostScript
-3. 1.28571 -2.83118 0.891795 MAarrowhead1
% End of user PostScript
.02381 .78307 m
.05594 .72684 L
s
% Start of user PostScript
-3. 1.71429 -2.78737 1.34218 MAarrowhead1
% End of user PostScript
.02381 .84782 m
.06145 .79513 L
s
% Start of user PostScript
-3. 2.14286 -2.7509 1.79411 MAarrowhead1
% End of user PostScript
.02381 .91258 m
.06595 .86341 L
s
% Start of user PostScript
-3. 2.57143 -2.72109 2.24603 MAarrowhead1
% End of user PostScript
.02381 .97734 m
.0696 .93155 L
s
% Start of user PostScript
-3. 3. -2.69695 2.69695 MAarrowhead1
% End of user PostScript
.08857 .07074 m
.13773 .11289 L
s
% Start of user PostScript
-2.57143 -3. -2.24603 -2.72109 MAarrowhead1
% End of user PostScript
.08857 .1355 m
.13436 .18129 L
s
% Start of user PostScript
-2.57143 -2.57143 -2.26838 -2.26838 MAarrowhead1
% End of user PostScript
.08857 .20026 m
.13002 .25 L
s
% Start of user PostScript
-2.57143 -2.14286 -2.29706 -1.81362 MAarrowhead1
% End of user PostScript
.08857 .26501 m
.12449 .31889 L
s
% Start of user PostScript
-2.57143 -1.71429 -2.3337 -1.35769 MAarrowhead1
% End of user PostScript
.08857 .32977 m
.11753 .38769 L
s
% Start of user PostScript
-2.57143 -1.28571 -2.37977 -0.902388 MAarrowhead1
% End of user PostScript
.08857 .39453 m
.10904 .45596 L
s
% Start of user PostScript
-2.57143 -0.857143 -2.4359 -0.450564 MAarrowhead1
% End of user PostScript
.08857 .45928 m
.09921 .52316 L
s
% Start of user PostScript
-2.57143 -0.428571 -2.50097 -0.00583118 MAarrowhead1
% End of user PostScript
.08857 .5888 m
.09921 .52492 L
s
% Start of user PostScript
-2.57143 0.428571 -2.50097 0.00583118 MAarrowhead1
% End of user PostScript
.08857 .65355 m
.10904 .59212 L
s
% Start of user PostScript
-2.57143 0.857143 -2.4359 0.450564 MAarrowhead1
% End of user PostScript
.08857 .71831 m
.11753 .66039 L
s
% Start of user PostScript
-2.57143 1.28571 -2.37977 0.902388 MAarrowhead1
% End of user PostScript
.08857 .78307 m
.12449 .72919 L
s
% Start of user PostScript
-2.57143 1.71429 -2.3337 1.35769 MAarrowhead1
% End of user PostScript
.08857 .84782 m
.13002 .79807 L
s
% Start of user PostScript
-2.57143 2.14286 -2.29706 1.81362 MAarrowhead1
% End of user PostScript
.08857 .91258 m
.13436 .86679 L
s
% Start of user PostScript
-2.57143 2.57143 -2.26838 2.26838 MAarrowhead1
% End of user PostScript
.08857 .97734 m
.13773 .93519 L
s
% Start of user PostScript
-2.57143 3. -2.24603 2.72109 MAarrowhead1
% End of user PostScript
.15332 .07074 m
.20602 .10838 L
s
% Start of user PostScript
-2.14286 -3. -1.79411 -2.7509 MAarrowhead1
% End of user PostScript
.15332 .1355 m
.20307 .17696 L
s
% Start of user PostScript
-2.14286 -2.57143 -1.81362 -2.29706 MAarrowhead1
% End of user PostScript
.15332 .20026 m
.19911 .24605 L
s
% Start of user PostScript
-2.14286 -2.14286 -1.83981 -1.83981 MAarrowhead1
% End of user PostScript
.15332 .26501 m
.19378 .31558 L
s
% Start of user PostScript
-2.14286 -1.71429 -1.87513 -1.37963 MAarrowhead1
% End of user PostScript
.15332 .32977 m
.18664 .3853 L
s
% Start of user PostScript
-2.14286 -1.28571 -1.92236 -0.918217 MAarrowhead1
% End of user PostScript
.15332 .39453 m
.17737 .45465 L
s
% Start of user PostScript
-2.14286 -0.857143 -1.98369 -0.459224 MAarrowhead1
% End of user PostScript
.15332 .45928 m
.16602 .52278 L
s
% Start of user PostScript
-2.14286 -0.428571 -2.05881 -0.00832257 MAarrowhead1
% End of user PostScript
.15332 .5888 m
.16602 .5253 L
s
% Start of user PostScript
-2.14286 0.428571 -2.05881 0.00832257 MAarrowhead1
% End of user PostScript
.15332 .65355 m
.17737 .59343 L
s
% Start of user PostScript
-2.14286 0.857143 -1.98369 0.459224 MAarrowhead1
% End of user PostScript
.15332 .71831 m
.18664 .66278 L
s
% Start of user PostScript
-2.14286 1.28571 -1.92236 0.918217 MAarrowhead1
% End of user PostScript
.15332 .78307 m
.19378 .7325 L
s
% Start of user PostScript
-2.14286 1.71429 -1.87513 1.37963 MAarrowhead1
% End of user PostScript
.15332 .84782 m
.19911 .80203 L
s
% Start of user PostScript
-2.14286 2.14286 -1.83981 1.83981 MAarrowhead1
% End of user PostScript
.15332 .91258 m
.20307 .87112 L
s
% Start of user PostScript
-2.14286 2.57143 -1.81362 2.29706 MAarrowhead1
% End of user PostScript
.15332 .97734 m
.20602 .9397 L
s
% Start of user PostScript
-2.14286 3. -1.79411 2.7509 MAarrowhead1
% End of user PostScript
.21808 .07074 m
.2743 .10287 L
s
% Start of user PostScript
-1.71429 -3. -1.34218 -2.78737 MAarrowhead1
% End of user PostScript
.21808 .1355 m
.27196 .17142 L
s
% Start of user PostScript
-1.71429 -2.57143 -1.35769 -2.3337 MAarrowhead1
% End of user PostScript
.21808 .20026 m
.26865 .24071 L
s
% Start of user PostScript
-1.71429 -2.14286 -1.37963 -1.87513 MAarrowhead1
% End of user PostScript
.21808 .26501 m
.26387 .3108 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.41124 -1.41124 MAarrowhead1
% End of user PostScript
.21808 .32977 m
.25693 .38158 L
s
% Start of user PostScript
-1.71429 -1.28571 -1.45714 -0.942857 MAarrowhead1
% End of user PostScript
.21808 .39453 m
.24704 .45245 L
s
% Start of user PostScript
-1.71429 -0.857143 -1.52262 -0.473817 MAarrowhead1
% End of user PostScript
.21808 .45928 m
.23378 .52211 L
s
% Start of user PostScript
-1.71429 -0.428571 -1.61034 -0.0127961 MAarrowhead1
% End of user PostScript
.21808 .5888 m
.23378 .52597 L
s
% Start of user PostScript
-1.71429 0.428571 -1.61034 0.0127961 MAarrowhead1
% End of user PostScript
.21808 .65355 m
.24704 .59563 L
s
% Start of user PostScript
-1.71429 0.857143 -1.52262 0.473817 MAarrowhead1
% End of user PostScript
.21808 .71831 m
.25693 .6665 L
s
% Start of user PostScript
-1.71429 1.28571 -1.45714 0.942857 MAarrowhead1
% End of user PostScript
.21808 .78307 m
.26387 .73728 L
s
% Start of user PostScript
-1.71429 1.71429 -1.41124 1.41124 MAarrowhead1
% End of user PostScript
.21808 .84782 m
.26865 .80737 L
s
% Start of user PostScript
-1.71429 2.14286 -1.37963 1.87513 MAarrowhead1
% End of user PostScript
.21808 .91258 m
.27196 .87666 L
s
% Start of user PostScript
-1.71429 2.57143 -1.35769 2.3337 MAarrowhead1
% End of user PostScript
.21808 .97734 m
.2743 .94521 L
s
% Start of user PostScript
-1.71429 3. -1.34218 2.78737 MAarrowhead1
% End of user PostScript
.28284 .07074 m
.34236 .09625 L
s
% Start of user PostScript
-1.28571 -3. -0.891795 -2.83118 MAarrowhead1
% End of user PostScript
.28284 .1355 m
.34076 .16446 L
s
% Start of user PostScript
-1.28571 -2.57143 -0.902388 -2.37977 MAarrowhead1
% End of user PostScript
.28284 .20026 m
.33836 .23357 L
s
% Start of user PostScript
-1.28571 -2.14286 -0.918217 -1.92236 MAarrowhead1
% End of user PostScript
.28284 .26501 m
.33464 .30387 L
s
% Start of user PostScript
-1.28571 -1.71429 -0.942857 -1.45714 MAarrowhead1
% End of user PostScript
.28284 .32977 m
.32863 .37556 L
s
% Start of user PostScript
-1.28571 -1.28571 -0.982669 -0.982669 MAarrowhead1
% End of user PostScript
.28284 .39453 m
.31876 .44841 L
s
% Start of user PostScript
-1.28571 -0.857143 -1.04799 -0.50055 MAarrowhead1
% End of user PostScript
.28284 .45928 m
.30331 .52072 L
s
% Start of user PostScript
-1.28571 -0.428571 -1.15019 -0.0219929 MAarrowhead1
% End of user PostScript
.28284 .5888 m
.30331 .52736 L
s
% Start of user PostScript
-1.28571 0.428571 -1.15019 0.0219929 MAarrowhead1
% End of user PostScript
.28284 .65355 m
.31876 .59967 L
s
% Start of user PostScript
-1.28571 0.857143 -1.04799 0.50055 MAarrowhead1
% End of user PostScript
.28284 .71831 m
.32863 .67252 L
s
% Start of user PostScript
-1.28571 1.28571 -0.982669 0.982669 MAarrowhead1
% End of user PostScript
.28284 .78307 m
.33464 .74421 L
s
% Start of user PostScript
-1.28571 1.71429 -0.942857 1.45714 MAarrowhead1
% End of user PostScript
.28284 .84782 m
.33836 .81451 L
s
% Start of user PostScript
-1.28571 2.14286 -0.918217 1.92236 MAarrowhead1
% End of user PostScript
.28284 .91258 m
.34076 .88362 L
s
% Start of user PostScript
-1.28571 2.57143 -0.902388 2.37977 MAarrowhead1
% End of user PostScript
.28284 .97734 m
.34236 .95183 L
s
% Start of user PostScript
-1.28571 3. -0.891795 2.83118 MAarrowhead1
% End of user PostScript
.34759 .07074 m
.40986 .08853 L
s
% Start of user PostScript
-0.857143 -3. -0.445061 -2.88226 MAarrowhead1
% End of user PostScript
.34759 .1355 m
.40903 .15598 L
s
% Start of user PostScript
-0.857143 -2.57143 -0.450564 -2.4359 MAarrowhead1
% End of user PostScript
.34759 .20026 m
.40772 .22431 L
s
% Start of user PostScript
-0.857143 -2.14286 -0.459224 -1.98369 MAarrowhead1
% End of user PostScript
.34759 .26501 m
.40551 .29397 L
s
% Start of user PostScript
-0.857143 -1.71429 -0.473817 -1.52262 MAarrowhead1
% End of user PostScript
.34759 .32977 m
.40147 .36569 L
s
% Start of user PostScript
-0.857143 -1.28571 -0.50055 -1.04799 MAarrowhead1
% End of user PostScript
.34759 .39453 m
.39338 .44032 L
s
% Start of user PostScript
-0.857143 -0.857143 -0.554097 -0.554097 MAarrowhead1
% End of user PostScript
.34759 .45928 m
.37655 .5172 L
s
% Start of user PostScript
-0.857143 -0.428571 -0.66548 -0.0452455 MAarrowhead1
% End of user PostScript
.34759 .5888 m
.37655 .53088 L
s
% Start of user PostScript
-0.857143 0.428571 -0.66548 0.0452455 MAarrowhead1
% End of user PostScript
.34759 .65355 m
.39338 .60776 L
s
% Start of user PostScript
-0.857143 0.857143 -0.554097 0.554097 MAarrowhead1
% End of user PostScript
.34759 .71831 m
.40147 .68239 L
s
% Start of user PostScript
-0.857143 1.28571 -0.50055 1.04799 MAarrowhead1
% End of user PostScript
.34759 .78307 m
.40551 .75411 L
s
% Start of user PostScript
-0.857143 1.71429 -0.473817 1.52262 MAarrowhead1
% End of user PostScript
.34759 .84782 m
.40772 .82377 L
s
% Start of user PostScript
-0.857143 2.14286 -0.459224 1.98369 MAarrowhead1
% End of user PostScript
.34759 .91258 m
.40903 .8921 L
s
% Start of user PostScript
-0.857143 2.57143 -0.450564 2.4359 MAarrowhead1
% End of user PostScript
.34759 .97734 m
.40986 .95955 L
s
% Start of user PostScript
-0.857143 3. -0.445061 2.88226 MAarrowhead1
% End of user PostScript
.41235 .07074 m
.47645 .0799 L
s
% Start of user PostScript
-0.428571 -3. -0.00430736 -2.93939 MAarrowhead1
% End of user PostScript
.41235 .1355 m
.47622 .14615 L
s
% Start of user PostScript
-0.428571 -2.57143 -0.00583118 -2.50097 MAarrowhead1
% End of user PostScript
.41235 .20026 m
.47585 .21296 L
s
% Start of user PostScript
-0.428571 -2.14286 -0.00832257 -2.05881 MAarrowhead1
% End of user PostScript
.41235 .26501 m
.47517 .28072 L
s
% Start of user PostScript
-0.428571 -1.71429 -0.0127961 -1.61034 MAarrowhead1
% End of user PostScript
.41235 .32977 m
.47378 .35025 L
s
% Start of user PostScript
-0.428571 -1.28571 -0.0219929 -1.15019 MAarrowhead1
% End of user PostScript
.41235 .39453 m
.47027 .42349 L
s
% Start of user PostScript
-0.428571 -0.857143 -0.0452455 -0.66548 MAarrowhead1
% End of user PostScript
.41235 .45928 m
.45814 .50507 L
s
% Start of user PostScript
-0.428571 -0.428571 -0.125526 -0.125526 MAarrowhead1
% End of user PostScript
.41235 .5888 m
.45814 .54301 L
s
% Start of user PostScript
-0.428571 0.428571 -0.125526 0.125526 MAarrowhead1
% End of user PostScript
.41235 .65355 m
.47027 .62459 L
s
% Start of user PostScript
-0.428571 0.857143 -0.0452455 0.66548 MAarrowhead1
% End of user PostScript
.41235 .71831 m
.47378 .69783 L
s
% Start of user PostScript
-0.428571 1.28571 -0.0219929 1.15019 MAarrowhead1
% End of user PostScript
.41235 .78307 m
.47517 .76736 L
s
% Start of user PostScript
-0.428571 1.71429 -0.0127961 1.61034 MAarrowhead1
% End of user PostScript
.41235 .84782 m
.47585 .83512 L
s
% Start of user PostScript
-0.428571 2.14286 -0.00832257 2.05881 MAarrowhead1
% End of user PostScript
.41235 .91258 m
.47622 .90193 L
s
% Start of user PostScript
-0.428571 2.57143 -0.00583118 2.50097 MAarrowhead1
% End of user PostScript
.41235 .97734 m
.47645 .96818 L
s
% Start of user PostScript
-0.428571 3. -0.00430736 2.93939 MAarrowhead1
% End of user PostScript
.47711 .07074 m
.54186 .07074 L
s
% Start of user PostScript
0 -3. 0.428571 -3. MAarrowhead1
% End of user PostScript
.47711 .1355 m
.54186 .1355 L
s
% Start of user PostScript
0 -2.57143 0.428571 -2.57143 MAarrowhead1
% End of user PostScript
.47711 .20026 m
.54186 .20026 L
s
% Start of user PostScript
0 -2.14286 0.428571 -2.14286 MAarrowhead1
% End of user PostScript
.47711 .26501 m
.54186 .26501 L
s
% Start of user PostScript
0 -1.71429 0.428571 -1.71429 MAarrowhead1
% End of user PostScript
.47711 .32977 m
.54186 .32977 L
s
% Start of user PostScript
0 -1.28571 0.428571 -1.28571 MAarrowhead1
% End of user PostScript
.47711 .39453 m
.54186 .39453 L
s
% Start of user PostScript
0 -0.857143 0.428571 -0.857143 MAarrowhead1
% End of user PostScript
.47711 .45928 m
.54186 .45928 L
s
% Start of user PostScript
0 -0.428571 0.428571 -0.428571 MAarrowhead1
% End of user PostScript
.47711 .5888 m
.54186 .5888 L
s
% Start of user PostScript
0 0.428571 0.428571 0.428571 MAarrowhead1
% End of user PostScript
.47711 .65355 m
.54186 .65355 L
s
% Start of user PostScript
0 0.857143 0.428571 0.857143 MAarrowhead1
% End of user PostScript
.47711 .71831 m
.54186 .71831 L
s
% Start of user PostScript
0 1.28571 0.428571 1.28571 MAarrowhead1
% End of user PostScript
.47711 .78307 m
.54186 .78307 L
s
% Start of user PostScript
0 1.71429 0.428571 1.71429 MAarrowhead1
% End of user PostScript
.47711 .84782 m
.54186 .84782 L
s
% Start of user PostScript
0 2.14286 0.428571 2.14286 MAarrowhead1
% End of user PostScript
.47711 .91258 m
.54186 .91258 L
s
% Start of user PostScript
0 2.57143 0.428571 2.57143 MAarrowhead1
% End of user PostScript
.47711 .97734 m
.54186 .97734 L
s
% Start of user PostScript
0 3. 0.428571 3. MAarrowhead1
% End of user PostScript
.54186 .07074 m
.60597 .06159 L
s
% Start of user PostScript
0.428571 -3. 0.852835 -3.06061 MAarrowhead1
% End of user PostScript
.54186 .1355 m
.60574 .12485 L
s
% Start of user PostScript
0.428571 -2.57143 0.851312 -2.64189 MAarrowhead1
% End of user PostScript
.54186 .20026 m
.60536 .18756 L
s
% Start of user PostScript
0.428571 -2.14286 0.84882 -2.22691 MAarrowhead1
% End of user PostScript
.54186 .26501 m
.60468 .24931 L
s
% Start of user PostScript
0.428571 -1.71429 0.844347 -1.81823 MAarrowhead1
% End of user PostScript
.54186 .32977 m
.6033 .30929 L
s
% Start of user PostScript
0.428571 -1.28571 0.83515 -1.42124 MAarrowhead1
% End of user PostScript
.54186 .39453 m
.59978 .36557 L
s
% Start of user PostScript
0.428571 -0.857143 0.811897 -1.04881 MAarrowhead1
% End of user PostScript
.54186 .45928 m
.58765 .41349 L
s
% Start of user PostScript
0.428571 -0.428571 0.731617 -0.731617 MAarrowhead1
% End of user PostScript
.54186 .5888 m
.58765 .63459 L
s
% Start of user PostScript
0.428571 0.428571 0.731617 0.731617 MAarrowhead1
% End of user PostScript
.54186 .65355 m
.59978 .68251 L
s
% Start of user PostScript
0.428571 0.857143 0.811897 1.04881 MAarrowhead1
% End of user PostScript
.54186 .71831 m
.6033 .73879 L
s
% Start of user PostScript
0.428571 1.28571 0.83515 1.42124 MAarrowhead1
% End of user PostScript
.54186 .78307 m
.60468 .79877 L
s
% Start of user PostScript
0.428571 1.71429 0.844347 1.81823 MAarrowhead1
% End of user PostScript
.54186 .84782 m
.60536 .86052 L
s
% Start of user PostScript
0.428571 2.14286 0.84882 2.22691 MAarrowhead1
% End of user PostScript
.54186 .91258 m
.60574 .92322 L
s
% Start of user PostScript
0.428571 2.57143 0.851312 2.64189 MAarrowhead1
% End of user PostScript
.54186 .97734 m
.60597 .98649 L
s
% Start of user PostScript
0.428571 3. 0.852835 3.06061 MAarrowhead1
% End of user PostScript
.60662 .07074 m
.66888 .05295 L
s
% Start of user PostScript
0.857143 -3. 1.26922 -3.11774 MAarrowhead1
% End of user PostScript
.60662 .1355 m
.66805 .11502 L
s
% Start of user PostScript
0.857143 -2.57143 1.26372 -2.70695 MAarrowhead1
% End of user PostScript
.60662 .20026 m
.66674 .17621 L
s
% Start of user PostScript
0.857143 -2.14286 1.25506 -2.30202 MAarrowhead1
% End of user PostScript
.60662 .26501 m
.66454 .23605 L
s
% Start of user PostScript
0.857143 -1.71429 1.24047 -1.90595 MAarrowhead1
% End of user PostScript
.60662 .32977 m
.6605 .29385 L
s
% Start of user PostScript
0.857143 -1.28571 1.21374 -1.52344 MAarrowhead1
% End of user PostScript
.60662 .39453 m
.65241 .34874 L
s
% Start of user PostScript
0.857143 -0.857143 1.16019 -1.16019 MAarrowhead1
% End of user PostScript
.60662 .45928 m
.63558 .40136 L
s
% Start of user PostScript
0.857143 -0.428571 1.04881 -0.811897 MAarrowhead1
% End of user PostScript
.60662 .5888 m
.63558 .64672 L
s
% Start of user PostScript
0.857143 0.428571 1.04881 0.811897 MAarrowhead1
% End of user PostScript
.60662 .65355 m
.65241 .69934 L
s
% Start of user PostScript
0.857143 0.857143 1.16019 1.16019 MAarrowhead1
% End of user PostScript
.60662 .71831 m
.6605 .75423 L
s
% Start of user PostScript
0.857143 1.28571 1.21374 1.52344 MAarrowhead1
% End of user PostScript
.60662 .78307 m
.66454 .81203 L
s
% Start of user PostScript
0.857143 1.71429 1.24047 1.90595 MAarrowhead1
% End of user PostScript
.60662 .84782 m
.66674 .87187 L
s
% Start of user PostScript
0.857143 2.14286 1.25506 2.30202 MAarrowhead1
% End of user PostScript
.60662 .91258 m
.66805 .93306 L
s
% Start of user PostScript
0.857143 2.57143 1.26372 2.70695 MAarrowhead1
% End of user PostScript
.60662 .97734 m
.66888 .99513 L
s
% Start of user PostScript
0.857143 3. 1.26922 3.11774 MAarrowhead1
% End of user PostScript
.67137 .07074 m
.7309 .04524 L
s
% Start of user PostScript
1.28571 -3. 1.67963 -3.16882 MAarrowhead1
% End of user PostScript
.67137 .1355 m
.72929 .10654 L
s
% Start of user PostScript
1.28571 -2.57143 1.66904 -2.76309 MAarrowhead1
% End of user PostScript
.67137 .20026 m
.7269 .16694 L
s
% Start of user PostScript
1.28571 -2.14286 1.65321 -2.36336 MAarrowhead1
% End of user PostScript
.67137 .26501 m
.72318 .22616 L
s
% Start of user PostScript
1.28571 -1.71429 1.62857 -1.97143 MAarrowhead1
% End of user PostScript
.67137 .32977 m
.71716 .28398 L
s
% Start of user PostScript
1.28571 -1.28571 1.58876 -1.58876 MAarrowhead1
% End of user PostScript
.67137 .39453 m
.7073 .34065 L
s
% Start of user PostScript
1.28571 -0.857143 1.52344 -1.21374 MAarrowhead1
% End of user PostScript
.67137 .45928 m
.69185 .39785 L
s
% Start of user PostScript
1.28571 -0.428571 1.42124 -0.83515 MAarrowhead1
% End of user PostScript
.67137 .5888 m
.69185 .65023 L
s
% Start of user PostScript
1.28571 0.428571 1.42124 0.83515 MAarrowhead1
% End of user PostScript
.67137 .65355 m
.7073 .70743 L
s
% Start of user PostScript
1.28571 0.857143 1.52344 1.21374 MAarrowhead1
% End of user PostScript
.67137 .71831 m
.71716 .7641 L
s
% Start of user PostScript
1.28571 1.28571 1.58876 1.58876 MAarrowhead1
% End of user PostScript
.67137 .78307 m
.72318 .82192 L
s
% Start of user PostScript
1.28571 1.71429 1.62857 1.97143 MAarrowhead1
% End of user PostScript
.67137 .84782 m
.7269 .88114 L
s
% Start of user PostScript
1.28571 2.14286 1.65321 2.36336 MAarrowhead1
% End of user PostScript
.67137 .91258 m
.72929 .94154 L
s
% Start of user PostScript
1.28571 2.57143 1.66904 2.76309 MAarrowhead1
% End of user PostScript
.67137 .97734 m
.7309 1.00284 L
s
% Start of user PostScript
1.28571 3. 1.67963 3.16882 MAarrowhead1
% End of user PostScript
.73613 .07074 m
.79236 .03862 L
s
% Start of user PostScript
1.71429 -3. 2.08639 -3.21263 MAarrowhead1
% End of user PostScript
.73613 .1355 m
.79001 .09958 L
s
% Start of user PostScript
1.71429 -2.57143 2.07088 -2.80916 MAarrowhead1
% End of user PostScript
.73613 .20026 m
.7867 .1598 L
s
% Start of user PostScript
1.71429 -2.14286 2.04894 -2.41058 MAarrowhead1
% End of user PostScript
.73613 .26501 m
.78192 .21922 L
s
% Start of user PostScript
1.71429 -1.71429 2.01733 -2.01733 MAarrowhead1
% End of user PostScript
.73613 .32977 m
.77499 .27796 L
s
% Start of user PostScript
1.71429 -1.28571 1.97143 -1.62857 MAarrowhead1
% End of user PostScript
.73613 .39453 m
.76509 .33661 L
s
% Start of user PostScript
1.71429 -0.857143 1.90595 -1.24047 MAarrowhead1
% End of user PostScript
.73613 .45928 m
.75184 .39646 L
s
% Start of user PostScript
1.71429 -0.428571 1.81823 -0.844347 MAarrowhead1
% End of user PostScript
.73613 .5888 m
.75184 .65162 L
s
% Start of user PostScript
1.71429 0.428571 1.81823 0.844347 MAarrowhead1
% End of user PostScript
.73613 .65355 m
.76509 .71147 L
s
% Start of user PostScript
1.71429 0.857143 1.90595 1.24047 MAarrowhead1
% End of user PostScript
.73613 .71831 m
.77499 .77011 L
s
% Start of user PostScript
1.71429 1.28571 1.97143 1.62857 MAarrowhead1
% End of user PostScript
.73613 .78307 m
.78192 .82886 L
s
% Start of user PostScript
1.71429 1.71429 2.01733 2.01733 MAarrowhead1
% End of user PostScript
.73613 .84782 m
.7867 .88828 L
s
% Start of user PostScript
1.71429 2.14286 2.04894 2.41058 MAarrowhead1
% End of user PostScript
.73613 .91258 m
.79001 .9485 L
s
% Start of user PostScript
1.71429 2.57143 2.07088 2.80916 MAarrowhead1
% End of user PostScript
.73613 .97734 m
.79236 1.00946 L
s
% Start of user PostScript
1.71429 3. 2.08639 3.21263 MAarrowhead1
% End of user PostScript
.80089 .07074 m
.85358 .03311 L
s
% Start of user PostScript
2.14286 -3. 2.4916 -3.2491 MAarrowhead1
% End of user PostScript
.80089 .1355 m
.85064 .09404 L
s
% Start of user PostScript
2.14286 -2.57143 2.47209 -2.84579 MAarrowhead1
% End of user PostScript
.80089 .20026 m
.84668 .15447 L
s
% Start of user PostScript
2.14286 -2.14286 2.4459 -2.4459 MAarrowhead1
% End of user PostScript
.80089 .26501 m
.84134 .21445 L
s
% Start of user PostScript
2.14286 -1.71429 2.41058 -2.04894 MAarrowhead1
% End of user PostScript
.80089 .32977 m
.8342 .27424 L
s
% Start of user PostScript
2.14286 -1.28571 2.36336 -1.65321 MAarrowhead1
% End of user PostScript
.80089 .39453 m
.82494 .3344 L
s
% Start of user PostScript
2.14286 -0.857143 2.30202 -1.25506 MAarrowhead1
% End of user PostScript
.80089 .45928 m
.81359 .39578 L
s
% Start of user PostScript
2.14286 -0.428571 2.22691 -0.84882 MAarrowhead1
% End of user PostScript
.80089 .5888 m
.81359 .6523 L
s
% Start of user PostScript
2.14286 0.428571 2.22691 0.84882 MAarrowhead1
% End of user PostScript
.80089 .65355 m
.82494 .71368 L
s
% Start of user PostScript
2.14286 0.857143 2.30202 1.25506 MAarrowhead1
% End of user PostScript
.80089 .71831 m
.8342 .77384 L
s
% Start of user PostScript
2.14286 1.28571 2.36336 1.65321 MAarrowhead1
% End of user PostScript
.80089 .78307 m
.84134 .83363 L
s
% Start of user PostScript
2.14286 1.71429 2.41058 2.04894 MAarrowhead1
% End of user PostScript
.80089 .84782 m
.84668 .89361 L
s
% Start of user PostScript
2.14286 2.14286 2.4459 2.4459 MAarrowhead1
% End of user PostScript
.80089 .91258 m
.85064 .95403 L
s
% Start of user PostScript
2.14286 2.57143 2.47209 2.84579 MAarrowhead1
% End of user PostScript
.80089 .97734 m
.85358 1.01497 L
s
% Start of user PostScript
2.14286 3. 2.4916 3.2491 MAarrowhead1
% End of user PostScript
.86564 .07074 m
.91481 .0286 L
s
% Start of user PostScript
2.57143 -3. 2.89682 -3.27891 MAarrowhead1
% End of user PostScript
.86564 .1355 m
.91143 .08971 L
s
% Start of user PostScript
2.57143 -2.57143 2.87447 -2.87447 MAarrowhead1
% End of user PostScript
.86564 .20026 m
.9071 .15051 L
s
% Start of user PostScript
2.57143 -2.14286 2.84579 -2.47209 MAarrowhead1
% End of user PostScript
.86564 .26501 m
.90156 .21113 L
s
% Start of user PostScript
2.57143 -1.71429 2.80916 -2.07088 MAarrowhead1
% End of user PostScript
.86564 .32977 m
.8946 .27185 L
s
% Start of user PostScript
2.57143 -1.28571 2.76309 -1.66904 MAarrowhead1
% End of user PostScript
.86564 .39453 m
.88612 .33309 L
s
% Start of user PostScript
2.57143 -0.857143 2.70695 -1.26372 MAarrowhead1
% End of user PostScript
.86564 .45928 m
.87629 .39541 L
s
% Start of user PostScript
2.57143 -0.428571 2.64189 -0.851312 MAarrowhead1
% End of user PostScript
.86564 .5888 m
.87629 .65267 L
s
% Start of user PostScript
2.57143 0.428571 2.64189 0.851312 MAarrowhead1
% End of user PostScript
.86564 .65355 m
.88612 .71499 L
s
% Start of user PostScript
2.57143 0.857143 2.70695 1.26372 MAarrowhead1
% End of user PostScript
.86564 .71831 m
.8946 .77623 L
s
% Start of user PostScript
2.57143 1.28571 2.76309 1.66904 MAarrowhead1
% End of user PostScript
.86564 .78307 m
.90156 .83695 L
s
% Start of user PostScript
2.57143 1.71429 2.80916 2.07088 MAarrowhead1
% End of user PostScript
.86564 .84782 m
.9071 .89757 L
s
% Start of user PostScript
2.57143 2.14286 2.84579 2.47209 MAarrowhead1
% End of user PostScript
.86564 .91258 m
.91143 .95837 L
s
% Start of user PostScript
2.57143 2.57143 2.87447 2.87447 MAarrowhead1
% End of user PostScript
.86564 .97734 m
.91481 1.01948 L
s
% Start of user PostScript
2.57143 3. 2.89682 3.27891 MAarrowhead1
% End of user PostScript
.9304 .07074 m
.97619 .02495 L
s
% Start of user PostScript
3. -3. 3.30305 -3.30305 MAarrowhead1
% End of user PostScript
.9304 .1355 m
.97254 .08633 L
s
% Start of user PostScript
3. -2.57143 3.27891 -2.89682 MAarrowhead1
% End of user PostScript
.9304 .20026 m
.96804 .14756 L
s
% Start of user PostScript
3. -2.14286 3.2491 -2.4916 MAarrowhead1
% End of user PostScript
.9304 .26501 m
.96253 .20879 L
s
% Start of user PostScript
3. -1.71429 3.21263 -2.08639 MAarrowhead1
% End of user PostScript
.9304 .32977 m
.95591 .27025 L
s
% Start of user PostScript
3. -1.28571 3.16882 -1.67963 MAarrowhead1
% End of user PostScript
.9304 .39453 m
.94819 .33226 L
s
% Start of user PostScript
3. -0.857143 3.11774 -1.26922 MAarrowhead1
% End of user PostScript
.9304 .45928 m
.93956 .39518 L
s
% Start of user PostScript
3. -0.428571 3.06061 -0.852835 MAarrowhead1
% End of user PostScript
.9304 .5888 m
.93956 .6529 L
s
% Start of user PostScript
3. 0.428571 3.06061 0.852835 MAarrowhead1
% End of user PostScript
.9304 .65355 m
.94819 .71582 L
s
% Start of user PostScript
3. 0.857143 3.11774 1.26922 MAarrowhead1
% End of user PostScript
.9304 .71831 m
.95591 .77783 L
s
% Start of user PostScript
3. 1.28571 3.16882 1.67963 MAarrowhead1
% End of user PostScript
.9304 .78307 m
.96253 .83929 L
s
% Start of user PostScript
3. 1.71429 3.21263 2.08639 MAarrowhead1
% End of user PostScript
.9304 .84782 m
.96804 .90052 L
s
% Start of user PostScript
3. 2.14286 3.2491 2.4916 MAarrowhead1
% End of user PostScript
.9304 .91258 m
.97254 .96175 L
s
% Start of user PostScript
3. 2.57143 3.27891 2.89682 MAarrowhead1
% End of user PostScript
.9304 .97734 m
.97619 1.02312 L
s
% Start of user PostScript
3. 3. 3.30305 3.30305 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1.04808 L
0 1.04808 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[112]:=",
  ImageSize->{170.75, 178.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002Z0000/R000`400?l00000o`00003oZ_ooool0
05;ooooo00?o0000ooooooooool0EOooool005;ooooo00?o0000ooooooooool0EOooool005;ooooo
00?o0000ooooooooool0EOooool005;ooooo00?o0000ooooooooool0EOooool005;ooooo00?o0000
ooooooooool0AOooool2o`0000Sooooo0_l00004ooooo`00D_ooool00ol0003oooooooooo`0koooo
o`;o00001oooool3o`0000Oooooo0ol00004ooooo`00D_ooool00ol0003oooooooooo`0`ooooo`;o
00001oooool3o`0000Oooooo0ol00007ooooo`?o00001Oooool005;ooooo00?o0000ooooooooool0
9_ooool2o`0000Kooooo1?l00006ooooo`?o00002?ooool2o`0000Wooooo00?o0000ooooooooool0
1?ooool005;ooooo00?o0000ooooooooool09?ooool2o`0000Oooooo1?l00006ooooo`?o00002?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo001:ooooo`?o00001Oooool0
0ol0003oooooooooo`0Iooooo`Go00001?ooool3o`0000Oooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool004Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00oooooo1?l0
0004ooooo`Go00001?ooool2o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`00@oooool5o`0000Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`?o00000oooool7o`0000?ooooo0ol00007
ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`07oooo
o`;o00002Oooool2o`0000Wooooo0_l00009ooooo`;o00002Oooool3o`0000Sooooo1_l000001Ooo
oooo0000o`000?l0003ooooo00go00002?ooool2o`0000Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool2o`0000Wooooo0ol00009ooooo`?o000000?oooooo`00
0?l000002?ooool6o`0005Oooooo0008ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool2o`0000[ooooo0_l0000:ooooo`Co00002?ooool4o`0000?ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo04oooooo0_l00004ooooo`002Oooool00ol0003o
ooooooooo`08ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`?o00002?ooool4o`0000[o
oooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`0jooooo`;o00002?ooool2o`0000So
oooo0ol00004ooooo`002_ooool2o`0000[ooooo0_l00009ooooo`;o00002Oooool4o`0000[ooooo
0_l0000Fooooo`03o`000?oooooooooo033ooooo0_l00007ooooo`?o00001oooool3o`0000Oooooo
0ol00005ooooo`002_ooool2o`0000Wooooo0ol00009ooooo`?o00002oooool2o`00027ooooo00?o
0000ooooooooool0;oooool3o`0000Kooooo0ol00007ooooo`?o00002Oooool00ol0003ooooooooo
o`04ooooo`003?ooool00ol0003oooooooooo`08ooooo`;o00002oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02?ooooo1Ol00005ooooo`Co00001_ooool00ol0003oooooo`000008
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01Oooool000gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Wooooo1Ol00005oooo
o`?o00001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`00D_ooool00ol0003oooooooooo`0?oooo
o`?o00001Oooool5o`0000Gooooo0_l000000ooooooo0000ooooo`04ooooo`;o00002Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool005;o
oooo00?o0000ooooooooool03Oooool6o`000004ooooool0003o0000o`0000?ooooo00Co0000oooo
oooooooooooo0ol00008ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool2o`0000Wooooo0_l00009ooooo`;o00002Oooool2o`00
00Wooooo1?l00007oooooa3o00000_ooool2o`000003ooooool0003o000000Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o
00002Oooool3o`0000[ooooo1_l000000ooooooo0000ooooo`05ooooo`;o0000Coooool000Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
0_l0000:ooooo`;o00002_ooool4o`0000Wooooo1Ol0001Aooooo`03o`000?oooooooooo00?ooooo
0008ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o
0000ooooooooool02Oooool3o`0000Wooooo0ol0000<ooooo`03o`000?oooooooooo04Cooooo0_l0
0008ooooo`;o00001Oooool000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`?o00002?ooool4o`0000_ooooo00?o0000
ooooooooool0;oooool2o`0000Wooooo0_l00007ooooo`?o00001oooool3o`0000Gooooo000:oooo
o`03o`000?oooooooooo00Sooooo0_l0000:ooooo`;o00002Oooool3o`0000Sooooo1Ol0000Foooo
o`03o`000?oooooooooo02kooooo0ol00007ooooo`Co00001_ooool3o`0000Oooooo0ol00006oooo
o`002_ooool2o`0000Wooooo0_l00009ooooo`Co00002oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02Gooooo0_l00006ooooo`?o00002?ooool3o`0000Sooooo00?o0000oooooooo
ool01oooool2o`0000Kooooo000:ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`;o0000
;Oooool00ol0003oooooooooo`0Kooooo`;o00001_ooool3o`0000Kooooo00?o0000ooooool00000
2?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo01Sooooo1?l00005ooooo`;o000000?oooooo`000?ooool01Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`003Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00oooooo1?l00003
ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool005;ooooo00?o0000ooooooooool01?ooool3o`0000?ooooo1ol00002oooo
o`?o00002?ooool2o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`;o
00002Oooool2o`0000Wooooo1?l00007ooooo`go00001Oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`?o00002?ooool8o`000003ooooool0003ooooo00Go
oooo0_l0001?ooooo`001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00002oooool4o`0000Gooooo
00?o0000ooooooooool01_l00015ooooo`;o00002Oooool00ol0003oooooooooo`04ooooo`002?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool2o`0000[ooooo00?o0000ooooool000002_ooool5o`0000?ooooo00?o0000ooooooooool00_l0
0002ooooo`03o`000?oooooooooo02oooooo0_l00008ooooo`;o00001oooool3o`0000Sooooo0_l0
0006ooooo`002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`08ooooo`;o00002Oooool5o`0000Gooooo00?o0000
ooooooooool00oooool2o`0002oooooo0ol00007ooooo`?o00001_ooool3o`0000Sooooo0_l00007
ooooo`002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l0000:oooo
o`;o00002Oooool3o`0000oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo02Gooooo0_l00006ooooo`?o00001oooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooo
oooo00Gooooo000:ooooo`;o00002?ooool00ol0003oooooo`000009ooooo`;o00002Oooool4o`00
00_ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool06oooool2o`0000Kooooo0ol00007ooooo`;o00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool000Wooooo0ol00009oooo
o`;o00002oooool00ol0003oooooooooo`09ooooo`;o00006_ooool3o`0000Gooooo00?o0000oooo
ooooool06Oooool3o`0000Kooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo000;ooooo`;o
00002Oooool2o`0000_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`Go
00001?ooool4o`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`00
3?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
3?ooool5o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo001Booooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`?o00000ooo
ool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o00002Oooool2o`0000Wooooo0ol0
0008ooooo`co00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`;o00002_ooool3o`000003ooooool0003o000000;ooooo00?o0000ooooooooool01?ooool2
o`0003gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`001oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`Co000000?oooooo`00
0?ooool0;oooool2o`0000Sooooo00?o0000ooooooooool01oooool2o`0000Wooooo00?o0000oooo
ooooool01Oooool000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2o`0000_ooooo0ol00009ooooo`Go
00009_ooool2o`0000Oooooo0ol00007ooooo`;o00002?ooool3o`0000Sooooo00?o0000oooooooo
ool01_ooool000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`Co0000
3?ooool00ol0003oooooooooo`0Sooooo`?o00001_ooool3o`0000Oooooo0_l00008ooooo`?o0000
2?ooool2o`0000Sooooo0008ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooo`000009ooooo`;o00002Oooool3o`0000cooooo0_l0000;ooooo`03o`000?oo
oooooooo01[ooooo0_l00006ooooo`?o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo0009ooooo`;o00002Oooool2
o`0000Wooooo0ol00009ooooo`;o00002oooool2o`0001Sooooo00?o0000ooooooooool06?ooool4
o`0000Kooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0008ooooo`?o00002Oooool2o`00
00Wooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Gooooo`Co00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo0009ooooo`;o00002_ooool2o`0000[ooooo0_l0000;ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03_ooool5o`0000?ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000:ooooo`;o00002_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool5o`0000?o
oooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000_ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`04ooooo`?o00000_ooool3o`0000Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
0006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000Wooooo0ol0
0008ooooo`co00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00Co
0000oooooooooooo00002?ooool000Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo0_l0
000Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo0007ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool2o`0000cooooo1?l000000ooooooo0000ooooo`0Tooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o00002Oooool2
o`0000Sooooo0007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool2o`00
00[ooooo1_l0000Kooooo`;o00001oooool2o`0000Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`?o00002?ooool2o`0000Wooooo0007ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool2o`0000kooooo00?o0000ooooooooool06?ooool3o`0000Ko
oooo0_l00008ooooo`;o00002?ooool2o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo00Oo
oooo0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`;o00002_ooool2o`0000[ooooo0ol00005ooooo`?o00001Oooool00ol0003ooooo
ooooo`0Gooooo`?o00001oooool2o`0000Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool000Sooooo00?o
0000ooooooooool02?ooool2o`0000[ooooo0_l00009ooooo`;o00002_ooool2o`0000gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo0_l0
0005ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0008
ooooo`;o00002Oooool2o`0000Wooooo0ol00009ooooo`?o00002oooool00ol0003oooooooooo`08
ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`;o00003oooool2o`0000Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0008oooo
o`;o00002Oooool2o`0000_ooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo0ol00006oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`002Oooool2o`0000Wooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0_l00008ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`00
2_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo0_l00006ooooo`03o`00
0?oooooooooo00Cooooo0ol000000ooooooo0000o`000009ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000;ooooo00?o
0000ooooooooool01?ooool;o`0000[ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`000008ooooo`?o
00002?ooool2o`0000[ooooo0006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0:ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`;o0000
4Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`001_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02ooo
ool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`06ooooo`;o00002?ooool2o`0000Sooooo0_l00009ooooo`;o00002?ooool2o`0000[ooooo0007
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<
ooooo`;o00000oooool00ol0003oooooooooo`0>ooooo`;o00001_ooool00ol0003oooooooooo`06
ooooo`;o00002?ooool3o`0000Oooooo0ol00008ooooo`?o00002?ooool2o`0000[ooooo0007oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;oooo
o`?o00000_ooool00ol0003oooooooooo`0=ooooo`?o00001Oooool2o`0000Wooooo00?o0000oooo
ooooool01oooool2o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`?o
00003Oooool00ol0003oooooo`00000>ooooo`?o00001_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`;o0000
2Oooool3o`0000oooooo00?o0000ooooooooool03?ooool2o`0000Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0007ooooo`;o00002Ooo
ool2o`0000Wooooo0ol00009ooooo`;o00002Oooool3o`0000_ooooo0_l0000>ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool000Oooooo0_l00009ooooo`;o00002Oooool3
o`0000Wooooo0_l0000;ooooo`;o00002oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool000Sooooo00?o0000ooooooooool02?ooool2o`00
00Wooooo0_l0000:ooooo`;o00002oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool000Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`04ooooo`?o000000?oooooo`000?ooool02Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000Kooooo1?l00006ooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooooooo1Ol00002ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01Oooool4o`0000[ooooo00?o0000ooooooooool02?ooool;o`0000[o
oooo00?o0000ooooool000000_l00006ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooooooo1Ol00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool3o`00
00_ooooo0006ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000002oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo0_l0000?ooooo`03o`000?oooooooooo01Gooooo00Co0000
oooooooooooo00005Oooool01Ol0003ooooooooooooooooo000000[ooooo0005o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`Go00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo1_l00003ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`001_oo
ool01?l0003oooooo`000?l00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo0_l0000;ooooo`00
1_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool02?ooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000001Wooooo
00?o0000ooooooooool02?ooool000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool02_ooool2o`00
00Cooooo00?o0000ooooooooool05?ooool2o`0001Kooooo00Go0000ooooooooooooooooo`00000E
ooooo`05o`000?ooooooooooooooool000002_ooool000Oooooo0ol00007ooooo`03o`000?oooooo
oooo00Sooooo00Co0000oooooooooooooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00002_ooool4o`0000?ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`?o00005oooool3o`0000_ooooo0006
ooooo`;o00002Oooool2o`0000Wooooo0_l00009ooooo`?o00002Oooool2o`0000Wooooo0ol0000=
ooooo`05o`000?ooooooooooooooool00000Eoooool000Kooooo0_l00009ooooo`;o00002Oooool2
o`0000Wooooo0ol00009ooooo`;o00002oooool2o`00013ooooo00?o0000ooooooooool0EOooool0
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1Eooooo`001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0EOooool000;oooooZ?l0000000Kooooo0_l0000:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`08ooooo`05o`000?oo
ooooooooooooool000001oooool2o`00013ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool000Kooooo0_l0
0009ooooo`;o00002Oooool2o`0000[ooooo0_l00009ooooo`;o00002_ooool3o`00013ooooo00?o
0000ooooooooool0EOooool000Kooooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo0ol00009
ooooo`;o00002Oooool3o`0000cooooo0_l00003ooooo`03o`000?oooooooooo05Gooooo0007oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo0ol00003oooo
o`03o`000?oooooooooo05Gooooo0007ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`?o00001?ooool00ol0003oooooooooo`1Eooooo`00
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo05Gooooo0006ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0EOooool000Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Eooooo`001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Gooooo0006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo2ol0000:ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`04ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`001oooool2o`0000[ooooo00?o0000ooooooooool02?ooool2o`0000[ooooo0_l0000:
ooooo`;o00006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0007oooo
o`;o00002Oooool2o`0000Wooooo0ol00009ooooo`;o00002_ooool3o`0000[ooooo0_l0000>oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000Oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`?o
00002Oooool4o`0000kooooo00?o0000ooooooooool03?ooool2o`0000Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0007ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo0_l0000:ooooo`;o00003?ooool2o`000003ooooool0003ooooo00gooooo
0_l00007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooool000002_ooool4o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool01?oo
ool2o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0007ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`Go00000_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`;o00002?ooool3
o`0000Oooooo0ol00008ooooo`?o00002?ooool2o`0000[ooooo0006ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Fooooo`;o00001oooool2o`0000Sooooo0ol00007
ooooo`?o00002?ooool3o`0000Sooooo0_l0000:ooooo`001_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000Sooooo00?o0000oooo
ooooool01?ooool3o`00013ooooo00?o0000ooooooooool01_ooool2o`0000Sooooo0_l00008oooo
o`;o00002Oooool2o`0000Wooooo00?o0000ooooooooool02?ooool000Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool<o`0000Wooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`000008ooooo`?o00002?ooool2
o`0000[ooooo000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool3o`00
00Gooooo00?o0000ooooooooool01?ooool2o`0000?ooooo0_l00008ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`;o00001oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo
0_l00009ooooo`;o00002Oooool3o`0000[ooooo0_l0000:ooooo`;o00004Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00gooooo0ol00005ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`002?ooool2o`0000Wooooo0_l0
0009ooooo`?o00002_ooool2o`0000[ooooo0ol0000Aooooo`03o`000?oooooooooo00Cooooo0_l0
000?ooooo`?o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01oooool2o`0000[ooooo0_l00009
ooooo`?o00002Oooool3o`0000_ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo0008ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`;o00002_ooool2o`0000[ooooo1?l00004oooo
o`;o00001_ooool00ol0003oooooooooo`0Gooooo`;o00002?ooool2o`0000Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`Co
00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01Oooool2o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo0_l00009ooooo`03
o`000?oooooooooo00Oooooo0007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool00009ooooo`Ko00007?ooool00ol0003oooooooooo`05ooooo`;o
00001oooool2o`0000Sooooo0_l00008ooooo`?o00002?ooool2o`0000Wooooo0007ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000cooooo1?l00002ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool01_ooool2o`0000Sooooo0_l00007ooooo`?o0000
2?ooool2o`0000Wooooo0007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000Kooooo
0ol0000Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Wooooo
0_l00008ooooo`001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool2o`0000Wooooo3?l00009ooooo`;o00002Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Sooooo001Booooo`03o`000?oooooooooo00Cooooo
0_l00003ooooo`?o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool000[ooooo0_l0000:ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool03?ooool5o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool000Wooooo0ol00009ooooo`;o00002_ooool2o`0000[ooooo0_l0000S
ooooo`03o`000?oooooooooo00kooooo1?l00005ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`002?ooool3o`0000Wooooo0_l0000:oooo
o`?o00002Oooool3o`0000[ooooo0_l0000Gooooo`03o`000?oooooooooo017ooooo0_l00005oooo
o`;o00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000:ooooo`03
o`000?oooooooooo00Oooooo0_l00009ooooo`?o00002Oooool3o`0000Wooooo0ol0000Hooooo`03
o`000?oooooooooo01Sooooo0ol00007ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`00
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l00009ooooo`;o0000
2Oooool3o`0000_ooooo0ol0000;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1?ooool2o`0000Sooooo0_l00008ooooo`;o00002Oooool2o`0000Sooooo00?o0000ooooooooool0
1oooool000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool3o`0000[ooooo0ol0000=ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool01Oooool2o`0000Sooooo0_l00008ooooo`?o00002?oo
ool2o`0000Sooooo0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool3
o`0000[ooooo1Ol0000Wooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2
o`0000Sooooo0_l00008ooooo`;o00002?ooool000Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`;o00002oooool4o`0000;ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o00001oooool000Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o00002_ooool3o`0000;o
oooo00Go0000ooooooooooooooooo`000006ooooo`?o0000??ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`;o00002Oooool=o`0000Sooooo0_l00009ooooo`;o
00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`00D_ooool00ol0003oooooooooo`04ooooo`;o0000
1?ooool4o`000003ooooool0003o000000?ooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool000_ooooo0_l00015ooooo`03o`000?oooooooooo00kooooo1?l0
0004ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000:
ooooo`?o00002_ooool00ol0003oooooooooo`08ooooo`;o0000;_ooool00ol0003oooooooooo`0>
ooooo`Go00001Oooool3o`0000Kooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`?o00002_ooool2o`0000Wooooo0ol0000:ooooo`;o00008_ooool00ol0003oooooooooo`0Ioooo
o`?o00001oooool2o`0000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool000[ooooo0_l00009ooooo`;o
00002Oooool3o`0000Wooooo0ol0000:ooooo`;o00003_ooool5o`0000Cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`04ooooo`;o00002?ooool2o`0000Sooooo0_l00008ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool000[ooooo00?o0000ooooooooool0
2?ooool2o`0000Wooooo0_l00009ooooo`?o00002Oooool4o`0000oooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`;o
00002Oooool2o`0000Sooooo0_l00007ooooo`002Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool3o`0000Wooooo1?l00008ooooo`Go0000
1?ooool00ol0003oooooooooo`04ooooo`;o00009oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01Oooool3o`0000Sooooo0_l00007ooooo`002?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Wooooo0ol00007ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo0_l00008ooooo`;o00001_ooool000Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool2o`0000_ooooo0_l000000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooooooo`Ko0000
A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0007ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool3o`0000Wooooo1ol00002ooooo`03o`000?oo
oooooooo00Cooooo0ol0001>ooooo`001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool6o`0000Gooooo3_l00007ooooo`;o00002Oooool2
o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`00D_ooool00ol0003oooooooooo`04ooooo`;o00001Oooool7o`00
00;ooooo0ol00008ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`003Oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00oooooo1?l00004ooooo`;o000000?oooooo`000?oo
ool01Oooool2o`0000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000cooooo0_l00009ooooo`;o0000
>Oooool00ol0003oooooooooo`0Iooooo`?o00001oooool2o`0000Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool000_ooooo0_l00009ooooo`?o00002Oooool3o`0002gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`04ooooo`?o00001oooool2o`0000Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo000:ooooo`?o00002?ooool3
o`0000Sooooo1Ol00009ooooo`;o00008_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Cooooo0_l00009ooooo`;o00002?ooool2o`0000Sooooo00?o0000ooooooooool01_ooool0
00[ooooo0_l00009ooooo`;o00002_ooool3o`0000Sooooo0ol0000:ooooo`?o00005_ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00002Oooool2o`00
00Kooooo0009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`000003
ooooool0003ooooo00Oooooo0ol00009ooooo`?o00002oooool2o`0000_ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01Oooool3o`0000Kooooo0009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo0ol00009ooooo`?o0000
3Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool2o`0000Gooooo0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`;o00002_ooool2o`0000[ooooo0_l000000ooooooo0000oooo
o`09ooooo`Go0000DOooool00ol0003oooooooooo`03ooooo`001oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`;o00002Oooool3o`0000[ooooo1_l00002ooooo`03o`000?oooooooooo00Cooooo0ol0001>
ooooo`001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool3o`0000Sooooo3_l00004ooooo`;o000000Coooooo`000?l0003o00002?ooool2
o`0000Wooooo0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo001Booooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`Oo00000oooool4o`00
0003ooooool0003o000000?ooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo001Booooo`03
o`000?oooooooooo00oooooo1?l00006ooooo`Co00001?ooool2o`000003ooooool0003ooooo00Go
oooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`003?ooool2o`0004Cooooo00?o0000ooooooooool06Oooool5o`0000Gooooo
0ol00007ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo000;ooooo`?o00002Oooool3o`0000Wooooo0_l0
000]ooooo`03o`000?oooooooooo02?ooooo1?l00007ooooo`;o00002?ooool2o`0000Sooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`06ooooo`002_ooool3o`0000Sooooo1?l00009
ooooo`?o00002Oooool3o`00027ooooo00?o0000ooooooooool09_ooool2o`0000Kooooo0ol00007
ooooo`;o00002Oooool2o`0000Sooooo0_l00006ooooo`002oooool00ol0003oooooooooo`08oooo
o`;o00002Oooool3o`0000Sooooo1?l00009ooooo`?o00005_ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool4o`0000Oooooo0_l00006oooo
o`002_ooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`000003ooooool0003ooooo00So
oooo0ol00008ooooo`?o00006?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`002Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool2o`000003oooo
ool0003ooooo00Oooooo0ol0000:ooooo`Co00000oooool3o`0000Gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`02ooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000[ooooo0_l0000;ooooo`Co00001?oo
ool01?l0003oooooooooooooool6o`0005Oooooo0007ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0_l0
000:ooooo`?o00002Oooool6o`0000;ooooo00?o0000ooooooooool01?ooool3o`0004kooooo0006
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000Wooooo0ol00000
0ooooooo0000o`000005oooooa7o000000?oooooo`000?l000001?l00008ooooo`;o00002Oooool2
o`0000Wooooo0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`09ooooo`00COooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo1Ol00002ooooo`Co000000?oooooo`00
0?l000000oooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`00BOooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool03oooool2o`0000Sooooo1?l00005ooooo`Co00001_ooool2o`00
00Sooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool004[o
oooo0ol00005ooooo`03o`000?oooooooooo01Wooooo1Ol00006ooooo`?o00001oooool2o`0000So
oooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool005;ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`?o00002?ooool2o`0000Sooooo
0_l00008ooooo`;o00001_ooool005;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`04ooooo`Co00001oooool2o`0000Wooooo00?o0000ooooooooool01?ooool005;ooooo00?o0000
ooooooooool0>oooool2o`0000Sooooo00?o0000ooooooooool01Oooool3o`0000Gooooo001Boooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`00D_ooool00ol0003oooooooooo`1Eooooo`00D_ooool00ol0003oooooooooo`1Eooooo`00D_oo
ool00ol0003oooooooooo`1Eooooo`00D_ooool00ol0003oooooooooo`1Eooooo`00Z_ooool00001
\
\>"],
  ImageRangeCache->{{{77.875, 247.625}, {657.25, 479.375}} -> {-6.30926, \
15.4045, 0.0394544, 0.0394544}}]
}, Open  ]],

Cell[TextData[{
  "Every point on the ",
  StyleBox["t",
    FontSlant->"Italic"],
  " axis is a singular point."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
DE3 = y'[t] == t/y[t]
solns1 = Table[ DSolve[ {DE3, y[k]==0.01}, y, t], {k,-3,3}];
solns2 = Table[ DSolve[ {DE3, y[k]==-0.01}, y, t], {k,-3,3}];
solns3 = Table[ DSolve[ {DE3, y[0]==k}, y, t], {k,-3.01,3.01}];
solns = Join[solns1,solns2,solns3];
Show[ S, Table[ Plot[ y[t]/.solns[[k]], {t,-3,3}, 
                PlotStyle->Thickness[0.01], DisplayFunction->Identity ], 
                {k,21} ], PlotRange->{{-3,3},{-3,3}}, 
                DisplayFunction->$DisplayFunction, 
                PlotLabel->\"Slope field and solution curves\"]\
\>", "Input",\

  CellLabel->"In[145]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(t\/y[t]\)}]], "Output",
  CellLabel->"Out[145]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.5 0.166667 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.0125 -95 0 ]
[.5 1.0125 95 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-3)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-2)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-1)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(1)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(2)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(3)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-2)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-1)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(1)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(2)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(3)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.0125 -156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Slope) show
99.000 13.000 moveto
(field) show
135.000 13.000 moveto
(and) show
159.000 13.000 moveto
(solution) show
213.000 13.000 moveto
(curves) show
249.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
0 0 m
.05051 .05051 L
s
% Start of user PostScript
-3. -3. -2.69695 -2.69695 MAarrowhead1
% End of user PostScript
0 .07143 m
.04649 .12566 L
s
% Start of user PostScript
-3. -2.57143 -2.72109 -2.24603 MAarrowhead1
% End of user PostScript
0 .14286 m
.04152 .20098 L
s
% Start of user PostScript
-3. -2.14286 -2.7509 -1.79411 MAarrowhead1
% End of user PostScript
0 .21429 m
.03544 .2763 L
s
% Start of user PostScript
-3. -1.71429 -2.78737 -1.34218 MAarrowhead1
% End of user PostScript
0 .28571 m
.02814 .35137 L
s
% Start of user PostScript
-3. -1.28571 -2.83118 -0.891795 MAarrowhead1
% End of user PostScript
0 .35714 m
.01962 .42582 L
s
% Start of user PostScript
-3. -0.857143 -2.88226 -0.445061 MAarrowhead1
% End of user PostScript
0 .42857 m
.0101 .49928 L
s
% Start of user PostScript
-3. -0.428571 -2.93939 -0.00430736 MAarrowhead1
% End of user PostScript
0 .57143 m
.0101 .50072 L
s
% Start of user PostScript
-3. 0.428571 -2.93939 0.00430736 MAarrowhead1
% End of user PostScript
0 .64286 m
.01962 .57418 L
s
% Start of user PostScript
-3. 0.857143 -2.88226 0.445061 MAarrowhead1
% End of user PostScript
0 .71429 m
.02814 .64863 L
s
% Start of user PostScript
-3. 1.28571 -2.83118 0.891795 MAarrowhead1
% End of user PostScript
0 .78571 m
.03544 .7237 L
s
% Start of user PostScript
-3. 1.71429 -2.78737 1.34218 MAarrowhead1
% End of user PostScript
0 .85714 m
.04152 .79902 L
s
% Start of user PostScript
-3. 2.14286 -2.7509 1.79411 MAarrowhead1
% End of user PostScript
0 .92857 m
.04649 .87434 L
s
% Start of user PostScript
-3. 2.57143 -2.72109 2.24603 MAarrowhead1
% End of user PostScript
0 1 m
.05051 .94949 L
s
% Start of user PostScript
-3. 3. -2.69695 2.69695 MAarrowhead1
% End of user PostScript
.07143 0 m
.12566 .04649 L
s
% Start of user PostScript
-2.57143 -3. -2.24603 -2.72109 MAarrowhead1
% End of user PostScript
.07143 .07143 m
.12194 .12194 L
s
% Start of user PostScript
-2.57143 -2.57143 -2.26838 -2.26838 MAarrowhead1
% End of user PostScript
.07143 .14286 m
.11716 .19773 L
s
% Start of user PostScript
-2.57143 -2.14286 -2.29706 -1.81362 MAarrowhead1
% End of user PostScript
.07143 .21429 m
.11105 .27372 L
s
% Start of user PostScript
-2.57143 -1.71429 -2.3337 -1.35769 MAarrowhead1
% End of user PostScript
.07143 .28571 m
.10337 .3496 L
s
% Start of user PostScript
-2.57143 -1.28571 -2.37977 -0.902388 MAarrowhead1
% End of user PostScript
.07143 .35714 m
.09402 .42491 L
s
% Start of user PostScript
-2.57143 -0.857143 -2.4359 -0.450564 MAarrowhead1
% End of user PostScript
.07143 .42857 m
.08317 .49903 L
s
% Start of user PostScript
-2.57143 -0.428571 -2.50097 -0.00583118 MAarrowhead1
% End of user PostScript
.07143 .57143 m
.08317 .50097 L
s
% Start of user PostScript
-2.57143 0.428571 -2.50097 0.00583118 MAarrowhead1
% End of user PostScript
.07143 .64286 m
.09402 .57509 L
s
% Start of user PostScript
-2.57143 0.857143 -2.4359 0.450564 MAarrowhead1
% End of user PostScript
.07143 .71429 m
.10337 .6504 L
s
% Start of user PostScript
-2.57143 1.28571 -2.37977 0.902388 MAarrowhead1
% End of user PostScript
.07143 .78571 m
.11105 .72628 L
s
% Start of user PostScript
-2.57143 1.71429 -2.3337 1.35769 MAarrowhead1
% End of user PostScript
.07143 .85714 m
.11716 .80227 L
s
% Start of user PostScript
-2.57143 2.14286 -2.29706 1.81362 MAarrowhead1
% End of user PostScript
.07143 .92857 m
.12194 .87806 L
s
% Start of user PostScript
-2.57143 2.57143 -2.26838 2.26838 MAarrowhead1
% End of user PostScript
.07143 1 m
.12566 .95351 L
s
% Start of user PostScript
-2.57143 3. -2.24603 2.72109 MAarrowhead1
% End of user PostScript
.14286 0 m
.20098 .04152 L
s
% Start of user PostScript
-2.14286 -3. -1.79411 -2.7509 MAarrowhead1
% End of user PostScript
.14286 .07143 m
.19773 .11716 L
s
% Start of user PostScript
-2.14286 -2.57143 -1.81362 -2.29706 MAarrowhead1
% End of user PostScript
.14286 .14286 m
.19336 .19336 L
s
% Start of user PostScript
-2.14286 -2.14286 -1.83981 -1.83981 MAarrowhead1
% End of user PostScript
.14286 .21429 m
.18748 .27006 L
s
% Start of user PostScript
-2.14286 -1.71429 -1.87513 -1.37963 MAarrowhead1
% End of user PostScript
.14286 .28571 m
.17961 .34696 L
s
% Start of user PostScript
-2.14286 -1.28571 -1.92236 -0.918217 MAarrowhead1
% End of user PostScript
.14286 .35714 m
.16939 .42346 L
s
% Start of user PostScript
-2.14286 -0.857143 -1.98369 -0.459224 MAarrowhead1
% End of user PostScript
.14286 .42857 m
.15687 .49861 L
s
% Start of user PostScript
-2.14286 -0.428571 -2.05881 -0.00832257 MAarrowhead1
% End of user PostScript
.14286 .57143 m
.15687 .50139 L
s
% Start of user PostScript
-2.14286 0.428571 -2.05881 0.00832257 MAarrowhead1
% End of user PostScript
.14286 .64286 m
.16939 .57654 L
s
% Start of user PostScript
-2.14286 0.857143 -1.98369 0.459224 MAarrowhead1
% End of user PostScript
.14286 .71429 m
.17961 .65304 L
s
% Start of user PostScript
-2.14286 1.28571 -1.92236 0.918217 MAarrowhead1
% End of user PostScript
.14286 .78571 m
.18748 .72994 L
s
% Start of user PostScript
-2.14286 1.71429 -1.87513 1.37963 MAarrowhead1
% End of user PostScript
.14286 .85714 m
.19336 .80664 L
s
% Start of user PostScript
-2.14286 2.14286 -1.83981 1.83981 MAarrowhead1
% End of user PostScript
.14286 .92857 m
.19773 .88284 L
s
% Start of user PostScript
-2.14286 2.57143 -1.81362 2.29706 MAarrowhead1
% End of user PostScript
.14286 1 m
.20098 .95848 L
s
% Start of user PostScript
-2.14286 3. -1.79411 2.7509 MAarrowhead1
% End of user PostScript
.21429 0 m
.2763 .03544 L
s
% Start of user PostScript
-1.71429 -3. -1.34218 -2.78737 MAarrowhead1
% End of user PostScript
.21429 .07143 m
.27372 .11105 L
s
% Start of user PostScript
-1.71429 -2.57143 -1.35769 -2.3337 MAarrowhead1
% End of user PostScript
.21429 .14286 m
.27006 .18748 L
s
% Start of user PostScript
-1.71429 -2.14286 -1.37963 -1.87513 MAarrowhead1
% End of user PostScript
.21429 .21429 m
.26479 .26479 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.41124 -1.41124 MAarrowhead1
% End of user PostScript
.21429 .28571 m
.25714 .34286 L
s
% Start of user PostScript
-1.71429 -1.28571 -1.45714 -0.942857 MAarrowhead1
% End of user PostScript
.21429 .35714 m
.24623 .42103 L
s
% Start of user PostScript
-1.71429 -0.857143 -1.52262 -0.473817 MAarrowhead1
% End of user PostScript
.21429 .42857 m
.23161 .49787 L
s
% Start of user PostScript
-1.71429 -0.428571 -1.61034 -0.0127961 MAarrowhead1
% End of user PostScript
.21429 .57143 m
.23161 .50213 L
s
% Start of user PostScript
-1.71429 0.428571 -1.61034 0.0127961 MAarrowhead1
% End of user PostScript
.21429 .64286 m
.24623 .57897 L
s
% Start of user PostScript
-1.71429 0.857143 -1.52262 0.473817 MAarrowhead1
% End of user PostScript
.21429 .71429 m
.25714 .65714 L
s
% Start of user PostScript
-1.71429 1.28571 -1.45714 0.942857 MAarrowhead1
% End of user PostScript
.21429 .78571 m
.26479 .73521 L
s
% Start of user PostScript
-1.71429 1.71429 -1.41124 1.41124 MAarrowhead1
% End of user PostScript
.21429 .85714 m
.27006 .81252 L
s
% Start of user PostScript
-1.71429 2.14286 -1.37963 1.87513 MAarrowhead1
% End of user PostScript
.21429 .92857 m
.27372 .88895 L
s
% Start of user PostScript
-1.71429 2.57143 -1.35769 2.3337 MAarrowhead1
% End of user PostScript
.21429 1 m
.2763 .96456 L
s
% Start of user PostScript
-1.71429 3. -1.34218 2.78737 MAarrowhead1
% End of user PostScript
.28571 0 m
.35137 .02814 L
s
% Start of user PostScript
-1.28571 -3. -0.891795 -2.83118 MAarrowhead1
% End of user PostScript
.28571 .07143 m
.3496 .10337 L
s
% Start of user PostScript
-1.28571 -2.57143 -0.902388 -2.37977 MAarrowhead1
% End of user PostScript
.28571 .14286 m
.34696 .17961 L
s
% Start of user PostScript
-1.28571 -2.14286 -0.918217 -1.92236 MAarrowhead1
% End of user PostScript
.28571 .21429 m
.34286 .25714 L
s
% Start of user PostScript
-1.28571 -1.71429 -0.942857 -1.45714 MAarrowhead1
% End of user PostScript
.28571 .28571 m
.33622 .33622 L
s
% Start of user PostScript
-1.28571 -1.28571 -0.982669 -0.982669 MAarrowhead1
% End of user PostScript
.28571 .35714 m
.32534 .41658 L
s
% Start of user PostScript
-1.28571 -0.857143 -1.04799 -0.50055 MAarrowhead1
% End of user PostScript
.28571 .42857 m
.3083 .49633 L
s
% Start of user PostScript
-1.28571 -0.428571 -1.15019 -0.0219929 MAarrowhead1
% End of user PostScript
.28571 .57143 m
.3083 .50367 L
s
% Start of user PostScript
-1.28571 0.428571 -1.15019 0.0219929 MAarrowhead1
% End of user PostScript
.28571 .64286 m
.32534 .58342 L
s
% Start of user PostScript
-1.28571 0.857143 -1.04799 0.50055 MAarrowhead1
% End of user PostScript
.28571 .71429 m
.33622 .66378 L
s
% Start of user PostScript
-1.28571 1.28571 -0.982669 0.982669 MAarrowhead1
% End of user PostScript
.28571 .78571 m
.34286 .74286 L
s
% Start of user PostScript
-1.28571 1.71429 -0.942857 1.45714 MAarrowhead1
% End of user PostScript
.28571 .85714 m
.34696 .82039 L
s
% Start of user PostScript
-1.28571 2.14286 -0.918217 1.92236 MAarrowhead1
% End of user PostScript
.28571 .92857 m
.3496 .89663 L
s
% Start of user PostScript
-1.28571 2.57143 -0.902388 2.37977 MAarrowhead1
% End of user PostScript
.28571 1 m
.35137 .97186 L
s
% Start of user PostScript
-1.28571 3. -0.891795 2.83118 MAarrowhead1
% End of user PostScript
.35714 0 m
.42582 .01962 L
s
% Start of user PostScript
-0.857143 -3. -0.445061 -2.88226 MAarrowhead1
% End of user PostScript
.35714 .07143 m
.42491 .09402 L
s
% Start of user PostScript
-0.857143 -2.57143 -0.450564 -2.4359 MAarrowhead1
% End of user PostScript
.35714 .14286 m
.42346 .16939 L
s
% Start of user PostScript
-0.857143 -2.14286 -0.459224 -1.98369 MAarrowhead1
% End of user PostScript
.35714 .21429 m
.42103 .24623 L
s
% Start of user PostScript
-0.857143 -1.71429 -0.473817 -1.52262 MAarrowhead1
% End of user PostScript
.35714 .28571 m
.41658 .32534 L
s
% Start of user PostScript
-0.857143 -1.28571 -0.50055 -1.04799 MAarrowhead1
% End of user PostScript
.35714 .35714 m
.40765 .40765 L
s
% Start of user PostScript
-0.857143 -0.857143 -0.554097 -0.554097 MAarrowhead1
% End of user PostScript
.35714 .42857 m
.38909 .49246 L
s
% Start of user PostScript
-0.857143 -0.428571 -0.66548 -0.0452455 MAarrowhead1
% End of user PostScript
.35714 .57143 m
.38909 .50754 L
s
% Start of user PostScript
-0.857143 0.428571 -0.66548 0.0452455 MAarrowhead1
% End of user PostScript
.35714 .64286 m
.40765 .59235 L
s
% Start of user PostScript
-0.857143 0.857143 -0.554097 0.554097 MAarrowhead1
% End of user PostScript
.35714 .71429 m
.41658 .67466 L
s
% Start of user PostScript
-0.857143 1.28571 -0.50055 1.04799 MAarrowhead1
% End of user PostScript
.35714 .78571 m
.42103 .75377 L
s
% Start of user PostScript
-0.857143 1.71429 -0.473817 1.52262 MAarrowhead1
% End of user PostScript
.35714 .85714 m
.42346 .83061 L
s
% Start of user PostScript
-0.857143 2.14286 -0.459224 1.98369 MAarrowhead1
% End of user PostScript
.35714 .92857 m
.42491 .90598 L
s
% Start of user PostScript
-0.857143 2.57143 -0.450564 2.4359 MAarrowhead1
% End of user PostScript
.35714 1 m
.42582 .98038 L
s
% Start of user PostScript
-0.857143 3. -0.445061 2.88226 MAarrowhead1
% End of user PostScript
.42857 0 m
.49928 .0101 L
s
% Start of user PostScript
-0.428571 -3. -0.00430736 -2.93939 MAarrowhead1
% End of user PostScript
.42857 .07143 m
.49903 .08317 L
s
% Start of user PostScript
-0.428571 -2.57143 -0.00583118 -2.50097 MAarrowhead1
% End of user PostScript
.42857 .14286 m
.49861 .15687 L
s
% Start of user PostScript
-0.428571 -2.14286 -0.00832257 -2.05881 MAarrowhead1
% End of user PostScript
.42857 .21429 m
.49787 .23161 L
s
% Start of user PostScript
-0.428571 -1.71429 -0.0127961 -1.61034 MAarrowhead1
% End of user PostScript
.42857 .28571 m
.49633 .3083 L
s
% Start of user PostScript
-0.428571 -1.28571 -0.0219929 -1.15019 MAarrowhead1
% End of user PostScript
.42857 .35714 m
.49246 .38909 L
s
% Start of user PostScript
-0.428571 -0.857143 -0.0452455 -0.66548 MAarrowhead1
% End of user PostScript
.42857 .42857 m
.47908 .47908 L
s
% Start of user PostScript
-0.428571 -0.428571 -0.125526 -0.125526 MAarrowhead1
% End of user PostScript
.42857 .57143 m
.47908 .52092 L
s
% Start of user PostScript
-0.428571 0.428571 -0.125526 0.125526 MAarrowhead1
% End of user PostScript
.42857 .64286 m
.49246 .61091 L
s
% Start of user PostScript
-0.428571 0.857143 -0.0452455 0.66548 MAarrowhead1
% End of user PostScript
.42857 .71429 m
.49633 .6917 L
s
% Start of user PostScript
-0.428571 1.28571 -0.0219929 1.15019 MAarrowhead1
% End of user PostScript
.42857 .78571 m
.49787 .76839 L
s
% Start of user PostScript
-0.428571 1.71429 -0.0127961 1.61034 MAarrowhead1
% End of user PostScript
.42857 .85714 m
.49861 .84313 L
s
% Start of user PostScript
-0.428571 2.14286 -0.00832257 2.05881 MAarrowhead1
% End of user PostScript
.42857 .92857 m
.49903 .91683 L
s
% Start of user PostScript
-0.428571 2.57143 -0.00583118 2.50097 MAarrowhead1
% End of user PostScript
.42857 1 m
.49928 .9899 L
s
% Start of user PostScript
-0.428571 3. -0.00430736 2.93939 MAarrowhead1
% End of user PostScript
.5 0 m
.57143 0 L
s
% Start of user PostScript
0 -3. 0.428571 -3. MAarrowhead1
% End of user PostScript
.5 .07143 m
.57143 .07143 L
s
% Start of user PostScript
0 -2.57143 0.428571 -2.57143 MAarrowhead1
% End of user PostScript
.5 .14286 m
.57143 .14286 L
s
% Start of user PostScript
0 -2.14286 0.428571 -2.14286 MAarrowhead1
% End of user PostScript
.5 .21429 m
.57143 .21429 L
s
% Start of user PostScript
0 -1.71429 0.428571 -1.71429 MAarrowhead1
% End of user PostScript
.5 .28571 m
.57143 .28571 L
s
% Start of user PostScript
0 -1.28571 0.428571 -1.28571 MAarrowhead1
% End of user PostScript
.5 .35714 m
.57143 .35714 L
s
% Start of user PostScript
0 -0.857143 0.428571 -0.857143 MAarrowhead1
% End of user PostScript
.5 .42857 m
.57143 .42857 L
s
% Start of user PostScript
0 -0.428571 0.428571 -0.428571 MAarrowhead1
% End of user PostScript
.5 .57143 m
.57143 .57143 L
s
% Start of user PostScript
0 0.428571 0.428571 0.428571 MAarrowhead1
% End of user PostScript
.5 .64286 m
.57143 .64286 L
s
% Start of user PostScript
0 0.857143 0.428571 0.857143 MAarrowhead1
% End of user PostScript
.5 .71429 m
.57143 .71429 L
s
% Start of user PostScript
0 1.28571 0.428571 1.28571 MAarrowhead1
% End of user PostScript
.5 .78571 m
.57143 .78571 L
s
% Start of user PostScript
0 1.71429 0.428571 1.71429 MAarrowhead1
% End of user PostScript
.5 .85714 m
.57143 .85714 L
s
% Start of user PostScript
0 2.14286 0.428571 2.14286 MAarrowhead1
% End of user PostScript
.5 .92857 m
.57143 .92857 L
s
% Start of user PostScript
0 2.57143 0.428571 2.57143 MAarrowhead1
% End of user PostScript
.5 1 m
.57143 1 L
s
% Start of user PostScript
0 3. 0.428571 3. MAarrowhead1
% End of user PostScript
.57143 0 m
0 0 rlineto s
% Start of user PostScript
0.428571 -3. 0.852835 -3.06061 MAarrowhead1
% End of user PostScript
.57143 .07143 m
.64189 .05969 L
s
% Start of user PostScript
0.428571 -2.57143 0.851312 -2.64189 MAarrowhead1
% End of user PostScript
.57143 .14286 m
.64147 .12885 L
s
% Start of user PostScript
0.428571 -2.14286 0.84882 -2.22691 MAarrowhead1
% End of user PostScript
.57143 .21429 m
.64072 .19696 L
s
% Start of user PostScript
0.428571 -1.71429 0.844347 -1.81823 MAarrowhead1
% End of user PostScript
.57143 .28571 m
.63919 .26313 L
s
% Start of user PostScript
0.428571 -1.28571 0.83515 -1.42124 MAarrowhead1
% End of user PostScript
.57143 .35714 m
.63532 .3252 L
s
% Start of user PostScript
0.428571 -0.857143 0.811897 -1.04881 MAarrowhead1
% End of user PostScript
.57143 .42857 m
.62194 .37806 L
s
% Start of user PostScript
0.428571 -0.428571 0.731617 -0.731617 MAarrowhead1
% End of user PostScript
.57143 .57143 m
.62194 .62194 L
s
% Start of user PostScript
0.428571 0.428571 0.731617 0.731617 MAarrowhead1
% End of user PostScript
.57143 .64286 m
.63532 .6748 L
s
% Start of user PostScript
0.428571 0.857143 0.811897 1.04881 MAarrowhead1
% End of user PostScript
.57143 .71429 m
.63919 .73687 L
s
% Start of user PostScript
0.428571 1.28571 0.83515 1.42124 MAarrowhead1
% End of user PostScript
.57143 .78571 m
.64072 .80304 L
s
% Start of user PostScript
0.428571 1.71429 0.844347 1.81823 MAarrowhead1
% End of user PostScript
.57143 .85714 m
.64147 .87115 L
s
% Start of user PostScript
0.428571 2.14286 0.84882 2.22691 MAarrowhead1
% End of user PostScript
.57143 .92857 m
.64189 .94031 L
s
% Start of user PostScript
0.428571 2.57143 0.851312 2.64189 MAarrowhead1
% End of user PostScript
.57143 1 m
0 0 rlineto s
.57143 1 m
.57143 1 L
s
% Start of user PostScript
0.428571 3. 0.852835 3.06061 MAarrowhead1
% End of user PostScript
.64286 0 m
0 0 rlineto s
% Start of user PostScript
0.857143 -3. 1.26922 -3.11774 MAarrowhead1
% End of user PostScript
.64286 .07143 m
.71062 .04884 L
s
% Start of user PostScript
0.857143 -2.57143 1.26372 -2.70695 MAarrowhead1
% End of user PostScript
.64286 .14286 m
.70918 .11633 L
s
% Start of user PostScript
0.857143 -2.14286 1.25506 -2.30202 MAarrowhead1
% End of user PostScript
.64286 .21429 m
.70674 .18234 L
s
% Start of user PostScript
0.857143 -1.71429 1.24047 -1.90595 MAarrowhead1
% End of user PostScript
.64286 .28571 m
.70229 .24609 L
s
% Start of user PostScript
0.857143 -1.28571 1.21374 -1.52344 MAarrowhead1
% End of user PostScript
.64286 .35714 m
.69336 .30664 L
s
% Start of user PostScript
0.857143 -0.857143 1.16019 -1.16019 MAarrowhead1
% End of user PostScript
.64286 .42857 m
.6748 .36468 L
s
% Start of user PostScript
0.857143 -0.428571 1.04881 -0.811897 MAarrowhead1
% End of user PostScript
.64286 .57143 m
.6748 .63532 L
s
% Start of user PostScript
0.857143 0.428571 1.04881 0.811897 MAarrowhead1
% End of user PostScript
.64286 .64286 m
.69336 .69336 L
s
% Start of user PostScript
0.857143 0.857143 1.16019 1.16019 MAarrowhead1
% End of user PostScript
.64286 .71429 m
.70229 .75391 L
s
% Start of user PostScript
0.857143 1.28571 1.21374 1.52344 MAarrowhead1
% End of user PostScript
.64286 .78571 m
.70674 .81766 L
s
% Start of user PostScript
0.857143 1.71429 1.24047 1.90595 MAarrowhead1
% End of user PostScript
.64286 .85714 m
.70918 .88367 L
s
% Start of user PostScript
0.857143 2.14286 1.25506 2.30202 MAarrowhead1
% End of user PostScript
.64286 .92857 m
.71062 .95116 L
s
% Start of user PostScript
0.857143 2.57143 1.26372 2.70695 MAarrowhead1
% End of user PostScript
.64286 1 m
0 0 rlineto s
.64286 1 m
.64286 1 L
s
% Start of user PostScript
0.857143 3. 1.26922 3.11774 MAarrowhead1
% End of user PostScript
.71429 0 m
0 0 rlineto s
% Start of user PostScript
1.28571 -3. 1.67963 -3.16882 MAarrowhead1
% End of user PostScript
.71429 .07143 m
.77817 .03948 L
s
% Start of user PostScript
1.28571 -2.57143 1.66904 -2.76309 MAarrowhead1
% End of user PostScript
.71429 .14286 m
.77554 .10611 L
s
% Start of user PostScript
1.28571 -2.14286 1.65321 -2.36336 MAarrowhead1
% End of user PostScript
.71429 .21429 m
.77143 .17143 L
s
% Start of user PostScript
1.28571 -1.71429 1.62857 -1.97143 MAarrowhead1
% End of user PostScript
.71429 .28571 m
.76479 .23521 L
s
% Start of user PostScript
1.28571 -1.28571 1.58876 -1.58876 MAarrowhead1
% End of user PostScript
.71429 .35714 m
.75391 .29771 L
s
% Start of user PostScript
1.28571 -0.857143 1.52344 -1.21374 MAarrowhead1
% End of user PostScript
.71429 .42857 m
.73687 .36081 L
s
% Start of user PostScript
1.28571 -0.428571 1.42124 -0.83515 MAarrowhead1
% End of user PostScript
.71429 .57143 m
.73687 .63919 L
s
% Start of user PostScript
1.28571 0.428571 1.42124 0.83515 MAarrowhead1
% End of user PostScript
.71429 .64286 m
.75391 .70229 L
s
% Start of user PostScript
1.28571 0.857143 1.52344 1.21374 MAarrowhead1
% End of user PostScript
.71429 .71429 m
.76479 .76479 L
s
% Start of user PostScript
1.28571 1.28571 1.58876 1.58876 MAarrowhead1
% End of user PostScript
.71429 .78571 m
.77143 .82857 L
s
% Start of user PostScript
1.28571 1.71429 1.62857 1.97143 MAarrowhead1
% End of user PostScript
.71429 .85714 m
.77554 .89389 L
s
% Start of user PostScript
1.28571 2.14286 1.65321 2.36336 MAarrowhead1
% End of user PostScript
.71429 .92857 m
.77817 .96052 L
s
% Start of user PostScript
1.28571 2.57143 1.66904 2.76309 MAarrowhead1
% End of user PostScript
.71429 1 m
0 0 rlineto s
.71429 1 m
.71429 1 L
s
% Start of user PostScript
1.28571 3. 1.67963 3.16882 MAarrowhead1
% End of user PostScript
.78571 0 m
0 0 rlineto s
% Start of user PostScript
1.71429 -3. 2.08639 -3.21263 MAarrowhead1
% End of user PostScript
.78571 .07143 m
.84515 .03181 L
s
% Start of user PostScript
1.71429 -2.57143 2.07088 -2.80916 MAarrowhead1
% End of user PostScript
.78571 .14286 m
.84149 .09824 L
s
% Start of user PostScript
1.71429 -2.14286 2.04894 -2.41058 MAarrowhead1
% End of user PostScript
.78571 .21429 m
.83622 .16378 L
s
% Start of user PostScript
1.71429 -1.71429 2.01733 -2.01733 MAarrowhead1
% End of user PostScript
.78571 .28571 m
.82857 .22857 L
s
% Start of user PostScript
1.71429 -1.28571 1.97143 -1.62857 MAarrowhead1
% End of user PostScript
.78571 .35714 m
.81766 .29326 L
s
% Start of user PostScript
1.71429 -0.857143 1.90595 -1.24047 MAarrowhead1
% End of user PostScript
.78571 .42857 m
.80304 .35928 L
s
% Start of user PostScript
1.71429 -0.428571 1.81823 -0.844347 MAarrowhead1
% End of user PostScript
.78571 .57143 m
.80304 .64072 L
s
% Start of user PostScript
1.71429 0.428571 1.81823 0.844347 MAarrowhead1
% End of user PostScript
.78571 .64286 m
.81766 .70674 L
s
% Start of user PostScript
1.71429 0.857143 1.90595 1.24047 MAarrowhead1
% End of user PostScript
.78571 .71429 m
.82857 .77143 L
s
% Start of user PostScript
1.71429 1.28571 1.97143 1.62857 MAarrowhead1
% End of user PostScript
.78571 .78571 m
.83622 .83622 L
s
% Start of user PostScript
1.71429 1.71429 2.01733 2.01733 MAarrowhead1
% End of user PostScript
.78571 .85714 m
.84149 .90176 L
s
% Start of user PostScript
1.71429 2.14286 2.04894 2.41058 MAarrowhead1
% End of user PostScript
.78571 .92857 m
.84515 .96819 L
s
% Start of user PostScript
1.71429 2.57143 2.07088 2.80916 MAarrowhead1
% End of user PostScript
.78571 1 m
0 0 rlineto s
.78571 1 m
.78571 1 L
s
% Start of user PostScript
1.71429 3. 2.08639 3.21263 MAarrowhead1
% End of user PostScript
.85714 0 m
0 0 rlineto s
% Start of user PostScript
2.14286 -3. 2.4916 -3.2491 MAarrowhead1
% End of user PostScript
.85714 .07143 m
.91202 .0257 L
s
% Start of user PostScript
2.14286 -2.57143 2.47209 -2.84579 MAarrowhead1
% End of user PostScript
.85714 .14286 m
.90765 .09235 L
s
% Start of user PostScript
2.14286 -2.14286 2.4459 -2.4459 MAarrowhead1
% End of user PostScript
.85714 .21429 m
.90176 .15851 L
s
% Start of user PostScript
2.14286 -1.71429 2.41058 -2.04894 MAarrowhead1
% End of user PostScript
.85714 .28571 m
.89389 .22446 L
s
% Start of user PostScript
2.14286 -1.28571 2.36336 -1.65321 MAarrowhead1
% End of user PostScript
.85714 .35714 m
.88367 .29082 L
s
% Start of user PostScript
2.14286 -0.857143 2.30202 -1.25506 MAarrowhead1
% End of user PostScript
.85714 .42857 m
.87115 .35853 L
s
% Start of user PostScript
2.14286 -0.428571 2.22691 -0.84882 MAarrowhead1
% End of user PostScript
.85714 .57143 m
.87115 .64147 L
s
% Start of user PostScript
2.14286 0.428571 2.22691 0.84882 MAarrowhead1
% End of user PostScript
.85714 .64286 m
.88367 .70918 L
s
% Start of user PostScript
2.14286 0.857143 2.30202 1.25506 MAarrowhead1
% End of user PostScript
.85714 .71429 m
.89389 .77554 L
s
% Start of user PostScript
2.14286 1.28571 2.36336 1.65321 MAarrowhead1
% End of user PostScript
.85714 .78571 m
.90176 .84149 L
s
% Start of user PostScript
2.14286 1.71429 2.41058 2.04894 MAarrowhead1
% End of user PostScript
.85714 .85714 m
.90765 .90765 L
s
% Start of user PostScript
2.14286 2.14286 2.4459 2.4459 MAarrowhead1
% End of user PostScript
.85714 .92857 m
.91202 .9743 L
s
% Start of user PostScript
2.14286 2.57143 2.47209 2.84579 MAarrowhead1
% End of user PostScript
.85714 1 m
0 0 rlineto s
.85714 1 m
.85714 1 L
s
% Start of user PostScript
2.14286 3. 2.4916 3.2491 MAarrowhead1
% End of user PostScript
.92857 0 m
0 0 rlineto s
% Start of user PostScript
2.57143 -3. 2.89682 -3.27891 MAarrowhead1
% End of user PostScript
.92857 .07143 m
.97908 .02092 L
s
% Start of user PostScript
2.57143 -2.57143 2.87447 -2.87447 MAarrowhead1
% End of user PostScript
.92857 .14286 m
.9743 .08798 L
s
% Start of user PostScript
2.57143 -2.14286 2.84579 -2.47209 MAarrowhead1
% End of user PostScript
.92857 .21429 m
.96819 .15485 L
s
% Start of user PostScript
2.57143 -1.71429 2.80916 -2.07088 MAarrowhead1
% End of user PostScript
.92857 .28571 m
.96052 .22183 L
s
% Start of user PostScript
2.57143 -1.28571 2.76309 -1.66904 MAarrowhead1
% End of user PostScript
.92857 .35714 m
.95116 .28938 L
s
% Start of user PostScript
2.57143 -0.857143 2.70695 -1.26372 MAarrowhead1
% End of user PostScript
.92857 .42857 m
.94031 .35811 L
s
% Start of user PostScript
2.57143 -0.428571 2.64189 -0.851312 MAarrowhead1
% End of user PostScript
.92857 .57143 m
.94031 .64189 L
s
% Start of user PostScript
2.57143 0.428571 2.64189 0.851312 MAarrowhead1
% End of user PostScript
.92857 .64286 m
.95116 .71062 L
s
% Start of user PostScript
2.57143 0.857143 2.70695 1.26372 MAarrowhead1
% End of user PostScript
.92857 .71429 m
.96052 .77817 L
s
% Start of user PostScript
2.57143 1.28571 2.76309 1.66904 MAarrowhead1
% End of user PostScript
.92857 .78571 m
.96819 .84515 L
s
% Start of user PostScript
2.57143 1.71429 2.80916 2.07088 MAarrowhead1
% End of user PostScript
.92857 .85714 m
.9743 .91202 L
s
% Start of user PostScript
2.57143 2.14286 2.84579 2.47209 MAarrowhead1
% End of user PostScript
.92857 .92857 m
.97908 .97908 L
s
% Start of user PostScript
2.57143 2.57143 2.87447 2.87447 MAarrowhead1
% End of user PostScript
.92857 1 m
0 0 rlineto s
.92857 1 m
.92857 1 L
s
% Start of user PostScript
2.57143 3. 2.89682 3.27891 MAarrowhead1
% End of user PostScript
1 0 m
0 0 rlineto s
% Start of user PostScript
3. -3. 3.30305 -3.30305 MAarrowhead1
% End of user PostScript
1 .07143 m
0 0 rlineto s
1 .07143 m
1 .07143 L
s
% Start of user PostScript
3. -2.57143 3.27891 -2.89682 MAarrowhead1
% End of user PostScript
1 .14286 m
0 0 rlineto s
1 .14286 m
1 .14286 L
s
% Start of user PostScript
3. -2.14286 3.2491 -2.4916 MAarrowhead1
% End of user PostScript
1 .21429 m
0 0 rlineto s
1 .21429 m
1 .21429 L
s
% Start of user PostScript
3. -1.71429 3.21263 -2.08639 MAarrowhead1
% End of user PostScript
1 .28571 m
0 0 rlineto s
1 .28571 m
1 .28571 L
s
% Start of user PostScript
3. -1.28571 3.16882 -1.67963 MAarrowhead1
% End of user PostScript
1 .35714 m
0 0 rlineto s
1 .35714 m
1 .35714 L
s
% Start of user PostScript
3. -0.857143 3.11774 -1.26922 MAarrowhead1
% End of user PostScript
1 .42857 m
0 0 rlineto s
1 .42857 m
1 .42857 L
s
% Start of user PostScript
3. -0.428571 3.06061 -0.852835 MAarrowhead1
% End of user PostScript
1 .57143 m
0 0 rlineto s
1 .57143 m
1 .57143 L
s
% Start of user PostScript
3. 0.428571 3.06061 0.852835 MAarrowhead1
% End of user PostScript
1 .64286 m
0 0 rlineto s
1 .64286 m
1 .64286 L
s
% Start of user PostScript
3. 0.857143 3.11774 1.26922 MAarrowhead1
% End of user PostScript
1 .71429 m
0 0 rlineto s
1 .71429 m
1 .71429 L
s
% Start of user PostScript
3. 1.28571 3.16882 1.67963 MAarrowhead1
% End of user PostScript
1 .78571 m
0 0 rlineto s
1 .78571 m
1 .78571 L
s
% Start of user PostScript
3. 1.71429 3.21263 2.08639 MAarrowhead1
% End of user PostScript
1 .85714 m
0 0 rlineto s
1 .85714 m
1 .85714 L
s
% Start of user PostScript
3. 2.14286 3.2491 2.4916 MAarrowhead1
% End of user PostScript
1 .92857 m
0 0 rlineto s
1 .92857 m
1 .92857 L
s
% Start of user PostScript
3. 2.57143 3.27891 2.89682 MAarrowhead1
% End of user PostScript
1 1 m
0 0 rlineto s
1 1 m
1 1 L
s
% Start of user PostScript
3. 3. 3.30305 3.30305 MAarrowhead1
% End of user PostScript
.01 w
0 .87268 m
.04057 .81618 L
.08481 .74754 L
.10632 .70947 L
.12636 .66882 L
.14567 .62018 L
.15122 .60264 L
.15648 .58305 L
.1612 .56065 L
.16249 .55296 L
.16386 .54338 L
.16503 .53312 L
.16632 .51533 L
s
.83409 .52247 m
.83546 .53772 L
.83675 .54788 L
.83793 .55555 L
.84353 .58309 L
.84934 .60455 L
.85482 .62162 L
.87502 .67184 L
.91564 .74829 L
.95603 .81121 L
.99899 .87133 L
1 .87268 L
s
0 .97141 m
.04057 .92814 L
.08481 .88027 L
.12636 .83441 L
.16632 .78908 L
.20885 .73873 L
.2498 .68662 L
.29331 .62225 L
.31342 .58389 L
.31882 .57108 L
.32476 .55415 L
.32721 .54561 L
.32985 .5343 L
.33059 .53039 L
.3313 .52615 L
.33263 .5154 L
s
.66681 .50704 m
.6671 .5122 L
.66839 .52409 L
.6696 .53144 L
.67208 .54284 L
.67479 .55269 L
.68025 .56868 L
.69002 .59129 L
.71204 .6311 L
.75463 .69252 L
.79563 .74418 L
.8392 .79544 L
.88118 .84282 L
.92157 .88723 L
.96454 .93361 L
1 .97141 L
s
0 1 m
.04057 .95944 L
.08481 .91519 L
.12636 .87364 L
.16632 .83369 L
.20885 .79115 L
.2498 .75021 L
.29331 .70669 L
.33524 .66477 L
.37557 .62444 L
.41848 .58153 L
.4598 .54023 L
.48055 .51952 L
.48962 .51051 L
.49442 .50583 L
.49705 .50339 L
.49834 .50235 L
.49953 .50173 L
.50089 .50189 L
.50161 .50232 L
.50237 .5029 L
.50495 .50522 L
.50998 .51012 L
.51991 .51998 L
.54183 .54186 L
.5817 .58172 L
.62415 .62416 L
.665 .66501 L
.70843 .70844 L
.75027 .75027 L
.79051 .79052 L
.83333 .83334 L
.87456 .87457 L
.9142 .91421 L
.95642 .95642 L
.99704 .99704 L
s
.99704 .99704 m
1 1 L
s
0 .97141 m
.04057 .92814 L
.08481 .88027 L
.12636 .83441 L
.16632 .78908 L
.20885 .73873 L
.2498 .68662 L
.29331 .62225 L
.31342 .58389 L
.31882 .57108 L
.32476 .55415 L
.32721 .54561 L
.32985 .5343 L
.33059 .53039 L
.3313 .52615 L
.33263 .5154 L
s
.66681 .50704 m
.6671 .5122 L
.66839 .52409 L
.6696 .53144 L
.67208 .54284 L
.67479 .55269 L
.68025 .56868 L
.69002 .59129 L
.71204 .6311 L
.75463 .69252 L
.79563 .74418 L
.8392 .79544 L
.88118 .84282 L
.92157 .88723 L
.96454 .93361 L
1 .97141 L
s
0 .87268 m
.04057 .81618 L
.08481 .74754 L
.10632 .70947 L
.12636 .66882 L
.14567 .62018 L
.15122 .60264 L
.15648 .58305 L
.1612 .56065 L
.16249 .55296 L
.16386 .54338 L
.16503 .53312 L
.16632 .51533 L
s
.83409 .52247 m
.83546 .53772 L
.83675 .54788 L
.83793 .55555 L
.84353 .58309 L
.84934 .60455 L
.85482 .62162 L
.87502 .67184 L
.91564 .74829 L
.95603 .81121 L
.99899 .87133 L
1 .87268 L
s
0 .12732 m
.04057 .18382 L
.08481 .25246 L
.10632 .29053 L
.12636 .33118 L
.14567 .37982 L
.15122 .39736 L
.15648 .41695 L
.1612 .43935 L
.16249 .44704 L
.16386 .45662 L
.16503 .46688 L
.16632 .48467 L
s
.83409 .47753 m
.83546 .46228 L
.83675 .45212 L
.83793 .44445 L
.84353 .41691 L
.84934 .39545 L
.85482 .37838 L
.87502 .32816 L
.91564 .25171 L
.95603 .18879 L
.99899 .12867 L
1 .12732 L
s
0 .02859 m
.04057 .07186 L
.08481 .11973 L
.12636 .16559 L
.16632 .21092 L
.20885 .26127 L
.2498 .31338 L
.29331 .37775 L
.31342 .41611 L
.31882 .42892 L
.32476 .44585 L
.32721 .45439 L
.32985 .4657 L
.33059 .46961 L
.3313 .47385 L
.33263 .4846 L
s
.66681 .49296 m
.6671 .4878 L
.66839 .47591 L
.6696 .46856 L
.67208 .45716 L
.67479 .44731 L
.68025 .43132 L
.69002 .40871 L
.71204 .3689 L
.75463 .30748 L
.79563 .25582 L
.8392 .20456 L
.88118 .15718 L
.92157 .11277 L
.96454 .06639 L
1 .02859 L
s
0 0 m
.04057 .04056 L
.08481 .08481 L
.12636 .12636 L
.16632 .16631 L
.20885 .20885 L
.2498 .24979 L
.29331 .29331 L
.33524 .33523 L
.37557 .37556 L
.41848 .41847 L
.4598 .45977 L
.48055 .48048 L
.48962 .48949 L
.49442 .49417 L
.49705 .49661 L
.49834 .49765 L
.49953 .49827 L
.50089 .49811 L
.50161 .49768 L
.50237 .4971 L
.50495 .49478 L
.50998 .48988 L
.51991 .48002 L
.54183 .45814 L
.5817 .41828 L
.62415 .37584 L
.665 .33499 L
.70843 .29156 L
.75027 .24973 L
.79051 .20948 L
.83333 .16666 L
.87456 .12543 L
.9142 .08579 L
.95642 .04358 L
.99704 .00296 L
s
.99704 .00296 m
1 0 L
s
0 .02859 m
.04057 .07186 L
.08481 .11973 L
.12636 .16559 L
.16632 .21092 L
.20885 .26127 L
.2498 .31338 L
.29331 .37775 L
.31342 .41611 L
.31882 .42892 L
.32476 .44585 L
.32721 .45439 L
.32985 .4657 L
.33059 .46961 L
.3313 .47385 L
.33263 .4846 L
s
.66681 .49296 m
.6671 .4878 L
.66839 .47591 L
.6696 .46856 L
.67208 .45716 L
.67479 .44731 L
.68025 .43132 L
.69002 .40871 L
.71204 .3689 L
.75463 .30748 L
.79563 .25582 L
.8392 .20456 L
.88118 .15718 L
.92157 .11277 L
.96454 .06639 L
1 .02859 L
s
0 .12732 m
.04057 .18382 L
.08481 .25246 L
.10632 .29053 L
.12636 .33118 L
.14567 .37982 L
.15122 .39736 L
.15648 .41695 L
.1612 .43935 L
.16249 .44704 L
.16386 .45662 L
.16503 .46688 L
.16632 .48467 L
s
.83409 .47753 m
.83546 .46228 L
.83675 .45212 L
.83793 .44445 L
.84353 .41691 L
.84934 .39545 L
.85482 .37838 L
.87502 .32816 L
.91564 .25171 L
.95603 .18879 L
.99899 .12867 L
1 .12732 L
s
.12888 0 m
.16632 .02717 L
.20885 .05616 L
.2498 .08188 L
.29331 .10637 L
.33524 .12668 L
.37557 .14264 L
.39599 .14923 L
.41848 .15522 L
.43982 .15964 L
.44937 .1612 L
.4598 .1626 L
.46545 .16322 L
.4707 .16372 L
.47614 .16415 L
.48106 .16447 L
.48591 .1647 L
.48813 .16479 L
.49048 .16486 L
.49299 .16493 L
.4941 .16495 L
.4953 .16497 L
.49658 .16498 L
.49778 .16499 L
.49852 .165 L
.49921 .165 L
.50051 .165 L
.50171 .165 L
.503 .16499 L
.50421 .16497 L
.50533 .16496 L
.50792 .16491 L
.51065 .16483 L
.51331 .16474 L
.51579 .16463 L
.52142 .16432 L
.53077 .16359 L
.54076 .16253 L
.55151 .16106 L
.56317 .1591 L
.58433 .15455 L
.6273 .14163 L
.66867 .12493 L
.70845 .10544 L
.75081 .08152 L
.79157 .05588 L
.83491 .0263 L
s
.83491 .0263 m
.87105 0 L
s
.02923 0 m
.04057 .0107 L
.08481 .05198 L
.12636 .09019 L
.16632 .12626 L
.20885 .16369 L
.2498 .19844 L
.29331 .23344 L
.33524 .26445 L
.37557 .29067 L
.39599 .30213 L
.41848 .31297 L
.43982 .32123 L
.4598 .32693 L
.46501 .32807 L
.4707 .32914 L
.47572 .32992 L
.48106 .3306 L
.48379 .33089 L
.48635 .33111 L
.48885 .3313 L
.49115 .33143 L
.49334 .33153 L
.49445 .33158 L
.49565 .33161 L
.49685 .33164 L
.49797 .33165 L
.4993 .33167 L
.50051 .33167 L
.50175 .33166 L
.50291 .33164 L
.50419 .33161 L
.50556 .33157 L
.50692 .33152 L
.50836 .33146 L
.51092 .33131 L
.51552 .33095 L
.52055 .33042 L
.52601 .32967 L
.53184 .32868 L
.54235 .32642 L
.56476 .31964 L
.58592 .31101 L
.62631 .28955 L
.66928 .26127 L
.71065 .23035 L
.75043 .19825 L
.79279 .16227 L
.83355 .12638 L
.87689 .08722 L
Mistroke
.91864 .04878 L
.9588 .01129 L
Mfstroke
.9588 .01129 m
.97077 0 L
s
0 0 m
.04057 .04056 L
.08481 .08481 L
.12636 .12636 L
.16632 .16631 L
.20885 .20885 L
.2498 .24979 L
.29331 .29331 L
.33524 .33523 L
.37557 .37556 L
.41848 .41847 L
.4598 .45977 L
.48055 .48048 L
.48962 .48949 L
.49442 .49417 L
.49705 .49661 L
.49834 .49765 L
.49953 .49827 L
.50089 .49811 L
.50161 .49768 L
.50237 .4971 L
.50495 .49478 L
.50998 .48988 L
.51991 .48002 L
.54183 .45814 L
.5817 .41828 L
.62415 .37584 L
.665 .33499 L
.70843 .29156 L
.75027 .24973 L
.79051 .20948 L
.83333 .16666 L
.87456 .12543 L
.9142 .08579 L
.95642 .04358 L
.99704 .00296 L
s
.99704 .00296 m
1 0 L
s
.02805 1 m
.04057 .98816 L
.08481 .94678 L
.12636 .90845 L
.16632 .87225 L
.20885 .83465 L
.2498 .79971 L
.29331 .76447 L
.33524 .73318 L
.37557 .70666 L
.39599 .69504 L
.41848 .68404 L
.43982 .67563 L
.4598 .66983 L
.46501 .66867 L
.4707 .66758 L
.47572 .66678 L
.48106 .66608 L
.48379 .66579 L
.48635 .66556 L
.48885 .66538 L
.49115 .66524 L
.49334 .66513 L
.49445 .66509 L
.49565 .66506 L
.49685 .66503 L
.49797 .66501 L
.4993 .665 L
.50051 .665 L
.50175 .66501 L
.50291 .66503 L
.50419 .66505 L
.50556 .66509 L
.50692 .66515 L
.50836 .66521 L
.51092 .66536 L
.51552 .66573 L
.52055 .66628 L
.52601 .66704 L
.53184 .66804 L
.54235 .67035 L
.56476 .67725 L
.58592 .68603 L
.62631 .7078 L
.66928 .73639 L
.71065 .76758 L
.75043 .7999 L
.79279 .83608 L
.83355 .87213 L
.87689 .91143 L
Mistroke
.91864 .94999 L
.9588 .98757 L
Mfstroke
.9588 .98757 m
.97195 1 L
s
.12585 1 m
.12636 .99961 L
.16632 .97047 L
.20885 .94133 L
.2498 .91546 L
.29331 .8908 L
.33524 .87034 L
.37557 .85424 L
.39599 .84759 L
.41848 .84154 L
.43982 .83708 L
.44937 .83551 L
.4598 .83409 L
.46545 .83346 L
.4707 .83296 L
.47614 .83252 L
.48106 .83221 L
.48591 .83197 L
.48813 .83188 L
.49048 .8318 L
.49299 .83174 L
.4941 .83172 L
.4953 .8317 L
.49658 .83168 L
.49778 .83167 L
.49852 .83167 L
.49921 .83167 L
.50051 .83167 L
.50171 .83167 L
.503 .83168 L
.50421 .83169 L
.50533 .83171 L
.50792 .83176 L
.51065 .83184 L
.51331 .83193 L
.51579 .83204 L
.52142 .83236 L
.53077 .83309 L
.54076 .83416 L
.55151 .83564 L
.56317 .83763 L
.58433 .84222 L
.6273 .85526 L
.66867 .87209 L
.70845 .89173 L
.75081 .91582 L
.79157 .94161 L
.83491 .97135 L
s
.83491 .97135 m
.8741 1 L
s
.45927 1 m
.4598 .99995 L
.46545 .99953 L
.4707 .99919 L
.47614 .9989 L
.48106 .99869 L
.48591 .99853 L
.48813 .99847 L
.49048 .99842 L
.49299 .99838 L
.4941 .99837 L
.4953 .99836 L
.49658 .99835 L
.49778 .99834 L
.49852 .99834 L
.49921 .99833 L
.50051 .99833 L
.50171 .99834 L
.503 .99834 L
.50421 .99835 L
.50533 .99836 L
.50792 .9984 L
.51065 .99845 L
.51331 .99851 L
.51579 .99858 L
.52142 .99879 L
.53077 .99928 L
.54076 1 L
s
.54076 1 m
.54079 1 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[145]:=",
  ImageSize->{191, 191},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002o0000_b000`400?l00000o`00003o_oooool0
0;oooooo001Gooooo`?o0000IOooool005Kooooo00Go0000ooooooooooooooooo`00001Tooooo`00
D?ooool5o`0000Gooooo00?o0000ooooooooool0H_ooool000Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`;o00002?ooool4o`0000_ooooo0_l0000:ooooo`;o00002_oo
ool3o`0000Wooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool=o`0000Sooooo00Co
0000oooooooooooo00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
0ol00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool2o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooo000000cooooo0_l0000:ooooo`;o00002oooool4o`0000Wooooo2?l0
00000ooooooo0000ooooo`06ooooo`;o0000<oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo0_l0000:ooooo`002_ooool2o`0000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooo0000o`0000cooooo00?o0000ooooooooool02Ooo
ool3o`0000cooooo1Ol00004ooooo`04o`000?ooooooooooooooo`Ko0000>oooool00ol0003ooooo
ooooo`0>ooooo`;o00001?ooool00ol0003oooooooooo`0:ooooo`002oooool2o`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000cooooo
0_l0000<ooooo`?o00002_ooool5o`0000Cooooo0ol00005ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo
000<ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00Ko
0000oooooooooooo0000ooooool0000;ooooo`;o00002oooool3o`0001[ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`08ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
00003Oooool000Wooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo00Go
oooo0_l00008ooooo`;o000000?oooooo`000?l000002oooool3o`0000gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0eooooo`Co00002?ooool3o`0000?ooooo00?o0000oooooooo
ool00_ooool4o`0000;ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo
oooo0ol00003ooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`Co00003Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo03Cooooo1?l00008ooooo`?o00000oooool00ol0003o
ooooooooo`03ooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`002oooool00ol0003ooooo
ooooo`03o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`;o0000
00?oooooo`000?ooool0<_ooool00ol0003oooooooooo`0[ooooo`;o00001Oooool5o`0000Sooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool02_ooool000cooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02Oooool2o`0003?ooooo00?o0000ooooooooool0
7oooool3o`0000Oooooo0_l00005ooooo`Co000000?oooooo`000?ooool01oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`003Oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Cooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool07Oooool3o`0000Kooooo1?l00005ooooo`03o`00
0?oooooo000000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03?ooool000kooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo017ooooo0_l0000`ooooo`03o`000?oooooooooo017ooooo
1Ol00004ooooo`?o000000?oooooo`000?ooool01?ooool2o`0000Oooooo1?l0000;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00gooooo000?ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0Booooo`;o0000;_ooool00ol0003oooooooooo`05ooooo`?o00001?ooool8o`0000?ooooo
0ol00008ooooo`;o00001oooool2o`000003ooooool0003ooooo00_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool000Wooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000Gooooo
00?o0000ooooooooool00oooool2o`0000_ooooo0_l000000ooooooo0000ooooo`07ooooo`;o0000
2_ooool3o`0000Wooooo1?l00009ooooo`oo00001_ooool00ol0003oooooooooo`02o`0000[ooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
00Co0000ooooool0003o00002?ooool2o`0000_ooooo0ol0000:ooooo`So000000?oooooo`000?oo
ool01_ooool2o`00027ooooo0_l0000Eooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0?ooooo`002_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2_ooool2o`000003ooooool0003o000000Sooooo0_l0000<ooooo`Go00002_ooool5o`0002Sooooo
0_l0000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0@ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0
0005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02o`0000Sooooo00?o0000ooooool000003?ooool3o`0000Wooooo0_l00002ooooo`03o`000?oo
oooooooo02Cooooo0_l0000Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool2o`0000kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool2o`0000cooooo0_l0
0002ooooo`03o`000?oooooooooo00Kooooo0ol0000:ooooo`Go00003?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00Co
0000oooooooooooooooo0ol0000>ooooo`003Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo0_l0000;ooooo`;o00000_oo
ool2o`0000Kooooo1?l0000Jooooo`03o`000?oooooooooo027ooooo0_l0000Cooooo`;o00000ooo
ool00ol0003oooooooooo`02ooooo`?o00001?ooool01?l0003oooooooooooooool3o`0000oooooo
000=ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`Co00000oooool2o`0000Oooooo0_l0
000Iooooo`03o`000?oooooooooo01oooooo0_l00009ooooo`?o00001oooool4o`0000;ooooo00?o
0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0>ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000
ooooooooool00oooool3o`0000cooooo0_l00004ooooo`;o00008?ooool00ol0003oooooooooo`0L
ooooo`?o00002Oooool4o`0000Oooooo1?l00002ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool000kooooo0ol00005oooo
o`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01[ooooo0_l000000ooo
oooo0000o`000002o`0000Kooooo1?l00007ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04?ooool0013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`;o00001Oooool00ol0003oooooooooo`0Iooooo`;o00007Oooool00ol0003oooooooooo`0Hoooo
o`;o00000_ooool3o`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo017ooooo0009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0001_ooooo0ol0000Joooo
o`03o`000?oooooooooo017ooooo1ol000001_oooooo0000o`000?l0003oooooo`0000Kooooo0_l0
0009ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0K
ooooo`?o00005oooool00ol0003oooooooooo`0<ooooo`Wo000000Coooooo`000?l0003o00002Ooo
ool2o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`;o00001Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool000Wooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`;o00002_ooool5
o`0000Oooooo0ol0000:ooooo`oo00001?ooool3o`0000;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2
o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`;o00002_ooool0
00Wooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo0_l00002oooo
o`03o`000?oooooooooo00Gooooo0_l00006ooooo`?o00008_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:oooo
o`002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool2o`0000_ooooo1_l00006ooooo`So000000?oooooo`000?ooool02_ooool4o`0002Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02_ooool000_ooooo00?o0000ooooool000002Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool9o`000004oooo
ool0003oooooooooo`Ko00002?ooool3o`0002Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000[ooooo0_l000000ooooooo0000ooooo`0<oooo
o`002oooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooo000000cooooo1_l000000ooooooo0000o`00000@o`0002Sooooo0_l00005ooooo`?o
00001_ooool01?l0003oooooo`000?l00009ooooo`Co00003_ooool000cooooo00?o0000ooooool0
00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`;o00002oooool2o`0000_ooooo1?l00007ooooo`03
o`000?oooooooooo00?ooooo0_l0000[ooooo`;o000000?oooooo`000?ooool01Oooool3o`0000Ko
oooo00Co0000ooooool0003o00002Oooool4o`0000oooooo000=ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo0ol0000Booooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`0Yooooo`Co00001_ooool3o`0000Kooooo00?o0000oooo
ooooool00_l0000:ooooo`?o00003oooool000kooooo0ol00009ooooo`;o00001?ooool00ol0003o
ooooooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`03o`0000gooooo00?o0000oooooooo
ool03oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool07_ooool3o`00
00Oooooo1?l00007ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000@
ooooo`003Oooool4o`0000Wooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo0ol00005oooo
o`03o`000?oooooooooo01cooooo1?l00007ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000Aooooo`003oooool3o`00
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Kooooo`Co00001_ooool2o`00
0003ooooool0003ooooo00Oooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooool000004Oooool0013ooooo0_l0000;ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o0000:Oooool00ol0
003oooooooooo`0Aooooo`Go00001?ooool01?l0003oooooooooool00006ooooo`04o`000?oooooo
0000o`0000Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000_ooooo
00?o0000ooooool000004_ooool001;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0?ooooo`Co00001Oooool2o`0000Wooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool2o`0001?ooooo000C
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool3o`0000?ooooo1?l00007
ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`03o`000?oooooo000001?ooooo0009ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooool000002oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool01oooool01?l0003oooooo`000?l0000:ooooo`;o00002_ooool3o`0000[ooooo
3_l0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000002Oooool00ol0003ooooo
ooooo`06ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooo`000009ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`04o`00
0?ooooooooooo`0000_ooooo0_l0000;ooooo`Co00000_ooool2o`0000;ooooo00?o0000oooooooo
ool01Oooool2o`0001_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
017ooooo000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02o`0000_ooooo0ol0000<ooooo`Go000000?oooooo`000?ooool08Oooool2o`0000Wo
oooo00?o0000ooooooooool01_ooool2o`0000Wooooo0_l00006ooooo`05o`000?oooooooooooooo
ool000004Oooool000_ooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000;ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`;o
00000_ooool00ol0003oooooooooo`0;ooooo`?o00002oooool5o`00027ooooo00?o0000oooooooo
ool01oooool2o`0000Sooooo0ol00008ooooo`?o00001Oooool01?l0003oooooooooooooool2o`00
017ooooo000;ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
00002oooool4o`0000kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`?o
00001oooool3o`0000Sooooo0ol00006ooooo`03o`000?oooooooooo00?o00004Oooool000cooooo
00?o0000ooooooooool01oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000=ooooo`;o0000
3Oooool00ol0003oooooooooo`0Mooooo`?o00001oooool3o`0000Oooooo00?o0000ooooool00000
2_ooool2o`0000Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000017ooooo000<ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooool000003?ooool2o`0000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`Co00006oooool00ol0003oooooooooo`0Looooo`Co
00001oooool2o`0000Oooooo00?o0000ooooool000002oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool000gooooo0_l00008ooooo`03o`00
0?oooooooooo00;o00002_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool3o`0000_ooooo
00Co0000ooooool0003o00006_ooool00ol0003oooooooooo`0Kooooo`Co00001oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000001Cooooo000<ooooo`?o00002Oooool4o`0000cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo0_l0000Kooooo`03
o`000?oooooooooo017ooooo1?l00004ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool000kooooo0_l00008ooooo`03o`00
0?oooooooooo00;o00003?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo0ol00005ooooo`;o
00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo000?ooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00[ooooo0_l0000Hooooo`03o`000?oooooooooo00gooooo0ol000000ooooooo
0000ooooo`03ooooo`?o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?o
oooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool3o`0000;ooooo
0ol00007ooooo`?o00002oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
0009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`09ooooo`?o00002Oooool3o`0000[ooooo3Ol00009ooooo`03o`000?oooooo000000_ooooo00?o
0000ooooooooool01oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002?ooool2o`0000cooooo0ol0
000:ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`;o00002_ooool2o`0000gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`0@ooooo`002_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooo000000Wooooo0_l0000<ooooo`Co00002oooool5o`0000;ooooo00?o0000
ooooooooool03_ooool3o`0000kooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo013ooooo000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000002Oooool2o`00
00gooooo00Co0000ooooool0003o00003?ooool3o`000003ooooool0003ooooo00gooooo0_l0000@
ooooo`03o`000?oooooooooo00Gooooo1?l00008ooooo`;o00002Oooool3o`0000Wooooo00?o0000
ooooooooool04Oooool000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00009
ooooo`;o00003Oooool00ol0003oooooo`000002o`0000Wooooo1_l0000<ooooo`;o00004Oooool2
o`0000Kooooo1?l00008ooooo`;o00002Oooool4o`0000Sooooo0_l0000Cooooo`002oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000=ooooo`;o00000_ooool3
o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`Co00001oooool3
o`0000Sooooo0_l0000:ooooo`;o00002_ooool00ol0003oooooooooo`0Aooooo`003?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`?o00002_ooool3o`0000_ooooo0ol00004ooooo`Ko00001Oooool00ol0
003oooooooooo`06ooooo`?o00004_ooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0Booooo`003?ooool00ol0003o
ooooooooo`0:ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`;o00002oooool00ol0003o
ooooo`000009ooooo`?o00003_ooool00ol0003oooooooooo`04ooooo`?o00001Oooool01?l0003o
ooooooooooooool5o`0000cooooo0ol00005ooooo`03o`000?oooooo000000Sooooo0_l00009oooo
o`03o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo01;ooooo000;ooooo`?o
00002_ooool3o`0000?ooooo00?o0000ooooooooool01?ooool3o`0000[ooooo0ol000000ooooooo
0000ooooo`09ooooo`;o00003Oooool5o`0000?ooooo00?o0000ooooool000002?l0000?ooooo`?o
00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Sooooo00?o0000oooooooo
ool02_ooool2o`0000[ooooo00?o0000ooooooooool04_ooool000cooooo0_l0000;ooooo`;o0000
0oooool00ol0003oooooooooo`06ooooo`;o00002oooool00ol0003oooooo`00000;ooooo`;o0000
5?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo1?l00006ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`09ooooo`;o0000
2_ooool00ol0003oooooooooo`0Cooooo`003Oooool2o`0000_ooooo0_l00003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000<ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`;o00002Ooo
ool00ol0003oooooooooo`09ooooo`;o00002Oooool00ol0003oooooooooo`0:ooooo`;o00002_oo
ool00ol0003oooooooooo`0Cooooo`003_ooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo
ooooooooool000006?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo0ol00002ooooo`;o00002_ooool00ol0003ooooooooo
o`09ooooo`;o00002_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool04oooool000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`;o00003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o0000
ooooooooool02Oooool2o`0000Cooooo00?o0000ooooooooool01?ooool=o`0000_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00[ooooo0ol00009
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`;o00003?ooool00ol0003oooooooooo`08oooo
o`;o00003?ooool00ol0003oooooooooo`0:ooooo`;o00002Oooool00ol0003oooooooooo`05oooo
o`;o00003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`08ooooo`;o00002oooool00ol0003oooooooooo`0B
ooooo`002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0_l0000<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0;oooo
o`;o00001oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooo`00000;ooooo`03o`000?oooooooooo01;ooooo000:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool2o`0000cooooo00?o0000ooooooooool02?ooool00ol0
003oooooo`00000<ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooo
oooo00;o00002Oooool2o`0000Wooooo0ol0000:ooooo`;o00005?ooool000[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool2o`0000gooooo00?o0000ooooooooool03?ooool3o`0000?ooooo00?o0000oooo
ooooool04?ooool3o`0000Gooooo0ol00005ooooo`03o`000?oooooooooo00?o00002Oooool2o`00
00Sooooo00Co0000ooooool0003o00002_ooool2o`0001Cooooo000:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool2o`0000cooooo00?o0000ooooooooool02?ooool00ol0
003oooooo`00000=ooooo`03o`000?oooooooooo00cooooo0ol00002ooooo`03o`000?oooooooooo
00oooooo0ol00006ooooo`03o`000?oooooo000000Gooooo00Go0000ooooooooooooooooo`00000:
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0C
ooooo`002_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000gooooo0_l0000?oooo
o`03o`000?oooooo0000013ooooo0ol00007ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00002ooo
ool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo0_l0000<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000003?ooool2
o`00017ooooo00?o0000ooooooooool03_ooool3o`0000Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooooooo01?ooooo000;ooooo`;o00002oooool2
o`0000Wooooo0ol0000;ooooo`;o00002_ooool3o`0000kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
ooooo`0000_ooooo00?o0000ooooooooool04oooool000[ooooo0ol0000:ooooo`?o00002_ooool2
o`0000_ooooo0_l0000;ooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000002oooool00ol0003oooooooooo`0Cooooo`002_ooool3o`0000[ooooo0ol0000:
ooooo`;o00003?ooool2o`0000_ooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo0_l00009ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`0Dooooo`002oooool2o`0000_ooooo0_l0000:
ooooo`?o00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`;o00002_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool05?ooool000Wooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Ko0000oooooooooooo
0000ooooool00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool>o`00
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`002Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09?ooool0
00Wooooo1?l00008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000001Ol00005oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03o`00
0003ooooool0003ooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00gooooo1?l0000Hooooo`Go00006?ooool3o`0000[ooooo0009ooooo`;o
00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooo000001Wooooo00Co0000ooooool0003o00005oooool01Ol0003ooooooooooooo
oooo000000Wooooo0003ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00Kooooo1Ol000001?oooooo0000ooooool00007ooooo`03o`000?oooooooooo00[ooooo
1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00000Jooooo`;o
00007?ooool00ol0003oooooooooo`07ooooo`002_ooool3o`0000Wooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool03?ooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`0001?ooooo00?o0000oooo
ool000006oooool00ol0003oooooooooo`0Hooooo`;o00002_ooool000[ooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0<ooooo`;o00001Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool000006?ooool00ol0003oooooooooo`02
o`0001_ooooo00?o0000ooooooooool01oooool000Wooooo0_l00002ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`?o00001?ooool3o`00
00kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Gooooo0_l00000
0ooooooo0000ooooo`0Gooooo`03o`000?oooooooooo00;o00005oooool01Ol0003ooooooooooooo
oooo000000Wooooo0009ooooo`Co00002Oooool2o`0000[ooooo1ol00006ooooo`;o00002oooool2
o`0000Cooooo00?o0000ooooool000001?ooool3o`0000oooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo01Gooooo0_l0000Jooooo`?o00006Oooool3o`0000[ooooo0009
ooooo`?o00002_ooool2o`0000[ooooo1?l00009ooooo`;o00002oooool2o`0000Cooooo00?o0000
ooooooooool01Oooool2o`00013ooooo00Ko0000oooooooooooo0000ooooool0000Iooooo`03o`00
0?oooooooooo047ooooo000:ooooo`;o00002_ooool2o`0000_ooooo0_l0000;ooooo`;o00002ooo
ool2o`0000cooooo00?o0000ooooooooool03oooool01?l0003oooooo`000?l0000Jooooo`03o`00
0?oooooooooo047ooooo000:ooooo`;o00002oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`;o0000Gooo
ool000Wooooo[?l0000:ooooo`002Oooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo
00[ooooo0_l0000;ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000008
ooooo`03o`000?oooooooooo00oooooo1?l0000Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`08ooooo`002_ooool2o`0000[ooooo0_l0000;oooo
o`?o00002_ooool2o`0000_ooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03_ooool01_l0003oooooooooool0003oooooo`0001Wooooo00?o0000ooooooooool0@Ooo
ool000Wooooo0ol0000:ooooo`;o00002_ooool4o`0000Wooooo0_l0000;ooooo`;o00001?ooool0
0ol0003oooooooooo`05ooooo`;o00003_ooool2o`0000?ooooo00Co0000oooooooooooo00006?oo
ool00ol0003oooooooooo`11ooooo`002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool3o`0000gooooo0ol00003ooooo`05o`000?oooooo
ooooooooool000005oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Cooooo000:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00cooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo000:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo000:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00cooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo000:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo000:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00[ooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo0009ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00[ooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo0009ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo00Gooooo1?l0000Booooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool09?ooool000Wooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool2o`0000_ooooo3Ol0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000<oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00000<oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`;o00002_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool05?ooool000_ooooo0_l0000<oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`09oooo
o`?o00003_ooool2o`0000gooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo01Cooooo000;oooo
o`;o00002oooool2o`0000[ooooo0_l0000<ooooo`;o00002oooool3o`0000gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0;ooooo`;o00002Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool05?ooool000[ooooo0ol0000:oooo
o`?o00002Oooool3o`0000_ooooo0_l0000;ooooo`?o00003Oooool2o`0000oooooo00?o0000oooo
ooooool03?ooool2o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`08ooooo`;o00003?ooool2o`0000_ooooo0_l0000<ooooo`Co00003oooool00ol0
003oooooooooo`0=ooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`;o00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo0000
00cooooo0ol0000@ooooo`03o`000?oooooooooo00kooooo0ol00007ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Cooooo`002_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooool000003?ooool00ol0003oooooo`00000<ooooo`Co000000?oooooo`00
0?ooool03oooool3o`0000Oooooo0ol00004ooooo`05o`000?ooooooooooooooool000002oooool0
0ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool04ooo
ool000[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`;o00003?ooool0
0ol0003oooooooooo`09ooooo`;o00003?ooool00ol0003oooooooooo`0=ooooo`?o00000_ooool0
0ol0003oooooooooo`0@ooooo`;o00001_ooool3o`0000Gooooo00Co0000oooooooooooooooo0_l0
0009ooooo`;o00002?ooool01?l0003oooooo`000?l0000:ooooo`;o00005?ooool000[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`;o00003?ooool00ol0003ooooooooo
o`08ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`?o000000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0Aooooo`;o00001Oooool3o`0000Gooooo00?o0000ooooooooool00ol0
0009ooooo`;o00002?ooool01?l0003oooooo`000?l0000:ooooo`;o00005?ooool000[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00003?ooool00ol0003ooooooooo
o`09ooooo`;o00002oooool00ol0003oooooooooo`0:ooooo`;o00002?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooo000000;o00002Ooo
ool2o`0000Sooooo00Co0000ooooool0003o00002_ooool2o`0001Cooooo0009ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02?ooool2o`0000cooooo00?o0000ooooooooool02?oo
ool2o`0000_ooooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool01Ooo
ool3o`0000cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o
0000ooooooooool04_ooool000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`;o00003?ooool00ol0003oooooooooo`08ooooo`;o00002oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo3_l0000:ooooo`03o`000?oooooooooo00Wooooo0_l00002
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool02?ooool000kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo0_l00004
ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool02_ooool2o`0000[ooooo00?o0000ooooooooool05?ooool000gooooo0_l0000;oooo
o`;o00001?ooool00ol0003oooooooooo`04ooooo`;o00003oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo013ooooo0ol00005ooooo`03o`000?oooooooooo00gooooo0_l00008oooo
o`03o`000?oooooooooo00Sooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Cooooo`003?ooool3o`0000[ooooo0ol00003ooooo`03
o`000?oooooooooo00Cooooo0ol0000;ooooo`;o000000?oooooo`000?ooool02_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooo`000006ooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`03o`000?oooooooooo00[o
oooo0_l0000:ooooo`03o`000?oooooooooo01?ooooo000;ooooo`?o00002_ooool3o`0000Cooooo
00?o0000ooooooooool00oooool3o`0000_ooooo0ol000000ooooooo0000ooooo`08ooooo`;o0000
5Oooool>o`0000cooooo0ol00006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
2Oooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003oooooooooo`0Cooooo`003?oo
ool2o`0000_ooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`?o000000?o
ooooo`000?ooool02?ooool3o`0001?ooooo1?l00005ooooo`03o`000?oooooooooo00Cooooo0ol0
0009ooooo`Co00001_ooool00ol0003oooooooooo`07ooooo`;o00002Oooool00ol0003ooooooooo
o`0:ooooo`;o00002_ooool00ol0003oooooooooo`0Booooo`003?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`;o000000?oooooo`000?ooool01oooool3o`0000gooooo0_l00002ooooo`?o00000_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0ol00009ooooo`;o00001_ooool2
o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooo
oooo01;ooooo000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooo`00000;ooooo`Ko00001?ooool2o`0000Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0>ooooo`;o00002Oooool2o`0000Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooo`000009ooooo`03o`000?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
0000o`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`;o00004?oo
ool00ol0003oooooooooo`05ooooo`?o00002Oooool2o`0000[ooooo0_l0000:ooooo`03o`000?oo
oooooooo017ooooo000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`0:ooooo`Co00003?ooool6o`0000oooooo0ol0000>ooooo`03o`000?oo
oooooooo00Kooooo0_l00008ooooo`;o00002Oooool4o`0000Sooooo0_l0000Cooooo`002_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool02Ooo
ool4o`0000cooooo1Ol00002ooooo`03o`000?oooooooooo013ooooo0_l0000=ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool2o`0000Sooooo1?l00008ooooo`;o00004ooo
ool000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00Wooooo0ol0000:ooooo`Co00001oooool00ol0003oooooooooo`0Booooo`;o00003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool2o`000003ooooool0003ooooo00Oooooo0_l0000Booooo`002Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000Sooooo0_l0000:ooooo`;o00002_ooool2o`0000_ooooo3_l0
0009ooooo`?o00002Oooool2o`0000Sooooo00Co0000oooooooooooo00003?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool02?ooool001_ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0_l0000Hooooo`03o`000?oooooooooo00Go
oooo0_l00004ooooo`?o00001oooool3o`0000Wooooo0_l00008ooooo`03o`000?oooooo000000co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Co
oooo000?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000004oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0>ooooo`Go00001?ooool3o`0000Sooooo0_l00008ooooo`03o`000?oooooo000000cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
000>ooooo`;o00002Oooool01?l0003oooooo`000?l0000;ooooo`;o00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Aooooo`?o00001Oooool2o`0000Sooooo0_l00007ooooo`04o`000?ooooooooooo`0000_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?o
oooo000=ooooo`;o00002_ooool4o`0000[ooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo
0ol00009ooooo`;o00007?ooool00ol0003oooooooooo`0Aooooo`Co00001Oooool2o`0000Sooooo
0_l00007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01;ooooo000<ooooo`?o00002Oooool4o`0000[ooooo
0ol00004ooooo`03o`000?oooooooooo00Cooooo0ol00009ooooo`03o`000?oooooooooo00;o0000
6_ooool00ol0003oooooooooo`0Looooo`;o00001oooool2o`0000Oooooo00Co0000oooooooooooo
00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04_ooool000gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`0000_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`?o00002?ooool2o`000004oooo
ool0003o0000o`0001_ooooo00?o0000ooooooooool07?ooool3o`0000Oooooo0ol00006ooooo`03
o`000?oooooo000000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo017ooooo000=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
3?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`03o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo01kooooo
0_l00007ooooo`;o00001oooool01?l0003oooooo`000?l0000:ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0_l0000;ooooo`?o
00003oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01Oooool3o`0000Wooooo0ol00005ooooo`04o`000?ooooooooooooooo`?o00004Oooool000_o
oooo00?o0000ooooooooool02?ooool00ol0003oooooo`00000<ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`05ooooo`;o00000_ooool2o`0000cooooo0ol0000@oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Wooooo0_l00006ooooo`03o`000?oooooooooo00?o00004Oooool000_o
oooo00?o0000ooooooooool01oooool00ol0003oooooo`00000<ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol0003oooooooooo`0=ooooo`Go00008oooool2o`0000Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000009ooooo`;o00001Oooool01?l0003oooooooooooooool2o`00017ooooo000:
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000co
oooo0_l0000=ooooo`Go00000_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00000Aooooo`002_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooo000000_ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`00000;ooooo`;o00002oooool4o`0000Oooooo00?o0000
ooooooooool01Oooool3o`0001cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool000Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooo`00000;ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooooooo
o`09ooooo`;o00002oooool?o`0000Wooooo0_l0000:ooooo`;o00000_ooool00ol0003ooooooooo
o`05ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooool00000
2Oooool00ol0003oooooooooo`08ooooo`004oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Ooo
ool2o`0000Gooooo1?l000000ooooooo0000o`000004ooooo`;o00002_ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002oooool01?l0003o
ooooooooool0000Cooooo`003oooool2o`000003ooooool0003ooooo00Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0_l0000Zooooo`03
o`000?oooooooooo013ooooo1Ol00004ooooo`?o00002?ooool2o`000003ooooool0003o000000Oo
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooo
ool000004oooool000kooooo1?l0000:ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`;o
00001oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo017ooooo1Ol00006ooooo`?o
00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`03o`000?oooooo000001;ooooo000=ooooo`?o000000?oooooo`00
0?ooool02?ooool2o`0000Gooooo00?o0000ooooooooool00oooool3o`0000Kooooo00?o0000oooo
ooooool00_ooool2o`0002Oooooo00?o0000ooooooooool07?ooool4o`0000Oooooo00Co0000oooo
ool0003o00001oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002_oo
ool01?l0003oooooooooool0000Aooooo`003_ooool3o`0000Wooooo0ol00004ooooo`03o`000?oo
oooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo00;ooooo0ol0000Nooooo`Go00001?oo
ool00ol0003oooooooooo`0Oooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo0_l0
0005ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooo`00000Aooooo`003_oo
ool00ol0003oooooo`000009ooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`;o00001_oo
ool00ol0003oooooooooo`02ooooo`?o00003?ooool2o`0001;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Xooooo`?o00000_ooool00ol0003oooooooooo`03ooooo`;o0000
1_ooool01_l0003oooooooooool0003oooooo`0000Wooooo00?o0000ooooool000004?ooool000go
oooo00?o0000ooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000_o
oooo0ol0000<ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02_o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;o00002Oooool4o`0000oooooo000<ooooo`03o`000?oooooo000000[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooool000002oooool3o`0000;ooooo5_l0000Xooooo`;o
00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o00002Oooool3o`0000oo
oooo000;ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0:ooooo`;o00002oooool3o`000003ooooool0003o000000;o00000oooool01?l0003o
ooooooooooooool6o`0000Wooooo1_l0000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool0000:ooooo`?o00003_ooool000_ooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0_l0000;oooo
o`Ko00001oooool00ol0003oooooo`000004o`0000;ooooo00?o0000ooooooooool03Oooool3o`00
02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooool000003Oooool000[ooooo00?o0000ooooool000002Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`Co00002Oooool6o`000003
ooooool0003ooooo00;ooooo00?o0000ooooooooool01Oooool3o`0000Sooooo0_l0000Qooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00[ooooo0009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0ol0000:ooooo`;o0000
2oooool@o`0000Gooooo1Ol0000:ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooo`00000:ooooo`002oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`;o00006_oo
ool00ol0003oooooooooo`05ooooo`;o00001_ooool7o`000003ooooool0003o000000?o00002Ooo
ool2o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00001Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06Oooool2o`0001cooooo00?o0000ooooooooool04Oooool5
o`0000;ooooo1ol00006ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0
003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`0Hooooo`;o00007_ooool00ol0
003oooooooooo`0Kooooo`Go00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000?ooooo`?o00001Oooool00ol0003o
ooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`;o00004_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01gooooo1?l00007ooooo`?o00001oooool2o`0000Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool000kooooo0ol00006ooooo`04o`000?ooooooooooooooo`?o
00001?ooool00ol0003oooooooooo`04ooooo`?o00002oooool2o`0000?ooooo0_l0000Qooooo`03
o`000?oooooooooo01kooooo0_l00008ooooo`Co00002?ooool2o`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04?ooool000oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o0000
0oooool00ol0003oooooooooo`04ooooo`?o00002_ooool3o`0000;ooooo0_l0000Sooooo`03o`00
0?oooooooooo023ooooo0_l00009ooooo`;o00001oooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`00013ooooo000>ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000002_ooool3o`000003ooooool0003o000000Oooooo1Ol0
000Iooooo`03o`000?oooooooooo02;ooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l0000@ooooo`003Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`;o00003?ooool01Ol0003oooooo`000?oooooo000000Wooooo
0ol0000<ooooo`?o00003?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`003?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02o`0000Sooooo1?l0000;ooooo`?o00003_oo
ool00ol0003oooooooooo`0Uooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`002oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`000008
ooooo`;o00003?ooool3o`000003ooooool0003ooooo00[ooooo1Ol0000Yooooo`;o00005Oooool0
0ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`0Aooooo`002_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00Co0000ooooool0003o00002?ooool2
o`0000_ooooo0ol0000:ooooo`So00000_ooool00ol0003oooooooooo`05ooooo`?o00008Oooool2
o`0001Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo013ooooo0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooo`000009ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`?o00001_ooool01?l0
003oooooooooooooool@o`0000Sooooo0ol00009ooooo`;o00002?ooool01?l0003oooooo`000?l0
000;ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool2o`0002oooooo00?o0000
ooooooooool01Oooool2o`0000Kooooo2?l00003ooooo`?o00002?ooool2o`0000Oooooo0_l00000
0ooooooo0000ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo000>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`;o0000<Oooool00ol0
003oooooooooo`0Aooooo`Go00001Oooool5o`0000Gooooo0_l00007ooooo`Co00002oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0=ooooo`003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01ko
oooo0ol00006ooooo`03o`000?oooooo000000Kooooo00Co0000ooooool0003o00002_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`003?ooool01?l0003oooooooooooooool2o`0000Cooooo00?o0000oooo
ooooool01?ooool2o`0000[ooooo0_l0000dooooo`03o`000?oooooooooo01gooooo1Ol00006oooo
o`?o00001_ooool2o`000003ooooool0003o000000Wooooo00?o0000ooooooooool00_ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`002oooool01?l0003o
ooooooooooooool3o`0000?ooooo00?o0000ooooooooool01?ooool3o`0000Sooooo0_l000000ooo
oooo0000o`00000cooooo`03o`000?oooooooooo02Wooooo0ol00007ooooo`Co00002Oooool2o`00
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00[ooooo000:ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`04oooo
o`?o00002?ooool00ol0003oooooooooo`03o`0000_ooooo0_l0000Vooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool01Oooool4o`0000Sooooo0_l00005ooooo`03o`000?oooooooooo
00;ooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo0009ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Oo
oooo0_l000000ooooooo0000o`000002o`0000[ooooo1?l0000Vooooo`03o`000?oooooooooo03Ko
oooo0ol00009ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00004oooo
o`03o`000?oooooooooo00Sooooo000=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool02?ooool4o`0000[ooooo1?l0000Iooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03?ooool000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Kooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo0_l00002ooooo`03
o`000?oooooooooo00Sooooo0ol0000:ooooo`Go00003?ooool00ol0003oooooooooo`0iooooo`;o
00003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo000;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;o00002oooool2o`0000cooooo0ol000000ooooooo0000ooooo`08ooooo`Go0000
1_ooool3o`000006ooooool0003o0000o`000?oooooo0000?Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool000[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooo
oooo00003?ooool00ol0003oooooooooo`09ooooo`?o00002_ooool4o`0000?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`000007o`0003kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo0009ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`00
00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`;o00002_oooolJo`00
00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02?ooool005Sooooo0_l0001Uooooo`00F_ooool00ol0003o
ooooooooo`1Rooooo`00E_ooool01Ol0003ooooooooooooooooo000006Cooooo000Dooooo`?o0000
@?ooool3o`0006Gooooo000Eooooo`03o`000?oooooooooo0:Oooooo0003ooooo`?o00000_ooool5
o`0000;ooooo0ol00003ooooo`?o00000oooool3o`0000Sooooo1Ol000000ooooooo0000o`000003
o`0000;ooooo0ol00002ooooo`Go00000_ooool4o`0000Sooooo1?l000001Ooooooo0000o`000?l0
003ooooo00;o000000?oooooo`000?l000000_l00007ooooo`Co00000oooool3o`0000;ooooo1Ol0
0003ooooo`;o000000Coooooo`000?oooooooooo0_l00002ooooo`Go00000_ooool3o`0000;ooooo
0ol000000ooooooo0000o`000007ooooo`?o00001?ooool2o`000003ooooool0003o000000;o0000
1Oooool00ol0003oooooooooo`02ooooo`?o00000_ooool4o`0000Gooooo0003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo
0006ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000oooooooooooo0000ooooo`05o`0000Wooooo00?o0000ooooooooool00oooool01?l0
003oooooooooooooool5o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Oooooo0ol00003ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003o
ooooooooo`07ooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000002ooooo`Go00000_ooool3o`0000Gooooo0004ooooo`;o0000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01_l0003oooooooooool0003ooooo
o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`;o00001?ooool00ol0003oooooo`000002ooooo`07o`000?oo
ooooooooooooool0003oooooo`000008ooooo`000oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo0ol00002ooooo`Co00000oooool3o`0000Wooooo1?l000001?oooooo0000
o`000?l00004ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00002Oooool2o`0000?o
oooo1?l00003ooooo`?o00002Oooool4o`0000;ooooo0ol00004ooooo`04o`000?oooooooooooooo
o`;o000000Coooooo`000?l0003ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l00009
ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000002ooooo`?o00000oooool4o`0000Cooooo0003ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0@Oooool000Cooooo0ol000001?oooooo0000o`00
0?l0000Nooooo`;o00000oooool00ol0003oooooooooo`07ooooo`?o00001Oooool2o`0001Kooooo
0_l0000Dooooo`?o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo
002oooooo`00_oooool00001\
\>"],
  ImageRangeCache->{{{77.875, 267.875}, {415.938, 225.938}} -> {-6.05316, \
4.75354, 0.0350147, 0.0350147}}]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Printout",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{727, 745},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->54,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1.25,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 348, 9, 94, "Text"],
Cell[2105, 62, 284, 16, 27, "Text"],
Cell[2392, 80, 591, 22, 63, "Text"],
Cell[2986, 104, 136, 3, 26, "Text"],
Cell[3125, 109, 802, 36, 63, "Text"],
Cell[3930, 147, 164, 4, 27, "Text"],
Cell[4097, 153, 95, 3, 27, "Text"],
Cell[4195, 158, 62, 1, 30, "Input"],
Cell[4260, 161, 251, 11, 27, "Text"],

Cell[CellGroupData[{
Cell[4536, 176, 124, 2, 30, "Input"],
Cell[4663, 180, 64797, 2079, 232, 33611, 1689, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[69475, 2262, 126, 3, 27, "Text"],
Cell[69604, 2267, 122, 3, 27, "Text"],
Cell[69729, 2272, 233, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[69987, 2282, 129, 4, 30, "Input"],
Cell[70119, 2288, 39104, 1147, 250, 14377, 837, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[109238, 3438, 274, 5, 63, "Text"],

Cell[CellGroupData[{
Cell[109537, 3447, 197, 6, 46, "Input"],
Cell[109737, 3455, 47459, 1280, 242, 15532, 879, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[157211, 4738, 270, 11, 27, "Text"],
Cell[157484, 4751, 629, 25, 63, "Text"],
Cell[158116, 4778, 242, 10, 28, "Text"],

Cell[CellGroupData[{
Cell[158383, 4792, 191, 5, 62, "Input"],
Cell[158577, 4799, 73761, 2211, 237, 35248, 1731, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[232353, 7013, 102, 3, 27, "Text"],
Cell[232458, 7018, 73, 2, 30, "Input"],
Cell[232534, 7022, 68, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[232627, 7026, 158, 5, 46, "Input"],
Cell[232788, 7033, 216, 6, 34, "Output"]
}, Open  ]],
Cell[233019, 7042, 155, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[233199, 7049, 347, 8, 95, "Input"],
Cell[233549, 7059, 91983, 3368, 243, 47444, 2813, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[325547, 10430, 88, 3, 27, "Text"],
Cell[325638, 10435, 272, 12, 27, "Text"],
Cell[325913, 10449, 711, 19, 98, "Text"],

Cell[CellGroupData[{
Cell[326649, 10472, 204, 7, 62, "Input"],
Cell[326856, 10481, 221, 6, 34, "Output"],
Cell[327080, 10489, 75654, 2197, 257, 33899, 1677, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[402749, 12689, 422, 13, 63, "Text"],
Cell[403174, 12704, 300, 15, 30, "Text"],
Cell[403477, 12721, 143, 5, 27, "Text"],
Cell[403623, 12728, 222, 4, 23, "Text"],

Cell[CellGroupData[{
Cell[403870, 12736, 583, 13, 176, "Input"],
Cell[404456, 12751, 273, 8, 34, "Output"],
Cell[404732, 12761, 128228, 5635, 246, 73596, 4954, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[532975, 18399, 129, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[533129, 18406, 166, 6, 46, "Input"],
Cell[533298, 18414, 74909, 2120, 237, 32177, 1587, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[608222, 20537, 125, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[608372, 20546, 593, 13, 176, "Input"],
Cell[608968, 20561, 205, 6, 36, "Output"],
Cell[609176, 20569, 102165, 3020, 252, 42000, 2272, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

