(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    245709,       6972]*)
(*NotebookOutlinePosition[    248058,       7043]*)
(*  CellTagsIndexPosition[    247968,       7037]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part III. First Order Ordinary Differential Equations", 
    "Section"],
  "\n",
  StyleBox["Section 4. Approximate Solutions ", "Subsection"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
In this section looping constructs are used to approximate \
solutions to initial value problems (IVP). Once created, and tested for \
accuracy, these loops can be easily be made into procedures that can be used \
on any IVP. Throughout the section discussions will refer to the standard IVP\
\
\>", "Text"],

Cell[TextData[{
  StyleBox["y'",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ")",
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  " (",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "))  ,  ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(t0) = y0  . "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["One step at a time: Euler's algorithm", \
"Subsubsection"]], "Text"],

Cell[TextData[{
  "The Euler one-step algorithm generates IVP approximations by moving from \
point to point along tangent lines in the slope field (Ledder, Chapter 2, \
Section 5). Movement from point ( ",
  StyleBox["t",
    FontSlant->"Italic"],
  ",",
  StyleBox[" y",
    FontSlant->"Italic"],
  ") is horizontal by a displacement  ",
  StyleBox["h",
    FontSlant->"Italic"],
  "  and vertical by the displacement  ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ") ",
  StyleBox["h",
    FontSlant->"Italic"],
  ". The horizontal distance ",
  StyleBox["h",
    FontSlant->"Italic"],
  " stays the same, it is called the \"step size\".  Thus ",
  StyleBox["t",
    FontSlant->"Italic"],
  " increases to ",
  StyleBox["t",
    FontSlant->"Italic"],
  " + ",
  StyleBox["h",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " changes to ",
  StyleBox["y",
    FontSlant->"Italic"],
  " + ",
  StyleBox["f",
    FontSlant->"Italic"],
  " (",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ") ",
  StyleBox["h",
    FontSlant->"Italic"],
  " yielding the famous Euler iteration formulas: "
}], "Text"],

Cell[TextData[{
  StyleBox["t",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "] = ",
  StyleBox["t",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1",
  "] + ",
  StyleBox["h",
    FontSlant->"Italic"],
  "                            \n",
  StyleBox["y",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "] = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1",
  "] + ",
  StyleBox["h",
    FontSlant->"Italic"],
  " ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1",
  "], ",
  StyleBox["y",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1",
  "] )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["Euler's algorithm will be implemented for the IVP", "Text"],

Cell[TextData[{
  " ",
  StyleBox["y'",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = cost(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") , ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 1"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "We begin by entering the differential equation and then defining the \
function  ",
  StyleBox["f",
    FontSlant->"Italic"],
  ". The equation is entered so we can  solve it later to check the \
algorithm. We also want to make sure that you see how the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  " is obtained  from the differential equation (which must be in normal \
form). "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
DE = y'[t] ==  Cos[t]*y[t]
f[t_,y_] := Cos[t]*y\
\>", "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(Cos[t]\ y[t]\)}]], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[TextData[{
  "We will use the symbols T and Y to denote the indexed variables that \
contain the values of ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " respectively. Both T and Y are defined recursively in a special way that \
tells ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to remember their values. "
}], "Text"],

Cell[TextData[{
  "Begin with step size ",
  StyleBox["h",
    FontSlant->"Italic"],
  " = 0.5."
}], "Text"],

Cell[TextData[{
  "The next entries first define ",
  StyleBox["h",
    FontSlant->"Italic"],
  ", T[0], and Y[0]. Then T[n] and Y[n] are defined as indexed variables that \
remember their values. See Section 2.5.9 of ",
  StyleBox["The Mathematica Book.",
    FontSlant->"Italic"]
}], "Text"],

Cell["\<\
h = 0.5; T[0] = 0; Y[0] = 1;
T[n_] := T[n] = T[n-1] + h;
Y[n_] := Y[n] = Y[n-1] + h*f[T[n-1],Y[n-1]];\
\>", "Input",
  CellLabel->"In[9]:="],

Cell["\<\
Once defined we can plot the approximation points using ListPlot. \
See below where the first 6 approximation points are plotted.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ Table[{T[n],Y[n]}, {n,0,6}], PlotStyle->PointSize[0.02], 
          PlotRange->{0,3} ]\
\>", "Input",
  CellLabel->"In[15]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0 0.206011 [
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .20601 Mdot
.18254 .30902 Mdot
.34127 .44461 Mdot
.5 .56472 Mdot
.65873 .5847 Mdot
.81746 .46304 Mdot
.97619 .27756 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{189.562, 117},
  ImageMargins->{{1.5, 0}, {0, 1.5}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003/0000TR000`400?l00000o`00003ok?ooool0
0>cooooo000dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Cooooo`Co000000?o410@ooooooooool04_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd04_ooool5o`0001?ooooo1Ol0
0005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01?ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c009ooooo`00=?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Aooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01;ooooo00Go410@
okZj^_ooooooMgMgoc8b<P09ooooo`00=?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04Oooool00onHV9So8B4Qonk^kP0Eooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`00=?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00kooooo00?oMgMgoc8b<_ooool04oooool00onHV9So8B4Qonk^kP0Eooooo`03oiRHV?lQ
8B7ok^k^00oooooo00?oMgMgoc8b<_ooool05Oooool00onYZJWo410@ooooo`08ooooo`00=?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Go
oooo00?oMgMgofIVI_ooool05Oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`05Oooool00ol@413o0000okZj^P09ooooo`00=?ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06?ooool00onj^[[o8B4Qooooo`08ooooo`00=?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool01Ol0003o^[ZjoooooonHV9So
410@01?ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01Gooooo00Go
410@oiRHV?oooooo^[Zjo`000009ooooo`00=?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000Dooooo`03oeEEEOmVIVKo000001Kooooo00?oEEEEofIVI_l000003Oooool4o`0001?ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00Cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`00
01Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@09ooooo`00k?ooool00>cooooo003/ooooo`00k?oo
ool001[oooooc?l00006ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007oooool00ol0003o
ooooooooo`3:ooooo`007oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003ooooooooo
o`3:ooooo`007oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003oooooooooo`3:oooo
o`007oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003oooooooooo`3:ooooo`007ooo
ool00ol0003oooooooooo`3:ooooo`007oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0
003oooooooooo`3:ooooo`007oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003ooooo
ooooo`3:ooooo`007oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003oooooooooo`3:
ooooo`007oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003oooooooooo`3:ooooo`00
7oooool00ol0003oooooooooo`3:ooooo`001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3:ooooo`00
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0b_ooool000Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00;ooooo0_l0003;ooooo`001Oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3:ooooo`001Oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo
0<[ooooo0005ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0<[ooooo0005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0<[ooooo0005ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000oooooooo
ool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_oo
ool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oo
oooo00?o0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o
0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000oooo
ooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0
b_ooool001Kooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0<[ooooo000H
ooooo`03o`000?oooooooooo00?ooooo0_l0003<ooooo`006?ooool00ol0003oooooooooo`02oooo
o`Co0000boooool001Sooooo00?o0000ooooooooool00_ooool4o`000<_ooooo000Hooooo`03o`00
0?oooooooooo00?ooooo0_l0003<ooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0<[ooooo000Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0b_ooool0
01Kooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003o
ooooooooo`3:ooooo`007oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003ooooooooo
o`3:ooooo`007oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003oooooooooo`3:oooo
o`007oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003oooooooooo`3:ooooo`007ooo
ool00ol0003oooooooooo`3:ooooo`007oooool00ol0003oooooooooo`2nooooo`;o00002_ooool0
01oooooo00?o0000ooooooooool0_Oooool4o`0000Wooooo000Oooooo`03o`000?oooooooooo0;go
oooo1?l00009ooooo`007oooool00ol0003oooooooooo`2nooooo`;o00002_ooool001oooooo00?o
0000ooooooooool0b_ooool000Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0b_ooool000Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0L
ooooo`;o0000[?ooool000Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01_ooooo1?l0002[ooooo`002?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00?ooooo0_l0000Looooo`Co0000Zoooool000Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool07?ooool2o`000:co
oooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3:ooooo`002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0b_ooool000Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo00?o0000
ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000oooooooo
ool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_oo
ool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oo
oooo00?o0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o
0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000oooo
ooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0
b_ooool001Gooooo1Ol00005ooooo`03o`000?oooooooooo0<[ooooo000Eooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01Oooool00ol0003oooooooooo`3:ooooo`005_ooool00onHV9So8B4Qonk^kP06
ooooo`03o`000?oooooooooo0<[ooooo000Gooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l0003;oooo
o`006?ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0<[ooooo000Iooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0b_ooool001Gooooo00Go0000okZj^_ooooooV9RH
oa0@4005ooooo`03o`000?oooooooooo0<[ooooo000Eooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1Oooool00ol0003oooooooooo`3:ooooo`007oooool00ol0003oooooooooo`0mooooo`;o0000Rooo
ool001oooooo00?o0000ooooooooool0??ooool4o`0008[ooooo000Oooooo`03o`000?oooooooooo
03cooooo1?l0002:ooooo`007oooool00ol0003oooooooooo`0mooooo`;o0000Roooool001oooooo
00?o0000ooooooooool0W_ooool2o`0002[ooooo000Oooooo`03o`000?oooooooooo09gooooo1?l0
000Yooooo`007oooool00ol0003oooooooooo`2Mooooo`Co0000:Oooool001oooooo00?o0000oooo
ooooool0W_ooool2o`0002[ooooo000Oooooo`03o`000?oooooooooo0<[ooooo000Oooooo`03o`00
0?oooooooooo0<[ooooo000Oooooo`03o`000?oooooooooo0<[ooooo000Oooooo`03o`000?oooooo
oooo0<[ooooo000Oooooo`03o`000?oooooooooo0<[ooooo0005ooooo`Go00001Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0<[ooooo0005ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`3:ooooo`001_ooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0b_ooool000Oooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8b
ooooo`03ooooo`;o0000boooool000Sooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0b_ooool000Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0<[ooooo0005ooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0<[ooooo0005
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0b_oo
ool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oo
oooo00?o0000ooooooooool0b_ooool001oooooo00?o0000ooooooooool0b_ooool001oooooo00?o
0000ooooooooool0GOooool2o`0006_ooooo000Oooooo`03o`000?oooooooooo05cooooo1?l0001Z
ooooo`007oooool00ol0003oooooooooo`1Looooo`Co0000J_ooool001oooooo00?o0000oooooooo
ool0GOooool2o`0006_ooooo000Oooooo`03o`000?oooooooooo07gooooo0_l0001;ooooo`007ooo
ool00ol0003oooooooooo`1looooo`Co0000B_ooool001oooooo00?o0000ooooooooool0O?ooool4
o`0004[ooooo000Oooooo`03o`000?oooooooooo07gooooo0_l0001;ooooo`007oooool00ol0003o
ooooooooo`3:ooooo`005Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0b_ooool001Gooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0<[o
oooo000Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0b_ooool001Sooooo00?o
ZJVYoa0@4?ooool01?ooool2o`000<_ooooo000Gooooo`03oa0@4?l0003o^[Zj0=;ooooo000Hoooo
o`03okZj^_lQ8B7ooooo0=7ooooo000Eooooo`05oa0@4?nHV9SooooookZj^_l00000d_ooool001Go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@3Booooo`00k?ooool00001\
\>"],
  ImageRangeCache->{{{79.375, 267.938}, {215.375, 99.375}} -> {-2.0216, \
2.63794, 0.0193775, 0.0298604}}]
}, Open  ]],

Cell["\<\
The following entry shows how to display the approximate solution \
values in matrix form.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Table[{T[n],Y[n]}, {n,0,6}]//MatrixForm", "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1"},
            {"0.5`", "1.5`"},
            {"1.`", "2.1581869214177796`"},
            {"1.5`", "2.741223606486024`"},
            {"2.`", "2.8381768500201585`"},
            {"2.5`", "2.247627691171547`"},
            {"3.`", "1.3472914037172572`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[20]//MatrixForm="]
}, Open  ]],

Cell["\<\
To check the algorithm we will obtain the solution formula and then \
add its graph to a plot of the approximation points. We will to use the \
solution several more times, so make it into a function named g. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
soln = DSolve[ {DE, y[0]==1}, y, t];
g := soln[[1,1,2]]
g[t]\
\>", "Input",
  CellLabel->"In[25]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\[ExponentialE]\^Sin[t]\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[TextData[{
  "Here is a plot of g, the Euler approximation points from ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0 to ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 10 and the broken line obtained by connecting the points (red). "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
pts = ListPlot[ Table[{T[n],Y[n]}, {n,0,20}],
                PlotStyle->PointSize[0.01], PlotRange->{0,3} ];
lines = ListPlot[ Table[{T[n],Y[n]}, {n,0,20}], PlotJoined->True, 
                  PlotStyle->RGBColor[1,0,0], PlotRange->{0,3} ];
Show[ pts, lines, Plot[ g[t], {t,0,10} ], AspectRatio->1/3 ]\
\>", "Input",
  CellLabel->"In[40]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.111111 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .05556 -18 -4.5 ]
[.01131 .05556 0 4.5 ]
[.01131 .11111 -6 -4.5 ]
[.01131 .11111 0 4.5 ]
[.01131 .16667 -18 -4.5 ]
[.01131 .16667 0 4.5 ]
[.01131 .22222 -6 -4.5 ]
[.01131 .22222 0 4.5 ]
[.01131 .27778 -18 -4.5 ]
[.01131 .27778 0 4.5 ]
[.01131 .33333 -6 -4.5 ]
[.01131 .33333 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .05556 m
.03006 .05556 L
s
[(0.5)] .01131 .05556 1 0 Mshowa
.02381 .11111 m
.03006 .11111 L
s
[(1)] .01131 .11111 1 0 Mshowa
.02381 .16667 m
.03006 .16667 L
s
[(1.5)] .01131 .16667 1 0 Mshowa
.02381 .22222 m
.03006 .22222 L
s
[(2)] .01131 .22222 1 0 Mshowa
.02381 .27778 m
.03006 .27778 L
s
[(2.5)] .01131 .27778 1 0 Mshowa
.02381 .33333 m
.03006 .33333 L
s
[(3)] .01131 .33333 1 0 Mshowa
.125 Mabswid
.02381 .01111 m
.02756 .01111 L
s
.02381 .02222 m
.02756 .02222 L
s
.02381 .03333 m
.02756 .03333 L
s
.02381 .04444 m
.02756 .04444 L
s
.02381 .06667 m
.02756 .06667 L
s
.02381 .07778 m
.02756 .07778 L
s
.02381 .08889 m
.02756 .08889 L
s
.02381 .1 m
.02756 .1 L
s
.02381 .12222 m
.02756 .12222 L
s
.02381 .13333 m
.02756 .13333 L
s
.02381 .14444 m
.02756 .14444 L
s
.02381 .15556 m
.02756 .15556 L
s
.02381 .17778 m
.02756 .17778 L
s
.02381 .18889 m
.02756 .18889 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .21111 m
.02756 .21111 L
s
.02381 .23333 m
.02756 .23333 L
s
.02381 .24444 m
.02756 .24444 L
s
.02381 .25556 m
.02756 .25556 L
s
.02381 .26667 m
.02756 .26667 L
s
.02381 .28889 m
.02756 .28889 L
s
.02381 .3 m
.02756 .3 L
s
.02381 .31111 m
.02756 .31111 L
s
.02381 .32222 m
.02756 .32222 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.01 w
.02381 .11111 Mdot
.07143 .16667 Mdot
.11905 .2398 Mdot
.16667 .30458 Mdot
.21429 .31535 Mdot
.2619 .24974 Mdot
.30952 .1497 Mdot
.35714 .0756 Mdot
.40476 .0402 Mdot
.45238 .02706 Mdot
.5 .02421 Mdot
.54762 .02764 Mdot
.59524 .03744 Mdot
.64286 .05541 Mdot
.69048 .08247 Mdot
.7381 .11356 Mdot
.78571 .13324 Mdot
.83333 .12355 Mdot
.88095 .08636 Mdot
.92857 .04702 Mdot
.97619 .02357 Mdot
1 0 0 r
.5 Mabswid
.02381 .11111 m
.07143 .16667 L
.11905 .2398 L
.16667 .30458 L
.21429 .31535 L
.2619 .24974 L
.30952 .1497 L
.35714 .0756 L
.40476 .0402 L
.45238 .02706 L
.5 .02421 L
.54762 .02764 L
.59524 .03744 L
.64286 .05541 L
.69048 .08247 L
.7381 .11356 L
.78571 .13324 L
.83333 .12355 L
.88095 .08636 L
.92857 .04702 L
.97619 .02357 L
s
0 g
.02381 .11111 m
.06244 .16487 L
.10458 .23523 L
.12507 .26625 L
.13506 .27882 L
.14415 .28822 L
.14868 .29208 L
.1536 .29559 L
.15825 .29824 L
.16254 .30007 L
.16488 .30082 L
.16708 .30137 L
.16834 .3016 L
.16949 .30178 L
.17013 .30185 L
.17082 .30192 L
.17209 .302 L
.17277 .30202 L
.17342 .30203 L
.17463 .30201 L
.17593 .30193 L
.17666 .30186 L
.17734 .30177 L
.1797 .30137 L
.1809 .3011 L
.18221 .30075 L
.18472 .29991 L
.18745 .29877 L
.19241 .2961 L
.20172 .28907 L
.21258 .27786 L
.22263 .26505 L
.2619 .20216 L
.29965 .14165 L
.32062 .11393 L
.33985 .09319 L
.3587 .07705 L
.37854 .06407 L
.39828 .05459 L
.41665 .04834 L
.42717 .0457 L
.43711 .04378 L
.44602 .04249 L
.45106 .04193 L
.45569 .04152 L
.46037 .04121 L
.46299 .04108 L
.46539 .04099 L
.46761 .04093 L
.46887 .04091 L
Mistroke
.47004 .04089 L
.47116 .04088 L
.47218 .04088 L
.47335 .04088 L
.47446 .04088 L
.47566 .0409 L
.47697 .04092 L
.47835 .04095 L
.47963 .04099 L
.48192 .04107 L
.48438 .04119 L
.48999 .04156 L
.4951 .04203 L
.50504 .04329 L
.51422 .0449 L
.5243 .04719 L
.53499 .05028 L
.5545 .05786 L
.5728 .06767 L
.59302 .08217 L
.61154 .09936 L
.65121 .14996 L
.68937 .21246 L
.71067 .24751 L
.72999 .27469 L
.73965 .28545 L
.74473 .29015 L
.75011 .29433 L
.75482 .29728 L
.75731 .29856 L
.75999 .29972 L
.76245 .30058 L
.76469 .30119 L
.76577 .30143 L
.76695 .30164 L
.76806 .3018 L
.76908 .30191 L
.77026 .30199 L
.77149 .30203 L
.77255 .30202 L
.77371 .30197 L
.77496 .30187 L
.77565 .30179 L
.77629 .3017 L
.77869 .30124 L
.78092 .30065 L
.78334 .29983 L
.78773 .29785 L
.79293 .29473 L
.79844 .29053 L
Mistroke
.80832 .28088 L
.82787 .25525 L
.84617 .22607 L
.88496 .1614 L
.90469 .13231 L
.92621 .10565 L
.94544 .08656 L
.96594 .0708 L
.97619 .06449 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{296.812, 98.9375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005c0000Nb000`400?l00000o`00003ooooooomd
ooooo`00oooooomdooooo`00J?ooool5o`0003Oooooo0_l000000ol@413oooooooooo`0cooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`0=Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<03?ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6Oooool006Sooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A00hooooo`03o`000?oooooooooo03Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0eoooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B40=Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06Oooool006Wooooo00?oV9RHob4Q8Oo^k^h0=_ooool5o`0003Gooooo00Go0000
ooooooooooooooooo`00000eooooo`05o`000?ooooooooooooooool00000=Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41006Oooool006[ooooo00?oV9RHob4Q8Oo^k^h0
=Oooool01?m4A4CogMgMooooool0000fooooo`05o`000?nHV9SooooooiRHV?lQ8B40=Oooool01Olb
<S;oV9RHoooooonHV9So<S8b03Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000001Wooooo001[ooooo`03ogMgMomVIVKooooo03Cooooo00CogMgMoeEEEOoooooo0000=_oo
ool01Ol0003oEEEEo`000?l@413oc<c<03Gooooo00Goc<c<o`000?l0003o0000olc<c00eooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Iooooo`00K?ooool00ol0003o
ooooooooo`0dooooo`03ogMgMoo<c<co000003Kooooo00?oEEEEohN7Qoooool0=oooool01Ol@413o
^[Zjoooooonj^[[o410@03Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@01Wooooo001Xooooo`05o`000?nj^[[ooooooiRHV?l@4100=_ooool00oo^k^koA4A4o`00000f
ooooo`03omgMgOl@413oV9RH03Oooooo00Go0000okZj^_oooooo^[Zjo`00000eooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`00J?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<03Oooooo00?oMgMgo`000?ooool0=_ooool01?o<c<coA4A4o`000?l@410eooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0<oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h06Oooool00?ooooooM?ooool00?ooooooM?ooool00?ooooooM?ooool00?ooooooM?oo
ool00?ooooooM?ooool002Woooooool0000do`0001Oooooo000`ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`00<?ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool07?ooool0033ooooo0_l0
003ooooood;ooooo000`ooooo`03o`000?oooooooooo0?oooooo@Oooool0033ooooo00?o0000oooo
ooooool0oooooom1ooooo`00<?ooool00ol0003oooooooooo`2>ooooo`?o0000Soooool3o`0001go
oooo000`ooooo`;o0000P?ooool3o`0000Kooooo3ooo0005ooooo`?o0000POooool2ool00003o`00
0?oooooooooo01_ooooo000`ooooo`03o`000?oooooooooo07kooooo2_oo0006ooooo`?o00001_oo
ool:ool007gooooo0_oo0003o`0001gooooo000`ooooo`03o`000?oooooooooo07_ooooo0ooo0000
1?oooooo0000o`000?l0000Jooooo`?o00000_ooool5ool007Kooooo0_oo000Rooooo`00<?ooool2
o`0007Sooooo1?oo000[ooooo`Goo`000ol0001[ooooo`?oo`009?ooool0033ooooo00?o0000oooo
ooooool0LOooool3o`0000?oo`00=?ooool3ool006Wooooo0_oo000Wooooo`00<?ooool00ol0003o
ooooooooo`1aooooo`?oo`004?ooool6o`00027ooooo0ol00003ool006Cooooo0_oo000Yooooo`00
<?ooool00ol0003oooooooooo`1`ooooo`04ool00?l0003o0000o`0000Oooooo2_l00004ooooo`[o
00007_ooool2ool005kooooo0_l00002ool002_ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`;o0000L?ooool00ooo
003oooooooooo`05ooooo`Co00006?ooool6o`0001[ooooo0ooo001Kooooo`;oo`0000?o0000oooo
ooooool0:_ooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo06gooooo0_oo0005ooooo`?o00008_ooool3o`00
01[ooooo0_oo001Hooooo`04ool00?l0003o0000o`0002cooooo000Eooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06cooooo00?oo`00
ooooooooool00_ooool3o`0002Sooooo0_l0000Jooooo`?oo`000_l0001Booooo`03ool00?oooooo
oooo02kooooo000Eooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04
ooooo`?o0000J_ooool2ool000?ooooo0_l0000]ooooo`;o00006_ooool00ol0003oo`00ool0001A
ooooo`03ool00?oooooooooo02oooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0JOooool01?oo003ooooooooo
ooooool2o`00037ooooo0_l0000Hooooo`?o00000_oo001=ooooo`;oo`00<_ooool001Gooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
J?ooool00ooo003oooooooooo`02o`0003Gooooo0_l0000Kooooo`03ool00?oooooooooo04Wooooo
00?oo`00ooooooooool0<_ooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Oooooo0_l0001Wooooo`;oo`0000?oooooo`000?l00000>Oooool00ol0003ooooo
ooooo`0Iooooo`;oo`00B?ooool00ooo003oooooooooo`0Cooooo`;o00007_ooool001Gooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`1Uooooo`04ool0
0?ooooooooooo`0003cooooo0_l0000Kooooo`;oo`00AOooool00ooo003oooooooooo`0Booooo`;o
00008?ooool0033ooooo00?o0000ooooooooool0H_ooool2o`000004ool00?oooooo0000o`0003oo
oooo00?o0000ooooooooool06_ooool2ool0047ooooo0_oo000Cooooo`;o00008_ooool0033ooooo
00?o0000ooooooooool0H_ooool01?l0003oo`00o`000?l00012ooooo`;o00007?ooool00ooo003o
ooooooooo`0mooooo`03ool00?oooooooooo01;ooooo00?o0000ooooooooool08_ooool0033ooooo
0_l0001Sooooo`?o0000AOooool00ol0003oooooooooo`0Jooooo`;oo`000_l0000jooooo`03ool0
0?oooooooooo017ooooo0_l0000Uooooo`00<?ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo04Kooooo0_l0000Kooooo`03o`000?oo003oo`0003Oooooo0_l000000ooo003ooooooooo
o`0Aooooo`03o`000?oooooooooo02Gooooo000`ooooo`03o`000?oooooooooo063ooooo0_l0001;
ooooo`03o`000?oooooooooo01Sooooo0ol000000ooo003oooooooooo`0dooooo`;oo`0000?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`00<?ooool2o`00063ooooo00?o0000oooo
oooo0000C?ooool00ol0003oooooooooo`0Kooooo`;oo`00<oooool01?oo003o0000o`000?l0000A
ooooo`03o`000?oooooooooo02Oooooo000`ooooo`03o`000?oooooooooo05kooooo00?o0000oooo
oooo0000C_ooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo02oooooo00?oo`00oooo
ooooool04_ooool00ol0003oooooooooo`0Xooooo`00<?ooool00ol0003oooooooooo`1Nooooo`03
o`000?ooooooo`0004oooooo00?o0000ooooooooool07?ooool2ool002kooooo00?oo`00oooooooo
ool04_ooool00ol0003oooooooooo`0Yooooo`00<?ooool00ol0003oooooooooo`1Mooooo`03o`00
0?ooooooo`00057ooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`0Zooooo`03ool0
0?oooooooooo01;ooooo00?o0000ooooooooool0:_ooool002Kooooo1?l000000ol@413ooooooooo
o`03ooooo`;o0000GOooool00ol0003oooooool0001Booooo`03o`000?oooooooooo01kooooo0_oo
000Yooooo`03ool00?oooooooooo01;ooooo00?o0000ooooooooool0:oooool002Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`04o`000?ooooooooooool005?ooooo00?o
0000ooooooooool07oooool00ooo003oooooooooo`0Tooooo`;oo`005?ooool00ol0003ooooooooo
o`0/ooooo`00:?ooool00ol0003oooooooooo`04ooooo`?o0000Foooool01?l0003ooooooooooooo
001Eooooo`03o`000?oooooooooo01oooooo0_oo000Sooooo`03ool00?oooooooooo01Cooooo00?o
0000ooooooooool0;?ooool002Sooooo00?o0000ooooooooool01?ooool4o`0005Wooooo00Go0000
ooooooooooooooooool0001Fooooo`03o`000?oooooooooo023ooooo00?oo`00o`000?l000007ooo
ool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo02gooooo000Xooooo`03o`000?oooooo
oooo00Cooooo0ol0001Iooooo`05o`000?oooooooooooooooooo0000Eoooool00ol0003ooooooooo
o`0Pooooo`03o`000?oo003oo`0001kooooo00?oo`00ooooooooool05?ooool00ol0003ooooooooo
o`0^ooooo`00:?ooool00ol0003oooooooooo`05ooooo`;o0000FOooool01?l0003ooooooooooooo
001Iooooo`03o`000?oooooooooo01oooooo0ol00003ool001[ooooo00?oo`00ooooooooool05?oo
ool00ol0003oooooooooo`0_ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000Eoooool0
1Ol0003oooooooooooooooooo`0005[ooooo00?o0000ooooooooool09?ooool2ool001Gooooo0_l0
00000ooo003oooooooooo`0Eooooo`03o`000?oooooooooo02oooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00Co0000oooooooooooo0000EOooool01Ol0003oooooooooooooooooo`0005cooooo
00?o0000ooooooooool09Oooool2ool001;ooooo0ooo00000ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo033ooooo000`ooooo`05o`000?ooooooooooo`000?oo0000Doooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo05[ooooo00?o0000ooooooooool09oooool3ool000[ooooo
1Ooo00001?oooooo0000o`000?l0000Eooooo`03o`000?oooooooooo037ooooo000`ooooo`06o`00
0?ooooooooooooooool0003oo`00D_ooool01Ol0003oooooooooooooooooo`0005kooooo00?o0000
ooooooooool0:Oooool2ool000;o000000?oooooool00?oo00000ooo000Mooooo`03o`000?oooooo
oooo03;ooooo000`ooooo`;o00000oooool00ol0003oo`00ooooo`1?ooooo`05o`000?oooooooooo
oooooooo0000H?ooool00ol0003oooooooooo`0Yooooo`04o`000?oo003oo`00ool002;ooooo00?o
0000ooooooooool0<_ooool0033ooooo00?o0000ooooooooool00oooool00ol0003oo`00ooooo`1=
ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0Goooool00ol0003oooooooooo`0X
ooooo`?o00008_ooool00ol0003oooooooooo`0cooooo`00<?ooool00ol0003oooooooooo`03oooo
o`03o`000?ooooooo`0004cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1Poooo
o`03o`000?oooooooooo04cooooo00?o0000ooooooooool0=?ooool0033ooooo0_l00005ooooo`03
o`000?oo003ooooo04_ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1Qooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool0=?ooool0033ooooo00?o0000ooooooooool0
1Oooool00ol0003oo`00ooooo`19ooooo`03o`000?oooooooooo00;o000000?oo`00ooooooooool0
Hoooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Gooooo000`ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ool00?ooool0Aoooool01ol0003ooooooooooooooooo0000ool00?l0
0000I_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Kooooo000`ooooo`03o`00
0?oooooooooo00Kooooo00?o0000oooooooo0000Aoooool01ol0003ooooooooooooooooo0000ool0
0?l00000I_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Kooooo000Fooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`;o00002?ooool00ol0003oooooool00015ooooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
ooooool0Ioooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Oooooo000Hooooo`03
o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooool00014ooooo`03o`000?oooooooooo00;ooooo00?oo`00oooooooo
ool0J?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03Sooooo000Hooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`00
0?ooooooo`0000;o0000@?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo06Wooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0hooooo`006?ooool00ol0003ooooooooo
o`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00009ooooo`05o`000?oooooo0000ool00?l00000
?oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo06[ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`0iooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0:ooooo`;o000000?oo`00o`000?ooool0
?_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo06_ooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`0jooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool01?l0003ooooooooooooo000nooooo`03o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0K?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo03[ooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool2o`0000cooooo00Co0000ooooooooooooo`00??ooool00ol0003oooooooooo`03ooooo`03ool0
0?oooooooooo06kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0kooooo`005_oo
ool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
ooooo`0003cooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1^ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0>oooool0033ooooo00?o0000ooooooooool03?ooool0
1?l0003ooooooooooooo000jooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0L?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000`ooooo`03o`000?oooooo
oooo00gooooo00Co0000ooooooooooooo`00>?ooool00ol0003oooooooooo`04ooooo`03ool00?oo
oooooooo077ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0mooooo`00<?ooool2
o`0000kooooo00Co0000ooooooooooooo`00>?ooool00ol0003oooooooooo`03ooooo`03ool00?oo
oooooooo07;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0mooooo`00<?ooool0
0ol0003oooooooooo`0>ooooo`04o`000?ooooooooooool003Kooooo00?o0000ooooooooool01?oo
ool00ooo003oooooooooo`1cooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0?_oo
ool0033ooooo00?o0000ooooooooool03oooool00ol0003oooooool0000fooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool0MOooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03kooooo000`ooooo`;o00004?ooool01?l0003ooooooooooooo000dooooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool0MOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo03oooooo000`ooooo`03o`000?oooooooooo013ooooo00Co0000ooooooooooooo`00<_ooool0
0ol0003oooooooooo`04ooooo`03ool00?oooooooooo07Oooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`10ooooo`00<?ooool00ol0003oooooooooo`0@ooooo`04o`000?oooooooooo
ool003;ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`1gooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0@?ooool0033ooooo0_l0000Booooo`04o`000?oooooooooo
ool0033ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`1iooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0@Oooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo
01;ooooo00Co0000ooooooooooooo`00;_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooo
oooo07[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`11ooooo`009Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04_ooool01?l0003ooooooooooooo
000^ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0Noooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo04;ooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000
ooooooooool04oooool01?l0003ooooooooooooo000/ooooo`03o`000?oooooooooo00Gooooo00?o
o`00ooooooooool0O?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04?ooooo000W
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Cooooo`05o`000?oooooooooooooooooo0000:ooo
ool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo07gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`13ooooo`00:?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo01Cooooo00Co0000ooooooooooooo`00:_ooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo07kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`14ooooo`00:Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00Co0000ooooooooooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo07oooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`14ooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo0_l0
000Fooooo`04o`000?ooooooooooool002Sooooo00?o0000ooooooooool01Oooool00ooo003ooooo
ooooo`20ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0AOooool002Gooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo
o`000_l0000Tooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0P_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo04Kooooo000`ooooo`03o`000?oooooooooo01Kooooo
00Ko0000oooooooooooo0000ool00?l0000Sooooo`03o`000?oooooooooo00Kooooo00?oo`00oooo
ooooool0P_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Kooooo000`ooooo`03
o`000?oooooooooo01Oooooo00Go0000ooooool0003oo`00o`00000Sooooo`03o`000?oooooooooo
00Gooooo00?oo`00ooooooooool0Q?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
04Oooooo000`ooooo`;o00006Oooool01?l0003ooooooooooooo000Rooooo`03o`000?oooooooooo
00Cooooo0_l000000ooo003oooooooooo`24ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0B?ooool0033ooooo00?o0000ooooooooool06?ooool01Ol0003oooooooooooooooooo`00
023ooooo00?o0000ooooooooool01Oooool00ol0003oo`00o`000027ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0B?ooool0033ooooo00?o0000ooooooooool06Oooool01Ol0003o
ooooooooooooooooo`0001oooooo00?o0000ooooooooool01Oooool00ol0003oo`00o`000027oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0BOooool0033ooooo0_l0000Kooooo`04
o`000?ooooooooooool001kooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`28oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0B_ooool0033ooooo00?o0000oooooooo
ool06_ooool01Ol0003oooooooooooooooooo`0001gooooo00?o0000ooooooooool01Oooool00ooo
003oooooooooo`2:ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0B_ooool0033o
oooo00?o0000ooooooooool06oooool01Ol0003oooooooooooooooooo`0001_ooooo00?o0000oooo
ooooool01_ooool00ooo003oooooooooo`2;ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0Boooool0033ooooo0_l0000Mooooo`05o`000?oooooooooooooooooo00006Oooool00ol0
003oooooooooo`06ooooo`03ool00?oooooooooo08cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`1<ooooo`005Oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0Looooo`05o`000?oooooooooooooooooo00006Oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo08kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1=ooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooo
ooooo`0001Oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`2@ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0COooool001Kooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooool0
000Eooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0TOooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04kooooo000Gooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0001oooooo00Go0000ooooooooooooooooool0000Cooooo`03o`000?oo
oooooooo00Kooooo00?oo`00ooooooooool0Toooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo04oooooo000Hooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo023ooooo00Co0000ooooooooooooo`004_ooool00ol0003ooooo
ooooo`06ooooo`03ool00?oooooooooo09Gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`1@ooooo`006Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08Oooool01?l0003ooooooooooooo000@ooooo`03o`000?oooooooooo00Oooooo
00?oo`00ooooooooool0U_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo057ooooo
000Eooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`;o0000
8oooool01?l0003ooooooooooooo000=ooooo`;o00002Oooool00ooo003oooooooooo`2Hooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0D_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`Co00001_ooool00ol0003oooooooooo`0Sooooo`;o000000?oooooool00?oo
ool02_ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo09[ooooo00?o0000oooooooo
ool03?ooool2o`0005Gooooo000`ooooo`03o`000?oooooooooo02Gooooo00?o0000ool00?ooool0
2?ooool2o`0000_ooooo00?oo`00ooooooooool0Voooool2o`0000_ooooo00?o0000ooooooooool0
EOooool0033ooooo00?o0000ooooooooool09_ooool2o`0000Oooooo00?o0000ooooooooool02_oo
ool00ooo003oooooooooo`2Nooooo`;o00002?ooool00ol0003oooooooooo`1Fooooo`00<?ooool2
o`0002Wooooo2?l0000;ooooo`03ool00?oooooooooo0:3ooooo2Ol0001Iooooo`00<?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oo003oo`0000;oo`003Oooool00ooo003oooooooooo`3ooooo
o`Cooooo000`ooooo`03o`000?oooooooooo02Sooooo0ol00002ooooo`Goo`002?ooool00ooo003o
ooooooooo`3oooooo`Cooooo000`ooooo`;o0000<oooool5ool000;o000000?oo`00ooooooooool0
ooooool5ooooo`00<?ooool00ol0003oooooooooo`0gooooo`;oo`0000?o0000ooooooooool0oooo
ool5ooooo`00<?ooool00ol0003oooooooooo`0gooooo`?o0000ooooool7ooooo`00<?ooool2o`00
0?oooooo@_ooool002Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Xooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooood7ooooo000Wooooo`03oa0@4?l0
003o^[Zj0?ooooooB_ooool002Sooooo00?o^[Zjob4Q8Oooool0oooooom9ooooo`009Oooool01Ol@
413oV9RHoooooonj^[[o00000?ooooooB_ooool002Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3o
oooood[ooooo003oooooogCooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 373.688}, {233.312, 135.375}} -> {-5.03342, \
4.54587, 0.0430052, 0.0368616}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Make it yours: User defined procedures", "Subsubsection"],
  " "
}], "Text"],

Cell[TextData[{
  "Examination of the input that creates a Table of Euler approximation \
points shows that it requires the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  ", the initial values t0 and y0, the step size ",
  StyleBox["h",
    FontSlant->"Italic"],
  ", and the number ",
  StyleBox["N",
    FontSlant->"Italic"],
  " of points that are to be generated. In other words, the process can be \
regarded as a function (or \"procedure\") that transforms the input ",
  StyleBox["f",
    FontSlant->"Italic"],
  ", t0, y0, ",
  StyleBox["h",
    FontSlant->"Italic"],
  ", ",
  StyleBox["N",
    FontSlant->"Italic"],
  " into a list of approximation points.  \nThe following input makes this \
process into a user defined ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function with the name euler. It is defined  to take ",
  StyleBox["f",
    FontSlant->"Italic"],
  ", t0, y0, ",
  StyleBox["h",
    FontSlant->"Italic"],
  ", ",
  StyleBox["N",
    FontSlant->"Italic"],
  " as input and output the approximation points in a list for easy plotting. \
The official name of the procedure is a \"module\" and requires the Module \
function to define. Each line in the following entry is explained below."
}], "Text"],

Cell["\<\
euler[f_,t0_,y0_,h_,N_] := 
Module[
        {T,Y}, 
        T[0] = t0; Y[0] = y0;
        T[n_] := T[n] = T[n-1] + h;
        Y[n_] := Y[n] = Y[n-1] + h*f[T[n-1],Y[n-1]];
        Table[ {T[n],Y[n]}, {n,0,N} ] 
      ]\
\>", "Input",
  CellLabel->"In[62]:=",
  FormatType->InputForm],

Cell["\<\
What is going on here? Answer: An explanation for each line appears \
below.
1. The first line names the procedure and identifies the input variables. \
Finish it with := .
2. The second line is the Module function and its opening left bracket.
3. The third line is a list of the local variables, T and Y, that will be \
used in the procedure. These variables work independently of their \
definitions in the Notebook and will cease to exist once the procedure is \
run.
4 - 7. These are the lines defining the procedure. You will recognize each \
one from the input that created the Euler approximation above. The last entry \
is the output for the procedure: The Table of approximation points.
8. Line 8 contains the right bracket signalling the end of the Module \
function (and the procedure definition).
Let's test the function named euler on the data that created the matrix of \
approximation points that is displayed following the first graph appearing \
above.\
\>", "Text"],

Cell[CellGroupData[{

Cell["euler[f,0,1,0.5,6]//MatrixForm", "Input",
  CellLabel->"In[161]:=",
  FormatType->InputForm],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1"},
            {"0.5`", "1.5`"},
            {"1.`", "2.1581869214177796`"},
            {"1.5`", "2.741223606486024`"},
            {"2.`", "2.8381768500201585`"},
            {"2.5`", "2.247627691171547`"},
            {"3.`", "1.3472914037172572`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[161]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "Cool. Now lets use euler to recreate the approximation for ",
  StyleBox["h",
    FontSlant->"Italic"],
  " = 0.5.",
  " "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
approx = euler[f,0,1,0.5,20];
pts = ListPlot[ approx, PlotStyle->PointSize[0.01], PlotRange->{0,3} ];
lines = ListPlot[ approx, PlotJoined->True, PlotStyle->RGBColor[1,0,0], 
                  PlotRange->{0,3} ];
Show[ pts, lines, Plot[ g[t], {t,0,10} ], AspectRatio->1/3, 
      PlotLabel\[Rule] \"h = 0.5\" ]\
\>", "Input",
  CellLabel->"In[83]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.111111 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .05556 -18 -4.5 ]
[.01131 .05556 0 4.5 ]
[.01131 .11111 -6 -4.5 ]
[.01131 .11111 0 4.5 ]
[.01131 .16667 -18 -4.5 ]
[.01131 .16667 0 4.5 ]
[.01131 .22222 -6 -4.5 ]
[.01131 .22222 0 4.5 ]
[.01131 .27778 -18 -4.5 ]
[.01131 .27778 0 4.5 ]
[.01131 .33333 -6 -4.5 ]
[.01131 .33333 0 4.5 ]
[.5 .34583 -23 0 ]
[.5 .34583 23 12 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .05556 m
.03006 .05556 L
s
[(0.5)] .01131 .05556 1 0 Mshowa
.02381 .11111 m
.03006 .11111 L
s
[(1)] .01131 .11111 1 0 Mshowa
.02381 .16667 m
.03006 .16667 L
s
[(1.5)] .01131 .16667 1 0 Mshowa
.02381 .22222 m
.03006 .22222 L
s
[(2)] .01131 .22222 1 0 Mshowa
.02381 .27778 m
.03006 .27778 L
s
[(2.5)] .01131 .27778 1 0 Mshowa
.02381 .33333 m
.03006 .33333 L
s
[(3)] .01131 .33333 1 0 Mshowa
.125 Mabswid
.02381 .01111 m
.02756 .01111 L
s
.02381 .02222 m
.02756 .02222 L
s
.02381 .03333 m
.02756 .03333 L
s
.02381 .04444 m
.02756 .04444 L
s
.02381 .06667 m
.02756 .06667 L
s
.02381 .07778 m
.02756 .07778 L
s
.02381 .08889 m
.02756 .08889 L
s
.02381 .1 m
.02756 .1 L
s
.02381 .12222 m
.02756 .12222 L
s
.02381 .13333 m
.02756 .13333 L
s
.02381 .14444 m
.02756 .14444 L
s
.02381 .15556 m
.02756 .15556 L
s
.02381 .17778 m
.02756 .17778 L
s
.02381 .18889 m
.02756 .18889 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .21111 m
.02756 .21111 L
s
.02381 .23333 m
.02756 .23333 L
s
.02381 .24444 m
.02756 .24444 L
s
.02381 .25556 m
.02756 .25556 L
s
.02381 .26667 m
.02756 .26667 L
s
.02381 .28889 m
.02756 .28889 L
s
.02381 .3 m
.02756 .3 L
s
.02381 .31111 m
.02756 .31111 L
s
.02381 .32222 m
.02756 .32222 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
gsave
.5 .34583 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(h) show
75.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.01 w
.02381 .11111 Mdot
.07143 .16667 Mdot
.11905 .2398 Mdot
.16667 .30458 Mdot
.21429 .31535 Mdot
.2619 .24974 Mdot
.30952 .1497 Mdot
.35714 .0756 Mdot
.40476 .0402 Mdot
.45238 .02706 Mdot
.5 .02421 Mdot
.54762 .02764 Mdot
.59524 .03744 Mdot
.64286 .05541 Mdot
.69048 .08247 Mdot
.7381 .11356 Mdot
.78571 .13324 Mdot
.83333 .12355 Mdot
.88095 .08636 Mdot
.92857 .04702 Mdot
.97619 .02357 Mdot
1 0 0 r
.5 Mabswid
.02381 .11111 m
.07143 .16667 L
.11905 .2398 L
.16667 .30458 L
.21429 .31535 L
.2619 .24974 L
.30952 .1497 L
.35714 .0756 L
.40476 .0402 L
.45238 .02706 L
.5 .02421 L
.54762 .02764 L
.59524 .03744 L
.64286 .05541 L
.69048 .08247 L
.7381 .11356 L
.78571 .13324 L
.83333 .12355 L
.88095 .08636 L
.92857 .04702 L
.97619 .02357 L
s
0 g
.02381 .11111 m
.06244 .16487 L
.10458 .23523 L
.12507 .26625 L
.13506 .27882 L
.14415 .28822 L
.14868 .29208 L
.1536 .29559 L
.15825 .29824 L
.16254 .30007 L
.16488 .30082 L
.16708 .30137 L
.16834 .3016 L
.16949 .30178 L
.17013 .30185 L
.17082 .30192 L
.17209 .302 L
.17277 .30202 L
.17342 .30203 L
.17463 .30201 L
.17593 .30193 L
.17666 .30186 L
.17734 .30177 L
.1797 .30137 L
.1809 .3011 L
.18221 .30075 L
.18472 .29991 L
.18745 .29877 L
.19241 .2961 L
.20172 .28907 L
.21258 .27786 L
.22263 .26505 L
.2619 .20216 L
.29965 .14165 L
.32062 .11393 L
.33985 .09319 L
.3587 .07705 L
.37854 .06407 L
.39828 .05459 L
.41665 .04834 L
.42717 .0457 L
.43711 .04378 L
.44602 .04249 L
.45106 .04193 L
.45569 .04152 L
.46037 .04121 L
.46299 .04108 L
.46539 .04099 L
.46761 .04093 L
.46887 .04091 L
Mistroke
.47004 .04089 L
.47116 .04088 L
.47218 .04088 L
.47335 .04088 L
.47446 .04088 L
.47566 .0409 L
.47697 .04092 L
.47835 .04095 L
.47963 .04099 L
.48192 .04107 L
.48438 .04119 L
.48999 .04156 L
.4951 .04203 L
.50504 .04329 L
.51422 .0449 L
.5243 .04719 L
.53499 .05028 L
.5545 .05786 L
.5728 .06767 L
.59302 .08217 L
.61154 .09936 L
.65121 .14996 L
.68937 .21246 L
.71067 .24751 L
.72999 .27469 L
.73965 .28545 L
.74473 .29015 L
.75011 .29433 L
.75482 .29728 L
.75731 .29856 L
.75999 .29972 L
.76245 .30058 L
.76469 .30119 L
.76577 .30143 L
.76695 .30164 L
.76806 .3018 L
.76908 .30191 L
.77026 .30199 L
.77149 .30203 L
.77255 .30202 L
.77371 .30197 L
.77496 .30187 L
.77565 .30179 L
.77629 .3017 L
.77869 .30124 L
.78092 .30065 L
.78334 .29983 L
.78773 .29785 L
.79293 .29473 L
.79844 .29053 L
Mistroke
.80832 .28088 L
.82787 .25525 L
.84617 .22607 L
.88496 .1614 L
.90469 .13231 L
.92621 .10565 L
.94544 .08656 L
.96594 .0708 L
.97619 .06449 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[83]:=",
  ImageSize->{250, 83.3125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004h0000J2000`400?l00000o`00003oooooooli
ooooo`00ooooooliooooo`00ooooooliooooo`00I?ooool5o`0002Kooooo0_l000000ol@413ooooo
ooooo`0Rooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
027ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool006Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00Wooooo`03o`000?oooooooooo02?ooooo00GoEEEEogMgMooooooo
V9RHob4Q8@0Sooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0:?ooool006Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5o`00
02Cooooo00Go0000ooooooooooooooooo`00000Sooooo`05o`000?ooooooooooooooool000008ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?ooool006Kooooo00?o
V9RHob4Q8Oo^k^h09?ooool01?m4A4CogMgMooooool0000Uooooo`05o`000?nHV9SooooooiRHV?lQ
8B408oooool01Olb<S;oV9RHoooooonHV9So<S8b02?ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000002Sooooo001Wooooo`03ogMgMomVIVKooooo02?ooooo00CogMgMoeEE
EOoooooo00009Oooool01Ol0003oEEEEo`000?l@413oc<c<02?ooooo00Goc<c<o`000?l0003o0000
olc<c00Sooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`00
J?ooool00ol0003oooooooooo`0Sooooo`03ogMgMoo<c<co000002Gooooo00?oEEEEohN7Qoooool0
9Oooool01Ol@413o^[Zjoooooonj^[[o410@02?ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@02Sooooo001Tooooo`05o`000?nj^[[ooooooiRHV?l@41009Oooool00oo^
k^koA4A4o`00000Uooooo`03omgMgOl@413oV9RH02Gooooo00Go0000okZj^_oooooo^[Zjo`00000S
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Xooooo`00I?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<02Kooooo00?oMgMgo`000?ooool09Oooool01?o<c<coA4A4o`00
0?l@410Sooooo`05ojVYZOl@413o0000oa0@4?nYZJT08Oooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0:?ooool00?oooooo>Oooool00?oooooo>Oooool00?oooooo>Ooo
ool003Woooooeol0000Xooooo`00?_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0:oooool003kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02_ooooo000nooooo`;o0000n?ooool003kooooo00?o
0000ooooooooool0moooool003kooooo0_l0001Oooooo`_oo`00Goooool2ool00003o`000?oooooo
oooo02[ooooo000nooooo`03o`000?oooooooooo05Oooooo1ooo0005ooooo`;o00001?ooool8ool0
05Gooooo0_oo00000ooooooo0000o`00000/ooooo`00?_ooool2o`0005Gooooo0ooo00000ooooooo
0000o`00000Cooooo`;o00000_ooool5ool004kooooo0_oo000aooooo`00?_ooool00ol0003ooooo
ooooo`1>ooooo`;o000000Coooooool00?oo003oo`008_ooool4ool004Sooooo0_oo000cooooo`00
?_ooool00ol0003oooooooooo`1>ooooo`?oo`001_ooool=o`0001?ooooo0_l000001?ooooooo`00
ool00?oo0013ooooo`;oo`00=Oooool002Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l0001>ooooo`03ool00?oooooooooo
00;ooooo1Ol0000=ooooo`Oo00004_ooool2ool003oooooo0_oo000gooooo`009?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0C?ooool00ooo003oooooooooo`03o`0001Wooooo0_l0000Booooo`?oo`00>oooool00ooo
003o0000o`00000gooooo`009?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00_ooool2o`0004_ooooo0_oo0003o`0001kooooo0_l0000Booooo`03o`000?oo003oo`00
03Sooooo00?oo`00ooooooooool0>?ooool002Cooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0BOooool00ooo003o0000o`00000Soooo
o`;o00004?ooool2o`000003oooooooo003oo`0003Gooooo00?oo`00ooooooooool0>Oooool002Co
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`17ooooo`03ool00?l0003o000002Oooooo0_l0000Cooooo`03ool00?oooooo
oooo037ooooo00?oo`00ooooooooool02oooool2o`0002gooooo000Tooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o0000Aoooool00ooo003o0000ooooo`0Z
ooooo`;o00004_ooool2ool0033ooooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0]
ooooo`009?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`14ooooo`03o`000?oo003o000002kooooo00?o0000ooooooooool04Oooool2
ool002gooooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0^ooooo`009?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`;o0000AOooool2o`00033ooooo00?o0000
ooooooooool04_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00_ooooo00?o0000
ooooooooool0;oooool003kooooo00?o0000ooooooooool0@oooool00ol0003oo`00ooooo`0aoooo
o`03o`000?oooooooooo017ooooo00?o0000ool00?oo00009_ooool2o`000003ool00?oooooooooo
00_ooooo00?o0000ooooooooool0<?ooool003kooooo0_l00013ooooo`03o`000?oo003ooooo03?o
oooo00?o0000ooooooooool04?ooool2o`000003oooooooo003ooooo02Cooooo0_oo000=ooooo`03
o`000?oooooooooo037ooooo000nooooo`03o`000?oooooooooo047ooooo00?o0000ool00?ooool0
=Oooool00ol0003oooooooooo`0Cooooo`;oo`008_ooool00ooo003oooooooooo`0<ooooo`03o`00
0?oooooooooo03;ooooo000nooooo`03o`000?oooooooooo047ooooo00?o0000ool00?ooool0=_oo
ool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool03?oo
ool00ol0003oooooooooo`0cooooo`00=Oooool4o`000003oa0@4?oooooooooo00;ooooo0_l00011
ooooo`03o`000?oo003ooooo03Sooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0L
ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0=?ooool003Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oo003ooooo03Wooooo00?o0000oooo
ooooool05Oooool2ool001[ooooo0_oo000>ooooo`03o`000?oooooooooo03Gooooo000gooooo`03
o`000?oooooooooo00?ooooo0ol0000oooooo`03o`000?ooooooo`0003_ooooo00?o0000oooooooo
ool05_ooool00ooo003o0000o`00000Fooooo`03ool00?oooooooooo00kooooo00?o0000oooooooo
ool0=Oooool003Oooooo00?o0000ooooooooool00oooool2o`0003oooooo00?o0000oooooooo0000
?Oooool00ol0003oooooooooo`0Fooooo`;oo`005Oooool00ooo003oooooooooo`0>ooooo`03o`00
0?oooooooooo03Kooooo000gooooo`03o`000?oooooooooo00Cooooo0_l0000nooooo`03o`000?oo
003ooooo03kooooo00?o0000ooooooooool05oooool3ool000oooooo0_l000000ooo003ooooooooo
o`0>ooooo`03o`000?oooooooooo03Oooooo000gooooo`03o`000?oooooooooo00Cooooo0ol0000l
ooooo`03o`000?ooooooo`00043ooooo00?o0000ooooooooool06Oooool2ool000_ooooo1?oo000@
ooooo`03o`000?oooooooooo03Sooooo000gooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
ool0003oo`00>_ooool00ol0003oooooool00012ooooo`03o`000?oooooooooo01[ooooo0ooo0002
o`000003oooooooo003oo`0000?oo`004oooool00ol0003oooooooooo`0iooooo`00=Oooool00omE
EEGoIVIVo`000006ooooo`;o000000?oooooo`000?oo0000>?ooool00ol0003oooooool00014oooo
o`03o`000?oooooooooo01cooooo0ooo000Gooooo`03o`000?oooooooooo03[ooooo000nooooo`06
o`000?ooooooooooooooool0003oo`00=_ooool01?l0003ooooooooooooo0015ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0>_ooool003kooooo0_l00002ooooo`03o`000?oo003o
oooo03Cooooo00Co0000ooooooooooooo`00Aoooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo03_ooooo000nooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?ooool0<oooool0
1?l0003oooooool00?l00018ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0??oo
ool003kooooo00?o0000ooooooooool00oooool00ol0003oo`00ooooo`0aooooo`05o`000?oooooo
ooooool00?l00000B?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo000U
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@04ooooo`;o00001?ooool00ol0003oooooool0000`ooooo`04o`000?ooooooooooool004_ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0mooooo`009oooool00ol0003ooooooooo
o`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000oooooooo0000;oooool01?l0003ooooooooooooo001;ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0?_ooool002Oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`;o00001_ooool01?l0003oooooool00?l0000/ooooo`04o`000?ooooooooooool004go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0nooooo`009oooool00ol0003ooooo
ooooo`0>ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ool00?l0000/ooooo`04o`000?ooooooooooool004kooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0oooooo`009oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool2o`0000Oooooo00?o0000oooooooo0000:oooool01?l0003ooooooooooooo001?
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0@?ooool002Oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
oooo0000:Oooool01Ol0003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`10ooooo`009oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooool0000Yooooo`05o`000?oooooooooo
oooooooo0000D?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo047ooooo000Uoooo
o`03oeEEEOmVIVKo000000gooooo1?l00005ooooo`;o00002Oooool00ol0003oooooool0000Woooo
o`05o`000?oooooooooooooooooo0000D_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04;ooooo000nooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo00009oooool01Ol0
003oooooooooooooooooo`0005;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`12
ooooo`00?_ooool2o`0000[ooooo00?o0000oooooooo00009Oooool01Ol0003ooooooooooooooooo
o`0005Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`13ooooo`00?_ooool00ol0
003oooooooooo`0:ooooo`03o`000?ooooooo`0002?ooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`1Cooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@oooool003Co
oooo1Ol00005ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo00008oooool01Ol0003o
ooooooooooooooooo`0005Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`14oooo
o`00=?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_l0000<ooooo`03o`000?ooooooo`00
027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0AOooool003Gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`0;ooooo`04o`000?ooooooooooool001oooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`1Fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0AOooool003Ko
oooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0000gooooo00?o0000oooooooo00007oooool00ol0003o
ooooooooo`02ooooo`03ool00?oooooooooo05Oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`16ooooo`00=oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00gooooo
00?o0000oooooooo00007Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo05Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`17ooooo`00>?ooool00ol0003ooooooooo
o`03ooooo`;o00003_ooool00ol0003oooooool0000Mooooo`03o`000?oooooooooo00;ooooo00?o
o`00ooooooooool0FOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Oooooo000d
ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
ooooo`0000;o00006Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`18ooooo`00=?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Gooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooo003o000001Sooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0BOooool003kooooo0_l0000@ooooo`03o`000?ooooooo`0001Wooooo00Co
0000oooooooooooooooo0_l000000ooo003oooooooooo`1Looooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0BOooool003kooooo00?o0000ooooooooool04?ooool00ol0003oooooool0
000Gooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?ooool0G_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04[ooooo000nooooo`;o00004_ooool00ol0003oooooool0000F
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04_ooooo000nooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
oooo00005?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo063ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1;ooooo`009?ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Cooooo`03o`000?ooooooo`00
01;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0C?ooool002Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`;o00005?ooool00ol0003oooooool0000Aoooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0Hoooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo04gooooo000Uooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?ooooooo`0000oooooo00?o0000oooooooo
ool01?ooool00ooo003oooooooooo`1Tooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0COooool002Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`;o0000
5_ooool00ol0003oooooool0000=ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0
I_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo000Wooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01Kooooo
00?o0000oooooooo00002oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo06Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1?ooooo`00:?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo0_l0000Hooooo`03o`000?oo003ooooo00Wooooo00?o
0000ooooooooool01Oooool00ooo003oooooooooo`1Yooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0D?ooool002Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oo`00ooooo`07ooooo`03o`000?oo
oooooooo00Gooooo00?oo`00ooooooooool0Joooool2o`0000Wooooo00?o0000ooooooooool0DOoo
ool002Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Oooool00ol0003ooooooooo
o`0Iooooo`;o00001Oooool2o`0000Oooooo00?oo`00ooooooooool0K_ooool00ol0003ooooooooo
o`04ooooo`;o0000E?ooool003kooooo0_l0000Looooo`Go00002?ooool00ooo003oooooooooo`1`
ooooo`Ko0000E_ooool003kooooo00?o0000ooooooooool06oooool00ol0003oo`00ool00002ool0
00Sooooo00?oo`00ooooooooool0c?ooool003kooooo0_l0000Qooooo`Goo`000_ooool00ooo003o
ooooooooo`3=ooooo`00?_ooool00ol0003oooooooooo`0Uooooo`;oo`00d?ooool003Cooooo00Go
V9RHoa0@4?l0003o<S8bolc<c005ooooo`;o00009_ooool2o`000=3ooooo000dooooo`05oa0@4?nj
^[[oooooogMgMolb<S801Oooool00ol0003oooooooooo`3gooooo`00>?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?Oooooo000gooooo`03ojVYZOl@413ooooo00Cooooo0_l0003h
ooooo`00=_ooool00ol@413o0000okZj^P3oooooo`00=oooool00onj^[[o8B4Qooooo`3nooooo`00
=?ooool01Ol@413oV9RHoooooonj^[[o00000?oooooo000dooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT0ooooool00?oooooo>Oooool00?oooooo>Oooool008_ooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`0Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@1iooooo`00S?ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool0N?ooool008cooooo00Go0000ooooooooooooooooo`00000Hooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`1gooooo`00S?ooool01Ol0003ooooooooooooooooo
000000Wooooo1_l00009ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`1hooooo`00S?ooool01Ol0003oMgMgoooooonYZJWo000001Sooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0NOooool008cooooo00Go0000ogMgMol0003o
0000oiRHV00Hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`1koooo
o`00S?ooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`1kooooo`00S?ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0007[ooooo002;ooooo`03oa0@4?l0003ooooo0:[ooooo003oooooocWooooo
003oooooocWooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 326.875}, {413.688, 331.375}} -> {-7.85276, \
16.8442, 0.061366, 0.0525995}}]
}, Open  ]],

Cell[TextData[{
  "And here is the plot",
  " for the approximation when ",
  StyleBox["h",
    FontSlant->"Italic"],
  " = 0.25. In order to get to ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 10, ",
  StyleBox["N",
    FontSlant->"Italic"],
  " = 40"
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
approx = euler[f,0,1,0.25,40];
pts = ListPlot[ approx, PlotStyle->PointSize[0.01], PlotRange->{0,3} ];
lines = ListPlot[ approx, PlotJoined->True, PlotStyle->RGBColor[1,0,0],
                  PlotRange->{0,3} ];
Show[ pts, lines, Plot[ g[t], {t,0,10} ], AspectRatio->1/3, 
      PlotLabel\[Rule] \"h = 0.25\" ]\
\>", "Input",
  CellLabel->"In[87]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.111111 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .05556 -18 -4.5 ]
[.01131 .05556 0 4.5 ]
[.01131 .11111 -6 -4.5 ]
[.01131 .11111 0 4.5 ]
[.01131 .16667 -18 -4.5 ]
[.01131 .16667 0 4.5 ]
[.01131 .22222 -6 -4.5 ]
[.01131 .22222 0 4.5 ]
[.01131 .27778 -18 -4.5 ]
[.01131 .27778 0 4.5 ]
[.01131 .33333 -6 -4.5 ]
[.01131 .33333 0 4.5 ]
[.5 .34583 -26 0 ]
[.5 .34583 26 12 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .05556 m
.03006 .05556 L
s
[(0.5)] .01131 .05556 1 0 Mshowa
.02381 .11111 m
.03006 .11111 L
s
[(1)] .01131 .11111 1 0 Mshowa
.02381 .16667 m
.03006 .16667 L
s
[(1.5)] .01131 .16667 1 0 Mshowa
.02381 .22222 m
.03006 .22222 L
s
[(2)] .01131 .22222 1 0 Mshowa
.02381 .27778 m
.03006 .27778 L
s
[(2.5)] .01131 .27778 1 0 Mshowa
.02381 .33333 m
.03006 .33333 L
s
[(3)] .01131 .33333 1 0 Mshowa
.125 Mabswid
.02381 .01111 m
.02756 .01111 L
s
.02381 .02222 m
.02756 .02222 L
s
.02381 .03333 m
.02756 .03333 L
s
.02381 .04444 m
.02756 .04444 L
s
.02381 .06667 m
.02756 .06667 L
s
.02381 .07778 m
.02756 .07778 L
s
.02381 .08889 m
.02756 .08889 L
s
.02381 .1 m
.02756 .1 L
s
.02381 .12222 m
.02756 .12222 L
s
.02381 .13333 m
.02756 .13333 L
s
.02381 .14444 m
.02756 .14444 L
s
.02381 .15556 m
.02756 .15556 L
s
.02381 .17778 m
.02756 .17778 L
s
.02381 .18889 m
.02756 .18889 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .21111 m
.02756 .21111 L
s
.02381 .23333 m
.02756 .23333 L
s
.02381 .24444 m
.02756 .24444 L
s
.02381 .25556 m
.02756 .25556 L
s
.02381 .26667 m
.02756 .26667 L
s
.02381 .28889 m
.02756 .28889 L
s
.02381 .3 m
.02756 .3 L
s
.02381 .31111 m
.02756 .31111 L
s
.02381 .32222 m
.02756 .32222 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
gsave
.5 .34583 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(h) show
75.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.01 w
.02381 .11111 Mdot
.04762 .13889 Mdot
.07143 .17253 Mdot
.09524 .21038 Mdot
.11905 .24887 Mdot
.14286 .28248 Mdot
.16667 .30475 Mdot
.19048 .31014 Mdot
.21429 .29632 Mdot
.2381 .26549 Mdot
.2619 .2238 Mdot
.28571 .17898 Mdot
.30952 .13762 Mdot
.33333 .10356 Mdot
.35714 .07782 Mdot
.38095 .0596 Mdot
.40476 .04738 Mdot
.42857 .03963 Mdot
.45238 .03521 Mdot
.47619 .03336 Mdot
.5 .03367 Mdot
.52381 .03606 Mdot
.54762 .04068 Mdot
.57143 .04788 Mdot
.59524 .05819 Mdot
.61905 .07216 Mdot
.64286 .09019 Mdot
.66667 .11221 Mdot
.69048 .13726 Mdot
.71429 .16313 Mdot
.7381 .18629 Mdot
.7619 .20243 Mdot
.78571 .20769 Mdot
.80952 .20013 Mdot
.83333 .18083 Mdot
.85714 .15362 Mdot
.88095 .12363 Mdot
.90476 .09547 Mdot
.92857 .07196 Mdot
.95238 .05402 Mdot
.97619 .04123 Mdot
1 0 0 r
.5 Mabswid
.02381 .11111 m
.04762 .13889 L
.07143 .17253 L
.09524 .21038 L
.11905 .24887 L
.14286 .28248 L
.16667 .30475 L
.19048 .31014 L
.21429 .29632 L
.2381 .26549 L
.2619 .2238 L
.28571 .17898 L
.30952 .13762 L
.33333 .10356 L
.35714 .07782 L
.38095 .0596 L
.40476 .04738 L
.42857 .03963 L
.45238 .03521 L
.47619 .03336 L
.5 .03367 L
.52381 .03606 L
.54762 .04068 L
.57143 .04788 L
.59524 .05819 L
.61905 .07216 L
.64286 .09019 L
.66667 .11221 L
.69048 .13726 L
.71429 .16313 L
.7381 .18629 L
.7619 .20243 L
.78571 .20769 L
.80952 .20013 L
.83333 .18083 L
.85714 .15362 L
.88095 .12363 L
.90476 .09547 L
.92857 .07196 L
.95238 .05402 L
.97619 .04123 L
s
0 g
.02381 .11111 m
.06244 .16487 L
.10458 .23523 L
.12507 .26625 L
.13506 .27882 L
.14415 .28822 L
.14868 .29208 L
.1536 .29559 L
.15825 .29824 L
.16254 .30007 L
.16488 .30082 L
.16708 .30137 L
.16834 .3016 L
.16949 .30178 L
.17013 .30185 L
.17082 .30192 L
.17209 .302 L
.17277 .30202 L
.17342 .30203 L
.17463 .30201 L
.17593 .30193 L
.17666 .30186 L
.17734 .30177 L
.1797 .30137 L
.1809 .3011 L
.18221 .30075 L
.18472 .29991 L
.18745 .29877 L
.19241 .2961 L
.20172 .28907 L
.21258 .27786 L
.22263 .26505 L
.2619 .20216 L
.29965 .14165 L
.32062 .11393 L
.33985 .09319 L
.3587 .07705 L
.37854 .06407 L
.39828 .05459 L
.41665 .04834 L
.42717 .0457 L
.43711 .04378 L
.44602 .04249 L
.45106 .04193 L
.45569 .04152 L
.46037 .04121 L
.46299 .04108 L
.46539 .04099 L
.46761 .04093 L
.46887 .04091 L
Mistroke
.47004 .04089 L
.47116 .04088 L
.47218 .04088 L
.47335 .04088 L
.47446 .04088 L
.47566 .0409 L
.47697 .04092 L
.47835 .04095 L
.47963 .04099 L
.48192 .04107 L
.48438 .04119 L
.48999 .04156 L
.4951 .04203 L
.50504 .04329 L
.51422 .0449 L
.5243 .04719 L
.53499 .05028 L
.5545 .05786 L
.5728 .06767 L
.59302 .08217 L
.61154 .09936 L
.65121 .14996 L
.68937 .21246 L
.71067 .24751 L
.72999 .27469 L
.73965 .28545 L
.74473 .29015 L
.75011 .29433 L
.75482 .29728 L
.75731 .29856 L
.75999 .29972 L
.76245 .30058 L
.76469 .30119 L
.76577 .30143 L
.76695 .30164 L
.76806 .3018 L
.76908 .30191 L
.77026 .30199 L
.77149 .30203 L
.77255 .30202 L
.77371 .30197 L
.77496 .30187 L
.77565 .30179 L
.77629 .3017 L
.77869 .30124 L
.78092 .30065 L
.78334 .29983 L
.78773 .29785 L
.79293 .29473 L
.79844 .29053 L
Mistroke
.80832 .28088 L
.82787 .25525 L
.84617 .22607 L
.88496 .1614 L
.90469 .13231 L
.92621 .10565 L
.94544 .08656 L
.96594 .0708 L
.97619 .06449 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[87]:=",
  ImageSize->{250, 83.3125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004h0000J2000`400?l00000o`00003oooooooli
ooooo`00ooooooliooooo`00ooooooliooooo`00I?ooool5o`0002Kooooo0_l000000ol@413ooooo
ooooo`0Rooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
027ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool006Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00Wooooo`03o`000?oooooooooo02?ooooo00GoEEEEogMgMooooooo
V9RHob4Q8@0Sooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0:?ooool006Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5o`00
02Cooooo00Go0000ooooooooooooooooo`00000Sooooo`05o`000?ooooooooooooooool000008ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?ooool006Kooooo00?o
V9RHob4Q8Oo^k^h09?ooool01?m4A4CogMgMooooool0000Uooooo`05o`000?nHV9SooooooiRHV?lQ
8B408oooool01Olb<S;oV9RHoooooonHV9So<S8b02?ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000002Sooooo001Wooooo`03ogMgMomVIVKooooo02?ooooo00CogMgMoeEE
EOoooooo00009Oooool01Ol0003oEEEEo`000?l@413oc<c<02?ooooo00Goc<c<o`000?l0003o0000
olc<c00Sooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`00
J?ooool00ol0003oooooooooo`0Sooooo`03ogMgMoo<c<co000002Gooooo00?oEEEEohN7Qoooool0
9Oooool01Ol@413o^[Zjoooooonj^[[o410@02?ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@02Sooooo001Tooooo`05o`000?nj^[[ooooooiRHV?l@41009Oooool00oo^
k^koA4A4o`00000Uooooo`03omgMgOl@413oV9RH02Gooooo00Go0000okZj^_oooooo^[Zjo`00000S
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Xooooo`00I?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<02Kooooo00?oMgMgo`000?ooool09Oooool01?o<c<coA4A4o`00
0?l@410Sooooo`05ojVYZOl@413o0000oa0@4?nYZJT08Oooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0:?ooool00?oooooo>Oooool00?oooooo>Oooool00?oooooo>Ooo
ool003Woooooeol0000Xooooo`00?_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0:oooool003kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02_ooooo000nooooo`;o0000n?ooool003kooooo00?o
0000ooooooooool0moooool003kooooo0_l0003hooooo`00?_ooool00ol0003oooooooooo`3goooo
o`00?_ooool2o`0005Wooooo0_l00002ooooo`Koo`0000?oooooo`000?l00000T_ooool003kooooo
00?o0000ooooooooool0Doooool2o`0000;ooooo1Ooo00000ooooooo0000o`000003ooooo`[oo`00
Roooool003kooooo00?o0000ooooooooool0D_ooool5ool000go00001?ooool2o`0000;ooooo0ooo
001Iooooo`;oo`0000?o0000ooooooooool0:_ooool002Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l0001?ooooo`Coo`00
1Ol0000=ooooo`Oo00000_ooool2o`0000?oo`000_l0001Booooo`;oo`0000?oooooo`000?l00000
;?ooool002Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo04cooooo0_oo0004o`0001Wooooo0_l00005ooooo`?oo`00
Coooool00ol0003oo`00ooooo`0`ooooo`009?ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00_ooool2o`0004cooooo00Coo`00o`000?l0003o00007_ooool2o`0000Ko
oooo0ooo00000ol0003oooooooooo`18ooooo`;oo`0000?o0000ooooooooool0;oooool002Cooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0BOooool00ooo003o0000o`00000Sooooo`;o00001_ooool00ol0003oo`00ool00018ooooo`03
ool00?oooooooooo03;ooooo000Tooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0B?ooool3o`0002Kooooo0_l00007oooo
o`;oo`00AOooool00ooo003oooooooooo`04ooooo`;o0000;Oooool002Cooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l00017ooooo`03ool00?l0003ooooo
02[ooooo0_l00007ooooo`03ool00?l0003ooooo03oooooo0_l000000ooo003oooooooooo`04oooo
o`03o`000?oooooooooo02gooooo000Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo04Gooooo00?oo`00o`000?ooool0;Oooool00ol0
003oooooooooo`04ooooo`03o`000?oo003oo`0003oooooo00?o0000ool00?ooool01Oooool00ol0
003oooooooooo`0^ooooo`009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005oooo
o`;o0000AOooool2o`00033ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0loooo
o`03ool00?oooooooooo00Cooooo00?o0000ooooooooool0;oooool003kooooo00?o0000oooooooo
ool0@oooool00ol0003oo`00o`00000aooooo`03o`000?oooooooooo00Kooooo00?oo`00oooooooo
ool0>_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo000nooooo`;o0000
@oooool00ol0003oo`00ooooo`0cooooo`03o`000?oooooooooo00Kooooo00?oo`00o`000?ooool0
>?ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo037ooooo000nooooo`03o`000?oo
oooooooo047ooooo00?o0000ool00?ooool0=Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
003oo`0003Gooooo0_l000000ooo003oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo000n
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07
ooooo`03ool00?oooooooooo03;ooooo00?o0000ool00?ooool01Oooool00ol0003oooooooooo`0c
ooooo`00=Oooool4o`000003oa0@4?oooooooooo00;ooooo0_l00010ooooo`;o0000>_ooool00ol0
003oooooooooo`07ooooo`03ool00?oooooooooo03;ooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`0dooooo`00=oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oo
oooo0_l0000jooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0<?ooool00ooo003o
ooooooooo`03ooooo`03o`000?oooooooooo03Gooooo000gooooo`03o`000?oooooooooo00?ooooo
0ol0000oooooo`03o`000?oo003ooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oo`00
ooooo`0_ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool0=Oooool003Oooooo00?o
0000ooooooooool00oooool2o`0003oooooo00?o0000ool00?ooool0?Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oo003ooooo02kooooo00?oo`00ooooooooool01?ooool00ol0003ooooooooo
o`0fooooo`00=oooool00ol0003oooooooooo`04ooooo`;o0000?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0:Oooool2o`000003ool00?oooooo
oooo00Cooooo00?o0000ooooooooool0=oooool003Oooooo00?o0000ooooooooool01?ooool3o`00
03cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo
02Sooooo00?o0000ool00?ooool01Oooool00ol0003oooooooooo`0hooooo`00=oooool00ol0003o
ooooooooo`04ooooo`04o`000?oooooo0000ool003[ooooo00?o0000ool00?ooool0@_ooool00ol0
003oooooooooo`07ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`0iooooo`00=Oooool00omEEEGoIVIVo`000006ooooo`;o000000?oooooo`000?oo
0000>?ooool00ol0003oo`00ooooo`14ooooo`03o`000?oooooooooo00Oooooo00?oo`00o`000?oo
ool09_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo03[ooooo000nooooo`06o`00
0?ooooooooooooooool0003oo`00=_ooool00ol0003oo`00o`000016ooooo`03o`000?oooooooooo
00Kooooo00?o0000ool00?ooool09Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo
03[ooooo000nooooo`;o00000_ooool00ol0003oo`00ooooo`0dooooo`03o`000?ooooooo`0004So
oooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0Rooooo`03ool00?oooooooooo00Co
oooo00?o0000ooooooooool0>oooool003kooooo00?o0000ooooooooool00_ooool00ol0003oo`00
ooooo`0cooooo`03o`000?oo003ooooo04Wooooo00?o0000ooooooooool01oooool00ooo003ooooo
ooooo`0Pooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool0??ooool003kooooo00?o
0000ooooooooool00oooool00ol0003oo`00ooooo`0aooooo`03o`000?ooooooo`0004[ooooo00?o
0000ooooooooool02?ooool00ooo003oooooooooo`0Mooooo`03o`000?oo003ooooo00Kooooo00?o
0000ooooooooool0??ooool002Gooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l00004ooooo`03o`000?ooooooo`00033ooooo00?o
0000oooooooo0000C?ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo01cooooo00?o
0000ool00?ooool01Oooool00ol0003oooooooooo`0mooooo`009oooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ool00?ooool0;oooool00ol0003oo`00ooooo`1<ooooo`03o`000?oooooooooo00Wooooo00?oo`00
o`000?ooool06oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo000Woooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ool0
0?ooool0;Oooool00ol0003oooooool0001>ooooo`03o`000?oooooooooo00Sooooo00?o0000ool0
0?ooool06_ooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo03kooooo000Wooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooo`00o`0002cooooo00?o0000ool00?ooool0Coooool00ol0003oooooooooo`09oooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`0ooooo
o`009oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`00
00Oooooo00?o0000ool00?l00000:oooool2o`000003ool00?oooooooooo04kooooo00?o0000oooo
ooooool02_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool0@?ooool002Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ool00?ooool0:Oooool01?l0003oooooool00?l0001Aoooo
o`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool04_ooool2ool000Sooooo00?o0000oooo
ooooool0@?ooool002Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000oooooooo0000:Oooool00ol0003oooooool0001Booooo`03
o`000?oooooooooo00_ooooo0_oo000Aooooo`03ool00?l0003o000000Oooooo00?o0000oooooooo
ool0@Oooool002Gooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo0_l00009ooooo`03o`00
0?oo003ooooo02Oooooo00?o0000oooooooo0000E?ooool00ol0003oooooooooo`0:ooooo`;o0000
00?oo`00ooooooooool03?ooool2ool000Wooooo00?o0000ooooooooool0@_ooool003kooooo00?o
0000ooooooooool02?ooool00ol0003oooooool0000Wooooo`03o`000?ooooooo`0005Cooooo00?o
0000ooooooooool03Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?o
0000ooooooooool0@_ooool003kooooo0_l0000:ooooo`03o`000?oo003ooooo02Gooooo00?o0000
oooooooo0000E_ooool00ol0003oooooooooo`0=ooooo`03ool00?l0003o000000Oooooo0_oo0000
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo04?ooooo000nooooo`03o`000?oooooooooo
00[ooooo00?o0000ool00?ooool08oooool00ol0003oooooool0001Hooooo`03o`000?oooooooooo
00gooooo1?oo00000ooooooo0000ool00002ool00003ooooool0003o000000[ooooo00?o0000oooo
ooooool0@oooool003Cooooo1Ol00005ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooo
003o00008_ooool00ol0003oooooool0001Hooooo`03o`000?oooooooooo017ooooo0_oo00000ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo04Cooooo000dooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01Oooool2o`0000cooooo00?o0000ool00?l000008Oooool00ol0003oooooool0001Joooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0AOooool003Gooooo00?oV9RHob4Q8Oo^
k^h01_ooool00ol0003oooooooooo`0;ooooo`03o`000?ooooooo`00023ooooo00Co0000oooooooo
ooooo`00F_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04Gooooo000fooooo`03
oiRHV?lQ8B7ok^k^00Gooooo0_l0000=ooooo`03o`000?oo003ooooo01oooooo0_l000000ooo003o
ooooooooo`1Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0A_ooool003Oooooo
00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo003ooooo01gooooo
00Co0000ooooool0003oo`00G?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Oo
oooo000hooooo`03o`000?oooooooooo00?ooooo0_l0000>ooooo`03o`000?ooooooo`0001gooooo
00?o0000oooooooo0000G_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Oooooo
000dooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oo003ooooo01_ooooo00Co0000ooooooooooooo`00Goooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo04Sooooo000dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?ooooooo`0001[ooooo00Co0000ooooooooooooo`00H?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo000nooooo`;o00004?ooool01?l0003o
o`00o`000?l0000Hooooo`03o`000?ooooooo`0006;ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`19ooooo`00?_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo003o000001Oo
oooo00Co0000ooooooooooooo`00H_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
04[ooooo000nooooo`;o00004_ooool00ol0003oooooooooo`0Fooooo`03o`000?ooooooo`0006Co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1;ooooo`00?_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01Cooooo00Co0000ooooooooooooo`00IOooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo04_ooooo000Tooooo`Go00001Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04_ooool01?l0003oooooo`000?oo001Vooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0C?ooool002Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`;o00005?ooool00ol0003oo`00ooooo`0Aooooo`05o`000?oooooooooo
o`000?oo0000Ioooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04gooooo000Uoooo
o`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooool0001Yooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0COooool002Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`03ooooo`;o00005_ooool3o`0000gooooo00Go0000ooooooooooooooooool0001[
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C_ooool002Oooooo00?oMgMgofIV
I_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05_ooool0
0ol0003oo`00ooooo`0;ooooo`05o`000?oooooooooooooooooo0000KOooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo04oooooo000Xooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01_ooool2o`0001Sooooo00?o0000ool00?ooool02Oooool00ol0003oooooooooo`02
ooooo`03ool00?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1@
ooooo`009?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oo003ooooo00Oooooo00?o0000ooooooooool00_l00000
0ooo003oooooooooo`1^ooooo`;o00002Oooool00ol0003oooooooooo`1Aooooo`009?ooool01OnH
V9So410@o`000?lQ8B7oc<c<00cooooo1?l00005ooooo`03o`000?oooooooooo01Wooooo0_l00005
ooooo`;o00000oooool2ool007?ooooo00?o0000ooooooooool01?ooool2o`0005Cooooo000noooo
o`;o00007?ooool5o`0000?ooooo0_oo001fooooo`Ko0000E_ooool003kooooo00?o0000oooooooo
ool06oooool00ol0003oo`00ool00002ool000;o000000?oo`00ooooooooool0d_ooool003kooooo
0_l0000Qooooo`;oo`00eOooool003kooooo00?o0000ooooooooool0moooool003Cooooo00GoV9RH
oa0@4?l0003o<S8bolc<c005ooooo`;o0000n?ooool003Cooooo00Go410@okZj^_ooooooMgMgoc8b
<P05ooooo`03o`000?oooooooooo0?Oooooo000hooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0moooool003Oooooo00?oZJVYoa0@4?ooool01?ooool2o`000?Sooooo000fooooo`03
oa0@4?l0003o^[Zj0?oooooo000gooooo`03okZj^_lQ8B7ooooo0?kooooo000dooooo`05oa0@4?nH
V9SooooookZj^_l00000ooooool003Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3oooooo`00oooo
ooliooooo`00ooooooliooooo`00Qoooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo01Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@1eooooo`00R?ooool01Ol0003ooooooooooooooooo000000Wooooo
1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo07Cooooo0028ooooo`05o`000?oooooooooooooo
ool000006?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`1cooooo`00R?ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo07Cooooo0028ooooo`05o`000?mgMgOoooooojVYZOl000006?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Go
oooo0028ooooo`05o`000?mgMgOo0000o`000?nHV9P06?ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1gooooo`00R?ooool00ol0003o
ooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool0Moooool008Sooooo00?o0000ooooooooool06_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000M_oo
ool008Oooooo00?o410@o`000?ooool0[_ooool00?oooooo>Oooool00?oooooo>Oooool00001\
\>"],
  ImageRangeCache->{{{77.875, 326.875}, {230.188, 147.875}} -> {-7.85276, \
7.19224, 0.061366, 0.0525995}}]
}, Open  ]],

Cell["\<\
Cutting the step size in half appears to have cut the error in half \
also. See Ledder, page 113. \
\>", "Text"],

Cell[TextData[{
  StyleBox["Modify it: The Euler two step algorithm",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell[TextData[{
  "The one step algorithm can be dramatically improved by making a very \
simple correction. Move from (",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ")  along the line with slope ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ") to the next Euler point (step one), use ",
  StyleBox["f",
    FontSlant->"Italic"],
  " to calculate the slope there, move  back to (",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "), calculate the average of the two slopes, and take a second (and last) \
step in the averaged direction. The algorithm looks like this: "
}], "Text"],

Cell[TextData[{
  StyleBox["t",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "] = ",
  StyleBox["t",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1] + ",
  StyleBox["h",
    FontSlant->"Italic"],
  "                                                         \n",
  StyleBox["k",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "] = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1] +",
  StyleBox["h ",
    FontSlant->"Italic"],
  " ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1],",
  StyleBox["y",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1])                                ",
  "\n",
  StyleBox["y",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "] = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1] + 0.5 ",
  StyleBox["h ",
    FontSlant->"Italic"],
  "(",
  " ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1], ",
  StyleBox["y",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1] + ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "],",
  StyleBox["k",
    FontSlant->"Italic"],
  "[",
  StyleBox["n",
    FontSlant->"Italic"],
  "]",
  " )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Ledder (pages 110-112) gives a clear explanation of why this \
algorithm is so much better. 
The Modified Euler algorithm is easily implemented in a procedure as follows. \
One more local variable is needed. \
\>", "Text"],

Cell["\<\
modeuler[f_,t0_,y0_,h_,N_] := 
Module[
        {T,K,Y}, 
        T[0] = t0; Y[0] = y0;
        T[n_] := T[n] = T[n-1] + h;
        K[n_] := K[n] = Y[n-1] + h*f[T[n-1],Y[n-1]];
        Y[n_] := Y[n] = Y[n-1] + 0.5*h*(f[T[n-1],Y[n-1]] + f[T[n],K[n]]);
        Table[ {T[n],Y[n]}, {n,0,N} ] 
      ]\
\>", "Input",
  CellLabel->"In[91]:="],

Cell["\<\
The next two plots show that modeuler works wonders on the example \
IVP.  \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
approx = modeuler[f,0,1,0.5,20];
pts = ListPlot[ approx, PlotStyle->PointSize[0.01], PlotRange->{0,3} ];
lines = ListPlot[ approx, PlotJoined->True, PlotStyle->RGBColor[1,0,0], 
                  PlotRange->{0,3} ];
Show[ pts, lines, Plot[ g[t], {t,0,10} ], AspectRatio->1/3, 
      PlotLabel\[Rule] \"h = 0.5 (modeuler)\" ]\
\>", "Input",
  CellLabel->"In[95]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.111111 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .05556 -18 -4.5 ]
[.01131 .05556 0 4.5 ]
[.01131 .11111 -6 -4.5 ]
[.01131 .11111 0 4.5 ]
[.01131 .16667 -18 -4.5 ]
[.01131 .16667 0 4.5 ]
[.01131 .22222 -6 -4.5 ]
[.01131 .22222 0 4.5 ]
[.01131 .27778 -18 -4.5 ]
[.01131 .27778 0 4.5 ]
[.01131 .33333 -6 -4.5 ]
[.01131 .33333 0 4.5 ]
[.5 .34583 -56 0 ]
[.5 .34583 56 12 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .05556 m
.03006 .05556 L
s
[(0.5)] .01131 .05556 1 0 Mshowa
.02381 .11111 m
.03006 .11111 L
s
[(1)] .01131 .11111 1 0 Mshowa
.02381 .16667 m
.03006 .16667 L
s
[(1.5)] .01131 .16667 1 0 Mshowa
.02381 .22222 m
.03006 .22222 L
s
[(2)] .01131 .22222 1 0 Mshowa
.02381 .27778 m
.03006 .27778 L
s
[(2.5)] .01131 .27778 1 0 Mshowa
.02381 .33333 m
.03006 .33333 L
s
[(3)] .01131 .33333 1 0 Mshowa
.125 Mabswid
.02381 .01111 m
.02756 .01111 L
s
.02381 .02222 m
.02756 .02222 L
s
.02381 .03333 m
.02756 .03333 L
s
.02381 .04444 m
.02756 .04444 L
s
.02381 .06667 m
.02756 .06667 L
s
.02381 .07778 m
.02756 .07778 L
s
.02381 .08889 m
.02756 .08889 L
s
.02381 .1 m
.02756 .1 L
s
.02381 .12222 m
.02756 .12222 L
s
.02381 .13333 m
.02756 .13333 L
s
.02381 .14444 m
.02756 .14444 L
s
.02381 .15556 m
.02756 .15556 L
s
.02381 .17778 m
.02756 .17778 L
s
.02381 .18889 m
.02756 .18889 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .21111 m
.02756 .21111 L
s
.02381 .23333 m
.02756 .23333 L
s
.02381 .24444 m
.02756 .24444 L
s
.02381 .25556 m
.02756 .25556 L
s
.02381 .26667 m
.02756 .26667 L
s
.02381 .28889 m
.02756 .28889 L
s
.02381 .3 m
.02756 .3 L
s
.02381 .31111 m
.02756 .31111 L
s
.02381 .32222 m
.02756 .32222 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
gsave
.5 .34583 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(h) show
75.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(H) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(modeuler) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
165.000 13.000 moveto
(L) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.01 w
.02381 .11111 Mdot
.07143 .17545 Mdot
.11905 .24805 Mdot
.16667 .28712 Mdot
.21429 .26127 Mdot
.2619 .19265 Mdot
.30952 .12548 Mdot
.35714 .07959 Mdot
.40476 .05404 Mdot
.45238 .04329 Mdot
.5 .04376 Mdot
.54762 .05571 Mdot
.59524 .0837 Mdot
.64286 .13403 Mdot
.69048 .20435 Mdot
.7381 .26725 Mdot
.78571 .27901 Mdot
.83333 .22992 Mdot
.88095 .15871 Mdot
.92857 .10102 Mdot
.97619 .06521 Mdot
1 0 0 r
.5 Mabswid
.02381 .11111 m
.07143 .17545 L
.11905 .24805 L
.16667 .28712 L
.21429 .26127 L
.2619 .19265 L
.30952 .12548 L
.35714 .07959 L
.40476 .05404 L
.45238 .04329 L
.5 .04376 L
.54762 .05571 L
.59524 .0837 L
.64286 .13403 L
.69048 .20435 L
.7381 .26725 L
.78571 .27901 L
.83333 .22992 L
.88095 .15871 L
.92857 .10102 L
.97619 .06521 L
s
0 g
.02381 .11111 m
.06244 .16487 L
.10458 .23523 L
.12507 .26625 L
.13506 .27882 L
.14415 .28822 L
.14868 .29208 L
.1536 .29559 L
.15825 .29824 L
.16254 .30007 L
.16488 .30082 L
.16708 .30137 L
.16834 .3016 L
.16949 .30178 L
.17013 .30185 L
.17082 .30192 L
.17209 .302 L
.17277 .30202 L
.17342 .30203 L
.17463 .30201 L
.17593 .30193 L
.17666 .30186 L
.17734 .30177 L
.1797 .30137 L
.1809 .3011 L
.18221 .30075 L
.18472 .29991 L
.18745 .29877 L
.19241 .2961 L
.20172 .28907 L
.21258 .27786 L
.22263 .26505 L
.2619 .20216 L
.29965 .14165 L
.32062 .11393 L
.33985 .09319 L
.3587 .07705 L
.37854 .06407 L
.39828 .05459 L
.41665 .04834 L
.42717 .0457 L
.43711 .04378 L
.44602 .04249 L
.45106 .04193 L
.45569 .04152 L
.46037 .04121 L
.46299 .04108 L
.46539 .04099 L
.46761 .04093 L
.46887 .04091 L
Mistroke
.47004 .04089 L
.47116 .04088 L
.47218 .04088 L
.47335 .04088 L
.47446 .04088 L
.47566 .0409 L
.47697 .04092 L
.47835 .04095 L
.47963 .04099 L
.48192 .04107 L
.48438 .04119 L
.48999 .04156 L
.4951 .04203 L
.50504 .04329 L
.51422 .0449 L
.5243 .04719 L
.53499 .05028 L
.5545 .05786 L
.5728 .06767 L
.59302 .08217 L
.61154 .09936 L
.65121 .14996 L
.68937 .21246 L
.71067 .24751 L
.72999 .27469 L
.73965 .28545 L
.74473 .29015 L
.75011 .29433 L
.75482 .29728 L
.75731 .29856 L
.75999 .29972 L
.76245 .30058 L
.76469 .30119 L
.76577 .30143 L
.76695 .30164 L
.76806 .3018 L
.76908 .30191 L
.77026 .30199 L
.77149 .30203 L
.77255 .30202 L
.77371 .30197 L
.77496 .30187 L
.77565 .30179 L
.77629 .3017 L
.77869 .30124 L
.78092 .30065 L
.78334 .29983 L
.78773 .29785 L
.79293 .29473 L
.79844 .29053 L
Mistroke
.80832 .28088 L
.82787 .25525 L
.84617 .22607 L
.88496 .1614 L
.90469 .13231 L
.92621 .10565 L
.94544 .08656 L
.96594 .0708 L
.97619 .06449 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[95]:=",
  ImageSize->{288, 95.9375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000Mb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Koooool5o`0002kooooo0_l000000ol@413oooooooooo`0[ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool006oooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A00_ooooo`03o`000?oooooooooo02cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0/oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0:oooool0073ooooo00?oV9RHob4Q8Oo^k^h0;Oooool5o`0002gooooo00Go0000
ooooooooooooooooo`00000/ooooo`05o`000?ooooooooooooooool00000:oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:oooool0077ooooo00?oV9RHob4Q8Oo^k^h0
;?ooool01?m4A4CogMgMooooool0000^ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb
<S;oV9RHoooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000002_ooooo001booooo`03ogMgMomVIVKooooo02_ooooo00CogMgMoeEEEOoooooo0000;_oo
ool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<o`000?l0003o0000olc<c00[ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[ooooo`00Loooool00ol0003o
ooooooooo`0[ooooo`03ogMgMoo<c<co000002kooooo00?oEEEEohN7Qoooool0;_ooool01Ol@413o
^[Zjoooooonj^[[o410@02_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@02_ooooo001_ooooo`05o`000?nj^[[ooooooiRHV?l@4100;Oooool00oo^k^koA4A4o`00000^
ooooo`03omgMgOl@413oV9RH02kooooo00Go0000okZj^_oooooo^[Zjo`00000[ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`00Koooool01OnHV9So410@o`00
0?lQ8B7oc<c<02kooooo00?oMgMgo`000?ooool0;_ooool01?o<c<coA4A4o`000?l@410/ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0:Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0:oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool003_oooooool00004o`0002[ooooo0011ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0^ooooo`00@Oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool0047ooooo0_l0003oooooobKooooo
0011ooooo`03o`000?oooooooooo0?oooooo9Oooool0047ooooo00?o0000ooooooooool0oooooolU
ooooo`00@Oooool2o`000?oooooo9_ooool0047ooooo00?o0000ooooooooool0oooooolUooooo`00
@Oooool00ol0003oooooooooo`3oooooobGooooo0011ooooo`;o0000oooooolVooooo`00@Oooool0
0ol0003oooooooooo`3oooooobGooooo0011ooooo`03o`000?oooooooooo06Oooooo5Ol0002Xoooo
o`009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool2o`0006Gooooo0ol00003ool00003ooooool0003o000000[ooooo0_l00002
ooooo`03ool00?l0003o000000?o0000Xoooool002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo067ooooo0ol00000
0ooo003oooooooooo`0Gooooo`?oo`000_l0002Qooooo`009oooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00_ooool3o`0005gooooo1?l0000Pooooo`;oo`000ol0002N
ooooo`009oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`1Kooooo`;o000000Coo`00ooooool0003o00008oooool2ool000;o0000W?oo
ool002Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`1Jooooo`03o`000?oo003ooooo02Wooooo0_oo0002o`0009[ooooo
000Wooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o0000
FOooool2o`000003ool00?oooooooooo02_ooooo0_oo00000ol0003oooooooooo`1Uooooo`;o0000
<?ooool002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0E_ooool2o`000003ool00?oooooooooo02oooooo00?oo`00o`000?l00000
Hoooool4o`00033ooooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool0EOooool00ol0003oo`00ooooo`0dooooo`03ool00?l0003o0000063ooooo
00?o0000ool00?ooool0<_ooool0047ooooo0_l0001Cooooo`?o000000?oo`00ooooooooool0=Ooo
ool2ool00003o`000?oooooooooo05_ooooo0_l000000ooo003oooooooooo`0booooo`00@Oooool0
0ol0003oooooooooo`1Booooo`03o`000?oo003ooooo03[ooooo00?oo`00o`000?l00000F_ooool0
0ol0003oo`00ooooo`0eooooo`00@Oooool00ol0003oooooooooo`1Aooooo`03o`000?oo003ooooo
03cooooo0_l0001Iooooo`03o`000?oo003ooooo03Kooooo0011ooooo`;o0000DOooool00ol0003o
o`00ooooo`0nooooo`03ool00?l0003ooooo05Kooooo00?o0000ool00?ooool0=oooool0047ooooo
00?o0000ooooooooool0Coooool00ol0003oo`00ooooo`10ooooo`03ool00?l0003ooooo05Cooooo
00?o0000ooooooooool0>?ooool0047ooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`11ooooo`03ool00?l0003ooooo05;ooooo00?o0000ooooooooool0>Oooool003Sooooo1?l00000
0ol@413oooooooooo`02ooooo`;o0000Coooool00ol0003oooooooooo`13ooooo`03ool00?l0003o
oooo04oooooo0_l0000looooo`00>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1>ooooo`03o`000?oo003ooooo
03_ooooo000jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0>oooool003[ooooo
00?o0000ooooooooool00oooool4o`0004_ooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo03cooooo000jooooo`03o`000?oooooooooo00?ooooo0_l0
001<ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0mooooo`00>_ooool00ol0003oooooooooo`04ooooo`;o0000B_ooool00ooo003o0000ooooo`1<
ooooo`03o`000?oo003ooooo04Sooooo00?o0000ooooooooool0?_ooool003[ooooo00?o0000oooo
ooooool01?ooool3o`0004Kooooo0_l000000ooo003o0000ooooo`1>ooooo`03o`000?oo003ooooo
04Oooooo00?o0000ooooooooool0?_ooool003Sooooo00?oEEEEofIVI_l000001_ooool01?l0003o
ooooooooool00015ooooo`03o`000?oo003o0000057ooooo00?o0000ool00?ooool0AOooool00ol0
003oooooooooo`0oooooo`00@Oooool01?l0003oooooooooool00016ooooo`03o`000?oooooooooo
057ooooo00?o0000ool00?l00000@oooool00ol0003oooooooooo`10ooooo`00@Oooool2o`0000;o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1Cooooo`03o`000?oo003ooooo047o
oooo00?oo`00o`000?ooool0@Oooool0047ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo05Cooooo00?o0000ool00?ooool0@?ooool00ooo003o0000
ooooo`12ooooo`00@Oooool2o`0000?ooooo00?o0000ool00?ooool0?oooool00ol0003oo`00oooo
o`1Fooooo`03o`000?oo003ooooo03oooooo00?o0000ooooooooool0@_ooool0047ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo05Oooooo00?o0000
ool00?ooool0?Oooool00ooo003o0000ooooo`13ooooo`00@Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0koooo
o`03ool00?l0003ooooo04Cooooo0011ooooo`;o00001_ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo05[ooooo00?o0000ool00?ooool0>_ooool00ooo003oooooo`000015ooooo`00
:?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo03[ooooo00?o0000oooooooo
ool0Foooool00ol0003oo`00ooooo`0gooooo`04o`000?oo003oooooo`0004Kooooo000Zooooo`03
o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool0=_ooool00ol0003oo`00o`000017ooooo`00:_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo03Kooooo00?oo`00o`000?ooool0
G_ooool00ol0003oo`00ooooo`0fooooo`03ool00?oooooo000004Oooooo000Zooooo`03o`000?oo
oooooooo00kooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
003ooooo03Kooooo00?o0000ooooooooool0Goooool00ol0003oo`00ooooo`0dooooo`03ool00?oo
oooo000004Sooooo000Zooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?l00000=?ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oo003ooooo03Cooooo00?oo`00ooooool00000B?ooool002[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`;o00002_ooool2o`0003?ooooo00?oo`00
o`000?ooool0H_ooool00ol0003oo`00ooooo`0booooo`03ool00?oooooo000004Wooooo000Zoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09oooo
o`03o`000?oo003ooooo037ooooo00?oo`00o`000?ooool0I?ooool00ol0003oo`00ooooo`0`oooo
o`03ool00?oooooo000004[ooooo000Xooooo`03oeEEEOmVIVKo000000gooooo1?l00005ooooo`03
o`000?oooooooooo00[ooooo00?o0000ool00?ooool0<?ooool00ooo003o0000ooooo`1Tooooo`03
o`000?oo003ooooo033ooooo00?oo`00ooooool00000B_ooool0047ooooo0_l0000;ooooo`03o`00
0?oo003ooooo02oooooo00?oo`00o`000?ooool0I_ooool00ol0003oo`00ooooo`0^ooooo`03ool0
0?oooooo000004_ooooo0011ooooo`03o`000?oooooooooo00_ooooo00?o0000ool00?ooool0;?oo
ool00ol0003oo`00o`00001Yooooo`03o`000?oo003ooooo02cooooo00Coo`00oooooooooooo0000
Boooool0047ooooo00?o0000ooooooooool03?ooool00ol0003oo`00ooooo`0[ooooo`03o`000?oo
003o000006Wooooo00?o0000ool00?ooool0:oooool01?oo003oooooooooool0001<ooooo`00@Ooo
ool2o`0000gooooo00?o0000ool00?ooool0:oooool00ooo003o0000ooooo`1Zooooo`03o`000?oo
003ooooo02[ooooo00?oo`00ooooool00000COooool0047ooooo00?o0000ooooooooool03Oooool0
0ol0003oo`00ooooo`0Yooooo`03ool00?oooooo000006_ooooo00Co0000oooooooo003o0000:?oo
ool01?oo003oooooooooool0001=ooooo`00@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
ooooo`0002Sooooo00?oo`00ooooool00000KOooool00ol0003oo`00o`00000Wooooo`04ool00?oo
ooooooooo`0004kooooo000gooooo`Go00001Oooool2o`0000oooooo00?o0000oooooooo00009ooo
ool00ooo003o0000ooooo`1^ooooo`03o`000?oo003ooooo02Kooooo00Coo`00oooooooooooo0000
C_ooool003Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo00oooooo
00?o0000ool00?ooool09Oooool00ooo003oooooo`00001_ooooo`03o`000?ooooooo`0002Gooooo
00Coo`00oooooooooooo0000Coooool003Sooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooooooo`0002Cooooo00?oo`00ooooool00000LOooool00ol0003ooooo
ool0000Sooooo`04ool00?ooooooooooo`00053ooooo000iooooo`03oiRHV?lQ8B7ok^k^00Gooooo
0ol0000@ooooo`03o`000?ooooooo`0002?ooooo00?oo`00o`000?ooool0L_ooool00ol0003ooooo
ool0000Rooooo`04ool00?ooooooooooo`00053ooooo000jooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool04?ooool00ol0003oooooool0000Rooooo`03ool00?oooooo000007?ooooo
00?o0000oooooooo00008?ooool01Ol0003oo`00oooooooooooo0000057ooooo000kooooo`03o`00
0?oooooooooo00?ooooo0_l0000Booooo`03o`000?ooooooo`00023ooooo00?oo`00ooooool00000
MOooool00ol0003oooooool0000Oooooo`05ool00?l0003oooooooooool00000DOooool003Oooooo
00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
00007_ooool00ooo003oooooo`00001gooooo`03o`000?ooooooo`0001gooooo00Goo`00oooooooo
ooooooooo`00001Booooo`00=oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooool0000Nooooo`03ool00?oooooo000007Oooooo00Co0000oooo
ooooooooo`006oooool01Ooo003ooooooooooooooooo000005?ooooo0011ooooo`;o00005?ooool0
0ol0003oooooool0000Looooo`03ool00?oooooo000007Wooooo00Co0000ooooooooooooo`006Ooo
ool01Ooo003ooooooooooooooooo000005Cooooo0011ooooo`03o`000?oooooooooo01Cooooo0_l0
0002ool001Wooooo00Coo`00oooooooooooo0000N_ooool01?l0003ooooooooooooo000Gooooo`03
ool00?oooooooooo00;ooooo00?o0000ooooooooool0D_ooool0047ooooo00?o0000ooooooooool0
5?ooool3o`000003oooooooo003ooooo01Oooooo00?oo`00ooooool00000Noooool01?l0003ooooo
oooooooo000Fooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0Doooool0047ooooo
0_l0000Fooooo`05o`000?oooooooooooooooooo00005_ooool00ooo003oooooo`00001mooooo`04
o`000?ooooooooooool001Cooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`1Doooo
o`00@Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?oo`00oooooooo
ool04Oooool01Ol0003oo`00oooooooooooo000007kooooo00Co0000ooooooooooooo`004_ooool0
0ooo003oooooooooo`03ooooo`03o`000?oooooooooo05Cooooo0011ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0?ooooo`;oo`0000?o0000oooo
ool00000P?ooool01?l0003ooooooooooooo000@ooooo`03ool00?oooooooooo00?ooooo00?o0000
ooooooooool0EOooool002Oooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo0_l0000Hooooo`03o`000?oooooooooo00;ooooo0_oo000=ooooo`;oo`000oooool0
0ol0003oooooooooo`1oooooo`04o`000?ooooooooooo`0000?oo`003?ooool00ooo003ooooooooo
o`03ooooo`03o`000?oooooooooo05Kooooo000Wooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool02?ooool2ool000Gooooo00?o0000ooooooooool0P?oo
ool01?l0003oooooo`000?l00002ooooo`Coo`001oooool00ooo003oooooooooo`03ooooo`03o`00
0?oooooooooo05Oooooo000Xooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool01Ooo
ool2ool000Kooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`06ooooo`Coo`000_oo
ool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo05Oooooo000Yooooo`03oiRHV?lQ8B7o
k^k^00oooooo00?oMgMgoc8b<_ooool00oooool3o`0001[ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`02ooooo`;oo`001oooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo00[ooooo0_oo0006ooooo`03o`000?oooooooooo05Sooooo000Zooooo`03ogMgMomVIVKooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool01?ooool01?oo003oooooool00?oo0008ooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool02Oooool2o`0000Cooooo0_l0001Kooooo`00:oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03
ooooo`03o`000?oo003ooooo00Sooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo05_ooooo000Wooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool0
0ol0003oooooooooo`06ooooo`;o00007Oooool00ol0003oooooooooo`02ooooo`;o00002?ooool0
0ol0003oooooooooo`29ooooo`;o00003?ooool00ol0003oooooooooo`1Looooo`009oooool01OnH
V9So410@o`000?lQ8B7oc<c<00cooooo1?l00005ooooo`03o`000?oooooooooo01gooooo0_l0000;
ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01oooool2o`0005oooooo0011oooo
o`03o`000?oooooooooo01oooooo0_l00006ooooo`?o0000T?ooool2o`0000Kooooo00?o0000oooo
ooooool0Goooool0047ooooo0_l0000Rooooo`Oo0000Toooool7o`0006;ooooo0011ooooo`03o`00
0?oooooooooo0?oooooo9Oooool0047ooooo00?o0000ooooooooool0oooooolUooooo`00@Oooool2
o`000?oooooo9_ooool0047ooooo00?o0000ooooooooool0oooooolUooooo`00@Oooool2o`000?oo
oooo9_ooool003Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo9Oooool003Oooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
oooo9Oooool003_ooooo00?o0000ooooooooool00oooool3o`000?oooooo9Oooool003[ooooo00?o
ZJVYoa0@4?ooool0ooooool/ooooo`00>Oooool00ol@413o0000okZj^P3oooooobgooooo000joooo
o`03okZj^_lQ8B7ooooo0?oooooo;?ooool003Oooooo00Go410@oiRHV?oooooo^[Zjo`00003ooooo
obgooooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT0ooooool]ooooo`00^_ooool00omgMgOo
IVIVooooo`0looooo`03ofIVI_mgMgOooooo06cooooo002iooooo`03omgMgOl@413ok^k^03gooooo
00?ok^k^oa0@4?oMgMd0K?ooool007[ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0;ooooo`03oeEEEOnHV9Sooooo00;o00000_ooool01ol0003oooooooooool0003o
410@onk^k_mEEED00_l000001_mEEEGok^k^ooooooooooook^k^oeEEE@;o000000KoV9RHo`000?l@
413oooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00;ooooo00OoV9RHo`000?l0003oMgMgo`00
0?l@413ooooo00Go00000oooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00000
0on7QhOoIVIVooooo`1[ooooo`00Noooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool02_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000oooooooooooo0000oooooomEEEGoMgMg
00;ooooo00[oMgMgoeEEEOoooooooooooeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGo
MgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000ojVYZOooooooQhN7o`000004ooooo`03o`000?oo
oooooooo00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`06o`000?oooooooooooooo
ooo^k^ko0000K?ooool007_ooooo00Go0000ooooooooooooooooo`00000Hooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`09ooooo`05oc8b<_ooooooooooooooool00000
0_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00Co0000oooooooooooo00000oooool0
1Oo^k^ko0000oooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo06[ooooo001kooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00[ooooo00Go<S8boooooooo
ooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01?l0003ooooooooo
ool00003ooooo`04onk^k_l0003oooooooooo`Ko00000oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Zooooo`00Noooool01Ol0003oMgMgoooooonYZJWo000001Sooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02oooool01Ol0003ok^k^oooo
oooooooo000000;oc<c<00Oo0000ojVYZOoMgMgo8B4QoooooomEEEGoMgMg00;ooooo00[oMgMgoeEE
EOooooooooooofIVI_mgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7
oc8b<P?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`06o`000?lb<S;ogMgMooooooo^k^ko0000K?ooool0
07_ooooo00Go0000ogMgMol0003o0000oiRHV00Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0=ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@
o`000?nYZJWoooooonk^k_mEEED2o`00000:oeEEEOo^k^koooooooooooo^k^koEEEEo`000?l@413o
c<c<o`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`04oa0@4?l0003ooooooooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_oo
ool2o`000005ojVYZOlQ8B7o0000o`l?3omEEED0K?ooool007_ooooo00?o0000ooooooooool06_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool00ooMgMgo410@
onk^kP0Fooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00oo^k^ko410@
omgMg@1/ooooo`00Noooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000gooooo00?oMgMgofIVI_ooool05Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00oooooo00?oIVIVogMgMoooool0K?ooool007[ooooo00?o410@o`000?ooool0E?oo
ool2o`0001;ooooo00?o410@o`000?l00000P?ooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{77.875, 364.875}, {242.812, 147.875}} -> {-6.63619, \
5.94493, 0.0508876, 0.043618}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
approx = modeuler[f,0,1,0.25,40];
pts = ListPlot[ approx, PlotStyle->PointSize[0.01], PlotRange->{0,3} ];
lines = ListPlot[ approx, PlotJoined->True, PlotStyle->RGBColor[1,0,0],
                  PlotRange->{0,3} ];
Show[ pts, lines, Plot[ g[t], {t,0,10} ], AspectRatio->1/3, 
      PlotLabel\[Rule] \"h = 0.25 (modeuler)\" ]\
\>", "Input",
  CellLabel->"In[99]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.111111 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .05556 -18 -4.5 ]
[.01131 .05556 0 4.5 ]
[.01131 .11111 -6 -4.5 ]
[.01131 .11111 0 4.5 ]
[.01131 .16667 -18 -4.5 ]
[.01131 .16667 0 4.5 ]
[.01131 .22222 -6 -4.5 ]
[.01131 .22222 0 4.5 ]
[.01131 .27778 -18 -4.5 ]
[.01131 .27778 0 4.5 ]
[.01131 .33333 -6 -4.5 ]
[.01131 .33333 0 4.5 ]
[.5 .34583 -59 0 ]
[.5 .34583 59 12 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .05556 m
.03006 .05556 L
s
[(0.5)] .01131 .05556 1 0 Mshowa
.02381 .11111 m
.03006 .11111 L
s
[(1)] .01131 .11111 1 0 Mshowa
.02381 .16667 m
.03006 .16667 L
s
[(1.5)] .01131 .16667 1 0 Mshowa
.02381 .22222 m
.03006 .22222 L
s
[(2)] .01131 .22222 1 0 Mshowa
.02381 .27778 m
.03006 .27778 L
s
[(2.5)] .01131 .27778 1 0 Mshowa
.02381 .33333 m
.03006 .33333 L
s
[(3)] .01131 .33333 1 0 Mshowa
.125 Mabswid
.02381 .01111 m
.02756 .01111 L
s
.02381 .02222 m
.02756 .02222 L
s
.02381 .03333 m
.02756 .03333 L
s
.02381 .04444 m
.02756 .04444 L
s
.02381 .06667 m
.02756 .06667 L
s
.02381 .07778 m
.02756 .07778 L
s
.02381 .08889 m
.02756 .08889 L
s
.02381 .1 m
.02756 .1 L
s
.02381 .12222 m
.02756 .12222 L
s
.02381 .13333 m
.02756 .13333 L
s
.02381 .14444 m
.02756 .14444 L
s
.02381 .15556 m
.02756 .15556 L
s
.02381 .17778 m
.02756 .17778 L
s
.02381 .18889 m
.02756 .18889 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .21111 m
.02756 .21111 L
s
.02381 .23333 m
.02756 .23333 L
s
.02381 .24444 m
.02756 .24444 L
s
.02381 .25556 m
.02756 .25556 L
s
.02381 .26667 m
.02756 .26667 L
s
.02381 .28889 m
.02756 .28889 L
s
.02381 .3 m
.02756 .3 L
s
.02381 .31111 m
.02756 .31111 L
s
.02381 .32222 m
.02756 .32222 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
gsave
.5 .34583 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(h) show
75.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(H) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(modeuler) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
171.000 13.000 moveto
(L) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.01 w
.02381 .11111 Mdot
.04762 .14182 Mdot
.07143 .17832 Mdot
.09524 .21777 Mdot
.11905 .25509 Mdot
.14286 .28373 Mdot
.16667 .29762 Mdot
.19048 .2935 Mdot
.21429 .27238 Mdot
.2381 .23905 Mdot
.2619 .2001 Mdot
.28571 .16157 Mdot
.30952 .12753 Mdot
.33333 .09982 Mdot
.35714 .07864 Mdot
.38095 .06325 Mdot
.40476 .05266 Mdot
.42857 .0459 Mdot
.45238 .04227 Mdot
.47619 .04134 Mdot
.5 .04301 Mdot
.52381 .04749 Mdot
.54762 .05527 Mdot
.57143 .06717 Mdot
.59524 .0842 Mdot
.61905 .10735 Mdot
.64286 .13714 Mdot
.66667 .17293 Mdot
.69048 .21217 Mdot
.71429 .25006 Mdot
.7381 .28019 Mdot
.7619 .29628 Mdot
.78571 .2946 Mdot
.80952 .27555 Mdot
.83333 .24353 Mdot
.85714 .20501 Mdot
.88095 .16621 Mdot
.90476 .13148 Mdot
.92857 .10294 Mdot
.95238 .08096 Mdot
.97619 .06489 Mdot
1 0 0 r
.5 Mabswid
.02381 .11111 m
.04762 .14182 L
.07143 .17832 L
.09524 .21777 L
.11905 .25509 L
.14286 .28373 L
.16667 .29762 L
.19048 .2935 L
.21429 .27238 L
.2381 .23905 L
.2619 .2001 L
.28571 .16157 L
.30952 .12753 L
.33333 .09982 L
.35714 .07864 L
.38095 .06325 L
.40476 .05266 L
.42857 .0459 L
.45238 .04227 L
.47619 .04134 L
.5 .04301 L
.52381 .04749 L
.54762 .05527 L
.57143 .06717 L
.59524 .0842 L
.61905 .10735 L
.64286 .13714 L
.66667 .17293 L
.69048 .21217 L
.71429 .25006 L
.7381 .28019 L
.7619 .29628 L
.78571 .2946 L
.80952 .27555 L
.83333 .24353 L
.85714 .20501 L
.88095 .16621 L
.90476 .13148 L
.92857 .10294 L
.95238 .08096 L
.97619 .06489 L
s
0 g
.02381 .11111 m
.06244 .16487 L
.10458 .23523 L
.12507 .26625 L
.13506 .27882 L
.14415 .28822 L
.14868 .29208 L
.1536 .29559 L
.15825 .29824 L
.16254 .30007 L
.16488 .30082 L
.16708 .30137 L
.16834 .3016 L
.16949 .30178 L
.17013 .30185 L
.17082 .30192 L
.17209 .302 L
.17277 .30202 L
.17342 .30203 L
.17463 .30201 L
.17593 .30193 L
.17666 .30186 L
.17734 .30177 L
.1797 .30137 L
.1809 .3011 L
.18221 .30075 L
.18472 .29991 L
.18745 .29877 L
.19241 .2961 L
.20172 .28907 L
.21258 .27786 L
.22263 .26505 L
.2619 .20216 L
.29965 .14165 L
.32062 .11393 L
.33985 .09319 L
.3587 .07705 L
.37854 .06407 L
.39828 .05459 L
.41665 .04834 L
.42717 .0457 L
.43711 .04378 L
.44602 .04249 L
.45106 .04193 L
.45569 .04152 L
.46037 .04121 L
.46299 .04108 L
.46539 .04099 L
.46761 .04093 L
.46887 .04091 L
Mistroke
.47004 .04089 L
.47116 .04088 L
.47218 .04088 L
.47335 .04088 L
.47446 .04088 L
.47566 .0409 L
.47697 .04092 L
.47835 .04095 L
.47963 .04099 L
.48192 .04107 L
.48438 .04119 L
.48999 .04156 L
.4951 .04203 L
.50504 .04329 L
.51422 .0449 L
.5243 .04719 L
.53499 .05028 L
.5545 .05786 L
.5728 .06767 L
.59302 .08217 L
.61154 .09936 L
.65121 .14996 L
.68937 .21246 L
.71067 .24751 L
.72999 .27469 L
.73965 .28545 L
.74473 .29015 L
.75011 .29433 L
.75482 .29728 L
.75731 .29856 L
.75999 .29972 L
.76245 .30058 L
.76469 .30119 L
.76577 .30143 L
.76695 .30164 L
.76806 .3018 L
.76908 .30191 L
.77026 .30199 L
.77149 .30203 L
.77255 .30202 L
.77371 .30197 L
.77496 .30187 L
.77565 .30179 L
.77629 .3017 L
.77869 .30124 L
.78092 .30065 L
.78334 .29983 L
.78773 .29785 L
.79293 .29473 L
.79844 .29053 L
Mistroke
.80832 .28088 L
.82787 .25525 L
.84617 .22607 L
.88496 .1614 L
.90469 .13231 L
.92621 .10565 L
.94544 .08656 L
.96594 .0708 L
.97619 .06449 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[99]:=",
  ImageSize->{288, 95.9375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000Mb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Koooool5o`0002kooooo0_l000000ol@413oooooooooo`0[ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool006oooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A00_ooooo`03o`000?oooooooooo02cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0/oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0:oooool0073ooooo00?oV9RHob4Q8Oo^k^h0;Oooool5o`0002gooooo00Go0000
ooooooooooooooooo`00000/ooooo`05o`000?ooooooooooooooool00000:oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:oooool0077ooooo00?oV9RHob4Q8Oo^k^h0
;?ooool01?m4A4CogMgMooooool0000^ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb
<S;oV9RHoooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000002_ooooo001booooo`03ogMgMomVIVKooooo02_ooooo00CogMgMoeEEEOoooooo0000;_oo
ool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<o`000?l0003o0000olc<c00[ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[ooooo`00Loooool00ol0003o
ooooooooo`0[ooooo`03ogMgMoo<c<co000002kooooo00?oEEEEohN7Qoooool0;_ooool01Ol@413o
^[Zjoooooonj^[[o410@02_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@02_ooooo001_ooooo`05o`000?nj^[[ooooooiRHV?l@4100;Oooool00oo^k^koA4A4o`00000^
ooooo`03omgMgOl@413oV9RH02kooooo00Go0000okZj^_oooooo^[Zjo`00000[ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`00Koooool01OnHV9So410@o`00
0?lQ8B7oc<c<02kooooo00?oMgMgo`000?ooool0;_ooool01?o<c<coA4A4o`000?l@410/ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0:Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0:oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool003_oooooool00004o`0002[ooooo0011ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0^ooooo`00@Oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool0047ooooo0_l0003oooooobKooooo
0011ooooo`03o`000?oooooooooo0?oooooo9Oooool0047ooooo00?o0000ooooooooool0oooooolU
ooooo`00@Oooool2o`000?oooooo9_ooool0047ooooo00?o0000ooooooooool0oooooolUooooo`00
@Oooool00ol0003oooooooooo`3oooooobGooooo0011ooooo`;o0000oooooolVooooo`00@Oooool0
0ol0003oooooooooo`3oooooobGooooo0011ooooo`03o`000?oooooooooo06Oooooo5Ol0002Xoooo
o`009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool2o`0006Gooooo0ol00002ool000;ooooo0_l00004ooooo`;o00001?ooool2
o`0000?ooooo1Ol0002Sooooo`009oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0Goooool5o`000003ooooool0003o
000001Oooooo0_l000001?oooooo0000o`000?oo002Pooooo`009oooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool3o`0005gooooo1?l0000Rooooo`?o0000W_oo
ool002Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0Foooool2o`000003ool00?oooooooooo02Cooooo1?l000000ooo003ooooooooo
o`2Iooooo`009oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo05Sooooo0_oo00000ol0003oooooooooo`0[ooooo`;o0000
00?oo`00ooooooooool0Uoooool002Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Kooooo0_l0001Hooooo`04ool00?l0003o0000o`0002oooooo00?o0000ool00?oo
0000IOooool2o`00033ooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05Gooooo00?oo`00o`000?l00000<_ooool3o`000003
ool00?oooooooooo063ooooo1?l0000`ooooo`009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00005ooooo`03o`000?oooooooooo05Cooooo00?oo`00o`000?ooool0=_ooool2o`00063o
oooo00?o0000ool00?ooool0<_ooool0047ooooo0_l0001Cooooo`?o0000>_ooool00ol0003ooooo
ooooo`1Kooooo`;o0000=Oooool0047ooooo00?o0000ooooooooool0D_ooool2o`0003cooooo00?o
0000ooooooooool0FOooool00ol0003oo`00ooooo`0eooooo`00@Oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo03cooooo0_l0001Iooooo`03o`000?oo003o000003Kooooo0011oooo
o`;o0000DOooool00ol0003oooooooooo`0mooooo`?o0000Eoooool00ol0003oo`00ooooo`0goooo
o`00@Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0Doooool00ol0003oo`00ooooo`0hooooo`00@Oooool00ol0003oooooooooo`1>ooooo`03ool0
0?l0003ooooo04?ooooo00?o0000ooooooooool0DOooool00ol0003oo`00ooooo`0iooooo`00>?oo
ool4o`000003oa0@4?oooooooooo00;ooooo0_l0001=ooooo`03o`000?oo003o000004Kooooo00?o
0000ooooooooool0C_ooool2o`000003ool00?oooooooooo03Wooooo000jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0C?ooool2o`0004Oooooo00?o0000ool00?ooool0C_ooool0
0ol0003oo`00ooooo`0kooooo`00>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0Aoooool00ol0003oo`00ooooo`1=ooooo`03o`000?oo003ooooo
03_ooooo000jooooo`03o`000?oooooooooo00?ooooo1?l0001;ooooo`03o`000?oooooooooo04So
oooo0_l0001=ooooo`03o`000?oo003ooooo03cooooo000jooooo`03o`000?oooooooooo00?ooooo
0_l0001<ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0BOooool00ol0003oo`00
ooooo`0mooooo`00>_ooool00ol0003oooooooooo`04ooooo`;o0000B_ooool00ooo003o0000oooo
o`1<ooooo`03o`000?oo003ooooo04Sooooo00?o0000ool00?ooool0?_ooool003[ooooo00?o0000
ooooooooool01?ooool3o`0004Sooooo00?oo`00o`000?ooool0C_ooool00ol0003oo`00ooooo`17
ooooo`03o`000?oooooooooo03kooooo000hooooo`03oeEEEOmVIVKo000000Kooooo00Co0000oooo
oooooooo0000AOooool00ol0003oo`00o`00001Aooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0?oooool0047ooooo00Co0000oooooooooooo0000AOooool2o`0005?ooooo00?o0000
ooooooooool0@_ooool2o`0004;ooooo0011ooooo`;o00000_ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo05?ooooo0_l00012ooooo`;o0000@_ooool0047ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo05Cooooo00?o0000ool00?oo
ool0@Oooool00ol0003oooooooooo`11ooooo`00@Oooool2o`0000?ooooo00?o0000ool00?ooool0
?oooool00ol0003oo`00ooooo`1Fooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
@_ooool0047ooooo00?o0000ooooooooool00_ooool2o`00043ooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo04;ooooo0011ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0@oooool0047ooooo0_l00006ooooo`03o`000?oooooooooo
03[ooooo00?o0000ool00?ooool0F_ooool00ol0003oooooooooo`0kooooo`03ool00?l0003ooooo
04Cooooo000Xooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0A?ooool002[o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03Oooooo0_l0001Oooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0AOooool002[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`?o00001oooool00ol0003oooooooooo`0fooooo`;o0000Goooool00ol0003ooooo
ooooo`0fooooo`03o`000?oo003o000004Oooooo000Zooooo`03o`000?oooooooooo00kooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`0eooooo`;o0000B?ooool002[ooooo00?o0000
ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo063ooooo00?o0000ool00?ooool0=Ooo
ool00ooo003o0000ooooo`17ooooo`00:_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo0_l0000:ooooo`;o0000=?ooool00ol0003oooooooooo`1Pooooo`;o0000=Oooool0
0ooo003o0000ooooo`18ooooo`00:_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool2o`0003?ooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo04Sooooo000Xooooo`03oeEEEOmVIVKo000000go
oooo1?l00005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`1Sooooo`03o`000?oo003ooooo037ooooo00?oo`00o`000?ooool0BOooool0047ooooo
0_l0000;ooooo`03o`000?oo003ooooo033ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`0_ooooo`03ool00?l0003ooooo04[ooooo0011ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02gooooo00?o
o`00ooooool00000Boooool0047ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0;Oooool00ooo003o0000ooooo`1;
ooooo`00@Oooool2o`0000gooooo00?o0000ooooooooool0:oooool2o`0006_ooooo00?o0000oooo
ooooool0:oooool00ooo003o0000ooooo`1<ooooo`00@Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02[ooooo0_l0001[ooooo`03o`000?oo003ooooo02[ooooo00?oo`00o`000?l0
0000COooool0047ooooo00?o0000ooooooooool03Oooool00ol0003oo`00ooooo`0Zooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool0:Oooool00ooo003o0000ooooo`1=ooooo`00=ooo
ool5o`0000Gooooo0_l0000?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0KOoo
ool2o`0002Sooooo00?oo`00ooooool00000C_ooool003Oooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`03o`000?oooooooooo06gooooo0_l0
000Wooooo`03ool00?oooooo000004oooooo000hooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000
ooooooooool03oooool2o`0002Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0U
ooooo`03ool00?l0003ooooo04oooooo000iooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000@oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Soooo
o`03ool00?oooooo0000053ooooo000jooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool04?ooool00ol0003oo`00ooooo`0Sooooo`03ool00?l0003ooooo07;ooooo00?o0000oooooooo
ool08oooool00ooo003o0000ooooo`1@ooooo`00>oooool00ol0003oooooooooo`03ooooo`;o0000
4_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
8Oooool00ooo003oooooo`00001Aooooo`00=oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07Gooooo
00?o0000ooooooooool07oooool00ooo003oooooo`00001Booooo`00=oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Gooooo00?o0000ooooooooool04_ooool00ol0003oo`00ooooo`0Oooooo`03ool0
0?l0003ooooo07Kooooo00?o0000ool00?ooool07oooool00ooo003o0000ooooo`1Booooo`00@Ooo
ool2o`0001Cooooo00?o0000ool00?ooool07_ooool2o`0007Sooooo00?o0000ooooooooool07Ooo
ool00ooo003o0000ooooo`1Cooooo`00@Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01cooooo00?oo`00o`000?ooool0NOooool2o`0001gooooo00?oo`00o`000?ooool0Doooool0
047ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ooooo`0Kooooo`03ool00?l0003ooooo
07[ooooo00?o0000ool00?ooool06oooool00ooo003o0000ooooo`1Dooooo`00@Oooool2o`0001Ko
oooo00?o0000ool00?ooool06_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01Wo
oooo00?oo`00o`000?ooool0EOooool0047ooooo00?o0000ooooooooool05Oooool00ol0003oo`00
ooooo`0Iooooo`03ool00?l0003ooooo07gooooo00?o0000ooooooooool05oooool00ooo003ooooo
o`00001Fooooo`00@Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo003ooooo01Oooooo00?o
o`00o`000?ooool0Ooooool00ol0003oooooooooo`0Fooooo`03ool00?l0003ooooo05Kooooo000W
ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o00006?oo
ool00ol0003oo`00ooooo`0Fooooo`03o`000?oooooooooo07oooooo00?o0000ool00?ooool05Ooo
ool00ooo003o0000ooooo`1Gooooo`009oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003oo`00oooo
o`0Cooooo`03o`000?oo003o000008;ooooo00?o0000ooooooooool04oooool00ooo003o0000oooo
o`1Hooooo`00:?ooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06Oooool00ol0003oo`00ooooo`0Aooooo`;oo`0000?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`0@ooooo`;oo`0000?oooooo`000?ooool0F?ooool002Wooooo00?oV9RHob4Q
8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`?o00006_ooool00ol0003oo`00ooooo`0?oooo
o`03ool00?oooooo000008Gooooo00?o0000ool00?l000003oooool01?oo003o0000o`000?l0001J
ooooo`00:_ooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0Jooooo`;o00000_oo000=ooooo`03ool00?oooooo000008Oooooo00?o0000
ool00?oo00003Oooool01?oo003oooooo`000?l0001Kooooo`00:oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool2o`000003oooooooo003o
oooo00[ooooo00?oo`00ooooool00000ROooool00ol0003oooooool0000;ooooo`03ool00?oooooo
000005gooooo000Wooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`06
ooooo`;o00007Oooool00ol0003oooooooooo`02ool000Sooooo00?oo`00ooooool00000Roooool2
o`0000;oo`002?ooool00ooo003oooooo`00001Nooooo`009oooool01OnHV9So410@o`000?lQ8B7o
c<c<00cooooo1?l00005ooooo`03o`000?oooooooooo01gooooo0_l00002ooooo`04ool00?oooooo
ooooooooo`Coo`0000?oooooo`000?ooool0SOooool01?l0003oooooool00?l00002ooooo`Coo`00
0_l0001Oooooo`00@Oooool00ol0003oooooooooo`0Oooooo`?o00000ooo0002ooooo`?o0000T?oo
ool2o`0000?oo`000_ooool2o`00067ooooo0011ooooo`;o00008_ooool7o`0009?ooooo1ol0001R
ooooo`00@Oooool00ol0003oooooooooo`3oooooobGooooo0011ooooo`03o`000?oooooooooo0?oo
oooo9Oooool0047ooooo0_l0003oooooobKooooo0011ooooo`03o`000?oooooooooo0?oooooo9Ooo
ool0047ooooo0_l0003oooooobKooooo000gooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooobGooooo000gooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool0
0ol0003oooooooooo`3oooooobGooooo000kooooo`03o`000?oooooooooo00?ooooo0ol0003ooooo
obGooooo000jooooo`03ojVYZOl@413ooooo0?oooooo;?ooool003Wooooo00?o410@o`000?nj^[X0
ooooool]ooooo`00>_ooool00onj^[[o8B4Qooooo`3oooooobcooooo000gooooo`05oa0@4?nHV9So
oooookZj^_l00000ooooool]ooooo`00=oooool01OnYZJWo410@o`000?l@413oZJVY0?oooooo;Ooo
ool00;gooooo00?oMgMgofIVI_ooool0?Oooool00omVIVKoMgMgooooo`1Xooooo`00_?ooool00ooM
gMgo410@onk^kP0nooooo`03onk^k_l@413ogMgM06Sooooo001fooooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00[ooooo00CoEEEEoiRHV?oooooooooo
0_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000006oeEEEOo^k^kooooo
ooooooo^k^koEEEE0_l000001_nHV9So0000oa0@4?ooooook^k^oeEEE@;o000000?oA4A4okZj^_oo
ool00_ooool01onHV9So0000o`000?mgMgOo0000oa0@4?ooool01Ol00003ooooo`08onk^k_mEEEGo
0000o`000?m4A4Co^[Zjooooool@4105o`000003ohN7QomVIVKooooo06Oooooo001gooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool02Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooomEEEGoMgMg
0_ooool02_mgMgOoEEEEooooooooooooEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmg
MgOoooooonk^k_mgMgOo410@0oooool01Ol0003oZJVYoooooon7QhOo000000Cooooo00?o0000oooo
ooooool00oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Ko0000oooooooooooooooo
onk^k_l0001Xooooo`00Moooool01Ol0003ooooooooooooooooo000001Sooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool02?ooool00olb
<S;oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001?ooool0
1?l0003oooooooooool00003ooooo`05onk^k_l0003oooooooooool000002?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0I_ooool007Oooooo00Go0000oooooooooooo
ooooo`000009ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`09ooooo`03oc8b<_oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Co
k^k^o`000?oooooooooo1_l00003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`03ooooo`Ko00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Ko
oooo001gooooo`05o`000?mgMgOoooooojVYZOl000006?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00[ooooo00?o0000
onk^k_ooool00_ooool02_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooooeEEEOmgMgL2oooo
o`0:ogMgMomEEEGooooooooooomVIVKoMgMgooooooo^k^koEEEEo`0000;ooooo00KoEEEEohN7Qoo^
k^koooooohN7Qolb<S83ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`03ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool01_l0003o<S8bomgMgOooooook^k^
o`0006Sooooo001gooooo`05o`000?mgMgOo0000o`000?nHV9P06?ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`0?oeEEEOmg
MgOoooooooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o0000
00[oEEEEonk^k_ooooooooooonk^k_mEEEGo0000oa0@4?o<c<co00000_ooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kP;ooooo00Co410@o`000?oooooooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o000000GoZJVYob4Q8Ol0003o3`l?
oeEEE@1Xooooo`00Moooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool03?ooool00ooMgMgo
410@onk^kP0Gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00oo^k^ko
410@omgMg@1Xooooo`00Moooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000<ooooo`03ogMgMomVIVKooooo
01Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03ofIVI_mgMgOooooo
06Sooooo001fooooo`03oa0@4?l0003ooooo05cooooo0_l0000Booooo`03oa0@4?l0003o000007co
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 364.875}, {435.75, 340.812}} -> {-6.63619, \
14.3605, 0.0508876, 0.043618}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Using NDSolve to generate numeric solutions", "Subsubsection"],
  " "
}], "Text"],

Cell["\<\
The function named NDSolve will generate numeric solutions to an \
IVP. Here, for example, is the numeric solution to the IVP used above. Recall \
that the equation looks like this.\
\>", "Text"],

Cell[CellGroupData[{

Cell["DE", "Input",
  CellLabel->"In[103]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "\[Equal]", \(Cos[t]\ y[t]\)}]], "Output",
  CellLabel->"Out[103]="]
}, Open  ]],

Cell["\<\
The input to NDSolve is the same as DSolve except that the \
independent variable is replaced with an interval.\
\>", "Text"],

Cell[CellGroupData[{

Cell["soln = NDSolve[ {DE,y[0]==1}, y, {t,0,10} ]", "Input",
  CellLabel->"In[104]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"y", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[104]="]
}, Open  ]],

Cell[TextData[{
  "The output is a sequence of approximate solution values (in this case from \
",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0 to ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 10) that will be interpolated by an \"interpolating function\" to any \
",
  StyleBox["t",
    FontSlant->"Italic"],
  " value from 0 to 10.\nValues can be obtained via substitution."
}], "Text"],

Cell[CellGroupData[{

Cell["y[2]/.soln", "Input",
  CellLabel->"In[105]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({2.4825775299128803`}\)], "Output",
  CellLabel->"Out[105]="]
}, Open  ]],

Cell["Plots are obtained the same way.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ y[t]/.soln, {t,0,10}, PlotRange->{0,3}, AspectRatio->1/3, 
      PlotLabel->\"Numeric solution\"]\
\>", "Input",
  CellLabel->"In[110]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.111111 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .05556 -18 -4.5 ]
[.01131 .05556 0 4.5 ]
[.01131 .11111 -6 -4.5 ]
[.01131 .11111 0 4.5 ]
[.01131 .16667 -18 -4.5 ]
[.01131 .16667 0 4.5 ]
[.01131 .22222 -6 -4.5 ]
[.01131 .22222 0 4.5 ]
[.01131 .27778 -18 -4.5 ]
[.01131 .27778 0 4.5 ]
[.01131 .33333 -6 -4.5 ]
[.01131 .33333 0 4.5 ]
[.5 .34583 -50 0 ]
[.5 .34583 50 12 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .05556 m
.03006 .05556 L
s
[(0.5)] .01131 .05556 1 0 Mshowa
.02381 .11111 m
.03006 .11111 L
s
[(1)] .01131 .11111 1 0 Mshowa
.02381 .16667 m
.03006 .16667 L
s
[(1.5)] .01131 .16667 1 0 Mshowa
.02381 .22222 m
.03006 .22222 L
s
[(2)] .01131 .22222 1 0 Mshowa
.02381 .27778 m
.03006 .27778 L
s
[(2.5)] .01131 .27778 1 0 Mshowa
.02381 .33333 m
.03006 .33333 L
s
[(3)] .01131 .33333 1 0 Mshowa
.125 Mabswid
.02381 .01111 m
.02756 .01111 L
s
.02381 .02222 m
.02756 .02222 L
s
.02381 .03333 m
.02756 .03333 L
s
.02381 .04444 m
.02756 .04444 L
s
.02381 .06667 m
.02756 .06667 L
s
.02381 .07778 m
.02756 .07778 L
s
.02381 .08889 m
.02756 .08889 L
s
.02381 .1 m
.02756 .1 L
s
.02381 .12222 m
.02756 .12222 L
s
.02381 .13333 m
.02756 .13333 L
s
.02381 .14444 m
.02756 .14444 L
s
.02381 .15556 m
.02756 .15556 L
s
.02381 .17778 m
.02756 .17778 L
s
.02381 .18889 m
.02756 .18889 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .21111 m
.02756 .21111 L
s
.02381 .23333 m
.02756 .23333 L
s
.02381 .24444 m
.02756 .24444 L
s
.02381 .25556 m
.02756 .25556 L
s
.02381 .26667 m
.02756 .26667 L
s
.02381 .28889 m
.02756 .28889 L
s
.02381 .3 m
.02756 .3 L
s
.02381 .31111 m
.02756 .31111 L
s
.02381 .32222 m
.02756 .32222 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
gsave
.5 .34583 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Numeric) show
111.000 13.000 moveto
(solution) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.02381 .11111 m
.06244 .16487 L
.10458 .23523 L
.12507 .26625 L
.13506 .27882 L
.14415 .28822 L
.14868 .29208 L
.1536 .29559 L
.15825 .29824 L
.16254 .30007 L
.16488 .30082 L
.16708 .30137 L
.16834 .3016 L
.16949 .30178 L
.17013 .30185 L
.17082 .30192 L
.17209 .302 L
.17277 .30202 L
.17342 .30203 L
.17463 .30201 L
.17593 .30193 L
.17666 .30186 L
.17734 .30177 L
.1797 .30137 L
.1809 .3011 L
.18221 .30075 L
.18472 .29991 L
.18745 .29877 L
.19241 .2961 L
.20172 .28907 L
.21258 .27786 L
.22263 .26505 L
.2619 .20216 L
.29965 .14165 L
.32062 .11393 L
.33985 .09319 L
.3587 .07705 L
.37854 .06407 L
.39828 .05459 L
.41665 .04834 L
.42717 .0457 L
.43711 .04378 L
.44602 .04249 L
.45106 .04193 L
.45569 .04152 L
.46037 .04121 L
.46299 .04108 L
.46539 .04099 L
.46761 .04093 L
.46887 .04091 L
Mistroke
.47004 .04089 L
.47116 .04088 L
.47218 .04088 L
.47335 .04088 L
.47446 .04088 L
.47566 .0409 L
.47697 .04092 L
.47835 .04095 L
.47963 .04099 L
.48192 .04107 L
.48438 .04119 L
.48999 .04156 L
.4951 .04203 L
.50504 .04329 L
.51422 .0449 L
.5243 .04719 L
.53499 .05028 L
.5545 .05786 L
.5728 .06767 L
.59302 .08217 L
.61154 .09936 L
.65121 .14996 L
.68937 .21246 L
.71067 .24751 L
.72999 .27469 L
.73965 .28545 L
.74473 .29015 L
.75011 .29433 L
.75482 .29728 L
.75731 .29856 L
.75999 .29972 L
.76245 .30058 L
.76469 .30119 L
.76577 .30143 L
.76695 .30164 L
.76806 .3018 L
.76908 .30191 L
.77026 .30199 L
.77149 .30203 L
.77255 .30202 L
.77371 .30197 L
.77496 .30187 L
.77565 .30178 L
.77629 .3017 L
.77869 .30124 L
.78092 .30065 L
.78334 .29983 L
.78773 .29785 L
.79293 .29473 L
.79844 .29053 L
Mistroke
.80832 .28088 L
.82787 .25525 L
.84617 .22607 L
.88496 .1614 L
.90469 .13231 L
.92621 .10565 L
.94544 .08656 L
.96594 .0708 L
.97619 .06449 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[110]:=",
  ImageSize->{288, 95.9375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000Mb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Koooool5o`0002kooooo0_l000000ol@413oooooooooo`0[ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool006oooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A00_ooooo`03o`000?oooooooooo02cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0/oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0:oooool0073ooooo00?oV9RHob4Q8Oo^k^h0;Oooool5o`0002gooooo00Go0000
ooooooooooooooooo`00000/ooooo`05o`000?ooooooooooooooool00000:oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:oooool0077ooooo00?oV9RHob4Q8Oo^k^h0
;?ooool01?m4A4CogMgMooooool0000^ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb
<S;oV9RHoooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000002_ooooo001booooo`03ogMgMomVIVKooooo02_ooooo00CogMgMoeEEEOoooooo0000;_oo
ool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<o`000?l0003o0000olc<c00[ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[ooooo`00Loooool00ol0003o
ooooooooo`0[ooooo`03ogMgMoo<c<co000002kooooo00?oEEEEohN7Qoooool0;_ooool01Ol@413o
^[Zjoooooonj^[[o410@02_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@02_ooooo001_ooooo`05o`000?nj^[[ooooooiRHV?l@4100;Oooool00oo^k^koA4A4o`00000^
ooooo`03omgMgOl@413oV9RH02kooooo00Go0000okZj^_oooooo^[Zjo`00000[ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`00Koooool01OnHV9So410@o`00
0?lQ8B7oc<c<02kooooo00?oMgMgo`000?ooool0;_ooool01?o<c<coA4A4o`000?l@410/ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0:Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0:oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool003_oooooool00004o`0002[ooooo0011ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0^ooooo`00@Oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool0047ooooo0_l0003oooooobKooooo
0011ooooo`03o`000?oooooooooo0?oooooo9Oooool0047ooooo00?o0000ooooooooool0oooooolU
ooooo`00@Oooool2o`000?oooooo9_ooool0047ooooo00?o0000ooooooooool0oooooolUooooo`00
@Oooool00ol0003oooooooooo`3oooooobGooooo0011ooooo`;o0000oooooolVooooo`00@Oooool0
0ol0003oooooooooo`3oooooobGooooo0011ooooo`03o`000?oooooooooo06Oooooo5Ol0002Xoooo
o`009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool2o`0006Gooooo0ol0000Eooooo`Go0000Xoooool002Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo067ooooo0ol0000Mooooo`;o0000XOooool002Oooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0ol0001Mooooo`Co00008_ooool3o`0009kooooo000Woooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo05_ooooo0_l0000Yooooo`;o0000W?ooool002Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo02_ooooo0_l0002Jooooo`009oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool2o`0005Wooooo0_l0000`ooooo`03o`000?oooooooooo06Gooooo0_l0
000`ooooo`009oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Fooooo`;o0000<oooool2o`0006?ooooo0_l0000booooo`009oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool0=Oooool2o`00063ooooo00?o0000ooooooooool0<_ooool0047ooooo0_l0001D
ooooo`;o0000>_ooool00ol0003oooooooooo`1Kooooo`;o0000=Oooool0047ooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool0=Oooool0047ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool0=_ooool0047ooooo0_l0001Aooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0gooooo`00@Ooo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`0hooooo`00@Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0iooooo`00>?ooool4o`00
0003oa0@4?oooooooooo00;ooooo0_l0001?ooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0jooooo`00>_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo03_ooooo000jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
>oooool003[ooooo00?o0000ooooooooool01?ooool3o`0004_ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03cooooo000jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0?Oooool003[ooooo00?o0000ooooooooool01?ooool2o`00
04_ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
03kooooo000jooooo`03o`000?oooooooooo00Cooooo0ol00019ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0nooooo`00>?ooool00omEEEGoIVIV
o`000006ooooo`04o`000?ooooooooooo`0004Oooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo03oooooo0011ooooo`04o`000?ooooooooooo`0004Ko
oooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo043o
oooo0011ooooo`;o00000_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`10ooooo`00@Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo047ooooo0011ooooo`;o00000oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`12
ooooo`00@Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo04;ooooo0011ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0@oooool0047ooooo0_l00006ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo04?ooooo000Xooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
A?ooool002[ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo04Gooooo000Zooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0AOooool0
02[ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0A_ooool002[ooooo00?o0000ooooooooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`16oooo
o`00:_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo04Oooooo000Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo04Sooooo000Xooooo`03oeEEEOmV
IVKo000000gooooo1?l00005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0B?oo
ool0047ooooo0_l0000;ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Wooooo0011ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0BOooool0047ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`1:ooooo`00@Oooool2o`0000gooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool0047ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`1;ooooo`00@Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo04cooooo000gooooo`Go00001Oooool2o`0000oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0C?ooool003Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0COooool003Sooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo04kooooo000iooooo`03oiRHV?lQ8B7ok^k^00Gooooo
0ol0000@ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo04kooooo000jooooo`03ogMgMomVIVKooooo00Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1?ooooo`00>oooool00ol0003oooooooooo`03
ooooo`;o00004_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`1?ooooo`00=oooool01Ol0003o^[ZjoooooonHV9So
410@00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo07Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1@ooooo`00=oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1A
ooooo`00@Oooool2o`0001Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1goooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0D_ooool0047ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1Booooo`00@Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo05?ooooo0011ooooo`;o00005_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Dooooo`00@Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05Cooooo0011ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0EOooool002Oooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo0_l0000Hooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Kooooo000Wooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0P?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo05Oooooo000Xooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Oo
oooo000Yooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool00oooool3o`0001[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0F?ooool002[ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo08Gooooo00?o0000ooooooooool03oooool2o`0005_ooooo000[ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo05_ooooo000Wooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooooooo
o`06ooooo`;o00007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Wooooo0_l0
000<ooooo`03o`000?oooooooooo05cooooo000Wooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000Gooooo00?o0000ooooooooool07Oooool2o`0000_ooooo00?o0000ooooooooool0S?oo
ool00ol0003oooooooooo`07ooooo`;o0000Goooool0047ooooo00?o0000ooooooooool07oooool2
o`0000Kooooo0ol0002@ooooo`;o00001_ooool00ol0003oooooooooo`1Oooooo`00@Oooool2o`00
02;ooooo1ol0002Cooooo`Oo0000H_ooool0047ooooo00?o0000ooooooooool0oooooolUooooo`00
@Oooool00ol0003oooooooooo`3oooooobGooooo0011ooooo`;o0000oooooolVooooo`00@Oooool0
0ol0003oooooooooo`3oooooobGooooo0011ooooo`;o0000oooooolVooooo`00=oooool01OnHV9So
410@o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolUooooo`00=oooool01Ol@413o
^[ZjoooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0oooooolUooooo`00>oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolUooooo`00>_ooool00onYZJWo410@ooooo`3oooooobcooooo
000iooooo`03oa0@4?l0003o^[Zj0?oooooo;Oooool003[ooooo00?o^[Zjob4Q8Oooool0ooooool/
ooooo`00=oooool01Ol@413oV9RHoooooonj^[[o00000?oooooo;Oooool003Oooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@3oooooobgooooo003oooooofWooooo003oooooofWooooo0020ooooo`06oa0@
4?l0003o0000oooooonj^[[o00001?ooool01_nHV9So0000o`000?mgMgOo0000oa0@40;o00000_oo
ool01ol0003oooooooooool0003o410@onk^k_mEEED00_l000001?m4A4Co^[Zjooooool@4105o`00
00Cooooo1Ol00003ooooo`05ofIVI_l0003o0000odA4A?o<c<`01_ooool01_l@413o<S8bo`000?l0
003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`Go00001?ooool01_nH
V9So0000o`000?mgMgOo0000oa0@40;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go0000
0_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`1Zooooo`00POooool01Ol0003ooooooooooolb<S;o000000Cooooo00Go0000
ojVYZOooooooQhN7o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooooomEEEGo
MgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@1_ooool01_l0003oZJVYoooooooooooo^[Zjo`00
00;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED4ooooo`03o`000?oooooooooo00Cooooo00Go
0000ojVYZOooooooQhN7o`000003ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001Oooool00ol0003o
ooooooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol0003ooooooooooooo
oooo000006gooooo0021ooooo`05o`000?oooooo^[Zjoa0@4?l000001?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05
okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06_ooooo0021ooooo`05o`000?oooooo
<S8boiRHV?l000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000005o`0000?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool0Joooool0087ooooo00Go0000ojVYZOl@413oooooo`000004ooooo`05o`00
0?ooooooooooooooool000000_ooool03_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooooeEE
EOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgMg@07ooooo`03o`000?oooooooooo
00;ooooo00KoIVIVogMgMoooooooooooohN7Qol00006ooooo`06o`000?nj^[[oooooonk^k_mgMgOo
00000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol0003oQhN7oooooonYZJWo0000
06gooooo0021ooooo`05o`000?l@413oV9RHooooool000000oooool01?l@413o0000ooooooooool2
o`00000<ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE0_l00000
1?m4A4Cok^k^ooooooooool2o`000004ojVYZOlQ8B7o0000ob4Q8@?ooooo00?o410@o`000?l00000
1?ooool01_o^k^koIVIVo`000?l0003oA4A4o`0000Kooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l0
0002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1?ooool00ol0003oooooooooo`03ooooo`04
oa0@4?l0003oooooooooo`;o000000?ooooooa0@4?l000001?l00004ooooo`03oa0@4?l0003o0000
00Cooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`03oa0@4?l0003oMgMg00;o000000?o
V9RHooooooooool0Joooool0087ooooo00Go0000oa0@4?ooooooooooo`000019ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0Qoooool0083ooooo00Co410@o`000?nYZJWooooo0ol0
000Uooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo07gooooo002/ooooo`03oa0@4?oooooooooo01kooooo00?o410@
o`000?l000006?ooool00ol@413oooooooooo`1mooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{77.875, 364.875}, {256.312, 161.375}} -> {-6.63619, \
6.53378, 0.0508876, 0.043618}}]
}, Open  ]],

Cell[TextData[{
  "The following matrix of values displaying ",
  StyleBox["t",
    FontSlant->"Italic"],
  "-values,  approximate ",
  StyleBox["y",
    FontSlant->"Italic"],
  "-values, and exact ",
  StyleBox["y",
    FontSlant->"Italic"],
  "-values shows that the numeric algorithm used by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is very accurate."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[{{t,approxy,exacty}},
     Table[ {t,y[t],g[t]}, {t,0,3,0.5} ]]/.soln[[1,1]]//MatrixForm\
\>", \
"Input",
  CellLabel->"In[124]:=",
  FormatType->InputForm],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"t", "approxy", "exacty"},
            {"0", "1.`", "1.`"},
            {"0.5`", "1.615146236807915`", "1.615146236807915`"},
            {"1.`", "2.3197766916647353`", "2.3197766916647353`"},
            {"1.5`", "2.711480315675588`", "2.711480315675588`"},
            {"2.`", "2.4825775299128803`", "2.4825775299128803`"},
            {"2.5`", "1.8193371988023734`", "1.8193371988023734`"},
            {"3.`", "1.151563004430646`", "1.151563004430646`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[124]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The following was copied from ",
  StyleBox["The Mathematica Book",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[StyleBox["For ordinary differential equations, NDSolve by \
default uses an LSODA approach, switching between a non\[Hyphen]stiff Adams \
method and a stiff Gear backward differentiation formula method. ", "Note"]], \
"Text"],

Cell["In addition", "Text"],

Cell[TextData[{
  StyleBox["NDSolve", "Note"],
  StyleBox[" supports explicit ", "Note"],
  StyleBox["Method", "Note"],
  StyleBox[" settings that cover most known methods from the literature. ", 
    "Note"]
}], "Text"],

Cell["See the Help page for NDSolve", "Text"],

Cell[CellGroupData[{

Cell["?NDSolve", "Input",
  CellLabel->"In[133]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{"\<\"NDSolve[eqns, y, {x, xmin, xmax}] finds a numerical solution \
to the ordinary differential equations eqns for the function y with the \
independent variable x in the range xmin to xmax. NDSolve[eqns, y, {x, xmin, \
xmax}, {t, tmin, tmax}] finds a numerical solution to the partial \
differential equations eqns. NDSolve[eqns, {y1, y2, ... }, {x, xmin, xmax}] \
finds numerical solutions for the functions yi.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"NDSolve",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3304069867-2173353"]
}, Open  ]],

Cell[TextData[{
  StyleBox["A preview of second order equations:",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["An aging spring",
    FontSlant->"Italic"]
}], "Text"],

Cell["\<\
Equations similar to the following second order differential \
equation are used as models for the position of a mass that is oscillating on \
an aging spring. See Ledder, Chapter 3, Section 7. \
\>", "Text"],

Cell[CellGroupData[{

Cell["agingspring = y''[t] + Exp[-0.2*t]*y[t] == 0", "Input",
  CellLabel->"In[134]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[ExponentialE]\^\(\(-0.2`\)\ t\)\ y[t]\), "+", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
      "0"}]], "Output",
  CellLabel->"Out[134]="]
}, Open  ]],

Cell[TextData[{
  "The exact solution formula for this equation requires special functions \
that are discussed in Appendix A2.  Given an IVP, the NDSolve solution works \
just as well.  The next entry generates that solution to the aging spring \
equation satisfying the initial conditions  ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 1 and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'(0) = 0. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
soln = NDSolve[ {agingspring, y[0]==1, y'[0]==0}, y, {t,0,40} \
]\
\>", "Input",
  CellLabel->"In[135]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"y", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 40.`}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[135]="]
}, Open  ]],

Cell[TextData[{
  "The following plot displays position and velocity of the spring for ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0 to ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 40. Position is red and thick, velocity is blue.\nNote the use of the \
Evaluate function."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ Evaluate[{y[t],y'[t]}/.soln], {t,0,40}, AspectRatio->1/3, 
      PlotStyle->{{RGBColor[1,0,0],Thickness[0.007]},RGBColor[0,0,1]} ]\
\>", \
"Input",
  CellLabel->"In[151]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.242875 0.0504499 [
[.2619 .23038 -6 -9 ]
[.2619 .23038 6 0 ]
[.5 .23038 -6 -9 ]
[.5 .23038 6 0 ]
[.7381 .23038 -6 -9 ]
[.7381 .23038 6 0 ]
[.97619 .23038 -6 -9 ]
[.97619 .23038 6 0 ]
[.01131 .04108 -12 -4.5 ]
[.01131 .04108 0 4.5 ]
[.01131 .09153 -12 -4.5 ]
[.01131 .09153 0 4.5 ]
[.01131 .14198 -12 -4.5 ]
[.01131 .14198 0 4.5 ]
[.01131 .19243 -12 -4.5 ]
[.01131 .19243 0 4.5 ]
[.01131 .29332 -6 -4.5 ]
[.01131 .29332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .24288 m
.2619 .24913 L
s
[(10)] .2619 .23038 0 1 Mshowa
.5 .24288 m
.5 .24913 L
s
[(20)] .5 .23038 0 1 Mshowa
.7381 .24288 m
.7381 .24913 L
s
[(30)] .7381 .23038 0 1 Mshowa
.97619 .24288 m
.97619 .24913 L
s
[(40)] .97619 .23038 0 1 Mshowa
.125 Mabswid
.07143 .24288 m
.07143 .24663 L
s
.11905 .24288 m
.11905 .24663 L
s
.16667 .24288 m
.16667 .24663 L
s
.21429 .24288 m
.21429 .24663 L
s
.30952 .24288 m
.30952 .24663 L
s
.35714 .24288 m
.35714 .24663 L
s
.40476 .24288 m
.40476 .24663 L
s
.45238 .24288 m
.45238 .24663 L
s
.54762 .24288 m
.54762 .24663 L
s
.59524 .24288 m
.59524 .24663 L
s
.64286 .24288 m
.64286 .24663 L
s
.69048 .24288 m
.69048 .24663 L
s
.78571 .24288 m
.78571 .24663 L
s
.83333 .24288 m
.83333 .24663 L
s
.88095 .24288 m
.88095 .24663 L
s
.92857 .24288 m
.92857 .24663 L
s
.25 Mabswid
0 .24288 m
1 .24288 L
s
.02381 .04108 m
.03006 .04108 L
s
[(-4)] .01131 .04108 1 0 Mshowa
.02381 .09153 m
.03006 .09153 L
s
[(-3)] .01131 .09153 1 0 Mshowa
.02381 .14198 m
.03006 .14198 L
s
[(-2)] .01131 .14198 1 0 Mshowa
.02381 .19243 m
.03006 .19243 L
s
[(-1)] .01131 .19243 1 0 Mshowa
.02381 .29332 m
.03006 .29332 L
s
[(1)] .01131 .29332 1 0 Mshowa
.125 Mabswid
.02381 .05117 m
.02756 .05117 L
s
.02381 .06126 m
.02756 .06126 L
s
.02381 .07135 m
.02756 .07135 L
s
.02381 .08144 m
.02756 .08144 L
s
.02381 .10162 m
.02756 .10162 L
s
.02381 .11171 m
.02756 .11171 L
s
.02381 .1218 m
.02756 .1218 L
s
.02381 .13189 m
.02756 .13189 L
s
.02381 .15207 m
.02756 .15207 L
s
.02381 .16216 m
.02756 .16216 L
s
.02381 .17225 m
.02756 .17225 L
s
.02381 .18234 m
.02756 .18234 L
s
.02381 .20252 m
.02756 .20252 L
s
.02381 .21261 m
.02756 .21261 L
s
.02381 .2227 m
.02756 .2227 L
s
.02381 .23279 m
.02756 .23279 L
s
.02381 .25297 m
.02756 .25297 L
s
.02381 .26305 m
.02756 .26305 L
s
.02381 .27314 m
.02756 .27314 L
s
.02381 .28323 m
.02756 .28323 L
s
.02381 .03099 m
.02756 .03099 L
s
.02381 .0209 m
.02756 .0209 L
s
.02381 .01081 m
.02756 .01081 L
s
.02381 .00072 m
.02756 .00072 L
s
.02381 .30341 m
.02756 .30341 L
s
.02381 .3135 m
.02756 .3135 L
s
.02381 .32359 m
.02756 .32359 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
1 0 0 r
.007 w
.02381 .29332 m
.06244 .24402 L
.08255 .20745 L
.08806 .19954 L
.09396 .19257 L
.09682 .1898 L
.09952 .18755 L
.10193 .18587 L
.10458 .18437 L
.10705 .18331 L
.10824 .18291 L
.10937 .1826 L
.11065 .18232 L
.11181 .18215 L
.11307 .18204 L
.11379 .18201 L
.11445 .18201 L
.11564 .18206 L
.11676 .18217 L
.11777 .18232 L
.11885 .18255 L
.1213 .18325 L
.12355 .18414 L
.12833 .18678 L
.13357 .19074 L
.14415 .20167 L
.18458 .26095 L
.20321 .28697 L
.21304 .29847 L
.22348 .30858 L
.22873 .31277 L
.23452 .3167 L
.23984 .31966 L
.24472 .32182 L
.24972 .32349 L
.25234 .32415 L
.2551 .3247 L
.25627 .32488 L
.25751 .32504 L
.25859 .32516 L
.25976 .32526 L
.26047 .32531 L
.26113 .32534 L
.26242 .32539 L
.2636 .3254 L
.26485 .32538 L
.26606 .32533 L
.26738 .32525 L
.26862 .32514 L
.26978 .32502 L
Mistroke
.27196 .32472 L
.27428 .3243 L
.2796 .32299 L
.28442 .32141 L
.29386 .31728 L
.30273 .31229 L
.34134 .28156 L
.38239 .24099 L
.42193 .20179 L
.45995 .16765 L
.50043 .13661 L
.53939 .11198 L
.58081 .09083 L
.6207 .0745 L
.65908 .06178 L
.69992 .05072 L
.73924 .04192 L
.77704 .03474 L
.8173 .02813 L
.85604 .02251 L
.89723 .01712 L
.9369 .01236 L
.97506 .00806 L
.97619 .00794 L
Mfstroke
0 0 1 r
.5 Mabswid
.02381 .24287 m
.03279 .22497 L
.04262 .20945 L
.04758 .20378 L
.0503 .20134 L
.05288 .19948 L
.05528 .19813 L
.05655 .19757 L
.05789 .19709 L
.05902 .19677 L
.06026 .19652 L
.06139 .19637 L
.06244 .1963 L
.0631 .19629 L
.06379 .19631 L
.06504 .19641 L
.06581 .19651 L
.06653 .19664 L
.06788 .19696 L
.06917 .19736 L
.07036 .1978 L
.07305 .19906 L
.07776 .20207 L
.08274 .2062 L
.10458 .23106 L
.12444 .25447 L
.13312 .26287 L
.14255 .27019 L
.14776 .27335 L
.15257 .2757 L
.15717 .27744 L
.16206 .27877 L
.16453 .27924 L
.16582 .27944 L
.16719 .27961 L
.16839 .27973 L
.1697 .27982 L
.17089 .27988 L
.172 .27991 L
.17269 .27991 L
.17343 .27991 L
.17413 .2799 L
.17478 .27988 L
.17601 .27982 L
.17731 .27973 L
.1787 .2796 L
.18001 .27945 L
.18298 .27901 L
.18796 .27797 L
.19338 .27645 L
Mistroke
.20326 .27285 L
.2218 .26414 L
.2625 .24333 L
.28133 .23529 L
.30168 .22848 L
.31286 .22559 L
.32313 .22345 L
.33295 .22183 L
.34331 .22053 L
.35282 .21968 L
.35814 .21934 L
.36299 .2191 L
.36751 .21893 L
.37006 .21886 L
.37242 .21881 L
.37448 .21878 L
.37565 .21876 L
.37675 .21875 L
.3779 .21874 L
.37896 .21874 L
.38012 .21874 L
.38134 .21874 L
.38258 .21874 L
.38328 .21874 L
.38392 .21875 L
.3851 .21876 L
.38636 .21877 L
.38852 .2188 L
.39091 .21884 L
.39619 .21897 L
.40112 .21914 L
.40999 .21951 L
.4195 .22003 L
.46083 .22302 L
.50064 .22631 L
.53894 .22927 L
.57969 .23197 L
.61892 .23407 L
.65664 .23566 L
.69681 .23696 L
.73547 .23792 L
.77657 .23867 L
.81617 .23921 L
.85424 .23959 L
.89477 .23989 L
.93378 .2401 L
.97525 .24026 L
.97619 .24027 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[151]:=",
  ImageSize->{346.438, 115.438},
  ImageMargins->{{41.5, 0}, {0, 10.25}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0000T2000`400?l00000o`00003ooooooonb
ooooo`00oooooonbooooo`005?ooool2o`000?ooooooW?ooool001Cooooo00?o0000ooooooooool0
oooooonKooooo`005?ooool00ol0003oooooooooo`3ooooooi_ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooR_ooool6ool000_ooooo000Dooooo`;o0000oooooon3ooooo`koo`002oooool001Co
oooo00?o0000ooooooooool0oooooomjoooooa7oo`004?ooool001Cooooo00?o0000ooooooooool0
oooooomaoooooa;oo`006?ooool001Cooooo00?o0000ooooooooool0oooooomYoooooa;oo`008?oo
ool001Cooooo0_l0003oooooof7ooooo4_oo000Yooooo`005?ooool00ol0003oooooooooo`3ooooo
oeSooooo4_oo000aooooo`005?ooool00ol0003oooooooooo`3oooooodoooooo4_oo000jooooo`00
5?ooool00ol0003oooooooooo`3oooooodSooooo4Ooo0012ooooo`005?ooool00ol0003ooooooooo
o`3ooooood;ooooo3_oo001;ooooo`005?ooool2o`000?oooooo?_ooool<ool005;ooooo000:oooo
o`;o000000?o410@ooooooooool01Oooool00ol0003oooooooooo`3oooooocSooooo2ooo001Hoooo
o`002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo<oooool;ool005go
oooo0006o`0000;ooooo1Ol00007ooooo`03o`000?oooooooooo0?oooooo;_ooool;ool006;ooooo
0008ooooo`04odA4A?oMgMgoooooo`0000Sooooo0ol0003oooooobWooooo2ooo001Wooooo`002?oo
ool01?oMgMgoEEEEooooool00008ooooo`03o`000?oooooooooo0?oooooo9Oooool:ool006cooooo
0009ooooo`03ogMgMoo<c<co000000Sooooo00?o0000ooooooooool0oooooolPooooo`[oo`00LOoo
ool000Wooooo00?ok^k^odA4A?l000002?ooool00ol0003oooooooooo`3ooooooacooooo2_oo001e
ooooo`002_ooool00omgMgOo0000ooooo`07ooooo`;o0000oooooolIooooo`Woo`00N_ooool001Co
oooo00?o0000ooooooooool0oooooolEooooo`Soo`00O_ooool001Cooooo00?o0000ooooooooool0
oooooolAooooo`Soo`00P_ooool001Cooooo00?o0000ooooooooool0ooooool>ooooo`Soo`00QOoo
ool001Cooooo0_l0003oooooo`cooooo1ooo0029ooooo`005?ooool00ol0003oooooooooo`3ooooo
o`Oooooo2?oo002<ooooo`005?ooool00ol0003oooooooooo`3oooooo`Cooooo2?oo002?ooooo`00
5?ooool00ol0003oooooooooo`3oooooo`7ooooo1ooo002Cooooo`005?ooool00ol0003ooooooooo
o`3mooooo`Ooo`00U_ooool001Cooooo0_l0003kooooo`Ooo`00VOooool001Cooooo00?o0000oooo
ooooool0moooool7ool009cooooo000Dooooo`03o`000?oooooooooo0?Cooooo1ooo002Oooooo`00
5?ooool00ol0003oooooooooo`3booooo`Koo`00X_ooool001Cooooo0_l0003`ooooo`Koo`00YOoo
ool001Cooooo00?o0000ooooooooool0kOooool6ool00:Oooooo0008ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`01oooool00ol0003oooooooooo`3[ooooo`Goo`00Z_ooool000Sooooo00Go410@okZj
^_ooooooMgMgoc8b<P07ooooo`03o`000?oooooooooo0>Sooooo1_oo002/ooooo`001_l00006oooo
o`03o`000?oooooooooo00Gooooo0ol0003Vooooo`Koo`00[_ooool000_ooooo00?oZJVYoa0@4?oo
ool01_ooool00ol0003oooooooooo`3Tooooo`Goo`00/Oooool000[ooooo00?o410@o`000?nj^[X0
1oooool00ol0003oooooooooo`3Rooooo`Goo`00/oooool000_ooooo00?o^[Zjob4Q8Oooool01_oo
ool00ol0003oooooooooo`3Pooooo`Goo`00]Oooool000Sooooo00Go410@oiRHV?oooooo^[Zjo`00
0007ooooo`;o0000goooool5ool00;Oooooo0008ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01ooo
ool00ol0003oooooooooo`3Looooo`Goo`00^Oooool001Cooooo00?o0000ooooooooool0f_ooool5
ool00;_ooooo000Dooooo`03o`000?oooooooooo0=Sooooo1Ooo002mooooo`005?ooool00ol0003o
ooooooooo`3Fooooo`Goo`00_oooool001Cooooo0_l0003Eooooo`Goo`00`Oooool001Cooooo00?o
0000ooooooooool0doooool4ool00<?ooooo000Dooooo`03o`000?oooooooooo0=7ooooo1?oo0035
ooooo`005?ooool00ol0003oooooooooo`3?ooooo`Goo`00a_ooool001Cooooo0_l0003?ooooo`Co
o`00b?ooool001Cooooo00?o0000ooooooooool0c?ooool4ool00<[ooooo000Dooooo`03o`000?oo
oooooooo0<_ooooo1?oo003;ooooo`005?ooool00ol0003oooooooooo`39ooooo`Coo`00cOooool0
01Cooooo0_l00038ooooo`Goo`00c_ooool001Cooooo00?o0000ooooooooool0a_ooool4ool00=3o
oooo0008ooooo`Go00001oooool00ol0003oooooooooo`34ooooo`Coo`00d_ooool000Sooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03o`000?oooooooooo0<?ooooo1?oo003Cooooo`001_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Sooooo0ol00032ooooo`?oo`00eOooool000[ooooo00?oV9RH
ob4Q8Oo^k^h01oooool00ol0003oooooooooo`30ooooo`Coo`00e_ooool000_ooooo00?oMgMgofIV
I_ooool01_ooool00ol0003oooooooooo`2oooooo`Coo`00eoooool000cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2nooooo`?oo`00fOooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4007ooooo`03o`000?oooooooooo0;cooooo1?oo003Jooooo`002?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00Oooooo0_l0002looooo`Coo`00foooool001Cooooo00?o0000ooooooooool0
^_ooool3ool00=gooooo000Dooooo`03o`000?oooooooooo0;Wooooo0ooo003Nooooo`005?ooool0
0ol0003oooooooooo`2gooooo`Coo`00goooool001Cooooo0_l0002gooooo`Coo`00h?ooool001Co
oooo00?o0000ooooooooool0]Oooool3ool00>;ooooo000Dooooo`03o`000?oooooooooo0;?ooooo
1?oo003Sooooo`005?ooool00ol0003oooooooooo`2booooo`Coo`00i?ooool001Cooooo0_l0002b
ooooo`?oo`00i_ooool001Cooooo00?o0000ooooooooool0/?ooool3ool00>Oooooo000Dooooo`03
o`000?oooooooooo0:oooooo0ooo003Xooooo`005?ooool00ol0003oooooooooo`2^ooooo`?oo`00
jOooool001Cooooo0_l0000Qooooo`Goo`00R?ooool3ool00>[ooooo000Dooooo`03o`000?oooooo
oooo01kooooo2ooo0023ooooo`?oo`00joooool000Wooooo1?l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo01gooooo1Ooo0002ooooo`Koo`00POooool3ool00>cooooo000;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool3ool000Wooooo0ooo001oooooo`?o
o`00kOooool000Ko00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo
1?oo000;ooooo`?oo`00OOooool3ool00>kooooo000;ooooo`03o`000?oooooooooo00Kooooo0ol0
000Iooooo`Coo`003Oooool3ool007_ooooo0ooo003_ooooo`002oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00cooooo0ol00?l:ooooo`;oo`004?ooool3ool007Wooooo0ooo003`
ooooo`002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0ol00?l2oooo
o`?o003o1_ooool3ool0017ooooo0ooo001gooooo`?oo`00lOooool000_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`08ooooo`;o003o2?ooool2o`00o`?ooooo0ooo000Cooooo`?o
o`00MOooool3ool00?;ooooo0009ooooo`03oeEEEOmVIVKo000000Sooooo0_l00009ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool00_oo000Eooooo`?oo`00L_ooool4ool00??ooooo
000Dooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool02oooool01?l00?ooo`00ool0
0?oo000Fooooo`;oo`00LOooool4ool00?Cooooo000Dooooo`03o`000?oooooooooo00Kooooo00?o
003oooooooooool03?ooool00ooo003o003oool0000Gooooo`?oo`00Koooool3ool00?Kooooo000D
ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool03Oooool00ooo003o003oooooo`0H
ooooo`?oo`00:?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hiooooo`?o
o`007?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Gooooo`05oiRHV?l@413o0000
oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^05Wooooo0_l000002Ol@413ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`005?ooool2o`0000Kooooo00?o003ooooooooo
ool03?ooool3ool00003o`00oooooooooooo01Oooooo0_oo000Zooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`?oo`007Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Gooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg05[ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o003ooooooooo
ool03?ooool3ool000;ooooo00?o003oooooooooool05_ooool3ool002Wooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Oooooo0ooo000Oooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@401Kooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`1Eooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Kooooo
000Dooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool03Oooool2ool000Cooooo00?o
003oooooooooool05_ooool3ool002Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000003Kooooo0ooo000Qooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`00001Jooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00001Goooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`005?ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00cooooo0ooo0005ooooo`03o`00oooooooo
oooo01Kooooo0_oo000Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Oooooob?o003o6Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
FOooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000Eoooool01?oMgMgo
EEEEooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool001Cooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`0=ooooo`;oo`001oooool00ol00?ooooooooooo`0Eoooo
o`?oo`009oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool9
o`00oaGooooo0ooo000;ooooo`Wo003o4Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool0F?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
F?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001_ooool001Cooooo
0_l00002ooooo`03o`00oooooooooooo00gooooo0ooo0008ooooo`03o`00oooooooooooo01Gooooo
0ooo000Vooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`Co
003o7Oooool3ool001Gooooo3Ol00?l01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`1Gooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg05Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo000Dooooo`05o`000?ooooooooooooooool00?l03_ooool3ool000[ooooo00?o003ooooooooo
ool05Oooool2ool002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo1?l00?lPooooo`?oo`008oooool@o`00oeCooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0FOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool001Cooooo00Co0000oooooooooooo003o3oooool2ool000cooooo
00?o003oooooooooool05?ooool3ool003Wooooo1?l00?lSooooo`?oo`00=?oooolAo`00ok[ooooo
000Dooooo`04o`000?ooooooooooo`00o`kooooo0ooo000=ooooo`03o`00oooooooooooo01Cooooo
0ooo000eooooo`?o003o9_ooool3ool004Kooooo4Ol00?nYooooo`005?ooool2o`000003o`00oooo
oooooooo00gooooo0_oo000>ooooo`03o`00oooooooooooo01Gooooo0ooo000aooooo`?o003o:?oo
ool3ool005Sooooo4?l00?nIooooo`005?ooool00ol0003oooooo`00o`0>ooooo`?oo`003oooool0
0ol00?ooooooooooo`0Eooooo`;oo`00;_ooool3o`00ob[ooooo0ooo001Yoooooa7o003oR?ooool0
01Cooooo00?o0000o`00ooooool03Oooool3ool0017ooooo00?o003oooooooooool05?ooool3ool0
02[ooooo0ol00?l/ooooo`?oo`00Nooooom2o`00odKooooo000Dooooo`03o`000?l00?oooooo00go
oooo0_oo000Cooooo`03o`00oooooooooooo01Cooooo0ooo000Vooooo`?o003o;_ooool3ool00;ko
oooo>ol00?l;ooooo`002_ooool:o`000003o`00ool0003o000000co00000ooo000Do`000003o`00
ool0003o000001Co00000_oo000To`0000;o003o<?l00003ool00?oo00001Ol00001ooooo`005?oo
ool00ol0003oooooooooo`0<ooooo`;oo`000oooool00ol0003oooooooooo`0?ooooo`03o`00oooo
oooo000001?ooooo00Co0000ool00?oo003oo`004?ooool00ol0003oooooooooo`0>ooooo`;o003o
00?oooooo`000?ooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo
0ooo0009ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Wooooo000Dooooo`03o`000?oooooooooo00_ooooo0ooo
0003ooooo`03o`000?oooooooooo013ooooo00?o003oo`000?ooool04_ooool00ol0003oooooool0
0002ool000oooooo00?o0000ooooooooool03?ooool2o`00o`?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo0ooo000:ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Wooooo000Dooooo`03o`000?oooooooooo00[ooooo0ooo000Hooooo`03o`00oooooooo
oooo01Cooooo0_oo000Looooo`;o003o1Oooool00ol0003oooooooooo`0[ooooo`?oo`00=?ooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool02Oooool0
01Cooooo0_l0000:ooooo`?oo`006_ooool00ol00?ooooooooooo`0Cooooo`?oo`006Oooool2o`00
ocCooooo0ooo003oooooo`[ooooo000Dooooo`03o`000?oooooooooo00Wooooo0_oo000Looooo`;o
003o5?ooool3ool001Oooooo00?o003oooooooooool0<oooool3ool00?oooooo2oooool001Cooooo
00?o0000ooooooooool02?ooool3ool001kooooo00?o003oooooooooool04_ooool2ool001Gooooo
0_l00?leooooo`?oo`00ooooool<ooooo`005?ooool00ol0003oooooooooo`07ooooo`?oo`008?oo
ool00ol00?ooooooooooo`0Aooooo`?oo`004_ooool2o`00ocKooooo0ooo003oooooo`gooooo000D
ooooo`03o`000?oooooooooo00Kooooo0ooo000Rooooo`03o`00oooooooooooo017ooooo0ooo000?
ooooo`;o003o=oooool3ool00?oooooo3_ooool001Cooooo0_l00007ooooo`;oo`009?ooool00ol0
0?ooooooooooo`0Aooooo`;oo`003Oooool2o`00ocSooooo0ooo003oooooo`oooooo000Dooooo`03
o`000?oooooooooo00Gooooo0ooo000Uooooo`03o`00oooooooooooo013ooooo0ooo000:ooooo`;o
003o>Oooool3ool00?oooooo4?ooool001Cooooo00?o0000ooooooooool01?ooool3ool002Oooooo
00?o003oooooooooool04?ooool3ool000Oooooo0_l00?ljooooo`?oo`00oooooolAooooo`005?oo
ool00ol0003oooooooooo`03ooooo`?oo`00:Oooool2o`00oa7ooooo0_oo0005ooooo`;o003o>ooo
ool3ool00?oooooo4_ooool001Cooooo0_l00003ooooo`?oo`00;?ooool2o`00o`oooooo0ooo0000
1?oooooo003oo`00ool00?llooooo`?oo`00oooooolCooooo`005?ooool00ol0003oooooooooo`02
ooooo`;oo`00;oooool2o`00o`kooooo0ol00?lnooooo`?oo`00oooooolDooooo`005?ooool01?l0
003oooooooooooooool3ool0037ooooo1Ol00?l5ooooo`Co003o00?oooooool00?oo0000?Oooool3
ool00?oooooo5Oooool001Cooooo00?o0000ooooooooool00ooo000fooooo`Ko003o1Oooool3ool0
03[ooooo1?oo003ooooooaKooooo000Dooooo`;o00000ooo0013ooooo`;oo`00>Oooool4ool00?oo
oooo5oooool001Cooooo00Co0000oooooooo003oo`00A?ooool3ool003Oooooo0ooo003ooooooaWo
oooo0009ooooo`Co000000?o410@ooooooooool01?ooool01?l0003oo`00ool00?oo0015ooooo`Co
o`00<oooool4ool00?oooooo6_ooool000_ooooo00?o0000ooooooooool01_ooool3ool004Oooooo
1?oo000aooooo`Coo`00oooooolKooooo`002oooool00ol0003oooooooooo`05ooooo`?oo`0000?o
0000ooooooooool0Aoooool3ool002oooooo0ooo003ooooooagooooo000;ooooo`03o`000?oooooo
oooo00Gooooo0_oo001<ooooo`?oo`00;?ooool4ool00?oooooo7_ooool000_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1;ooooo`?oo`00:_ooool4ool00?oooooo7oooool000_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1<ooooo`;oo`00:Oooool3ool00?oo
oooo8Oooool000_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1<ooooo`?oo`00
9oooool3ool00?oooooo8_ooool000Wooooo00?oEEEEofIVI_l000002?ooool2o`0004kooooo0ooo
000Tooooo`Coo`00oooooolSooooo`005?ooool00ol0003oooooooooo`1>ooooo`?oo`008_ooool4
ool00?oooooo9?ooool001Cooooo00?o0000ooooooooool0Coooool4ool001oooooo0ooo003ooooo
obKooooo000Dooooo`03o`000?oooooooooo053ooooo1Ooo000Kooooo`Coo`00oooooolWooooo`00
5?ooool2o`0005?ooooo1?oo000Iooooo`Coo`00oooooolXooooo`005?ooool00ol0003ooooooooo
o`1Dooooo`Coo`005Oooool4ool00?oooooo:_ooool001Cooooo00?o0000ooooooooool0EOooool5
ool0017ooooo1Ooo003oooooob_ooooo000Dooooo`03o`000?oooooooooo05Oooooo1Ooo000=oooo
o`Goo`00ooooool]ooooo`005?ooool2o`0005[ooooo1Ooo0007ooooo`Ooo`00ooooool_ooooo`00
5?ooool00ol0003oooooooooo`1Kooooo`ooo`00oooooolaooooo`005?ooool00ol0003ooooooooo
o`1Mooooo`Woo`00ooooooleooooo`005?ooool00ol0003oooooooooo`3ooooooi_ooooo000Doooo
o`03o`000?oooooooooo0?ooooooVoooool00?oooooo/_ooool00001\
\>"],
  ImageRangeCache->{{{119.375, 464.812}, {585, 470.562}} -> {-16.8863, \
22.7835, 0.124537, 0.0587746}}]
}, Open  ]],

Cell["\<\
The last plot of velocity versus position is called the phase plane \
trajectory. It requires the use of parametric plot.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot[ {y[t],y'[t]}/.soln, {t,0,40},
                 AxesLabel->{\"position\",\"velocity\"} ]\
\>", "Input",
  CellLabel->"In[153]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.728626 0.15135 0.342624 0.355101 [
[.12323 .33012 -6 -9 ]
[.12323 .33012 6 0 ]
[.27458 .33012 -6 -9 ]
[.27458 .33012 6 0 ]
[.42593 .33012 -6 -9 ]
[.42593 .33012 6 0 ]
[.57728 .33012 -6 -9 ]
[.57728 .33012 6 0 ]
[.87998 .33012 -3 -9 ]
[.87998 .33012 3 0 ]
[1.025 .34262 0 -6 ]
[1.025 .34262 52 6 ]
[.71613 .0763 -30 -4.5 ]
[.71613 .0763 0 4.5 ]
[.71613 .16507 -24 -4.5 ]
[.71613 .16507 0 4.5 ]
[.71613 .25385 -30 -4.5 ]
[.71613 .25385 0 4.5 ]
[.71613 .4314 -24 -4.5 ]
[.71613 .4314 0 4.5 ]
[.71613 .52017 -18 -4.5 ]
[.71613 .52017 0 4.5 ]
[.71613 .60895 -24 -4.5 ]
[.71613 .60895 0 4.5 ]
[.72863 .64303 -26 0 ]
[.72863 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12323 .34262 m
.12323 .34887 L
s
[(-4)] .12323 .33012 0 1 Mshowa
.27458 .34262 m
.27458 .34887 L
s
[(-3)] .27458 .33012 0 1 Mshowa
.42593 .34262 m
.42593 .34887 L
s
[(-2)] .42593 .33012 0 1 Mshowa
.57728 .34262 m
.57728 .34887 L
s
[(-1)] .57728 .33012 0 1 Mshowa
.87998 .34262 m
.87998 .34887 L
s
[(1)] .87998 .33012 0 1 Mshowa
.125 Mabswid
.1535 .34262 m
.1535 .34637 L
s
.18377 .34262 m
.18377 .34637 L
s
.21404 .34262 m
.21404 .34637 L
s
.24431 .34262 m
.24431 .34637 L
s
.30485 .34262 m
.30485 .34637 L
s
.33512 .34262 m
.33512 .34637 L
s
.36539 .34262 m
.36539 .34637 L
s
.39566 .34262 m
.39566 .34637 L
s
.4562 .34262 m
.4562 .34637 L
s
.48647 .34262 m
.48647 .34637 L
s
.51674 .34262 m
.51674 .34637 L
s
.54701 .34262 m
.54701 .34637 L
s
.60755 .34262 m
.60755 .34637 L
s
.63782 .34262 m
.63782 .34637 L
s
.66809 .34262 m
.66809 .34637 L
s
.69836 .34262 m
.69836 .34637 L
s
.7589 .34262 m
.7589 .34637 L
s
.78917 .34262 m
.78917 .34637 L
s
.81944 .34262 m
.81944 .34637 L
s
.84971 .34262 m
.84971 .34637 L
s
.09296 .34262 m
.09296 .34637 L
s
.06269 .34262 m
.06269 .34637 L
s
.03242 .34262 m
.03242 .34637 L
s
.00215 .34262 m
.00215 .34637 L
s
.91025 .34262 m
.91025 .34637 L
s
.94052 .34262 m
.94052 .34637 L
s
.97079 .34262 m
.97079 .34637 L
s
.25 Mabswid
0 .34262 m
1 .34262 L
s
gsave
1.025 .34262 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72863 .0763 m
.73488 .0763 L
s
[(-0.75)] .71613 .0763 1 0 Mshowa
.72863 .16507 m
.73488 .16507 L
s
[(-0.5)] .71613 .16507 1 0 Mshowa
.72863 .25385 m
.73488 .25385 L
s
[(-0.25)] .71613 .25385 1 0 Mshowa
.72863 .4314 m
.73488 .4314 L
s
[(0.25)] .71613 .4314 1 0 Mshowa
.72863 .52017 m
.73488 .52017 L
s
[(0.5)] .71613 .52017 1 0 Mshowa
.72863 .60895 m
.73488 .60895 L
s
[(0.75)] .71613 .60895 1 0 Mshowa
.125 Mabswid
.72863 .09405 m
.73238 .09405 L
s
.72863 .11181 m
.73238 .11181 L
s
.72863 .12956 m
.73238 .12956 L
s
.72863 .14732 m
.73238 .14732 L
s
.72863 .18283 m
.73238 .18283 L
s
.72863 .20058 m
.73238 .20058 L
s
.72863 .21834 m
.73238 .21834 L
s
.72863 .23609 m
.73238 .23609 L
s
.72863 .2716 m
.73238 .2716 L
s
.72863 .28936 m
.73238 .28936 L
s
.72863 .30711 m
.73238 .30711 L
s
.72863 .32487 m
.73238 .32487 L
s
.72863 .36038 m
.73238 .36038 L
s
.72863 .37813 m
.73238 .37813 L
s
.72863 .39589 m
.73238 .39589 L
s
.72863 .41364 m
.73238 .41364 L
s
.72863 .44915 m
.73238 .44915 L
s
.72863 .46691 m
.73238 .46691 L
s
.72863 .48466 m
.73238 .48466 L
s
.72863 .50242 m
.73238 .50242 L
s
.72863 .53793 m
.73238 .53793 L
s
.72863 .55568 m
.73238 .55568 L
s
.72863 .57344 m
.73238 .57344 L
s
.72863 .59119 m
.73238 .59119 L
s
.72863 .05854 m
.73238 .05854 L
s
.72863 .04079 m
.73238 .04079 L
s
.72863 .02303 m
.73238 .02303 L
s
.72863 .00528 m
.73238 .00528 L
s
.25 Mabswid
.72863 0 m
.72863 .61803 L
s
gsave
.72863 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.87998 .34262 m
.87979 .32518 L
.87931 .3095 L
.87838 .29165 L
.87714 .27508 L
.87569 .26002 L
.87409 .24639 L
.86961 .2166 L
.8639 .18818 L
.85632 .15897 L
.84707 .13103 L
.83727 .10739 L
.82599 .08544 L
.81439 .06727 L
.80322 .0531 L
.79074 .04047 L
.7767 .02967 L
.76329 .0223 L
.75494 .01903 L
.75081 .01776 L
.747 .0168 L
.73984 .01548 L
.73607 .01505 L
.73207 .01479 L
.72829 .01472 L
.72417 .01483 L
.71669 .01557 L
.70943 .01691 L
.70275 .01868 L
.69559 .02116 L
.68777 .02456 L
.67221 .03345 L
.65909 .04325 L
.64547 .05579 L
.62247 .08311 L
.59834 .12212 L
.57748 .16872 L
.5637 .21137 L
.55763 .23619 L
.55312 .25946 L
.55135 .27065 L
.54975 .28249 L
.5486 .29269 L
.54761 .3036 L
.54715 .30969 L
.54681 .31524 L
.54631 .32605 L
.54614 .33205 L
.54604 .33856 L
.54603 .34467 L
Mistroke
.54608 .3503 L
.54639 .3611 L
.5469 .37114 L
.54755 .38003 L
.54845 .3895 L
.55119 .41026 L
.55456 .42861 L
.5624 .45901 L
.56785 .4751 L
.57356 .48931 L
.58676 .51554 L
.60314 .53984 L
.62292 .56147 L
.64283 .57733 L
.65374 .58406 L
.66608 .59026 L
.67927 .5954 L
.68526 .59728 L
.69186 .59903 L
.69735 .60025 L
.70323 .60132 L
.70947 .6022 L
.71528 .60278 L
.72111 .60316 L
.72661 .60332 L
.73155 .60331 L
.7369 .60313 L
.74277 .60274 L
.74609 .60243 L
.7492 .60208 L
.75597 .60114 L
.76212 .60006 L
.77319 .59758 L
.78494 .59422 L
.80622 .58622 L
.82798 .57543 L
.86426 .55115 L
.89836 .51979 L
.92919 .48127 L
.94058 .46321 L
.95085 .44401 L
.9583 .42743 L
.9648 .40984 L
.97014 .39119 L
.97197 .383 L
.97358 .37422 L
.97437 .36893 L
.97497 .36409 L
.97542 .35959 L
.97562 .35723 L
Mistroke
.9758 .35469 L
.97603 .35035 L
.97616 .34632 L
.97619 .34398 L
.97619 .34177 L
.97612 .33764 L
.97597 .33366 L
.97584 .33143 L
.9757 .3294 L
.97539 .32577 L
.97496 .32182 L
.974 .31509 L
.9727 .30815 L
.96871 .29313 L
.96375 .27996 L
.95805 .26831 L
.95204 .25835 L
.93593 .23821 L
.92654 .2292 L
.91576 .22048 L
.89454 .20694 L
.86949 .19524 L
.85438 .18983 L
.83975 .18552 L
.81149 .17933 L
.79693 .17705 L
.7808 .17515 L
.76684 .17398 L
.75899 .1735 L
.75185 .17317 L
.74516 .17294 L
.74139 .17284 L
.73791 .17278 L
.73486 .17274 L
.73151 .17272 L
.72801 .17271 L
.72474 .17272 L
.72093 .17276 L
.7188 .17279 L
.71687 .17282 L
.70959 .17299 L
.7055 .17312 L
.70109 .17329 L
.69312 .17367 L
.67758 .17464 L
.6634 .17579 L
.63666 .17859 L
.60902 .18227 L
.50611 .20167 L
.41243 .22517 L
Mistroke
.33804 .24647 L
.27413 .2658 L
.2248 .28081 L
.18637 .29216 L
.15301 .30141 L
.12646 .30811 L
.10481 .31296 L
.08488 .31681 L
.06796 .31954 L
.05176 .32167 L
.03743 .32316 L
.02451 .32422 L
.02381 .32427 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[153]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00d?ooool00ol0003oooooooooo`2Eooooo`00d?ooool00ol0003oooooooooo`2Eooooo`00
d?ooool3o`0009Gooooo003@ooooo`03o`000?oooooooooo09Gooooo003>ooooo`Ko0000U?ooool0
0<Sooooo1_l00002ooooo`04o`000?ooooooooooooooo`Co0000T?ooool00<Kooooo0_l00008oooo
o`03o`000?oooooooooo00Gooooo1?l0002<ooooo`00a?ooool2o`0000[ooooo0ol00009ooooo`03
o`000?oooooooooo08Wooooo0032ooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo08Sooooo0031ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool2o`0008Sooooo002oooooo`;o00003oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo08Gooooo002nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`24ooooo`00_Oooool00ol0003oooooooooo`0@ooooo`?o00003oooool2o`0008Co
oooo002looooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`21ooooo`00^oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0P?ooool00;[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo07oooooo002iooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1oooooo`00^Oooool00ol0003oooooooooo`0Dooooo`?o
00005?ooool00ol0003oooooooooo`1nooooo`00^?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0OOooool00:kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP04ooooo`03o`000?lQ8B7o8B4Q00Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1looooo`00
[_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooolQ8B7o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`1looooo`00Y_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4002oooo
o`03o`000?oooooooooo00Sooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Noooool00:kooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000cooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03
ooooo`?o00005oooool00ol0003oooooooooo`1kooooo`00[_ooool01?l0003oooooooooooooool2
o`0000gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1jooooo`00[_ooool01Ol@413ooooooooooooo
oooo000000kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0N_ooool00:kooooo00GoMgMgoiRHV?ooooooV9RHo`00
000;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0NOooool00:kooooo00Gok^k^oc8b<_l0003o0000
onk^kP0;ooooo`Go00001?ooool4o`0000Gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1iooooo`00/?ooool00ol0003oooooooooo`0Mooooo`?o00006_ooool00ol0003ooooooooo
o`1hooooo`00/?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0Moooool00:oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo07Oooooo002^ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1fooooo`00[_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0MOooool00:gooooo00?o0000ooooooooool08?oo
ool3o`0001gooooo00?o0000ooooooooool0MOooool00:gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07Gooooo002/ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1dooooo`00Zoooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0M?ooool00:_ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Cooooo
002Zooooo`03o`000?oooooooooo02?ooooo0ol0000Oooooo`03o`000?oooooooooo07?ooooo002Z
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1c
ooooo`00ZOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0Loooool00:Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo07;ooooo002Xooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`1booooo`00Z?ooool00ol0003oooooooooo`0Uooooo`?o00008?oo
ool00ol0003oooooooooo`1booooo`00Z?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0LOooool00:Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo077ooooo002Wooooo`03o`000?oooooooooo00co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1aooooo`00Y_ooool00ol0
003oooooooooo`0=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo073ooooo002Voooo
o`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`?o00008_ooool00ol0003oooooooooo`1`ooooo`00YOooool00ol0
003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0L?ooool00:Gooooo00?o0000oooo
ooooool03_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Koooool00:Gooooo00?o0000
ooooooooool03_ooool01Ol@413ooooooooooooooooo410@00Gooooo8ol0000Cooooo`03o`000?oo
oooooooo06oooooo002Tooooo`03o`000?oooooooooo00_ooooo3_l00007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04?ooool4o`0000oooooo00?o0000ooooooooool0Koooool0
0:Cooooo00?o0000ooooooooool01Oooool6o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00001Oooool00ol0003oooooooooo`0Dooooo`Ko00002Oooool00ol0003oooooooooo`1_
ooooo`00Y?ooool00ol0003oooooooooo`05o`0002Cooooo0ol0000Jooooo`Go00001Oooool00ol0
003oooooooooo`1^ooooo`00X_ooool5o`0002Wooooo00?o0000ooooooooool07oooool3o`0000;o
oooo00?o0000ooooooooool0K_ooool009gooooo1Ol000000ooooooo0000ooooo`0[ooooo`03o`00
0?oooooooooo02;ooooo0ol0001`ooooo`00V?ooool5o`0000Kooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Tooooo`Co0000KOooool009?ooooo1Ol0000:ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03o`0006[ooooo002?oooo
o`Co00003oooool00ol0003oooooooooo`0[ooooo`?o00009Oooool00ol0003oooooooooo`03oooo
o`;o0000J?ooool008_ooooo1?l0000Cooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`05ooooo`;o0000I_ooool008Oooooo1?l0000Fooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo06?ooooo0023ooooo`Co00006_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01oooool2o`0006?ooooo0020ooooo`?o00007_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Pooooo`00O?ooool4o`00027ooooo00?o0000ooooooooool0;?ooool3o`00
02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Oooooo`00N?ooool4o`0002Co
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0G_ooool007Cooooo1?l0000Xooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05gooooo
001`ooooo`Co0000;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool03Oooool2o`0005gooooo001]ooooo`?o0000;oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1J
ooooo`00JOooool4o`0003;ooooo00?o0000ooooooooool0;_ooool3o`0002Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1Iooooo`00IOooool4o`0003Kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0FOooool006;ooooo0ol0000jooooo`03o`000?oooooooooo00cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Hoooo
o`00G_ooool4o`0003gooooo00?o0000ooooooooool03?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1G
ooooo`00Foooool3o`00043ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0E_ooool0
05Oooooo1?l00013ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool3o`0002Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1Eooooo`00Doooool4o`0004Oooooo00?o0000oooo
ooooool03Oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo05Cooooo001@ooooo`?o0000Boooool00ol0003oooooooooo`0=
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo05Cooooo001=ooooo`?o0000C_ooool00ol0003oooooooooo`0=ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
Doooool004[ooooo0ol0001Aooooo`03o`000?oooooooooo00gooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05?ooooo0017ooooo`?o0000
E?ooool00ol0003oooooooooo`0_ooooo`?o0000:?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo05?ooooo0014ooooo`?o0000Eoooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Booooo`00@Oooool3
o`0005Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0DOooool003kooooo0ol0001Looooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
057ooooo000jooooo`Co0000Goooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Aooooo`00=oooool3o`0006?ooooo
00?o0000ooooooooool0<?ooool3o`0002Sooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`1@ooooo`00<oooool4o`0006Kooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0D?ooool0033ooooo0ol0001Z
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo053ooooo000Vooooo`;o000000?o410@ooooooooool00_ooool3o`00
01oooooo00GoV9RHoa0@4?l0003o<S8bolc<c00Wooooo`Go00007Oooool00ol0003oooooooooo`07
ooooo`Co000000?o410@ooooooooool08_ooool00ol0003oooooooooo`0Wooooo`Co000000?o410@
ooooooooool05?ooool00ol0003oooooooooo`1@ooooo`009oooool6o`0002;ooooo00Go410@okZj
^_ooooooMgMgoc8b<P0Wooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04oooooo000Looooo`Ko000000?oooooo`000?l000001?l0000N
ooooo`Ko00001_ooool00ol0003oooooooooo`0Mooooo`Ko00000oooool00onHV9So8B4Qonk^kP0N
ooooo`Oo00001Oooool00ol0003oooooooooo`0Tooooo`?o0000:Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo04oooooo000Pooooo`?o000000GoooooodA4A?oMgMgoooooo`00000Z
ooooo`03ojVYZOl@413ooooo02Sooooo00?oV9RHob4Q8Oo^k^h07?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo04oooooo000Kooooo`Go00001?ooool01?oMgMgoEEEEooooool0000Y
ooooo`03oa0@4?l0003o^[Zj02[ooooo00?oMgMgofIVI_ooool06oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo04kooooo000Fooooo`Go00002_ooool00omgMgOoc<c<o`00000Zoooo
o`03okZj^_lQ8B7ooooo02[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo04kooooo000<ooooo`[o00003oooool00oo^k^koA4A4o`00000Wooooo`05
oa0@4?nHV9SooooookZj^_l000009oooool01Ol0003o^[ZjoooooonHV9So410@01cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1>ooooo`001_ooool6o`0001[ooooo00?oMgMgo`00
0?ooool09_ooool01OnYZJWo410@o`000?l@413oZJVY02Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00Looooo`03o`000?oooooooooo00Sooooo00?oEEEEofIVI_l000009_ooool3o`0002Oooooo00?o
EEEEofIVI_l000006_ooool00ol0003oooooooooo`0?ooooo`04oa0@4?l0003o0000o`0003_ooooo
002Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>oooool009cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0kooooo`00W?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@oooo
o`09o`000?mgMgOo0000o`000?mEEEGok^k^ooooooo^k^koEEEE00;o000000KoEEEEonk^k_oooooo
oooooa0@4?lb<S82o`000003oa0@4?nYZJWooooo00;ooooo1Ol00003ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`04oa0@
4?l0003o0000ooooo`;o00000Ol@410009cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool02Ol0003oEEEE
onk^k_ooooooMgMgoeEEEOooooooEEEEogMgM`02ooooo`06ogMgMomEEEGoooooooooool0003oZJVY
0_ooool00onj^[[o0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Go410@okZj^_o^k^ko
MgMgoa0@4005ooooo`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3
ooooo`05o`000?ooooooooooooooool000000Oooool00?oo00008?l0000;ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooool000001?ooool01_l0003ooooooooooooooooo^[ZjohN7Q`;oIVIV
00?o410@ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
0ol0000Aooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooool000001?ooool01Ol0003ooooo
oooooolb<S;o8B4Q00;oMgMg00?oQhN7onk^k_ooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool1o`00007ooooo000Sooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool04?ooool02Ol0003oEEEEonk^k_ooooooMgMgofIVI_ooooooEEEEogMg
M`02ooooo`0:ogMgMomEEEGoooooooooool0003o^[Zjooooooo^k^koMgMgo`0000Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00KoEEEE
ogMgMoooooooooooogMgMomEEED3ooooo`05o`000?n7QhOoooooojVYZOl000000Oooool009cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00oooooo
00?o410@o`000?mgMgL00_l000001OmVIVKok^k^ooooooo^k^koEEEE00;o000000KoEEEEonk^k_oo
ooooooooojVYZOlQ8B42o`000003oc8b<_l0003ooooo00;ooooo00?o410@o`000?l000000oooool0
0ol@413o0000o`000003o`0000Cooooo00?o410@o`000?l000001?ooool01_o^k^koEEEEo`000?l0
003oEEEEonk^kP;ooooo00?o410@o`000?mgMgL00_l00001oiRHV07ooooo002Looooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01_ooooo002Looooo`03o`000?oooooooooo037ooooo0ol00014ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo017ooooo002Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0Zooooo`03oa0@4?oooooooooo00gooooo00?o410@ooooooooool04Oooool009co
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04ko
oooo002Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`1>ooooo`00W?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0C_ooool009cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo04kooooo002Mooooo`03o`000?oooooooooo033ooooo0ol00013oooo
o`03o`000?oooooooooo04oooooo002Mooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`1?ooooo`00WOooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0Coooool009gooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04oooooo002Mooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1?ooooo`00WOooool00ol0
003oooooooooo`0`ooooo`?o0000@_ooool00ol0003oooooooooo`1@ooooo`00WOooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0D?ooool009kooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo053ooooo
002Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`1Aooooo`00W_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0DOooool009kooooo00?o0000ooooooooool0;oooool3o`00047ooooo00?o0000oooo
ooooool0DOooool009kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo05;ooooo002Oooooo`03o`000?oooooooooo00cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool0D_ooool009oooooo00?o0000oooooooo
ool03?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool0D_ooool009oooooo00?o0000ooooooooool03?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0Doooool009oooooo00?o0000ooooooooool03?ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03
ooooo`?o0000?oooool00ol0003oooooooooo`1Cooooo`00Woooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo05Cooooo002P
ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo05Cooooo002Pooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0EOooool00:3ooooo00?o0000ooooooooool02ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo05Gooooo002Pooooo`03o`00
0?oooooooooo02gooooo0ol0000looooo`03o`000?oooooooooo05Kooooo002Pooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Fooooo`00XOooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Eoooool0
0:7ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
05Oooooo002Qooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`1Hooooo`00XOooool00ol0003oooooooooo`0/ooooo`?o0000>_ooool00ol0003ooooo
ooooo`1Hooooo`00X_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0FOooool00:;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo05[ooooo002Rooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`1Jooooo`00Xoooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0Foooool00:?ooooo00?o0000ooooooooool0
:_ooool3o`0003Oooooo00?o0000ooooooooool0Foooool00:Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo05cooooo002Tooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Mooooo`00YOooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0G_ooool00:Go
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo05oo
oooo002Vooooo`03o`000?oooooooooo02Oooooo0ol0000booooo`03o`000?oooooooooo063ooooo
002Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`1Pooooo`00Yoooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0HOooool00:Oooooo00?o0000ooooooooool03?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo06;ooooo002Xooooo`03o`000?oooooooooo00_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0Hoooool00:Sooooo00?o0000ooooooooool02oooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0002gooooo0_l0
001Vooooo`00ZOooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0I_oo
ool00:Wooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
Ioooool00:[ooooo00?o0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06Sooooo
002[ooooo`03o`000?oooooooooo00Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Yooooo`00Zooo
ool00ol0003oooooooooo`08ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
0ol0000Xooooo`03o`000?oooooooooo06[ooooo002/ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`1[ooooo`00[Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0K?ooool00:kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo002_ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool08oooool2o`00073ooooo002`ooooo`03o`00
0?oooooooooo01gooooo0ol0000Rooooo`03o`000?oooooooooo073ooooo002aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool08?ooool2o`0007?ooooo002booooo`;o00007?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07?ooooo002dooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1dooooo`00]Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01cooooo0_l0001gooooo`00]_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Moooool00;Oooooo00?o
0000ooooooooool05_ooool3o`0001Wooooo0_l0001jooooo`00^?ooool2o`0001Kooooo00?o0000
ooooooooool05oooool2o`0007cooooo002jooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool05Oooool2o`0007kooooo002kooooo`?o00004_ooool00ol0003oooooooooo`0Cooooo`;o
0000P?ooool00;kooooo0ol0000?ooooo`03o`000?oooooooooo017ooooo0_l00022ooooo`00`Ooo
ool00ol0003oooooooooo`0<ooooo`?o00003oooool2o`0008Cooooo0032ooooo`Co00002_ooool0
0ol0003oooooooooo`09ooooo`Ko0000Q_ooool00:kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`03ooooo`Co000000?o<S8bomgMgOooool00oooool0
0ol0003oooooooooo`06ooooo`?o0000S?ooool00:kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`06oooooa3o0000Soooool00:kooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2Eooooo`00[_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`?o0000UOooool00:kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo09Gooooo002^ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0UOoo
ool00:kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`2Nooooo`00[_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co0000WOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00>[ooooo0ol000000ol@413oooooooooo`1h
ooooo`00k?ooool00ol@413o^[Zjooooo`1iooooo`00k?ooool00onHV9So<S8booooo`1iooooo`00
]Oooool00olQ8B7o<S8booooo`03ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool5o`00
00?ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0
0oooool5o`0000?ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03omgMgOl0003o^[Zj07Wo
oooo002dooooo`04oiRHV?lb<S;o410@okZj^P?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104
ooooo`03o`000?oooooooooo00?ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06ofIV
I_mgMgOooooooooooon7QhOo410@1Oooool00ol0003oooooooooo`03ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41000oooool00omEEEGoMgMgodA4A01iooooo`00]?ooool01?l@413o^[ZjoiRHV?lb<S83
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05omgMgOl@413oooooob4Q8OoMgMd0N?ooool00;?ooooo00KoV9RHoc8b<_oooooooooo
oa0@4?nj^[X2ooooo`Ko00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00GoIVIVohN7QoooooooV9RHoeEEE@1hooooo`00/_ooool00oo^k^ko0000omgMg@02oooo
o`0:oiRHV?lb<S;ooooooooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000oooooooo
ool00oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoIVIVogMgMoooooooooooohN7
Qol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00oo^k^ko0000
onk^kP02ooooo`03o`000?oMgMgooooo07Kooooo002booooo`03oa0@4?l0003o000000;ooooo0ol0
00000oooooook^k^oeEEE@02o`000003odA4A?o^k^kooooo00?ooooo00?o0000ooooooooool00ooo
ool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l00003
ooooo`03oa0@4?l0003o000000?ooooo00?o410@o`000?l000000ol00002ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool0MOooool00<Gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`21ooooo`00aOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0POooool00<?ooooo00?o410@o`000?l000006?ooool00ol@413o
ooooooooo`27ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 364.875}, {274.812, 97.875}} -> {-7.05849, \
0.129792, 0.0288189, 0.0122831}}]
}, Open  ]],

Cell["\<\
Question: What happens to the object as the spring continues to \
age? 
Answer: Study the phase plane trajectory carefully, it shows us were the \
object is going and how fast it is  moving as it goes there. \
\>", "Text"]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Printout",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{756, 747},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->61,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1.25,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3304069867-2173353"->{
    Cell[185356, 5360, 663, 13, 110, "Print",
      CellTags->"Info3304069867-2173353"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3304069867-2173353", 247853, 7030}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 229, 7, 65, "Text"],
Cell[1986, 60, 317, 6, 63, "Text"],
Cell[2306, 68, 448, 25, 27, "Text"],
Cell[2757, 95, 92, 1, 26, "Text"],
Cell[2852, 98, 1283, 55, 81, "Text"],
Cell[4138, 155, 889, 52, 57, "Text"],
Cell[5030, 209, 65, 0, 27, "Text"],
Cell[5098, 211, 395, 22, 27, "Text"],
Cell[5496, 235, 422, 11, 63, "Text"],

Cell[CellGroupData[{
Cell[5943, 250, 96, 4, 46, "Input"],
Cell[6042, 256, 208, 6, 23, "Output"]
}, Open  ]],
Cell[6265, 265, 393, 13, 45, "Text"],
Cell[6661, 280, 108, 5, 27, "Text"],
Cell[6772, 287, 293, 8, 45, "Text"],
Cell[7068, 297, 150, 5, 62, "Input"],
Cell[7221, 304, 153, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[7399, 311, 146, 4, 46, "Input"],
Cell[7548, 317, 14291, 409, 161, 3661, 273, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[21854, 729, 114, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[21993, 736, 81, 1, 30, "Input"],
Cell[22077, 739, 490, 13, 122, "Output"]
}, Open  ]],
Cell[22582, 755, 233, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[22840, 763, 135, 6, 56, "Input"],
Cell[22978, 771, 82, 2, 24, "Output"]
}, Open  ]],
Cell[23075, 776, 260, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[23360, 788, 378, 8, 85, "Input"],
Cell[23741, 798, 25247, 638, 137, 5648, 391, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[49003, 1439, 104, 3, 27, "Text"],
Cell[49110, 1444, 1247, 37, 164, "Text"],
Cell[50360, 1483, 292, 11, 127, "Input"],
Cell[50655, 1496, 993, 18, 259, "Text"],

Cell[CellGroupData[{
Cell[51673, 1518, 98, 2, 28, "Input"],
Cell[51774, 1522, 491, 13, 122, "Output"]
}, Open  ]],
Cell[52280, 1538, 153, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[52458, 1548, 360, 8, 111, "Input"],
Cell[52821, 1558, 22902, 652, 117, 7370, 455, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[75738, 2213, 270, 12, 27, "Text"],

Cell[CellGroupData[{
Cell[76033, 2229, 361, 8, 111, "Input"],
Cell[76397, 2239, 24064, 697, 117, 8071, 495, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[100476, 2939, 122, 3, 27, "Text"],
Cell[100601, 2944, 137, 5, 27, "Text"],
Cell[100741, 2951, 779, 28, 81, "Text"],
Cell[101523, 2981, 1705, 96, 87, "Text"],
Cell[103231, 3079, 232, 5, 75, "Text"],
Cell[103466, 3086, 346, 11, 160, "Input"],
Cell[103815, 3099, 99, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[103939, 3106, 374, 8, 111, "Input"],
Cell[104316, 3116, 26256, 707, 133, 7990, 476, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[130609, 3828, 375, 8, 111, "Input"],
Cell[130987, 3838, 26255, 738, 133, 8679, 516, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[157257, 4579, 109, 3, 27, "Text"],
Cell[157369, 4584, 205, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[157599, 4592, 70, 2, 28, "Input"],
Cell[157672, 4596, 210, 6, 23, "Output"]
}, Open  ]],
Cell[157897, 4605, 135, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[158057, 4612, 111, 2, 28, "Input"],
Cell[158171, 4616, 251, 7, 23, "Output"]
}, Open  ]],
Cell[158437, 4626, 398, 13, 75, "Text"],

Cell[CellGroupData[{
Cell[158860, 4643, 78, 2, 28, "Input"],
Cell[158941, 4647, 81, 2, 23, "Output"]
}, Open  ]],
Cell[159037, 4652, 48, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[159110, 4656, 179, 5, 42, "Input"],
Cell[159292, 4663, 23985, 621, 133, 6285, 397, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[183292, 5287, 384, 14, 45, "Text"],

Cell[CellGroupData[{
Cell[183701, 5305, 171, 6, 42, "Input"],
Cell[183875, 5313, 689, 14, 139, "Output"]
}, Open  ]],
Cell[184579, 5330, 130, 5, 27, "Text"],
Cell[184712, 5337, 239, 3, 37, "Text"],
Cell[184954, 5342, 27, 0, 27, "Text"],
Cell[184984, 5344, 220, 6, 23, "Text"],
Cell[185207, 5352, 45, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[185277, 5356, 76, 2, 28, "Input"],
Cell[185356, 5360, 663, 13, 110, "Print",
  CellTags->"Info3304069867-2173353"]
}, Open  ]],
Cell[186034, 5376, 225, 8, 27, "Text"],
Cell[186262, 5386, 218, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[186505, 5394, 112, 2, 28, "Input"],
Cell[186620, 5398, 278, 7, 24, "Output"]
}, Open  ]],
Cell[186913, 5408, 423, 11, 63, "Text"],

Cell[CellGroupData[{
Cell[187361, 5423, 141, 5, 28, "Input"],
Cell[187505, 5430, 251, 7, 23, "Output"]
}, Open  ]],
Cell[187771, 5440, 297, 9, 75, "Text"],

Cell[CellGroupData[{
Cell[188093, 5453, 214, 6, 42, "Input"],
Cell[188310, 5461, 20724, 599, 170, 5957, 412, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[209049, 6063, 145, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[209219, 6070, 179, 5, 42, "Input"],
Cell[209401, 6077, 36057, 885, 236, 9135, 548, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[245473, 6965, 232, 5, 75, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

