(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    418253,      11874]*)
(*NotebookOutlinePosition[    420434,      11939]*)
(*  CellTagsIndexPosition[    420390,      11935]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part IV. Linear Differential Equations", "Section"],
  "\n",
  StyleBox["Section 1. Linear Oscillators ", "Subsection"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Let's set the stage by recalling some of the things you are \
learning in your differential equations course.  A first order linear \
ordinary differential equation has the general form \
\>", "Text"],

Cell[TextData[{
  StyleBox["a",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") ",
  StyleBox["y'",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") + ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ")",
  " ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ")"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["or", "Text"],

Cell[TextData[{
  StyleBox["a",
    FontSlant->"Italic"],
  " ",
  StyleBox["y'",
    FontSlant->"Italic"],
  " + ",
  StyleBox["b",
    FontSlant->"Italic"],
  " ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
for short. Some equations like these were solved and analyzed in \
Part II. See the differential equation that was used to model Juanita's \
credit card payments and the equation modeling the temperature inside of a \
house on a  sunny day. A second order linear differential equation has the \
general form \
\>", "Text"],

Cell[TextData[{
  StyleBox["a",
    FontSlant->"Italic"],
  " ",
  StyleBox["y''",
    FontSlant->"Italic"],
  " + ",
  StyleBox["b",
    FontSlant->"Italic"],
  " ",
  StyleBox["y' + ",
    FontSlant->"Italic"],
  StyleBox["c y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "The letters ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", ",
  StyleBox["c",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["f",
    FontSlant->"Italic"],
  " represent known functions of, say, time, and  ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") is unknown. This is called a linear oscillator equation when ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["c",
    FontSlant->"Italic"],
  " are constant functions, ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and ",
  StyleBox["c",
    FontSlant->"Italic"],
  " positive, ",
  StyleBox["b",
    FontSlant->"Italic"],
  " non-negative. Certainly the most famous example of a linear oscillator is \
the model for an object of mass ",
  StyleBox["m",
    FontSlant->"Italic"],
  " as it oscillates on a spring with spring constant ",
  StyleBox["k",
    FontSlant->"Italic"],
  " and possibly slowed down by a force proportional to its speed. The \
constant of proportionality is  called the damping constant and is often \
denoted by the letter ",
  StyleBox["b",
    FontSlant->"Italic"],
  ". Application of Newton's equally famous "
}], "Text"],

Cell[TextData[{
  StyleBox["Force",
    FontSlant->"Italic"],
  " = ",
  StyleBox["Mass",
    FontSlant->"Italic"],
  " x ",
  StyleBox["Acceleration",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["yields the equation ", "Text"],

Cell[TextData[{
  StyleBox["m",
    FontSlant->"Italic"],
  " ",
  StyleBox["y''",
    FontSlant->"Italic"],
  " + ",
  StyleBox["b",
    FontSlant->"Italic"],
  " ",
  StyleBox["y' + ",
    FontSlant->"Italic"],
  StyleBox["k y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "The function ",
  StyleBox["f",
    FontSlant->"Italic"],
  " is called the forcing function or the input because it usually represents \
an external force applied  to the mass. If ",
  StyleBox["f",
    FontSlant->"Italic"],
  " = 0, the equation is called \"unforced\" (or homogeneous in the general \
case). See Ledder, Chapter 3, Section 1. "
}], "Text"],

Cell[TextData[{
  StyleBox["Solve this too: DSolve and the unforced equation", 
    "Subsubsection"],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s DSolve function can be applied to an ordinary differential equation of \
any order. In particular it can  supply the solution formula for any unforced \
linear oscillator equation. Most of this section is devoted to  examples \
illustrating how to obtain solutions and plot their graphs.    "
}], "Text"],

Cell[TextData[{
  StyleBox["Example",
    FontSlant->"Italic",
    FontVariations->{"Underline"->True}],
  StyleBox[" An object of mass",
    FontSlant->"Italic"],
  " 4.3",
  StyleBox[" kilograms is attached to a spring with spring constant",
    FontSlant->"Italic"],
  " 15.2 ",
  StyleBox["Newtons per  meter. Find the general solution if the system is \
undamped. ",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
undampedDE = 4.3y''[t] + 15.2y[t] == 0
gensoln = DSolve[ undampedDE, y[t], t ]\
\>", "Input",
  CellLabel->"In[162]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{\(15.2`\ y[t]\), "+", 
        RowBox[{"4.3`", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
      "0"}]], "Output",
  CellLabel->"Out[162]="],

Cell[BoxData[
    \({{y[
            t] \[Rule] \[ExponentialE]\^\(0.`\ t\)\ C[1]\ Cos[
                1.880128644782115`\ t] + \[ExponentialE]\^\(0.`\ t\)\ C[
                2]\ Sin[1.880128644782115`\ t]}}\)], "Output",
  CellLabel->"Out[163]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Typical Problem",
    FontVariations->{"Underline"->True}],
  " Pull the mass 2 meters in the positive direction. Push it away from \
equilibrium with an ",
  "initial speed of 3 meters per second. Plot the solution. How far does the \
mass move in the positive direction?  When does it pass through the \
equilibrium position for the first time? How fast is it going at that time? \
",
  " "
}], "Text"],

Cell[TextData[{
  "This is an initial value problem, ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 2, ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'(0) = 3. We name the solution soln and use it to define the solution \
function, g. FullSimplify is applied to the solution formula to make it as \
simple as possible."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
soln = DSolve[ {undampedDE, y[0]==2, y'[0]==3}, y, t ];
g := soln[[1,1,2]]//FullSimplify
g[t]\
\>", "Input",
  CellLabel->"In[171]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(2.`\ \[ExponentialE]\^\(0.`\ t\)\ Cos[1.880128644782115`\ t] + 
      1.5956354945848212`\ \[ExponentialE]\^\(0.`\ t\)\ Sin[
          1.880128644782115`\ t]\)], "Output",
  CellLabel->"Out[173]="]
}, Open  ]],

Cell["\<\
The graph of the solution is a shifted sine wave or, if you prefer, \
a shifted cosine wave. Such curves are referred to as sinusoids. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Plot[ g[t], {t,0,6}, AspectRatio->1/3 ]", "Input",
  CellLabel->"In[176]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.166666 0.0620399 [
[.18254 .15417 -3 -9 ]
[.18254 .15417 3 0 ]
[.34127 .15417 -3 -9 ]
[.34127 .15417 3 0 ]
[.5 .15417 -3 -9 ]
[.5 .15417 3 0 ]
[.65873 .15417 -3 -9 ]
[.65873 .15417 3 0 ]
[.81746 .15417 -3 -9 ]
[.81746 .15417 3 0 ]
[.97619 .15417 -3 -9 ]
[.97619 .15417 3 0 ]
[.01131 .04259 -12 -4.5 ]
[.01131 .04259 0 4.5 ]
[.01131 .10463 -12 -4.5 ]
[.01131 .10463 0 4.5 ]
[.01131 .22871 -6 -4.5 ]
[.01131 .22871 0 4.5 ]
[.01131 .29075 -6 -4.5 ]
[.01131 .29075 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .16667 m
.18254 .17292 L
s
[(1)] .18254 .15417 0 1 Mshowa
.34127 .16667 m
.34127 .17292 L
s
[(2)] .34127 .15417 0 1 Mshowa
.5 .16667 m
.5 .17292 L
s
[(3)] .5 .15417 0 1 Mshowa
.65873 .16667 m
.65873 .17292 L
s
[(4)] .65873 .15417 0 1 Mshowa
.81746 .16667 m
.81746 .17292 L
s
[(5)] .81746 .15417 0 1 Mshowa
.97619 .16667 m
.97619 .17292 L
s
[(6)] .97619 .15417 0 1 Mshowa
.125 Mabswid
.05556 .16667 m
.05556 .17042 L
s
.0873 .16667 m
.0873 .17042 L
s
.11905 .16667 m
.11905 .17042 L
s
.15079 .16667 m
.15079 .17042 L
s
.21429 .16667 m
.21429 .17042 L
s
.24603 .16667 m
.24603 .17042 L
s
.27778 .16667 m
.27778 .17042 L
s
.30952 .16667 m
.30952 .17042 L
s
.37302 .16667 m
.37302 .17042 L
s
.40476 .16667 m
.40476 .17042 L
s
.43651 .16667 m
.43651 .17042 L
s
.46825 .16667 m
.46825 .17042 L
s
.53175 .16667 m
.53175 .17042 L
s
.56349 .16667 m
.56349 .17042 L
s
.59524 .16667 m
.59524 .17042 L
s
.62698 .16667 m
.62698 .17042 L
s
.69048 .16667 m
.69048 .17042 L
s
.72222 .16667 m
.72222 .17042 L
s
.75397 .16667 m
.75397 .17042 L
s
.78571 .16667 m
.78571 .17042 L
s
.84921 .16667 m
.84921 .17042 L
s
.88095 .16667 m
.88095 .17042 L
s
.9127 .16667 m
.9127 .17042 L
s
.94444 .16667 m
.94444 .17042 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.02381 .04259 m
.03006 .04259 L
s
[(-2)] .01131 .04259 1 0 Mshowa
.02381 .10463 m
.03006 .10463 L
s
[(-1)] .01131 .10463 1 0 Mshowa
.02381 .22871 m
.03006 .22871 L
s
[(1)] .01131 .22871 1 0 Mshowa
.02381 .29075 m
.03006 .29075 L
s
[(2)] .01131 .29075 1 0 Mshowa
.125 Mabswid
.02381 .05499 m
.02756 .05499 L
s
.02381 .0674 m
.02756 .0674 L
s
.02381 .07981 m
.02756 .07981 L
s
.02381 .09222 m
.02756 .09222 L
s
.02381 .11703 m
.02756 .11703 L
s
.02381 .12944 m
.02756 .12944 L
s
.02381 .14185 m
.02756 .14185 L
s
.02381 .15426 m
.02756 .15426 L
s
.02381 .17907 m
.02756 .17907 L
s
.02381 .19148 m
.02756 .19148 L
s
.02381 .20389 m
.02756 .20389 L
s
.02381 .2163 m
.02756 .2163 L
s
.02381 .24111 m
.02756 .24111 L
s
.02381 .25352 m
.02756 .25352 L
s
.02381 .26593 m
.02756 .26593 L
s
.02381 .27834 m
.02756 .27834 L
s
.02381 .03018 m
.02756 .03018 L
s
.02381 .01777 m
.02756 .01777 L
s
.02381 .00536 m
.02756 .00536 L
s
.02381 .30315 m
.02756 .30315 L
s
.02381 .31556 m
.02756 .31556 L
s
.02381 .32797 m
.02756 .32797 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.02381 .29075 m
.03279 .30055 L
.04262 .30955 L
.05288 .31688 L
.05747 .31944 L
.06244 .32172 L
.06529 .32277 L
.06792 .32359 L
.07039 .32422 L
.0731 .32476 L
.07428 .32494 L
.07553 .3251 L
.07672 .32522 L
.07781 .32531 L
.07904 .32537 L
.07973 .32539 L
.08037 .3254 L
.08155 .32539 L
.0828 .32535 L
.08352 .32531 L
.08427 .32525 L
.08563 .32512 L
.08708 .32494 L
.08868 .32468 L
.09155 .32408 L
.09422 .32335 L
.09922 .32158 L
.10458 .31907 L
.11475 .31263 L
.12582 .30323 L
.14594 .28026 L
.18672 .21577 L
.22599 .14286 L
.26374 .07734 L
.28471 .04782 L
.2939 .0371 L
.30394 .02713 L
.31305 .01979 L
.32279 .01384 L
.32817 .01142 L
.33307 .00976 L
.33543 .00915 L
.33799 .00863 L
.33916 .00844 L
.3404 .00827 L
.34156 .00814 L
.34263 .00805 L
.34384 .00798 L
.34516 .00794 L
.34632 .00794 L
Mistroke
.34756 .00797 L
.34878 .00803 L
.34993 .00812 L
.35096 .00822 L
.35207 .00836 L
.35464 .00879 L
.35735 .0094 L
.3622 .01089 L
.36673 .01274 L
.37094 .01487 L
.38052 .0211 L
.391 .03006 L
.40091 .04046 L
.41948 .06451 L
.45786 .12823 L
.49869 .20426 L
.51899 .23989 L
.53801 .26951 L
.55644 .29325 L
.56648 .30372 L
.57582 .31172 L
.58548 .31813 L
.59059 .32073 L
.59604 .32287 L
.59844 .32361 L
.60104 .32427 L
.60349 .32475 L
.60466 .32493 L
.60575 .32508 L
.60681 .32519 L
.60779 .32527 L
.60887 .32534 L
.61003 .32538 L
.61114 .3254 L
.61235 .32538 L
.6135 .32533 L
.61456 .32527 L
.61573 .32516 L
.61697 .32502 L
.61918 .32467 L
.62156 .32419 L
.62417 .32351 L
.62884 .32191 L
.6332 .32 L
.64315 .31411 L
.65379 .30555 L
.67511 .28194 L
.69526 .25289 L
.73369 .18551 L
.77458 .10996 L
Mistroke
.79491 .07624 L
.81395 .04936 L
.83219 .02916 L
.84243 .02057 L
.8518 .0146 L
.85657 .01227 L
.86166 .01033 L
.86413 .0096 L
.86645 .00902 L
.86854 .00861 L
.8708 .00828 L
.8721 .00814 L
.87331 .00804 L
.874 .008 L
.87463 .00797 L
.87536 .00795 L
.87605 .00794 L
.87672 .00794 L
.87743 .00795 L
.87871 .008 L
.87942 .00804 L
.88008 .00809 L
.8816 .00824 L
.88282 .0084 L
.88409 .0086 L
.88638 .00905 L
.89153 .01049 L
.89654 .01245 L
.90108 .0147 L
.91129 .02133 L
.92074 .02937 L
.92966 .03854 L
.96814 .09287 L
.97619 .10658 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[176]:=",
  ImageSize->{233.5, 77.625},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004S0000HB000`400?l00000o`00003ooooooolT
ooooo`00oooooolTooooo`004_ooool00ol0003oooooooooo`3oooooo`oooooo000Booooo`;o0000
ooooool@ooooo`004_ooool00ol0003oooooooooo`1Eooooo`Go0000Soooool5o`00023ooooo000B
ooooo`03o`000?oooooooooo057ooooo1?l00005ooooo`?o0000R?ooool4o`0000Gooooo1?l0000L
ooooo`004_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00[ooooo0ol00023oooo
o`;o00003Oooool2o`0001[ooooo000Booooo`;o0000D?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`00
4_ooool00ol0003oooooooooo`1=ooooo`;o00004_ooool00ol0003oooooooooo`1mooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool05_ooool001;ooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Eooooo`004_ooool2o`0004_ooooo0_l0000Gooooo`03o`000?oooooo
oooo07Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`002?ooool5o`00
00Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
07Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`002?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Boooo
o`001_l00003ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Aooooo`002_ooool00onHV9So8B4Qonk^kP05ooooo`?o0000Aoooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Aooooo`002oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool04?ooool000cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00oooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2
o`0004Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool03oooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1/
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03_ooool001;ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0=ooooo`004_ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00gooooo000Booooo`;o0000@oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`004_oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo000Booooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool02oooool001;ooooo0_l00011ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00[ooooo000Booooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool001;ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`004_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo00Sooooo000Booooo`;o0000?oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07
ooooo`002Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`07ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01_ooool000Ko00001Oooool00ol0003oooooooooo`04ooooo`?o0000
??ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`05ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool01?ooool000_ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0mooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
03gooooo000;ooooo`03o`000?oooooooooo00Cooooo0_l0000kooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0nooooo`002Oooool00omEEEGoIVIV
o`000006ooooo`03o`000?oooooooooo02Oooooo1?l000000ol@413oooooooooo`0;ooooo`03o`00
0?oooooooooo01Oooooo1Ol0000Looooo`03o`000?oooooooooo00Sooooo00GoV9RHoa0@4?l0003o
<S8bolc<c00Yooooo`;o000000?o410@ooooooooool06oooool00ol0003oooooooooo`08ooooo`05
odA4A?l0003o0000oc8b<_oMgMd09oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo000Boooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hoooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@07Oooool00ol0003oooooooooo`07ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S80:_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo00?o
MgMgoc8b<_ooool09_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo000Booooo`;o0000:_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?oV9RHob4Q8Oo^k^h07ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1Ol0000Looooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000000Gooooo
000Booooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Kooooo`03oiRHV?lQ8B7ok^k^01kooooo00?o0000ooooooooool02Oooool00onYZJWo410@oooo
o`0Vooooo`04odA4A?oMgMgoooooo`0001cooooo00?o0000ooooooooool03Oooool00omgMgOo<S8b
ooooo`0Vooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool001;ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01cooooo00?oMgMgofIVI_ooool0
7_ooool00ol0003oooooooooo`07ooooo`03oa0@4?l0003o^[Zj02Oooooo00CogMgMoeEEEOoooooo
00007?ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09oooool01Ol0
003oEEEEo`000?l@413oc<c<00Gooooo000Booooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02?ooool00onj^[[o8B4Qooooo`0Wooooo`03ogMgMoo<c<co000001_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Yooooo`03oeEEEOn7QhOooooo00Oooooo000Booooo`;o
0000:_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo00Go0000okZj^_oo
ooooV9RHoa0@400Pooooo`03o`000?oooooooooo00Cooooo00Go410@oiRHV?oooooo^[Zjo`00000X
ooooo`03onk^k_m4A4Co000001_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Y
ooooo`03omgMgOl@413oV9RH00Oooooo000Booooo`03o`000?oooooooooo02Oooooo00?oEEEEofIV
I_l000002oooool00ol0003oooooooooo`0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`08?ooool0
0ol0003oooooooooo`04ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:Oooool00omgMgOo0000oooo
o`0Iooooo`03o`000?oooooooooo00cooooo1?l0000Yooooo`04olc<c?m4A4Co0000oa0@40Gooooo
000Booooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo04?ooooo000Booooo`;o0000=Oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0@oooool001;ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool0A?ooool001;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0A?ooool000_oooooool0000Io`0000004_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo000Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`004_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`16ooooo`004_ooool2o`00037ooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo04Oooooo000Booooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04Oooooo000B
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo04Sooooo000Booooo`;o0000;oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool0B?ooool001;ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0BOooool001;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0BOooool001;ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0B_oo
ool001;ooooo0_l0000]ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`1;ooooo`004_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1;ooooo`004_ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`1<ooooo`004_ooool2o`0002_ooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo04cooooo0009ooooo`Co000000?o410@ooooooooool00_oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`1=ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo04kooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0C_ooool000_o
oooo00?o0000ooooooooool01?ooool3o`0002Sooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo04oooooo000;ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0Coooool000_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`1@ooooo`002oooool00ol0003oooooooooo`04ooooo`;o00009oooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0D?ooool000Wooooo00?oEEEEofIV
I_l000001_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Aooooo`004_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Booooo`00
4_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`1Booooo`004_ooool2o`0002Gooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05?ooooo000Booooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo05?ooooo000Booooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo05Cooooo000Booooo`;o00008oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0EOooool001;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0EOooool001;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool001;ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0E_ooool001;ooooo0_l0000Pooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Gooooo`002?ooool5o`0000Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0F?ooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05Wo
oooo0009ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Mooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Jooooo`002_ooool00onHV9So8B4Qonk^
kP05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo05_ooooo000;ooooo`03ogMgMomVIVKooooo00Cooooo0_l0000L
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1L
ooooo`003?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`0001Wooooo00?o0000
ooooooooool0M_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05gooooo0008oooo
o`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`0000;ooooo00?o0000ooooooooool05?ooool2
o`0007[ooooo0_l0000Gooooo`03o`000?oooooooooo05kooooo0008ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`02ooooo`;o00004oooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Goooool001;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07kooooo0_l0000Boooo
o`03o`000?oooooooooo063ooooo000Booooo`;o00001_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo087ooooo00?o0000ooooooooool03Oooool2o`0006?ooooo000Booooo`03o`00
0?oooooooooo00Kooooo0_l0000;ooooo`;o0000QOooool3o`0000[ooooo0_l0001Uooooo`004_oo
ool00ol0003oooooooooo`08ooooo`?o00001Oooool3o`0008[ooooo0_l00005ooooo`?o0000Iooo
ool001;ooooo00?o0000ooooooooool02oooool5o`0008oooooo1Ol0001Zooooo`004_ooool2o`00
0?oooooo4?ooool001;ooooo00?o0000ooooooooool0ooooool?ooooo`00oooooolTooooo`00\
\>"],
  ImageRangeCache->{{{78.625, 311.125}, {423.375, 346.75}} -> {-2.63881, \
22.2921, 0.0282486, 0.0722745}}]
}, Open  ]],

Cell[TextData[{
  "To find how far the mass moves in the positive direction we will find the \
first maximum value of  ",
  StyleBox["g",
    FontSlant->"Italic"],
  " for ",
  StyleBox["t",
    FontSlant->"Italic"],
  " positive. Name the ",
  StyleBox["t",
    FontSlant->"Italic"],
  " value ",
  StyleBox["tmax",
    FontSlant->"Italic"],
  ". The number ",
  StyleBox["ymax",
    FontSlant->"Italic"],
  " is obtained as ",
  StyleBox["g",
    FontSlant->"Italic"],
  "(",
  StyleBox["tmax",
    FontSlant->"Italic"],
  "). "
}], "Text"],

Cell[CellGroupData[{

Cell["tmax = t/.FindRoot[ g'[t]==0, {t,0.5} ]", "Input",
  CellLabel->"In[178]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(0.358171705425415`\)], "Output",
  CellLabel->"Out[178]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["ymax = g[tmax]", "Input",
  CellLabel->"In[180]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(ymax\\)\\\" is similar to existing symbol \\\
\"\\!\\(tmax\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[180]:="],

Cell[BoxData[
    \(2.558525479954997`\)], "Output",
  CellLabel->"Out[180]="]
}, Open  ]],

Cell["\<\
So, the mass initially moves 0.558 meters in the positive direction \
to the position 2.558 meters from  equilibrium.  \
\>", "Text"],

Cell[TextData[{
  "To find when the mass passes through equilibrium, we solve the equation  \
",
  StyleBox["g",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = 0. The graph tells us that the first positive root of  g is near ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 1. We name it t0."
}], "Text"],

Cell[CellGroupData[{

Cell["t0 = t/.FindRoot[ g[t]==0, {t,1} ]", "Input",
  CellLabel->"In[181]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(1.1936444966912134`\)], "Output",
  CellLabel->"Out[181]="]
}, Open  ]],

Cell[TextData[{
  "The velocity of the object at time t0 is ",
  StyleBox["g",
    FontSlant->"Italic"],
  "'(t0). It will be negative (see the graph), so apply the absolute value \
function Abs to get the speed. "
}], "Text"],

Cell[CellGroupData[{

Cell["Abs[g'[t0]]*meterspersecond", "Input",
  CellLabel->"In[182]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(4.810357043268299`\ meterspersecond\)], "Output",
  CellLabel->"Out[182]="]
}, Open  ]],

Cell["\<\
This information is plotted on the following graph. Position is \
red, velocity blue, and the dashed lines indicate the point where the mass \
passes through equilibrium for the first time.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
lines = ListPlot[ {{0,-4.81},{t0,-4.81},{t0,0}}, PlotJoined->True, 
                  PlotStyle->Dashing[{0.02,0.02}] ];
Show[ lines,
      Plot[ {g[t],g'[t]}, {t,0,2},
            PlotStyle->{RGBColor[1,0,0],RGBColor[0,0,1]} ] ,
      PlotRange->{-6,4}
    ]\
\>", "Input",
  CellLabel->"In[190]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.37082 0.0618034 [
[.2619 .35832 -9 -9 ]
[.2619 .35832 9 0 ]
[.5 .35832 -3 -9 ]
[.5 .35832 3 0 ]
[.7381 .35832 -9 -9 ]
[.7381 .35832 9 0 ]
[.97619 .35832 -3 -9 ]
[.97619 .35832 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .12361 -12 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -12 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .37082 m
.2619 .37707 L
s
[(0.5)] .2619 .35832 0 1 Mshowa
.5 .37082 m
.5 .37707 L
s
[(1)] .5 .35832 0 1 Mshowa
.7381 .37082 m
.7381 .37707 L
s
[(1.5)] .7381 .35832 0 1 Mshowa
.97619 .37082 m
.97619 .37707 L
s
[(2)] .97619 .35832 0 1 Mshowa
.125 Mabswid
.07143 .37082 m
.07143 .37457 L
s
.11905 .37082 m
.11905 .37457 L
s
.16667 .37082 m
.16667 .37457 L
s
.21429 .37082 m
.21429 .37457 L
s
.30952 .37082 m
.30952 .37457 L
s
.35714 .37082 m
.35714 .37457 L
s
.40476 .37082 m
.40476 .37457 L
s
.45238 .37082 m
.45238 .37457 L
s
.54762 .37082 m
.54762 .37457 L
s
.59524 .37082 m
.59524 .37457 L
s
.64286 .37082 m
.64286 .37457 L
s
.69048 .37082 m
.69048 .37457 L
s
.78571 .37082 m
.78571 .37457 L
s
.83333 .37082 m
.83333 .37457 L
s
.88095 .37082 m
.88095 .37457 L
s
.92857 .37082 m
.92857 .37457 L
s
.25 Mabswid
0 .37082 m
1 .37082 L
s
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .12361 m
.03006 .12361 L
s
[(-4)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(-2)] .01131 .24721 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(2)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .07355 m
.59221 .07355 L
.59221 .37082 L
s
1 0 0 r
[ ] 0 setdash
.02381 .49443 m
.06244 .50798 L
.08255 .51379 L
.10458 .51911 L
.12507 .52306 L
.14415 .52585 L
.15465 .52701 L
.16457 .52785 L
.17348 .52841 L
.1785 .52864 L
.18314 .52879 L
.18558 .52885 L
.1878 .52889 L
.18903 .52891 L
.19037 .52893 L
.19164 .52894 L
.19281 .52894 L
.194 .52895 L
.19511 .52895 L
.19611 .52894 L
.1972 .52894 L
.19838 .52893 L
.19963 .52891 L
.20187 .52888 L
.20432 .52882 L
.20696 .52875 L
.2117 .52858 L
.21735 .5283 L
.2225 .52797 L
.23241 .52717 L
.24158 .52621 L
.26234 .52329 L
.28101 .51978 L
.30161 .51498 L
.34181 .5029 L
.3805 .48813 L
.42164 .46944 L
.46126 .44898 L
.49937 .42749 L
.53993 .40323 L
.57898 .37908 L
.62047 .35321 L
.66046 .32873 L
.69892 .30615 L
.73984 .28378 L
.77924 .26438 L
.81713 .24814 L
.85747 .23387 L
.8963 .22341 L
.91747 .21914 L
Mistroke
.92721 .21754 L
.93757 .21608 L
.94799 .21487 L
.95742 .21401 L
.96197 .21367 L
.9669 .21336 L
.97582 .21294 L
.97619 .21293 L
Mfstroke
0 0 1 r
.02381 .55623 m
.06244 .51876 L
.10458 .47402 L
.14415 .42938 L
.18221 .38509 L
.22272 .33761 L
.26171 .2927 L
.30316 .24701 L
.34309 .20611 L
.3815 .17061 L
.42237 .1379 L
.46172 .11212 L
.49955 .0932 L
.51896 .08587 L
.53984 .07986 L
.54994 .07765 L
.56097 .07578 L
.56602 .07511 L
.57139 .07453 L
.57646 .0741 L
.58106 .07381 L
.58339 .0737 L
.58594 .07362 L
.58722 .07358 L
.58793 .07357 L
.5886 .07355 L
.5899 .07354 L
.59109 .07353 L
.5922 .07352 L
.59338 .07353 L
.59439 .07353 L
.59551 .07355 L
.5967 .07357 L
.59798 .0736 L
.60031 .07368 L
.60284 .07379 L
.6056 .07394 L
.61117 .07436 L
.61633 .07487 L
.62113 .07546 L
.63165 .07712 L
.64159 .07916 L
.66018 .08416 L
.68019 .09128 L
.69864 .09939 L
.73804 .12146 L
.77593 .14837 L
.81627 .18247 L
.8551 .21979 L
.89637 .26334 L
Mistroke
.93613 .308 L
.97438 .35243 L
.97619 .35455 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[190]:=",
  ImageSize->{184.688, 114.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003V0000SR000`400?l00000o`00003oi_ooool0
0>Kooooo003Vooooo`002oooool01Oo^k^ko<S8bo`000?l@413oc<c<0=Kooooo000;ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B40e_ooool000?ooooo1_l00002ooooo`05o`000?ooooooooooooooool0
0000e_ooool000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@04ooooo`?o0000coooool000_ooooo
00Go0000oeEEEOl0003o410@olc<c004ooooo`03o`000?oooooooooo0<oooooo000;ooooo`03oeEE
EOn7QhOooooo00Kooooo00?o0000ooooooooool0coooool000_ooooo00?ogMgMoa0@4?nHV9P01_oo
ool00ol0003oooooooooo`3?ooooo`003?ooool01?o<c<coA4A4o`000?l@4104ooooo`03o`000?oo
oooooooo0<oooooo000Dooooo`03o`000?oooooooooo0<oooooo000Dooooo`;o0000d?ooool001Co
oooo00?o0000ooooooooool0coooool001Cooooo00?o0000ooooooooool0coooool001Cooooo00?o
0000ooooooooool0coooool001Cooooo00?o0000ooooooooool0coooool001Cooooo00?o0000oooo
ooooool0coooool001Cooooo00?o0000ooooooooool0coooool001Cooooo0_l0003@ooooo`005?oo
ool00ol0003oooooooooo`3?ooooo`005?ooool5o`0000Cooooo1Ol00003ooooo`Go00001?ooool5
o`0000?ooooo1Ol00003ooooo`Ko00000oooool5o`0000?ooooo1_l00003ooooo`Go00000oooool5
o`0000Cooooo1Ol00003ooooo`Go00000oooool6o`0000?ooooo1Ol0000=o`00oe;ooooo000Doooo
o`03o`000?oooooooooo06Wooooo1ol00?l5ooooo`03o`000?oooooooooo00Gooooo1_l00?m<oooo
o`005?ooool00ol0003oooooooooo`1Wooooo`;o003o3?ooool00ol0003oooooooooo`0;ooooo`;o
003oB_ooool001Cooooo00?o0000ooooooooool0I?ooool3o`00o`kooooo00?o0000ooooooooool0
3Oooool3o`00odOooooo000Dooooo`;o0000H_ooool3o`00obCooooo0_l00?m5ooooo`005?ooool0
0ol0003oooooooooo`1Oooooo`;o003o:Oooool2o`00od?ooooo000Dooooo`03o`000?oooooooooo
05gooooo0_l00?l]ooooo`;o003o@Oooool001Cooooo00?o0000ooooooooool0Foooool2o`00oaSo
oooo00?o0000ooooooooool05_ooool2o`00ocoooooo000=ooooo`;o000000?o410@ooooooooool0
0_ooool00ol0003oooooooooo`1Iooooo`;o003o6_ooool00ol0003oooooooooo`0Hooooo`;o003o
?Oooool000kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`03o`00oooo
oooooooo01[ooooo00?o0000ooooooooool06_ooool2o`00oc_ooooo0003ooooo`Ko00000_ooool5
o`0000Cooooo00?o0000ooooooooool0E_ooool2o`00oagooooo00?o0000ooooooooool07?ooool2
o`00ocWooooo000;ooooo`04odA4A?oMgMgoooooo`0000Gooooo0ol0001Eooooo`03o`00oooooooo
oooo01gooooo00?o0000ooooooooool07_ooool00ol00?ooooooooooo`0fooooo`002oooool01?oM
gMgoEEEEooooool00005ooooo`03o`000?oooooooooo05?ooooo0_l00?m2ooooo`03o`00oooooooo
oooo03Gooooo000<ooooo`03ogMgMoo<c<co000000Gooooo00?o0000ooooooooool0D_ooool00ol0
0?ooooooooooo`13ooooo`;o003o=Oooool000cooooo00?ok^k^odA4A?l000001Oooool00ol0003o
ooooooooo`1@ooooo`;o003oB?ooool00ol00?ooooooooooo`0booooo`003Oooool00omgMgOo0000
ooooo`04ooooo`03o`000?oooooooooo04oooooo00?o003oooooooooool08oooool00ol0003ooooo
ooooo`0Sooooo`03o`00oooooooooooo037ooooo000Dooooo`03o`000?oooooooooo04kooooo00?o
003oooooooooool09?ooool00ol0003oooooooooo`0Tooooo`;o003o<Oooool001Cooooo0_l0001>
ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool09_ooool00ol00?ooooooooooo`0^
ooooo`005?ooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo02Kooooo00?o0000oooo
ooooool09oooool00ol00?ooooooooooo`0]ooooo`005?ooool00ol0003oooooooooo`1;ooooo`03
o`00oooooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol00?ooooooooooo`0/ooooo`00
5?ooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo05Cooooo00?o003oooooooooool0
:oooool001Cooooo00?o0000ooooooooool0B?ooool2o`00oeSooooo00?o003oooooooooool0:_oo
ool001Cooooo00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooo
oooo02Wooooo000Dooooo`03o`000?oooooooooo04Kooooo00?o003oooooooooool0Foooool2o`00
obWooooo000Dooooo`;o0000A_ooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo02ko
oooo00?o003oooooooooool09_ooool001Cooooo00?o0000ooooooooool0A?ooool00ol00?oooooo
ooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o003oooooooooool09Oooool001Cooooo00?o
0000ooooooooool0@oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o
003oooooooooool09?ooool001Cooooo00?o0000ooooooooool0@_ooool00ol00?ooooooooooo`0`
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool08oooool001Cooooo00?o0000oooo
ooooool0@Oooool00ol00?ooooooooooo`0aooooo`03o`000?oooooooooo03;ooooo00?o003ooooo
ooooool08_ooool001Cooooo00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1Xooooo`03
o`00oooooooooooo01Oooooo0_oo0008ooooo`005?ooool2o`00043ooooo00?o003oooooooooool0
J_ooool00ol00?ooooooooooo`0<ooooo`[oo`002_ooool001Cooooo00?o0000ooooooooool0?_oo
ool00ol00?ooooooooooo`1/ooooo`03o`00oooooooooooo00Sooooo0ooo000Dooooo`005?ooool0
0ol0003oooooooooo`0mooooo`03o`00oooooooooooo03Gooooo00?o0000ooooooooool0=Oooool0
0ol00?ooooooooooo`03ooooo`Goo`005oooool001Cooooo00?o0000ooooooooool0??ooool00ol0
0?ooooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o003oool00?oo00000_oo000Loooo
o`002oooool5o`0000Cooooo00?o0000ooooooooool0>oooool00ol00?ooooooooooo`0gooooo`03
o`000?oooooooooo03Cooooo0ooo00000ol00?ooooooooooo`0Mooooo`002oooool01OnHV9So8B4Q
onk^k_ooooooA4A400Cooooo00?o0000ooooooooool0>_ooool00ol00?ooooooooooo`0hooooo`03
o`000?oooooooooo037ooooo0ooo0004ooooo`03o`00oooooooooooo01cooooo0003ooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo03Wooooo00?o003oooooooooool0
>Oooool00ol0003oooooooooo`0^ooooo`?oo`002?ooool00ol00?ooooooooooo`0Kooooo`003Ooo
ool00onHV9So8B4Qonk^kP04ooooo`?o0000>?ooool00ol00?ooooooooooo`1Yooooo`;oo`003?oo
ool00ol00?ooooooooooo`0Jooooo`003_ooool00omgMgOoIVIVooooo`03ooooo`03o`000?oooooo
oooo03Oooooo00?o003oooooooooool0Ioooool3ool000oooooo00?o003oooooooooool06Oooool0
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0fooooo`03o`00oooooooooooo
06Gooooo0ooo000Cooooo`03o`00oooooooooooo01Sooooo000;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`0eooooo`03o`00oooooooooooo03gooooo00?o0000oooo
ooooool09?ooool2ool001Oooooo00?o003oooooooooool05oooool000_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool0?_ooool00ol0
003oooooooooo`0Rooooo`;oo`006Oooool00ol00?ooooooooooo`0Gooooo`005?ooool00ol0003o
ooooooooo`0cooooo`03o`00oooooooooooo03oooooo00?o0000ooooooooool07oooool3ool001co
oooo00?o003oooooooooool05_ooool001Cooooo0_l0000cooooo`03o`00oooooooooooo043ooooo
00?o0000ooooooooool07Oooool2ool0023ooooo00?o003oooooooooool05Oooool001Cooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`11ooooo`03o`000?oooooooooo01_ooooo0_oo
000Sooooo`03o`00oooooooooooo01Cooooo000Dooooo`03o`000?oooooooooo033ooooo00?o003o
ooooooooool0@_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo02Cooooo00?o003o
ooooooooool04oooool001Cooooo00?o0000ooooooooool0;oooool00ol00?ooooooooooo`1Noooo
o`;oo`00:?ooool00ol00?ooooooooooo`0Booooo`005?ooool00ol0003oooooooooo`0_ooooo`03
o`00oooooooooooo05cooooo0_oo000[ooooo`03o`00oooooooooooo017ooooo000Dooooo`03o`00
0?oooooooooo02kooooo00?o003oooooooooool0G?ooool00ooo003oooooooooo`0/ooooo`03o`00
oooooooooooo013ooooo000Dooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool0AOoo
ool00ol0003oooooooooo`0Cooooo`;oo`00<?ooool00ol00?ooooooooooo`0?ooooo`005?ooool2
o`0002gooooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`0Booooo`03ool00?oooooo
oooo037ooooo00?o003oooooooooool03_ooool001Cooooo00?o0000ooooooooool09Oooool01oo^
k^ko<S8bo`000?lb<S;ok^k^ooooool00?l00oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Uooooo`Co000000?o410@ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`;oo`00
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oo
oooo00?o003oooooooooool00_ooool5o`0000Oooooo000Dooooo`03o`000?oooooooooo02Gooooo
00OoMgMgoiRHV?ooooooV9RHogMgMooooooo003o00?ooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`;oo`001?ooool00ol0
003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Oooooo`09o`00oooooooooooo
oooooonHV9So8B4Qonk^k_ooooooA4A400Oooooo000Dooooo`03o`000?oooooooooo02Gooooo00Ko
410@oooooooooooooooooa0@4?l00?l?ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo00Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Oooooo`07o`00oooooooooooooooooonHV9So8B4Qonk^kP08
ooooo`005?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool00?l03oooool0
0omgMgOo<S8booooo`0Vooooo`03o`000?oooooooooo01kooooo0_oo0007ooooo`03o`000?oooooo
oooo00kooooo00?oMgMgoc8b<_ooool08Oooool01ol00?ooooooooooooooooooV9RHob4Q8Oo^k^h0
1oooool001Cooooo00?o0000ooooooooool09Oooool01Ol0003oooooooooool00?oo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Wooooo`03o`000?oooooooooo01cooooo0_oo0009ooooo`03
o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Sooooo`06o`00oooooooooooo
oooooomgMgOoIVIV1oooool001Cooooo0_l0000Vooooo`05oa0@4?oooooo003oooooool@41003?oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo0_oo000;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09_ooool01Ol00?oooooooooooooooooo000000Oooooo
000Dooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?l00?ooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03ool0
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`05o`00
0?l00?oooooooiRHV?l@41001oooool001Cooooo00?o0000ooooooooool09Oooool01Oo^k^ko003o
o`000?lb<S;ok^k^00cooooo1?l0000Vooooo`03oeEEEOmVIVKo000001;ooooo00?o0000oooooooo
ool01?ooool2ool000cooooo00?oEEEEofIVI_l000003Oooool4o`0002Gooooo00GoV9RHoa0@4?l0
0?oo8B4Qolc<c007ooooo`005?ooool00ol0003oooooooooo`0Uooooo`03o`00oooooooooooo04go
oooo00?o0000ooooooooool00_ooool2ool004[ooooo00?o003oooooooooool01_ooool001Cooooo
00?o0000ooooooooool09?ooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooooooo00;oo`00
EOooool001Cooooo00?o0000ooooooooool08oooool00ol00?ooooooooooo`1?ooooo`03o`000?oo
003oo`0005Oooooo000Dooooo`03o`000?oooooooooo02?ooooo00?o003oooooooooool0Coooool0
0ooo003oooooooooo`1Gooooo`003ooooolZo`000003o`00ool0003o000004ko00000_oo001Go`00
00?ooooo000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00Go003oooooooooooooooooo`00000:oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo0_oo0003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`005?ooool00ol0003oooooooooo`0Pooooo`03
o`00oooooooooooo04gooooo00?oo`00ooooooooool0G?ooool001Cooooo00?o0000ooooooooool0
7oooool00ol00?ooooooooooo`1=ooooo`03ool00?oooooooooo05gooooo000Dooooo`03o`000?oo
oooooooo01oooooo00?o003oooooooooool0Boooool2ool0063ooooo000Dooooo`03o`000?oooooo
oooo01kooooo00?o003oooooooooool0Boooool00ooo003oooooooooo`1Pooooo`005?ooool2o`00
01kooooo00?o003oooooooooool0Boooool00ooo003oooooooooo`1Qooooo`005?ooool00ol0003o
ooooooooo`0Looooo`03o`00oooooooooooo04[ooooo0_oo001Tooooo`005?ooool00ol0003ooooo
ooooo`0Kooooo`03o`00oooooooooooo04[ooooo00?oo`00ooooooooool0I?ooool001Cooooo00?o
0000ooooooooool06_ooool00ol00?ooooooooooo`19ooooo`;oo`00Ioooool001Cooooo00?o0000
ooooooooool06Oooool00ol00?ooooooooooo`18ooooo`;oo`00JOooool001Cooooo00?o0000oooo
ooooool06?ooool00ol00?ooooooooooo`18ooooo`03ool00?oooooooooo06Wooooo000Dooooo`03
o`000?oooooooooo01Oooooo00?o003oooooooooool0Aoooool2ool006cooooo000Dooooo`;o0000
6?ooool00ol00?ooooooooooo`15ooooo`;oo`00K_ooool001Cooooo00?o0000ooooooooool05_oo
ool00ol00?ooooooooooo`14ooooo`;oo`00L?ooool001Cooooo00?o0000ooooooooool05Oooool0
0ol00?ooooooooooo`13ooooo`;oo`00L_ooool001Cooooo00?o0000ooooooooool05?ooool00ol0
0?ooooooooooo`12ooooo`;oo`00M?ooool001Cooooo00?o0000ooooooooool04oooool00ol00?oo
ooooooooo`11ooooo`;oo`00M_ooool001Cooooo00?o0000ooooooooool04_ooool00ol00?oooooo
ooooo`10ooooo`;oo`00N?ooool001Cooooo0_l0000Booooo`03o`00oooooooooooo043ooooo00?o
o`00ooooooooool0N?ooool001Cooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`0o
ooooo`;oo`00Noooool001Cooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0noooo
o`;oo`00OOooool001Cooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`0looooo`?o
o`00Ooooool000_ooooo1Ol00004ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0
>_ooool3ool008;ooooo000;ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00ol0003ooooo
ooooo`0<ooooo`03o`00oooooooooooo03Wooooo0_oo0025ooooo`003?ooool00onHV9So8B4Qonk^
kP05ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool0>?ooool2ool008Oooooo000=
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo0_oo00000ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo03Kooooo0ooo0029ooooo`003_ooool00omgMgOoIVIVooooo`03ooooo`03o`000?ooooooo`00
00;oo`001oooool00ol00?ooooooooooo`0eooooo`;oo`00S?ooool000oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`?oo`000oooool00ol00?ooooooooooo`0cooooo`?o
o`00S_ooool000_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Go
oooo0_oo00000ol00?ooo`00ooooo`0`ooooo`Coo`00TOooool000_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?oo000Yooooo`Co
o`00UOooool001Cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`Goo`00
8?ooool4ool009Wooooo000Dooooo`;o00001Oooool00ol00?ooooooooooo`0;ooooo`Ooo`005Ooo
ool4ool009gooooo000Dooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool04ooooolE
ool00:7ooooo000Dooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0b_ooool001Co
oooo00Go0000ooooooooooooooooo`00o`3=ooooo`005?ooool01?l0003oooooooooool00?o>oooo
o`005?ooool00ol0003oooooo`00o`3?ooooo`005?ooool00ol0003o003oooooo`3?ooooo`005?oo
ool00ol00?oo0000ooooo`3?ooooo`005?ooool00ol0003oooooooooo`3?ooooo`005?ooool00ol0
003oooooooooo`3?ooooo`005?ooool00ol0003oooooooooo`3?ooooo`005?ooool00ol0003ooooo
ooooo`3?ooooo`005?ooool00ol0003oooooooooo`3?ooooo`005?ooool2o`000=3ooooo000Doooo
o`03o`000?oooooooooo0<oooooo000Dooooo`03o`000?oooooooooo0<oooooo000Dooooo`03o`00
0?oooooooooo0<oooooo000=ooooo`;o000000?o410@ooooooooool00_ooool00ol0003ooooooooo
o`3?ooooo`003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<oooooo000;oooo
o`Go00001?ooool00ol0003oooooooooo`3?ooooo`002oooool01?m4A4CogMgMooooool00005oooo
o`?o0000coooool000_ooooo00CogMgMoeEEEOoooooo0000eoooool000cooooo00?oMgMgolc<c?l0
0000eoooool000cooooo00?ok^k^odA4A?l00000eoooool000gooooo00?oMgMgo`000?ooool0e_oo
ool00>Kooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 261.562}, {428.438, 315.375}} -> {-1.1797, \
23.8739, 0.0124721, 0.0960964}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["The phase plane trajectory", "Subsubsection"],
  " "
}], "Text"],

Cell[TextData[{
  "The information contained in the last plot can also be displayed using \
what is known as the phase plane trajectory. This is a plot of the \
parametrized curve ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") , ",
  StyleBox["v",
    FontSlant->"Italic"],
  " = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") in two dimensional ",
  StyleBox["y,v",
    FontSlant->"Italic"],
  " space called the phase plane (",
  StyleBox["v",
    FontSlant->"Italic"],
  " denotes velocity). Since ",
  StyleBox["g",
    FontSlant->"Italic"],
  " is defined so that ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["g",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), the phase plane trajectory for the first 2  seconds is obtained by \
applying the ParametricPlot procedure to the list { ",
  StyleBox["g",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), ",
  StyleBox["g'",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") }. The setting AspectRatio->6/4 makes sure that the same scale is used \
on the two axes."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
traj = ParametricPlot[ {g[t],g'[t]}, {t,0,2}, \
PlotRange->{{-4,4},{-6,6}},
                AspectRatio->6/4 ]\
\>", "Input",
  CellLabel->"In[201]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.75 0.125 [
[0 .7375 -6 -9 ]
[0 .7375 6 0 ]
[.125 .7375 -6 -9 ]
[.125 .7375 6 0 ]
[.25 .7375 -6 -9 ]
[.25 .7375 6 0 ]
[.375 .7375 -6 -9 ]
[.375 .7375 6 0 ]
[.625 .7375 -3 -9 ]
[.625 .7375 3 0 ]
[.75 .7375 -3 -9 ]
[.75 .7375 3 0 ]
[.875 .7375 -3 -9 ]
[.875 .7375 3 0 ]
[1 .7375 -3 -9 ]
[1 .7375 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -12 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -6 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .75 m
0 .75625 L
s
[(-4)] 0 .7375 0 1 Mshowa
.125 .75 m
.125 .75625 L
s
[(-3)] .125 .7375 0 1 Mshowa
.25 .75 m
.25 .75625 L
s
[(-2)] .25 .7375 0 1 Mshowa
.375 .75 m
.375 .75625 L
s
[(-1)] .375 .7375 0 1 Mshowa
.625 .75 m
.625 .75625 L
s
[(1)] .625 .7375 0 1 Mshowa
.75 .75 m
.75 .75625 L
s
[(2)] .75 .7375 0 1 Mshowa
.875 .75 m
.875 .75625 L
s
[(3)] .875 .7375 0 1 Mshowa
1 .75 m
1 .75625 L
s
[(4)] 1 .7375 0 1 Mshowa
.125 Mabswid
.025 .75 m
.025 .75375 L
s
.05 .75 m
.05 .75375 L
s
.075 .75 m
.075 .75375 L
s
.1 .75 m
.1 .75375 L
s
.15 .75 m
.15 .75375 L
s
.175 .75 m
.175 .75375 L
s
.2 .75 m
.2 .75375 L
s
.225 .75 m
.225 .75375 L
s
.275 .75 m
.275 .75375 L
s
.3 .75 m
.3 .75375 L
s
.325 .75 m
.325 .75375 L
s
.35 .75 m
.35 .75375 L
s
.4 .75 m
.4 .75375 L
s
.425 .75 m
.425 .75375 L
s
.45 .75 m
.45 .75375 L
s
.475 .75 m
.475 .75375 L
s
.525 .75 m
.525 .75375 L
s
.55 .75 m
.55 .75375 L
s
.575 .75 m
.575 .75375 L
s
.6 .75 m
.6 .75375 L
s
.65 .75 m
.65 .75375 L
s
.675 .75 m
.675 .75375 L
s
.7 .75 m
.7 .75375 L
s
.725 .75 m
.725 .75375 L
s
.775 .75 m
.775 .75375 L
s
.8 .75 m
.8 .75375 L
s
.825 .75 m
.825 .75375 L
s
.85 .75 m
.85 .75375 L
s
.9 .75 m
.9 .75375 L
s
.925 .75 m
.925 .75375 L
s
.95 .75 m
.95 .75375 L
s
.975 .75 m
.975 .75375 L
s
.25 Mabswid
0 .75 m
1 .75 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-4)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(-2)] .4875 .5 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(4)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(6)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .0625 m
.50375 .0625 L
s
.5 .125 m
.50375 .125 L
s
.5 .1875 m
.50375 .1875 L
s
.5 .3125 m
.50375 .3125 L
s
.5 .375 m
.50375 .375 L
s
.5 .4375 m
.50375 .4375 L
s
.5 .5625 m
.50375 .5625 L
s
.5 .625 m
.50375 .625 L
s
.5 .6875 m
.50375 .6875 L
s
.5 .8125 m
.50375 .8125 L
s
.5 .875 m
.50375 .875 L
s
.5 .9375 m
.50375 .9375 L
s
.5 1.0625 m
.50375 1.0625 L
s
.5 1.125 m
.50375 1.125 L
s
.5 1.1875 m
.50375 1.1875 L
s
.5 1.3125 m
.50375 1.3125 L
s
.5 1.375 m
.50375 1.375 L
s
.5 1.4375 m
.50375 1.4375 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.5 Mabswid
.75 1.125 m
.76411 1.08909 L
.7774 1.04922 L
.79007 1.00325 L
.79993 .95873 L
.80719 .91727 L
.81317 .87196 L
.81553 .84812 L
.81657 .83549 L
.81751 .82206 L
.8182 .8103 L
.81882 .79732 L
.81926 .7855 L
.81955 .77441 L
.81967 .76831 L
.81975 .76264 L
.81978 .75937 L
.8198 .75641 L
.81981 .75477 L
.81981 .753 L
.81981 .75132 L
.81982 .74978 L
.81981 .74697 L
.8198 .74435 L
.81978 .74147 L
.81976 .73839 L
.81972 .73515 L
.81967 .73209 L
.81957 .72636 L
.81929 .71543 L
.81893 .70533 L
.8178 .68251 L
.8162 .65986 L
.81429 .63871 L
.80844 .59106 L
.80073 .54541 L
.79199 .50468 L
.76809 .42214 L
.73892 .35029 L
.70196 .28377 L
.66149 .23099 L
.63768 .20728 L
.6143 .18842 L
.59037 .17321 L
.5678 .16237 L
.55579 .15792 L
.54448 .15455 L
.532 .15172 L
.52498 .15054 L
.51855 .14972 L
Mistroke
.51544 .14941 L
.51252 .14917 L
.5109 .14905 L
.50915 .14895 L
.50769 .14888 L
.5061 .14881 L
.50458 .14877 L
.50317 .14873 L
.50167 .14871 L
.50007 .14871 L
.49858 .14871 L
.49718 .14873 L
.49591 .14875 L
.49454 .14879 L
.49292 .14885 L
.4914 .14892 L
.48794 .14913 L
.48457 .14941 L
.48094 .14977 L
.47439 .15064 L
.46841 .15165 L
.45608 .1544 L
.44469 .15777 L
.41914 .16824 L
.39439 .18244 L
.37253 .19853 L
.32795 .24313 L
.28909 .29799 L
.25312 .36776 L
.22457 .4444 L
.2034 .52511 L
.19508 .56863 L
.18816 .61652 L
.18557 .64013 L
.18332 .66604 L
.18249 .67795 L
.18175 .69065 L
.18077 .71354 L
.18066 .7171 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[201]:=",
  ImageSize->{109.25, 163.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000280000c2000`400?l00000o`00003oR?ooool0
08Sooooo0028ooooo`00R?ooool008Sooooo0028ooooo`00?Oooool01Oo^k^ko<S8bo`000?l@413o
c<c<04Kooooo000mooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40A_ooool003Gooooo1_l00002oooo
o`05o`000?ooooooooooooooool000000oooool2o`00047ooooo000mooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B400oooool00ol0003oooooooooo`10ooooo`00?Oooool01Ol0003oEEEEo`000?l@413o
c<c<00?ooooo00?o0000ooooooooool0@?ooool003gooooo00?oEEEEohN7Qoooool01Oooool00ol0
003oooooooooo`10ooooo`00?Oooool00ooMgMgo410@oiRHV005ooooo`03o`000?oooooooooo043o
oooo000nooooo`04olc<c?m4A4Co0000oa0@40?ooooo00?o0000ooooooooool0@?ooool004Gooooo
00?o0000ooooooooool0@?ooool004Gooooo00?o0000ooooooooool0@?ooool004Gooooo0_l00011
ooooo`00AOooool00ol0003oooooooooo`10ooooo`00AOooool00ol0003oooooooooo`10ooooo`00
AOooool00ol0003oooooooooo`10ooooo`00AOooool00ol0003oooooooooo`10ooooo`00AOooool0
0ol0003oooooooooo`10ooooo`00AOooool00ol0003oooooooooo`10ooooo`00AOooool00ol0003o
ooooooooo`10ooooo`00AOooool2o`00047ooooo0015ooooo`03o`000?oooooooooo043ooooo0015
ooooo`03o`000?oooooooooo043ooooo0011ooooo`[o0000?Oooool003gooooo1?l00004ooooo`03
o`000?oooooooooo00?ooooo0ol0000jooooo`00>_ooool3o`0000Sooooo00?o0000ooooooooool0
1_ooool2o`0003Sooooo000iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool2o`0003Kooooo000gooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03?ooooo000fooooo`03o`000?oooooooooo00cooooo0_l0000<ooooo`;o0000<oooool003Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo033o
oooo000eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0_ooooo`00=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0;_ooool003?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02gooooo000booooo`03o`000?oooooooooo00[ooooo0_l000001Ol@
413ooooooooooooooooo000001?ooooo00?o0000ooooooooool0;?ooool0037ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0;?ooool0033ooooo00?o0000ooooooooool00_ooool6o`0000;ooooo1Ol00003ooooo`;o
00004oooool00ol0003oooooooooo`0[ooooo`00<?ooool00ol0003oooooooooo`0:ooooo`04odA4
A?oMgMgoooooo`0000Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Zooooo`00
;oooool00ol0003oooooooooo`0;ooooo`04omgMgOmEEEGoooooo`0000Cooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Yooooo`00;_ooool00ol0003oooooooooo`0=ooooo`03ogMg
Moo<c<co000000Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Yooooo`00;Ooo
ool00ol0003oooooooooo`0>ooooo`03onk^k_m4A4Co000000Cooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Xooooo`00;?ooool00ol0003oooooooooo`0@ooooo`03ogMgMol0003o
oooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Wooooo`00:oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09oooool002_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Ko
oooo000Zooooo`03o`000?oooooooooo01Sooooo0_l0000Iooooo`03o`000?oooooooooo02Gooooo
000Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Uooooo`00:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool09?ooool002Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02Cooooo000Xooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Sooooo`009oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool08_ooool002Oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02;ooooo000Vooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`009_ooool00ol0
003oooooooooo`0Looooo`;o00007Oooool00ol0003oooooooooo`0Qooooo`009_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08Oooool002Gooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo023ooooo
000Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Pooooo`009Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool08?ooool002Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01oooooo000Tooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Oooooo`009?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool07oooool002?ooooo00?o0000ooooooooool07ooo
ool2o`0001oooooo00?o0000ooooooooool07oooool002?ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo000Sooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`008oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_ooool002;ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01gooooo
000Rooooo`03o`000?oooooooooo01Sooooo1Ol00003ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool07Oooool002;ooooo00?o0000ooooooooool06?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Mooooo`008Oooool0
0ol0003oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`;o00008_ooool0
0ol0003oooooooooo`0Looooo`008Oooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Looooo`008Oooool00ol0003o
ooooooooo`0Looooo`03ogMgMomVIVKooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Looooo`008?ooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool0
00009?ooool00ol0003oooooooooo`0Kooooo`008?ooool00ol0003oooooooooo`0Jooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01_o
oooo000Pooooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool06oooool0023ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01[ooooo000Oooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Jooooo`007oooool0
0ol0003oooooooooo`0Sooooo`;o00009?ooool00ol0003oooooooooo`0Jooooo`007oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06_ooool001oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wo
oooo000Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Iooooo`007oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool06Oooool001kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool0
9?ooool2o`0002Gooooo00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06Oooool001ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wo
oooo000:ooooo`;o000000?o410@ooooooooool02Oooool01onHV9So410@o`000?lb<S;oc<c<oooo
ool000002?ooool5o`0000cooooo1?l000000ol@413oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo1?l000000ol@413oooooooooo`07ooooo`Go00001_ooool00ol0003oooooooooo`02oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`03?ooool2o`000003oa0@4?oooooooooo007ooooo000;oooo
o`03o`000?oooooooooo00[ooooo00Oo410@okZj^_ooooooMgMgoc8b<_oooooo000000Sooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`09ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02Ol0003o
oooooooooooooooo410@okZj^_ooooooMgMgoc8b<P0=ooooo`03o`000?oooooooooo00;ooooo0006
o`0000;ooooo1Ol00003ooooo`Ko00001_ooool00ol0003oooooo`000006o`0000?ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool6o`0000Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo1Ol00003ooooo`002?ooool01?m4A4CogMgMooooool0000?
ooooo`04ojVYZOl@413oooooo`0000[ooooo00?oV9RHob4Q8Oo^k^h03_ooool00ol0003ooooooooo
o`08ooooo`;o00003_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
0000ooooooooool01?ooool00onYZJWo410@ooooo`09ooooo`04odA4A?oMgMgoooooo`0000Cooooo
0008ooooo`04omgMgOmEEEGoooooo`0000kooooo00Go410@o`000?nj^[[oooooo`00000;ooooo`03
ogMgMomVIVKooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01_ooool00ol0003oooooooooo`03ooooo`03
oa0@4?l0003o^[Zj00[ooooo00CogMgMoeEEEOoooooo00001?ooool000Wooooo00?oMgMgolc<c?l0
00003oooool00onj^[[o8B4Qo`00000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03okZj^_lQ8B7ooooo00[ooooo00?oMgMgolc<c?l0
00001?ooool000Wooooo00?ok^k^odA4A?l000003?ooool01?l@413oV9RHoooooonj^[X2o`0000Wo
oooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`09ooooo`05o`000?nj^[[ooooooiRHV?l@41001oooool0
2Ol0003ooooooooooooooooo410@oiRHV?oooooo^[Zjo`00000;ooooo`03onk^k_m4A4Co000000Co
oooo000:ooooo`03ogMgMol0003ooooo00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0:ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`00000:ooooo`03o`000?oooooooooo
00_ooooo00?oEEEEofIVI_l000002oooool01OnHV9So410@o`000?lQ8B7oc<c<00Oooooo00Wo0000
ooooooooooooooooojVYZOl@413o0000oa0@4?nYZJT03?ooool00omgMgOo0000ooooo`03ooooo`00
AOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Sooooo0015ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool06?ooool004Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Hooooo`001ooooommo`0000Cooooo0015ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool06?ooool004Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Hooooo`00AOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Sooooo0015
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06?ooool004Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Hooooo`00AOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01Sooooo0015ooooo`;o00009_ooool00ol0003oooooooooo`0Hooooo`00AOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Sooooo0015ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool06?ooool004Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Hooooo`00AOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01So
oooo0015ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06Oooool004Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Iooooo`00AOooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01Wooooo0015ooooo`;o00009Oooool00ol0003oooooooooo`0Ioooo
o`00AOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo0015ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool06Oooool004Gooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Jooooo`00AOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01[ooooo0015ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06_ooool004Go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Jooooo`00AOooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo01[ooooo0015ooooo`;o00009?ooool00ol0003ooooooooo
o`0Jooooo`00AOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01_ooooo0015oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06oooool004Gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Kooooo`00AOooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01_ooooo000mooooo`Go00000oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo01_ooooo000mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01cooooo000nooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Looooo`00?oooool00onHV9So8B4Qonk^kP03oooo
o`;o00008_ooool00ol0003oooooooooo`0Looooo`00@?ooool00omgMgOoIVIVooooo`02ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool0047ooooo00Go0000oooooooooooo
ooooo`00000Sooooo`03o`000?oooooooooo01cooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01cooooo000mooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01go
oooo0015ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07Oooool004Gooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Mooooo`00AOooool2o`00027ooooo00?o0000
ooooooooool07Oooool004Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Noooo
o`00AOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0015ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool07_ooool004Gooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Oooooo`00AOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01oooooo0015ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool004Go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Pooooo`00AOooool2o`0001gooooo
00?o0000ooooooooool08Oooool004Gooooo00?o0000ooooooooool0@?ooool004Gooooo00?o0000
ooooooooool0@?ooool004Gooooo00?o0000ooooooooool0@?ooool004Gooooo00?o0000oooooooo
ool0@?ooool004Gooooo00?o0000ooooooooool0@?ooool004Gooooo00?o0000ooooooooool0@?oo
ool004Gooooo00?o0000ooooooooool0@?ooool004Gooooo0_l00011ooooo`00AOooool00ol0003o
ooooooooo`10ooooo`00AOooool00ol0003oooooooooo`10ooooo`00AOooool00ol0003ooooooooo
o`10ooooo`00AOooool00ol0003oooooooooo`10ooooo`00?oooool2o`000005oa0@4?oooooooooo
ooooool00000@_ooool0043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10oooo
o`00?Oooool5o`0000?ooooo00?o0000ooooooooool0@?ooool003gooooo00CoA4A4omgMgOoooooo
00001?ooool2o`00047ooooo000mooooo`04omgMgOmEEEGoooooo`0000Cooooo00?o0000oooooooo
ool0@?ooool003kooooo00?oMgMgolc<c?l000001?ooool00ol0003oooooooooo`10ooooo`00?_oo
ool00oo^k^koA4A4o`000004ooooo`03o`000?oooooooooo043ooooo000oooooo`03ogMgMol0003o
oooo00?ooooo00?o0000ooooooooool0@?ooool004Gooooo00?o0000ooooooooool0@?ooool004Go
oooo00?o0000ooooooooool0@?ooool004Gooooo0_l00011ooooo`00AOooool00ol0003ooooooooo
o`10ooooo`00AOooool00ol0003oooooooooo`10ooooo`00AOooool00ol0003oooooooooo`10oooo
o`00AOooool00ol0003oooooooooo`10ooooo`00AOooool00ol0003oooooooooo`10ooooo`00AOoo
ool00ol0003oooooooooo`10ooooo`00AOooool00ol0003oooooooooo`10ooooo`00AOooool2o`00
047ooooo0015ooooo`03o`000?oooooooooo043ooooo0015ooooo`03o`000?oooooooooo043ooooo
0015ooooo`03o`000?oooooooooo043ooooo0015ooooo`03o`000?oooooooooo043ooooo0015oooo
o`03o`000?oooooooooo043ooooo0015ooooo`03o`000?oooooooooo043ooooo0015ooooo`03o`00
0?oooooooooo043ooooo0015ooooo`;o0000@Oooool004Gooooo00?o0000ooooooooool0@?ooool0
04Gooooo00?o0000ooooooooool0@?ooool004Gooooo00?o0000ooooooooool0@?ooool004Gooooo
00?o0000ooooooooool0@?ooool003gooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`03o`00
0?oooooooooo043ooooo000mooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool00ol0003ooooo
ooooo`10ooooo`00?Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
@?ooool003gooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`;o0000@Oooool003gooooo00Go
0000oeEEEOl0003o410@olc<c016ooooo`00?Oooool00omEEEGoQhN7ooooo`18ooooo`00?Oooool0
0ooMgMgo410@oiRHV018ooooo`00?_ooool01?o<c<coA4A4o`000?l@4116ooooo`00R?ooool008So
oooo0028ooooo`00R?ooool00001\
\>"],
  ImageRangeCache->{{{77.875, 186.125}, {260.812, 97.875}} -> {-10.7608, \
1.32243, 0.0806053, 0.0806053}}]
}, Open  ]],

Cell[TextData[{
  "The next plot shows the same trajectory, but with the phase points \
corresponding to position and velocity at  the 9 time values ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0, 0.25, 0.5, ... , 2.0. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ traj, ListPlot[ Table[ {g[t],g'[t]}, {t,0,2,0.25}], \
PlotStyle->PointSize[0.03] ]]\
\>", "Input",
  CellLabel->"In[212]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.75 0.125 [
[0 .7375 -6 -9 ]
[0 .7375 6 0 ]
[.125 .7375 -6 -9 ]
[.125 .7375 6 0 ]
[.25 .7375 -6 -9 ]
[.25 .7375 6 0 ]
[.375 .7375 -6 -9 ]
[.375 .7375 6 0 ]
[.625 .7375 -3 -9 ]
[.625 .7375 3 0 ]
[.75 .7375 -3 -9 ]
[.75 .7375 3 0 ]
[.875 .7375 -3 -9 ]
[.875 .7375 3 0 ]
[1 .7375 -3 -9 ]
[1 .7375 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -12 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -6 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .75 m
0 .75625 L
s
[(-4)] 0 .7375 0 1 Mshowa
.125 .75 m
.125 .75625 L
s
[(-3)] .125 .7375 0 1 Mshowa
.25 .75 m
.25 .75625 L
s
[(-2)] .25 .7375 0 1 Mshowa
.375 .75 m
.375 .75625 L
s
[(-1)] .375 .7375 0 1 Mshowa
.625 .75 m
.625 .75625 L
s
[(1)] .625 .7375 0 1 Mshowa
.75 .75 m
.75 .75625 L
s
[(2)] .75 .7375 0 1 Mshowa
.875 .75 m
.875 .75625 L
s
[(3)] .875 .7375 0 1 Mshowa
1 .75 m
1 .75625 L
s
[(4)] 1 .7375 0 1 Mshowa
.125 Mabswid
.025 .75 m
.025 .75375 L
s
.05 .75 m
.05 .75375 L
s
.075 .75 m
.075 .75375 L
s
.1 .75 m
.1 .75375 L
s
.15 .75 m
.15 .75375 L
s
.175 .75 m
.175 .75375 L
s
.2 .75 m
.2 .75375 L
s
.225 .75 m
.225 .75375 L
s
.275 .75 m
.275 .75375 L
s
.3 .75 m
.3 .75375 L
s
.325 .75 m
.325 .75375 L
s
.35 .75 m
.35 .75375 L
s
.4 .75 m
.4 .75375 L
s
.425 .75 m
.425 .75375 L
s
.45 .75 m
.45 .75375 L
s
.475 .75 m
.475 .75375 L
s
.525 .75 m
.525 .75375 L
s
.55 .75 m
.55 .75375 L
s
.575 .75 m
.575 .75375 L
s
.6 .75 m
.6 .75375 L
s
.65 .75 m
.65 .75375 L
s
.675 .75 m
.675 .75375 L
s
.7 .75 m
.7 .75375 L
s
.725 .75 m
.725 .75375 L
s
.775 .75 m
.775 .75375 L
s
.8 .75 m
.8 .75375 L
s
.825 .75 m
.825 .75375 L
s
.85 .75 m
.85 .75375 L
s
.9 .75 m
.9 .75375 L
s
.925 .75 m
.925 .75375 L
s
.95 .75 m
.95 .75375 L
s
.975 .75 m
.975 .75375 L
s
.25 Mabswid
0 .75 m
1 .75 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-4)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(-2)] .4875 .5 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(4)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(6)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .0625 m
.50375 .0625 L
s
.5 .125 m
.50375 .125 L
s
.5 .1875 m
.50375 .1875 L
s
.5 .3125 m
.50375 .3125 L
s
.5 .375 m
.50375 .375 L
s
.5 .4375 m
.50375 .4375 L
s
.5 .5625 m
.50375 .5625 L
s
.5 .625 m
.50375 .625 L
s
.5 .6875 m
.50375 .6875 L
s
.5 .8125 m
.50375 .8125 L
s
.5 .875 m
.50375 .875 L
s
.5 .9375 m
.50375 .9375 L
s
.5 1.0625 m
.50375 1.0625 L
s
.5 1.125 m
.50375 1.125 L
s
.5 1.1875 m
.50375 1.1875 L
s
.5 1.3125 m
.50375 1.3125 L
s
.5 1.375 m
.50375 1.375 L
s
.5 1.4375 m
.50375 1.4375 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.5 Mabswid
.75 1.125 m
.76411 1.08909 L
.7774 1.04922 L
.79007 1.00325 L
.79993 .95873 L
.80719 .91727 L
.81317 .87196 L
.81553 .84812 L
.81657 .83549 L
.81751 .82206 L
.8182 .8103 L
.81882 .79732 L
.81926 .7855 L
.81955 .77441 L
.81967 .76831 L
.81975 .76264 L
.81978 .75937 L
.8198 .75641 L
.81981 .75477 L
.81981 .753 L
.81981 .75132 L
.81982 .74978 L
.81981 .74697 L
.8198 .74435 L
.81978 .74147 L
.81976 .73839 L
.81972 .73515 L
.81967 .73209 L
.81957 .72636 L
.81929 .71543 L
.81893 .70533 L
.8178 .68251 L
.8162 .65986 L
.81429 .63871 L
.80844 .59106 L
.80073 .54541 L
.79199 .50468 L
.76809 .42214 L
.73892 .35029 L
.70196 .28377 L
.66149 .23099 L
.63768 .20728 L
.6143 .18842 L
.59037 .17321 L
.5678 .16237 L
.55579 .15792 L
.54448 .15455 L
.532 .15172 L
.52498 .15054 L
.51855 .14972 L
Mistroke
.51544 .14941 L
.51252 .14917 L
.5109 .14905 L
.50915 .14895 L
.50769 .14888 L
.5061 .14881 L
.50458 .14877 L
.50317 .14873 L
.50167 .14871 L
.50007 .14871 L
.49858 .14871 L
.49718 .14873 L
.49591 .14875 L
.49454 .14879 L
.49292 .14885 L
.4914 .14892 L
.48794 .14913 L
.48457 .14941 L
.48094 .14977 L
.47439 .15064 L
.46841 .15165 L
.45608 .1544 L
.44469 .15777 L
.41914 .16824 L
.39439 .18244 L
.37253 .19853 L
.32795 .24313 L
.28909 .29799 L
.25312 .36776 L
.22457 .4444 L
.2034 .52511 L
.19508 .56863 L
.18816 .61652 L
.18557 .64013 L
.18332 .66604 L
.18249 .67795 L
.18175 .69065 L
.18077 .71354 L
.18066 .7171 L
Mfstroke
.03 w
.75 1.125 Mdot
.81322 .87145 Mdot
.80851 .59155 Mdot
.73689 .34603 Mdot
.61388 .18812 Mdot
.46618 .15208 Mdot
.32581 .24572 Mdot
.22322 .44874 Mdot
.18066 .7171 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[212]:=",
  ImageSize->{106.25, 159.438},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000240000ab000`400?l00000o`00003oQ?ooool0
08Cooooo0024ooooo`00Q?ooool008Cooooo0024ooooo`00>oooool01Oo^k^ko<S8bo`000?l@413o
c<c<04Cooooo000kooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40A?ooool003?ooooo1_l00002oooo
o`05o`000?ooooooooooooooool00000A?ooool003_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03
ooooo`;o0000?oooool003_ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`03o`000?oooooo
oooo03kooooo000kooooo`03oeEEEOn7QhOooooo00Gooooo00?o0000ooooooooool0?_ooool003_o
oooo00?ogMgMoa0@4?nHV9P01Oooool00ol0003oooooooooo`0nooooo`00??ooool01?o<c<coA4A4
o`000?l@4103ooooo`03o`000?oooooooooo03kooooo0013ooooo`03o`000?oooooooooo03kooooo
0013ooooo`03o`000?oooooooooo03kooooo0013ooooo`;o0000?oooool004?ooooo00?o0000oooo
ooooool0?_ooool004?ooooo00?o0000ooooooooool0?_ooool004?ooooo00?o0000ooooooooool0
?_ooool004?ooooo00?o0000ooooooooool0?_ooool004?ooooo00?o0000ooooooooool0?_ooool0
04?ooooo00?o0000ooooooooool0?_ooool004?ooooo00?o0000ooooooooool0?_ooool004?ooooo
0_l0000oooooo`00@oooool00ol0003oooooooooo`0nooooo`00@oooool00ol0003oooooooooo`0n
ooooo`00?_ooool;o`0003_ooooo000looooo`Go00000_ooool00ol0003oooooooooo`03ooooo`;o
0000>Oooool003Wooooo0ol00002ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`?o0000
=_ooool003Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o0000=?oo
ool003Kooooo0_l0000;ooooo`03o`000?oooooooooo00[ooooo0ol0000aooooo`00=Oooool00ol0
003oooooooooo`0;ooooo`;o00002oooool3o`00037ooooo000dooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool4o`00033ooooo000cooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0]ooooo`00<_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;?ooool0037ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo000`oooo
o`03o`000?oooooooooo00[ooooo0_l000001Ol@413ooooooooooooooooo000001?ooooo00?o0000
ooooooooool0:_ooool002gooooo0ol0000>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Zooooo`00;Oooool3o`0000?ooooo1_l00002ooooo`Go
00000oooool2o`0001?ooooo00?o0000ooooooooool0:Oooool002gooooo0ol0000;ooooo`04odA4
A?oMgMgoooooo`0000Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Xooooo`00
;Oooool00ol0003oooooooooo`0;ooooo`04omgMgOmEEEGoooooo`0000Cooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Wooooo`00;?ooool00ol0003oooooooooo`0=ooooo`03ogMg
Moo<c<co000000Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`00;?oo
ool00ol0003oooooooooo`0=ooooo`03onk^k_m4A4Co000000Cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Uooooo`00:oooool00ol0003oooooooooo`0?ooooo`03ogMgMol0003o
oooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Uooooo`00:_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool002[o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Co
oooo000Yooooo`03o`000?oooooooooo01Oooooo0_l0000Iooooo`03o`000?oooooooooo02?ooooo
000Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Sooooo`00:?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool08_ooool002Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Ioooo
o`?o00008_ooool002Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`?o
00008_ooool002Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`?o0000
8_ooool002Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo023ooooo000Vooooo`03o`000?oooooooooo01[ooooo0_l0000Looooo`03o`000?oooooo
oooo023ooooo000Uooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01oooooo000Tooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`009?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool002?ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo000Sooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`00
8Oooool3o`0001oooooo0_l0000Oooooo`03o`000?oooooooooo01gooooo000Qooooo`?o00007ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01cooooo000Qooooo`?o00007oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01cooooo000Rooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Looooo`008Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07?ooool0027ooooo
00?o0000ooooooooool05oooool5o`0000?ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Looooo`008Oooool00ol0003oooooooooo`0Gooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oo
oooooooo00oooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo0_l0000Qooooo`03o`000?oo
oooooooo01_ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?oV9RHob4Q8Oo^k^h00oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo000Pooooo`03o`000?oooooooooo
01_ooooo00?oMgMgofIVI_ooool00_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
01_ooooo000Pooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00000Soooo
o`03o`000?oooooooooo01[ooooo000Pooooo`03o`000?oooooooooo01Sooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06_ooool0023o
oooo00?o0000ooooooooool06?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Jooooo`008?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool06Oooool001oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Wooooo000Oooooo`03o`000?oo
oooooooo027ooooo0_l0000Sooooo`03o`000?oooooooooo01Wooooo000Oooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Iooooo`007oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06Oooool001oo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`?o00006_ooool001kooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`?o00006_ooool001kooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`?o00006_ooool001kooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Wooooo000Noooo
o`03o`000?oooooooooo02;ooooo0_l0000Tooooo`03o`000?oooooooooo01Sooooo000Mooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Hooooo`00
7Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
6?ooool001gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01Sooooo000Mooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Hooooo`002_ooool2o`000003oa0@4?oooooooooo00Sooooo00OoV9RHoa0@
4?l0003o<S8bolc<c?oooooo000000Sooooo1Ol0000;ooooo`Co000000?o410@ooooooooool01_oo
ool00ol0003oooooooooo`0:ooooo`Co000000?o410@ooooooooool01oooool5o`0000Kooooo00Wo
0000oooooooooooooooooiRHV?l@413o0000oc8b<_o<c<`03Oooool2o`00007o410@0Oooool1oooo
o`002oooool00ol0003oooooooooo`09ooooo`07oa0@4?nj^[[oooooogMgMolb<S;oooooo`000008
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00Wo0000oooooooooooooooooa0@4?nj^[[oooooogMgMolb<S803_ooool00ol0003oooooooooo`01
ooooo`001_l00002ooooo`Go00000_ooool6o`0000Kooooo00?o0000ooooool000001_l00003oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo1_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`09ooooo`Go00000_ooool000Sooooo00CoA4A4omgMgOoo
oooo00003_ooool01?nYZJWo410@ooooool0000:ooooo`03oiRHV?lQ8B7ok^k^00gooooo00?o0000
ooooooooool02?ooool2o`0000gooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07
ooooo`03o`000?oooooooooo00?ooooo00?oZJVYoa0@4?ooool02_ooool01?m4A4CogMgMooooool0
0003ooooo`002?ooool01?oMgMgoEEEEooooool0000=ooooo`05oa0@4?l0003o^[Zjooooool00000
2oooool00omgMgOoIVIVooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol@413o0000okZj^P0;ooooo`04omgMgOmEEEGoooooo`0000?ooooo0009ooooo`03ogMg
Moo<c<co000000kooooo00Co^[Zjob4Q8Ooooooo00003?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00onj^[[o8B4Qooooo`0;ooooo`03
ogMgMoo<c<co000000?ooooo0009ooooo`03onk^k_m4A4Co000000_ooooo00Co410@oiRHV?oooooo
^[Zj1?l00007ooooo`05o`000?nj^[[ooooooiRHV?l@41003Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool01Ol0003o^[ZjoooooonHV9So
410@00Oooooo00So0000oooooooooooo410@oiRHV?oooooo^[Zjo`0000cooooo00?ok^k^odA4A?l0
00000oooool000[ooooo00?oMgMgo`000?ooool02_ooool01OnYZJWo410@o`000?l@413oZJVY00?o
00001oooool01OnHV9So410@o`000?lQ8B7oc<c<00_ooooo00?oEEEEofIVI_l000002_ooool00ol0
003oooooooooo`0:ooooo`03oeEEEOmVIVKo000000_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c007
ooooo`08o`000?ooooooooooojVYZOl@413o0000oa0@4?nYZJT=ooooo`03ogMgMol0003ooooo00;o
oooo000Looooo`?o00009?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Oooooo
0013ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05oooool000OoooooN_l00003
ooooo`001oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00Oooool004?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Gooooo`00
@oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Oooooo0013ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool05oooool004?ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Gooooo`00@oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01Oooooo0013ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05oooool004?ooooo
0_l0000Uooooo`03o`000?oooooooooo01Oooooo0013ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool05oooool004?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0G
ooooo`00@oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo0013ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool06?ooool004?ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Hooooo`00@oooool00ol0003oooooooooo`0Rooooo`?o00006Ooo
ool004?ooooo0_l0000Sooooo`?o00006Oooool004?ooooo00?o0000ooooooooool08_ooool3o`00
01Wooooo0013ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06?ooool004?ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Hooooo`00@oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01Wooooo0013ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool06Oooool004?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Ioooo
o`00@oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Wooooo0013ooooo`;o0000
8oooool00ol0003oooooooooo`0Iooooo`00@oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo01[ooooo0013ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06_ooool0
04?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Jooooo`00@oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo01[ooooo000kooooo`Go00000oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01[ooooo000kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo000looooo`03oiRHV?lQ
8B7ok^k^00Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`00?Oooool0
0onHV9So8B4Qonk^kP03ooooo`;o00008Oooool00ol0003oooooooooo`0Kooooo`00?_ooool00omg
MgOoIVIVooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06oooool003oo
oooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooooooo01_ooooo000kooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01cooooo000kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01cooooo0013ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool07?ooool004?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Looooo`00@ooo
ool2o`0001oooooo00?o0000ooooooooool07Oooool004?ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Mooooo`00@oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01gooooo0013ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool004?ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`00@oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01oooooo0013ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07oooool004?ooooo00?o0000ooooooooool06_ooool3o`00027ooooo0013ooooo`;o
00006oooool3o`00027ooooo0013ooooo`03o`000?oooooooooo01[ooooo0ol0000Qooooo`00@ooo
ool00ol0003oooooooooo`0nooooo`00@oooool00ol0003oooooooooo`0nooooo`00@oooool00ol0
003oooooooooo`0nooooo`00@oooool00ol0003oooooooooo`0nooooo`00@oooool00ol0003ooooo
ooooo`0nooooo`00@oooool2o`0003oooooo0013ooooo`03o`000?oooooooooo03kooooo0013oooo
o`03o`000?oooooooooo03kooooo0013ooooo`03o`000?oooooooooo03kooooo0013ooooo`03o`00
0?oooooooooo03kooooo000mooooo`;o000000Go410@ooooooooooooooooo`000010ooooo`00?_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03kooooo000kooooo`Go00000oooool0
0ol0003oooooooooo`0nooooo`00>oooool01?m4A4CogMgMooooool00004ooooo`;o0000?oooool0
03_ooooo00CogMgMoeEEEOoooooo00001?ooool00ol0003oooooooooo`0nooooo`00??ooool00omg
MgOoc<c<o`000004ooooo`03o`000?oooooooooo03kooooo000looooo`03onk^k_m4A4Co000000Co
oooo00?o0000ooooooooool0?_ooool003gooooo00?oMgMgo`000?ooool00oooool00ol0003ooooo
ooooo`0nooooo`00@oooool00ol0003oooooooooo`0nooooo`00@oooool00ol0003oooooooooo`0n
ooooo`00@oooool2o`0003oooooo0013ooooo`03o`000?oooooooooo03kooooo0013ooooo`03o`00
0?oooooooooo03kooooo0013ooooo`03o`000?oooooooooo03kooooo0013ooooo`03o`000?oooooo
oooo03kooooo0013ooooo`03o`000?oooooooooo03kooooo0013ooooo`03o`000?oooooooooo03ko
oooo0013ooooo`03o`000?oooooooooo03kooooo0013ooooo`;o0000?oooool004?ooooo00?o0000
ooooooooool0?_ooool004?ooooo00?o0000ooooooooool0?_ooool004?ooooo00?o0000oooooooo
ool0?_ooool004?ooooo00?o0000ooooooooool0?_ooool004?ooooo00?o0000ooooooooool0?_oo
ool004?ooooo00?o0000ooooooooool0?_ooool004?ooooo0_l0000oooooo`00@oooool00ol0003o
ooooooooo`0nooooo`00@oooool00ol0003oooooooooo`0nooooo`00@oooool00ol0003ooooooooo
o`0nooooo`00@oooool00ol0003oooooooooo`0nooooo`00>oooool01Oo^k^ko<S8bo`000?l@413o
c<c<00?ooooo00?o0000ooooooooool0?_ooool003_ooooo00GoEEEEogMgMoooooooV9RHob4Q8@03
ooooo`03o`000?oooooooooo03kooooo000kooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`0nooooo`00>oooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo0_l0000o
ooooo`00>oooool01Ol0003oEEEEo`000?l@413oc<c<04Cooooo000kooooo`03oeEEEOn7QhOooooo
04Kooooo000kooooo`03omgMgOl@413oV9RH04Kooooo000looooo`04olc<c?m4A4Co0000oa0@44Co
oooo0024ooooo`00Q?ooool008Cooooo0024ooooo`00\
\>"],
  ImageRangeCache->{{{78.625, 183.875}, {503.25, 344.812}} -> {-11.0339, \
22.0755, 0.0831177, 0.0831177}}]
}, Open  ]],

Cell[TextData[StyleBox["The key to phase plane trajectories",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "Given a point on the trajectory, its first coordinate is the position  of \
the object and its second coordinate is its velocity. The nine points on the \
trajectory above correspond to the nine  pairs of points appearing on the \
position (red) and velocity (blue) curves displayed below. By a \"pair\" of \
points we mean two points corresponding to the same ",
  StyleBox["t",
    FontSlant->"Italic"],
  " value. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
pos = ListPlot[ Table[ {t,g[t]}, {t,0,2,0.25}], 
                PlotStyle->PointSize[0.02] ];
vel = ListPlot[ Table[ {t,g'[t]}, {t,0,2,0.25}], 
                PlotStyle->PointSize[0.02] ];
Show[ pos, vel,
      Plot[ {g[t],g'[t]}, {t,0,2}, 
            PlotStyle->{RGBColor[1,0,1],RGBColor[0,0,1]} ] 
    ]\
\>", "Input",
  CellLabel->"In[209]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.377233 0.075362 [
[.2619 .36473 -9 -9 ]
[.2619 .36473 9 0 ]
[.5 .36473 -3 -9 ]
[.5 .36473 3 0 ]
[.7381 .36473 -9 -9 ]
[.7381 .36473 9 0 ]
[.97619 .36473 -3 -9 ]
[.97619 .36473 3 0 ]
[.01131 .07579 -12 -4.5 ]
[.01131 .07579 0 4.5 ]
[.01131 .22651 -12 -4.5 ]
[.01131 .22651 0 4.5 ]
[.01131 .52796 -6 -4.5 ]
[.01131 .52796 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .37723 m
.2619 .38348 L
s
[(0.5)] .2619 .36473 0 1 Mshowa
.5 .37723 m
.5 .38348 L
s
[(1)] .5 .36473 0 1 Mshowa
.7381 .37723 m
.7381 .38348 L
s
[(1.5)] .7381 .36473 0 1 Mshowa
.97619 .37723 m
.97619 .38348 L
s
[(2)] .97619 .36473 0 1 Mshowa
.125 Mabswid
.07143 .37723 m
.07143 .38098 L
s
.11905 .37723 m
.11905 .38098 L
s
.16667 .37723 m
.16667 .38098 L
s
.21429 .37723 m
.21429 .38098 L
s
.30952 .37723 m
.30952 .38098 L
s
.35714 .37723 m
.35714 .38098 L
s
.40476 .37723 m
.40476 .38098 L
s
.45238 .37723 m
.45238 .38098 L
s
.54762 .37723 m
.54762 .38098 L
s
.59524 .37723 m
.59524 .38098 L
s
.64286 .37723 m
.64286 .38098 L
s
.69048 .37723 m
.69048 .38098 L
s
.78571 .37723 m
.78571 .38098 L
s
.83333 .37723 m
.83333 .38098 L
s
.88095 .37723 m
.88095 .38098 L
s
.92857 .37723 m
.92857 .38098 L
s
.25 Mabswid
0 .37723 m
1 .37723 L
s
.02381 .07579 m
.03006 .07579 L
s
[(-4)] .01131 .07579 1 0 Mshowa
.02381 .22651 m
.03006 .22651 L
s
[(-2)] .01131 .22651 1 0 Mshowa
.02381 .52796 m
.03006 .52796 L
s
[(2)] .01131 .52796 1 0 Mshowa
.125 Mabswid
.02381 .11347 m
.02756 .11347 L
s
.02381 .15115 m
.02756 .15115 L
s
.02381 .18883 m
.02756 .18883 L
s
.02381 .26419 m
.02756 .26419 L
s
.02381 .30187 m
.02756 .30187 L
s
.02381 .33955 m
.02756 .33955 L
s
.02381 .41491 m
.02756 .41491 L
s
.02381 .45259 m
.02756 .45259 L
s
.02381 .49028 m
.02756 .49028 L
s
.02381 .0381 m
.02756 .0381 L
s
.02381 .00042 m
.02756 .00042 L
s
.02381 .56564 m
.02756 .56564 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .52796 Mdot
.14286 .56607 Mdot
.2619 .56323 Mdot
.38095 .52005 Mdot
.5 .44589 Mdot
.61905 .35684 Mdot
.7381 .27221 Mdot
.85714 .21036 Mdot
.97619 .18471 Mdot
.02381 .60332 Mdot
.14286 .45045 Mdot
.2619 .28171 Mdot
.38095 .13368 Mdot
.5 .03848 Mdot
.61905 .01675 Mdot
.7381 .07321 Mdot
.85714 .1956 Mdot
.97619 .3574 Mdot
1 0 1 r
.5 Mabswid
.02381 .52796 m
.06244 .54448 L
.08255 .55156 L
.10458 .55806 L
.12507 .56288 L
.14415 .56627 L
.15465 .56768 L
.16457 .56872 L
.17348 .56939 L
.1785 .56967 L
.18314 .56986 L
.18558 .56993 L
.1878 .56998 L
.18903 .57001 L
.19037 .57002 L
.19164 .57004 L
.19281 .57004 L
.194 .57005 L
.19511 .57005 L
.19611 .57004 L
.1972 .57004 L
.19838 .57002 L
.19963 .57001 L
.20187 .56996 L
.20432 .5699 L
.20696 .56981 L
.2117 .5696 L
.21735 .56926 L
.2225 .56886 L
.23241 .56788 L
.24158 .56671 L
.26234 .56315 L
.28101 .55888 L
.30161 .55302 L
.34181 .53829 L
.3805 .52028 L
.42164 .49749 L
.46126 .47254 L
.49937 .44634 L
.53993 .41675 L
.57898 .3873 L
.62047 .35576 L
.66046 .32591 L
.69892 .29838 L
.73984 .2711 L
.77924 .24744 L
.81713 .22764 L
.85747 .21024 L
.8963 .19748 L
.91747 .19228 L
Mistroke
.92721 .19032 L
.93757 .18854 L
.94799 .18707 L
.95742 .18602 L
.96197 .1856 L
.9669 .18522 L
.97582 .18472 L
.97619 .18471 L
Mfstroke
0 0 1 r
.02381 .60332 m
.06244 .55763 L
.10458 .50307 L
.14415 .44864 L
.18221 .39463 L
.22272 .33674 L
.26171 .28198 L
.30316 .22627 L
.34309 .17639 L
.3815 .1331 L
.42237 .09322 L
.46172 .06178 L
.49955 .03871 L
.51896 .02977 L
.53984 .02244 L
.54994 .01975 L
.56097 .01747 L
.56602 .01665 L
.57139 .01594 L
.57646 .01542 L
.58106 .01507 L
.58339 .01494 L
.58594 .01483 L
.58722 .01479 L
.58793 .01477 L
.5886 .01475 L
.5899 .01473 L
.59109 .01472 L
.5922 .01472 L
.59338 .01472 L
.59439 .01473 L
.59551 .01475 L
.5967 .01477 L
.59798 .01481 L
.60031 .0149 L
.60284 .01503 L
.6056 .01522 L
.61117 .01573 L
.61633 .01636 L
.62113 .01708 L
.63165 .0191 L
.64159 .02158 L
.66018 .02769 L
.68019 .03637 L
.69864 .04625 L
.73804 .07317 L
.77593 .10598 L
.81627 .14756 L
.8551 .19307 L
.89637 .24618 L
Mistroke
.93613 .30063 L
.97438 .35481 L
.97619 .3574 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[209]:=",
  ImageSize->{183.875, 113.5},
  ImageMargins->{{1.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003U0000SB000`400?l00000o`00003oiOooool0
0>Gooooo003Uooooo`004Oooool2o`000=;ooooo000Aooooo`03o`000?oooooooooo0=7ooooo000A
ooooo`03o`000?oooooooooo07gooooo0_l0001Booooo`004Oooool00ol0003oooooooooo`1foooo
o`Go003o00?oooooo`000?l000000_l0001Aooooo`004Oooool00ol0003oooooooooo`1`ooooo`Ko
003o1Oooool8o`00odkooooo000Aooooo`03o`000?oooooooooo06cooooo1?l00?l=ooooo`;o0000
1?ooool3o`00od_ooooo000Aooooo`03o`000?oooooooooo06Wooooo0ol00?lJooooo`?o003oB?oo
ool0017ooooo00?o0000ooooooooool0I?ooool2o`000003ooooool00?oo003o023ooooo0_l00?m6
ooooo`004Oooool2o`0006Cooooo0_l00002o`00obCooooo0_l00?m4ooooo`004Oooool00ol0003o
ooooooooo`1Sooooo`;o003o0_l0000Vooooo`;o003o@_ooool0017ooooo00?o0000ooooooooool0
H_ooool01?l00?ooooooo`000?l0000Yooooo`;o003o@?ooool0017ooooo00?o0000ooooooooool0
H?ooool2o`00oboooooo00?o003oooooooooool0?Oooool0017ooooo00?o0000ooooooooool0G_oo
ool2o`00oc;ooooo0_l00?lmooooo`004Oooool00ol0003oooooooooo`1Mooooo`03o`00oooooooo
oooo03Cooooo00?o003oooooooooool0>_ooool000[ooooo0_l000000ol@413oooooooooo`02oooo
o`03o`000?oooooooooo05_ooooo0_l00?lhooooo`;o003o>_ooool000_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo03[ooooo00?o003oo`000?oo
ool0=oooool000Ko00000_ooool5o`0000Cooooo00?o0000ooooooooool0F?ooool2o`00occooooo
0_l00002o`00ocOooooo0008ooooo`04odA4A?oMgMgoooooo`0000Gooooo0ol0001Gooooo`03o`00
oooooooooooo03cooooo1?l000000ol00?ooooooooooo`0dooooo`002?ooool01?oMgMgoEEEEoooo
ool00005ooooo`03o`000?oooooooooo05Gooooo0_l00?m0ooooo`;o00000_ooool00ol00?oooooo
ooooo`0cooooo`002Oooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo05Cooooo00?o
003oooooooooool0AOooool00ol00?ooooooooooo`0booooo`002Oooool00oo^k^koA4A4o`000005
ooooo`03o`000?oooooooooo05?ooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0a
ooooo`002_ooool00omgMgOo0000ooooo`04ooooo`03o`000?oooooooooo05?ooooo00?o003ooooo
ooooool0B?ooool00ol00?ooooooooooo`0`ooooo`004Oooool00ol0003oooooooooo`1Booooo`03
o`00oooooooooooo04[ooooo00?o003oooooooooool0;oooool0017ooooo00?o0000ooooooooool0
DOooool00ol00?ooooooooooo`1<ooooo`03o`00oooooooooooo02kooooo000Aooooo`03o`000?oo
oooooooo053ooooo00?o003oooooooooool0C_ooool00ol00?ooooooooooo`0]ooooo`004Oooool2
o`00053ooooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0/ooooo`004Oooool00ol0
003oooooooooo`1>ooooo`03o`00oooooooooooo05;ooooo00?o003oooooooooool0:oooool0017o
oooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`1Dooooo`03o`00oooooooooooo02[o
oooo000Aooooo`03o`000?oooooooooo04[ooooo0_l000000ol00?ooooooooooo`1Fooooo`03o`00
oooooooooooo02Wooooo000Aooooo`03o`000?oooooooooo04Wooooo0_l000000ol00?oo0000oooo
o`1Hooooo`03o`00oooooooooooo02Sooooo000Aooooo`03o`000?oooooooooo04Wooooo00Co0000
o`00ool0003o0000F_ooool00ol00?ooooooooooo`0Wooooo`004Oooool00ol0003oooooooooo`19
ooooo`03o`00ool0003o000005cooooo00?o003oooooooooool09_ooool0017ooooo00?o0000oooo
ooooool0B?ooool00ol00?ooooooooooo`1Nooooo`03o`00oooooooooooo02Gooooo000Aooooo`;o
0000B?ooool00ol00?ooooooooooo`1Oooooo`03o`00oooooooooooo02Gooooo000Aooooo`03o`00
0?oooooooooo04Kooooo00?o003oooooooooool0HOooool00ol00?ooooooooooo`0Tooooo`004Ooo
ool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo06?ooooo00?o003oooooooooool08ooo
ool0017ooooo00?o0000ooooooooool0A?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooo
oooo02;ooooo000Aooooo`03o`000?oooooooooo04?ooooo00?o003oooooooooool0Ioooool00ol0
0?ooooooooooo`0Qooooo`004Oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo06So
oooo00?o003oooooooooool08Oooool0017ooooo00?o0000ooooooooool0@_ooool00ol00?oooooo
ooooo`1Yooooo`03o`00oooooooooooo01[ooooo0_l00004ooooo`004Oooool00ol0003ooooooooo
o`11ooooo`03o`00oooooooooooo06_ooooo00?o003oooooooooool05?ooool6ool0o`;o00000ooo
ool0017ooooo0_l00011ooooo`03o`00oooooooooooo06gooooo00?o003oo`000?l000003Oooool6
ool0o`Cooooo1?l00003ooooo`004Oooool00ol0003oooooooooo`0oooooo`03o`00oooooooooooo
06kooooo00Co0000o`00ool0003o00002?ooool4ool0o`_ooooo0_l00004ooooo`004Oooool00ol0
003oooooooooo`0oooooo`03o`00oooooooooooo06kooooo00Co0000o`00ool0003o00001Oooool3
ool0oaGooooo000Aooooo`03o`000?oooooooooo03kooooo00?o003oooooooooool0L?ooool00ol0
003o003oooooo`02ooooo`?oo`3o6?ooool0017ooooo00?o0000ooooooooool0?Oooool00ol00?oo
ooooooooo`1`ooooo`?o000000?o003oool0oooo0?l06oooool0017ooooo00?o0000ooooooooool0
?Oooool00ol00?ooooooooooo`1`ooooo`?oo`3o00?o0000o`00ooooool06oooool000Sooooo1Ol0
0004ooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0K_ooool3ool0o`03ooooool0
003o000000;ooooo00?o003oooooooooool06Oooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4
A004ooooo`03o`000?oooooooooo03_ooooo00?o003oooooooooool0K?ooool3ool0o`Wooooo00?o
003oooooooooool06?ooool000Ko00000oooool00onHV9So8B4Qonk^kP05ooooo`?o0000>_ooool0
0ol00?ooooooooooo`1[ooooo`;oo`3o3?ooool00ol00?ooooooooooo`0Hooooo`002_ooool00onH
V9So8B4Qonk^kP04ooooo`03o`000?oooooooooo03[ooooo00?o003oooooooooool0J_ooool00ooo
0?ooooooooooo`0=ooooo`03o`00oooooooooooo01Oooooo000;ooooo`03ogMgMomVIVKooooo00?o
oooo00?o0000ooooooooool0>Oooool00ol00?ooooooooooo`1Yooooo`;oo`3o4Oooool00ol00?oo
ooooooooo`0Fooooo`003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo
00?o003oooooooooool0J?ooool2ool0oaCooooo00?o003oooooooooool05Oooool000Sooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03Oooooo00?o003oooooooooool0
J?ooool00ooo0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo0008ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`0gooooo`03o`00oooooooooooo06Kooooo
0_oo0?lHooooo`03o`00oooooooooooo01Cooooo000Aooooo`03o`000?oooooooooo03Kooooo00?o
003oooooooooool0IOooool2ool0oa_ooooo00?o003oooooooooool04oooool0017ooooo00?o0000
ooooooooool0=Oooool00ol00?ooooooooooo`1Tooooo`;oo`3o7_ooool00ol00?ooooooooooo`0B
ooooo`004Oooool2o`0003Gooooo00?o003oooooooooool0I?ooool00ooo0?ooooooooooo`0Ooooo
o`03o`00oooooooooooo017ooooo000Aooooo`03o`000?oooooooooo03Cooooo00?o003ooooooooo
ool0H?ooool2o`0000;oo`3o8_ooool00ol00?ooooooooooo`0Aooooo`004Oooool00ol0003ooooo
ooooo`0cooooo`03o`00oooooooooooo063ooooo00Co0000ool0oooo0?oo00009?ooool00ol00?oo
ooooooooo`0@ooooo`004Oooool00ol0003oooooooooo`0`ooooo`;o000000?o003oooooooooool0
HOooool01?oo0?oo0000o`000?l0000Uooooo`03o`00oooooooooooo00oooooo000Aooooo`03o`00
0?oooooooooo02oooooo0_l000000ol00?oo0000ooooo`1Pooooo`;oo`3o00?oooooo`000?l00000
9oooool00ol00?ooooooooooo`0>ooooo`004Oooool00ol0003oooooooooo`0_ooooo`;o000000?o
003oo`000?ooool0Goooool00ooo0?ooooooooooo`0Zooooo`03o`00oooooooooooo00kooooo000A
ooooo`03o`000?oooooooooo033ooooo00?o003oo`000?ooool0G_ooool2ool0obkooooo00?o003o
ooooooooool03Oooool0017ooooo00?o0000ooooooooool0;oooool00ol00?ooooooooooo`1Noooo
o`03ool0oooooooooooo02oooooo00?o003oooooooooool03?ooool0017ooooo00?o0000oooooooo
ool0;_ooool00ol00?ooooooooooo`1Mooooo`;oo`3o<oooool00ol00?ooooooooooo`0;ooooo`00
4Oooool2o`0002oooooo00?o003oooooooooool0G?ooool00ooo0?ooooooooooo`0cooooo`03o`00
oooooooooooo00_ooooo000Aooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool0G?oo
ool00ooo0?ooooooooooo`0eooooo`03o`00oooooooooooo00[ooooo000Aooooo`03o`000?oooooo
oooo02cooooo00?o003oooooooooool0Foooool2ool0ocWooooo00?o003oooooooooool02Oooool0
017ooooo00?o0000ooooooooool0:oooool00ol00?ooooooooooo`1Kooooo`03ool0oooooooooooo
03Wooooo00?o003oooooooooool02Oooool0017ooooo00?o0000ooooooooool09_ooool01_o^k^ko
<S8bo`000?lb<S;ok^k^o`00o`Cooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd09_oo
ool4o`000003oa0@4?oooooooooo01oooooo00?oo`3oooooooooool00oooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool00ol00?oooooo
o`000004o`0000Cooooo000Aooooo`03o`000?oooooooooo02Kooooo00GoMgMgoiRHV?ooooooV9RH
o`00o`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Wooooo`03o`000?oooooooooo01oooooo
0_oo0?l8ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02?ooooo
00Ko003ooiRHV?lQ8B7ok^k^oooooom4A4@4ooooo`004Oooool00ol0003oooooooooo`0Vooooo`05
oa0@4?ooooooooooo`00ool@41004?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01kooooo00?oo`3oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02;ooooo00Go003ooooooonHV9So8B4Qonk^kP05ooooo`004Oooool00ol0003oooooooooo`0Voooo
o`05o`000?oooooo003oooooool000003oooool00omgMgOo<S8booooo`0Wooooo`03o`000?oooooo
oooo01cooooo0_oo0?l;ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool09?ooool0
1Ol00?oooooooiRHV?lQ8B7ok^k^00Cooooo000Aooooo`;o00009oooool01Ol0003oooooo`00oooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03o`000?oooooooooo01_ooooo
00?oo`3oooooooooool02oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`09_ooool01?l00?ooooooogMgMomVIVH4ooooo`004Oooool00ol0003oooooooooo`0Vooooo`05
oa0@4?l00?ooooooooooool@41003?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
01Wooooo0_oo0?l>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool01?l0
0?ooooooooooool00004ooooo`004Oooool00ol0003oooooooooo`0Vooooo`05o`00oonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Kooooo0_l00000
0ooo0?ooooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool0
0ol0003o^[Zjo`00o`02o`0000Cooooo000Aooooo`03o`000?oooooooooo02Kooooo00Go003ooc8b
<_l0003o<S8bonk^kP0<ooooo`Co00009oooool00omEEEGoIVIVo`00000Gooooo`04o`000?oo0?oo
o`3oo`0000kooooo00?oEEEEofIVI_l000003Oooool4o`0002Kooooo00CoV9RHoa0@4?l0003o003o
0_l00003ooooo`004Oooool00ol0003oooooooooo`0Uooooo`03o`00oooooooooooo05Cooooo00Co
o`3oo`000?l0003o0000B_ooool01?l0003o003oo`000?l00003ooooo`004Oooool00ol0003ooooo
ooooo`0Tooooo`03o`00oooooooooooo05Cooooo00Coo`3oooooool0003o0000C?ooool2o`0000Co
oooo000Aooooo`03o`000?oooooooooo02?ooooo00?o003oooooooooool0Doooool2ool0oeKooooo
000Aooooo`03o`000?oooooooooo02?ooooo00?o003oooooooooool0D_ooool00ooo0?oooooooooo
o`1Fooooo`003?oooolZo`000003o`00ool0003o000005;o000000?oo`3oo`000?l00000Eol00000
017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool01?oo0?ooooooooooool00009ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00oooool0017ooooo00?o0000ooooooooool08Oooool00ol0
0?ooooooooooo`1@ooooo`;oo`3oFoooool0017ooooo00?o0000ooooooooool08?ooool00ol00?oo
ooooooooo`1@ooooo`03ool0oooooooooooo05_ooooo000Aooooo`03o`000?oooooooooo01oooooo
00?o003oooooooooool0D?ooool00ooo0?ooooooooooo`1Looooo`004Oooool00ol0003ooooooooo
o`0Oooooo`03o`00oooooooooooo04kooooo0_oo0?mOooooo`004Oooool00ol0003oooooooooo`0N
ooooo`03o`00oooooooooooo04kooooo00?oo`3oooooooooool0Goooool0017ooooo00?o0000oooo
ooooool07Oooool00ol00?ooooooooooo`1>ooooo`03ool0oooooooooooo063ooooo000Aooooo`;o
00007Oooool00ol00?ooooooooooo`1=ooooo`;oo`3oHoooool0017ooooo00?o0000ooooooooool0
7?ooool00ol00?ooooooooooo`1<ooooo`03ool0oooooooooooo06?ooooo000Aooooo`03o`000?oo
oooooooo01_ooooo00?o003oooooooooool0C?ooool00ooo0?ooooooooooo`1Tooooo`004Oooool0
0ol0003oooooooooo`0Jooooo`03o`00oooooooooooo04_ooooo0_oo0?mWooooo`004Oooool00ol0
003oooooooooo`0Jooooo`03o`00oooooooooooo04[ooooo00?oo`3oooooooooool0Ioooool0017o
oooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`18ooooo`;o000000?oo`3ooooooooo
ool0J?ooool0017ooooo00?o0000ooooooooool05_ooool2o`000003o`00oooooooooooo04Sooooo
0_l000000ooo0?oo0000ooooo`1Yooooo`004Oooool00ol0003oooooooooo`0Eooooo`;o000000?o
003oo`000?ooool0BOooool2ool0o`;o0000J_ooool0017ooooo0_l0000Fooooo`;o000000?o003o
o`000?ooool0B?ooool01?oo0?ooooooo`000?l0001[ooooo`004Oooool00ol0003oooooooooo`0F
ooooo`03o`00ool0003ooooo04Oooooo0_oo0?m_ooooo`004Oooool00ol0003oooooooooo`0Eoooo
o`03o`00oooooooooooo04Kooooo0_oo0?maooooo`004Oooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooooooo04Gooooo00?oo`3oooooooooool0LOooool0017ooooo00?o0000ooooooooool0
5?ooool00ol00?ooooooooooo`14ooooo`;oo`3oM?ooool0017ooooo00?o0000ooooooooool04ooo
ool00ol00?ooooooooooo`14ooooo`03ool0oooooooooooo07Cooooo000Aooooo`03o`000?oooooo
oooo01?ooooo00?o003oooooooooool0@_ooool2ool0ogOooooo000Aooooo`03o`000?oooooooooo
01;ooooo00?o003oooooooooool0@_ooool00ooo0?ooooooooooo`1gooooo`004Oooool2o`0001;o
oooo00?o003oooooooooool0@Oooool2ool0og[ooooo000Aooooo`03o`000?oooooooooo017ooooo
00?o003oooooooooool0@?ooool00ooo0?ooooooooooo`1jooooo`004Oooool00ol0003ooooooooo
o`0@ooooo`03o`00oooooooooooo03oooooo0_oo0?mmooooo`004Oooool00ol0003oooooooooo`0?
ooooo`03o`00oooooooooooo03kooooo0_oo0?moooooo`004Oooool00ol0003oooooooooo`0?oooo
o`03o`00oooooooooooo03cooooo0_oo0?n1ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03
o`00oooooooooooo03Wooooo0_l000000oooooooo`3oooooo`22ooooo`002?ooool5o`0000Cooooo
00?o0000ooooooooool03Oooool00ol00?ooooooooooo`0iooooo`;o00000_oo0?n4ooooo`002?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Cooooo0_l0000=ooooo`03o`00oooooooooooo03[ooooo
0_oo0?l2o`0008Cooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Co0000ool0oooo0?oo0000
3?ooool00ol00?ooooooooooo`0hooooo`;oo`3o00?oooooo`000?l00000QOooool000[ooooo00?o
V9RHob4Q8Oo^k^h00oooool3o`0000;oo`3o2_ooool00ol00?ooooooooooo`0gooooo`;oo`3oR_oo
ool000_ooooo00?oMgMgofIVI_ooool00oooool2o`0000;ooooo0ooo0?l6ooooo`03o`00oooooooo
oooo03Kooooo0_oo0?n<ooooo`003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo0_oo0?l3ooooo`03o`00oooooooooooo03Gooooo0_oo0?n>ooooo`002?ooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool2ool0o`03ooooool00?oooooo
03?ooooo0ooo0?n@ooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000oooo
ooooool02?ooool00ol00?ooo`3oooooo`0`ooooo`?oo`3oToooool0017ooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`04ool0obWooooo1?oo0?nFooooo`004Oooool00ol0003ooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo1?oo0?l4ooooo`;o00006?ooool2o`000003oooo
oooo0?ooo`3o00;oo`3oV_ooool0017ooooo00?o0000ooooooooool01_ooool00ol00?oooooooooo
o`09ooooo`Coo`3o0ol0000Fooooo`Coo`3oW_ooool0017ooooo0_l00006ooooo`03o`00oooooooo
oooo00gooooo00?o0000ool0oooo0?l02_oo0?l2ooooo`_oo`3o1?l0002Nooooo`004Oooool00ol0
003oooooooooo`04ooooo`03o`00oooooooooooo00oooooo0_l00009ooooo`?oo`3o3?ooool2o`00
09oooooo000Aooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0boooool0017ooooo
00?o0000ooooooooool00_ooool00ol00?ooooooooooo`3<ooooo`004Oooool01Ol0003ooooooooo
oooooooo003o0<oooooo000Aooooo`04o`000?ooooooooooo`00om3ooooo000Aooooo`;o000000?o
003oooooooooool0coooool0013ooooo0_l000000ol00?oo0000ooooo`3@ooooo`004?ooool01?l0
003o003oo`000?l0003Aooooo`004Oooool2o`000=;ooooo000Aooooo`03o`000?oooooooooo0=7o
oooo000Aooooo`03o`000?oooooooooo0=7ooooo003Uooooo`00iOooool00>Gooooo0000\
\>"],
  ImageRangeCache->{{{79.375, 262.25}, {285.375, 172.875}} -> {-1.13654, \
8.04896, 0.0121508, 0.0767774}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Simple Harmonic Motion",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell["\<\
Simple harmonic motion is the name given to the motion of an \
undamped mass on a linear spring. The plot of  position versus time, called a \
\"time series\", is a sinusoid. The phase plane trajectory for simple \
harmonic  motion is an ellipse. Only a portion of the ellipse is shown in the \
trajectory plotted above. The time it takes a phase point to traverse the \
ellipse is the same time it takes the mass spring system to return to its \
original configuration. The motion is periodic. The extreme values on the \
time series for position correspond to the points on the phase plane  \
trajectory that are farthest from the vertical velocity axis. The extreme \
values on the time series for velocity  correspond to the points on the phase \
plane trajectory that are farthest from the horizontal position axis. \
\>", \
"Text"],

Cell[TextData[StyleBox["Underdamped, unforced motion",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "We now examine the geometry of unforced oscillations when the system is \
underdamped. Solutions still oscillate. The overdamped case is considered in \
the exercises. Consider the same mass and spring, but add a damping term with \
",
  StyleBox["b",
    FontSlant->"Italic"],
  " = 1.0. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
dampedDE = 4.3y''[t] + y'[t] + 15.2y[t] == 0
gensoln = DSolve[ dampedDE, y[t], t]\
\>", "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(15.2`\ y[t]\), "+", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "+", 
        RowBox[{"4.3`", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
      "0"}]], "Output",
  CellLabel->"Out[4]="],

Cell[BoxData[
    \({{y[
            t] \[Rule] \[ExponentialE]\^\(\(-0.11627906976744186`\)\ t\)\ C[
                2]\ Cos[
                1.876529482545971`\ t] + \
\[ExponentialE]\^\(\(-0.11627906976744186`\)\ t\)\ C[1]\ Sin[
                1.876529482545971`\ t]}}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
Observe that the general solution still contains a sine and a \
cosine, but now a decaying exponential term appears on each one. Factor it \
out and what remains is a sinusoid. \
\>", "Text"],

Cell[TextData[{
  StyleBox["Typical Problem",
    FontVariations->{"Underline"->True}],
  " Pull the mass 2 meters in the positive direction and push it away from \
equilibrium with an  initial speed of 3 meters per second, just like before. \
Plot the solution and answer the same questions about its motion. Compare the \
answers to the ones obtained in the undamped case. "
}], "Text"],

Cell["\<\
These are the same initial conditions. We call the solution \
function G.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
soln = DSolve[ {dampedDE, y[0]==2, y'[0]==3}, y, t];
G := soln[[1,1,2]]
G[t]\
\>", "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-0.11627906976744186`\)\ t\)\ \((2.`\ Cos[
              1.876529482545971`\ t] + 
          1.7226258204849136`\ Sin[1.876529482545971`\ t])\)\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["The graph:", "Text"],

Cell[CellGroupData[{

Cell["Plot[ G[t], {t,0,6}, AspectRatio->1/3]", "Input",
  CellLabel->"In[225]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.151266 0.0688086 [
[.18254 .13877 -3 -9 ]
[.18254 .13877 3 0 ]
[.34127 .13877 -3 -9 ]
[.34127 .13877 3 0 ]
[.5 .13877 -3 -9 ]
[.5 .13877 3 0 ]
[.65873 .13877 -3 -9 ]
[.65873 .13877 3 0 ]
[.81746 .13877 -3 -9 ]
[.81746 .13877 3 0 ]
[.97619 .13877 -3 -9 ]
[.97619 .13877 3 0 ]
[.01131 .01365 -12 -4.5 ]
[.01131 .01365 0 4.5 ]
[.01131 .08246 -12 -4.5 ]
[.01131 .08246 0 4.5 ]
[.01131 .22007 -6 -4.5 ]
[.01131 .22007 0 4.5 ]
[.01131 .28888 -6 -4.5 ]
[.01131 .28888 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .15127 m
.18254 .15752 L
s
[(1)] .18254 .13877 0 1 Mshowa
.34127 .15127 m
.34127 .15752 L
s
[(2)] .34127 .13877 0 1 Mshowa
.5 .15127 m
.5 .15752 L
s
[(3)] .5 .13877 0 1 Mshowa
.65873 .15127 m
.65873 .15752 L
s
[(4)] .65873 .13877 0 1 Mshowa
.81746 .15127 m
.81746 .15752 L
s
[(5)] .81746 .13877 0 1 Mshowa
.97619 .15127 m
.97619 .15752 L
s
[(6)] .97619 .13877 0 1 Mshowa
.125 Mabswid
.05556 .15127 m
.05556 .15502 L
s
.0873 .15127 m
.0873 .15502 L
s
.11905 .15127 m
.11905 .15502 L
s
.15079 .15127 m
.15079 .15502 L
s
.21429 .15127 m
.21429 .15502 L
s
.24603 .15127 m
.24603 .15502 L
s
.27778 .15127 m
.27778 .15502 L
s
.30952 .15127 m
.30952 .15502 L
s
.37302 .15127 m
.37302 .15502 L
s
.40476 .15127 m
.40476 .15502 L
s
.43651 .15127 m
.43651 .15502 L
s
.46825 .15127 m
.46825 .15502 L
s
.53175 .15127 m
.53175 .15502 L
s
.56349 .15127 m
.56349 .15502 L
s
.59524 .15127 m
.59524 .15502 L
s
.62698 .15127 m
.62698 .15502 L
s
.69048 .15127 m
.69048 .15502 L
s
.72222 .15127 m
.72222 .15502 L
s
.75397 .15127 m
.75397 .15502 L
s
.78571 .15127 m
.78571 .15502 L
s
.84921 .15127 m
.84921 .15502 L
s
.88095 .15127 m
.88095 .15502 L
s
.9127 .15127 m
.9127 .15502 L
s
.94444 .15127 m
.94444 .15502 L
s
.25 Mabswid
0 .15127 m
1 .15127 L
s
.02381 .01365 m
.03006 .01365 L
s
[(-2)] .01131 .01365 1 0 Mshowa
.02381 .08246 m
.03006 .08246 L
s
[(-1)] .01131 .08246 1 0 Mshowa
.02381 .22007 m
.03006 .22007 L
s
[(1)] .01131 .22007 1 0 Mshowa
.02381 .28888 m
.03006 .28888 L
s
[(2)] .01131 .28888 1 0 Mshowa
.125 Mabswid
.02381 .02741 m
.02756 .02741 L
s
.02381 .04117 m
.02756 .04117 L
s
.02381 .05493 m
.02756 .05493 L
s
.02381 .0687 m
.02756 .0687 L
s
.02381 .09622 m
.02756 .09622 L
s
.02381 .10998 m
.02756 .10998 L
s
.02381 .12374 m
.02756 .12374 L
s
.02381 .1375 m
.02756 .1375 L
s
.02381 .16503 m
.02756 .16503 L
s
.02381 .17879 m
.02756 .17879 L
s
.02381 .19255 m
.02756 .19255 L
s
.02381 .20631 m
.02756 .20631 L
s
.02381 .23384 m
.02756 .23384 L
s
.02381 .2476 m
.02756 .2476 L
s
.02381 .26136 m
.02756 .26136 L
s
.02381 .27512 m
.02756 .27512 L
s
.02381 .30264 m
.02756 .30264 L
s
.02381 .31641 m
.02756 .31641 L
s
.02381 .33017 m
.02756 .33017 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.02381 .28888 m
.03279 .29968 L
.04262 .30944 L
.04758 .31351 L
.05288 .3172 L
.05785 .32005 L
.06244 .32215 L
.06503 .3231 L
.06788 .32396 L
.07075 .32462 L
.07232 .3249 L
.07379 .3251 L
.07445 .32517 L
.07517 .32524 L
.07648 .32534 L
.07776 .32539 L
.07895 .3254 L
.07968 .32539 L
.08036 .32536 L
.08164 .32529 L
.08236 .32524 L
.08302 .32517 L
.08451 .32499 L
.08691 .32458 L
.08916 .32407 L
.09427 .32247 L
.09924 .32033 L
.10458 .31739 L
.11475 .31005 L
.12582 .29959 L
.14594 .27471 L
.18672 .20742 L
.22599 .13432 L
.26374 .07103 L
.28309 .04527 L
.29305 .03435 L
.30394 .02445 L
.31432 .0171 L
.32398 .01217 L
.32933 .01025 L
.33186 .00954 L
.33418 .009 L
.33687 .00852 L
.33829 .00832 L
.33979 .00816 L
.34109 .00805 L
.34231 .00798 L
.34301 .00796 L
.34365 .00794 L
.34438 .00794 L
Mistroke
.34508 .00794 L
.34633 .00797 L
.34704 .008 L
.34768 .00804 L
.34887 .00813 L
.35013 .00826 L
.35231 .00855 L
.35469 .00898 L
.35999 .01034 L
.36493 .01209 L
.37381 .01639 L
.38333 .02258 L
.40461 .04181 L
.42474 .06575 L
.46312 .12128 L
.50396 .18324 L
.52425 .21083 L
.54328 .23292 L
.56148 .24968 L
.57171 .25697 L
.58108 .26219 L
.58583 .26431 L
.59091 .26615 L
.5957 .26749 L
.60004 .26838 L
.60271 .26878 L
.60397 .26892 L
.60516 .26903 L
.60644 .26912 L
.60712 .26916 L
.60785 .2692 L
.60862 .26922 L
.60934 .26923 L
.60999 .26924 L
.6107 .26924 L
.6119 .26922 L
.61259 .26919 L
.61323 .26916 L
.61453 .26909 L
.61592 .26897 L
.61844 .26868 L
.62076 .26832 L
.62549 .26733 L
.63054 .26586 L
.63966 .26223 L
.65049 .25631 L
.66035 .24951 L
.7003 .21074 L
.73873 .16341 L
.77962 .11349 L
Mistroke
.79995 .09229 L
.81899 .07602 L
.83723 .06438 L
.84747 .0597 L
.85684 .05665 L
.86161 .05556 L
.86423 .0551 L
.8667 .05474 L
.869 .05449 L
.8703 .05438 L
.8715 .05429 L
.8725 .05424 L
.87361 .0542 L
.87477 .05417 L
.87584 .05416 L
.87713 .05417 L
.87786 .05418 L
.87853 .05421 L
.87977 .05426 L
.88108 .05434 L
.88335 .05453 L
.88585 .05483 L
.88851 .05523 L
.89138 .05577 L
.89657 .05702 L
.90615 .06022 L
.91663 .06501 L
.93773 .07831 L
.97619 .11215 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[225]:=",
  ImageSize->{265.562, 88.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0000KR000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`004_ooool00ol0003oooooooooo`3oooooocOooooo000Booooo`03o`00
0?oooooooooo0?oooooo=oooool000Sooooo1Ol00005ooooo`03o`000?oooooooooo0?oooooo=ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo05kooooo3Ol0
003;ooooo`001_l00003ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0G?ooool2
o`0000gooooo0_l00039ooooo`002_ooool00onHV9So8B4Qonk^kP05ooooo`?o0000Foooool00ol0
003oooooooooo`0?ooooo`;o0000aoooool000_ooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`1Iooooo`;o00005?ooool00ol0003oooooooooo`34ooooo`003?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`33ooooo`002?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<;ooooo0008ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01Oooool3o`0005Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`31ooooo`004_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0`?ooool001;ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo0;oooooo000Booooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`2nooooo`004_ooool3o`0005;ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`2mooooo`004_ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0_?ooool001;ooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;_ooooo000Booooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2jooooo`004_ooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0T?ooool3o`00
02Kooooo000Booooo`?o0000C_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08Wo
oooo1_l00002ooooo`So00007oooool001;ooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo08Gooooo0ol0000@ooooo`;o00007Oooool001;ooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08;ooooo0_l0
000Eooooo`;o00006oooool001;ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo07oooooo0_l0000Iooooo`;o00006Oooool001;ooooo0ol0001;oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0OOooool2o`0001gooooo0_l0000Goooo
o`004_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Cooooo0009ooooo`Co0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Qooooo`;o00005?ooool000_ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`0Tooooo`;o00004_ooool000Ko00001Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`1fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool0
00_ooooo00?o0000ooooooooool01?ooool3o`0004Sooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_ooool000_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00go
oooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0<ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`1^ooooo`;o0000<Oooool00ol0003ooooooooo
o`0;ooooo`002Oooool00omEEEGoIVIVo`000006ooooo`?o0000AOooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0:
ooooo`004_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0Joooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Booooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`07ooooo`004_ooool3o`0002kooooo1?l000000ol@413ooooooooo
o`0>ooooo`03o`000?oooooooooo01[ooooo1Ol0000Rooooo`03o`000?oooooooooo00Wooooo00Go
V9RHoa0@4?l0003o<S8bolc<c00_ooooo`;o000000?o410@ooooooooool09?ooool00ol0003ooooo
ooooo`06ooooo`05odA4A?l0003o0000oc8b<_oMgMd0;Oooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo000Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08oooool00ol0003oooooooooo`08oooo
o`05oa0@4?nj^[[oooooogMgMolb<S80<?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00[ooooo00?oMgMgoc8b<_ooool0;?ooool01OmEEEGoMgMgooooool0003o8B4Q00Kooooo000B
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0L
ooooo`03oiRHV?lQ8B7ok^k^02Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0[
ooooo`Go00009Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo00Go0000
ooooooooooooooooo`000006ooooo`004_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool07_ooool00onHV9So8B4Qonk^kP0Tooooo`03o`000?oooooo
oooo00[ooooo00?oZJVYoa0@4?ooool0;?ooool01?m4A4CogMgMooooool0000Uooooo`03o`000?oo
oooooooo00_ooooo00?oMgMgoc8b<_ooool0;?ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
000Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Oooooo`03ogMgMomVIVKooooo02Cooooo00?o0000ooooooooool02?ooool00ol@413o0000okZj
^P0]ooooo`04omgMgOmEEEGoooooo`0002Cooooo00?o0000ooooooooool02Oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<02gooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`004_ooool3o`00033o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool02Oooool00onj^[[o8B4Qooooo`0]ooooo`03ogMgMoo<c<co000002?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0_ooooo`03oeEEEOn7QhOooooo00So
oooo000Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Nooooo`05o`000?nj^[[ooooooiRHV?l@41009_ooool00ol0003oooooooooo`05ooooo`05
oa0@4?nHV9SooooookZj^_l00000;_ooool00oo^k^koA4A4o`00000Rooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0;oooool00ooMgMgo410@oiRHV008ooooo`004_ooool00ol0003o
ooooooooo`0^ooooo`03oeEEEOmVIVKo000000kooooo00?o0000ooooooooool07_ooool01OnHV9So
410@o`000?lQ8B7oc<c<02Oooooo00?o0000ooooooooool01?ooool01OnYZJWo410@o`000?l@413o
ZJVY02oooooo00?oMgMgo`000?ooool08Oooool00ol0003oooooooooo`0;ooooo`Co0000;oooool0
1?o<c<coA4A4o`000?l@4106ooooo`004_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`19ooooo`004_ooool3o`00
03kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
04[ooooo000Booooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo04_ooooo000Booooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo04cooooo
000Booooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo04gooooo000;oooooooo0000@Ol0000001;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l00009oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo000Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`004_ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`1@ooooo`004_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Aooooo`004_ooool3o`0003Wooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo057ooooo
000Booooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo05;ooooo000Booooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo05?ooooo000Boooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo05Cooooo000Booooo`?o0000=oooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0EOooool001;ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
EOooool001;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0E_ooool001;ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0Eoooool0
01;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool0F?ooool001;ooooo0ol0000dooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Iooooo`004_ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`1Iooooo`004_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`1Jooooo`004_ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1K
ooooo`004_ooool3o`0003;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo05cooooo000Booooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo05gooooo0009ooooo`Co0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06Wooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Nooooo`002oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo05oooooo000;ooooo`03o`000?oooooooooo00Cooooo0ol0000`
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1P
ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo067ooooo000;ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0H_ooool000_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`1Sooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06Cooooo0009ooooo`03oeEEEOmVIVKo000000Kooooo0ol0000]ooooo`03o`000?oooooo
oooo07?ooooo0_l0000Yooooo`03o`000?oooooooooo06Gooooo000Booooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06Kooooo000Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Moooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo000Booooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Sooooo
000Booooo`?o0000:oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0JOooool001;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1l
ooooo`;o00007Oooool2o`0006cooooo000Booooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0Ooooool2o`0001[ooooo00?o0000ooooooooool0K?ooool001;ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`21ooooo`;o00005_ooool2o`0006oooooo000Booooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Aooooo`;o0000
LOooool001;ooooo0ol0000Xooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool03_oo
ool2o`0007?ooooo000Booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Qoooool3
o`0000_ooooo0_l0001eooooo`004_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
08_ooooo2ol0001gooooo`004_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0?oo
oooo3_ooool001;ooooo0ol0000Uooooo`03o`000?oooooooooo0?oooooo3oooool001;ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`3oooooo`oooooo0008ooooo`Go00001Oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0?oooooo4?ooool000Sooooo00GoV9RHob4Q
8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0oooooolA
ooooo`002Oooool00onHV9So8B4Qonk^kP06ooooo`?o00008_ooool00ol0003oooooooooo`3ooooo
oa;ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`3ooooooa?ooooo000;ooooo`03ogMgMomVIVKooooo00Cooooo0_l0000Qooooo`03o`00
0?oooooooooo0?oooooo5?ooool000cooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
000Oooooo`03o`000?oooooooooo0?oooooo5Oooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@
4005ooooo`03o`000?oooooooooo00;o00007?ooool00ol0003oooooooooo`3ooooooaKooooo0008
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool3o`0000;ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`3ooooooaOooooo000Booooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`3ooooooaSooooo000Booooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04oooool2o`000?oooooo6oooool001;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0?oooooo6oooool001;ooooo
0ol00006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0oooooolLooooo`004_oo
ool00ol0003oooooooooo`07ooooo`?o00003Oooool00ol0003oooooooooo`3ooooooagooooo000B
ooooo`03o`000?oooooooooo00[ooooo0_l00007ooooo`Co0000oooooolPooooo`004_ooool00ol0
003oooooooooo`0<ooooo`Oo0000oooooolTooooo`004_ooool00ol0003oooooooooo`3oooooocOo
oooo000Booooo`?o0000oooooolgooooo`004_ooool00ol0003oooooooooo`3oooooocOooooo0000
\
\>"],
  ImageRangeCache->{{{77.875, 342.438}, {261.688, 174.312}} -> {-2.29532, \
7.62652, 0.0246625, 0.0568922}}]
}, Open  ]],

Cell[TextData[{
  "This not a sinusoid because the oscillations are not of constant \
amplitude, they are decreasing. The time  constant for the exponential term \
is approximately 9 seconds (0.11 is about ",
  Cell[BoxData[
      \(TraditionalForm\`1\/9\)]],
  ") so, over the 6 second time interval shown above, the oscillations \
decrease by a factor of about 6/9 x 1/3 = 2/9. The ",
  StyleBox["t",
    FontSlant->"Italic"],
  " value for the widest oscillation will  be called tmaxG. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
tmaxG = t/.FindRoot[ G'[t]==0, {t,0.5} ]
ymaxG = G[tmaxG]\
\>", "Input",
  CellLabel->"In[227]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(0.3459255032843377`\)], "Output",
  CellLabel->"Out[227]="],

Cell[BoxData[
    \(2.530669435626702`\)], "Output",
  CellLabel->"Out[228]="]
}, Open  ]],

Cell["\<\
The damped mass moves 0.531 meters in the positive direction \
(compared to 0.558 meters before) and it gets  there a tiny bit faster (the \
tmax value calculated earlier was 0.358). The time that the damped mass first \
passes through equilibrium will be denoted t0G.  \
\>", "Text"],

Cell[CellGroupData[{

Cell["t0G = t/.FindRoot[ G[t]==0, {t,1} ]", "Input",
  CellLabel->"In[229]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(1.2159795971433995`\)], "Output",
  CellLabel->"Out[229]="]
}, Open  ]],

Cell[TextData[{
  "Recall that the undamped mass got to the equilibrium for the first time at \
 ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 1.194 seconds. It was traveling at  a speed of 4.809 meters a second. \
The next calculation shows that the damped mass not only took longer, but it \
is also going more slowly through equilibrium, traveling 4.300 meters per \
second. "
}], "Text"],

Cell[CellGroupData[{

Cell["Abs[G'[t0G]]*meterspersecond", "Input",
  CellLabel->"In[230]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(4.300171857220278`\ meterspersecond\)], "Output",
  CellLabel->"Out[230]="]
}, Open  ]],

Cell["\<\
This information goes on the the graph of the position and \
velocity, with dashed lines, just like before. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
lines = ListPlot[ {{0,-4.30},{t0G,-4.30},{t0,0}}, PlotJoined->True, \

                  PlotStyle->Dashing[{0.02,0.02}] ];
Show[ lines,
      Plot[ {G[t],G'[t]}, {t,0,2},
            PlotStyle->{RGBColor[1,0,0],RGBColor[0,0,1]} ] ,
      PlotRange->{-6,4}
    ]\
\>", "Input",
  CellLabel->"In[231]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.37082 0.0618034 [
[.2619 .35832 -9 -9 ]
[.2619 .35832 9 0 ]
[.5 .35832 -3 -9 ]
[.5 .35832 3 0 ]
[.7381 .35832 -9 -9 ]
[.7381 .35832 9 0 ]
[.97619 .35832 -3 -9 ]
[.97619 .35832 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .12361 -12 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -12 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .37082 m
.2619 .37707 L
s
[(0.5)] .2619 .35832 0 1 Mshowa
.5 .37082 m
.5 .37707 L
s
[(1)] .5 .35832 0 1 Mshowa
.7381 .37082 m
.7381 .37707 L
s
[(1.5)] .7381 .35832 0 1 Mshowa
.97619 .37082 m
.97619 .37707 L
s
[(2)] .97619 .35832 0 1 Mshowa
.125 Mabswid
.07143 .37082 m
.07143 .37457 L
s
.11905 .37082 m
.11905 .37457 L
s
.16667 .37082 m
.16667 .37457 L
s
.21429 .37082 m
.21429 .37457 L
s
.30952 .37082 m
.30952 .37457 L
s
.35714 .37082 m
.35714 .37457 L
s
.40476 .37082 m
.40476 .37457 L
s
.45238 .37082 m
.45238 .37457 L
s
.54762 .37082 m
.54762 .37457 L
s
.59524 .37082 m
.59524 .37457 L
s
.64286 .37082 m
.64286 .37457 L
s
.69048 .37082 m
.69048 .37457 L
s
.78571 .37082 m
.78571 .37457 L
s
.83333 .37082 m
.83333 .37457 L
s
.88095 .37082 m
.88095 .37457 L
s
.92857 .37082 m
.92857 .37457 L
s
.25 Mabswid
0 .37082 m
1 .37082 L
s
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .12361 m
.03006 .12361 L
s
[(-4)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(-2)] .01131 .24721 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(2)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .10507 m
.60285 .10507 L
.59221 .37082 L
s
1 0 0 r
[ ] 0 setdash
.02381 .49443 m
.06244 .50785 L
.08255 .51349 L
.10458 .51859 L
.12507 .52229 L
.14415 .52481 L
.15465 .52582 L
.15981 .52621 L
.16457 .52652 L
.16881 .52675 L
.17348 .52695 L
.17817 .52709 L
.18074 .52715 L
.18314 .52719 L
.18439 .5272 L
.18507 .52721 L
.18572 .52721 L
.18697 .52722 L
.18811 .52722 L
.18877 .52722 L
.18946 .52722 L
.19071 .52722 L
.1914 .52721 L
.19205 .52721 L
.19352 .52719 L
.1948 .52718 L
.19602 .52716 L
.19829 .52711 L
.20073 .52704 L
.20339 .52696 L
.20806 .52676 L
.21301 .5265 L
.22192 .52588 L
.23129 .52502 L
.24139 .52386 L
.25967 .52117 L
.27971 .51735 L
.30081 .51238 L
.33892 .5011 L
.37948 .48612 L
.41852 .46921 L
.46002 .44907 L
.5 .42808 L
.53847 .40693 L
.57939 .38397 L
.61879 .36196 L
.65668 .34139 L
.69702 .32063 L
.73584 .30221 L
.77712 .28477 L
Mistroke
.81688 .27042 L
.85512 .25919 L
.87648 .25409 L
.89582 .25023 L
.91624 .24696 L
.935 .24468 L
.94439 .24381 L
.95429 .24308 L
.96423 .24255 L
.96986 .24234 L
.97512 .2422 L
.97619 .24217 L
Mfstroke
0 0 1 r
.02381 .55623 m
.06244 .51566 L
.10458 .46851 L
.14415 .42265 L
.18221 .37818 L
.22272 .33158 L
.26171 .28852 L
.30316 .24577 L
.34309 .20852 L
.3815 .17711 L
.42237 .14918 L
.46172 .1282 L
.48147 .11997 L
.49955 .11385 L
.51896 .10879 L
.52966 .10667 L
.53984 .1051 L
.54943 .10402 L
.55479 .10359 L
.55732 .10343 L
.55964 .1033 L
.56181 .1032 L
.56419 .10312 L
.56535 .10309 L
.56659 .10306 L
.56789 .10304 L
.56911 .10302 L
.57026 .10301 L
.57151 .10301 L
.57269 .10301 L
.57378 .10302 L
.57476 .10303 L
.57584 .10305 L
.57697 .10307 L
.57803 .1031 L
.58046 .10318 L
.58273 .10327 L
.58786 .10357 L
.59287 .10396 L
.59821 .1045 L
.60791 .10576 L
.61672 .10725 L
.6359 .11155 L
.6567 .11784 L
.69762 .13491 L
.73702 .15678 L
.77491 .18226 L
.81525 .21345 L
.85407 .24663 L
.89535 .28436 L
Mistroke
.93511 .32215 L
.97336 .35895 L
.97619 .36167 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[231]:=",
  ImageSize->{197.5, 121.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003f0000V2000`400?l00000o`00003om_ooool0
0?Kooooo003fooooo`002oooool01Oo^k^ko<S8bo`000?l@413oc<c<0>Kooooo000;ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B40i_ooool000?ooooo1_l00002ooooo`05o`000?ooooooooooooooool0
0000i_ooool000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`;o0000goooool000_ooooo
00Go0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oooooooooo0=kooooo000;ooooo`03oeEE
EOn7QhOooooo00Oooooo00?o0000ooooooooool0g_ooool000_ooooo00?ogMgMoa0@4?nHV9P01ooo
ool00ol0003oooooooooo`3Nooooo`003?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oo
oooooooo0=kooooo000Eooooo`03o`000?oooooooooo0=kooooo000Eooooo`03o`000?oooooooooo
0=kooooo000Eooooo`;o0000goooool001Gooooo00?o0000ooooooooool0g_ooool001Gooooo00?o
0000ooooooooool0g_ooool001Gooooo00?o0000ooooooooool0g_ooool001Gooooo00?o0000oooo
ooooool0g_ooool001Gooooo00?o0000ooooooooool0g_ooool001Gooooo00?o0000ooooooooool0
g_ooool001Gooooo0_l0003Oooooo`005Oooool00ol0003oooooooooo`3Nooooo`005Oooool00ol0
003oooooooooo`3Nooooo`005Oooool00ol0003oooooooooo`3Nooooo`005Oooool00ol0003ooooo
ooooo`3Nooooo`005Oooool00ol0003oooooooooo`3Nooooo`005Oooool00ol0003oooooooooo`3N
ooooo`005Oooool2o`000=oooooo000Eooooo`03o`000?oooooooooo0=kooooo000Eooooo`03o`00
0?oooooooooo07?ooooo3_l00?mMooooo`005Oooool5o`0000Cooooo1Ol00004ooooo`Go00001?oo
ool5o`0000Cooooo1_l00003ooooo`Ko00000oooool6o`0000?ooooo1_l00003ooooo`Ko00000ooo
ool6o`0000?ooooo1_l00003ooooo`Ko00001?ooool2o`0000Oo003o1Ol00004ooooo`Go00001Ol0
0?mHooooo`003Oooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0J_ooool2
o`00oa[ooooo1Ol00?mCooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
06Oooooo0ol00?lQooooo`?o003oD?ooool000?ooooo1_l00002ooooo`Go00001Oooool00ol0003o
ooooooooo`1Sooooo`Co003o9oooool2o`00odkooooo000;ooooo`04odA4A?oMgMgoooooo`0000Ko
oooo0_l0001Rooooo`;o003o7Oooool00ol0003oooooooooo`0=ooooo`?o003oBoooool000_ooooo
00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`1Oooooo`;o003o7oooool00ol0003o
ooooooooo`0@ooooo`;o003oBOooool000cooooo00?oMgMgolc<c?l000001_ooool00ol0003ooooo
ooooo`1Mooooo`;o003o8Oooool00ol0003oooooooooo`0Booooo`;o003oAoooool000cooooo00?o
k^k^odA4A?l000001_ooool00ol0003oooooooooo`1Kooooo`;o003o8oooool00ol0003ooooooooo
o`0Dooooo`;o003oAOooool000gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`1J
ooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool05_ooool2o`00od?ooooo000Eoooo
o`03o`000?oooooooooo05Sooooo0_l00?lVooooo`03o`000?oooooooooo01Sooooo00?o003ooooo
ooooool0@?ooool001Gooooo00?o0000ooooooooool0E_ooool2o`00odCooooo0_l00?m0ooooo`00
5Oooool2o`0005Kooooo00?o003oooooooooool0A_ooool2o`00ockooooo000Eooooo`03o`000?oo
oooooooo05?ooooo0_l00?m;ooooo`03o`00oooooooooooo03_ooooo000Eooooo`03o`000?oooooo
oooo05;ooooo00?o003oooooooooool0:_ooool00ol0003oooooooooo`0Oooooo`;o003o>oooool0
01Gooooo00?o0000ooooooooool0D?ooool2o`00obgooooo00?o0000ooooooooool08Oooool00ol0
0?ooooooooooo`0hooooo`005Oooool00ol0003oooooooooo`1?ooooo`03o`00oooooooooooo02go
oooo00?o0000ooooooooool08_ooool2o`00ocSooooo000Eooooo`03o`000?oooooooooo04gooooo
0_l00?l`ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0=Oooool001Gooooo00?o
0000ooooooooool0C?ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo02Gooooo0_l0
0?leooooo`005Oooool2o`0004cooooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`0W
ooooo`03o`00oooooooooooo03;ooooo000Eooooo`03o`000?oooooooooo04Wooooo0_l00?mOoooo
o`03o`00oooooooooooo037ooooo000Eooooo`03o`000?oooooooooo04Sooooo00?o003ooooooooo
ool0H?ooool2o`00oc7ooooo000Eooooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool0
Hoooool00ol00?ooooooooooo`0^ooooo`005Oooool00ol0003oooooooooo`16ooooo`03o`00oooo
oooooooo06Gooooo00?o003oooooooooool0;Oooool001Gooooo00?o0000ooooooooool0A?ooool2
o`00ocWooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`0/ooooo`005Oooool00ol0
003oooooooooo`13ooooo`03o`00oooooooooooo03Wooooo00?o0000ooooooooool0;_ooool2o`00
obcooooo000Eooooo`;o0000@oooool00ol00?ooooooooooo`0jooooo`03o`000?oooooooooo033o
oooo00?o003oooooooooool0:Oooool001Gooooo00?o0000ooooooooool0@Oooool00ol00?oooooo
ooooo`0kooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0:?ooool001Gooooo00?o
0000ooooooooool0@?ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo03;ooooo00?o
003oooooooooool09oooool001Gooooo00?o0000ooooooooool0?oooool00ol00?ooooooooooo`1c
ooooo`03o`00oooooooooooo02Kooooo000;ooooo`Go00001Oooool00ol0003oooooooooo`0noooo
o`03o`00oooooooooooo07Gooooo00?o003oooooooooool09Oooool000_ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool0Moooool00ol0
0?ooooooooooo`0Tooooo`000oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`0looooo`03o`00oooooooooooo07Wooooo00?o003oooooooooool03_ooool=ool000So
oooo000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l0000mooooo`03o`00oooooooooooo043ooooo
00?o0000ooooooooool0=oooool2o`00o`Gooooo2Ooo000Eooooo`003_ooool00omgMgOoIVIVoooo
o`04ooooo`03o`000?oooooooooo03_ooooo00?o003oooooooooool0@Oooool00ol0003ooooooooo
o`0iooooo`03o`00ooooooooo`0000;oo`007_ooool000oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0jooooo`03o`00oooooooooooo04;ooooo00?o0000ooooooooool0>?ooool2
ool00003o`00oooooooooooo01oooooo000;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool0
0ol0003oooooooooo`0iooooo`03o`00oooooooooooo04?ooooo00?o0000ooooooooool0=Oooool3
ool000?ooooo00?o003oooooooooool07_ooool000_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005
ooooo`03o`000?oooooooooo03Sooooo00?o003oooooooooool0A?ooool00ol0003oooooooooo`0a
ooooo`Coo`001oooool00ol00?ooooooooooo`0Mooooo`005Oooool00ol0003oooooooooo`0goooo
o`03o`00oooooooooooo07Gooooo1?oo000<ooooo`03o`00oooooooooooo01cooooo000Eooooo`03
o`000?oooooooooo03Kooooo00?o003oooooooooool0Loooool3ool0017ooooo00?o003ooooooooo
ool06oooool001Gooooo0_l0000fooooo`03o`00oooooooooooo077ooooo0ooo000Eooooo`03o`00
oooooooooooo01[ooooo000Eooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool0Kooo
ool3ool001Wooooo00?o003oooooooooool06Oooool001Gooooo00?o0000ooooooooool0<oooool0
0ol00?ooooooooooo`18ooooo`03o`000?oooooooooo02?ooooo0_oo000Mooooo`03o`00oooooooo
oooo01Sooooo000Eooooo`03o`000?oooooooooo03?ooooo00?o003oooooooooool0B?ooool00ol0
003oooooooooo`0Pooooo`?oo`008?ooool00ol00?ooooooooooo`0Gooooo`005Oooool00ol0003o
ooooooooo`0booooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool07_ooool2ool002Co
oooo00?o003oooooooooool05_ooool001Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`1:ooooo`03o`000?oooooooooo01cooooo0_oo000Wooooo`03o`00oooooooooooo01Gooooo
000Eooooo`03o`000?oooooooooo033ooooo00?o003oooooooooool0Boooool00ol0003ooooooooo
o`0Jooooo`;oo`00:_ooool00ol00?ooooooooooo`0Dooooo`005Oooool2o`00033ooooo00?o003o
ooooooooool0I_ooool3ool002gooooo00?o003oooooooooool04oooool001Gooooo00?o0000oooo
ooooool0;_ooool00ol00?ooooooooooo`1Uooooo`;oo`00<Oooool00ol00?ooooooooooo`0Boooo
o`005Oooool00ol0003oooooooooo`0Xooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko003o1?ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Yooooo`Co000000?o410@ooooooooool09_oo
ool2ool000?o000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Pooooo`03o`00oooooooooooo00Gooooo1Ol00007ooooo`005Oooool00ol0003ooooooooo
o`0Xooooo`05ogMgMonHV9SooooooiRHV?l00?l01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
:_ooool00ol0003oooooooooo`0Vooooo`;oo`000oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0Pooooo`;o003o1Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo000Eooooo`03o`000?oooooooooo02Sooooo00Go410@oooooooooooo003ooa0@400@ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`;o
o`001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00?o003ooooooooo
ool00oooool00onHV9So8B4Qonk^kP08ooooo`005Oooool00ol0003oooooooooo`0Xooooo`05o`00
0?oooooo003oooooool000003oooool00omgMgOo<S8booooo`0Zooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool08oooool00ol00?ooooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo000Eooooo`03o`000?oooooooooo02Sooooo00Go0000ooooool00?ooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0:oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00cooooo0_oo0008ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00U
ooooo`03o`00oooooooooooo00?ooooo00?oMgMgofIVI_ooool01_ooool001Gooooo0_l0000Yoooo
o`05oa0@4?l00?ooooooooooool@41003?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool02_ooool2ool000[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Xooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool0:?ooool01Ol00?ooV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?oo`00
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00Ko003o
o`000?nj^[[ooooooiRHV?l@4107ooooo`005Oooool00ol0003oooooooooo`0Wooooo`06o`00ooo^
k^ko<S8bo`000?lb<S;ok^k^3?ooool4o`0002[ooooo00?oEEEEofIVI_l000007_ooool2ool000_o
oooo00?oEEEEofIVI_l000003Oooool4o`0002Wooooo00Go003ooa0@4?l0003o8B4Qolc<c007oooo
o`005Oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo05gooooo0_oo001;ooooo`03
o`00oooooooooooo00Sooooo000Eooooo`03o`000?oooooooooo02Gooooo00?o003oooooooooool0
GOooool00ooo003oooooooooo`1<ooooo`03o`00oooooooooooo00Oooooo000Eooooo`03o`000?oo
oooooooo02Cooooo00?o003oooooooooool0G?ooool2ool0053ooooo00?o003oooooooooool01_oo
ool001Gooooo00?o0000ooooooooool08oooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooo
oooo00;oo`00Foooool000oooooo:ol000000ol00?oo0000o`00001Jo`0000;oo`00F_l00003oooo
o`005Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool01Ol0003ooooooooooooooooo003o00Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`06ooooo`005Oooool00ol0003oooooooooo`0Qooooo`03o`00oooooooooooo05So
oooo0_oo001Pooooo`005Oooool00ol0003oooooooooo`0Pooooo`03o`00oooooooooooo05Oooooo
0_oo001Rooooo`005Oooool00ol0003oooooooooo`0Oooooo`03o`00oooooooooooo05Kooooo0_oo
001Tooooo`005Oooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo05Gooooo0_oo001V
ooooo`005Oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo05Cooooo0_oo001Xoooo
o`005Oooool2o`0001gooooo00?o003oooooooooool0Doooool2ool006[ooooo000Eooooo`03o`00
0?oooooooooo01cooooo00?o003oooooooooool0DOooool2ool006cooooo000Eooooo`03o`000?oo
oooooooo01_ooooo00?o003oooooooooool0DOooool00ooo003oooooooooo`1/ooooo`005Oooool0
0ol0003oooooooooo`0Jooooo`03o`00oooooooooooo053ooooo0_oo001_ooooo`005Oooool00ol0
003oooooooooo`0Iooooo`03o`00oooooooooooo04oooooo0_oo001aooooo`005Oooool00ol0003o
ooooooooo`0Hooooo`03o`00oooooooooooo04oooooo00?oo`00ooooooooool0LOooool001Gooooo
00?o0000ooooooooool06?ooool00ol00?ooooooooooo`1=ooooo`;oo`00M?ooool001Gooooo0_l0
000Hooooo`03o`00oooooooooooo04cooooo0_oo001fooooo`005Oooool00ol0003oooooooooo`0F
ooooo`03o`00oooooooooooo04_ooooo0_oo001hooooo`005Oooool00ol0003oooooooooo`0Eoooo
o`03o`00oooooooooooo04_ooooo00?oo`00ooooooooool0N?ooool001Gooooo00?o0000oooooooo
ool05?ooool00ol00?ooooooooooo`1:ooooo`;oo`00Noooool001Gooooo00?o0000ooooooooool0
4oooool00ol00?ooooooooooo`19ooooo`;oo`00OOooool001Gooooo00?o0000ooooooooool04_oo
ool00ol00?ooooooooooo`17ooooo`?oo`00Ooooool001Gooooo00?o0000ooooooooool04Oooool0
0ol00?ooooooooooo`16ooooo`;oo`00P_ooool001Gooooo0_l0000Aooooo`03o`00oooooooooooo
04Cooooo0ooo0024ooooo`005Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo04?o
oooo0_oo0027ooooo`005Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo047ooooo
0_oo0029ooooo`005Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo03oooooo0ooo
002;ooooo`002oooool5o`0000Gooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`0n
ooooo`;oo`00S_ooool000_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooo
oooo00cooooo00?o003oooooooooool0?Oooool2ool0093ooooo000<ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0kooooo`?oo`00T_ooool000go
oooo00?oV9RHob4Q8Oo^k^h01Oooool2ool000_ooooo00?o003oooooooooool0>Oooool3ool009Go
oooo000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo00000_oo0007ooooo`03o`00
oooooooooooo03Oooooo0ooo002Hooooo`003oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo0ooo0003ooooo`03o`00oooooooooooo03Gooooo0ooo002Kooooo`002oooool0
1Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool01Oooool2ool00003o`00oooo
003ooooo03?ooooo0ooo002Nooooo`002oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o
0000ooooooooool01_ooool00ol00?ooooooooooo`05ool002_ooooo1?oo002Qooooo`005Oooool0
0ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Kooooo1Ooo000Rooooo`Coo`00YOooool0
01Gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`Coo`006Oooool5ool0
0:Wooooo000Eooooo`;o00001Oooool00ol00?ooooooooooo`0@oooooaWoo`00[_ooool001Gooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`3Hooooo`005Oooool00ol0003ooooooooo
o`02ooooo`03o`00oooooooooooo0=Wooooo000Eooooo`05o`000?ooooooooooooooool00?l0g?oo
ool001Gooooo00Co0000oooooooooooo003ogOooool001Gooooo00?o0000ooooool00?l0g_ooool0
01Gooooo00?o0000o`00ooooool0g_ooool001Gooooo00?o003oo`000?ooool0g_ooool001Gooooo
00?o0000ooooooooool0g_ooool001Gooooo00?o0000ooooooooool0g_ooool001Gooooo00?o0000
ooooooooool0g_ooool001Gooooo00?o0000ooooooooool0g_ooool001Gooooo00?o0000oooooooo
ool0g_ooool001Gooooo00?o0000ooooooooool0g_ooool001Gooooo0_l0003Oooooo`005Oooool0
0ol0003oooooooooo`3Nooooo`005Oooool00ol0003oooooooooo`3Nooooo`005Oooool00ol0003o
ooooooooo`3Nooooo`003Oooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
g_ooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Nooooo`002oooool5
o`0000Gooooo00?o0000ooooooooool0g_ooool000_ooooo00CoA4A4omgMgOoooooo00001_ooool2
o`000=oooooo000;ooooo`04omgMgOmEEEGoooooo`000>Oooooo000<ooooo`03ogMgMoo<c<co0000
0>Oooooo000<ooooo`03onk^k_m4A4Co00000>Oooooo000=ooooo`03ogMgMol0003ooooo0>Kooooo
003fooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 274.375}, {281.312, 160.375}} -> {-1.0998, \
7.92519, 0.0115947, 0.0893359}}]
}, Open  ]],

Cell[TextData[StyleBox["The phase plane trajectory for underdamped \
oscillations ",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
The motion of the damped system is no longer periodic and the phase \
plane trajectory is no longer an ellipse. It spirals inward. See the phase \
trajectory below where the time of motion has been extended to 6 seconds. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
traj = ParametricPlot[ {G[t],G'[t]}, {t,0,6}, \
PlotRange->{{-4,4},{-6,6}},
                AspectRatio->6/4 ]\
\>", "Input",
  CellLabel->"In[234]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.75 0.125 [
[0 .7375 -6 -9 ]
[0 .7375 6 0 ]
[.125 .7375 -6 -9 ]
[.125 .7375 6 0 ]
[.25 .7375 -6 -9 ]
[.25 .7375 6 0 ]
[.375 .7375 -6 -9 ]
[.375 .7375 6 0 ]
[.625 .7375 -3 -9 ]
[.625 .7375 3 0 ]
[.75 .7375 -3 -9 ]
[.75 .7375 3 0 ]
[.875 .7375 -3 -9 ]
[.875 .7375 3 0 ]
[1 .7375 -3 -9 ]
[1 .7375 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -12 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -6 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .75 m
0 .75625 L
s
[(-4)] 0 .7375 0 1 Mshowa
.125 .75 m
.125 .75625 L
s
[(-3)] .125 .7375 0 1 Mshowa
.25 .75 m
.25 .75625 L
s
[(-2)] .25 .7375 0 1 Mshowa
.375 .75 m
.375 .75625 L
s
[(-1)] .375 .7375 0 1 Mshowa
.625 .75 m
.625 .75625 L
s
[(1)] .625 .7375 0 1 Mshowa
.75 .75 m
.75 .75625 L
s
[(2)] .75 .7375 0 1 Mshowa
.875 .75 m
.875 .75625 L
s
[(3)] .875 .7375 0 1 Mshowa
1 .75 m
1 .75625 L
s
[(4)] 1 .7375 0 1 Mshowa
.125 Mabswid
.025 .75 m
.025 .75375 L
s
.05 .75 m
.05 .75375 L
s
.075 .75 m
.075 .75375 L
s
.1 .75 m
.1 .75375 L
s
.15 .75 m
.15 .75375 L
s
.175 .75 m
.175 .75375 L
s
.2 .75 m
.2 .75375 L
s
.225 .75 m
.225 .75375 L
s
.275 .75 m
.275 .75375 L
s
.3 .75 m
.3 .75375 L
s
.325 .75 m
.325 .75375 L
s
.35 .75 m
.35 .75375 L
s
.4 .75 m
.4 .75375 L
s
.425 .75 m
.425 .75375 L
s
.45 .75 m
.45 .75375 L
s
.475 .75 m
.475 .75375 L
s
.525 .75 m
.525 .75375 L
s
.55 .75 m
.55 .75375 L
s
.575 .75 m
.575 .75375 L
s
.6 .75 m
.6 .75375 L
s
.65 .75 m
.65 .75375 L
s
.675 .75 m
.675 .75375 L
s
.7 .75 m
.7 .75375 L
s
.725 .75 m
.725 .75375 L
s
.775 .75 m
.775 .75375 L
s
.8 .75 m
.8 .75375 L
s
.825 .75 m
.825 .75375 L
s
.85 .75 m
.85 .75375 L
s
.9 .75 m
.9 .75375 L
s
.925 .75 m
.925 .75375 L
s
.95 .75 m
.95 .75375 L
s
.975 .75 m
.975 .75375 L
s
.25 Mabswid
0 .75 m
1 .75 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-4)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(-2)] .4875 .5 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(4)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(6)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .0625 m
.50375 .0625 L
s
.5 .125 m
.50375 .125 L
s
.5 .1875 m
.50375 .1875 L
s
.5 .3125 m
.50375 .3125 L
s
.5 .375 m
.50375 .375 L
s
.5 .4375 m
.50375 .4375 L
s
.5 .5625 m
.50375 .5625 L
s
.5 .625 m
.50375 .625 L
s
.5 .6875 m
.50375 .6875 L
s
.5 .8125 m
.50375 .8125 L
s
.5 .875 m
.50375 .875 L
s
.5 .9375 m
.50375 .9375 L
s
.5 1.0625 m
.50375 1.0625 L
s
.5 1.125 m
.50375 1.125 L
s
.5 1.1875 m
.50375 1.1875 L
s
.5 1.3125 m
.50375 1.3125 L
s
.5 1.375 m
.50375 1.375 L
s
.5 1.4375 m
.50375 1.4375 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.5 Mabswid
.75 1.125 m
.76962 1.06845 L
.78734 1.00328 L
.79473 .96941 L
.80145 .93262 L
.80662 .89774 L
.81043 .8653 L
.81216 .84696 L
.81372 .82673 L
.81492 .80639 L
.81542 .79527 L
.81579 .78485 L
.81593 .78017 L
.81605 .77506 L
.81622 .76577 L
.81631 .75674 L
.81633 .74836 L
.81631 .74325 L
.81627 .73844 L
.81614 .72946 L
.81604 .72444 L
.81592 .71982 L
.81559 .70943 L
.81485 .6927 L
.81393 .67719 L
.81102 .64231 L
.80712 .60895 L
.80179 .57401 L
.78844 .51017 L
.76945 .44575 L
.74756 .3906 L
.72426 .34517 L
.69848 .30581 L
.67227 .27456 L
.64168 .24699 L
.62379 .23466 L
.60704 .22542 L
.59127 .21862 L
.58252 .21561 L
.57422 .21325 L
.56646 .21146 L
.56236 .21068 L
.55801 .20998 L
.55435 .20949 L
.55032 .20905 L
.54665 .20874 L
.54322 .20853 L
.53885 .20837 L
.53638 .20834 L
.53409 .20835 L
Mistroke
.52989 .20845 L
.52542 .20868 L
.52103 .20904 L
.5169 .20948 L
.5092 .21062 L
.50009 .21246 L
.49175 .21462 L
.47308 .22115 L
.45747 .22842 L
.44104 .23795 L
.41227 .25953 L
.3799 .29215 L
.35255 .32791 L
.30657 .41154 L
.28536 .46561 L
.26914 .51893 L
.25672 .57284 L
.2481 .62479 L
.2445 .65492 L
.24207 .68262 L
.24113 .69717 L
.24036 .71306 L
.24008 .72107 L
.23995 .72547 L
.23985 .72961 L
.23977 .73348 L
.23971 .73766 L
.23964 .74496 L
.23963 .75213 L
.23966 .75867 L
.23977 .7662 L
.23992 .77333 L
.24011 .77988 L
.24033 .78593 L
.24097 .79959 L
.24183 .81321 L
.24301 .82815 L
.24616 .85799 L
.25018 .88635 L
.25555 .91612 L
.26789 .96743 L
.28234 1.01198 L
.30109 1.0562 L
.32359 1.09666 L
.34685 1.12861 L
.37283 1.15539 L
.3862 1.16614 L
.39882 1.17461 L
.41025 1.18097 L
.42302 1.18667 L
Mistroke
.436 1.19103 L
.44316 1.19282 L
.44988 1.19412 L
.45337 1.19465 L
.4571 1.19511 L
.46062 1.19544 L
.46381 1.19566 L
.46577 1.19575 L
.46757 1.19581 L
.46956 1.19584 L
.47165 1.19584 L
.47517 1.19576 L
.47717 1.19568 L
.47903 1.19557 L
.48263 1.19528 L
.48603 1.19491 L
.49239 1.19398 L
.49922 1.19262 L
.50662 1.19072 L
.51953 1.18636 L
.53307 1.18031 L
.55682 1.16586 L
.58082 1.14588 L
.60521 1.11924 L
.64441 1.05907 L
.66197 1.02226 L
.67852 .97864 L
.69261 .93011 L
.70265 .88296 L
.70651 .85902 L
.70982 .83285 L
.71103 .82079 L
.71211 .80801 L
.71287 .79695 L
.71351 .78509 L
.71376 .77919 L
.71395 .7736 L
.71409 .76858 L
.7142 .76312 L
.71428 .75797 L
.71431 .7525 L
.71431 .74734 L
.71428 .74268 L
.7142 .7367 L
.71408 .73122 L
.71391 .72522 L
.71367 .71891 L
.71316 .70832 L
.71242 .6968 L
.71025 .67253 L
Mistroke
.70747 .65001 L
.70039 .60929 L
.69541 .58744 L
.69017 .56797 L
.67624 .52669 L
.66162 .4937 L
.6462 .46623 L
.62761 .44024 L
.60595 .41745 L
.58424 .40109 L
.57155 .39412 L
.56539 .39139 L
.55956 .38916 L
.55398 .38736 L
.54791 .38577 L
.54238 .38463 L
.53727 .38386 L
.5344 .38353 L
.53172 .3833 L
.52878 .38313 L
.52713 .38307 L
.52563 .38303 L
.5226 .38303 L
.52089 .38307 L
.51931 .38313 L
.5164 .38331 L
.51494 .38343 L
.51332 .38359 L
.50791 .38429 L
.502 .38538 L
.49586 .38687 L
.49017 .38858 L
.48004 .39243 L
.46935 .39761 L
.44561 .41349 L
.42513 .43257 L
.40589 .45584 L
.38955 .48062 L
.3724 .51312 L
.35844 .54654 L
.34695 .58139 L
.33837 .6148 L
.33109 .65315 L
.32812 .67465 L
.32694 .68523 L
.32598 .69521 L
.32522 .70479 L
.32456 .71516 L
.32432 .71974 L
.32411 .72457 L
Mistroke
.32394 .72909 L
.32382 .73321 L
.32371 .73802 L
.32363 .74316 L
.3236 .74792 L
.3236 .75242 L
.32361 .75496 L
.32364 .75765 L
.32372 .76246 L
.32378 .76513 L
.32384 .76764 L
.32403 .77332 L
.32443 .78205 L
.32497 .79118 L
.32629 .80732 L
.32818 .82442 L
.3308 .84273 L
.33801 .87906 L
.34653 .90994 L
.35852 .94262 L
.37177 .97013 L
.38476 .99133 L
.39971 1.01054 L
.4133 1.02417 L
.42895 1.03611 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[234]:=",
  ImageSize->{102.25, 153.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001o0000_b000`400?l00000o`00003oOoooool0
07oooooo001oooooo`00Ooooool007oooooo001oooooo`00>?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<04;ooooo000hooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40@_ooool0033ooooo1_l00002oooo
o`05o`000?ooooooooooooooool000001?ooool2o`0003cooooo000hooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401?ooool00ol0003oooooooooo`0kooooo`00>?ooool01Ol0003oEEEEo`000?l@413o
c<c<00Cooooo00?o0000ooooooooool0>oooool003Sooooo00?oEEEEohN7Qoooool01_ooool00ol0
003oooooooooo`0kooooo`00>?ooool00ooMgMgo410@oiRHV006ooooo`03o`000?oooooooooo03_o
oooo000iooooo`04olc<c?m4A4Co0000oa0@40Cooooo00?o0000ooooooooool0>oooool0047ooooo
00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000
ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000oooooooo
ool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>ooo
ool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047o
oooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o
0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000oooo
ooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0
>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0
047ooooo00?o0000ooooooooool0>oooool003oooooo3?l0000dooooo`00?Oooool2o`0000;ooooo
00?o0000ooooooooool01oooool2o`0003;ooooo000jooooo`?o00001?ooool00ol0003ooooooooo
o`09ooooo`;o0000<?ooool003Wooooo0ol00005ooooo`03o`000?oooooooooo00_ooooo0_l0000^
ooooo`00<?ooool6o`0000;ooooo1Ol00004ooooo`;o00003_ooool2o`0002cooooo000gooooo`05
o`000?m4A4CogMgMooooool000001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02Wooooo000fooooo`06o`000?oooooogMgMoeEEEOoooooo00001Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02Sooooo000eooooo`07o`000?oooooooooooooooomgMgOoc<c<o`00
0005ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09oooool003Cooooo00?o0000
ooooooooool00_ooool00oo^k^koA4A4o`000005ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool09oooool003?ooooo00?o0000ooooooooool01?ooool00omgMgOo0000ooooo`04oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool003?ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Gooooo000booooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Tooooo`00<Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09?oo
ool0033ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo02?ooooo000`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Rooooo`00;oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool08Oooool002kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo027ooooo000^ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08?ooool002gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo023ooooo000/ooooo`03
o`000?oooooooooo013ooooo2_l0000Dooooo`03o`000?oooooooooo01oooooo000[ooooo`03o`00
0?oooooooooo00kooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo0ol0000Booooo`03o`00
0?oooooooooo01oooooo000[ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07ooo
ool002[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`00:_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool2o`00
00oooooo00?o0000ooooooooool07_ooool002Wooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Mooooo`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo
000Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool002Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Looooo`00:?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01cooooo000Xooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool06oooool002Oooooo00?o0000ooooooooool02_ooool01?l0003oooooooooooooool5o`0000Co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_o
oooo000Wooooo`03o`000?oooooooooo00[ooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^
oooooom4A4@01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06oooool002Oooooo00?o0000ooooooooool01_ooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h01Oooool2o`00013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Joooo
o`009_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^
k^h01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool06_ooool002Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03ogMg
MomVIVKooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01[ooooo000Vooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Jooooo`009_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Cooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`009_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`009Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo000Uooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Hooooo`009Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo
000Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool002Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`009Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Sooooo000Tooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06?ooool002Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`009?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo000Tooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05oooool002?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Gooooo`008oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oo
oooo000:ooooo`;o000000?o410@ooooooooool01oooool01OnHV9So410@o`000?lb<S;oc<c<00So
oooo00?o0000ooooool000001?l00003ooooo`03o`000?oooooooooo00Cooooo1?l000000ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo1?l000000ol@413oooooooooo`05ooooo`03
o`000?oooooo000000Co00001Oooool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o<S8bolc<
c00<ooooo`;o00000Ol@4101ooooo`7ooooo000;ooooo`03o`000?oooooooooo00Sooooo00Go410@
okZj^_ooooooMgMgoc8b<P08ooooo`07o`000?ooooooV9RHob4Q8Oo^k^koooooodA4A003ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo00Oo0000oooooonHV9So8B4Qonk^k_ooooooA4A400Gooooo00Wo0000
oooooooooooooooooa0@4?nj^[[oooooogMgMolb<S803Oooool00ol0003oooooooooo`01ooooo`00
1_l00002ooooo`Go000000?oooooo`000?l000001?l00006ooooo`03o`000?oooooooooo00Oo0000
0_ooool00onHV9So8B4Qonk^kP02ooooo`Ko00001Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool01_l0003ooooooooooonHV9So8B4Qonk^
kPKooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`Go00000_ooool000So
oooo00CoA4A4omgMgOoooooo00003Oooool00onYZJWo410@ooooo`07ooooo`07o`000?oooooooooo
oooooonHV9So8B4Qonk^kP03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00Oo0000oooooooooooooooo
oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool01?ooool00onYZJWo410@ooooo`09ooooo`04
odA4A?oMgMgoooooo`0000?ooooo0008ooooo`04omgMgOmEEEGoooooo`0000cooooo00?o410@o`00
0?nj^[X02?ooool00ol0003oooooooooo`02ooooo`03ogMgMomVIVKooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooo
ooooool00oooool00ol@413o0000okZj^P0:ooooo`04omgMgOmEEEGoooooo`0000?ooooo0009oooo
o`03ogMgMoo<c<co000000gooooo00?o^[Zjob4Q8Oooool01oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00onj^[[o8B4Qooooo`0:ooooo`03ogMgMoo<c<co
000000?ooooo0009ooooo`03onk^k_m4A4Co000000[ooooo00Go410@oiRHV?oooooo^[Zjo`000008
ooooo`07o`000?oooooo0000okZj^_ooooooV9RHoa0@4003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00Oo0000ooooool0003o^[ZjoooooonHV9So410@00Gooooo00Wo0000oooooooooooooooooa0@4?nH
V9SooooookZj^_l000002oooool00oo^k^koA4A4o`000003ooooo`002_ooool00omgMgOo0000oooo
o`09ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02?ooool01ol0003ooooooiRHV?l@413o0000ob4Q
8Oo<c<`00_ooool00ol0003oooooooooo`05ooooo`03oeEEEOmVIVKo000000[ooooo00?o0000oooo
ooooool02Oooool00omEEEGoIVIVo`000009ooooo`;o000000GoV9RHoa0@4?l0003o8B4Qolc<c005
ooooo`09o`000?oooooooooooooooonYZJWo410@o`000?l@413oZJVY00cooooo00?oMgMgo`000?oo
ool00_ooool002?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`008ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo0007ooooogGo00000oooool0
00Oooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00;o
00000_ooool01Ol0003oooooooooool0003ooooo00;o000000Goooooo`000?ooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?oooooo0000o`0000;ooooo00Oo0000oooooooooooo0000
ooooool0003ooooo00;o00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`01ooooo`008oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo000Sooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`;o00002_ooool00ol0
003oooooooooo`0Gooooo`008oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oo
oooo000Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool002?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`008oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Oooooo000Sooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05oooool002?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`00
8oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo000Sooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool05oooool002?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Gooooo`008oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Oooooo000Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool002Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Sooooo000Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool06?ooool002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Hoooo
o`009Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo000Uooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06?ooool002Gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Hooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Sooooo000Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool002Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`009_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Wooooo000Vooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool06Oooool002Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`Go00001?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06Oooool002Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool06_ooool002Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l0000Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06_ooool002Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo000Xooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00_ooool00omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`00:Oooool00ol0003ooooooooo
o`0;ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`00:Oooool00ol0003oooooooooo`0<
ooooo`;o000000?ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool06oooool002Wooooo00?o0000ooooooooool03?ooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01_ooooo000Zooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo000Zooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01cooooo000Zooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo000[ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01cooooo000[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01gooooo000/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01gooooo000]ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo
000^ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0`ooooo`00<?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool0037ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`05ooooo`;o0000=?ooool003;ooooo0_l0000=ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool003Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo000eooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0fooooo`00=_ooool2o`00
00Wooooo00?o0000ooooooooool00_l0000iooooo`00>?ooool4o`0000Cooooo1?l0000kooooo`00
>oooool5o`000003ooooool0003ooooo03cooooo0011ooooo`03o`000?oooooooooo03_ooooo0011
ooooo`03o`000?oooooooooo03_ooooo000jooooo`;o000000?o410@ooooooooool00_ooool00ol0
003oooooooooo`0kooooo`00>oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_o
oooo000hooooo`Go00001?ooool00ol0003oooooooooo`0kooooo`00>?ooool01?m4A4CogMgMoooo
ool00005ooooo`;o0000??ooool003Sooooo00CogMgMoeEEEOoooooo00001Oooool00ol0003ooooo
ooooo`0kooooo`00>Oooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo03_ooooo000i
ooooo`03onk^k_m4A4Co000000Gooooo00?o0000ooooooooool0>oooool003[ooooo00?oMgMgo`00
0?ooool01?ooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00
@Oooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00@Oooool0
0ol0003oooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003o
ooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003ooooooooo
o`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0koooo
o`00@Oooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00@Ooo
ool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0
003oooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003ooooo
ooooo`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0k
ooooo`00@Oooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00
>?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Cooooo00?o0000ooooooooool0>oooool003Sooooo
00GoEEEEogMgMoooooooV9RHob4Q8@04ooooo`03o`000?oooooooooo03_ooooo000hooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0kooooo`00>?ooool01Ol0003oV9RH
oooooonHV9So8B4Q00Cooooo0_l0000looooo`00>?ooool01Ol0003oEEEEo`000?l@413oc<c<04;o
oooo000hooooo`03oeEEEOn7QhOooooo04Cooooo000hooooo`03omgMgOl@413oV9RH04Cooooo000i
ooooo`04olc<c?m4A4Co0000oa0@44;ooooo001oooooo`00Ooooool007oooooo001oooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 179.125}, {539.75, 387.312}} -> {-11.2738, \
26.9786, 0.0867217, 0.0867217}}]
}, Open  ]],

Cell[TextData[{
  "The next picture adds the 25 points to the trajectory corresponding to \
position and velocity at time values   ",
  StyleBox["t",
    FontSlant->"Italic"],
  " =  0, 0.25, 0.5, ... , 6.0. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ traj, ListPlot[ Table[ {G[t],G'[t]}, {t,0,6,0.25}], \
PlotStyle->PointSize[0.03] ]]\
\>", "Input",
  CellLabel->"In[235]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.75 0.125 [
[0 .7375 -6 -9 ]
[0 .7375 6 0 ]
[.125 .7375 -6 -9 ]
[.125 .7375 6 0 ]
[.25 .7375 -6 -9 ]
[.25 .7375 6 0 ]
[.375 .7375 -6 -9 ]
[.375 .7375 6 0 ]
[.625 .7375 -3 -9 ]
[.625 .7375 3 0 ]
[.75 .7375 -3 -9 ]
[.75 .7375 3 0 ]
[.875 .7375 -3 -9 ]
[.875 .7375 3 0 ]
[1 .7375 -3 -9 ]
[1 .7375 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -12 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -6 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .75 m
0 .75625 L
s
[(-4)] 0 .7375 0 1 Mshowa
.125 .75 m
.125 .75625 L
s
[(-3)] .125 .7375 0 1 Mshowa
.25 .75 m
.25 .75625 L
s
[(-2)] .25 .7375 0 1 Mshowa
.375 .75 m
.375 .75625 L
s
[(-1)] .375 .7375 0 1 Mshowa
.625 .75 m
.625 .75625 L
s
[(1)] .625 .7375 0 1 Mshowa
.75 .75 m
.75 .75625 L
s
[(2)] .75 .7375 0 1 Mshowa
.875 .75 m
.875 .75625 L
s
[(3)] .875 .7375 0 1 Mshowa
1 .75 m
1 .75625 L
s
[(4)] 1 .7375 0 1 Mshowa
.125 Mabswid
.025 .75 m
.025 .75375 L
s
.05 .75 m
.05 .75375 L
s
.075 .75 m
.075 .75375 L
s
.1 .75 m
.1 .75375 L
s
.15 .75 m
.15 .75375 L
s
.175 .75 m
.175 .75375 L
s
.2 .75 m
.2 .75375 L
s
.225 .75 m
.225 .75375 L
s
.275 .75 m
.275 .75375 L
s
.3 .75 m
.3 .75375 L
s
.325 .75 m
.325 .75375 L
s
.35 .75 m
.35 .75375 L
s
.4 .75 m
.4 .75375 L
s
.425 .75 m
.425 .75375 L
s
.45 .75 m
.45 .75375 L
s
.475 .75 m
.475 .75375 L
s
.525 .75 m
.525 .75375 L
s
.55 .75 m
.55 .75375 L
s
.575 .75 m
.575 .75375 L
s
.6 .75 m
.6 .75375 L
s
.65 .75 m
.65 .75375 L
s
.675 .75 m
.675 .75375 L
s
.7 .75 m
.7 .75375 L
s
.725 .75 m
.725 .75375 L
s
.775 .75 m
.775 .75375 L
s
.8 .75 m
.8 .75375 L
s
.825 .75 m
.825 .75375 L
s
.85 .75 m
.85 .75375 L
s
.9 .75 m
.9 .75375 L
s
.925 .75 m
.925 .75375 L
s
.95 .75 m
.95 .75375 L
s
.975 .75 m
.975 .75375 L
s
.25 Mabswid
0 .75 m
1 .75 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-4)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(-2)] .4875 .5 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(4)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(6)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .0625 m
.50375 .0625 L
s
.5 .125 m
.50375 .125 L
s
.5 .1875 m
.50375 .1875 L
s
.5 .3125 m
.50375 .3125 L
s
.5 .375 m
.50375 .375 L
s
.5 .4375 m
.50375 .4375 L
s
.5 .5625 m
.50375 .5625 L
s
.5 .625 m
.50375 .625 L
s
.5 .6875 m
.50375 .6875 L
s
.5 .8125 m
.50375 .8125 L
s
.5 .875 m
.50375 .875 L
s
.5 .9375 m
.50375 .9375 L
s
.5 1.0625 m
.50375 1.0625 L
s
.5 1.125 m
.50375 1.125 L
s
.5 1.1875 m
.50375 1.1875 L
s
.5 1.3125 m
.50375 1.3125 L
s
.5 1.375 m
.50375 1.375 L
s
.5 1.4375 m
.50375 1.4375 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.5 Mabswid
.75 1.125 m
.76962 1.06845 L
.78734 1.00328 L
.79473 .96941 L
.80145 .93262 L
.80662 .89774 L
.81043 .8653 L
.81216 .84696 L
.81372 .82673 L
.81492 .80639 L
.81542 .79527 L
.81579 .78485 L
.81593 .78017 L
.81605 .77506 L
.81622 .76577 L
.81631 .75674 L
.81633 .74836 L
.81631 .74325 L
.81627 .73844 L
.81614 .72946 L
.81604 .72444 L
.81592 .71982 L
.81559 .70943 L
.81485 .6927 L
.81393 .67719 L
.81102 .64231 L
.80712 .60895 L
.80179 .57401 L
.78844 .51017 L
.76945 .44575 L
.74756 .3906 L
.72426 .34517 L
.69848 .30581 L
.67227 .27456 L
.64168 .24699 L
.62379 .23466 L
.60704 .22542 L
.59127 .21862 L
.58252 .21561 L
.57422 .21325 L
.56646 .21146 L
.56236 .21068 L
.55801 .20998 L
.55435 .20949 L
.55032 .20905 L
.54665 .20874 L
.54322 .20853 L
.53885 .20837 L
.53638 .20834 L
.53409 .20835 L
Mistroke
.52989 .20845 L
.52542 .20868 L
.52103 .20904 L
.5169 .20948 L
.5092 .21062 L
.50009 .21246 L
.49175 .21462 L
.47308 .22115 L
.45747 .22842 L
.44104 .23795 L
.41227 .25953 L
.3799 .29215 L
.35255 .32791 L
.30657 .41154 L
.28536 .46561 L
.26914 .51893 L
.25672 .57284 L
.2481 .62479 L
.2445 .65492 L
.24207 .68262 L
.24113 .69717 L
.24036 .71306 L
.24008 .72107 L
.23995 .72547 L
.23985 .72961 L
.23977 .73348 L
.23971 .73766 L
.23964 .74496 L
.23963 .75213 L
.23966 .75867 L
.23977 .7662 L
.23992 .77333 L
.24011 .77988 L
.24033 .78593 L
.24097 .79959 L
.24183 .81321 L
.24301 .82815 L
.24616 .85799 L
.25018 .88635 L
.25555 .91612 L
.26789 .96743 L
.28234 1.01198 L
.30109 1.0562 L
.32359 1.09666 L
.34685 1.12861 L
.37283 1.15539 L
.3862 1.16614 L
.39882 1.17461 L
.41025 1.18097 L
.42302 1.18667 L
Mistroke
.436 1.19103 L
.44316 1.19282 L
.44988 1.19412 L
.45337 1.19465 L
.4571 1.19511 L
.46062 1.19544 L
.46381 1.19566 L
.46577 1.19575 L
.46757 1.19581 L
.46956 1.19584 L
.47165 1.19584 L
.47517 1.19576 L
.47717 1.19568 L
.47903 1.19557 L
.48263 1.19528 L
.48603 1.19491 L
.49239 1.19398 L
.49922 1.19262 L
.50662 1.19072 L
.51953 1.18636 L
.53307 1.18031 L
.55682 1.16586 L
.58082 1.14588 L
.60521 1.11924 L
.64441 1.05907 L
.66197 1.02226 L
.67852 .97864 L
.69261 .93011 L
.70265 .88296 L
.70651 .85902 L
.70982 .83285 L
.71103 .82079 L
.71211 .80801 L
.71287 .79695 L
.71351 .78509 L
.71376 .77919 L
.71395 .7736 L
.71409 .76858 L
.7142 .76312 L
.71428 .75797 L
.71431 .7525 L
.71431 .74734 L
.71428 .74268 L
.7142 .7367 L
.71408 .73122 L
.71391 .72522 L
.71367 .71891 L
.71316 .70832 L
.71242 .6968 L
.71025 .67253 L
Mistroke
.70747 .65001 L
.70039 .60929 L
.69541 .58744 L
.69017 .56797 L
.67624 .52669 L
.66162 .4937 L
.6462 .46623 L
.62761 .44024 L
.60595 .41745 L
.58424 .40109 L
.57155 .39412 L
.56539 .39139 L
.55956 .38916 L
.55398 .38736 L
.54791 .38577 L
.54238 .38463 L
.53727 .38386 L
.5344 .38353 L
.53172 .3833 L
.52878 .38313 L
.52713 .38307 L
.52563 .38303 L
.5226 .38303 L
.52089 .38307 L
.51931 .38313 L
.5164 .38331 L
.51494 .38343 L
.51332 .38359 L
.50791 .38429 L
.502 .38538 L
.49586 .38687 L
.49017 .38858 L
.48004 .39243 L
.46935 .39761 L
.44561 .41349 L
.42513 .43257 L
.40589 .45584 L
.38955 .48062 L
.3724 .51312 L
.35844 .54654 L
.34695 .58139 L
.33837 .6148 L
.33109 .65315 L
.32812 .67465 L
.32694 .68523 L
.32598 .69521 L
.32522 .70479 L
.32456 .71516 L
.32432 .71974 L
.32411 .72457 L
Mistroke
.32394 .72909 L
.32382 .73321 L
.32371 .73802 L
.32363 .74316 L
.3236 .74792 L
.3236 .75242 L
.32361 .75496 L
.32364 .75765 L
.32372 .76246 L
.32378 .76513 L
.32384 .76764 L
.32403 .77332 L
.32443 .78205 L
.32497 .79118 L
.32629 .80732 L
.32818 .82442 L
.3308 .84273 L
.33801 .87906 L
.34653 .90994 L
.35852 .94262 L
.37177 .97013 L
.38476 .99133 L
.39971 1.01054 L
.4133 1.02417 L
.42895 1.03611 L
Mfstroke
.03 w
.75 1.125 Mdot
.81116 .85788 Mdot
.80331 .58312 Mdot
.73199 .35904 Mdot
.61581 .23 Mdot
.4818 .21781 Mdot
.35919 .31845 Mdot
.27317 .50433 Mdot
.23981 .73148 Mdot
.26316 .94971 Mdot
.33509 1.11352 Mdot
.43771 1.19149 Mdot
.54765 1.17203 Mdot
.64135 1.06474 Mdot
.69997 .89719 Mdot
.71315 .7081 Mdot
.68066 .53851 Mdot
.61195 .42306 Mdot
.52353 .38302 Mdot
.43514 .42257 Mdot
.36542 .52888 Mdot
.32798 .67577 Mdot
.32891 .83001 Mdot
.36584 .95868 Mdot
.42895 1.03611 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[235]:=",
  ImageSize->{102.25, 153.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001o0000_b000`400?l00000o`00003oOoooool0
07oooooo001oooooo`00Ooooool007oooooo001oooooo`00>?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<04;ooooo000hooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40@_ooool0033ooooo1_l00002oooo
o`05o`000?ooooooooooooooool00000@_ooool003Sooooo00Go0000oiRHV?ooooooV9RHob4Q8@04
ooooo`;o0000??ooool003Sooooo00Go0000oeEEEOl0003o410@olc<c004ooooo`03o`000?oooooo
oooo03_ooooo000hooooo`03oeEEEOn7QhOooooo00Kooooo00?o0000ooooooooool0>oooool003So
oooo00?ogMgMoa0@4?nHV9P01_ooool00ol0003oooooooooo`0kooooo`00>Oooool01?o<c<coA4A4
o`000?l@4104ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03o`000?oooooooooo03_ooooo
0011ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03o`000?oooooooooo03_ooooo0011oooo
o`03o`000?oooooooooo03_ooooo0011ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03o`00
0?oooooooooo03_ooooo0011ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03o`000?oooooo
oooo03_ooooo0011ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03o`000?oooooooooo03_o
oooo0011ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03o`000?oooooooooo03_ooooo0011
ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03
o`000?oooooooooo03_ooooo0011ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03o`000?oo
oooooooo03_ooooo0011ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03o`000?oooooooooo
03_ooooo000mooooo`ko0000=?ooool003gooooo0ol000000ooooooo0000ooooo`08ooooo`Go0000
;oooool003[ooooo1_l000000ooooooo0000ooooo`0:ooooo`?o0000;oooool003[ooooo0_l00005
ooooo`03o`000?oooooooooo00Wooooo1?l0000^ooooo`00<?ooool6o`0000;ooooo1Ol00004oooo
o`;o00003_ooool2o`0002cooooo000hooooo`04o`000?oMgMgoooooo`0000Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Yooooo`00=_ooool2o`000004omgMgOmEEEGoooooo`00
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`00=Oooool01ol0003o
ooooooooooooooooMgMgolc<c?l000001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo02Oooooo000dooooo`03o`000?oooooooooo00;ooooo00?ok^k^odA4A?l000001Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo02Oooooo000cooooo`03o`000?oooooooooo00Co
oooo00?oMgMgo`000?ooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Ko
oooo000cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Uooooo`00<_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool09?ooool002oooooo0ol0000?ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool09?ooool002oooooo0ol0000?ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool08oooool002oooooo0ol0000?ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool08_ooool002oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo027ooooo000^ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_oo
ool3o`0002;ooooo000^ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool3
o`0002;ooooo000]ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool3o`00
02;ooooo000]ooooo`03o`000?oooooooooo017ooooo1?l0000Gooooo`03o`000?oooooooooo023o
oooo000/ooooo`03o`000?oooooooooo013ooooo2_l0000Dooooo`03o`000?oooooooooo01oooooo
000[ooooo`03o`000?oooooooooo00kooooo0ol00002ooooo`Co00000oooool3o`0001;ooooo00?o
0000ooooooooool07oooool002_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0O
ooooo`00:_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo000Zooooo`03
o`000?oooooooooo00_ooooo0ol00006ooooo`03o`000?oooooooooo00Wooooo0ol0000>ooooo`03
o`000?oooooooooo01kooooo000Yooooo`03o`000?oooooooooo00cooooo0ol00006ooooo`03o`00
0?oooooooooo00Wooooo0ol0000?ooooo`03o`000?oooooooooo01gooooo000Yooooo`03o`000?oo
oooooooo00cooooo0ol00006ooooo`03o`000?oooooooooo00Wooooo1?l0000>ooooo`03o`000?oo
oooooooo01gooooo000Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool0
02Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`00:?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01cooooo000Xooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool06oooool002Oooooo00?o0000ooooooooool02_ooool01?l0003ooooooooo
ooooool5o`0000Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01_ooooo000Wooooo`03o`000?oooooooooo00[ooooo00Wo0000oooooooooooooooo
oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool06oooool002Gooooo0ol00008ooooo`Ko00000oooool00onHV9So
8B4Qonk^kP05ooooo`;o00004?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[o
oooo000Uooooo`?o00002oooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo
000Uooooo`?o00002_ooool00ol0003oooooooooo`06ooooo`03ogMgMomVIVKooooo00?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo000V
ooooo`03o`000?oooooooooo00Oooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo000Voooo
o`03o`000?oooooooooo00Oooooo0ol00005ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`0@ooooo`?o00003?ooool00ol0003oooooooooo`0Iooooo`009_ooool00ol0
003oooooooooo`07ooooo`?o00001Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000
ooooooooool04?ooool3o`0000cooooo00?o0000ooooooooool06Oooool002Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo0ol0000<oooo
o`03o`000?oooooooooo01Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06Oooool002Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`009Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`09ooooo`?o00006Oooool002Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool3
o`0001Wooooo000Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo0ol0000Iooooo`009Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Sooooo000Tooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06?ooool002Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Hooooo`009?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo000Toooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool002?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Gooooo`008oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Oooooo000:ooooo`;o000000?o410@ooooooooool01oooool01OnHV9So410@o`00
0?lb<S;oc<c<00Sooooo00?o0000ooooool000001?l00003ooooo`03o`000?oooooooooo00Cooooo
1?l000000ol@413oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo1?l000000ol@413ooooo
ooooo`05ooooo`03o`000?oooooo000000Co00001Oooool02Ol0003oooooooooooooooooV9RHoa0@
4?l0003o<S8bolc<c00<ooooo`;o00000Ol@4101ooooo`7ooooo000;ooooo`03o`000?oooooooooo
00Sooooo00Go410@okZj^_ooooooMgMgoc8b<P08ooooo`07o`000?ooooooV9RHob4Q8Oo^k^kooooo
odA4A002ooooo`?o00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@01Oooool02Ol0
003ooooooooooooooooo410@okZj^_ooooooMgMgoc8b<P0=ooooo`03o`000?oooooooooo007ooooo
0006o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000Kooooo00?o0000ooooooooool01ol0
0002ooooo`03oiRHV?lQ8B7ok^k^00;ooooo1_l00005ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`06o`000?oooooooooooiRHV?lQ8B7o
k^k^1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo1Ol00002ooooo`00
2?ooool01?m4A4CogMgMooooool0000=ooooo`03ojVYZOl@413ooooo00Oooooo00Oo0000oooooooo
oooooooooiRHV?lQ8B7ok^k^00;ooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`07ooooo`07o`000?oooooooooooooooonHV9So8B4Q
onk^kP05ooooo`03o`000?oooooooooo00Cooooo00?oZJVYoa0@4?ooool02Oooool01?m4A4CogMgM
ooooool00003ooooo`002?ooool01?oMgMgoEEEEooooool0000<ooooo`03oa0@4?l0003o^[Zj00So
oooo00?o0000ooooooooool00_ooool00omgMgOoIVIVooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o410@o`000?nj^[X02_ooool01?oMgMgoEEEEooooool00003ooooo`002Oooool00omgMgOo
c<c<o`00000=ooooo`03okZj^_lQ8B7ooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00onj^[[o8B4Qooooo`0:ooooo`03ogMgMoo<c<co000000?ooooo0009ooooo`03
onk^k_m4A4Co000000[ooooo00Go410@oiRHV?oooooo^[Zjo`000008ooooo`07o`000?oooooo0000
okZj^_ooooooV9RHoa0@4003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo1?l000001?nj^[[ooooooiRH
V?l@4105ooooo`09o`000?ooooooooooooooool@413oV9RHoooooonj^[[o000000_ooooo00?ok^k^
odA4A?l000000oooool000[ooooo00?oMgMgo`000?ooool02Oooool01OnYZJWo410@o`000?l@413o
ZJVY00Oooooo0ol000001OnHV9So410@o`000?lQ8B7oc<c<00;ooooo00?o0000ooooooooool01Ooo
ool00omEEEGoIVIVo`00000:ooooo`03o`000?oooooooooo00Wooooo00?oEEEEofIVI_l000002?oo
ool3o`000005oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool02Ol0003oooooooooooooooooZJVYoa0@
4?l0003o410@ojVYZ@0<ooooo`03ogMgMol0003ooooo00;ooooo000Rooooo`?o00001oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Gooooo`008_ooool3o`0000Oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool000Oooooo
MOl00003ooooo`001oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooo
o`000?ooool00_l00002ooooo`05o`000?ooooooooooo`000?ooool00_l000001Ooooooo0000oooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00000_ooool01ol0003o
ooooooooool0003oooooo`000?ooool00_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007o
oooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool002?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`008oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Oooooo000Sooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05oooool002?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`00
8oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo000Sooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool05oooool002?ooooo00?o0000ooooooooool01_ooool3
o`0001;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Oooooo000Sooooo`03o`000?oooooooooo00Kooooo0ol0000Booooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`008oooool00ol0003o
ooooooooo`06ooooo`?o00004_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05oooool002?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool3o`0001Sooooo
000Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Sooooo0ol0000Hooooo`008oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08
ooooo`?o00006?ooool002Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Goooo
o`009?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04oooool3o`0000[ooooo00?o0000ooooooooool06?ooool002Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo0ol0000:ooooo`03o`00
0?oooooooooo01Sooooo000Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Cooooo`?o00002_ooool00ol0003oooooooooo`0Hooooo`009Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo000Uooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06?ooool002Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Hooooo`009?ooool3o`0000Wooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool002Cooooo0ol0
0009ooooo`?o00003_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool06?ooool002Cooooo0ol00009ooooo`?o00003_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool002Kooooo00?o0000oooo
ooooool01oooool3o`0000kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Wooooo000Vooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06Oooool002Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`Go0000
1?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
6Oooool002Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06_ooool002Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l0000Booooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06_ooool002Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01[ooooo000Xooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00_ooool00omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Jooooo`00:Oooool00ol0003oooooooooo`0;ooooo`?o
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Kooooo`00:Oooool00ol0003oooooooooo`0;ooooo`?o0000
00?ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06oooool002Wooooo00?o0000ooooooooool02oooool4o`000003ob4Q8Oo<
c<cooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01_ooooo000Zooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo000Zooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03?ooool3o`0000gooooo00?o0000ooooooooool07?ooool002[o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`?o00003Oooool00ol0003o
ooooooooo`0Looooo`00:oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo
0ol0000=ooooo`03o`000?oooooooooo01cooooo000[ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo000/
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01gooooo000/ooooo`Co00004Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool002gooooo0ol0000Aooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`00
;Oooool3o`00017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`?o0000
8?ooool002oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00gooooo0ol0000Pooooo`00<?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03_ooool3o`00023ooooo000aooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01Oooool2o`0003Cooooo000booooo`;o00003Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Cooooo000dooooo`03o`000?oooooooooo00[ooooo
00Co0000oooooooooooooooo0ol0000gooooo`00=Oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooooooo`?o0000=oooool003Kooooo1Ol00006ooooo`03o`000?oooooooooo00Co0000
=oooool003Sooooo0ol00005ooooo`Co0000>oooool003Sooooo2?l000000ooooooo0000ooooo`0l
ooooo`00@Oooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`0kooooo`00
>_ooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0>oooool003_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0kooooo`00>?ooool5o`0000Cooooo00?o0000
ooooooooool0>oooool003Sooooo00CoA4A4omgMgOoooooo00001Oooool2o`0003cooooo000hoooo
o`04omgMgOmEEEGoooooo`0000Gooooo00?o0000ooooooooool0>oooool003Wooooo00?oMgMgolc<
c?l000001Oooool00ol0003oooooooooo`0kooooo`00>Oooool00oo^k^koA4A4o`000005ooooo`03
o`000?oooooooooo03_ooooo000jooooo`03ogMgMol0003ooooo00Cooooo00?o0000ooooooooool0
>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0
047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo
00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000
ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000oooooooo
ool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>ooo
ool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047o
oooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o
0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000oooo
ooooool0>oooool0047ooooo00?o0000ooooooooool0>oooool0047ooooo00?o0000ooooooooool0
>oooool0047ooooo00?o0000ooooooooool0>oooool003Sooooo00Gok^k^oc8b<_l0003o410@olc<
c004ooooo`03o`000?oooooooooo03_ooooo000hooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401?oo
ool00ol0003oooooooooo`0kooooo`00>?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0>oooool003Sooooo00Go0000oiRHV?ooooooV9RHob4Q8@04ooooo`;o0000??oo
ool003Sooooo00Go0000oeEEEOl0003o410@olc<c012ooooo`00>?ooool00omEEEGoQhN7ooooo`14
ooooo`00>?ooool00ooMgMgo410@oiRHV014ooooo`00>Oooool01?o<c<coA4A4o`000?l@4112oooo
o`00Ooooool007oooooo001oooooo`00Ooooool00001\
\>"],
  ImageRangeCache->{{{77.875, 179.125}, {250.188, 97.875}} -> {-11.2738, \
1.88349, 0.0867217, 0.0867217}}]
}, Open  ]],

Cell["\<\
And here are the corresponding pairs of points on the time series \
graphs. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
pos = ListPlot[ Table[ {t,G[t]}, {t,0,6,0.25}], 
                PlotStyle->PointSize[0.01], DisplayFunction\[Rule]Identity ];
vel = ListPlot[ Table[ {t,G'[t]}, {t,0,6,0.25}], 
                PlotStyle->PointSize[0.01], DisplayFunction\[Rule]Identity ];
Show[ pos, vel,
      Plot[ {G[t],G'[t]}, {t,0,6}, 
            PlotStyle->{RGBColor[1,0,1],RGBColor[0,0,1]}, 
            DisplayFunction\[Rule]Identity ] , 
      AspectRatio\[Rule]1/3, DisplayFunction\[Rule]$DisplayFunction ]\
\>", \
"Input",
  CellLabel->"In[12]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.182068 0.0401848 [
[.18254 .16957 -3 -9 ]
[.18254 .16957 3 0 ]
[.34127 .16957 -3 -9 ]
[.34127 .16957 3 0 ]
[.5 .16957 -3 -9 ]
[.5 .16957 3 0 ]
[.65873 .16957 -3 -9 ]
[.65873 .16957 3 0 ]
[.81746 .16957 -3 -9 ]
[.81746 .16957 3 0 ]
[.97619 .16957 -3 -9 ]
[.97619 .16957 3 0 ]
[.01131 .02133 -12 -4.5 ]
[.01131 .02133 0 4.5 ]
[.01131 .1017 -12 -4.5 ]
[.01131 .1017 0 4.5 ]
[.01131 .26244 -6 -4.5 ]
[.01131 .26244 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .18207 m
.18254 .18832 L
s
[(1)] .18254 .16957 0 1 Mshowa
.34127 .18207 m
.34127 .18832 L
s
[(2)] .34127 .16957 0 1 Mshowa
.5 .18207 m
.5 .18832 L
s
[(3)] .5 .16957 0 1 Mshowa
.65873 .18207 m
.65873 .18832 L
s
[(4)] .65873 .16957 0 1 Mshowa
.81746 .18207 m
.81746 .18832 L
s
[(5)] .81746 .16957 0 1 Mshowa
.97619 .18207 m
.97619 .18832 L
s
[(6)] .97619 .16957 0 1 Mshowa
.125 Mabswid
.05556 .18207 m
.05556 .18582 L
s
.0873 .18207 m
.0873 .18582 L
s
.11905 .18207 m
.11905 .18582 L
s
.15079 .18207 m
.15079 .18582 L
s
.21429 .18207 m
.21429 .18582 L
s
.24603 .18207 m
.24603 .18582 L
s
.27778 .18207 m
.27778 .18582 L
s
.30952 .18207 m
.30952 .18582 L
s
.37302 .18207 m
.37302 .18582 L
s
.40476 .18207 m
.40476 .18582 L
s
.43651 .18207 m
.43651 .18582 L
s
.46825 .18207 m
.46825 .18582 L
s
.53175 .18207 m
.53175 .18582 L
s
.56349 .18207 m
.56349 .18582 L
s
.59524 .18207 m
.59524 .18582 L
s
.62698 .18207 m
.62698 .18582 L
s
.69048 .18207 m
.69048 .18582 L
s
.72222 .18207 m
.72222 .18582 L
s
.75397 .18207 m
.75397 .18582 L
s
.78571 .18207 m
.78571 .18582 L
s
.84921 .18207 m
.84921 .18582 L
s
.88095 .18207 m
.88095 .18582 L
s
.9127 .18207 m
.9127 .18582 L
s
.94444 .18207 m
.94444 .18582 L
s
.25 Mabswid
0 .18207 m
1 .18207 L
s
.02381 .02133 m
.03006 .02133 L
s
[(-4)] .01131 .02133 1 0 Mshowa
.02381 .1017 m
.03006 .1017 L
s
[(-2)] .01131 .1017 1 0 Mshowa
.02381 .26244 m
.03006 .26244 L
s
[(2)] .01131 .26244 1 0 Mshowa
.125 Mabswid
.02381 .04142 m
.02756 .04142 L
s
.02381 .06151 m
.02756 .06151 L
s
.02381 .08161 m
.02756 .08161 L
s
.02381 .12179 m
.02756 .12179 L
s
.02381 .14188 m
.02756 .14188 L
s
.02381 .16198 m
.02756 .16198 L
s
.02381 .20216 m
.02756 .20216 L
s
.02381 .22225 m
.02756 .22225 L
s
.02381 .24235 m
.02756 .24235 L
s
.02381 .00124 m
.02756 .00124 L
s
.02381 .28253 m
.02756 .28253 L
s
.02381 .30262 m
.02756 .30262 L
s
.02381 .32271 m
.02756 .32271 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.01 w
.02381 .26244 Mdot
.06349 .2821 Mdot
.10317 .27958 Mdot
.14286 .25665 Mdot
.18254 .2193 Mdot
.22222 .17622 Mdot
.2619 .1368 Mdot
.30159 .10915 Mdot
.34127 .09842 Mdot
.38095 .10593 Mdot
.42063 .12905 Mdot
.46032 .16204 Mdot
.5 .19739 Mdot
.53968 .22751 Mdot
.57937 .24635 Mdot
.61905 .25059 Mdot
.65873 .24015 Mdot
.69841 .21806 Mdot
.7381 .18963 Mdot
.77778 .16122 Mdot
.81746 .1388 Mdot
.85714 .12677 Mdot
.89683 .12707 Mdot
.93651 .13894 Mdot
.97619 .15923 Mdot
.02381 .30262 Mdot
.06349 .21675 Mdot
.10317 .12842 Mdot
.14286 .05638 Mdot
.18254 .0149 Mdot
.22222 .01098 Mdot
.2619 .04333 Mdot
.30159 .10309 Mdot
.34127 .17612 Mdot
.38095 .24627 Mdot
.42063 .29893 Mdot
.46032 .324 Mdot
.5 .31774 Mdot
.53968 .28325 Mdot
.57937 .22939 Mdot
.61905 .1686 Mdot
.65873 .11408 Mdot
.69841 .07696 Mdot
.7381 .06409 Mdot
.77778 .07681 Mdot
.81746 .11098 Mdot
.85714 .15821 Mdot
.89683 .20779 Mdot
.93651 .24915 Mdot
.97619 .27405 Mdot
1 0 1 r
.5 Mabswid
.02381 .26244 m
.03279 .26875 L
.04262 .27444 L
.04758 .27682 L
.05288 .27898 L
.05785 .28064 L
.06244 .28186 L
.06503 .28242 L
.06788 .28292 L
.07075 .28331 L
.07232 .28347 L
.07379 .28359 L
.07445 .28363 L
.07517 .28367 L
.07648 .28373 L
.07776 .28376 L
.07895 .28376 L
.07968 .28376 L
.08036 .28374 L
.08164 .2837 L
.08236 .28367 L
.08302 .28363 L
.08451 .28352 L
.08691 .28329 L
.08916 .28299 L
.09427 .28206 L
.09924 .2808 L
.10458 .27909 L
.11475 .2748 L
.12582 .26869 L
.14594 .25416 L
.18672 .21486 L
.22599 .17217 L
.26374 .13521 L
.28309 .12016 L
.29305 .11379 L
.30394 .10801 L
.31432 .10372 L
.32398 .10084 L
.32933 .09971 L
.33186 .0993 L
.33418 .09898 L
.33687 .0987 L
.33829 .09859 L
.33979 .09849 L
.34109 .09843 L
.34231 .09839 L
.34301 .09837 L
.34365 .09837 L
.34438 .09836 L
Mistroke
.34508 .09836 L
.34633 .09838 L
.34704 .0984 L
.34768 .09842 L
.34887 .09848 L
.35013 .09855 L
.35231 .09872 L
.35469 .09897 L
.35999 .09976 L
.36493 .10079 L
.37381 .1033 L
.38333 .10692 L
.40461 .11814 L
.42474 .13213 L
.46312 .16456 L
.50396 .20074 L
.52425 .21685 L
.54328 .22975 L
.56148 .23954 L
.57171 .2438 L
.58108 .24685 L
.58583 .24808 L
.59091 .24916 L
.5957 .24995 L
.60004 .25047 L
.60271 .25069 L
.60397 .25078 L
.60516 .25084 L
.60644 .2509 L
.60712 .25092 L
.60785 .25094 L
.60862 .25095 L
.60934 .25096 L
.60999 .25097 L
.6107 .25097 L
.6119 .25095 L
.61259 .25094 L
.61323 .25092 L
.61453 .25088 L
.61592 .25081 L
.61844 .25064 L
.62076 .25043 L
.62549 .24985 L
.63054 .24899 L
.63966 .24687 L
.65049 .24341 L
.66035 .23945 L
.7003 .2168 L
.73873 .18916 L
.77962 .16 L
Mistroke
.79995 .14762 L
.81899 .13813 L
.83723 .13132 L
.84747 .12859 L
.85684 .12681 L
.86161 .12618 L
.86423 .1259 L
.8667 .1257 L
.869 .12555 L
.8703 .12548 L
.8715 .12544 L
.8725 .1254 L
.87361 .12538 L
.87477 .12536 L
.87584 .12536 L
.87713 .12536 L
.87786 .12537 L
.87853 .12538 L
.87977 .12542 L
.88108 .12546 L
.88335 .12557 L
.88585 .12575 L
.88851 .12598 L
.89138 .1263 L
.89657 .12703 L
.90615 .1289 L
.91663 .13169 L
.93773 .13946 L
.97619 .15923 L
Mfstroke
0 0 1 r
.02381 .30262 m
.06244 .21914 L
.10458 .12549 L
.12507 .08561 L
.14415 .05449 L
.16254 .03136 L
.17284 .0217 L
.18221 .01509 L
.18704 .01251 L
.19216 .01041 L
.19654 .00912 L
.19902 .00859 L
.20135 .00824 L
.20264 .0081 L
.20336 .00805 L
.20404 .008 L
.20527 .00795 L
.20658 .00794 L
.20788 .00796 L
.20909 .00803 L
.21019 .00811 L
.21137 .00824 L
.21267 .00842 L
.21409 .00866 L
.21698 .00931 L
.21965 .01008 L
.22214 .01095 L
.22714 .01314 L
.23259 .01617 L
.24249 .02337 L
.26105 .0423 L
.28082 .06918 L
.30183 .10351 L
.33958 .17295 L
.37978 .24439 L
.39826 .27211 L
.41847 .29671 L
.42816 .30601 L
.43851 .31402 L
.44424 .31756 L
.44944 .32021 L
.45467 .32233 L
.45722 .32316 L
.45961 .32382 L
.46203 .32438 L
.46424 .32478 L
.46669 .3251 L
.46805 .32523 L
.46933 .32532 L
.47057 .32537 L
Mistroke
.47189 .3254 L
.47313 .32539 L
.47426 .32535 L
.47495 .32532 L
.47558 .32527 L
.47702 .32515 L
.47829 .32501 L
.47962 .32483 L
.48182 .32445 L
.48418 .32394 L
.48843 .32274 L
.49348 .32087 L
.49808 .31875 L
.50802 .31284 L
.5172 .30585 L
.53797 .28522 L
.57729 .23249 L
.61509 .17458 L
.65535 .11818 L
.67386 .09739 L
.68435 .08759 L
.69409 .07991 L
.70462 .07325 L
.71417 .06875 L
.71943 .06691 L
.72438 .0656 L
.72711 .06505 L
.72962 .06465 L
.73104 .06447 L
.73237 .06434 L
.73376 .06423 L
.73449 .06418 L
.73528 .06415 L
.7365 .06411 L
.73719 .0641 L
.73784 .06409 L
.73915 .06411 L
.73988 .06413 L
.74056 .06415 L
.74169 .06422 L
.74293 .06431 L
.74544 .06457 L
.74821 .06498 L
.75116 .06555 L
.7565 .06694 L
.76191 .0688 L
.76703 .07098 L
.77661 .07609 L
.7966 .09078 L
.81504 .10843 L
Mistroke
.85442 .15476 L
.89227 .20233 L
.91332 .22653 L
.93258 .24568 L
.95247 .26149 L
.97137 .27209 L
.97619 .27405 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{250, 83.3125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004h0000J2000`400?l00000o`00003oooooooli
ooooo`00ooooooliooooo`004_ooool2o`000?oooooo9Oooool001;ooooo00?o0000ooooooooool0
oooooolTooooo`004_ooool00ol0003oooooooooo`0booooo`Go003o00Coooooo`000?l0003o0000
j?ooool001;ooooo00?o0000ooooooooool0;?ooool3o`0000Co003o0oooool4o`00o`03o`000?oo
oooooooo0>Kooooo000:ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`0/
ooooo`?o003o2Oooool2o`0000;o003oioooool000_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0[ooooo`04o`00ool0003o0000o`0000gooooo0_l00?oUooooo`001_l00002oooo
o`Go00001Oooool3o`0002[ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`3Roooo
o`002?ooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo02Wooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`3Qooooo`002?ooool01?oMgMgoEEEEooooool00006oooo
o`03o`000?oooooooooo02Sooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`3Qoooo
o`002Oooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo02Oooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`3Pooooo`002Oooool00oo^k^koA4A4o`000006ooooo`03o`00
0?oooooooooo02Oooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`3Oooooo`002_oo
ool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`3Nooooo`004_ooool2o`0002Kooooo00?o003oooooooooool06oooool0
1?l00?oo0000o`000?l0003Looooo`004_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooo
oooo01gooooo00?o003oo`000?l00000g?ooool001;ooooo00?o0000ooooooooool08oooool00ol0
0?ooooooooooo`0Nooooo`03o`00ool0003o00000=cooooo000Booooo`03o`000?oooooooooo02;o
oooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`3Kooooo`004_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?l00?oo000002?ooooo00?o003oooooooooool0f_ooool001;ooooo00?o
0000ooooooooool08?ooool00ol0003o003oo`00000Tooooo`03o`00oooooooooooo0=Wooooo000B
ooooo`;o00008Oooool00ol00?oo0000o`00000Tooooo`03o`00oooooooooooo08Sooooo0ol0001>
ooooo`004_ooool00ol0003oooooooooo`0Pooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool0QOooool7o`00odcooooo000Booooo`03o`000?oooooooooo01oooooo00?o003ooooooooo
ool09oooool00ol00?ooooooooooo`21ooooo`?o003o0_ooool3o`0000;ooooo1?l00?m8ooooo`00
4_ooool00ol0003oooooooooo`0Oooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool0
O_ooool2o`00o`kooooo0ol00?m5ooooo`004_ooool00ol0003oooooooooo`0Nooooo`03o`00oooo
oooooooo02Wooooo00?o003oooooooooool0N_ooool01?l0003o003oo`00ool00?lCooooo`03o`00
ool0003o000004;ooooo000Booooo`03o`000?oooooooooo01kooooo00?o003oooooooooool0:_oo
ool00ol00?ooooooooooo`1iooooo`03o`00ool0003o000001Cooooo00?o0000o`00ool00?l0@_oo
ool001;ooooo0_l0000Nooooo`03o`00oooooooooooo02cooooo00?o003oooooooooool0M_ooool2
o`00o`?o00005?ooool3o`000003o`00oooooooooooo03oooooo000Booooo`03o`000?oooooooooo
01gooooo00?o003oooooooooool0;?ooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo
01_ooooo0_l00?loooooo`004_ooool00ol0003oooooooooo`0Looooo`03o`00oooooooooooo02ko
oooo00?o003oooooooooool0Loooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo03co
oooo000Booooo`03o`000?oooooooooo01cooooo00?o003oooooooooool0;oooool00ol00?oooooo
ooooo`1aooooo`03o`00oooooooooooo023ooooo0_l00?llooooo`002?ooool5o`0000Gooooo00?o
0000ooooooooool06oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo00Wooooo0ol0
001Sooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0>Oooool000Sooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool0<Ooo
ool00ol00?ooooooooooo`09ooooo`03o`000?oo0?ooo`3o00;oo`3oH?ooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo03Sooooo0006o`0000?ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`0001[ooooo00?o003oooooooooool0<oooool00ol00?oo0000o`000003ooooo`Ooo`3o00?o0000
oooooooo0?l01_oo0?mJooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0=oooool0
00[ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo
03Cooooo00?o0000o`00ool000000ooo0?l@ooooo`?oo`3o00?o0000ooooooooool0Doooool00ol0
0?ooooooooooo`0Xooooo`03o`00oooooooooooo03Kooooo000;ooooo`03ogMgMomVIVKooooo00Co
oooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0dooooo`03ool0ool00?ooo`3o01Co
oooo0_l00002ool0oe?ooooo00?o003oooooooooool0:Oooool00ol0003o003oo`00000fooooo`00
3?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool0
=?ooool01?oo0?oo0000o`000?l00?lDooooo`?o000000?oooooool0oooo0?l0C_ooool2o`000003
o`00oooooooooooo02[ooooo00?o0000o`00ool00000=_ooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4005ooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool0<_ooool2ool0o`04
ooooool0003o0000o`00oa[ooooo0_oo0?m<ooooo`03o`000?l00?oo000002cooooo0_l000000ol0
0?ooooooooooo`0dooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000oooo
ooooool05oooool00ol00?ooooooooooo`0booooo`03ool0oooooooooooo00Cooooo00?o003ooooo
ooooool06Oooool2ool0od[ooooo00?o003oo`000?l00000;oooool00ol00?ooooooooooo`0coooo
o`004_ooool2o`0001Oooooo00?o003oooooooooool0<Oooool2ool0o`Oooooo00?o003ooooooooo
ool06oooool00ooo0?ooooooooooo`17ooooo`03o`00oooooooooooo033ooooo00?o003ooooooooo
ool0<_ooool001;ooooo00?o0000ooooooooool05?ooool2o`000003o`00oooooooooooo033ooooo
00?oo`3oooooooooool02?ooool00ol00?ooooooooooo`0Kooooo`03ool0oooooooooooo04Gooooo
00?o003oooooooooool0<_ooool00ol00?ooooooooooo`04ooooo`?o00002Oooool3o`0001kooooo
000Booooo`03o`000?oooooooooo01Cooooo00?o0000o`00ool00000<Oooool00ooo0?oooooooooo
o`09ooooo`03o`00oooooooooooo01cooooo00?oo`3oo`000?l00000@oooool00ol00?oooooooooo
o`0cooooo`03o`00oooooooooooo00Cooooo4?oo0?lMooooo`004_ooool00ol0003oooooooooo`0D
ooooo`03o`000?l00?oo0000033ooooo00?oo`3oooooooooool02oooool00ol00?ooooooooooo`0K
ooooo`03o`000?oo0?oo000004?ooooo00?o003oooooooooool0=?ooool00ol00?ooo`3oool0o`03
ool0o`?o00002Oooool3o`000003oooooooo0?ooo`3o00?oo`3o6?ooool001;ooooo00?o0000oooo
ooooool05?ooool00ol00?ooooooooooo`0]ooooo`;o000000?oo`3oooooooooool03?ooool00ol0
0?ooooooooooo`0Kooooo`;o00000_oo0?m1ooooo`03o`00oooooooooooo03;ooooo0ooo0?l00ooo
oooo003oooooo`0Hooooo`;oo`3o5_ooool001;ooooo00?o0000ooooooooool05?ooool00ol00?oo
ooooooooo`0]ooooo`03o`000?oo0?oo000000oooooo00?o003oooooooooool07_ooool00ooo0?oo
ooooooooo`0mooooo`03o`00oooooooooooo033ooooo00?o0000ool0oooo0?l01Oooool00ol00?oo
ooooooooo`0Hooooo`;oo`3o0_l0000Booooo`004_ooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo01Gooooo1?l000000ol@413oooooooooo`0Booooo`03ool0ool0003o0000013ooooo
00?o003oooooool000001?l0000Jooooo`03ool0oooooooooooo00kooooo00GoV9RHoa0@4?l0003o
<S8bolc<c00Xooooo`03o`00oooooooooooo00;ooooo0_l000000ol@413oooooooooo`0Yooooo`;o
o`3o0_l000000ooMgMgoooooooooo`02ooooo`03o`00oooooooooooo01Wooooo00?o0000ool0oooo
0?l01oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo000Booooo`;o00005?ooool00ol00?oo
ooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?oo`3oooooooooool04Oooool01ol00?oo
oooooiRHV?lQ8B7ok^k^oooooom4A4@06oooool2ool0o`kooooo00Go410@okZj^_ooooooMgMgoc8b
<P0Xooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool0:?ooool2ool0o`05ooooool0
003o0000o`000?lb<S801Oooool00ol00?ooooooooooo`0Hooooo`?o00000_oo0?l5ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool001;ooooo00?o0000ooooooooool04oooool00ol00?oooooo
ooooo`0Gooooo`03o`000?oooooooooo01;ooooo00?oo`3oooooooooool04oooool01Ol00?oooooo
oiRHV?lQ8B7ok^k^01kooooo00?oo`3oooooooooool03oooool00ol0003oooooooooo`0Uooooo`04
o`00ooooooooooooooooo`Go00009oooool2ool0o`Kooooo00?o0000ooooooooool01?ooool00ol0
0?ooooooooooo`0Looooo`;oo`3o0oooool01Ol0003ooooooooooooooooo000000Kooooo000Boooo
o`03o`000?oooooooooo01;ooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0Aoooo
o`03ool0oooooooooooo01Cooooo00Ko003oooooooooooooV9RHob4Q8Oo^k^hNooooo`03ool0oooo
oooooooo00gooooo00?oZJVYoa0@4?ooool09Oooool00ol00?ooooooooooo`02ooooo`04odA4A?oM
gMgoooooo`0002Oooooo00?oo`3oooooooooool01Oooool00omgMgOo<S8booooo`06ooooo`03o`00
oooooooooooo01gooooo0_oo0?l01_oooooo0000oiRHV?ooooooV9RHob4Q8@Kooooo000Booooo`03
o`000?oooooooooo01;ooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0@ooooo`03
ool0oooooooooooo01Kooooo00Go003oooooooooooooMgMgofIVIP0Oooooo`;oo`3o3?ooool00ol@
413o0000okZj^P0Vooooo`03o`00oooooooooooo00;ooooo00CogMgMoeEEEOoooooo00009Oooool2
ool0o`Gooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`03o`00ool0003o000001kooooo0_oo
0?l01?mEEEGo0000oa0@4?o<c<`6ooooo`004_ooool00ol0003oooooooooo`0Aooooo`03o`00oooo
oooooooo01Wooooo00?o0000ooooooooool03oooool00ooo0?ooooooooooo`0Gooooo`05o`00oooo
ooooooooooooool000008Oooool00ooo0?ooooooooooo`0:ooooo`03okZj^_lQ8B7ooooo02Cooooo
00?o003oooooooooool01?ooool00omgMgOoc<c<o`00000Qooooo`?o000000?oo`3oooooooooool0
1Oooool00ol0003oooooooooo`0:ooooo`03o`00ool0003o000001oooooo00?oEEEEool0oooo0?l0
0_l00006ooooo`004_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o
0000ooooooooool03_ooool00ooo0?ooooooooooo`0Hooooo`05o`000?l00?oooooooiRHV?l@4100
8Oooool00ol0003oo`3oo`000007ooooo`05oa0@4?nHV9SooooookZj^_l000009?ooool00ol00?oo
ooooooooo`05ooooo`03onk^k_m4A4Co0000027ooooo00?o0000ool0oooo0?l02?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?l00?oo000001oooooo00GogMgMoa0@4?l0003oo`3oo`000006oooo
o`004_ooool2o`00017ooooo00?o003oooooooooool06?ooool00omEEEGoIVIVo`00000?ooooo`03
ool0oooooooooooo01Wooooo00GoV9RHo`00ool0003o8B4Qolc<c00Qooooo`;o00000_oo0?l6oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT08oooool00ol00?ooooooooooo`07ooooo`03ogMgMol0003o
oooo023ooooo00?oo`3oo`000?l000002?ooool4o`0000_ooooo00?o003oooooooooool07_ooool0
1?o<c<co0000o`000?l00006ooooo`004_ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo
oooo02Wooooo00?oo`3oooooooooool07?ooool00ol00?ooooooooooo`0Qooooo`?o000000?ooooo
ool0ooooool0:_ooool2o`000003o`00oooooooooooo02Wooooo00?oo`3oooooooooool06Oooool0
0ol00?ooooooooooo`0Wooooo`004_ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo
02Sooooo00?oo`3oooooooooool07Oooool00ol00?ooooooooooo`0Vooooo`03ool0oooooooooooo
02Sooooo00?o0000o`00ool00000:Oooool2ool0oagooooo00?o003oooooooooool09_ooool001;o
oooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0Vooooo`;o000000?oo`3ooooooooo
ool07_ooool00ol0003o003oo`00000Wooooo`03ool0oooooooooooo02Oooooo00?o003oo`000?l0
0000:?ooool00ooo0?ooooooooooo`0Mooooo`03o`00oooooooooooo02Kooooo000Booooo`03o`00
0?oooooooooo00oooooo00?o003oooooooooool09_ooool00ol0003oo`3oo`00000Pooooo`03o`00
0?l00?oo000002Sooooo00?oo`3oooooooooool09_ooool00ol00?ooooooooooo`0Wooooo`03ool0
oooooooooooo01oooooo00?o003oooooooooool09Oooool001;ooooo00?o0000ooooooooool03_oo
ool00ol00?ooooooooooo`0Wooooo`03ool0ool0003o0000023ooooo0_l000000ol00?oooooooooo
o`0Wooooo`03ool0oooooooooooo02Cooooo00?o003oooooooooool09_ooool2ool0ob?ooooo00?o
003oooooooooool09?ooool000_ooooo6?l000000ol00?oo0000o`00000Vo`000003ool0ool0003o
000002?o000000?o003oo`000?l00000:?l000000ooo0?oo0000o`00000Ro`000003o`00ool0003o
000002Ko000000?oo`3oo`000?l000009?l000000ol00?oo0000o`00000So`0000004_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00Co003ooooooooooooo00002Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ooo0?ooooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooo003o00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool0
1?oo0?ooooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo003o00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ol000001?oo0?oooooo
ooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00gooooo
00?o003oooooooooool09Oooool00ooo0?ooooooooooo`0Wooooo`03o`00oooooooooooo02Sooooo
00?oo`3oooooooooool07oooool00ol00?ooooooooooo`0Sooooo`03o`000?oo0?ooo`3o02Wooooo
00?o003oooooooooool08_ooool001;ooooo00?o0000ooooooooool03Oooool00ol00?oooooooooo
o`0Tooooo`03ool0oooooooooooo02Sooooo00?o003oooooooooool0:Oooool00ooo0?oo0000o`00
000Mooooo`03o`00oooooooooooo02Cooooo00?oo`3oo`000?l00000:_ooool00ol00?oooooooooo
o`0Qooooo`004_ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo02Cooooo00?oo`3o
ooooooooool0:_ooool00ol00?ooooooooooo`0Xooooo`03o`000?oo0?oo000001gooooo00?o003o
ooooooooool08_ooool2ool0obkooooo00?o003oooooooooool08?ooool001;ooooo00?o0000oooo
ooooool03?ooool00ol00?ooooooooooo`0Sooooo`03ool0oooooooooooo02_ooooo00?o003ooooo
ooooool0:?ooool2o`0000;oo`3o6oooool00ol00?ooooooooooo`0Rooooo`03ool0oooooooooooo
02oooooo00?o003oooooooooool07oooool001;ooooo0_l0000<ooooo`03o`00oooooooooooo02?o
oooo00?oo`3oooooooooool0;Oooool00ol00?ooooooooooo`0[ooooo`03ool0oooooooooooo01Oo
oooo00?o003oooooooooool08Oooool2ool0oc?ooooo00?o003oo`000?l000007_ooool001;ooooo
00?o0000ooooooooool02oooool00ol00?ooooooooooo`0Rooooo`03ool0oooooooooooo02kooooo
00?o003oooooooooool0;?ooool00ooo0?ooooooooooo`0Fooooo`03o`00oooooooooooo023ooooo
00?oo`3oooooooooool0<oooool00ol00?oo0000o`00000Nooooo`004_ooool00ol0003ooooooooo
o`0:ooooo`03o`00oooooooooooo02;ooooo00?oo`3oooooooooool0<?ooool00ol00?oooooooooo
o`0/ooooo`03ool0oooooooooooo01Cooooo00?o003oooooooooool07oooool2ool0ocKooooo00?o
0000o`00ool000007_ooool001;ooooo00?o0000ooooooooool02?ooool2o`000003o`00oooooooo
oooo027ooooo00?oo`3oooooooooool0<_ooool00ol00?ooooooooooo`0/ooooo`03ool0oooooooo
oooo01;ooooo00?o003oooooooooool07Oooool2o`000003ool0oooooooooooo03Sooooo00?o003o
ooooooooool07?ooool001;ooooo00?o0000ooooooooool02?ooool2o`000003o`00oooooooooooo
01oooooo00?o0000ool0ool00000=?ooool00ol00?ooooooooooo`0]ooooo`;oo`3o4_ooool00ol0
0?ooooooooooo`0Mooooo`;oo`3o00?o0000ooooooooool0>Oooool00ol00?ooooooooooo`0Koooo
o`004_ooool00ol0003oooooooooo`08ooooo`03o`000?l00?oo0000027ooooo00?oo`3oo`000?l0
0000=Oooool00ol00?ooooooooooo`0^ooooo`03ool0oooooooooooo00kooooo00?o003ooooooooo
ool07?ooool2ool0o`?o0000??ooool00ol00?ooooooooooo`0Jooooo`004_ooool2o`0000[ooooo
00?o003oooooooooool07oooool01?oo0?oo0000o`000?l0000eooooo`03o`00oooooooooooo02oo
oooo0_oo0?l2o`0000_ooooo00?o003oooooooooool07?ooool00ooo0?ooooooooooo`10ooooo`03
o`00oooooooooooo01Wooooo000Booooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0
7oooool00ooo0?ooooooooooo`0hooooo`03o`00oooooooooooo02oooooo00?o0000ool0ool00000
2Oooool2o`000003o`00oooooooooooo01[ooooo0_oo0?m4ooooo`03o`00oooooooooooo01Sooooo
000Booooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool07_ooool00ooo0?oooooooooo
o`0iooooo`03o`00oooooooooooo02oooooo0_l00002ool0o`Sooooo00?o0000o`00ool000006_oo
ool2ool0odOooooo00?o003oooooooooool05oooool001;ooooo00?o0000ooooooooool01oooool0
0ol00?ooooooooooo`0Nooooo`03ool0oooooooooooo03_ooooo00?o003oooooooooool0<_ooool2
ool0o`Kooooo00?o003oo`000?l000006Oooool00ooo0?ooooooooooo`18ooooo`03o`00oooooooo
oooo01Kooooo000Booooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ooo
0?ooooooooooo`0mooooo`03o`00oooooooooooo03?ooooo00?oo`3oooooooooool00oooool00ol0
0?ooooooooooo`0Eooooo`;o00000_oo0?m<ooooo`03o`00oooooooooooo01Gooooo000Booooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool07Oooool00ooo0?ooooooooooo`0nooooo`03
o`00oooooooooooo03Cooooo0ooo0?l00ooooooo003oooooo`0Gooooo`;oo`3o00?o0000oooooooo
ool0C?ooool00ol00?ooooooooooo`0Dooooo`004_ooool2o`0000Oooooo00?o003oooooooooool0
7?ooool00ooo0?ooooooooooo`0oooooo`03o`000?l00?oo000003Oooooo00?o003oool0oooo0?l0
0_l0000Booooo`?oo`3o0ol0001?ooooo`03o`00oooooooooooo01?ooooo000Booooo`03o`000?oo
oooooooo00Gooooo00?o003oooooooooool07?ooool00ooo0?ooooooooooo`10ooooo`03o`000?l0
0?oo000003Kooooo00Co003ooooooooooooo00000ooo0?l8ooooo`?o00000oooool3ool0oeKooooo
0_l00?l00ol0003oooooooooo`0@ooooo`004_ooool00ol0003oooooooooo`05ooooo`03o`00oooo
oooooooo01_ooooo00?oo`3oooooooooool0@Oooool2o`000003o`00oooooooooooo03?ooooo00Co
003ooooooooooooooooo0ol000000oooooooo`3oool0o`0<ool0oeWooooo0_l000000ol00?oooooo
ooooo`0@ooooo`002?ooool5o`0000Gooooo00?o0000ooooooooool01?ooool00ol00?oooooooooo
o`0Iooooo`03o`000?oo0?ooo`3o04Oooooo00?o003oooooooooool0<_ooool00ol00?oooooooooo
o`0=ooooo`?o0000G?ooool3o`0000;o003o4?ooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool06Oooool00ooo0?oo0000o`00
0017ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0L_ooool00ol00?oooooooooo
o`0=ooooo`002Oooool00onHV9So8B4Qonk^kP05ooooo`?o00001?ooool00ol00?ooooooooooo`0I
ooooo`04ool0ool0003o0000o`0004Sooooo00?o003oooooooooool0;oooool00ol00?oooooooooo
o`1dooooo`;o003o3Oooool000[ooooo00?oV9RHob4Q8Oo^k^h01?ooool01?l0003oo`3oool0ool0
0003ooooo`03o`00oooooooooooo01Sooooo00?oo`3oooooooooool0Boooool00ol00?oooooooooo
o`0]ooooo`03o`00oooooooooooo07Oooooo00?o003oooooooooool02_ooool000_ooooo00?oMgMg
ofIVI_ooool00oooool3o`000005ool0ooooooooooooooooool00?l06Oooool00ooo0?oooooooooo
o`1<ooooo`03o`00oooooooooooo02cooooo00?o003oooooooooool0NOooool00ol00?oooooooooo
o`09ooooo`003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;oo`3o00?o003o
ooooooooool05_ooool2ool0oe3ooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`1j
ooooo`03o`00oooooooo000000;o00001_ooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@4005
ooooo`03o`000?oooooooooo00;ooooo00?o003oool0ooooool04oooool3ool0oe?ooooo00?o003o
ooooooooool0:Oooool00ol00?ooooooooooo`1looooo`?o003o00?o0000ooooooooool01?ooool0
00Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`05o`000?ooooooooooooooool00?l00_oo
ool2ool0o`kooooo0_l00002ool0oeKooooo00?o003oooooooooool0:?ooool00ol00?oooooooooo
o`1nooooo`?o00001_ooool001;ooooo00Go0000ooooooooooooooooo`00o`04ooooo`Coo`3o00?o
0000ooooooooool01_ooool3ool0o`03o`000?oooooooooo05Kooooo00?o003oooooooooool09Ooo
ool00ol0003o003oo`000029ooooo`004_ooool2o`000003ooooool00?oooooo00Kooooo0_l00009
ool0o`04ooooool0003o0000o`0005Wooooo00?o003oooooooooool09?ooool00ol00?oo0000o`00
0029ooooo`004_ooool01?l0003oooooooooool00?l7ooooo`?o0000I_ooool00ol00?oooooooooo
o`0Sooooo`03o`00ool0003o000008Wooooo000Booooo`03o`000?oooooo003o07;ooooo00?o003o
ooooooooool08Oooool00ol00?ooooooooooo`2:ooooo`004_ooool00ol0003oooooo`00o`1coooo
o`03o`00oooooooooooo01oooooo00?o003oooooooooool0Roooool001;ooooo00?o0000o`00oooo
ool0Loooool00ol0003o003oo`00000Nooooo`03o`00oooooooooooo08cooooo000Aooooo`;o0000
00?o003oooooooooool0L_ooool2o`000003o`00oooooooooooo01_ooooo00?o003oooooooooool0
SOooool0017ooooo00?o0000o`00ool00000M?ooool3o`000003o`00oooooooooooo01Wooooo00?o
003oooooooooool0S_ooool0017ooooo0ol0001hooooo`;o003o5oooool2o`00oi7ooooo000Boooo
o`03o`000?oooooooooo07Wooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`2Aoooo
o`004_ooool00ol0003oooooooooo`1jooooo`03o`00oooooooooooo00kooooo0_l00002o`00oiCo
oooo000Booooo`03o`000?oooooooooo07_ooooo0_l00?l>ooooo`03o`000?l00?oo000009Gooooo
000Booooo`03o`000?oooooooooo07gooooo00?o003oooooool000000_l00008ooooo`;o003o0_l0
002Eooooo`004_ooool2o`0007oooooo1Ol00?l2ooooo`Go003oVOooool001;ooooo00?o0000oooo
ooooool0Ooooool3o`000004ooooool00?oo003oo`00oigooooo000Booooo`03o`000?oooooooooo
0?oooooo9?ooool001;ooooo00?o0000ooooooooool0oooooolTooooo`00ooooooliooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 326.875}, {267.688, 185.375}} -> {-2.44087, \
14.5886, 0.0262819, 0.103814}}]
}, Open  ]],

Cell[TextData[StyleBox["Phase plane trajectories and vector fields ",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "When the phase plane trajectory passes through the phase point (",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["v",
    FontSlant->"Italic"],
  ") its velocity vector, which is tangent to the trajectory, is  < ",
  StyleBox["y",
    FontSlant->"Italic"],
  "', ",
  StyleBox["v",
    FontSlant->"Italic"],
  "' >. Since ",
  StyleBox["y",
    FontSlant->"Italic"],
  "' = ",
  StyleBox["v",
    FontSlant->"Italic"],
  " and  ",
  StyleBox["v",
    FontSlant->"Italic"],
  "' = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'', we have  "
}], "Text"],

Cell[TextData[{
  "< ",
  StyleBox["y",
    FontSlant->"Italic"],
  "', ",
  StyleBox["v",
    FontSlant->"Italic"],
  "' > = < ",
  StyleBox["v",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'' > . "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
This tells us several things about the trajectories for a linear \
oscillator.   \
\>", "Text"],

Cell[TextData[{
  "1. All phase plane trajectories cross the ",
  StyleBox["y",
    FontSlant->"Italic"],
  " axis with a vertical tangent. This is because ",
  StyleBox["v",
    FontSlant->"Italic"],
  " = 0 on the ",
  StyleBox["y",
    FontSlant->"Italic"],
  " axis so the first component of the velocity vector is also 0.   "
}], "Text"],

Cell["\<\
2. Similarly, trajectories move to the right when they are in the \
upper half plane, and move to the left in the  lower half plane.    \
\>", \
"Text"],

Cell[TextData[{
  "3. Since the differential equation determines ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'' in terms of ",
  StyleBox["y",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "' (= ",
  StyleBox["v",
    FontSlant->"Italic"],
  "), the trajectory's velocity vector can  be found without knowledge of the \
solution formula. Consider, for example, a second order linear constant \
coefficient homogeneous equation: (",
  StyleBox["a",
    FontSlant->"Italic"],
  " not zero)"
}], "Text"],

Cell[TextData[{
  " ",
  StyleBox["a y",
    FontSlant->"Italic"],
  "'' + ",
  StyleBox["b y",
    FontSlant->"Italic"],
  "' +",
  StyleBox[" c y",
    FontSlant->"Italic"],
  " = 0 . "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Substitute ",
  StyleBox["y",
    FontSlant->"Italic"],
  "' = ",
  StyleBox["v",
    FontSlant->"Italic"],
  " and solve for ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'' to obtain  "
}], "Text"],

Cell[TextData[{
  StyleBox["y",
    FontSlant->"Italic"],
  "'' = (-",
  StyleBox["c y",
    FontSlant->"Italic"],
  " - ",
  StyleBox["b v",
    FontSlant->"Italic"],
  ")/",
  StyleBox["a",
    FontSlant->"Italic"],
  " .  "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Consequently, when a phase plane trajectory is at (",
  StyleBox["y, v",
    FontSlant->"Italic"],
  " )",
  ", its velocity vector is "
}], "Text"],

Cell[TextData[{
  "< ",
  StyleBox["y",
    FontSlant->"Italic"],
  "', ",
  StyleBox["v",
    FontSlant->"Italic"],
  "' > = < ",
  StyleBox["v",
    FontSlant->"Italic"],
  " , (-",
  StyleBox["c y",
    FontSlant->"Italic"],
  " - ",
  StyleBox["b v",
    FontSlant->"Italic"],
  ")/",
  StyleBox["a",
    FontSlant->"Italic"],
  " > . "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
This vector equation can be expressed equivalently as a system of \
two first order scalar differential equations. \
\>", "Text"],

Cell[TextData[{
  StyleBox["y",
    FontSlant->"Italic"],
  "' = ",
  StyleBox["v",
    FontSlant->"Italic"],
  "                 \n",
  StyleBox["v",
    FontSlant->"Italic"],
  "' = (-",
  StyleBox["c y",
    FontSlant->"Italic"],
  " - ",
  StyleBox["b v",
    FontSlant->"Italic"],
  ")/",
  StyleBox["a",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "The system of differential equations is called autonomous because the two \
derivatives do not depend directly upon  the time variable. In this case, a \
plot of an array of tangent vectors in the ",
  StyleBox["y,v",
    FontSlant->"Italic"],
  " plane gives the same information  about the trajectories associated with \
a second order differential equation as a direction field gives for a first  \
order equation. Such an array is called the vector field associated with the \
differential equation. "
}], "Text"],

Cell[TextData[StyleBox["Example. The vector field for the damped mass spring \
system in this section is defined below. We name it F. ",
  FontSlant->"Italic"]], "Text"],

Cell[CellGroupData[{

Cell["dampedDE", "Input",
  CellLabel->"In[247]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{\(15.2`\ y[t]\), "+", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "+", 
        RowBox[{"4.3`", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
      "0"}]], "Output",
  CellLabel->"Out[247]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["F = { v, (-15.2y - v)/4.3 }", "Input",
  CellLabel->"In[248]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({v, 0.23255813953488372`\ \((\(-v\) - 15.2`\ y)\)}\)], "Output",
  CellLabel->"Out[248]="]
}, Open  ]],

Cell[TextData[{
  "Recall that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s PlotVectorField function will plot the vector field. It must be loaded \
into the kernel."
}], "Text"],

Cell["<<Graphics`PlotField`", "Input",
  CellLabel->"In[249]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["vf = PlotVectorField[ F, {y,-5,5}, {v,-5,5}, Axes->True ]", "Input",
  CellLabel->"In[257]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0814 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.091871 0.540698 0.091871 [
[.13252 .5282 -6 -9 ]
[.13252 .5282 6 0 ]
[.31626 .5282 -6 -9 ]
[.31626 .5282 6 0 ]
[.68374 .5282 -3 -9 ]
[.68374 .5282 3 0 ]
[.86748 .5282 -3 -9 ]
[.86748 .5282 3 0 ]
[.4875 .17321 -12 -4.5 ]
[.4875 .17321 0 4.5 ]
[.4875 .35696 -12 -4.5 ]
[.4875 .35696 0 4.5 ]
[.4875 .72444 -6 -4.5 ]
[.4875 .72444 0 4.5 ]
[.4875 .90818 -6 -4.5 ]
[.4875 .90818 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.0814 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13252 .5407 m
.13252 .54695 L
s
[(-4)] .13252 .5282 0 1 Mshowa
.31626 .5407 m
.31626 .54695 L
s
[(-2)] .31626 .5282 0 1 Mshowa
.68374 .5407 m
.68374 .54695 L
s
[(2)] .68374 .5282 0 1 Mshowa
.86748 .5407 m
.86748 .54695 L
s
[(4)] .86748 .5282 0 1 Mshowa
.125 Mabswid
.17845 .5407 m
.17845 .54445 L
s
.22439 .5407 m
.22439 .54445 L
s
.27032 .5407 m
.27032 .54445 L
s
.36219 .5407 m
.36219 .54445 L
s
.40813 .5407 m
.40813 .54445 L
s
.45406 .5407 m
.45406 .54445 L
s
.54594 .5407 m
.54594 .54445 L
s
.59187 .5407 m
.59187 .54445 L
s
.63781 .5407 m
.63781 .54445 L
s
.72968 .5407 m
.72968 .54445 L
s
.77561 .5407 m
.77561 .54445 L
s
.82155 .5407 m
.82155 .54445 L
s
.08658 .5407 m
.08658 .54445 L
s
.04064 .5407 m
.04064 .54445 L
s
.91342 .5407 m
.91342 .54445 L
s
.95936 .5407 m
.95936 .54445 L
s
.25 Mabswid
0 .5407 m
1 .5407 L
s
.5 .17321 m
.50625 .17321 L
s
[(-4)] .4875 .17321 1 0 Mshowa
.5 .35696 m
.50625 .35696 L
s
[(-2)] .4875 .35696 1 0 Mshowa
.5 .72444 m
.50625 .72444 L
s
[(2)] .4875 .72444 1 0 Mshowa
.5 .90818 m
.50625 .90818 L
s
[(4)] .4875 .90818 1 0 Mshowa
.125 Mabswid
.5 .21915 m
.50375 .21915 L
s
.5 .26509 m
.50375 .26509 L
s
.5 .31102 m
.50375 .31102 L
s
.5 .40289 m
.50375 .40289 L
s
.5 .44883 m
.50375 .44883 L
s
.5 .49476 m
.50375 .49476 L
s
.5 .58663 m
.50375 .58663 L
s
.5 .63257 m
.50375 .63257 L
s
.5 .6785 m
.50375 .6785 L
s
.5 .77038 m
.50375 .77038 L
s
.5 .81631 m
.50375 .81631 L
s
.5 .86225 m
.50375 .86225 L
s
.5 .12728 m
.50375 .12728 L
s
.5 .08134 m
.50375 .08134 L
s
.5 .03541 m
.50375 .03541 L
s
.5 .95412 m
.50375 .95412 L
s
.5 1.00005 m
.50375 1.00005 L
s
.5 1.04599 m
.50375 1.04599 L
s
.25 Mabswid
.5 0 m
.5 1.0814 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.04064 .08134 m
.02381 .14477 L
s
% Start of user PostScript
-5. -5. -5.18325 -4.30962 MAarrowhead1
% End of user PostScript
.04064 .14697 m
.02621 .20983 L
s
% Start of user PostScript
-5. -4.28571 -5.15707 -3.60142 MAarrowhead1
% End of user PostScript
.04064 .21259 m
.02862 .27489 L
s
% Start of user PostScript
-5. -3.57143 -5.13089 -2.89323 MAarrowhead1
% End of user PostScript
.04064 .27821 m
.03102 .33996 L
s
% Start of user PostScript
-5. -2.85714 -5.10471 -2.18503 MAarrowhead1
% End of user PostScript
.04064 .34383 m
.03343 .40502 L
s
% Start of user PostScript
-5. -2.14286 -5.07854 -1.47683 MAarrowhead1
% End of user PostScript
.04064 .40945 m
.03583 .47008 L
s
% Start of user PostScript
-5. -1.42857 -5.05236 -0.768632 MAarrowhead1
% End of user PostScript
.04064 .47508 m
.03824 .53515 L
s
% Start of user PostScript
-5. -0.714286 -5.02618 -0.0604342 MAarrowhead1
% End of user PostScript
.04064 .5407 m
.04064 .60021 L
s
% Start of user PostScript
-5. 0 -5. 0.647764 MAarrowhead1
% End of user PostScript
.04064 .60632 m
.04305 .66527 L
s
% Start of user PostScript
-5. 0.714286 -4.97382 1.35596 MAarrowhead1
% End of user PostScript
.04064 .67194 m
.04545 .73033 L
s
% Start of user PostScript
-5. 1.42857 -4.94764 2.06416 MAarrowhead1
% End of user PostScript
.04064 .73756 m
.04786 .7954 L
s
% Start of user PostScript
-5. 2.14286 -4.92146 2.77236 MAarrowhead1
% End of user PostScript
.04064 .80319 m
.05026 .86046 L
s
% Start of user PostScript
-5. 2.85714 -4.89529 3.48055 MAarrowhead1
% End of user PostScript
.04064 .86881 m
.05267 .92552 L
s
% Start of user PostScript
-5. 3.57143 -4.86911 4.18875 MAarrowhead1
% End of user PostScript
.04064 .93443 m
.05508 .99059 L
s
% Start of user PostScript
-5. 4.28571 -4.84293 4.89695 MAarrowhead1
% End of user PostScript
.04064 1.00005 m
.05748 1.05565 L
s
% Start of user PostScript
-5. 5. -4.81675 5.60515 MAarrowhead1
% End of user PostScript
.10627 .08134 m
.08943 .13627 L
s
% Start of user PostScript
-4.28571 -5. -4.46896 -4.40216 MAarrowhead1
% End of user PostScript
.10627 .14697 m
.09184 .20133 L
s
% Start of user PostScript
-4.28571 -4.28571 -4.44278 -3.69396 MAarrowhead1
% End of user PostScript
.10627 .21259 m
.09424 .26639 L
s
% Start of user PostScript
-4.28571 -3.57143 -4.41661 -2.98576 MAarrowhead1
% End of user PostScript
.10627 .27821 m
.09665 .33146 L
s
% Start of user PostScript
-4.28571 -2.85714 -4.39043 -2.27756 MAarrowhead1
% End of user PostScript
.10627 .34383 m
.09905 .39652 L
s
% Start of user PostScript
-4.28571 -2.14286 -4.36425 -1.56937 MAarrowhead1
% End of user PostScript
.10627 .40945 m
.10146 .46158 L
s
% Start of user PostScript
-4.28571 -1.42857 -4.33807 -0.86117 MAarrowhead1
% End of user PostScript
.10627 .47508 m
.10386 .52664 L
s
% Start of user PostScript
-4.28571 -0.714286 -4.31189 -0.152972 MAarrowhead1
% End of user PostScript
.10627 .5407 m
.10627 .59171 L
s
% Start of user PostScript
-4.28571 0 -4.28571 0.555226 MAarrowhead1
% End of user PostScript
.10627 .60632 m
.10867 .65677 L
s
% Start of user PostScript
-4.28571 0.714286 -4.25954 1.26342 MAarrowhead1
% End of user PostScript
.10627 .67194 m
.11108 .72183 L
s
% Start of user PostScript
-4.28571 1.42857 -4.23336 1.97162 MAarrowhead1
% End of user PostScript
.10627 .73756 m
.11348 .7869 L
s
% Start of user PostScript
-4.28571 2.14286 -4.20718 2.67982 MAarrowhead1
% End of user PostScript
.10627 .80319 m
.11589 .85196 L
s
% Start of user PostScript
-4.28571 2.85714 -4.181 3.38802 MAarrowhead1
% End of user PostScript
.10627 .86881 m
.11829 .91702 L
s
% Start of user PostScript
-4.28571 3.57143 -4.15482 4.09621 MAarrowhead1
% End of user PostScript
.10627 .93443 m
.1207 .98208 L
s
% Start of user PostScript
-4.28571 4.28571 -4.12864 4.80441 MAarrowhead1
% End of user PostScript
.10627 1.00005 m
.1231 1.04715 L
s
% Start of user PostScript
-4.28571 5. -4.10247 5.51261 MAarrowhead1
% End of user PostScript
.17189 .08134 m
.15505 .12777 L
s
% Start of user PostScript
-3.57143 -5. -3.75468 -4.4947 MAarrowhead1
% End of user PostScript
.17189 .14697 m
.15746 .19283 L
s
% Start of user PostScript
-3.57143 -4.28571 -3.7285 -3.7865 MAarrowhead1
% End of user PostScript
.17189 .21259 m
.15986 .25789 L
s
% Start of user PostScript
-3.57143 -3.57143 -3.70232 -3.0783 MAarrowhead1
% End of user PostScript
.17189 .27821 m
.16227 .32295 L
s
% Start of user PostScript
-3.57143 -2.85714 -3.67614 -2.3701 MAarrowhead1
% End of user PostScript
.17189 .34383 m
.16467 .38802 L
s
% Start of user PostScript
-3.57143 -2.14286 -3.64996 -1.6619 MAarrowhead1
% End of user PostScript
.17189 .40945 m
.16708 .45308 L
s
% Start of user PostScript
-3.57143 -1.42857 -3.62379 -0.953707 MAarrowhead1
% End of user PostScript
.17189 .47508 m
.16948 .51814 L
s
% Start of user PostScript
-3.57143 -0.714286 -3.59761 -0.245509 MAarrowhead1
% End of user PostScript
.17189 .5407 m
.17189 .58321 L
s
% Start of user PostScript
-3.57143 0 -3.57143 0.462688 MAarrowhead1
% End of user PostScript
.17189 .60632 m
.17429 .64827 L
s
% Start of user PostScript
-3.57143 0.714286 -3.54525 1.17089 MAarrowhead1
% End of user PostScript
.17189 .67194 m
.1767 .71333 L
s
% Start of user PostScript
-3.57143 1.42857 -3.51907 1.87908 MAarrowhead1
% End of user PostScript
.17189 .73756 m
.1791 .77839 L
s
% Start of user PostScript
-3.57143 2.14286 -3.49289 2.58728 MAarrowhead1
% End of user PostScript
.17189 .80319 m
.18151 .84346 L
s
% Start of user PostScript
-3.57143 2.85714 -3.46671 3.29548 MAarrowhead1
% End of user PostScript
.17189 .86881 m
.18391 .90852 L
s
% Start of user PostScript
-3.57143 3.57143 -3.44054 4.00368 MAarrowhead1
% End of user PostScript
.17189 .93443 m
.18632 .97358 L
s
% Start of user PostScript
-3.57143 4.28571 -3.41436 4.71187 MAarrowhead1
% End of user PostScript
.17189 1.00005 m
.18872 1.03865 L
s
% Start of user PostScript
-3.57143 5. -3.38818 5.42007 MAarrowhead1
% End of user PostScript
.23751 .08134 m
.22068 .11926 L
s
% Start of user PostScript
-2.85714 -5. -3.04039 -4.58723 MAarrowhead1
% End of user PostScript
.23751 .14697 m
.22308 .18433 L
s
% Start of user PostScript
-2.85714 -4.28571 -3.01421 -3.87904 MAarrowhead1
% End of user PostScript
.23751 .21259 m
.22549 .24939 L
s
% Start of user PostScript
-2.85714 -3.57143 -2.98803 -3.17084 MAarrowhead1
% End of user PostScript
.23751 .27821 m
.22789 .31445 L
s
% Start of user PostScript
-2.85714 -2.85714 -2.96186 -2.46264 MAarrowhead1
% End of user PostScript
.23751 .34383 m
.2303 .37952 L
s
% Start of user PostScript
-2.85714 -2.14286 -2.93568 -1.75444 MAarrowhead1
% End of user PostScript
.23751 .40945 m
.2327 .44458 L
s
% Start of user PostScript
-2.85714 -1.42857 -2.9095 -1.04624 MAarrowhead1
% End of user PostScript
.23751 .47508 m
.23511 .50964 L
s
% Start of user PostScript
-2.85714 -0.714286 -2.88332 -0.338047 MAarrowhead1
% End of user PostScript
.23751 .5407 m
.23751 .5747 L
s
% Start of user PostScript
-2.85714 0 -2.85714 0.370151 MAarrowhead1
% End of user PostScript
.23751 .60632 m
.23992 .63977 L
s
% Start of user PostScript
-2.85714 0.714286 -2.83096 1.07835 MAarrowhead1
% End of user PostScript
.23751 .67194 m
.24232 .70483 L
s
% Start of user PostScript
-2.85714 1.42857 -2.80479 1.78655 MAarrowhead1
% End of user PostScript
.23751 .73756 m
.24473 .76989 L
s
% Start of user PostScript
-2.85714 2.14286 -2.77861 2.49474 MAarrowhead1
% End of user PostScript
.23751 .80319 m
.24713 .83496 L
s
% Start of user PostScript
-2.85714 2.85714 -2.75243 3.20294 MAarrowhead1
% End of user PostScript
.23751 .86881 m
.24954 .90002 L
s
% Start of user PostScript
-2.85714 3.57143 -2.72625 3.91114 MAarrowhead1
% End of user PostScript
.23751 .93443 m
.25194 .96508 L
s
% Start of user PostScript
-2.85714 4.28571 -2.70007 4.61934 MAarrowhead1
% End of user PostScript
.23751 1.00005 m
.25435 1.03014 L
s
% Start of user PostScript
-2.85714 5. -2.67389 5.32753 MAarrowhead1
% End of user PostScript
.30313 .08134 m
.2863 .11076 L
s
% Start of user PostScript
-2.14286 -5. -2.32611 -4.67977 MAarrowhead1
% End of user PostScript
.30313 .14697 m
.2887 .17583 L
s
% Start of user PostScript
-2.14286 -4.28571 -2.29993 -3.97157 MAarrowhead1
% End of user PostScript
.30313 .21259 m
.29111 .24089 L
s
% Start of user PostScript
-2.14286 -3.57143 -2.27375 -3.26338 MAarrowhead1
% End of user PostScript
.30313 .27821 m
.29351 .30595 L
s
% Start of user PostScript
-2.14286 -2.85714 -2.24757 -2.55518 MAarrowhead1
% End of user PostScript
.30313 .34383 m
.29592 .37101 L
s
% Start of user PostScript
-2.14286 -2.14286 -2.22139 -1.84698 MAarrowhead1
% End of user PostScript
.30313 .40945 m
.29832 .43608 L
s
% Start of user PostScript
-2.14286 -1.42857 -2.19521 -1.13878 MAarrowhead1
% End of user PostScript
.30313 .47508 m
.30073 .50114 L
s
% Start of user PostScript
-2.14286 -0.714286 -2.16904 -0.430585 MAarrowhead1
% End of user PostScript
.30313 .5407 m
.30313 .5662 L
s
% Start of user PostScript
-2.14286 0 -2.14286 0.277613 MAarrowhead1
% End of user PostScript
.30313 .60632 m
.30554 .63127 L
s
% Start of user PostScript
-2.14286 0.714286 -2.11668 0.985811 MAarrowhead1
% End of user PostScript
.30313 .67194 m
.30794 .69633 L
s
% Start of user PostScript
-2.14286 1.42857 -2.0905 1.69401 MAarrowhead1
% End of user PostScript
.30313 .73756 m
.31035 .76139 L
s
% Start of user PostScript
-2.14286 2.14286 -2.06432 2.40221 MAarrowhead1
% End of user PostScript
.30313 .80319 m
.31275 .82645 L
s
% Start of user PostScript
-2.14286 2.85714 -2.03814 3.1104 MAarrowhead1
% End of user PostScript
.30313 .86881 m
.31516 .89152 L
s
% Start of user PostScript
-2.14286 3.57143 -2.01197 3.8186 MAarrowhead1
% End of user PostScript
.30313 .93443 m
.31756 .95658 L
s
% Start of user PostScript
-2.14286 4.28571 -1.98579 4.5268 MAarrowhead1
% End of user PostScript
.30313 1.00005 m
.31997 1.02164 L
s
% Start of user PostScript
-2.14286 5. -1.95961 5.235 MAarrowhead1
% End of user PostScript
.36876 .08134 m
.35192 .10226 L
s
% Start of user PostScript
-1.42857 -5. -1.61182 -4.77231 MAarrowhead1
% End of user PostScript
.36876 .14697 m
.35433 .16732 L
s
% Start of user PostScript
-1.42857 -4.28571 -1.58564 -4.06411 MAarrowhead1
% End of user PostScript
.36876 .21259 m
.35673 .23239 L
s
% Start of user PostScript
-1.42857 -3.57143 -1.55946 -3.35591 MAarrowhead1
% End of user PostScript
.36876 .27821 m
.35914 .29745 L
s
% Start of user PostScript
-1.42857 -2.85714 -1.53329 -2.64772 MAarrowhead1
% End of user PostScript
.36876 .34383 m
.36154 .36251 L
s
% Start of user PostScript
-1.42857 -2.14286 -1.50711 -1.93952 MAarrowhead1
% End of user PostScript
.36876 .40945 m
.36395 .42758 L
s
% Start of user PostScript
-1.42857 -1.42857 -1.48093 -1.23132 MAarrowhead1
% End of user PostScript
.36876 .47508 m
.36635 .49264 L
s
% Start of user PostScript
-1.42857 -0.714286 -1.45475 -0.523122 MAarrowhead1
% End of user PostScript
.36876 .5407 m
.36876 .5577 L
s
% Start of user PostScript
-1.42857 0 -1.42857 0.185075 MAarrowhead1
% End of user PostScript
.36876 .60632 m
.37116 .62276 L
s
% Start of user PostScript
-1.42857 0.714286 -1.40239 0.893273 MAarrowhead1
% End of user PostScript
.36876 .67194 m
.37357 .68783 L
s
% Start of user PostScript
-1.42857 1.42857 -1.37621 1.60147 MAarrowhead1
% End of user PostScript
.36876 .73756 m
.37597 .75289 L
s
% Start of user PostScript
-1.42857 2.14286 -1.35004 2.30967 MAarrowhead1
% End of user PostScript
.36876 .80319 m
.37838 .81795 L
s
% Start of user PostScript
-1.42857 2.85714 -1.32386 3.01787 MAarrowhead1
% End of user PostScript
.36876 .86881 m
.38078 .88302 L
s
% Start of user PostScript
-1.42857 3.57143 -1.29768 3.72606 MAarrowhead1
% End of user PostScript
.36876 .93443 m
.38319 .94808 L
s
% Start of user PostScript
-1.42857 4.28571 -1.2715 4.43426 MAarrowhead1
% End of user PostScript
.36876 1.00005 m
.38559 1.01314 L
s
% Start of user PostScript
-1.42857 5. -1.24532 5.14246 MAarrowhead1
% End of user PostScript
.43438 .08134 m
.41754 .09376 L
s
% Start of user PostScript
-0.714286 -5. -0.897535 -4.86485 MAarrowhead1
% End of user PostScript
.43438 .14697 m
.41995 .15882 L
s
% Start of user PostScript
-0.714286 -4.28571 -0.871356 -4.15665 MAarrowhead1
% End of user PostScript
.43438 .21259 m
.42235 .22389 L
s
% Start of user PostScript
-0.714286 -3.57143 -0.845178 -3.44845 MAarrowhead1
% End of user PostScript
.43438 .27821 m
.42476 .28895 L
s
% Start of user PostScript
-0.714286 -2.85714 -0.818999 -2.74025 MAarrowhead1
% End of user PostScript
.43438 .34383 m
.42716 .35401 L
s
% Start of user PostScript
-0.714286 -2.14286 -0.792821 -2.03206 MAarrowhead1
% End of user PostScript
.43438 .40945 m
.42957 .41907 L
s
% Start of user PostScript
-0.714286 -1.42857 -0.766643 -1.32386 MAarrowhead1
% End of user PostScript
.43438 .47508 m
.43197 .48414 L
s
% Start of user PostScript
-0.714286 -0.714286 -0.740464 -0.61566 MAarrowhead1
% End of user PostScript
.43438 .5407 m
.43438 .5492 L
s
% Start of user PostScript
-0.714286 0 -0.714286 0.0925376 MAarrowhead1
% End of user PostScript
.43438 .60632 m
.43678 .61426 L
s
% Start of user PostScript
-0.714286 0.714286 -0.688107 0.800735 MAarrowhead1
% End of user PostScript
.43438 .67194 m
.43919 .67933 L
s
% Start of user PostScript
-0.714286 1.42857 -0.661929 1.50893 MAarrowhead1
% End of user PostScript
.43438 .73756 m
.44159 .74439 L
s
% Start of user PostScript
-0.714286 2.14286 -0.63575 2.21713 MAarrowhead1
% End of user PostScript
.43438 .80319 m
.444 .80945 L
s
% Start of user PostScript
-0.714286 2.85714 -0.609572 2.92533 MAarrowhead1
% End of user PostScript
.43438 .86881 m
.4464 .87451 L
s
% Start of user PostScript
-0.714286 3.57143 -0.583394 3.63353 MAarrowhead1
% End of user PostScript
.43438 .93443 m
.44881 .93958 L
s
% Start of user PostScript
-0.714286 4.28571 -0.557215 4.34172 MAarrowhead1
% End of user PostScript
.43438 1.00005 m
.45121 1.00464 L
s
% Start of user PostScript
-0.714286 5. -0.531037 5.04992 MAarrowhead1
% End of user PostScript
.5 .08134 m
.48316 .08526 L
s
% Start of user PostScript
0 -5. -0.183249 -4.95738 MAarrowhead1
% End of user PostScript
.5 .14697 m
.48557 .15032 L
s
% Start of user PostScript
0 -4.28571 -0.15707 -4.24919 MAarrowhead1
% End of user PostScript
.5 .21259 m
.48797 .21538 L
s
% Start of user PostScript
0 -3.57143 -0.130892 -3.54099 MAarrowhead1
% End of user PostScript
.5 .27821 m
.49038 .28045 L
s
% Start of user PostScript
0 -2.85714 -0.104714 -2.83279 MAarrowhead1
% End of user PostScript
.5 .34383 m
.49278 .34551 L
s
% Start of user PostScript
0 -2.14286 -0.0785352 -2.12459 MAarrowhead1
% End of user PostScript
.5 .40945 m
.49519 .41057 L
s
% Start of user PostScript
0 -1.42857 -0.0523568 -1.4164 MAarrowhead1
% End of user PostScript
.5 .47508 m
.49759 .47564 L
s
% Start of user PostScript
0 -0.714286 -0.0261784 -0.708198 MAarrowhead1
% End of user PostScript
.5 .5407 m
.5 .5407 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .60632 m
.50241 .60576 L
s
% Start of user PostScript
0 0.714286 0.0261784 0.708198 MAarrowhead1
% End of user PostScript
.5 .67194 m
.50481 .67082 L
s
% Start of user PostScript
0 1.42857 0.0523568 1.4164 MAarrowhead1
% End of user PostScript
.5 .73756 m
.50722 .73589 L
s
% Start of user PostScript
0 2.14286 0.0785352 2.12459 MAarrowhead1
% End of user PostScript
.5 .80319 m
.50962 .80095 L
s
% Start of user PostScript
0 2.85714 0.104714 2.83279 MAarrowhead1
% End of user PostScript
.5 .86881 m
.51203 .86601 L
s
% Start of user PostScript
0 3.57143 0.130892 3.54099 MAarrowhead1
% End of user PostScript
.5 .93443 m
.51443 .93108 L
s
% Start of user PostScript
0 4.28571 0.15707 4.24919 MAarrowhead1
% End of user PostScript
.5 1.00005 m
.51684 .99614 L
s
% Start of user PostScript
0 5. 0.183249 4.95738 MAarrowhead1
% End of user PostScript
.56562 .08134 m
.54879 .07676 L
s
% Start of user PostScript
0.714286 -5. 0.531037 -5.04992 MAarrowhead1
% End of user PostScript
.56562 .14697 m
.55119 .14182 L
s
% Start of user PostScript
0.714286 -4.28571 0.557215 -4.34172 MAarrowhead1
% End of user PostScript
.56562 .21259 m
.5536 .20688 L
s
% Start of user PostScript
0.714286 -3.57143 0.583394 -3.63353 MAarrowhead1
% End of user PostScript
.56562 .27821 m
.556 .27195 L
s
% Start of user PostScript
0.714286 -2.85714 0.609572 -2.92533 MAarrowhead1
% End of user PostScript
.56562 .34383 m
.55841 .33701 L
s
% Start of user PostScript
0.714286 -2.14286 0.63575 -2.21713 MAarrowhead1
% End of user PostScript
.56562 .40945 m
.56081 .40207 L
s
% Start of user PostScript
0.714286 -1.42857 0.661929 -1.50893 MAarrowhead1
% End of user PostScript
.56562 .47508 m
.56322 .46713 L
s
% Start of user PostScript
0.714286 -0.714286 0.688107 -0.800735 MAarrowhead1
% End of user PostScript
.56562 .5407 m
.56562 .5322 L
s
% Start of user PostScript
0.714286 0 0.714286 -0.0925376 MAarrowhead1
% End of user PostScript
.56562 .60632 m
.56803 .59726 L
s
% Start of user PostScript
0.714286 0.714286 0.740464 0.61566 MAarrowhead1
% End of user PostScript
.56562 .67194 m
.57043 .66232 L
s
% Start of user PostScript
0.714286 1.42857 0.766643 1.32386 MAarrowhead1
% End of user PostScript
.56562 .73756 m
.57284 .72739 L
s
% Start of user PostScript
0.714286 2.14286 0.792821 2.03206 MAarrowhead1
% End of user PostScript
.56562 .80319 m
.57524 .79245 L
s
% Start of user PostScript
0.714286 2.85714 0.818999 2.74025 MAarrowhead1
% End of user PostScript
.56562 .86881 m
.57765 .85751 L
s
% Start of user PostScript
0.714286 3.57143 0.845178 3.44845 MAarrowhead1
% End of user PostScript
.56562 .93443 m
.58005 .92257 L
s
% Start of user PostScript
0.714286 4.28571 0.871356 4.15665 MAarrowhead1
% End of user PostScript
.56562 1.00005 m
.58246 .98764 L
s
% Start of user PostScript
0.714286 5. 0.897535 4.86485 MAarrowhead1
% End of user PostScript
.63124 .08134 m
.61441 .06826 L
s
% Start of user PostScript
1.42857 -5. 1.24532 -5.14246 MAarrowhead1
% End of user PostScript
.63124 .14697 m
.61681 .13332 L
s
% Start of user PostScript
1.42857 -4.28571 1.2715 -4.43426 MAarrowhead1
% End of user PostScript
.63124 .21259 m
.61922 .19838 L
s
% Start of user PostScript
1.42857 -3.57143 1.29768 -3.72606 MAarrowhead1
% End of user PostScript
.63124 .27821 m
.62162 .26344 L
s
% Start of user PostScript
1.42857 -2.85714 1.32386 -3.01787 MAarrowhead1
% End of user PostScript
.63124 .34383 m
.62403 .32851 L
s
% Start of user PostScript
1.42857 -2.14286 1.35004 -2.30967 MAarrowhead1
% End of user PostScript
.63124 .40945 m
.62643 .39357 L
s
% Start of user PostScript
1.42857 -1.42857 1.37621 -1.60147 MAarrowhead1
% End of user PostScript
.63124 .47508 m
.62884 .45863 L
s
% Start of user PostScript
1.42857 -0.714286 1.40239 -0.893273 MAarrowhead1
% End of user PostScript
.63124 .5407 m
.63124 .5237 L
s
% Start of user PostScript
1.42857 0 1.42857 -0.185075 MAarrowhead1
% End of user PostScript
.63124 .60632 m
.63365 .58876 L
s
% Start of user PostScript
1.42857 0.714286 1.45475 0.523122 MAarrowhead1
% End of user PostScript
.63124 .67194 m
.63605 .65382 L
s
% Start of user PostScript
1.42857 1.42857 1.48093 1.23132 MAarrowhead1
% End of user PostScript
.63124 .73756 m
.63846 .71888 L
s
% Start of user PostScript
1.42857 2.14286 1.50711 1.93952 MAarrowhead1
% End of user PostScript
.63124 .80319 m
.64086 .78395 L
s
% Start of user PostScript
1.42857 2.85714 1.53329 2.64772 MAarrowhead1
% End of user PostScript
.63124 .86881 m
.64327 .84901 L
s
% Start of user PostScript
1.42857 3.57143 1.55946 3.35591 MAarrowhead1
% End of user PostScript
.63124 .93443 m
.64567 .91407 L
s
% Start of user PostScript
1.42857 4.28571 1.58564 4.06411 MAarrowhead1
% End of user PostScript
.63124 1.00005 m
.64808 .97914 L
s
% Start of user PostScript
1.42857 5. 1.61182 4.77231 MAarrowhead1
% End of user PostScript
.69687 .08134 m
.68003 .05975 L
s
% Start of user PostScript
2.14286 -5. 1.95961 -5.235 MAarrowhead1
% End of user PostScript
.69687 .14697 m
.68244 .12482 L
s
% Start of user PostScript
2.14286 -4.28571 1.98579 -4.5268 MAarrowhead1
% End of user PostScript
.69687 .21259 m
.68484 .18988 L
s
% Start of user PostScript
2.14286 -3.57143 2.01197 -3.8186 MAarrowhead1
% End of user PostScript
.69687 .27821 m
.68725 .25494 L
s
% Start of user PostScript
2.14286 -2.85714 2.03814 -3.1104 MAarrowhead1
% End of user PostScript
.69687 .34383 m
.68965 .32001 L
s
% Start of user PostScript
2.14286 -2.14286 2.06432 -2.40221 MAarrowhead1
% End of user PostScript
.69687 .40945 m
.69206 .38507 L
s
% Start of user PostScript
2.14286 -1.42857 2.0905 -1.69401 MAarrowhead1
% End of user PostScript
.69687 .47508 m
.69446 .45013 L
s
% Start of user PostScript
2.14286 -0.714286 2.11668 -0.985811 MAarrowhead1
% End of user PostScript
.69687 .5407 m
.69687 .51519 L
s
% Start of user PostScript
2.14286 0 2.14286 -0.277613 MAarrowhead1
% End of user PostScript
.69687 .60632 m
.69927 .58026 L
s
% Start of user PostScript
2.14286 0.714286 2.16904 0.430585 MAarrowhead1
% End of user PostScript
.69687 .67194 m
.70168 .64532 L
s
% Start of user PostScript
2.14286 1.42857 2.19521 1.13878 MAarrowhead1
% End of user PostScript
.69687 .73756 m
.70408 .71038 L
s
% Start of user PostScript
2.14286 2.14286 2.22139 1.84698 MAarrowhead1
% End of user PostScript
.69687 .80319 m
.70649 .77545 L
s
% Start of user PostScript
2.14286 2.85714 2.24757 2.55518 MAarrowhead1
% End of user PostScript
.69687 .86881 m
.70889 .84051 L
s
% Start of user PostScript
2.14286 3.57143 2.27375 3.26338 MAarrowhead1
% End of user PostScript
.69687 .93443 m
.7113 .90557 L
s
% Start of user PostScript
2.14286 4.28571 2.29993 3.97157 MAarrowhead1
% End of user PostScript
.69687 1.00005 m
.7137 .97063 L
s
% Start of user PostScript
2.14286 5. 2.32611 4.67977 MAarrowhead1
% End of user PostScript
.76249 .08134 m
.74565 .05125 L
s
% Start of user PostScript
2.85714 -5. 2.67389 -5.32753 MAarrowhead1
% End of user PostScript
.76249 .14697 m
.74806 .11631 L
s
% Start of user PostScript
2.85714 -4.28571 2.70007 -4.61934 MAarrowhead1
% End of user PostScript
.76249 .21259 m
.75046 .18138 L
s
% Start of user PostScript
2.85714 -3.57143 2.72625 -3.91114 MAarrowhead1
% End of user PostScript
.76249 .27821 m
.75287 .24644 L
s
% Start of user PostScript
2.85714 -2.85714 2.75243 -3.20294 MAarrowhead1
% End of user PostScript
.76249 .34383 m
.75527 .3115 L
s
% Start of user PostScript
2.85714 -2.14286 2.77861 -2.49474 MAarrowhead1
% End of user PostScript
.76249 .40945 m
.75768 .37657 L
s
% Start of user PostScript
2.85714 -1.42857 2.80479 -1.78655 MAarrowhead1
% End of user PostScript
.76249 .47508 m
.76008 .44163 L
s
% Start of user PostScript
2.85714 -0.714286 2.83096 -1.07835 MAarrowhead1
% End of user PostScript
.76249 .5407 m
.76249 .50669 L
s
% Start of user PostScript
2.85714 0 2.85714 -0.370151 MAarrowhead1
% End of user PostScript
.76249 .60632 m
.76489 .57176 L
s
% Start of user PostScript
2.85714 0.714286 2.88332 0.338047 MAarrowhead1
% End of user PostScript
.76249 .67194 m
.7673 .63682 L
s
% Start of user PostScript
2.85714 1.42857 2.9095 1.04624 MAarrowhead1
% End of user PostScript
.76249 .73756 m
.7697 .70188 L
s
% Start of user PostScript
2.85714 2.14286 2.93568 1.75444 MAarrowhead1
% End of user PostScript
.76249 .80319 m
.77211 .76694 L
s
% Start of user PostScript
2.85714 2.85714 2.96186 2.46264 MAarrowhead1
% End of user PostScript
.76249 .86881 m
.77451 .83201 L
s
% Start of user PostScript
2.85714 3.57143 2.98803 3.17084 MAarrowhead1
% End of user PostScript
.76249 .93443 m
.77692 .89707 L
s
% Start of user PostScript
2.85714 4.28571 3.01421 3.87904 MAarrowhead1
% End of user PostScript
.76249 1.00005 m
.77932 .96213 L
s
% Start of user PostScript
2.85714 5. 3.04039 4.58723 MAarrowhead1
% End of user PostScript
.82811 .08134 m
.81128 .04275 L
s
% Start of user PostScript
3.57143 -5. 3.38818 -5.42007 MAarrowhead1
% End of user PostScript
.82811 .14697 m
.81368 .10781 L
s
% Start of user PostScript
3.57143 -4.28571 3.41436 -4.71187 MAarrowhead1
% End of user PostScript
.82811 .21259 m
.81609 .17288 L
s
% Start of user PostScript
3.57143 -3.57143 3.44054 -4.00368 MAarrowhead1
% End of user PostScript
.82811 .27821 m
.81849 .23794 L
s
% Start of user PostScript
3.57143 -2.85714 3.46671 -3.29548 MAarrowhead1
% End of user PostScript
.82811 .34383 m
.8209 .303 L
s
% Start of user PostScript
3.57143 -2.14286 3.49289 -2.58728 MAarrowhead1
% End of user PostScript
.82811 .40945 m
.8233 .36806 L
s
% Start of user PostScript
3.57143 -1.42857 3.51907 -1.87908 MAarrowhead1
% End of user PostScript
.82811 .47508 m
.82571 .43313 L
s
% Start of user PostScript
3.57143 -0.714286 3.54525 -1.17089 MAarrowhead1
% End of user PostScript
.82811 .5407 m
.82811 .49819 L
s
% Start of user PostScript
3.57143 0 3.57143 -0.462688 MAarrowhead1
% End of user PostScript
.82811 .60632 m
.83052 .56325 L
s
% Start of user PostScript
3.57143 0.714286 3.59761 0.245509 MAarrowhead1
% End of user PostScript
.82811 .67194 m
.83292 .62832 L
s
% Start of user PostScript
3.57143 1.42857 3.62379 0.953707 MAarrowhead1
% End of user PostScript
.82811 .73756 m
.83533 .69338 L
s
% Start of user PostScript
3.57143 2.14286 3.64996 1.6619 MAarrowhead1
% End of user PostScript
.82811 .80319 m
.83773 .75844 L
s
% Start of user PostScript
3.57143 2.85714 3.67614 2.3701 MAarrowhead1
% End of user PostScript
.82811 .86881 m
.84014 .8235 L
s
% Start of user PostScript
3.57143 3.57143 3.70232 3.0783 MAarrowhead1
% End of user PostScript
.82811 .93443 m
.84254 .88857 L
s
% Start of user PostScript
3.57143 4.28571 3.7285 3.7865 MAarrowhead1
% End of user PostScript
.82811 1.00005 m
.84495 .95363 L
s
% Start of user PostScript
3.57143 5. 3.75468 4.4947 MAarrowhead1
% End of user PostScript
.89373 .08134 m
.8769 .03425 L
s
% Start of user PostScript
4.28571 -5. 4.10247 -5.51261 MAarrowhead1
% End of user PostScript
.89373 .14697 m
.8793 .09931 L
s
% Start of user PostScript
4.28571 -4.28571 4.12864 -4.80441 MAarrowhead1
% End of user PostScript
.89373 .21259 m
.88171 .16437 L
s
% Start of user PostScript
4.28571 -3.57143 4.15482 -4.09621 MAarrowhead1
% End of user PostScript
.89373 .27821 m
.88411 .22944 L
s
% Start of user PostScript
4.28571 -2.85714 4.181 -3.38802 MAarrowhead1
% End of user PostScript
.89373 .34383 m
.88652 .2945 L
s
% Start of user PostScript
4.28571 -2.14286 4.20718 -2.67982 MAarrowhead1
% End of user PostScript
.89373 .40945 m
.88892 .35956 L
s
% Start of user PostScript
4.28571 -1.42857 4.23336 -1.97162 MAarrowhead1
% End of user PostScript
.89373 .47508 m
.89133 .42463 L
s
% Start of user PostScript
4.28571 -0.714286 4.25954 -1.26342 MAarrowhead1
% End of user PostScript
.89373 .5407 m
.89373 .48969 L
s
% Start of user PostScript
4.28571 0 4.28571 -0.555226 MAarrowhead1
% End of user PostScript
.89373 .60632 m
.89614 .55475 L
s
% Start of user PostScript
4.28571 0.714286 4.31189 0.152972 MAarrowhead1
% End of user PostScript
.89373 .67194 m
.89854 .61981 L
s
% Start of user PostScript
4.28571 1.42857 4.33807 0.86117 MAarrowhead1
% End of user PostScript
.89373 .73756 m
.90095 .68488 L
s
% Start of user PostScript
4.28571 2.14286 4.36425 1.56937 MAarrowhead1
% End of user PostScript
.89373 .80319 m
.90335 .74994 L
s
% Start of user PostScript
4.28571 2.85714 4.39043 2.27756 MAarrowhead1
% End of user PostScript
.89373 .86881 m
.90576 .815 L
s
% Start of user PostScript
4.28571 3.57143 4.41661 2.98576 MAarrowhead1
% End of user PostScript
.89373 .93443 m
.90816 .88007 L
s
% Start of user PostScript
4.28571 4.28571 4.44278 3.69396 MAarrowhead1
% End of user PostScript
.89373 1.00005 m
.91057 .94513 L
s
% Start of user PostScript
4.28571 5. 4.46896 4.40216 MAarrowhead1
% End of user PostScript
.95936 .08134 m
.94252 .02575 L
s
% Start of user PostScript
5. -5. 4.81675 -5.60515 MAarrowhead1
% End of user PostScript
.95936 .14697 m
.94492 .09081 L
s
% Start of user PostScript
5. -4.28571 4.84293 -4.89695 MAarrowhead1
% End of user PostScript
.95936 .21259 m
.94733 .15587 L
s
% Start of user PostScript
5. -3.57143 4.86911 -4.18875 MAarrowhead1
% End of user PostScript
.95936 .27821 m
.94974 .22094 L
s
% Start of user PostScript
5. -2.85714 4.89529 -3.48055 MAarrowhead1
% End of user PostScript
.95936 .34383 m
.95214 .286 L
s
% Start of user PostScript
5. -2.14286 4.92146 -2.77236 MAarrowhead1
% End of user PostScript
.95936 .40945 m
.95455 .35106 L
s
% Start of user PostScript
5. -1.42857 4.94764 -2.06416 MAarrowhead1
% End of user PostScript
.95936 .47508 m
.95695 .41612 L
s
% Start of user PostScript
5. -0.714286 4.97382 -1.35596 MAarrowhead1
% End of user PostScript
.95936 .5407 m
.95936 .48119 L
s
% Start of user PostScript
5. 0 5. -0.647764 MAarrowhead1
% End of user PostScript
.95936 .60632 m
.96176 .54625 L
s
% Start of user PostScript
5. 0.714286 5.02618 0.0604342 MAarrowhead1
% End of user PostScript
.95936 .67194 m
.96417 .61131 L
s
% Start of user PostScript
5. 1.42857 5.05236 0.768632 MAarrowhead1
% End of user PostScript
.95936 .73756 m
.96657 .67638 L
s
% Start of user PostScript
5. 2.14286 5.07854 1.47683 MAarrowhead1
% End of user PostScript
.95936 .80319 m
.96898 .74144 L
s
% Start of user PostScript
5. 2.85714 5.10471 2.18503 MAarrowhead1
% End of user PostScript
.95936 .86881 m
.97138 .8065 L
s
% Start of user PostScript
5. 3.57143 5.13089 2.89323 MAarrowhead1
% End of user PostScript
.95936 .93443 m
.97379 .87156 L
s
% Start of user PostScript
5. 4.28571 5.15707 3.60142 MAarrowhead1
% End of user PostScript
.95936 1.00005 m
.97619 .93663 L
s
% Start of user PostScript
5. 5. 5.18325 4.30962 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1.0814 L
0 1.0814 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[257]:=",
  ImageSize->{166.875, 180.438},
  ImageMargins->{{0.75, 0}, {0, 2.25}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003@0000hB000`400?l00000o`00003oIoooool0
0ol0003oooooooooo`1Vooooo`00Ioooool00ol0003oooooooooo`1Vooooo`00Ioooool00ol0003o
ooooooooo`1Vooooo`00Ioooool00ol0003oooooooooo`1Vooooo`00Ioooool00ol0003ooooooooo
o`1Vooooo`00Ioooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00[ooooo001Woooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool02_ooool006Oooooo0_l0001=ooooo`03
o`000?oooooooooo00[ooooo0_l0000;ooooo`00Ioooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo00[ooooo0_l0000;ooooo`00Ioooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00_ooooo0_l0000;ooooo`?o00002_ooool006Oooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0;ooooo`;o00002oooool00ol0003oooooo`00000:ooooo`00Ioooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`?o00003?ooool00ol0
003oooooooooo`08ooooo`00Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[o
oooo0_l0000=ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo001Wooooo`03o`000?oooooooooo02?ooooo0_l0000;ooooo`?o00003?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool006Oooooo00?o
0000ooooooooool05Oooool2o`0000cooooo0ol0000;ooooo`?o00003?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool006Oooooo00?o0000
ooooooooool05Oooool4o`0000_ooooo0ol0000:ooooo`;o00003Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool005Wooooo00?o0000oooo
ooooool02oooool2o`0000Sooooo1_l00009ooooo`Co00002_ooool2o`0000gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooo000000_ooooo0ol0000:ooooo`Co00002_ooool4o`0000[ooooo0ol0000<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`?o00002_ooool4o`0000Wooooo1Ol0000<ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0Boooool000Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool2o`0000cooooo0ol00009ooooo`;o00003oooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo00Wooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo0ol0000:ooooo`;o00007?ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Wooooo0007ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`?o00002oooool2o`00
00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
00_ooooo0_l0000:ooooo`001oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo0ol0000;ooooo`?o00002_ooool2o`0002[ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l0000:ooooo`001_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Wooooo0ol0000;ooooo`;o00002oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02oooool2o`0000cooooo
0ol00009ooooo`001_ooool00ol0003oooooooooo`09ooooo`?o00002oooool3o`0000[ooooo0_l0
000hooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02_ooool2o`0000cooooo0ol0
000<ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00Wooooo0ol0000;
ooooo`;o00002oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool02oooool2o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo00Sooooo0005oooo
o`?o00002_ooool3o`0000_ooooo0_l00015ooooo`;o00009?ooool00ol0003oooooooooo`0;oooo
o`;o00003?ooool3o`0000_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07oooo
o`001Oooool3o`0000[ooooo0_l0000<ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool08oooool2o`0000gooooo0_l0000;ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo0005ooooo`;o00002oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo01Kooooo0_l0000<ooooo`;o00003?ooool2o`0000cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo0004ooooo`;o0000HOoo
ool2o`0000Wooooo0ol0000;ooooo`?o00002oooool3o`0000cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool000Cooooo00?o0000ooooooooool0D_ooool2o`0000[ooooo1?l0000:ooooo`Co00002_ooool3
o`0000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`?o00002?ooool6o`00
00[ooooo0ol0000;ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0ol0000<ooooo`;o00002oooool2o`0000go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Wo
oooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Wooooo0ol0000;ooooo`;o00002oooool00ol0003ooooo
ooooo`06ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooooooo00Wooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`?o00002oooool3o`0000_ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool02_oo
ool2o`0000[ooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`?o00002_ooool3o`0000_ooooo00?o0000ooooooooool02_ooool6
o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool02_ooool2
o`0000[ooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`00
00_ooooo0ol0000:ooooo`;o00008Oooool01?m4A4CogMgMooooool00005ooooo`?o0000?oooool0
0ol0003oooooooooo`0;ooooo`;o00002oooool3o`0000Wooooo0007ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool3o`0000_ooooo0_l0000;ooooo`03o`000?oooooooooo
023ooooo00CogMgMoeEEEOoooooo00001Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00_ooooo0_l0000;ooooo`;o00002_ooool000Kooooo00?o0000ooooooooool02_ooool3o`00
00[ooooo0_l0000<ooooo`03o`000?oooooooooo02kooooo00?oMgMgolc<c?l000001Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`?o00002oooool00ol0
003oooooooooo`08ooooo`001Oooool2o`0000cooooo0ol0000:ooooo`;o0000?Oooool00oo^k^ko
A4A4o`000005ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool2o`0000co
oooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool000Gooooo
0ol0000;ooooo`;o00002oooool00ol0003oooooooooo`0mooooo`03ogMgMol0003ooooo00Cooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`?o00002oooool3o`0000cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`001Oooool3o`0000_ooooo0_l0
001Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool2o`0000cooooo0ol0
000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`001Oooool2o`0000cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0F
ooooo`;o00003Oooool00ol0003oooooooooo`0:ooooo`;o00003?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool000Gooooo0_l0001Boooo
o`;o00003?ooool3o`0000Sooooo1?l0000;ooooo`;o00003?ooool2o`0000cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool000Gooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`;o00003?ooool3o`0000[ooooo1?l0000:ooooo`Co00002Oooool3o`0000_ooooo0_l0000=oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool3o`0000[ooooo0_l0000;ooooo`Go00002oooool3o`0000[ooooo00?o0000oooooooo
ool0Boooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`;o0000
2_ooool00ol0003oooooooooo`0=ooooo`;o00003Oooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo00Sooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`;o00006ooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Sooooo0007ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`?o00002oooool2
o`0000_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02?ooool000Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`09ooooo`;o00003?ooool3o`0000[ooooo0_l0000Yooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`?o00002Oooool000Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`?o00002oooool2o`0000_o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_o
oooo0_l0000;ooooo`?o00002Oooool000Kooooo00?o0000ooooooooool02_ooool2o`0000cooooo
0ol0000:ooooo`;o0000=oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00[ooooo
0_l0000<ooooo`;o00003Oooool00ol0003oooooooooo`07ooooo`001_ooool00ol0003ooooooooo
o`0:ooooo`?o00002oooool2o`0000_ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`?o00003?ooool00ol0003ooooooooo
o`07ooooo`001Oooool3o`0000_ooooo0ol0000;ooooo`;o0000A?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`?o00003?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo0005ooooo`?o00002oooool2o`0000cooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Tooooo`;o00003?ooool2o`0000_ooooo0_l0000=oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool000Gooooo0_l0000<ooooo`03
o`000?oooooooooo057ooooo0_l0000Hooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`?o
00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01oooool000Gooooo0_l0001Cooooo`03o`000?oooooooooo00[ooooo0ol00009ooooo`;o0000
3?ooool2o`0000cooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0005ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool02Oooool4o`0000Wooooo1?l0000:ooooo`?o00002ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool2o`0000cooooo0ol00009ooooo`Ko00002Oooool4
o`0000[ooooo0ol0000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool0
00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02Oooool2o`0000cooooo0ol0000;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool3o`0000[ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`08ooooo`002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`?o00002oooool2o`0000_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool02?ooool000Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`?o00002_ooool2o`0001_ooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0:ooooo`;o00002Oooool000Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo0ol0
000:ooooo`?o00002oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool02_ooool2o`0000Wooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02Oooool3o`0000_ooooo0ol0000:ooooo`;o0000:Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool3o`0000Sooooo0007oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool3o`0000_ooooo0_l0000;oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0:oooo
o`?o00002oooool2o`0000Wooooo0007ooooo`03o`000?oooooooooo00Wooooo0ol0000;ooooo`;o
00003?ooool00ol0003oooooooooo`0eooooo`;o0000<oooool00ol0003oooooooooo`0;ooooo`;o
00002oooool3o`0000cooooo00?o0000ooooooooool01oooool000Kooooo0_l0000;ooooo`?o0000
2oooool2o`0004Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo0_l0000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool000Kooooo0ol0000:ooooo`?o00002oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool02_ooool2o`0000cooooo0ol0000<ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01oooool000Kooooo0ol0000;ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`;o00002oooool2
o`0000gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Oooooo0006ooooo`;o00003?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool02oooool2o`0000_ooooo0ol0000<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`001_ooool2o`0005;o
oooo00?o0000ooooooooool02_ooool01?l0003oooooo`000?l00008ooooo`;o00003?ooool2o`00
00cooooo0ol0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0006ooooo`03o`000?oooooo000000go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool2o`0000gooooo0_l0000;ooooo`Co00002?ooool4o`0000_o
oooo0_l0000;ooooo`;o00003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`03o`000?oooooooooo00;ooooo
1Ol00003ooooo`Go00002Oooool4o`0000[ooooo0ol0001;ooooo`002?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`09ooooo`?o00002oooool3o`0000[ooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^
k_ooooooA4A400Cooooo00?o0000ooooooooool02oooool3o`0004kooooo00?o0000ooooooooool0
1oooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool3o`0000_ooooo0_l00009ooooo`Ko00000ooo
ool00onHV9So8B4Qonk^kP05ooooo`?o00003?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo00Oooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`09ooooo`?o00002oooool2o`0000cooooo00?o0000ooooooooool04_ooool0
0onHV9So8B4Qonk^kP04ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`07ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Wooooo0ol0000;ooooo`?o00002oooool2o`0002;ooooo00?oMgMgofIVI_ooool00oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool3o`00
00Sooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool3o`0000_o
oooo0_l0000<ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool3o`0000So
oooo0007ooooo`03o`000?oooooooooo00[ooooo0ol0000:ooooo`?o00002oooool2o`0002gooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool02_ooool2o`0000_ooooo0ol0000<ooooo`03o`000?oooooooooo00Oooooo0007ooooo`03o`00
0?oooooooooo00[ooooo0ol0000;ooooo`;o00002oooool00ol0003oooooooooo`0/ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00[o
oooo0_l0000;ooooo`?o00003?ooool00ol0003oooooooooo`07ooooo`001_ooool3o`0000_ooooo
0_l0000<ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01_ooool000Kooooo0ol0000;ooooo`;o00003?ooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool3o`0000_ooooo0_l0
000=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool000Kooooo0_l0000<
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:
ooooo`;o00002oooool3o`0000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo0006ooooo`;o0000D_ooool00ol0003oooooooooo`0:oooo
o`04o`000?oooooo0000o`0000Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`;o00003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`001_ooool00ol0003oooooooooo`1Aoooo
o`;o00002oooool4o`0000Wooooo0_l0000<ooooo`;o00002oooool3o`0000cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`?o
00003?ooool2o`0000[ooooo1_l00008ooooo`?o00002oooool3o`0000_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`;o0000
3?ooool3o`0000_ooooo0_l0000<ooooo`03o`000?oooooooooo00;o00002Oooool3o`0000[ooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`09ooooo`?o00002oooool2o`0000cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`;o0000Coooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool3o`0000_ooooo0ol0000;
ooooo`;o00006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool3o`0000_ooooo0_l0000<oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`09oooo
o`?o00002?ooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`?o
00002_ooool3o`0000_ooooo0_l0000Xooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`09ooooo`?o00002?ooool000Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`?o00002oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0:ooooo`?o0000
2_ooool3o`0000Sooooo0007ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`;o00003?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`?o00002oooool00ol0003oooooooooo`07ooooo`001_ooool2
o`0000cooooo0ol0000;ooooo`;o0000@oooool2o`0002Oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`?o00003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo0006ooooo`?o00002oooool3o`0000_ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`?o00003?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0006ooooo`?o00003?ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01_ooool000Oooooo0_l0000<ooooo`03o`000?oooooooooo047ooooo
0_l0000<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool3o`0000_ooooo
0ol0000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`06ooooo`001oooool00ol0003oooooooooo`1?ooooo`?o00002oooool00ol0003ooooooooo
o`02o`0000Sooooo00?o0000ooooooooool02oooool2o`0000_ooooo0ol0000<ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo0007ooooo`03o`000?oooooooooo047ooooo0ol0000;ooooo`?o00002oooool5
o`0000Sooooo00?o0000ooooooooool02oooool2o`0000_ooooo0ol0000<ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool3o`00
00_ooooo0_l0000<ooooo`Go00002?ooool2o`0000cooooo0ol0000;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool3o`0000_o
oooo0ol0000;ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`;o00002oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01Oooool2o`000004oa0@4?ooooooooooo`0000gooooo00?o0000oooooooo
ool02Oooool3o`0000;ooooo1Ol00005ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`?o00004_ooool5o`0002Cooooo0_l000000ol@413o
ooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000cooooo0ol0000:ooooo`?o
00000_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Pooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000oooo
ooooool02Oooool6o`0000;ooooo1Ol000000ooooooo0000o`00000<ooooo`?o00001oooool6o`00
00?ooooo00?oV9RHob4Q8Oo^k^h08Oooool2o`0002;ooooo00?oV9RHob4Q8Oo^k^h07Oooool00ol0
003oooooooooo`03ooooo`Go00000oooool00ol0003oooooooooo`0:ooooo`?o00001oooool000So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`04odA4A?oMgMgoooooo`00
00;ooooo0ol0000;ooooo`;o00003?ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^
023ooooo00?o0000ooooooooool08_ooool00onHV9So8B4Qonk^kP0Looooo`03o`000?oooooooooo
00?ooooo00CoA4A4omgMgOoooooo00001?ooool00ol0003oooooooooo`0:ooooo`?o00001oooool0
00Sooooo00?o0000ooooooooool02Oooool3o`0000Gooooo00CogMgMoeEEEOoooooo00000_ooool3
o`0000_ooooo0_l0000Cooooo`03ogMgMomVIVKooooo01oooooo00?o0000ooooooooool08oooool0
0omgMgOoIVIVooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool0
1?oMgMgoEEEEooooool00003ooooo`?o00003?ooool00ol0003oooooooooo`06ooooo`001oooool0
0ol0003oooooooooo`0:ooooo`?o00001_ooool00omgMgOoc<c<o`000003ooooo`;o00002oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo0ol00005ooooo`03ogMgMoo<c<co
000000?ooooo0ol0000<ooooo`03o`000?oooooooooo00Kooooo0007ooooo`?o00002_ooool3o`00
00Kooooo00?ok^k^odA4A?l000000oooool00ol0003oooooooooo`0Looooo`05o`000?nj^[[ooooo
oiRHV?l@41008?ooool00ol0003oooooooooo`0Pooooo`07o`000?nj^[[ooooooiRHV?l@413ooooo
o`00000=ooooo`03o`000?oooooooooo00Wooooo0ol00005ooooo`03onk^k_m4A4Co000000Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`001oooool3o`0000_ooooo00?o
0000ooooooooool01_ooool00omgMgOo0000ooooo`02ooooo`03o`000?oooooooooo01cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Pooooo`03o`000?oooooooooo023ooooo00OoV9RHoa0@4?l0003o
8B4Qolc<c?oooooo000000cooooo0ol0000:ooooo`?o00001_ooool00omgMgOo0000ooooo`03oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool000Oooooo0_l0000<ooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo0ol0000;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`001oooool2o`00053ooooo0ol0000;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`?o0000
3?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`1?ooooo`?o00002ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`?o00003?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`06ooooo`00d?l0000000Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`000008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00_ooool3
o`000003ooooool0003ooooo00Sooooo0ol00006ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ol0
0003ooooo`03o`000?oooooooooo00Cooooo1?l00008ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0008
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool3o`000003ooooool0003o
oooo00Sooooo0ol0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool3
o`0001Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Kooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`?o00002_ooool3o`0000cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0:ooooo`?o0000@oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Kooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`?o00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`09ooooo`?o00001oooool000Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`?o00002oooool3o`0000_ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00[ooooo
0_l0000;ooooo`?o00001oooool000Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`09ooooo`?o00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`0:ooooo`;o00002oooool3o`0000Oooooo0008
ooooo`03o`000?oooooooooo00Wooooo1?l0000:ooooo`?o00003?ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09
ooooo`?o00003?ooool00ol0003oooooooooo`06ooooo`001oooool3o`0000[ooooo1?l0000;oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00[ooooo0ol0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool000Oooooo0ol0000;ooooo`?o00002oooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`?o
00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0007ooooo`?o0000
2oooool2o`00053ooooo0_l0000Jooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`?o0000
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1_ooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`10ooooo`;o00003?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`?o00002ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_oo
ool000Sooooo00?o0000ooooooooool0COooool3o`0000cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`;o00003?ooool2o`0000cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool0
00Sooooo00?o0000ooooooooool0@?ooool3o`0000[ooooo0ol00009ooooo`Co00003Oooool00ol0
003oooooooooo`0:ooooo`;o00002oooool3o`0000cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool000So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`?o00002oooool2o`0000Wo
oooo1Ol0000;ooooo`;o00002oooool3o`0000cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`06ooooo`002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`Co00002oooool2o`0000_ooooo
0_l00009ooooo`;o000000?oooooo`000?ooool02oooool2o`0000gooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`Co00002ooo
ool2o`0000cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`?o0000D_oo
ool00ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool3o`0000_ooooo0ol0000<ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0:ooooo`;o00001oooool0
00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`;o00002oooool3o`00
00_ooooo0_l0000Wooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0:ooooo`;o00001oooool000Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`09ooooo`?o00002oooool3o`0000cooooo00?o0000ooooooooool09Oooool2o`0004?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`?o00001oooool000Sooooo
00?o0000ooooooooool02_ooool3o`0000[ooooo0ol0000<ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
0ol0000<ooooo`03o`000?oooooooooo00Gooooo0008ooooo`03o`000?oooooooooo00[ooooo0ol0
000;ooooo`;o00003?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool02Oooool3o`0000_ooooo0ol0000<ooooo`03o`000?oooooooooo00Gooooo0007
ooooo`?o00002oooool3o`0000_ooooo0_l00012ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool02_ooool2o`0000_ooooo0ol0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01_ooool000Oooooo0ol0000<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo0_l0000;oooo
o`03o`000?oooooo000000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06oooo
o`001oooool3o`0000cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Wooooo0_l0000;ooooo`?o00002oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2_ooool2o`0000_ooooo0_l0000<ooooo`;o00002oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool0COoo
ool2o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`?o00002_oo
ool3o`0000cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`?o00002oooool2o`0000Wooooo1Ol0000<ooooo`;o00002_ooool3
o`0000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0:ooooo`?o00002_ooool3o`0000cooooo00?o0000ooooooooool01oooool4o`00
00cooooo0_l0000=ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01Oooool000So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool3o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_l0000:ooooo`?o0000D_ooool00ol0003oooooooooo`05ooooo`00
2?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool3o`0000_ooooo0ol0000;ooooo`;o00006Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`002?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool3o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`09ooooo`?o00001_ooool000Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`?o00002oooool2o`0000cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`?o00001_ooool0
00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`?o00002oooool2o`00
00cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
00[ooooo0_l0000<ooooo`;o00001_ooool000Wooooo00?o0000ooooooooool02Oooool3o`0000_o
oooo0ol0000<ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0:ooooo`;o00002oooool3o`0000cooooo00?o0000ooooooooool01Oooool000Wooooo
0_l0000:ooooo`?o00003?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`;o00003?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Kooooo0008ooooo`?o00002oooool2o`0000cooooo00?o
0000ooooooooool0=oooool5o`0000Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`09ooooo`;o00002oooool3o`0000cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`002?ooool3o`0000_ooooo0_l00016ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`;o00003?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool000Sooooo0_l0000=ooooo`03o`000?oooooooooo04Gooooo00?oV9RHob4Q8Oo^k^h01Oooool3
o`0001[ooooo00?o0000ooooooooool02_ooool2o`0000[ooooo0ol0000<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`002Oooool00ol0
003oooooooooo`1<ooooo`;o00001_ooool00onHV9So8B4Qonk^kP04ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool2o`0000_ooooo0ol0000;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo0009ooooo`03o`000?oooooooooo043ooooo0_l00009ooooo`?o00001oooool00omgMgOo
IVIVooooo`03ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooool000002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`;o00001oooool00ol0003ooooo
o`000005o`0000[ooooo0ol0000;ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`;o00003?oo
ool02_l0003ooooooooooooooooo0000okZj^_ooooooV9RHoa0@4?ooool4o`0000_ooooo0ol0001C
ooooo`03o`000?oooooooooo00Cooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0ol0000<oooo
o`;o00003?ooool02?l0003ooooooooooonHV9So410@o`000?lQ8B7oc<c<0_ooool00ol0003ooooo
o`00000=ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool01?ooool000Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo0ol0
000<ooooo`;o00003Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool02_ooool2o`0000Kooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool2o`0000[ooooo0ol0000<ooooo`;o00009_ooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0008oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool3o`0000_ooooo0_l0000=oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0:oooo
o`;o00002oooool3o`0000Kooooo0008ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`?o
00002oooool2o`0003Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`;o
00003?ooool2o`0000cooooo00?o0000ooooooooool01Oooool000Wooooo00?o0000ooooooooool0
2Oooool3o`0000cooooo0_l0000<ooooo`03o`000?oooooooooo03;ooooo0_l0000gooooo`03o`00
0?oooooooooo00Wooooo0ol0000:ooooo`?o00003?ooool00ol0003oooooooooo`05ooooo`002?oo
ool3o`0000_ooooo0_l0000<ooooo`;o0000@Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00[ooooo0_l0000:ooooo`Co00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Gooooo0008ooooo`?o00002oooool2o`0000gooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`03o`000?oooooo
000000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`002?ooool3o`00
00cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Wooooo0_l0000;ooooo`?o00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01Oooool000Wooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0Jooooo`;o00002oooool2o`0000cooooo0_l0000;ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`002Oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool2o`0000_ooooo
0ol0000:ooooo`?o00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`00C?ooool2o`0000_ooooo0_l0
000:ooooo`Go00002_ooool4o`0000[ooooo0ol0000;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool3o`0000[ooooo0ol0000:
ooooo`Co00002Oooool3o`0000_ooooo1?l0000<ooooo`;o00002oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooo000000Kooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0ol0000;oooo
o`;o00003Oooool2o`0000Sooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo00Cooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0<ooooo`;o00002_ooool3o`0000cooooo0_l0000Hooooo`;o
0000Doooool00ol0003oooooooooo`09ooooo`;o00001_ooool000Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`;o0000
3Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
2Oooool2o`0000Kooooo0009ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Ooo
ool3o`0000_ooooo0ol0000;ooooo`;o00009_ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo00[ooooo0_l0000:ooooo`?o00001_ooool000Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`09ooooo`?o00003?ooool2o`0000cooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`;o00001_ooool0
00Wooooo00?o0000ooooooooool02_ooool3o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0:ooooo`;o00002oooool3o`00
00_ooooo00?o0000ooooooooool01Oooool000Wooooo0_l0000;ooooo`?o00002oooool2o`00047o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool000Sooooo
0ol0000<ooooo`;o00003?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool02Oooool2o`0000_ooooo0ol0000;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01Oooool000Sooooo0ol0000<ooooo`;o0000C_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`?o00002oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool000Wooooo0_l0000=
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool06_ooool2o`0000_ooooo0_l0000<
ooooo`;o00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool000Wooooo0_l0001Looooo`03o`000?oooooooooo00cooooo0_l0000;oooo
o`?o00002_ooool3o`0000cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool000[ooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`?o
00002_ooool3o`0000cooooo0_l0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool2o`0000_ooooo0_l0000:ooooo`Ko0000
2Oooool3o`0000cooooo0_l0000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1_ooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool3o`0000[ooooo1?l00009ooooo`Co00002Ooo
ool4o`0000_ooooo0ol0001Cooooo`03o`000?oooooooooo00?ooooo0008ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo0ol0000<ooooo`;o00003?ooool2o`0000Wooooo0_l0000=ooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool00oooool000Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`;o00003_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02_ooool2o`00
00Gooooo0009ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool2o`0000_o
oooo0ol0000<ooooo`;o00009Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool2o`0000Gooooo0009ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02Oooool3o`0000cooooo0_l0000=ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0:ooooo`;o00002oooool3o`0000Gooooo
0009ooooo`03o`000?oooooooooo00_ooooo0_l0000:ooooo`?o00003?ooool2o`0002cooooo0_l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02Ooo
ool2o`0000_ooooo0ol0000<ooooo`03o`000?oooooooooo00Cooooo0009ooooo`03o`000?oooooo
oooo00[ooooo0ol0000;ooooo`?o00003?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o00003?ooool2
o`0000cooooo00?o0000ooooooooool01?ooool000Wooooo0ol0000:ooooo`?o00003?ooool2o`00
03Oooooo1Ol00004ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool2o`00
00[ooooo0ol0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool000Wo
oooo0ol0000;ooooo`;o00003Oooool00ol0003oooooooooo`0eooooo`04odA4A?oMgMgoooooo`00
00Gooooo0ol0000Xooooo`;o00002oooool2o`0000cooooo0_l0000;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01Oooool000Wooooo0ol0000<ooooo`03o`000?oooooooooo04?o
oooo00CogMgMoeEEEOoooooo00001Oooool00ol0003oooooooooo`0Kooooo`;o00002_ooool3o`00
00[ooooo0ol0000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`002_ooool00ol0003oooooooooo`1Booooo`03ogMgMoo<c<co000000Go
oooo00?o0000ooooooooool06_ooool3o`0000Wooooo0ol0000<ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Go
oooo000:ooooo`03o`000?oooooooooo05;ooooo00?ok^k^odA4A?l000001Oooool00ol0003ooooo
ooooo`0<ooooo`?o00002_ooool3o`0000_ooooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo
001=ooooo`03o`000?oooooooooo00Wooooo0_l00005ooooo`03ogMgMol0003ooooo00?ooooo1Ol0
0009ooooo`Co00002_ooool4o`0000_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`06ooooo`002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0_l0000;
ooooo`Co00002Oooool3o`0000_ooooo0ol0000<ooooo`;o00002oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`04o`000?ooooooooooo`0000Gooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0ol0000:
ooooo`Co00002Oooool6o`0000Sooooo0_l0000=ooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool00oooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo0_l0000:ooooo`?o00003?ooool2o`0001Sooooo00?o0000oooo
ooooool0Doooool00ol0003oooooooooo`09ooooo`;o00001Oooool000Wooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`;o
00003_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool02Oooool2o`0000Gooooo0009ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool3o`0000_ooooo0_l0000<ooooo`;o00009Oooool2o`0004Kooooo00?o0000ooooooooool0
2_ooool2o`0000[ooooo0ol00005ooooo`002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00[ooooo0ol0000<ooooo`;o00003?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool02Oooool2o`0000cooooo0_l00005ooooo`002Oooool0
0ol0003oooooooooo`0:ooooo`?o00002oooool3o`0000gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`?o00003?ooool0
0ol0003oooooooooo`04ooooo`002_ooool2o`0000[ooooo0ol0000<ooooo`;o0000@?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool2o`00
00cooooo0_l0000<ooooo`03o`000?oooooooooo00Cooooo0009ooooo`?o00002oooool2o`0000go
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Wo
oooo0_l0000:ooooo`?o00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Go
oooo0009ooooo`?o00003?ooool2o`0004gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo0ol0000;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`002_ooool2o`0000gooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Kooooo`;o00002oooool2o`0000cooooo0_l0
000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`05ooooo`002_ooool2o`0005_ooooo00?o0000ooooooooool03Oooool2o`0000_ooooo0_l0000;
ooooo`?o00002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`002oooool00ol0003oooooooooo`1;oooo
o`;o00003?ooool00ol0003oooooooooo`0;ooooo`Co00002_ooool3o`0000_ooooo0_l0000<oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oooooooooo00Wooooo0ol0000:ooooo`Ko
00002?ooool4o`0000cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool00000
2oooool3o`0000[ooooo1?l00009ooooo`Co00002oooool2o`0000cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo0_l0000;ooooo`Co00003?ooool2o`0000Wooooo00?o0000ooooooooool0I_oo
ool000Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo0_l0000<ooooo`;o00003Oooool2o`0001Kooooo00?o0000ooooooooool0I_ooool0
00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`?o00002_ooool3o`00
00gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Vooooo`002Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`;o00003_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo06Kooooo0009ooooo`03o`000?oooooooooo00cooooo
0_l0000:ooooo`?o00003?ooool2o`0003;ooooo00?o0000ooooooooool0I_ooool000[ooooo00?o
0000ooooooooool02_ooool3o`0000_ooooo0ol0000<ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0I_ooool000[ooooo0_l0000;ooooo`?o00003?ooool2o`0003oooooo00?o0000
ooooooooool0I_ooool000Wooooo0ol0000<ooooo`;o00003Oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo06Kooooo0009ooooo`?o00003Oooool00ol0003oooooooooo`1;ooooo`;o
0000Ioooool000[ooooo0_l0001Kooooo`03o`000?oooooooooo06Kooooo000;ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool0I_ooool006Oooooo00?o0000ooooooooool0I_ooool0
06Oooooo00?o0000ooooooooool0I_ooool006Oooooo00?o0000ooooooooool0I_ooool006Oooooo
00?o0000ooooooooool0I_ooool006Oooooo00?o0000ooooooooool0I_ooool00001\
\>"],
  ImageRangeCache->{{{78.625, 244.5}, {481.562, 302.125}} -> {-10.6019, \
13.9384, 0.0656213, 0.0656213}}]
}, Open  ]],

Cell["\<\
The Show function will display this field and the last trajectory \
shown above.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Show[ traj, vf, PlotRange->{{-4,4},{-6,6}} ]", "Input",
  CellLabel->"In[261]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.75 0.125 [
[0 .7375 -6 -9 ]
[0 .7375 6 0 ]
[.125 .7375 -6 -9 ]
[.125 .7375 6 0 ]
[.25 .7375 -6 -9 ]
[.25 .7375 6 0 ]
[.375 .7375 -6 -9 ]
[.375 .7375 6 0 ]
[.625 .7375 -3 -9 ]
[.625 .7375 3 0 ]
[.75 .7375 -3 -9 ]
[.75 .7375 3 0 ]
[.875 .7375 -3 -9 ]
[.875 .7375 3 0 ]
[1 .7375 -3 -9 ]
[1 .7375 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -12 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -6 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .75 m
0 .75625 L
s
[(-4)] 0 .7375 0 1 Mshowa
.125 .75 m
.125 .75625 L
s
[(-3)] .125 .7375 0 1 Mshowa
.25 .75 m
.25 .75625 L
s
[(-2)] .25 .7375 0 1 Mshowa
.375 .75 m
.375 .75625 L
s
[(-1)] .375 .7375 0 1 Mshowa
.625 .75 m
.625 .75625 L
s
[(1)] .625 .7375 0 1 Mshowa
.75 .75 m
.75 .75625 L
s
[(2)] .75 .7375 0 1 Mshowa
.875 .75 m
.875 .75625 L
s
[(3)] .875 .7375 0 1 Mshowa
1 .75 m
1 .75625 L
s
[(4)] 1 .7375 0 1 Mshowa
.125 Mabswid
.025 .75 m
.025 .75375 L
s
.05 .75 m
.05 .75375 L
s
.075 .75 m
.075 .75375 L
s
.1 .75 m
.1 .75375 L
s
.15 .75 m
.15 .75375 L
s
.175 .75 m
.175 .75375 L
s
.2 .75 m
.2 .75375 L
s
.225 .75 m
.225 .75375 L
s
.275 .75 m
.275 .75375 L
s
.3 .75 m
.3 .75375 L
s
.325 .75 m
.325 .75375 L
s
.35 .75 m
.35 .75375 L
s
.4 .75 m
.4 .75375 L
s
.425 .75 m
.425 .75375 L
s
.45 .75 m
.45 .75375 L
s
.475 .75 m
.475 .75375 L
s
.525 .75 m
.525 .75375 L
s
.55 .75 m
.55 .75375 L
s
.575 .75 m
.575 .75375 L
s
.6 .75 m
.6 .75375 L
s
.65 .75 m
.65 .75375 L
s
.675 .75 m
.675 .75375 L
s
.7 .75 m
.7 .75375 L
s
.725 .75 m
.725 .75375 L
s
.775 .75 m
.775 .75375 L
s
.8 .75 m
.8 .75375 L
s
.825 .75 m
.825 .75375 L
s
.85 .75 m
.85 .75375 L
s
.9 .75 m
.9 .75375 L
s
.925 .75 m
.925 .75375 L
s
.95 .75 m
.95 .75375 L
s
.975 .75 m
.975 .75375 L
s
.25 Mabswid
0 .75 m
1 .75 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-4)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(-2)] .4875 .5 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(4)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(6)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .0625 m
.50375 .0625 L
s
.5 .125 m
.50375 .125 L
s
.5 .1875 m
.50375 .1875 L
s
.5 .3125 m
.50375 .3125 L
s
.5 .375 m
.50375 .375 L
s
.5 .4375 m
.50375 .4375 L
s
.5 .5625 m
.50375 .5625 L
s
.5 .625 m
.50375 .625 L
s
.5 .6875 m
.50375 .6875 L
s
.5 .8125 m
.50375 .8125 L
s
.5 .875 m
.50375 .875 L
s
.5 .9375 m
.50375 .9375 L
s
.5 1.0625 m
.50375 1.0625 L
s
.5 1.125 m
.50375 1.125 L
s
.5 1.1875 m
.50375 1.1875 L
s
.5 1.3125 m
.50375 1.3125 L
s
.5 1.375 m
.50375 1.375 L
s
.5 1.4375 m
.50375 1.4375 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.5 Mabswid
.75 1.125 m
.76962 1.06845 L
.78734 1.00328 L
.79473 .96941 L
.80145 .93262 L
.80662 .89774 L
.81043 .8653 L
.81216 .84696 L
.81372 .82673 L
.81492 .80639 L
.81542 .79527 L
.81579 .78485 L
.81593 .78017 L
.81605 .77506 L
.81622 .76577 L
.81631 .75674 L
.81633 .74836 L
.81631 .74325 L
.81627 .73844 L
.81614 .72946 L
.81604 .72444 L
.81592 .71982 L
.81559 .70943 L
.81485 .6927 L
.81393 .67719 L
.81102 .64231 L
.80712 .60895 L
.80179 .57401 L
.78844 .51017 L
.76945 .44575 L
.74756 .3906 L
.72426 .34517 L
.69848 .30581 L
.67227 .27456 L
.64168 .24699 L
.62379 .23466 L
.60704 .22542 L
.59127 .21862 L
.58252 .21561 L
.57422 .21325 L
.56646 .21146 L
.56236 .21068 L
.55801 .20998 L
.55435 .20949 L
.55032 .20905 L
.54665 .20874 L
.54322 .20853 L
.53885 .20837 L
.53638 .20834 L
.53409 .20835 L
Mistroke
.52989 .20845 L
.52542 .20868 L
.52103 .20904 L
.5169 .20948 L
.5092 .21062 L
.50009 .21246 L
.49175 .21462 L
.47308 .22115 L
.45747 .22842 L
.44104 .23795 L
.41227 .25953 L
.3799 .29215 L
.35255 .32791 L
.30657 .41154 L
.28536 .46561 L
.26914 .51893 L
.25672 .57284 L
.2481 .62479 L
.2445 .65492 L
.24207 .68262 L
.24113 .69717 L
.24036 .71306 L
.24008 .72107 L
.23995 .72547 L
.23985 .72961 L
.23977 .73348 L
.23971 .73766 L
.23964 .74496 L
.23963 .75213 L
.23966 .75867 L
.23977 .7662 L
.23992 .77333 L
.24011 .77988 L
.24033 .78593 L
.24097 .79959 L
.24183 .81321 L
.24301 .82815 L
.24616 .85799 L
.25018 .88635 L
.25555 .91612 L
.26789 .96743 L
.28234 1.01198 L
.30109 1.0562 L
.32359 1.09666 L
.34685 1.12861 L
.37283 1.15539 L
.3862 1.16614 L
.39882 1.17461 L
.41025 1.18097 L
.42302 1.18667 L
Mistroke
.436 1.19103 L
.44316 1.19282 L
.44988 1.19412 L
.45337 1.19465 L
.4571 1.19511 L
.46062 1.19544 L
.46381 1.19566 L
.46577 1.19575 L
.46757 1.19581 L
.46956 1.19584 L
.47165 1.19584 L
.47517 1.19576 L
.47717 1.19568 L
.47903 1.19557 L
.48263 1.19528 L
.48603 1.19491 L
.49239 1.19398 L
.49922 1.19262 L
.50662 1.19072 L
.51953 1.18636 L
.53307 1.18031 L
.55682 1.16586 L
.58082 1.14588 L
.60521 1.11924 L
.64441 1.05907 L
.66197 1.02226 L
.67852 .97864 L
.69261 .93011 L
.70265 .88296 L
.70651 .85902 L
.70982 .83285 L
.71103 .82079 L
.71211 .80801 L
.71287 .79695 L
.71351 .78509 L
.71376 .77919 L
.71395 .7736 L
.71409 .76858 L
.7142 .76312 L
.71428 .75797 L
.71431 .7525 L
.71431 .74734 L
.71428 .74268 L
.7142 .7367 L
.71408 .73122 L
.71391 .72522 L
.71367 .71891 L
.71316 .70832 L
.71242 .6968 L
.71025 .67253 L
Mistroke
.70747 .65001 L
.70039 .60929 L
.69541 .58744 L
.69017 .56797 L
.67624 .52669 L
.66162 .4937 L
.6462 .46623 L
.62761 .44024 L
.60595 .41745 L
.58424 .40109 L
.57155 .39412 L
.56539 .39139 L
.55956 .38916 L
.55398 .38736 L
.54791 .38577 L
.54238 .38463 L
.53727 .38386 L
.5344 .38353 L
.53172 .3833 L
.52878 .38313 L
.52713 .38307 L
.52563 .38303 L
.5226 .38303 L
.52089 .38307 L
.51931 .38313 L
.5164 .38331 L
.51494 .38343 L
.51332 .38359 L
.50791 .38429 L
.502 .38538 L
.49586 .38687 L
.49017 .38858 L
.48004 .39243 L
.46935 .39761 L
.44561 .41349 L
.42513 .43257 L
.40589 .45584 L
.38955 .48062 L
.3724 .51312 L
.35844 .54654 L
.34695 .58139 L
.33837 .6148 L
.33109 .65315 L
.32812 .67465 L
.32694 .68523 L
.32598 .69521 L
.32522 .70479 L
.32456 .71516 L
.32432 .71974 L
.32411 .72457 L
Mistroke
.32394 .72909 L
.32382 .73321 L
.32371 .73802 L
.32363 .74316 L
.3236 .74792 L
.3236 .75242 L
.32361 .75496 L
.32364 .75765 L
.32372 .76246 L
.32378 .76513 L
.32384 .76764 L
.32403 .77332 L
.32443 .78205 L
.32497 .79118 L
.32629 .80732 L
.32818 .82442 L
.3308 .84273 L
.33801 .87906 L
.34653 .90994 L
.35852 .94262 L
.37177 .97013 L
.38476 .99133 L
.39971 1.01054 L
.4133 1.02417 L
.42895 1.03611 L
Mfstroke
.0001 w
% Start of user PostScript
-5. -5. -5.18325 -4.30962 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. -4.28571 -5.15707 -3.60142 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. -3.57143 -5.13089 -2.89323 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. -2.85714 -5.10471 -2.18503 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. -2.14286 -5.07854 -1.47683 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. -1.42857 -5.05236 -0.768632 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. -0.714286 -5.02618 -0.0604342 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. 0 -5. 0.647764 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. 0.714286 -4.97382 1.35596 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. 1.42857 -4.94764 2.06416 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. 2.14286 -4.92146 2.77236 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. 2.85714 -4.89529 3.48055 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. 3.57143 -4.86911 4.18875 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. 4.28571 -4.84293 4.89695 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-5. 5. -4.81675 5.60515 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 -5. -4.46896 -4.40216 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 -4.28571 -4.44278 -3.69396 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 -3.57143 -4.41661 -2.98576 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 -2.85714 -4.39043 -2.27756 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 -2.14286 -4.36425 -1.56937 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 -1.42857 -4.33807 -0.86117 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 -0.714286 -4.31189 -0.152972 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 0 -4.28571 0.555226 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 0.714286 -4.25954 1.26342 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 1.42857 -4.23336 1.97162 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 2.14286 -4.20718 2.67982 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 2.85714 -4.181 3.38802 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 3.57143 -4.15482 4.09621 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 4.28571 -4.12864 4.80441 MAarrowhead1
% End of user PostScript
% Start of user PostScript
-4.28571 5. -4.10247 5.51261 MAarrowhead1
% End of user PostScript
.05357 .125 m
.03067 .18816 L
s
% Start of user PostScript
-3.57143 -5. -3.75468 -4.4947 MAarrowhead1
% End of user PostScript
.05357 .21429 m
.03394 .27669 L
s
% Start of user PostScript
-3.57143 -4.28571 -3.7285 -3.7865 MAarrowhead1
% End of user PostScript
.05357 .30357 m
.03721 .36521 L
s
% Start of user PostScript
-3.57143 -3.57143 -3.70232 -3.0783 MAarrowhead1
% End of user PostScript
.05357 .39286 m
.04048 .45374 L
s
% Start of user PostScript
-3.57143 -2.85714 -3.67614 -2.3701 MAarrowhead1
% End of user PostScript
.05357 .48214 m
.04375 .54226 L
s
% Start of user PostScript
-3.57143 -2.14286 -3.64996 -1.6619 MAarrowhead1
% End of user PostScript
.05357 .57143 m
.04703 .63079 L
s
% Start of user PostScript
-3.57143 -1.42857 -3.62379 -0.953707 MAarrowhead1
% End of user PostScript
.05357 .66071 m
.0503 .71931 L
s
% Start of user PostScript
-3.57143 -0.714286 -3.59761 -0.245509 MAarrowhead1
% End of user PostScript
.05357 .75 m
.05357 .80784 L
s
% Start of user PostScript
-3.57143 0 -3.57143 0.462688 MAarrowhead1
% End of user PostScript
.05357 .83929 m
.05684 .89636 L
s
% Start of user PostScript
-3.57143 0.714286 -3.54525 1.17089 MAarrowhead1
% End of user PostScript
.05357 .92857 m
.06012 .98489 L
s
% Start of user PostScript
-3.57143 1.42857 -3.51907 1.87908 MAarrowhead1
% End of user PostScript
.05357 1.01786 m
.06339 1.07341 L
s
% Start of user PostScript
-3.57143 2.14286 -3.49289 2.58728 MAarrowhead1
% End of user PostScript
.05357 1.10714 m
.06666 1.16193 L
s
% Start of user PostScript
-3.57143 2.85714 -3.46671 3.29548 MAarrowhead1
% End of user PostScript
.05357 1.19643 m
.06993 1.25046 L
s
% Start of user PostScript
-3.57143 3.57143 -3.44054 4.00368 MAarrowhead1
% End of user PostScript
.05357 1.28571 m
.07321 1.33898 L
s
% Start of user PostScript
-3.57143 4.28571 -3.41436 4.71187 MAarrowhead1
% End of user PostScript
.05357 1.375 m
.07648 1.42751 L
s
% Start of user PostScript
-3.57143 5. -3.38818 5.42007 MAarrowhead1
% End of user PostScript
.14286 .125 m
.11995 .1766 L
s
% Start of user PostScript
-2.85714 -5. -3.04039 -4.58723 MAarrowhead1
% End of user PostScript
.14286 .21429 m
.12322 .26512 L
s
% Start of user PostScript
-2.85714 -4.28571 -3.01421 -3.87904 MAarrowhead1
% End of user PostScript
.14286 .30357 m
.1265 .35365 L
s
% Start of user PostScript
-2.85714 -3.57143 -2.98803 -3.17084 MAarrowhead1
% End of user PostScript
.14286 .39286 m
.12977 .44217 L
s
% Start of user PostScript
-2.85714 -2.85714 -2.96186 -2.46264 MAarrowhead1
% End of user PostScript
.14286 .48214 m
.13304 .53069 L
s
% Start of user PostScript
-2.85714 -2.14286 -2.93568 -1.75444 MAarrowhead1
% End of user PostScript
.14286 .57143 m
.13631 .61922 L
s
% Start of user PostScript
-2.85714 -1.42857 -2.9095 -1.04624 MAarrowhead1
% End of user PostScript
.14286 .66071 m
.13958 .70774 L
s
% Start of user PostScript
-2.85714 -0.714286 -2.88332 -0.338047 MAarrowhead1
% End of user PostScript
.14286 .75 m
.14286 .79627 L
s
% Start of user PostScript
-2.85714 0 -2.85714 0.370151 MAarrowhead1
% End of user PostScript
.14286 .83929 m
.14613 .88479 L
s
% Start of user PostScript
-2.85714 0.714286 -2.83096 1.07835 MAarrowhead1
% End of user PostScript
.14286 .92857 m
.1494 .97332 L
s
% Start of user PostScript
-2.85714 1.42857 -2.80479 1.78655 MAarrowhead1
% End of user PostScript
.14286 1.01786 m
.15267 1.06184 L
s
% Start of user PostScript
-2.85714 2.14286 -2.77861 2.49474 MAarrowhead1
% End of user PostScript
.14286 1.10714 m
.15595 1.15037 L
s
% Start of user PostScript
-2.85714 2.85714 -2.75243 3.20294 MAarrowhead1
% End of user PostScript
.14286 1.19643 m
.15922 1.23889 L
s
% Start of user PostScript
-2.85714 3.57143 -2.72625 3.91114 MAarrowhead1
% End of user PostScript
.14286 1.28571 m
.16249 1.32742 L
s
% Start of user PostScript
-2.85714 4.28571 -2.70007 4.61934 MAarrowhead1
% End of user PostScript
.14286 1.375 m
.16576 1.41594 L
s
% Start of user PostScript
-2.85714 5. -2.67389 5.32753 MAarrowhead1
% End of user PostScript
.23214 .125 m
.20924 .16503 L
s
% Start of user PostScript
-2.14286 -5. -2.32611 -4.67977 MAarrowhead1
% End of user PostScript
.23214 .21429 m
.21251 .25355 L
s
% Start of user PostScript
-2.14286 -4.28571 -2.29993 -3.97157 MAarrowhead1
% End of user PostScript
.23214 .30357 m
.21578 .34208 L
s
% Start of user PostScript
-2.14286 -3.57143 -2.27375 -3.26338 MAarrowhead1
% End of user PostScript
.23214 .39286 m
.21905 .4306 L
s
% Start of user PostScript
-2.14286 -2.85714 -2.24757 -2.55518 MAarrowhead1
% End of user PostScript
.23214 .48214 m
.22233 .51913 L
s
% Start of user PostScript
-2.14286 -2.14286 -2.22139 -1.84698 MAarrowhead1
% End of user PostScript
.23214 .57143 m
.2256 .60765 L
s
% Start of user PostScript
-2.14286 -1.42857 -2.19521 -1.13878 MAarrowhead1
% End of user PostScript
.23214 .66071 m
.22887 .69618 L
s
% Start of user PostScript
-2.14286 -0.714286 -2.16904 -0.430585 MAarrowhead1
% End of user PostScript
.23214 .75 m
.23214 .7847 L
s
% Start of user PostScript
-2.14286 0 -2.14286 0.277613 MAarrowhead1
% End of user PostScript
.23214 .83929 m
.23542 .87323 L
s
% Start of user PostScript
-2.14286 0.714286 -2.11668 0.985811 MAarrowhead1
% End of user PostScript
.23214 .92857 m
.23869 .96175 L
s
% Start of user PostScript
-2.14286 1.42857 -2.0905 1.69401 MAarrowhead1
% End of user PostScript
.23214 1.01786 m
.24196 1.05028 L
s
% Start of user PostScript
-2.14286 2.14286 -2.06432 2.40221 MAarrowhead1
% End of user PostScript
.23214 1.10714 m
.24523 1.1388 L
s
% Start of user PostScript
-2.14286 2.85714 -2.03814 3.1104 MAarrowhead1
% End of user PostScript
.23214 1.19643 m
.2485 1.22733 L
s
% Start of user PostScript
-2.14286 3.57143 -2.01197 3.8186 MAarrowhead1
% End of user PostScript
.23214 1.28571 m
.25178 1.31585 L
s
% Start of user PostScript
-2.14286 4.28571 -1.98579 4.5268 MAarrowhead1
% End of user PostScript
.23214 1.375 m
.25505 1.40437 L
s
% Start of user PostScript
-2.14286 5. -1.95961 5.235 MAarrowhead1
% End of user PostScript
.32143 .125 m
.29852 .15346 L
s
% Start of user PostScript
-1.42857 -5. -1.61182 -4.77231 MAarrowhead1
% End of user PostScript
.32143 .21429 m
.30179 .24199 L
s
% Start of user PostScript
-1.42857 -4.28571 -1.58564 -4.06411 MAarrowhead1
% End of user PostScript
.32143 .30357 m
.30507 .33051 L
s
% Start of user PostScript
-1.42857 -3.57143 -1.55946 -3.35591 MAarrowhead1
% End of user PostScript
.32143 .39286 m
.30834 .41904 L
s
% Start of user PostScript
-1.42857 -2.85714 -1.53329 -2.64772 MAarrowhead1
% End of user PostScript
.32143 .48214 m
.31161 .50756 L
s
% Start of user PostScript
-1.42857 -2.14286 -1.50711 -1.93952 MAarrowhead1
% End of user PostScript
.32143 .57143 m
.31488 .59608 L
s
% Start of user PostScript
-1.42857 -1.42857 -1.48093 -1.23132 MAarrowhead1
% End of user PostScript
.32143 .66071 m
.31816 .68461 L
s
% Start of user PostScript
-1.42857 -0.714286 -1.45475 -0.523122 MAarrowhead1
% End of user PostScript
.32143 .75 m
.32143 .77313 L
s
% Start of user PostScript
-1.42857 0 -1.42857 0.185075 MAarrowhead1
% End of user PostScript
.32143 .83929 m
.3247 .86166 L
s
% Start of user PostScript
-1.42857 0.714286 -1.40239 0.893273 MAarrowhead1
% End of user PostScript
.32143 .92857 m
.32797 .95018 L
s
% Start of user PostScript
-1.42857 1.42857 -1.37621 1.60147 MAarrowhead1
% End of user PostScript
.32143 1.01786 m
.33125 1.03871 L
s
% Start of user PostScript
-1.42857 2.14286 -1.35004 2.30967 MAarrowhead1
% End of user PostScript
.32143 1.10714 m
.33452 1.12723 L
s
% Start of user PostScript
-1.42857 2.85714 -1.32386 3.01787 MAarrowhead1
% End of user PostScript
.32143 1.19643 m
.33779 1.21576 L
s
% Start of user PostScript
-1.42857 3.57143 -1.29768 3.72606 MAarrowhead1
% End of user PostScript
.32143 1.28571 m
.34106 1.30428 L
s
% Start of user PostScript
-1.42857 4.28571 -1.2715 4.43426 MAarrowhead1
% End of user PostScript
.32143 1.375 m
.34433 1.39281 L
s
% Start of user PostScript
-1.42857 5. -1.24532 5.14246 MAarrowhead1
% End of user PostScript
.41071 .125 m
.38781 .14189 L
s
% Start of user PostScript
-0.714286 -5. -0.897535 -4.86485 MAarrowhead1
% End of user PostScript
.41071 .21429 m
.39108 .23042 L
s
% Start of user PostScript
-0.714286 -4.28571 -0.871356 -4.15665 MAarrowhead1
% End of user PostScript
.41071 .30357 m
.39435 .31894 L
s
% Start of user PostScript
-0.714286 -3.57143 -0.845178 -3.44845 MAarrowhead1
% End of user PostScript
.41071 .39286 m
.39763 .40747 L
s
% Start of user PostScript
-0.714286 -2.85714 -0.818999 -2.74025 MAarrowhead1
% End of user PostScript
.41071 .48214 m
.4009 .49599 L
s
% Start of user PostScript
-0.714286 -2.14286 -0.792821 -2.03206 MAarrowhead1
% End of user PostScript
.41071 .57143 m
.40417 .58452 L
s
% Start of user PostScript
-0.714286 -1.42857 -0.766643 -1.32386 MAarrowhead1
% End of user PostScript
.41071 .66071 m
.40744 .67304 L
s
% Start of user PostScript
-0.714286 -0.714286 -0.740464 -0.61566 MAarrowhead1
% End of user PostScript
.41071 .75 m
.41071 .76157 L
s
% Start of user PostScript
-0.714286 0 -0.714286 0.0925376 MAarrowhead1
% End of user PostScript
.41071 .83929 m
.41399 .85009 L
s
% Start of user PostScript
-0.714286 0.714286 -0.688107 0.800735 MAarrowhead1
% End of user PostScript
.41071 .92857 m
.41726 .93862 L
s
% Start of user PostScript
-0.714286 1.42857 -0.661929 1.50893 MAarrowhead1
% End of user PostScript
.41071 1.01786 m
.42053 1.02714 L
s
% Start of user PostScript
-0.714286 2.14286 -0.63575 2.21713 MAarrowhead1
% End of user PostScript
.41071 1.10714 m
.4238 1.11567 L
s
% Start of user PostScript
-0.714286 2.85714 -0.609572 2.92533 MAarrowhead1
% End of user PostScript
.41071 1.19643 m
.42708 1.20419 L
s
% Start of user PostScript
-0.714286 3.57143 -0.583394 3.63353 MAarrowhead1
% End of user PostScript
.41071 1.28571 m
.43035 1.29272 L
s
% Start of user PostScript
-0.714286 4.28571 -0.557215 4.34172 MAarrowhead1
% End of user PostScript
.41071 1.375 m
.43362 1.38124 L
s
% Start of user PostScript
-0.714286 5. -0.531037 5.04992 MAarrowhead1
% End of user PostScript
.5 .125 m
.47709 .13033 L
s
% Start of user PostScript
0 -5. -0.183249 -4.95738 MAarrowhead1
% End of user PostScript
.5 .21429 m
.48037 .21885 L
s
% Start of user PostScript
0 -4.28571 -0.15707 -4.24919 MAarrowhead1
% End of user PostScript
.5 .30357 m
.48364 .30738 L
s
% Start of user PostScript
0 -3.57143 -0.130892 -3.54099 MAarrowhead1
% End of user PostScript
.5 .39286 m
.48691 .3959 L
s
% Start of user PostScript
0 -2.85714 -0.104714 -2.83279 MAarrowhead1
% End of user PostScript
.5 .48214 m
.49018 .48443 L
s
% Start of user PostScript
0 -2.14286 -0.0785352 -2.12459 MAarrowhead1
% End of user PostScript
.5 .57143 m
.49346 .57295 L
s
% Start of user PostScript
0 -1.42857 -0.0523568 -1.4164 MAarrowhead1
% End of user PostScript
.5 .66071 m
.49673 .66148 L
s
% Start of user PostScript
0 -0.714286 -0.0261784 -0.708198 MAarrowhead1
% End of user PostScript
.5 .75 m
.5 .75 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .83929 m
.50327 .83852 L
s
% Start of user PostScript
0 0.714286 0.0261784 0.708198 MAarrowhead1
% End of user PostScript
.5 .92857 m
.50654 .92705 L
s
% Start of user PostScript
0 1.42857 0.0523568 1.4164 MAarrowhead1
% End of user PostScript
.5 1.01786 m
.50982 1.01557 L
s
% Start of user PostScript
0 2.14286 0.0785352 2.12459 MAarrowhead1
% End of user PostScript
.5 1.10714 m
.51309 1.1041 L
s
% Start of user PostScript
0 2.85714 0.104714 2.83279 MAarrowhead1
% End of user PostScript
.5 1.19643 m
.51636 1.19262 L
s
% Start of user PostScript
0 3.57143 0.130892 3.54099 MAarrowhead1
% End of user PostScript
.5 1.28571 m
.51963 1.28115 L
s
% Start of user PostScript
0 4.28571 0.15707 4.24919 MAarrowhead1
% End of user PostScript
.5 1.375 m
.52291 1.36967 L
s
% Start of user PostScript
0 5. 0.183249 4.95738 MAarrowhead1
% End of user PostScript
.58929 .125 m
.56638 .11876 L
s
% Start of user PostScript
0.714286 -5. 0.531037 -5.04992 MAarrowhead1
% End of user PostScript
.58929 .21429 m
.56965 .20728 L
s
% Start of user PostScript
0.714286 -4.28571 0.557215 -4.34172 MAarrowhead1
% End of user PostScript
.58929 .30357 m
.57292 .29581 L
s
% Start of user PostScript
0.714286 -3.57143 0.583394 -3.63353 MAarrowhead1
% End of user PostScript
.58929 .39286 m
.5762 .38433 L
s
% Start of user PostScript
0.714286 -2.85714 0.609572 -2.92533 MAarrowhead1
% End of user PostScript
.58929 .48214 m
.57947 .47286 L
s
% Start of user PostScript
0.714286 -2.14286 0.63575 -2.21713 MAarrowhead1
% End of user PostScript
.58929 .57143 m
.58274 .56138 L
s
% Start of user PostScript
0.714286 -1.42857 0.661929 -1.50893 MAarrowhead1
% End of user PostScript
.58929 .66071 m
.58601 .64991 L
s
% Start of user PostScript
0.714286 -0.714286 0.688107 -0.800735 MAarrowhead1
% End of user PostScript
.58929 .75 m
.58929 .73843 L
s
% Start of user PostScript
0.714286 0 0.714286 -0.0925376 MAarrowhead1
% End of user PostScript
.58929 .83929 m
.59256 .82696 L
s
% Start of user PostScript
0.714286 0.714286 0.740464 0.61566 MAarrowhead1
% End of user PostScript
.58929 .92857 m
.59583 .91548 L
s
% Start of user PostScript
0.714286 1.42857 0.766643 1.32386 MAarrowhead1
% End of user PostScript
.58929 1.01786 m
.5991 1.00401 L
s
% Start of user PostScript
0.714286 2.14286 0.792821 2.03206 MAarrowhead1
% End of user PostScript
.58929 1.10714 m
.60237 1.09253 L
s
% Start of user PostScript
0.714286 2.85714 0.818999 2.74025 MAarrowhead1
% End of user PostScript
.58929 1.19643 m
.60565 1.18106 L
s
% Start of user PostScript
0.714286 3.57143 0.845178 3.44845 MAarrowhead1
% End of user PostScript
.58929 1.28571 m
.60892 1.26958 L
s
% Start of user PostScript
0.714286 4.28571 0.871356 4.15665 MAarrowhead1
% End of user PostScript
.58929 1.375 m
.61219 1.35811 L
s
% Start of user PostScript
0.714286 5. 0.897535 4.86485 MAarrowhead1
% End of user PostScript
.67857 .125 m
.65567 .10719 L
s
% Start of user PostScript
1.42857 -5. 1.24532 -5.14246 MAarrowhead1
% End of user PostScript
.67857 .21429 m
.65894 .19572 L
s
% Start of user PostScript
1.42857 -4.28571 1.2715 -4.43426 MAarrowhead1
% End of user PostScript
.67857 .30357 m
.66221 .28424 L
s
% Start of user PostScript
1.42857 -3.57143 1.29768 -3.72606 MAarrowhead1
% End of user PostScript
.67857 .39286 m
.66548 .37277 L
s
% Start of user PostScript
1.42857 -2.85714 1.32386 -3.01787 MAarrowhead1
% End of user PostScript
.67857 .48214 m
.66875 .46129 L
s
% Start of user PostScript
1.42857 -2.14286 1.35004 -2.30967 MAarrowhead1
% End of user PostScript
.67857 .57143 m
.67203 .54982 L
s
% Start of user PostScript
1.42857 -1.42857 1.37621 -1.60147 MAarrowhead1
% End of user PostScript
.67857 .66071 m
.6753 .63834 L
s
% Start of user PostScript
1.42857 -0.714286 1.40239 -0.893273 MAarrowhead1
% End of user PostScript
.67857 .75 m
.67857 .72687 L
s
% Start of user PostScript
1.42857 0 1.42857 -0.185075 MAarrowhead1
% End of user PostScript
.67857 .83929 m
.68184 .81539 L
s
% Start of user PostScript
1.42857 0.714286 1.45475 0.523122 MAarrowhead1
% End of user PostScript
.67857 .92857 m
.68512 .90392 L
s
% Start of user PostScript
1.42857 1.42857 1.48093 1.23132 MAarrowhead1
% End of user PostScript
.67857 1.01786 m
.68839 .99244 L
s
% Start of user PostScript
1.42857 2.14286 1.50711 1.93952 MAarrowhead1
% End of user PostScript
.67857 1.10714 m
.69166 1.08096 L
s
% Start of user PostScript
1.42857 2.85714 1.53329 2.64772 MAarrowhead1
% End of user PostScript
.67857 1.19643 m
.69493 1.16949 L
s
% Start of user PostScript
1.42857 3.57143 1.55946 3.35591 MAarrowhead1
% End of user PostScript
.67857 1.28571 m
.69821 1.25801 L
s
% Start of user PostScript
1.42857 4.28571 1.58564 4.06411 MAarrowhead1
% End of user PostScript
.67857 1.375 m
.70148 1.34654 L
s
% Start of user PostScript
1.42857 5. 1.61182 4.77231 MAarrowhead1
% End of user PostScript
.76786 .125 m
.74495 .09563 L
s
% Start of user PostScript
2.14286 -5. 1.95961 -5.235 MAarrowhead1
% End of user PostScript
.76786 .21429 m
.74822 .18415 L
s
% Start of user PostScript
2.14286 -4.28571 1.98579 -4.5268 MAarrowhead1
% End of user PostScript
.76786 .30357 m
.7515 .27267 L
s
% Start of user PostScript
2.14286 -3.57143 2.01197 -3.8186 MAarrowhead1
% End of user PostScript
.76786 .39286 m
.75477 .3612 L
s
% Start of user PostScript
2.14286 -2.85714 2.03814 -3.1104 MAarrowhead1
% End of user PostScript
.76786 .48214 m
.75804 .44972 L
s
% Start of user PostScript
2.14286 -2.14286 2.06432 -2.40221 MAarrowhead1
% End of user PostScript
.76786 .57143 m
.76131 .53825 L
s
% Start of user PostScript
2.14286 -1.42857 2.0905 -1.69401 MAarrowhead1
% End of user PostScript
.76786 .66071 m
.76458 .62677 L
s
% Start of user PostScript
2.14286 -0.714286 2.11668 -0.985811 MAarrowhead1
% End of user PostScript
.76786 .75 m
.76786 .7153 L
s
% Start of user PostScript
2.14286 0 2.14286 -0.277613 MAarrowhead1
% End of user PostScript
.76786 .83929 m
.77113 .80382 L
s
% Start of user PostScript
2.14286 0.714286 2.16904 0.430585 MAarrowhead1
% End of user PostScript
.76786 .92857 m
.7744 .89235 L
s
% Start of user PostScript
2.14286 1.42857 2.19521 1.13878 MAarrowhead1
% End of user PostScript
.76786 1.01786 m
.77767 .98087 L
s
% Start of user PostScript
2.14286 2.14286 2.22139 1.84698 MAarrowhead1
% End of user PostScript
.76786 1.10714 m
.78095 1.0694 L
s
% Start of user PostScript
2.14286 2.85714 2.24757 2.55518 MAarrowhead1
% End of user PostScript
.76786 1.19643 m
.78422 1.15792 L
s
% Start of user PostScript
2.14286 3.57143 2.27375 3.26338 MAarrowhead1
% End of user PostScript
.76786 1.28571 m
.78749 1.24645 L
s
% Start of user PostScript
2.14286 4.28571 2.29993 3.97157 MAarrowhead1
% End of user PostScript
.76786 1.375 m
.79076 1.33497 L
s
% Start of user PostScript
2.14286 5. 2.32611 4.67977 MAarrowhead1
% End of user PostScript
.85714 .125 m
.83424 .08406 L
s
% Start of user PostScript
2.85714 -5. 2.67389 -5.32753 MAarrowhead1
% End of user PostScript
.85714 .21429 m
.83751 .17258 L
s
% Start of user PostScript
2.85714 -4.28571 2.70007 -4.61934 MAarrowhead1
% End of user PostScript
.85714 .30357 m
.84078 .26111 L
s
% Start of user PostScript
2.85714 -3.57143 2.72625 -3.91114 MAarrowhead1
% End of user PostScript
.85714 .39286 m
.84405 .34963 L
s
% Start of user PostScript
2.85714 -2.85714 2.75243 -3.20294 MAarrowhead1
% End of user PostScript
.85714 .48214 m
.84733 .43816 L
s
% Start of user PostScript
2.85714 -2.14286 2.77861 -2.49474 MAarrowhead1
% End of user PostScript
.85714 .57143 m
.8506 .52668 L
s
% Start of user PostScript
2.85714 -1.42857 2.80479 -1.78655 MAarrowhead1
% End of user PostScript
.85714 .66071 m
.85387 .61521 L
s
% Start of user PostScript
2.85714 -0.714286 2.83096 -1.07835 MAarrowhead1
% End of user PostScript
.85714 .75 m
.85714 .70373 L
s
% Start of user PostScript
2.85714 0 2.85714 -0.370151 MAarrowhead1
% End of user PostScript
.85714 .83929 m
.86042 .79226 L
s
% Start of user PostScript
2.85714 0.714286 2.88332 0.338047 MAarrowhead1
% End of user PostScript
.85714 .92857 m
.86369 .88078 L
s
% Start of user PostScript
2.85714 1.42857 2.9095 1.04624 MAarrowhead1
% End of user PostScript
.85714 1.01786 m
.86696 .96931 L
s
% Start of user PostScript
2.85714 2.14286 2.93568 1.75444 MAarrowhead1
% End of user PostScript
.85714 1.10714 m
.87023 1.05783 L
s
% Start of user PostScript
2.85714 2.85714 2.96186 2.46264 MAarrowhead1
% End of user PostScript
.85714 1.19643 m
.8735 1.14635 L
s
% Start of user PostScript
2.85714 3.57143 2.98803 3.17084 MAarrowhead1
% End of user PostScript
.85714 1.28571 m
.87678 1.23488 L
s
% Start of user PostScript
2.85714 4.28571 3.01421 3.87904 MAarrowhead1
% End of user PostScript
.85714 1.375 m
.88005 1.3234 L
s
% Start of user PostScript
2.85714 5. 3.04039 4.58723 MAarrowhead1
% End of user PostScript
.94643 .125 m
.92352 .07249 L
s
% Start of user PostScript
3.57143 -5. 3.38818 -5.42007 MAarrowhead1
% End of user PostScript
.94643 .21429 m
.92679 .16102 L
s
% Start of user PostScript
3.57143 -4.28571 3.41436 -4.71187 MAarrowhead1
% End of user PostScript
.94643 .30357 m
.93007 .24954 L
s
% Start of user PostScript
3.57143 -3.57143 3.44054 -4.00368 MAarrowhead1
% End of user PostScript
.94643 .39286 m
.93334 .33807 L
s
% Start of user PostScript
3.57143 -2.85714 3.46671 -3.29548 MAarrowhead1
% End of user PostScript
.94643 .48214 m
.93661 .42659 L
s
% Start of user PostScript
3.57143 -2.14286 3.49289 -2.58728 MAarrowhead1
% End of user PostScript
.94643 .57143 m
.93988 .51511 L
s
% Start of user PostScript
3.57143 -1.42857 3.51907 -1.87908 MAarrowhead1
% End of user PostScript
.94643 .66071 m
.94316 .60364 L
s
% Start of user PostScript
3.57143 -0.714286 3.54525 -1.17089 MAarrowhead1
% End of user PostScript
.94643 .75 m
.94643 .69216 L
s
% Start of user PostScript
3.57143 0 3.57143 -0.462688 MAarrowhead1
% End of user PostScript
.94643 .83929 m
.9497 .78069 L
s
% Start of user PostScript
3.57143 0.714286 3.59761 0.245509 MAarrowhead1
% End of user PostScript
.94643 .92857 m
.95297 .86921 L
s
% Start of user PostScript
3.57143 1.42857 3.62379 0.953707 MAarrowhead1
% End of user PostScript
.94643 1.01786 m
.95625 .95774 L
s
% Start of user PostScript
3.57143 2.14286 3.64996 1.6619 MAarrowhead1
% End of user PostScript
.94643 1.10714 m
.95952 1.04626 L
s
% Start of user PostScript
3.57143 2.85714 3.67614 2.3701 MAarrowhead1
% End of user PostScript
.94643 1.19643 m
.96279 1.13479 L
s
% Start of user PostScript
3.57143 3.57143 3.70232 3.0783 MAarrowhead1
% End of user PostScript
.94643 1.28571 m
.96606 1.22331 L
s
% Start of user PostScript
3.57143 4.28571 3.7285 3.7865 MAarrowhead1
% End of user PostScript
.94643 1.375 m
.96933 1.31184 L
s
% Start of user PostScript
3.57143 5. 3.75468 4.4947 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 -5. 4.10247 -5.51261 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 -4.28571 4.12864 -4.80441 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 -3.57143 4.15482 -4.09621 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 -2.85714 4.181 -3.38802 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 -2.14286 4.20718 -2.67982 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 -1.42857 4.23336 -1.97162 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 -0.714286 4.25954 -1.26342 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 0 4.28571 -0.555226 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 0.714286 4.31189 0.152972 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 1.42857 4.33807 0.86117 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 2.14286 4.36425 1.56937 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 2.85714 4.39043 2.27756 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 3.57143 4.41661 2.98576 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 4.28571 4.44278 3.69396 MAarrowhead1
% End of user PostScript
% Start of user PostScript
4.28571 5. 4.46896 4.40216 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. -5. 4.81675 -5.60515 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. -4.28571 4.84293 -4.89695 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. -3.57143 4.86911 -4.18875 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. -2.85714 4.89529 -3.48055 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. -2.14286 4.92146 -2.77236 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. -1.42857 4.94764 -2.06416 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. -0.714286 4.97382 -1.35596 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. 0 5. -0.647764 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. 0.714286 5.02618 0.0604342 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. 1.42857 5.05236 0.768632 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. 2.14286 5.07854 1.47683 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. 2.85714 5.10471 2.18503 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. 3.57143 5.13089 2.89323 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. 4.28571 5.15707 3.60142 MAarrowhead1
% End of user PostScript
% Start of user PostScript
5. 5. 5.18325 4.30962 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[261]:=",
  ImageSize->{166.375, 249.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003?0001=b000`400?l00000o`00003ocoooool0
0<oooooo003?ooooo`00coooool00<oooooo003?ooooo`00Goooool01Oo^k^ko<S8bo`000?l@413o
c<c<06_ooooo001Oooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40Joooool005Oooooo1_l00002oooo
o`05o`000?ooooooooooooooool000001Oooool2o`0006Cooooo001Oooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401Oooool00ol0003oooooooooo`1Sooooo`00Goooool01Ol0003oEEEEo`000?l@413o
c<c<00Gooooo00?o0000ooooooooool0Hoooool005oooooo00?oEEEEohN7Qoooool01oooool00ol0
003oooooooooo`1Sooooo`00Goooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo06?o
oooo001Pooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0Hoooool006Wooooo
00?o0000ooooooooool0Hoooool006Wooooo00?o0000ooooooooool0Hoooool006Wooooo00?o0000
ooooooooool0Hoooool006Wooooo00?o0000ooooooooool0Hoooool006Wooooo00?o0000oooooooo
ool0Hoooool006Wooooo00?o0000ooooooooool0Hoooool006Wooooo0_l0001Tooooo`00JOooool0
0ol0003oooooooooo`1Sooooo`00JOooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
013ooooo001Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool04?ooool006Wooooo
00?o0000ooooooooool0D?ooool2o`00017ooooo001Yooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool03oooool2o`00017ooooo001Yooooo`03o`000?oooooooooo03kooooo0_l0000@
ooooo`?o00004?ooool006Wooooo00?o0000ooooooooool0;Oooool2o`0000oooooo0ol0000Aoooo
o`03o`000?oooooooooo00kooooo001Yooooo`03o`000?oooooooooo02gooooo0ol0000?ooooo`?o
00004?ooool00ol0003oooooooooo`0>ooooo`00JOooool00ol0003oooooooooo`0Kooooo`;o0000
4?ooool4o`0000kooooo0_l0000Aooooo`03o`000?oooooooooo00kooooo001Yooooo`03o`000?oo
oooooooo01cooooo0ol0000?ooooo`;o00004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00gooooo001Yooooo`03o`000?oooooooooo01gooooo0ol0000>ooooo`;o00004Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo001Wooooo`?o00003?ooool5o`00
00oooooo0_l0000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`?o00003Oooool6o`0000go
oooo0ol0000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
0_l0000=ooooo`Ko00003oooool00ol0003oooooooooo`1Cooooo`004?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool2o`0000oooooo1?l0
000Aooooo`03o`000?oooooooooo06?ooooo000@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`?o00003Oooool2o`0001Cooooo00?o0000
ooooooooool0Hoooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=oooo
o`;o00003oooool2o`0002Gooooo00?o0000ooooooooool0Hoooool000oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0=ooooo`?o00003Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06?ooooo000?ooooo`03o`000?oooooooooo00gooooo0_l0000@ooooo`;o0000
=_ooool00ol0003oooooooooo`1Sooooo`003oooool00ol0003oooooooooo`0=ooooo`?o00003_oo
ool2o`0003Oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0@ooooo`003Oooool2
o`00013ooooo0_l0000?ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0D?ooool2
o`00017ooooo000=ooooo`?o00003_ooool2o`0004Wooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0>ooooo`?o00004?ooool000gooooo0ol0000>ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`?o00003oooool000gooooo
0_l0001Jooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03oooool2o`00013ooooo
00?o0000ooooooooool03oooool000gooooo00?o0000ooooooooool0FOooool2o`0002kooooo0_l0
000Aooooo`;o00004?ooool00ol0003oooooooooo`0>ooooo`00JOooool00ol0003oooooooooo`0^
ooooo`;o00004?ooool2o`00013ooooo00?o0000ooooooooool03_ooool006Wooooo00?o0000oooo
ooooool07?ooool2o`00013ooooo0ol0000@ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03Oooool006Wooooo00?o0000ooooooooool07?ooool3o`00013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo001Xoooooa?o0000
3_ooool3o`00013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0_l0000>ooooo`Co00003?oo
ool5o`0000oooooo00?o0000ooooool000004?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`Go00004?ooool4o`00057ooooo000Aooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`?o00003oooool3o`00
00_ooooo0_l00004ooooo`03o`000?oooooooooo01;ooooo0_l0001?ooooo`004?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool3o`0000ko
oooo0_l0000:ooooo`?o00001_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04co
oooo000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool3o`0000oooooo
0_l0000Iooooo`;o00002Oooool00ol0003oooooooooo`0Eooooo`;o0000C?ooool0013ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`?o00003_ooool2o`0001Sooooo0_l0
0003ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo04Wooooo000@ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`?o00003_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Sooooo000?ooooo`03o`000?oooooooooo
00kooooo0_l0000?ooooo`;o00009?ooool6o`0000;ooooo1Ol00005ooooo`;o00006_ooool2o`00
03Kooooo00?o0000ooooooooool03oooool000kooooo0_l0000@ooooo`;o00003oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool000ko
oooo0ol0000>ooooo`;o0000=_ooool2o`0000Kooooo00CogMgMoeEEEOoooooo00001_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool2o`00
013ooooo000>ooooo`?o00003_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oo
oooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool03_ooool2o`00013ooooo000>ooooo`;o0000AOooool00ol0003ooooo
ooooo`08ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Oooooo`;o00003oooool3o`0000oooooo000>ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool02_ooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`;o00004?ooool00ol0003ooooooooo
o`0>ooooo`00Doooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool03?ooool2o`00013ooooo0ol0000@ooooo`03o`000?oooooooooo00gooooo001Boooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07Oooool2o`000003ooooool0003ooooo
00cooooo0ol0000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool0057o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Mooooo`?o000000?oooooo`000?oo
ool03?ooool3o`00013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`00
DOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo0ol0000?ooooo`Co0000
00?oooooo`000?ooool02oooool2o`00017ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`00D?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0
000>ooooo`Co00003_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool0017ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`;o00003_ooool5o`0000kooooo0ol0000>
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool0017ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo0ol00007oooo
o`03o`000?oooooooooo00Cooooo1?l0000@ooooo`;o00003oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo03cooooo000Aooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`?o00001oooool00ol0003oooooooooo`04ooooo`;o
00004_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03_ooooo000@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03Oooool2o`00013ooooo0_l00007ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03[ooooo000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Ooo
ool3o`0000kooooo0_l00007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0jooooo`004?ooool00ol0003oooooooooo`0=ooooo`;o00004?ooool2
o`0000oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0>Oooool0013ooooo00?o0000ooooooooool03Oooool3o`00
00kooooo0_l0000Hooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo000?ooooo`03o`000?oooooooooo00ko
oooo0ol0000>ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03_ooool000kooooo
0ol0000?ooooo`;o0000:?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0>ooooo`003_ooool3o`0000oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`;o00003oooool000kooooo0_l0000i
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00oooooo0_l0000?ooooo`003_ooool2o`0003Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03_ooool2o`00017ooooo00?o0000ooooooooool03Oooool000kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02_ooooo00Go0000oooooooo
ooooooooo`00000@ooooo`?o00004?ooool00ol0003oooooooooo`0=ooooo`00Aoooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool01?l0003o
ooooooooooooool2o`0000oooooo0_l0000Aooooo`03o`000?oooooooooo00gooooo0017ooooo`03
o`000?oooooooooo01oooooo0_l0000Nooooo`;o00003?ooool01?l0003oooooooooooooool3o`00
013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`00A_ooool00ol0003o
ooooooooo`0Pooooo`So00001oooool2o`00013ooooo0_l0000<ooooo`03o`000?oooooooooo00;o
00004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo0016ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03?ooool5o`0000Kooooo1Ol00002ooooo`Co0000
3_ooool3o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo0_l0000@ooooo`03o`000?oo
oooooooo00[ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l000000ooooooo0000o`00
0002o`0000kooooo0_l0000<ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`?o00003oooool3o`0000Wooooo0_l0
0002ooooo`Go00003Oooool00ol0003oooooo`00000Nooooo`03o`000?oooooooooo03?ooooo000A
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=
ooooo`?o00003oooool00ol0003oooooooooo`07ooooo`;o00001oooool00ol0003oooooooooo`0=
ooooo`;o00007oooool00ol0003oooooooooo`0booooo`004Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool2o`0000oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0000Moooo
o`03o`000?oooooooooo03;ooooo000@ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03Oooool3o`0000kooooo0_l0000Iooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo037ooooo000@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03Oooool3o`0000kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0aooooo`004?ooool00ol0003oooooooooo`0=ooooo`?o00003ooo
ool2o`0000kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0`ooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`?o00003oooool2o`0000kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo000?ooooo`?o00003_ooool2o`00
013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool03_ooool000oooooo0ol0000>ooooo`;o00007oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00gooooo0_l0000Gooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`;o00003oooool000oooooo
0_l0000?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00kooooo0ol0000>ooooo`003oooool2o`0002oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool05Oooool01?l0003oooooooooool0000>ooooo`;o00003oooool2o`0000oooooo
000?ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0000>ooooo`;o00004?ooool00ol0003oooooooooo`0=ooooo`00@?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Dooooo`;o00000_ooool00ol0003oooooooooo`0;ooooo`?o00003oooool00ol0003ooooooooo
o`0=ooooo`00?oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooo00003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo000o
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool2o`000003ooooool0003o
oooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`00?oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo0_l0000=ooooo`;o00003?ooool01?l0
003oooooooooooooool2o`00013ooooo00Co0000oooooooooooo00003_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo01;ooooo00Go0000
ooooooooooooooooo`00000@ooooo`?o00003_ooool3o`0000[ooooo00?o0000ooooooooool00_oo
ool2o`00013ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00cooooo000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool01?l0003oooooooooooooool2o`0000kooooo1Ol0000>ooooo`?o00002_ooool01?l0003ooooo
ooooooooool2o`00013ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0000;ooooo`05
o`000?ooooooooooooooool000002?ooool5o`0000Gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool0017o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01?ooool3o`0000_ooooo00Co0000oooooooooooo00002Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo02cooooo000Aooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool2o`0000Sooooo00?o0000ooooooooool01?ooool2o`0000_ooooo00?o0000oooo
ooooool00oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0001gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0/ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo0_l00008ooooo`03o`000?oooooooooo00Cooooo0_l0000;ooooo`03
o`000?oooooooooo00gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0:oooool0017ooooo00?o0000ooooooooool0
3Oooool3o`0000oooooo0_l00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02_ooooo000@ooooo`03o`000?oo
oooooooo00kooooo0ol0000?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Ooo
ool000oooooo0_l0000@ooooo`;o00004?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool03?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool03Oooool000oooooo0ol0000?ooooo`;o00006Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03Oooool000oooooo0ol0000?ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00kooooo0ol0000>ooooo`004?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02?ooool2o`0000oooooo0ol0000>ooooo`004?ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`;o00004?ooool00ol0003oooooooooo`0=ooooo`00>oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool3o`00013ooooo
00?o0000ooooooooool03?ooool003[ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000003_ooool2o`0000Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000j
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooo000000kooooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0<ooooo`00>_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01[ooooo0_l0000>ooooo`03o`000?oooooooooo00oooooo0ol0000>oooo
o`;o00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03?ooool003Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`;o
00004?ooool3o`0000gooooo0_l0000@ooooo`Co00003_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00
4Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool3o`0000kooooo1Ol0000<ooooo`?o00003oooool2o`000003ooooool0003ooooo00gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool3o`0000?ooooo00?o
0000ooooooooool02Oooool2o`00013ooooo00?o0000ooooooooool03_ooool3o`00017ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Xooooo`004Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`?o00000oooool00ol0003oooooooooo`08ooooo`;o00004Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0X
ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0_l00004oooo
o`03o`000?oooooooooo00Wooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0:?ooool0017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`?o
00000oooool00ol0003oooooooooo`09ooooo`;o00001?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`00
4Oooool00ol0003oooooooooo`0=ooooo`;o00004?ooool3o`0000?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo000Aooooo`03o`000?oo
oooooooo00gooooo0ol0000?ooooo`;o00000oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool03?ooool0013ooooo00?o0000ooooooooool03_ooool3
o`0000oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool03?ooool0013ooooo0ol0000?ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00cooooo000@ooooo`?o00003oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`?o00003Oooool0013ooooo
0_l0000Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0>ooooo`?o00003Oooool0013ooooo0_l0000Vooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool07Oooool2o`0002Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0<ooooo`004?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`?o00004?ooool00ol0003oooooooooo`0<
ooooo`00>?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`?o00004?ooool00ol0003oooooooooo`0<oooo
o`00=oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0ol00007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00
=oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`?o0000
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3?ooool003Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`?o00003ooo
ool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0<ooooo`?o00003oooool4o`0000gooooo0_l0000?ooooo`?o00000ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000=ooooo`Co00003_oo
ool2o`0000oooooo1Ol0000=ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`0000gooooo0ol0000?ooooo`;o00004?oo
ool00ol0003oooooooooo`0>ooooo`?o00005Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02Kooooo000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooo`00000>ooooo`?o00003oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo02Kooooo000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool4o`00
00kooooo0ol0000Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Vooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00go
oooo1?l0000>ooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo02Kooooo000Aooooo`03o`000?oooooooooo00kooooo
0ol0000?ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool07oooool2o`0002Oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Vooooo`002_ooool2o`000003oa0@4?oo
oooooooo00;ooooo00?o0000ooooooooool03?ooool00onHV9So410@o`000002o`0000oooooo00?o
0000ooooool000000_ooool5o`0000Wooooo00?o0000ooooooooool02?ooool4o`000003oa0@4?oo
oooooooo013ooooo00?o0000ooooooooool04oooool4o`000003oa0@4?oooooooooo00cooooo00?o
0000ooooooooool00_ooool5o`0000[ooooo00?o0000ooooooooool01_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00cooooo00?o0000ooooooooool01oooool2o`00007o410@0Oooool1ooooo`002ooo
ool00ol0003oooooooooo`02ooooo`?o00003Oooool01Ol@413o^[Zjo`000?l0003o<S8b017ooooo
00So0000ooooooooooooV9RHob4Q8Oo^k^koooooodA4A0Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool00ol0003ooooooooo
o`06ooooo`05oa0@4?nj^[[oooooogMgMolb<S803?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo007ooooo0006o`0000;ooooo1Ol00003ooooo`?o00001Oooool6o`0000Cooooo0ol0
000<ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0:ooooo`03o`000?oooooo000000Go00001Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool01Oooool5o`0000;ooooo
0008ooooo`04odA4A?oMgMgoooooo`0000Cooooo0ol0000?ooooo`03o`000?nYZJWo410@017ooooo
00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP0;ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooZJVYoa0@400;ooooo`?o00001_ooool01?m4A4CogMgMooooool00003oooo
o`002?ooool01?oMgMgoEEEEooooool00005ooooo`03o`000?oooooooooo00kooooo00?o410@o`00
0?nj^[X04Oooool00ol0003oooooooooo`03ooooo`03ogMgMomVIVKooooo00Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`04ooooo`04ogMgMomVIVKoooooo`0000Wooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooa0@4?l0003o^[Zj00_ooooo0ol00006ooooo`04omgMgOmE
EEGoooooo`0000?ooooo0009ooooo`03ogMgMoo<c<co000000Gooooo00?o0000ooooooooool03ooo
ool00onj^[[o8B4Qooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000002Ooo
ool00ol0003oooooooooo`04ooooo`?o000000?ooooookZj^_lQ8B403?ooool00ol0003ooooooooo
o`06ooooo`03ogMgMoo<c<co000000?ooooo0009ooooo`03onk^k_m4A4Co000001Cooooo00Go410@
oiRHV?oooooo^[Zjo`00000Aooooo`08o`000?ooooooooooo`000?nj^[[ooooooiRHV?l@4108oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00oooooo00_o0000ooooooooooooooooo`000?nj^[[ooooooiRHV?l@413o
ooooo`000009ooooo`03o`000?oooooooooo00Cooooo0ol000000ooooooo^[Zjo`00000<ooooo`03
o`000?oooooooooo00Kooooo00?ok^k^odA4A?l000000oooool000[ooooo00?oMgMgo`000?ooool0
4oooool01OnYZJWo410@o`000?l@413oZJVY017ooooo00So0000ooooooooooooV9RHoa0@4?l0003o
8B4Qolc<c0Sooooo00?o0000ooooooooool02Oooool00omEEEGoIVIVo`00000Dooooo`03o`000?oo
oooooooo01?ooooo00?oEEEEofIVI_l000002_ooool00ol0003oooooooooo`04ooooo`09o`000?oo
oooooooooooooonHV9So410@o`000?lQ8B7oc<c<00?o00002?ooool00ol0003oooooooooo`05oooo
o`05o`000?l@413o0000oa0@4?nYZJT03?ooool00ol0003oooooooooo`07ooooo`03ogMgMol0003o
oooo00;ooooo000fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool3o`00
00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00cooooo000fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool3o`00013o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`?o00001Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000fooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool3o`00013ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`?o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo
0007ooooolGo00000oooool000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool2o`000004ooooool0003oooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo1Ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l00004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooo`00000>ooooo`?o00003oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00gooooo0ol0000Gooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool09Oooool0017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`Co0000
3_ooool3o`00027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo02Gooooo000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Ooo
ool4o`0000oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool09Oooool0017ooooo00?o0000ooooooooool03_ooool3
o`0000kooooo1?l0000?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Gooooo000Aooooo`03o`000?oooooooooo
00kooooo0ol0000?ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0;ooooo`004?ooool3o`0000oooooo0ol0000?ooooo`03o`000?oooooo000000oo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`004?ooool3o`00013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`004?ooool3o`00013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03_ooool3o`0000cooooo000Aooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo0ol0000<
ooooo`004Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`?o00004?ooool00ol0003oooooooooo`0;oooo
o`00=_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo0_l0000Wooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o
00004?ooool00ol0003oooooooooo`0;ooooo`00=_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo0ol00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000@ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03Oooool3o`0000Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_o
oooo0ol0000>ooooo`?o00004?ooool2o`0000oooooo0ol00004ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0>ooooo`04o`000?ooooooooooo`0000gooooo1?l0000>ooooo`;o00003?ooool3o`000003
ooooool0003ooooo00oooooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0<ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00Co0000oooooooooooo00003Oooool4o`0000kooooo0_l0000=ooooo`04
o`000?ooooooooooo`0000oooooo0ol0000Eooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool09_ooool0017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`Co
00003_ooool3o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool0017ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0>ooooo`Co00003_ooool3o`00023ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Kooooo000Aooooo`03o`000?oo
oooooooo00oooooo0_l0000?ooooo`Co00003oooool00ol0003oooooo`00000Oooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`004Oooool0
0ol0003oooooooooo`0>ooooo`?o00004?ooool00ol0003oooooo`00000Aooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool02oooool001;ooooo00?o0000ooooooooool03Oooool3o`00
013ooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`0Mooooo`;o00009_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool0017o
oooo0ol0000?ooooo`;o00004oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool02oooool0017ooooo0ol0000@ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo
0ol0000<ooooo`004Oooool3o`0002Cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00gooooo0ol0000<ooooo`004_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`;o00004?ooool00ol0003oooooooooo`0;ooooo`004_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06oooo
o`?o00004?ooool00ol0003oooooooooo`0;ooooo`00>?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool0000=oooo
o`;o00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool003Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo027ooooo00Co0000oooooooooooo00003Oooool2o`0000Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000iooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00gooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo0ol00005ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03?ooool003Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`07ooooo`;o00004Oooool00ol0003oooooooooo`0?ooooo`;o00003_oo
ool3o`000003ooooool0003ooooo00cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool0017ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool2o`0000Cooooo00?o0000ooooooooool02?ooool2o`0000gooooo1Ol0000?
ooooo`;o00004?ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000A
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo0ol00004ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool4o`0000oooooo0ol0000Cooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0:?ooool0017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`;o00000oooool00ol0003oooooooooo`08ooooo`?o00001Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00_ooooo00Co0000ooooool0003o00009?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo02Sooooo000Aooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03_ooool3o`0000?ooooo00?o0000ooooooooool02Oooool2o`0000Gooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0:?ooool001;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`?o
00000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0:?ooool001;ooooo00?o0000ooooooooool03_ooool3o`0000oooooo0_l00003ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool001;ooooo00?o0000ooooooooool03_oo
ool3o`00013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool02_ooool0017ooooo0ol0000?ooooo`?o00005Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool0
017ooooo0ol0000@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo0_l0000<ooooo`004_ooool2o`00013o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03Oooool2o`0000cooooo000Booooo`;o0000:?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool000003?ooool2o`0000oooooo0_l0000<ooooo`00
4oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2oooool5o`0000Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0@ooooo`04o`00
0?ooooooooooo`0000gooooo0_l0000?ooooo`03o`000?oooooooooo00_ooooo000looooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool07oooool01?l0003oooooooooool0000?ooooo`;o00000_ooool00ol0
003oooooooooo`0:ooooo`?o00003oooool00ol0003oooooooooo`0;ooooo`00?Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`0Oooooo`04o`000?ooooooooooo`0000oooooo0_l00002ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`00?Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`00023o
oooo00Co0000ooooool0003o00003_ooool3o`000003ooooool0003ooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0;ooooo`00?Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00_ooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0?ooooo`;o
00003Oooool01?l0003oooooo`000?l0000@ooooo`04o`000?ooooooooooo`0000kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`00?_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooo000000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>oooo
o`?o00003Oooool4o`0000oooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0=ooooo`;o00001oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo1Ol0000=
ooooo`Co00003Oooool01?l0003oooooo`000?l0000?ooooo`05o`000?ooooooooooooooool00000
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00?ooooo0ol0000?ooooo`;o00001_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
0ol0000@ooooo`;o00003Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02cooooo
000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0000@ooooo`;o00003Oooool00ol0003oooooo`00
000Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0/ooooo`004Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo0ol00009
ooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02cooooo000Boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool3o`0000Wooooo00?o0000oooo
ooooool01?ooool2o`0001;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;?ooool001;ooooo00?o0000oooooooo
ool03_ooool3o`0000oooooo0_l00009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0;Oooool001;ooooo00?o0000ooooooooool03_ooool3o`0000oooooo0_l0000:ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02Oooool001;ooooo0ol0000?ooooo`;o00004?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Ooo
ool001;ooooo0ol0000?ooooo`;o00007?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo0_l0000;ooooo`004_ooool3o`00013ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Tooooo`;o00006_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03_ooool2o`0000_ooooo000Cooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03oooool2o`0000oooooo0ol0000;ooooo`004oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooo000000oooooo0_l0000@ooooo`03o`000?oooooooooo00[ooooo
0014ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Gooooo`04o`000?ooooooooooo`0000kooooo0ol0000@ooooo`03o`000?oooooooooo00[ooooo
0014ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00cooooo00Co0000ooooool0003o00003oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00_ooooo0015ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo0ol0
000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool004Gooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0@ooooo`;o00000oooool00ol0003oooooooooo`09
ooooo`;o00003Oooool01?l0003oooooo`000?l0000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool02oooool004Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0?
ooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`;o00003_ooool00ol0003oooooo`00000@
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool004Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`Go00003_ooool3o`0000?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo0000013ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0<ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool2o`0000kooooo0ol0000>ooooo`?o
00004?ooool3o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooo0000017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00
4Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool4o`0000oooooo0_l0000>ooooo`;o00004Oooool01?l0003oooooooooool0000Looooo`03
o`000?oooooooooo037ooooo000Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3_ooool2o`0000oooooo0_l000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo037ooooo
000Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool2o`00013ooooo0_l0
00000ooooooo0000ooooo`0Mooooo`;o00004_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo03;ooooo000Booooo`03o`000?oooooooooo00oooooo0_l0000?ooooo`;o00004Oooool0
1?l0003oooooooooool0000Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?oo
ool001;ooooo00?o0000ooooooooool03_ooool3o`00013ooooo0_l0000Dooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo00Wooooo000Cooooo`03o`000?oooooooooo00kooooo0_l0000Aooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool02Oooool001;ooooo0ol0000@ooooo`;o00009oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00cooooo0_l00018ooooo`;o00002oooool001;ooooo
0ol0000Aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03Oooool2o`0000_ooooo
000Cooooo`;o0000>oooool2o`0001Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00cooooo0ol0000;ooooo`004oooool2o`0003gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool03_ooool2o`0000oooooo00?o0000ooooooooool02_ooool001Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo0_l0000[oooo
o`03o`000?oooooooooo00gooooo0ol0000?ooooo`03o`000?oooooooooo00[ooooo001Dooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool2o`0001cooooo00?o0000oooooooo
ool03Oooool2o`00013ooooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo001Eooooo`;o0000
4_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo0_l0000>ooooo`?o0000
3oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo001Gooooo`?o00003ooo
ool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`0000kooooo0ol0000>ooooo`03o`000?oo
oooo000000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`00F_ooool2
o`0000gooooo00?o0000ooooooooool00_l0000=ooooo`Co00003Oooool3o`0000oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo001Goooo
o`;o00000oooool2o`0000_ooooo0ol0000>ooooo`Co00003oooool2o`0000oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000Aooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo0ol00004ooooo`oo00003Oooool3o`0000oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03?ooool0017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo0_l0000?ooooo`Co00003Oooool3o`00013ooooo00?o0000ooooooooool0
DOooool001;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo0_l0000Booooo`;o00003?ooool2o`0006Gooooo000Booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool3o`00013ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1Sooooo`004_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00oooooo0_l0000Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Hoooool001?o
oooo00?o0000ooooooooool03_ooool3o`00013ooooo0_l0000`ooooo`03o`000?oooooooooo06?o
oooo000Cooooo`03o`000?oooooooooo00kooooo0ol0000Aooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`08ooooo`004oooool2o`00013ooooo0_l0
0012ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool02?ooool001?ooooo0_l0000@
ooooo`;o0000>_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0=ooooo`;o00002_ooool001?ooooo0_l0000Aooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`16ooooo`;o00003_ooool3o`00
00[ooooo000Dooooo`;o0000BOooool5o`0000Gooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`?o00003oooool2o`0000[ooooo000Eooooo`03o`000?oooooooooo04Oooooo
00CoA4A4omgMgOoooooo00001_ooool2o`0003Gooooo0_l0000>ooooo`?o00003oooool00ol0003o
ooooooooo`0:ooooo`00Goooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool03?ooool3o`00013ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`00H?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo02?ooooo
0_l0000=ooooo`?o00004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo
001Pooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool08_ooool2o`0000oooooo0_l0
000@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0067ooooo00?oMgMg
o`000?ooool01Oooool00ol0003oooooooooo`0@ooooo`?o00003_ooool3o`0000oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo001Yoooo
o`03o`000?oooooooooo00kooooo1Ol0000?ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo001Hooooo`;o
00003oooool5o`0000gooooo0ol0000?ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`?o0000
3_ooool4o`0000kooooo0ol0000>ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3?ooool0017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo013ooooo0_l0000>ooooo`Go00003Oooool00ol0003oooooooooo`1Sooooo`004_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo0ol0000>ooooo`Co00007oooool0
0ol0003oooooooooo`1Sooooo`004_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo0ol0000Aooooo`;o00007_ooool00ol0003oooooooooo`1Sooooo`004_ooool00ol0003o
ooooooooo`0@ooooo`;o00003oooool2o`00037ooooo00?o0000ooooooooool0Hoooool001?ooooo
00?o0000ooooooooool03_ooool3o`00013ooooo0_l0000`ooooo`;o0000F_ooool00ol0003ooooo
ooooo`07ooooo`004oooool3o`0000oooooo0_l0000Aooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0F?ooool2o`0000Wooooo000Cooooo`?o00004?ooool2o`00047ooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0=ooooo`?o00002Oooool001?ooooo0ol0000Aoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0<oooo
o`?o00002_ooool001Cooooo0_l0001Cooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool03Oooool2o`00013ooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`0eooooo`;o00003_ooool2o`00013ooooo00?o0000ooooooooool0
2Oooool006Wooooo00?o0000ooooooooool0=?ooool3o`0000oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`09ooooo`00JOooool00ol0003oooooooooo`0Sooooo`;o00003_ooool3
o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`00JOooool00ol0
003oooooooooo`0Rooooo`?o00003oooool2o`0000oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0:ooooo`00JOooool00ol0003oooooooooo`0Booooo`;o00003Oooool3o`0000oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_o
oooo001Yooooo`03o`000?oooooooooo013ooooo0ol0000?ooooo`;o00003oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool006Wooooo1Ol0
000=ooooo`?o00003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`004Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`?o00003oooool3o`0000kooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<
ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04?ooool2o`0000oooooo1?l0000=ooooo`;o0000I?ooool001;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000oooooo0_l0000?ooooo`Go
00003?ooool00ol0003oooooooooo`1Sooooo`004_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00oooooo0_l0000Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
Hoooool001?ooooo00?o0000ooooooooool03oooool2o`0000oooooo0ol0000Aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0Hoooool001?ooooo00?o0000ooooooooool03oooool2
o`00017ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Sooooo`005?ooool00ol0
003oooooooooo`0>ooooo`;o00004_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
06?ooooo000Cooooo`?o00004?ooool2o`00047ooooo00?o0000ooooooooool0Hoooool001?ooooo
0ol0000Aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Hoooool001Cooooo0_l0
001Cooooo`03o`000?oooooooooo06?ooooo000Eooooo`;o0000D_ooool00ol0003oooooooooo`1S
ooooo`005_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo06?ooooo001Yooooo`03
o`000?oooooooooo06?ooooo001Yooooo`;o0000I?ooool006Wooooo00?o0000ooooooooool0Hooo
ool006Wooooo00?o0000ooooooooool0Hoooool006Wooooo00?o0000ooooooooool0Hoooool006Wo
oooo00?o0000ooooooooool0Hoooool006Wooooo00?o0000ooooooooool0Hoooool006Wooooo00?o
0000ooooooooool0Hoooool006Wooooo00?o0000ooooooooool0Hoooool006Wooooo00?o0000oooo
ooooool0Hoooool005oooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo
06?ooooo001Oooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`1Soooo
o`00Goooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0Hoooool005oo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`;o0000I?ooool005oooooo00Go0000oeEEEOl0
003o410@olc<c01[ooooo`00Goooool00omEEEGoQhN7ooooo`1]ooooo`00Goooool00ooMgMgo410@
oiRHV01]ooooo`00H?ooool01?o<c<coA4A4o`000?l@411[ooooo`00coooool00<oooooo003?oooo
o`00coooool00001\
\>"],
  ImageRangeCache->{{{77.875, 243.25}, {333.938, 85.375}} -> {-8.29105, \
-1.99043, 0.0511596, 0.0511596}}]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Printout",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{736, 777},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->70,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1.25,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 206, 6, 65, "Text"],
Cell[1963, 59, 210, 4, 45, "Text"],
Cell[2176, 65, 580, 34, 27, "Text"],
Cell[2759, 101, 18, 0, 27, "Text"],
Cell[2780, 103, 318, 17, 27, "Text"],
Cell[3101, 122, 332, 6, 63, "Text"],
Cell[3436, 130, 367, 19, 27, "Text"],
Cell[3806, 151, 1353, 53, 98, "Text"],
Cell[5162, 206, 237, 11, 27, "Text"],
Cell[5402, 219, 36, 0, 27, "Text"],
Cell[5441, 221, 367, 19, 27, "Text"],
Cell[5811, 242, 377, 10, 63, "Text"],
Cell[6191, 254, 119, 4, 27, "Text"],
Cell[6313, 260, 378, 7, 63, "Text"],
Cell[6694, 269, 408, 13, 45, "Text"],

Cell[CellGroupData[{
Cell[7127, 286, 154, 5, 46, "Input"],
Cell[7284, 293, 288, 8, 23, "Output"],
Cell[7575, 303, 249, 5, 24, "Output"]
}, Open  ]],
Cell[7839, 311, 432, 10, 63, "Text"],
Cell[8274, 323, 339, 10, 45, "Text"],

Cell[CellGroupData[{
Cell[8638, 337, 169, 6, 62, "Input"],
Cell[8810, 345, 217, 4, 24, "Output"]
}, Open  ]],
Cell[9042, 352, 159, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[9226, 359, 107, 2, 30, "Input"],
Cell[9336, 363, 20551, 575, 110, 5525, 385, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[29902, 941, 542, 24, 45, "Text"],

Cell[CellGroupData[{
Cell[30469, 969, 107, 2, 30, "Input"],
Cell[30579, 973, 78, 2, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30694, 980, 82, 2, 30, "Input"],
Cell[30779, 984, 387, 6, 45, "Message"],
Cell[31169, 992, 78, 2, 23, "Output"]
}, Open  ]],
Cell[31262, 997, 143, 3, 45, "Text"],
Cell[31408, 1002, 341, 12, 45, "Text"],

Cell[CellGroupData[{
Cell[31774, 1018, 102, 2, 30, "Input"],
Cell[31879, 1022, 79, 2, 23, "Output"]
}, Open  ]],
Cell[31973, 1027, 226, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[32224, 1037, 95, 2, 30, "Input"],
Cell[32322, 1041, 95, 2, 23, "Output"]
}, Open  ]],
Cell[32432, 1046, 213, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[32670, 1054, 335, 10, 127, "Input"],
Cell[33008, 1066, 18789, 500, 156, 4633, 320, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[51812, 1569, 92, 3, 27, "Text"],
Cell[51907, 1574, 1299, 54, 98, "Text"],

Cell[CellGroupData[{
Cell[53231, 1632, 186, 6, 46, "Input"],
Cell[53420, 1640, 19896, 568, 218, 4676, 375, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[73331, 2211, 238, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[73594, 2221, 165, 5, 46, "Input"],
Cell[73762, 2228, 20087, 578, 213, 4848, 385, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[93864, 2809, 116, 2, 27, "Text"],
Cell[93983, 2813, 449, 9, 81, "Text"],

Cell[CellGroupData[{
Cell[94457, 2826, 359, 10, 143, "Input"],
Cell[94819, 2838, 19311, 501, 155, 4613, 315, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[114145, 3342, 120, 5, 27, "Text"],
Cell[114268, 3349, 847, 13, 152, "Text"],
Cell[115118, 3364, 109, 2, 27, "Text"],
Cell[115230, 3368, 321, 8, 63, "Text"],

Cell[CellGroupData[{
Cell[115576, 3380, 130, 4, 46, "Input"],
Cell[115709, 3386, 406, 11, 23, "Output"],
Cell[116118, 3399, 310, 7, 24, "Output"]
}, Open  ]],
Cell[116443, 3409, 201, 4, 45, "Text"],
Cell[116647, 3415, 388, 7, 63, "Text"],
Cell[117038, 3424, 97, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[117160, 3431, 125, 5, 62, "Input"],
Cell[117288, 3438, 222, 4, 24, "Output"]
}, Open  ]],
Cell[117525, 3445, 26, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[117576, 3449, 106, 2, 30, "Input"],
Cell[117685, 3453, 20300, 561, 124, 5350, 371, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[138000, 4017, 502, 11, 81, "Text"],

Cell[CellGroupData[{
Cell[138527, 4032, 133, 5, 46, "Input"],
Cell[138663, 4039, 79, 2, 23, "Output"],
Cell[138745, 4043, 78, 2, 23, "Output"]
}, Open  ]],
Cell[138838, 4048, 294, 5, 63, "Text"],

Cell[CellGroupData[{
Cell[139157, 4057, 103, 2, 30, "Input"],
Cell[139263, 4061, 79, 2, 23, "Output"]
}, Open  ]],
Cell[139357, 4066, 396, 9, 63, "Text"],

Cell[CellGroupData[{
Cell[139778, 4079, 96, 2, 30, "Input"],
Cell[139877, 4083, 95, 2, 23, "Output"]
}, Open  ]],
Cell[139987, 4088, 132, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[140144, 4095, 313, 10, 127, "Input"],
Cell[140460, 4107, 18853, 504, 166, 4703, 324, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[159328, 4614, 139, 3, 27, "Text"],
Cell[159470, 4619, 247, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[159742, 4628, 161, 5, 46, "Input"],
Cell[159906, 4635, 27193, 769, 205, 6903, 514, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[187114, 5407, 221, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[187360, 5417, 140, 4, 46, "Input"],
Cell[187503, 5423, 26909, 786, 205, 7380, 540, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[214427, 6212, 100, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[214552, 6219, 535, 12, 160, "Input"],
Cell[215090, 6233, 26454, 746, 117, 7707, 510, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[241559, 6982, 124, 2, 27, "Text"],
Cell[241686, 6986, 588, 26, 45, "Text"],
Cell[242277, 7014, 295, 16, 27, "Text"],
Cell[242575, 7032, 105, 3, 27, "Text"],
Cell[242683, 7037, 342, 11, 45, "Text"],
Cell[243028, 7050, 162, 4, 45, "Text"],
Cell[243193, 7056, 539, 19, 63, "Text"],
Cell[243735, 7077, 248, 13, 27, "Text"],
Cell[243986, 7092, 220, 11, 27, "Text"],
Cell[244209, 7105, 287, 15, 27, "Text"],
Cell[244499, 7122, 167, 6, 27, "Text"],
Cell[244669, 7130, 401, 22, 27, "Text"],
Cell[245073, 7154, 139, 3, 27, "Text"],
Cell[245215, 7159, 395, 20, 57, "Text"],
Cell[245613, 7181, 536, 10, 81, "Text"],
Cell[246152, 7193, 169, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[246346, 7199, 76, 2, 30, "Input"],
Cell[246425, 7203, 408, 11, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[246870, 7219, 95, 2, 30, "Input"],
Cell[246968, 7223, 110, 2, 23, "Output"]
}, Open  ]],
Cell[247093, 7228, 194, 6, 27, "Text"],
Cell[247290, 7236, 89, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[247404, 7242, 125, 2, 30, "Input"],
Cell[247532, 7246, 80556, 2194, 242, 32728, 1599, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[328103, 9443, 104, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[328232, 9450, 112, 2, 30, "Input"],
Cell[328347, 9454, 89890, 2417, 325, 34991, 1734, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

