(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    978560,      31617]*)
(*NotebookOutlinePosition[    980737,      31682]*)
(*  CellTagsIndexPosition[    980693,      31678]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part IV. Linear Differential Equations", "Section"],
  "\n",
  StyleBox["Section 2. State Space", "Subsection"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["The motion of an unforced linear oscillator  ", "Text"],

Cell[TextData[{
  StyleBox["a",
    FontSlant->"Italic"],
  " ",
  StyleBox["y''",
    FontSlant->"Italic"],
  " + ",
  StyleBox["b",
    FontSlant->"Italic"],
  " ",
  StyleBox["y' + c y",
    FontSlant->"Italic"],
  " = 0  (",
  StyleBox["a, b, c ",
    FontSlant->"Italic"],
  "constant)"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
is completely determined by its initial position and velocity, time \
does not matter because the system is  autonomous. The rate of change of \
position: \
\>", "Text"],

Cell[TextData[{
  StyleBox["y'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["v",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["and velocity:  ", "Text"],

Cell[TextData[{
  StyleBox["v' = ",
    FontSlant->"Italic"],
  "(",
  StyleBox["-c y - b v",
    FontSlant->"Italic"],
  ")/",
  StyleBox["a",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
only depend upon position and velocity. Because of this phase plane \
trajectories for the unforced oscillator cannot overlap. See Ledder, Chapter \
5, Theorem 5.3.1.  \
\>", "Text"],

Cell["\<\
In this section we continue to analyze second order linear \
equations, autonomous and forced. Exact solutions will be obtained, then \
numeric solutions using NDSolve. The phase plane plays an important role in  \
the analysis and state space is introduced to help understand solutions to \
the forced equation.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["Autonomous equations", "Subsubsection"],
  " "
}], "Text"],

Cell[TextData[{
  "Families of solution curves for a second order equation can be studied \
using the phi function. This is a function defined using the formula for the \
solution to the generic initial conditions ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = y0 and ",
  StyleBox["y'",
    FontSlant->"Italic"],
  "(0) = v0. The solution formula is made into the function phi of the \
parameters y0 and v0, and time ",
  StyleBox["t",
    FontSlant->"Italic"],
  ":",
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["y",
    FontSlant->"Italic"],
  " = \[CurlyPhi](y0, v0, ",
  StyleBox["t ",
    FontSlant->"Italic"],
  ")"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "This formula gives position at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  ". The partial derivative of \[CurlyPhi] with respect to ",
  StyleBox["t",
    FontSlant->"Italic"],
  " provides the velocity formula:"
}], "Text"],

Cell[TextData[{
  StyleBox["v",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_t\ \(\[CurlyPhi](y0, v0, t)\)\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["Example. Obtain the phi function for the following \
damped, unforced mass spring system",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  StyleBox["y''",
    FontSlant->"Italic"],
  " + 0.2 ",
  StyleBox["y'",
    FontSlant->"Italic"],
  " + ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = 0"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox[" and use it to plot time series for y and v and \
trajectories in the phase plane ",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
We will first generate the solution formula for the generic initial \
conditions. Note that we have asked for the y[t] solution.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
DE1 = y''[t] + 0.2y'[t] + y[t] == 0;
soln1 = DSolve[ {DE1, y[0]==y0, y'[0]==v0}, y[t], t]\
\>", "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \({{y[
            t] \[Rule] \[ExponentialE]\^\(\(-0.1`\)\ t\)\ \((1.`\ y0\ Cos[
                    0.99498743710662`\ t] + 
                1.005037815259212`\ v0\ Sin[0.99498743710662`\ t] + 
                0.10050378152592121`\ y0\ Sin[
                    0.99498743710662`\ t])\)}}\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
The output cell for soln1 contains the formula for the phi \
function. It can be defined using the following entry. We call is phi1 \
because we will be defining other phi functions later in this section.\
\>", \
"Text"],

Cell["phi1[y0_,v0_,t0_] := Evaluate[ y[t]/.soln1 ]", "Input",
  CellLabel->"In[9]:="],

Cell[TextData[{
  "For example, the solution satisfying ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 3 and ",
  StyleBox["y'",
    FontSlant->"Italic"],
  "(0) = -2 is given by \[CurlyPhi] (3,-2, ",
  StyleBox["t ",
    FontSlant->"Italic"],
  ")"
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
phi1[3,-2,t]
Plot[ phi1[3,-2,t], {t,0,10} ]\
\>", "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({\[ExponentialE]\^\(\(-0.1`\)\ t\)\ \((3.`\ Cos[0.99498743710662`\ t] - 
            1.7085642859406605`\ Sin[0.99498743710662`\ t])\)}\)], "Output",
  CellLabel->"Out[10]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.291643 0.103892 [
[.21429 .27914 -3 -9 ]
[.21429 .27914 3 0 ]
[.40476 .27914 -3 -9 ]
[.40476 .27914 3 0 ]
[.59524 .27914 -3 -9 ]
[.59524 .27914 3 0 ]
[.78571 .27914 -3 -9 ]
[.78571 .27914 3 0 ]
[.97619 .27914 -6 -9 ]
[.97619 .27914 6 0 ]
[.01131 .08386 -12 -4.5 ]
[.01131 .08386 0 4.5 ]
[.01131 .18775 -12 -4.5 ]
[.01131 .18775 0 4.5 ]
[.01131 .39554 -6 -4.5 ]
[.01131 .39554 0 4.5 ]
[.01131 .49943 -6 -4.5 ]
[.01131 .49943 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .29164 m
.21429 .29789 L
s
[(2)] .21429 .27914 0 1 Mshowa
.40476 .29164 m
.40476 .29789 L
s
[(4)] .40476 .27914 0 1 Mshowa
.59524 .29164 m
.59524 .29789 L
s
[(6)] .59524 .27914 0 1 Mshowa
.78571 .29164 m
.78571 .29789 L
s
[(8)] .78571 .27914 0 1 Mshowa
.97619 .29164 m
.97619 .29789 L
s
[(10)] .97619 .27914 0 1 Mshowa
.125 Mabswid
.07143 .29164 m
.07143 .29539 L
s
.11905 .29164 m
.11905 .29539 L
s
.16667 .29164 m
.16667 .29539 L
s
.2619 .29164 m
.2619 .29539 L
s
.30952 .29164 m
.30952 .29539 L
s
.35714 .29164 m
.35714 .29539 L
s
.45238 .29164 m
.45238 .29539 L
s
.5 .29164 m
.5 .29539 L
s
.54762 .29164 m
.54762 .29539 L
s
.64286 .29164 m
.64286 .29539 L
s
.69048 .29164 m
.69048 .29539 L
s
.7381 .29164 m
.7381 .29539 L
s
.83333 .29164 m
.83333 .29539 L
s
.88095 .29164 m
.88095 .29539 L
s
.92857 .29164 m
.92857 .29539 L
s
.25 Mabswid
0 .29164 m
1 .29164 L
s
.02381 .08386 m
.03006 .08386 L
s
[(-2)] .01131 .08386 1 0 Mshowa
.02381 .18775 m
.03006 .18775 L
s
[(-1)] .01131 .18775 1 0 Mshowa
.02381 .39554 m
.03006 .39554 L
s
[(1)] .01131 .39554 1 0 Mshowa
.02381 .49943 m
.03006 .49943 L
s
[(2)] .01131 .49943 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(3)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .10464 m
.02756 .10464 L
s
.02381 .12542 m
.02756 .12542 L
s
.02381 .14619 m
.02756 .14619 L
s
.02381 .16697 m
.02756 .16697 L
s
.02381 .20853 m
.02756 .20853 L
s
.02381 .22931 m
.02756 .22931 L
s
.02381 .25009 m
.02756 .25009 L
s
.02381 .27086 m
.02756 .27086 L
s
.02381 .31242 m
.02756 .31242 L
s
.02381 .3332 m
.02756 .3332 L
s
.02381 .35398 m
.02756 .35398 L
s
.02381 .37476 m
.02756 .37476 L
s
.02381 .41631 m
.02756 .41631 L
s
.02381 .43709 m
.02756 .43709 L
s
.02381 .45787 m
.02756 .45787 L
s
.02381 .47865 m
.02756 .47865 L
s
.02381 .52021 m
.02756 .52021 L
s
.02381 .54098 m
.02756 .54098 L
s
.02381 .56176 m
.02756 .56176 L
s
.02381 .58254 m
.02756 .58254 L
s
.02381 .06308 m
.02756 .06308 L
s
.02381 .0423 m
.02756 .0423 L
s
.02381 .02152 m
.02756 .02152 L
s
.02381 .00075 m
.02756 .00075 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .49993 L
.10458 .36009 L
.14415 .22755 L
.18221 .11971 L
.20178 .07691 L
.22272 .04286 L
.23293 .03099 L
.23832 .02603 L
.24402 .02175 L
.24901 .01884 L
.25165 .01761 L
.25449 .01653 L
.2571 .01577 L
.25949 .01525 L
.26063 .01506 L
.26188 .0149 L
.26307 .0148 L
.26416 .01474 L
.26545 .01472 L
.2661 .01472 L
.26681 .01475 L
.26806 .01483 L
.26924 .01494 L
.27062 .01513 L
.27189 .01536 L
.27473 .01604 L
.27718 .01682 L
.27984 .01787 L
.28468 .02031 L
.29435 .02718 L
.30329 .03581 L
.32196 .06035 L
.34256 .09637 L
.38276 .18582 L
.42145 .2821 L
.46259 .37754 L
.48312 .41738 L
.50221 .44785 L
.52064 .4703 L
.53095 .47967 L
.54032 .48612 L
.54517 .48867 L
.5503 .4908 L
.55469 .49214 L
.55718 .4927 L
.55951 .49311 L
.56079 .49328 L
.56147 .49335 L
.56219 .49342 L
Mistroke
.56289 .49348 L
.56352 .49352 L
.56475 .49357 L
.56593 .49359 L
.56721 .49358 L
.56842 .49353 L
.56953 .49346 L
.57083 .49334 L
.57203 .4932 L
.57477 .49276 L
.57744 .49217 L
.5803 .49137 L
.5856 .48942 L
.5905 .4871 L
.60158 .48006 L
.61135 .47189 L
.62172 .46136 L
.65952 .40944 L
.69977 .33941 L
.73851 .2696 L
.7582 .23692 L
.77971 .20537 L
.80051 .18025 L
.81938 .16285 L
.8295 .15581 L
.83903 .1507 L
.84427 .14853 L
.8491 .14694 L
.8544 .14563 L
.85706 .14514 L
.85859 .14492 L
.86 .14475 L
.86119 .14463 L
.8625 .14452 L
.86382 .14444 L
.86455 .14441 L
.86523 .14439 L
.86647 .14437 L
.86761 .14438 L
.86886 .14441 L
.87018 .14447 L
.8713 .14454 L
.87248 .14463 L
.87462 .14487 L
.87717 .14524 L
.87948 .14567 L
.88464 .14692 L
.89023 .14874 L
.90039 .15323 L
.90984 .15873 L
Mistroke
.92024 .16615 L
.94127 .18504 L
.97619 .22517 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{187.188, 115.625},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002k0000Lb000`400?l00000o`00003o^oooool0
0;_ooooo000>ooooo`03o`000?oooooooooo0:[ooooo000>ooooo`03o`000?oooooooooo0:[ooooo
000>ooooo`03o`000?oooooooooo0:[ooooo000>ooooo`03o`000?oooooooooo02Cooooo1_l00020
ooooo`003_ooool00ol0003oooooooooo`0Sooooo`;o00001Oooool2o`0007kooooo000>ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`00
3_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
Noooool000kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo07[ooooo000>ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1iooooo`003_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0N?ooool000kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo07Oooooo000>ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1fooooo`001_ooool5o`0000?ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07Kooooo0007
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo07Gooooo0005o`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0MOooool0
00Wooooo00?o0000ooooooooool00_ooool2o`0001gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1dooooo`001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07Cooooo0006ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0Loooool000Oooooo0ol00004ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1cooooo`003_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0L_ooool000kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07;ooooo000>
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1a
ooooo`003_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0LOooool000kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo077ooooo000>ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1`ooooo`003_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0L?ooool000kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo057ooooo2Ol0000Eooooo`003_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Coooool2o`00
00Wooooo0_l0000Cooooo`003_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0C?ooool2o`0000gooooo0_l0000Aooooo`003_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo000>ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03Oooool000Oooooo0ol00004ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool03?ooool000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00_ooooo0005o`0000?ooooo00?o0000ooooooooool00oooool2o`0001Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool02_ooool000Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00[ooooo0008ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`001oooool2o`0000Gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`08ooooo`002?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool000kooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`06ooooo`003_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01?oo
ool000kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`Go00007_ooool3
o`0001gooooo0ol0000Mooooo`Co00007?ooool3o`0000Cooooo0_l00003ooooo`003_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00007oooool0
0ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000006oooool2o`0000?ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
000>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Looooo`Go00007?ooool01Ol0003ooooooooooooooooo000001_ooooo0_l00003ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`00
3_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool0000Mooooo`Co00006oooool00ol0003oooooooooo`03o`0001go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`003_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Moooo
o`04o`000?oooooo0000o`0001cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`003_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00Go
0000ooooooooooooooooo`00000Nooooo`?o00007Oooool00ol0003oooooooooo`0Iooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Iooooo`;o00001?ooool01?l0003o
ooooooooool00002ooooo`003_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wo
oooo0ol0000Pooooo`03o`000?oooooo000001gooooo0_l0000Hooooo`03o`000?oooooooooo00?o
oooo0ol0000Mooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`003_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0^ooooo`003_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`003_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0_
ooooo`002_oooon_o`0000;ooooo000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool000kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool000kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0<Oooool000kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<Oooool000kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0<_ooool000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<_ooool000kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0<oooool000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0<oooool000kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0=?oo
ool000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0=?ooool000kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool000ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0=_ooool000kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=_ooool000kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0=oooool000kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>?ooool000Oooooo0ol00004oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03Sooooo0008ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0>Oooool000Sooooo00?o0000ooooooooool00oooool2o`0000[ooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo0008ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0>_ooool000Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0kooooo`001oooool2o`0000Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0??ooool000So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0looooo`003_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0mooooo`003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0nooooo`003_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0n
ooooo`003_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0oooooo`003_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`10ooooo`00
3_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`10ooooo`003_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`11ooooo`003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`12ooooo`003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`13ooooo`003_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool02oooool2o`0004Ko
oooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_ooool2o`0000Wooooo
0_l00018ooooo`001_ooool5o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool000Oooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05;ooooo2?l0
001:ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`2T
ooooo`002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Y?ooool000Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Y?ooool000Kooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0YOooool000Oooooo0ol00004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0YOooool000kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2Uooooo`003_ooool01Ol0003ooooooooooooooooo00000:Sooooo
000>ooooo`05o`000?ooooooooooooooool00000Z?ooool000kooooo00Go0000oooooooooooooooo
o`00002Xooooo`003_ooool01?l0003oooooooooool0002Yooooo`003_ooool01?l0003ooooooooo
ool0002Yooooo`003_ooool01?l0003oooooooooool0002Yooooo`003_ooool00ol0003oooooo`00
002Zooooo`003_ooool00ol0003oooooo`00002Zooooo`003_ooool00ol0003oooooo`00002Zoooo
o`003_ooool2o`000:_ooooo0007ooooo`?o00001?ooool2o`000:_ooooo0006ooooo`05o`000?oo
ooooooooooooool000000oooool2o`000:_ooooo000:ooooo`05o`000?ooooooooooooooool00000
[?ooool000Sooooo0_l00004ooooo`;o0000Zoooool000[ooooo00Go0000ooooooooooooooooo`00
002/ooooo`001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0Z_oo
ool000Oooooo0ol0002aooooo`00^oooool00;_ooooo002kooooo`00\
\>"],
  ImageRangeCache->{{{78.625, 264.812}, {379.375, 264.75}} -> {-5.5904, \
11.6755, 0.0602384, 0.0552207}}]
}, Open  ]],

Cell["\<\
Noting that the system is underdamped with time constant 10 \
seconds, in about 40 seconds any solution that can graphed with reasonable \
scale factors will disappear from view. The first plot below is a family of \
three time series for position, using the initial conditions  \
\>", "Text"],

Cell[TextData[{
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 3, ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(0) = -3, 0, 3 ."
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["Note the use Evaluate on the Table function.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ Evaluate[Table[phi1[3,v,t],{v,-3,3,3}]], {t,0,40},
      PlotStyle->RGBColor[1,0,0], AspectRatio->1/4, PlotLabel->\"Position\" ]\
\
\>", "Input",
  CellLabel->"In[12]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.109713 0.032505 [
[.2619 .09721 -6 -9 ]
[.2619 .09721 6 0 ]
[.5 .09721 -6 -9 ]
[.5 .09721 6 0 ]
[.7381 .09721 -6 -9 ]
[.7381 .09721 6 0 ]
[.97619 .09721 -6 -9 ]
[.97619 .09721 6 0 ]
[.01131 .0122 -12 -4.5 ]
[.01131 .0122 0 4.5 ]
[.01131 .0447 -12 -4.5 ]
[.01131 .0447 0 4.5 ]
[.01131 .07721 -12 -4.5 ]
[.01131 .07721 0 4.5 ]
[.01131 .14222 -6 -4.5 ]
[.01131 .14222 0 4.5 ]
[.01131 .17472 -6 -4.5 ]
[.01131 .17472 0 4.5 ]
[.01131 .20723 -6 -4.5 ]
[.01131 .20723 0 4.5 ]
[.01131 .23973 -6 -4.5 ]
[.01131 .23973 0 4.5 ]
[.5 .2625 -26 0 ]
[.5 .2625 26 12 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .10971 m
.2619 .11596 L
s
[(10)] .2619 .09721 0 1 Mshowa
.5 .10971 m
.5 .11596 L
s
[(20)] .5 .09721 0 1 Mshowa
.7381 .10971 m
.7381 .11596 L
s
[(30)] .7381 .09721 0 1 Mshowa
.97619 .10971 m
.97619 .11596 L
s
[(40)] .97619 .09721 0 1 Mshowa
.125 Mabswid
.07143 .10971 m
.07143 .11346 L
s
.11905 .10971 m
.11905 .11346 L
s
.16667 .10971 m
.16667 .11346 L
s
.21429 .10971 m
.21429 .11346 L
s
.30952 .10971 m
.30952 .11346 L
s
.35714 .10971 m
.35714 .11346 L
s
.40476 .10971 m
.40476 .11346 L
s
.45238 .10971 m
.45238 .11346 L
s
.54762 .10971 m
.54762 .11346 L
s
.59524 .10971 m
.59524 .11346 L
s
.64286 .10971 m
.64286 .11346 L
s
.69048 .10971 m
.69048 .11346 L
s
.78571 .10971 m
.78571 .11346 L
s
.83333 .10971 m
.83333 .11346 L
s
.88095 .10971 m
.88095 .11346 L
s
.92857 .10971 m
.92857 .11346 L
s
.25 Mabswid
0 .10971 m
1 .10971 L
s
.02381 .0122 m
.03006 .0122 L
s
[(-3)] .01131 .0122 1 0 Mshowa
.02381 .0447 m
.03006 .0447 L
s
[(-2)] .01131 .0447 1 0 Mshowa
.02381 .07721 m
.03006 .07721 L
s
[(-1)] .01131 .07721 1 0 Mshowa
.02381 .14222 m
.03006 .14222 L
s
[(1)] .01131 .14222 1 0 Mshowa
.02381 .17472 m
.03006 .17472 L
s
[(2)] .01131 .17472 1 0 Mshowa
.02381 .20723 m
.03006 .20723 L
s
[(3)] .01131 .20723 1 0 Mshowa
.02381 .23973 m
.03006 .23973 L
s
[(4)] .01131 .23973 1 0 Mshowa
.125 Mabswid
.02381 .0187 m
.02756 .0187 L
s
.02381 .0252 m
.02756 .0252 L
s
.02381 .0317 m
.02756 .0317 L
s
.02381 .0382 m
.02756 .0382 L
s
.02381 .0512 m
.02756 .0512 L
s
.02381 .05771 m
.02756 .05771 L
s
.02381 .06421 m
.02756 .06421 L
s
.02381 .07071 m
.02756 .07071 L
s
.02381 .08371 m
.02756 .08371 L
s
.02381 .09021 m
.02756 .09021 L
s
.02381 .09671 m
.02756 .09671 L
s
.02381 .10321 m
.02756 .10321 L
s
.02381 .11621 m
.02756 .11621 L
s
.02381 .12272 m
.02756 .12272 L
s
.02381 .12922 m
.02756 .12922 L
s
.02381 .13572 m
.02756 .13572 L
s
.02381 .14872 m
.02756 .14872 L
s
.02381 .15522 m
.02756 .15522 L
s
.02381 .16172 m
.02756 .16172 L
s
.02381 .16822 m
.02756 .16822 L
s
.02381 .18122 m
.02756 .18122 L
s
.02381 .18773 m
.02756 .18773 L
s
.02381 .19423 m
.02756 .19423 L
s
.02381 .20073 m
.02756 .20073 L
s
.02381 .21373 m
.02756 .21373 L
s
.02381 .22023 m
.02756 .22023 L
s
.02381 .22673 m
.02756 .22673 L
s
.02381 .23323 m
.02756 .23323 L
s
.02381 .0057 m
.02756 .0057 L
s
.02381 .24623 m
.02756 .24623 L
s
.25 Mabswid
.02381 0 m
.02381 .25 L
s
gsave
.5 .2625 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Position) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .20723 m
.04262 .11573 L
.0522 .0696 L
.05746 .04802 L
.06244 .03117 L
.06506 .02391 L
.0679 .01737 L
.07047 .01268 L
.0717 .01087 L
.07286 .00944 L
.07403 .00823 L
.0751 .00735 L
.07628 .00662 L
.07756 .00614 L
.07879 .00595 L
.07948 .00597 L
.08012 .00606 L
.0813 .00643 L
.08255 .00709 L
.08328 .0076 L
.08404 .00824 L
.08541 .00963 L
.0885 .0139 L
.09117 .01879 L
.09411 .02533 L
.10458 .05669 L
.11544 .09652 L
.12572 .13355 L
.13496 .16077 L
.14018 .17218 L
.1425 .17618 L
.145 .1797 L
.14742 .1823 L
.14847 .18319 L
.14963 .18399 L
.15073 .18459 L
.15174 .18499 L
.15282 .18526 L
.15397 .18538 L
.15525 .18531 L
.15597 .18517 L
.15664 .18498 L
.15786 .18448 L
.15916 .18375 L
.1614 .18199 L
.16387 .17935 L
.16886 .17198 L
.17422 .16144 L
.18391 .13757 L
.20366 .08581 L
Mistroke
.20907 .07446 L
.21204 .06917 L
.21483 .06489 L
.21744 .06151 L
.22027 .0586 L
.22152 .05755 L
.22283 .05662 L
.22396 .05596 L
.22519 .05538 L
.22646 .05494 L
.22767 .05467 L
.22884 .05454 L
.22993 .05455 L
.2311 .05468 L
.23239 .05498 L
.23304 .05519 L
.23374 .05546 L
.23501 .05606 L
.23733 .05754 L
.23978 .0596 L
.24416 .06445 L
.25409 .07999 L
.26495 .10102 L
.27506 .12057 L
.2846 .1359 L
.28988 .14227 L
.29285 .14506 L
.29559 .14708 L
.2979 .14838 L
.29921 .14894 L
.30044 .14936 L
.30173 .14968 L
.30291 .14986 L
.30356 .14992 L
.30427 .14995 L
.30556 .14992 L
.30678 .14978 L
.30789 .14956 L
.30911 .14922 L
.3104 .14875 L
.31257 .14773 L
.31495 .14627 L
.32032 .14179 L
.32531 .13636 L
.34631 .10716 L
.35682 .09374 L
.36198 .08852 L
.36675 .08476 L
.36898 .08338 L
.37107 .08232 L
Mistroke
.37325 .08146 L
.37441 .0811 L
.37566 .08079 L
.3769 .08057 L
.3776 .08048 L
.37825 .08042 L
.37944 .08037 L
.38071 .08039 L
.38196 .0805 L
.38313 .08067 L
.38419 .08088 L
.38533 .08117 L
.3877 .08197 L
.39025 .08312 L
.39484 .08587 L
.40528 .09471 L
.42635 .11638 L
.43653 .12475 L
.43932 .12651 L
.44229 .12808 L
.44485 .12919 L
.44619 .12967 L
.4476 .1301 L
.44884 .13042 L
.45018 .13069 L
.4514 .13088 L
.45254 .13101 L
.45372 .13109 L
.45478 .13111 L
.45601 .13109 L
.45717 .13102 L
.45845 .13088 L
.4591 .13078 L
.45981 .13066 L
.46224 .13012 L
.46508 .12923 L
.46773 .12818 L
.47272 .12566 L
.47815 .12226 L
.48803 .11498 L
.49759 .10767 L
.50657 .10158 L
.51155 .09882 L
.51417 .09761 L
.51693 .09651 L
.51926 .09573 L
.52181 .09505 L
.52294 .09481 L
.52414 .09459 L
.52519 .09444 L
Mistroke
.5263 .0943 L
.52697 .09424 L
.52771 .09418 L
.52901 .09412 L
.52974 .09411 L
.53053 .09411 L
.53127 .09413 L
.53195 .09416 L
.53326 .09425 L
.534 .09432 L
.53469 .0944 L
.53729 .09481 L
.53983 .09537 L
.54213 .09601 L
.54729 .09784 L
.56815 .10866 L
.5773 .11356 L
.58215 .11582 L
.58735 .11787 L
.58995 .11873 L
.59241 .11943 L
.59481 .11999 L
.59703 .12041 L
.59914 .12072 L
.6002 .12084 L
.60137 .12094 L
.60254 .12102 L
.6038 .12107 L
.60499 .12109 L
.60608 .12109 L
.60724 .12105 L
.60847 .12099 L
.60963 .1209 L
.61069 .1208 L
.61328 .12046 L
.61573 .12004 L
.6206 .1189 L
.62588 .11729 L
.64536 .10965 L
.65569 .10579 L
.66138 .10406 L
.66419 .10335 L
.66679 .10279 L
.66946 .1023 L
.67188 .10195 L
.67456 .10167 L
.67604 .10156 L
.6767 .10152 L
.67742 .10148 L
.67861 .10144 L
Mistroke
.67986 .10142 L
.68101 .10142 L
.68209 .10143 L
.68337 .10148 L
.68453 .10154 L
.68587 .10163 L
.68714 .10174 L
.68944 .10199 L
.69188 .10233 L
.69626 .10311 L
.70618 .10552 L
.72591 .11129 L
.73454 .11342 L
.73943 .11436 L
.74397 .11504 L
.74637 .11531 L
.74854 .1155 L
.74974 .11558 L
.75105 .11565 L
.75228 .11571 L
.75342 .11574 L
.7546 .11576 L
.75572 .11577 L
.75693 .11576 L
.75824 .11573 L
.7589 .11571 L
.75961 .11568 L
.76091 .11562 L
.76335 .11545 L
.76584 .11523 L
.7686 .11491 L
.77418 .1141 L
.78421 .11218 L
.79441 .10996 L
.80515 .10779 L
.80959 .10703 L
.81433 .10636 L
.81705 .10604 L
.81953 .1058 L
.82183 .10561 L
.82315 .10553 L
.82437 .10546 L
.82563 .1054 L
.82678 .10536 L
.82801 .10533 L
.82933 .10531 L
.83045 .1053 L
.83167 .1053 L
.83283 .10532 L
.8339 .10534 L
Mistroke
.83455 .10535 L
.83525 .10538 L
.83653 .10543 L
.83891 .10555 L
.84168 .10574 L
.84424 .10596 L
.85337 .10704 L
.86302 .10848 L
.87322 .1101 L
.88288 .11144 L
.88709 .11192 L
.89156 .11234 L
.89389 .11251 L
.89646 .11267 L
.8988 .11279 L
.901 .11286 L
.90214 .11289 L
.90338 .11291 L
.90468 .11293 L
.9059 .11293 L
.90703 .11293 L
.90807 .11292 L
.90926 .1129 L
.91039 .11288 L
.91162 .11284 L
.91292 .1128 L
.91525 .1127 L
.92051 .11237 L
.92566 .11194 L
.93047 .11147 L
.94143 .11023 L
.97619 .10742 L
Mfstroke
.02381 .20723 m
.06244 .11441 L
.07216 .08231 L
.0775 .06731 L
.08255 .05564 L
.08542 .05028 L
.08852 .04556 L
.0899 .04385 L
.09135 .04231 L
.09271 .0411 L
.09396 .0402 L
.09521 .0395 L
.09591 .0392 L
.09657 .03897 L
.09774 .0387 L
.09901 .0386 L
.09974 .03864 L
.10041 .03873 L
.10118 .0389 L
.1019 .03913 L
.10319 .03969 L
.10458 .04052 L
.10705 .04255 L
.10936 .04505 L
.1146 .05273 L
.11971 .0625 L
.12519 .07485 L
.14415 .12241 L
.15433 .14362 L
.15711 .14821 L
.16007 .1524 L
.16263 .15541 L
.16539 .15801 L
.16665 .15895 L
.16797 .15979 L
.16919 .16043 L
.17032 .16089 L
.17139 .16122 L
.17254 .16145 L
.1738 .16157 L
.17496 .16154 L
.17561 .16148 L
.17631 .16136 L
.17756 .16105 L
.17826 .16082 L
.17891 .16056 L
.18039 .15984 L
.18286 .15823 L
.18551 .15597 L
.19077 .15 L
Mistroke
.19564 .14298 L
.20669 .12366 L
.21635 .1057 L
.22679 .08865 L
.23231 .08162 L
.23473 .07908 L
.23738 .07672 L
.23973 .07502 L
.24223 .0736 L
.24362 .073 L
.24488 .07256 L
.24615 .07224 L
.24735 .07203 L
.24842 .07192 L
.2496 .0719 L
.25083 .07197 L
.25199 .07213 L
.25307 .07235 L
.25405 .07262 L
.25628 .07346 L
.25853 .07461 L
.261 .0762 L
.26597 .08036 L
.27627 .0921 L
.28562 .10468 L
.29653 .11896 L
.30132 .1244 L
.30658 .12945 L
.31141 .13307 L
.31373 .13443 L
.31593 .13547 L
.31712 .13594 L
.31842 .13638 L
.3195 .13667 L
.32069 .13693 L
.32198 .13713 L
.32269 .13721 L
.32335 .13726 L
.32453 .13729 L
.32581 .13725 L
.32711 .13713 L
.32833 .13694 L
.32966 .13666 L
.33109 .13627 L
.33401 .13519 L
.33666 .1339 L
.34178 .13067 L
.34662 .12688 L
.36491 .10931 L
.37531 .09994 L
Mistroke
.3804 .0962 L
.38505 .09344 L
.3874 .09232 L
.38996 .09131 L
.39238 .09056 L
.39462 .09006 L
.39527 .08995 L
.39596 .08985 L
.39723 .08971 L
.39846 .08963 L
.3996 .0896 L
.40083 .08962 L
.40153 .08966 L
.40218 .08971 L
.40349 .08985 L
.40423 .08996 L
.4049 .09007 L
.40759 .09068 L
.41008 .09143 L
.41571 .09379 L
.42594 .09988 L
.4357 .10683 L
.44621 .11419 L
.45104 .11716 L
.45613 .11983 L
.46048 .12167 L
.46276 .12246 L
.46523 .12316 L
.46655 .12347 L
.46778 .12372 L
.46892 .12392 L
.47019 .12409 L
.47132 .12422 L
.47237 .1243 L
.47349 .12436 L
.47469 .12438 L
.47599 .12436 L
.47672 .12434 L
.4774 .1243 L
.47865 .1242 L
.47997 .12405 L
.4825 .12365 L
.4848 .12316 L
.48931 .12187 L
.49418 .12005 L
.503 .11594 L
.5226 .10588 L
.52797 .10357 L
.53371 .10155 L
.5365 .10077 L
Mistroke
.53914 .10016 L
.5415 .09972 L
.54274 .09953 L
.54407 .09936 L
.54535 .09923 L
.54652 .09914 L
.5477 .09907 L
.54882 .09903 L
.55012 .09902 L
.55132 .09903 L
.55264 .09908 L
.55338 .09912 L
.55405 .09917 L
.55542 .09928 L
.55667 .09942 L
.5595 .09983 L
.562 .10029 L
.56464 .10089 L
.57369 .10357 L
.58363 .10725 L
.59364 .11106 L
.60313 .11419 L
.60837 .11555 L
.61113 .11613 L
.61407 .11665 L
.61653 .11699 L
.61784 .11713 L
.61925 .11726 L
.62054 .11736 L
.62172 .11743 L
.62285 .11747 L
.62404 .1175 L
.62528 .11751 L
.62597 .11751 L
.62661 .1175 L
.62779 .11747 L
.62904 .11741 L
.63016 .11735 L
.6312 .11727 L
.63358 .11705 L
.63615 .11673 L
.6385 .11637 L
.64378 .11537 L
.66214 .11057 L
.67135 .10807 L
.68115 .10588 L
.68406 .10537 L
.6868 .10496 L
.68946 .10463 L
.69191 .10439 L
Mistroke
.69424 .10422 L
.69542 .10415 L
.69671 .10409 L
.698 .10405 L
.69873 .10404 L
.69939 .10403 L
.70067 .10403 L
.70189 .10404 L
.70303 .10406 L
.70426 .1041 L
.70542 .10415 L
.70649 .10421 L
.70896 .10438 L
.71156 .10462 L
.71647 .10522 L
.72183 .10606 L
.74026 .10969 L
.75036 .11159 L
.75533 .11237 L
.7599 .11295 L
.76241 .11322 L
.76517 .11346 L
.76795 .11365 L
.76947 .11372 L
.77088 .11378 L
.77218 .11382 L
.7734 .11384 L
.7745 .11386 L
.7757 .11386 L
.77699 .11385 L
.77765 .11385 L
.77838 .11383 L
.77966 .1138 L
.78086 .11376 L
.78328 .11365 L
.78554 .11351 L
.79067 .11309 L
.79566 .11254 L
.80101 .11185 L
.8195 .10915 L
.82972 .10786 L
.83549 .10732 L
.83824 .10711 L
.84081 .10696 L
.84305 .10685 L
.84547 .10676 L
.84684 .10673 L
.84814 .10671 L
.84931 .10669 L
.85059 .10669 L
Mistroke
.85129 .10669 L
.85195 .10669 L
.85319 .1067 L
.85389 .10671 L
.85452 .10673 L
.85596 .10676 L
.85839 .10684 L
.86095 .10695 L
.86591 .10726 L
.87044 .10761 L
.8806 .10861 L
.89893 .11055 L
.90374 .11097 L
.90885 .11135 L
.91321 .1116 L
.91569 .11171 L
.91802 .1118 L
.92056 .11186 L
.92184 .11189 L
.92257 .1119 L
.92324 .1119 L
.92443 .11191 L
.92571 .11192 L
.9269 .11192 L
.92802 .11191 L
.92932 .1119 L
.92998 .11189 L
.93071 .11188 L
.93318 .11182 L
.93608 .11173 L
.93879 .11162 L
.94881 .11103 L
.95833 .11032 L
.97619 .10897 L
Mfstroke
.02381 .20723 m
.02846 .22395 L
.03068 .23024 L
.03279 .23513 L
.03398 .23743 L
.03527 .23954 L
.03635 .24099 L
.03754 .24226 L
.03882 .24325 L
.03952 .24363 L
.04018 .24387 L
.04135 .24405 L
.04262 .24387 L
.04393 .2433 L
.04516 .2424 L
.0465 .24103 L
.04793 .23913 L
.05057 .23446 L
.05297 .229 L
.05785 .21462 L
.06244 .19766 L
.08439 .09562 L
.09401 .05522 L
.09948 .03715 L
.1021 .03005 L
.10458 .02435 L
.10685 .02005 L
.10931 .01637 L
.1104 .01509 L
.11155 .01396 L
.11264 .01311 L
.11363 .01251 L
.11477 .01203 L
.116 .01178 L
.11709 .01177 L
.11824 .01199 L
.1195 .01248 L
.12067 .01317 L
.12195 .0142 L
.12333 .01558 L
.12589 .01895 L
.12866 .02369 L
.1337 .03489 L
.14313 .06282 L
.16262 .13001 L
.16795 .14606 L
.17369 .16053 L
.17647 .16629 L
.1791 .17094 L
.1817 .17469 L
Mistroke
.18405 .17736 L
.18522 .17843 L
.18649 .17939 L
.18769 .1801 L
.18879 .18059 L
.18996 .18095 L
.19124 .18114 L
.19189 .18115 L
.19258 .18111 L
.19383 .18088 L
.195 .1805 L
.19627 .17989 L
.19747 .17914 L
.19858 .1783 L
.2029 .1737 L
.20535 .17024 L
.20764 .16649 L
.21287 .15632 L
.22345 .13106 L
.24197 .08562 L
.24704 .07576 L
.25245 .06735 L
.25508 .06416 L
.25756 .06171 L
.25978 .06 L
.26095 .05928 L
.26219 .05866 L
.26344 .05818 L
.26461 .05787 L
.26533 .05774 L
.266 .05766 L
.26727 .05762 L
.26792 .05766 L
.26861 .05774 L
.26985 .058 L
.27053 .0582 L
.27118 .05843 L
.27265 .05908 L
.27506 .06055 L
.27728 .06232 L
.28227 .06762 L
.29255 .08315 L
.30338 .1031 L
.31291 .12041 L
.31815 .12881 L
.3231 .1356 L
.32771 .14069 L
.33014 .14284 L
.33272 .14471 L
.33488 .14593 L
Mistroke
.33603 .14645 L
.33726 .14691 L
.3384 .14724 L
.33943 .14746 L
.34047 .14761 L
.34146 .14769 L
.34271 .14769 L
.34341 .14765 L
.34405 .14758 L
.34524 .14738 L
.34649 .14707 L
.34762 .14671 L
.34867 .1463 L
.35106 .14512 L
.35599 .14167 L
.36128 .13664 L
.37967 .11301 L
.38986 .09976 L
.39523 .09378 L
.40093 .08859 L
.4059 .08522 L
.40873 .08382 L
.41002 .08331 L
.41138 .08287 L
.41254 .08256 L
.41381 .08231 L
.41497 .08214 L
.41604 .08205 L
.41731 .08201 L
.41846 .08204 L
.4191 .08209 L
.4198 .08216 L
.42105 .08235 L
.42229 .08261 L
.42341 .0829 L
.42595 .08378 L
.4283 .08483 L
.43053 .08603 L
.44094 .09381 L
.46199 .11424 L
.47161 .12222 L
.47699 .12561 L
.47952 .1269 L
.48185 .12788 L
.48403 .12863 L
.48641 .12926 L
.48765 .1295 L
.48881 .12968 L
.49003 .12981 L
.49134 .12989 L
Mistroke
.49249 .12992 L
.49374 .12989 L
.49492 .12981 L
.49601 .1297 L
.49699 .12956 L
.49807 .12937 L
.50026 .12887 L
.50274 .12812 L
.50545 .12709 L
.51039 .12472 L
.51966 .11894 L
.5306 .11105 L
.54053 .10421 L
.5454 .10134 L
.55066 .09875 L
.55307 .09776 L
.55562 .09688 L
.55802 .0962 L
.5602 .09571 L
.56139 .09549 L
.56269 .0953 L
.5634 .09522 L
.56406 .09515 L
.56537 .09505 L
.56648 .095 L
.56771 .09498 L
.56899 .095 L
.57019 .09506 L
.57083 .09511 L
.57153 .09517 L
.57295 .09534 L
.57547 .09575 L
.57842 .09642 L
.58117 .09721 L
.59168 .10144 L
.60161 .10652 L
.61046 .11118 L
.6202 .11567 L
.62488 .1174 L
.62991 .11886 L
.63269 .11947 L
.63523 .1199 L
.63645 .12007 L
.63778 .12021 L
.63904 .12032 L
.6402 .12039 L
.64136 .12044 L
.64262 .12046 L
.6438 .12045 L
.64489 .12042 L
Mistroke
.64588 .12037 L
.64696 .1203 L
.64809 .1202 L
.64914 .12009 L
.65154 .11976 L
.65373 .11938 L
.65865 .11827 L
.66859 .11514 L
.67777 .11166 L
.68849 .10762 L
.69373 .10587 L
.69854 .10449 L
.70284 .10348 L
.70754 .10264 L
.70999 .10233 L
.71226 .10211 L
.71352 .10202 L
.71467 .10196 L
.71599 .10191 L
.71723 .10188 L
.71842 .10188 L
.71973 .1019 L
.7204 .10192 L
.7211 .10194 L
.72238 .10201 L
.72366 .10209 L
.72486 .1022 L
.72713 .10243 L
.73226 .10319 L
.73784 .10431 L
.7572 .10949 L
.76748 .11219 L
.77289 .11336 L
.77858 .11434 L
.78101 .11467 L
.78361 .11496 L
.78511 .1151 L
.78647 .1152 L
.78785 .11528 L
.78912 .11534 L
.79028 .11538 L
.79151 .11541 L
.79274 .11543 L
.79344 .11543 L
.7941 .11542 L
.79528 .11541 L
.79636 .11538 L
.79761 .11533 L
.7988 .11527 L
.80108 .11512 L
Mistroke
.80351 .11491 L
.80789 .11441 L
.8178 .11281 L
.83778 .1088 L
.84326 .10781 L
.84904 .10692 L
.85398 .10631 L
.85676 .10605 L
.85939 .10585 L
.8619 .1057 L
.86332 .10564 L
.86463 .1056 L
.86573 .10557 L
.86694 .10555 L
.86821 .10555 L
.8694 .10555 L
.87071 .10557 L
.87137 .10558 L
.87209 .1056 L
.87337 .10564 L
.87456 .10568 L
.87725 .10583 L
.88012 .10603 L
.88534 .10652 L
.89026 .10709 L
.89947 .10838 L
.91816 .11107 L
.9227 .1116 L
.92758 .11207 L
.93038 .11228 L
.93293 .11245 L
.9355 .11258 L
.93676 .11263 L
.93794 .11267 L
.9391 .1127 L
.94036 .11272 L
.9415 .11274 L
.94254 .11275 L
.94368 .11275 L
.94493 .11275 L
.94623 .11273 L
.94744 .11271 L
.94858 .11268 L
.94967 .11265 L
.95169 .11258 L
.95624 .11234 L
.96121 .11199 L
.96581 .11159 L
.97619 .11052 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{397.25, 99.3125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006=0000Hb000`400?l00000o`00003ooooooon>
ooooo`00;_ooool00ol0003oooooooooo`3ooooooegooooo000Uooooo`?o00001_ooool00ol0003o
ooooooooo`3ooooooegooooo000Tooooo`05o`000?ooooooooooooooool000001Oooool2o`0000oo
oooo1?oo003ooooood_ooooo000Nooooo`Go00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00gooooo00Goo`00ooooooooooooooooool0003ooooood_ooooo000Vooooo`;o0000
1_ooool3o`0000cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`05ooooo`Coo`00
ooooooloooooo`00:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0oooooollooooo`009?ooool01Ol0003ooooooooooooooooo000000Gooooo0_l0
000=ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo0?oooooo??ooool002Gooooo0ol00006ooooo`03o`000?oooooo
oooo00_ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool0oooooolkooooo`00;_ooool2o`0000cooooo00?oo`00oooo
ooooool01_ooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool0oooooolk
ooooo`00;_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Kooooo00Goo`00oooo
ooooooooooooool00007ooooo`03ool00?oooooooooo0?oooooo>_ooool002kooooo0_l0000;oooo
o`03ool00?oooooooooo00Sooooo00?oo`00oooooooo00002?ooool00ooo003oooooooooo`3ooooo
oc[ooooo000^ooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool02?ooool00ooo003o
ooooool00009ooooo`03ool00?oooooooooo0?oooooo>Oooool002Cooooo1Ol00005ooooo`;o0000
2_ooool00ooo003oooooooooo`09ooooo`?oo`002Oooool00ooo003oooooooooo`3oooooocWooooo
000Uooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool02Oooool00ooo003ooooo
ooooo`08ooooo`Goo`002Oooool00ooo003oooooooooo`3oooooocSooooo000Nooooo`Go00000ooo
ool00ol0003oooooooooo`05ooooo`?o00002Oooool00ooo003oooooooooo`07ooooo`05ool00?oo
ooooo`00ool00?ooool00_oo0008ooooo`03ool00?oooooooooo0?oooooo>?ooool002Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00Oooooo00So
o`00ooooooooooooo`00oooooooo003oooooool000Sooooo00?oo`00ooooooooool0oooooolhoooo
o`009?ooool01Ol0003ooooooooooooooooo000000Gooooo0_l00009ooooo`03ool00?oooooooooo
00Kooooo00Ooo`00ooooooooooooooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`3oooooocOooooo000Tooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00Kooooo00Coo`00ooooooooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00ooooooooool0oooooolgooooo`00
9Oooool3o`0000Kooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`06ooooo`05ool0
0?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo
01Sooooo1Ooo003ooooooa[ooooo000^ooooo`;o00002?ooool00ooo003oooooooooo`06ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00
ooooooooool05_ooool2ool000Cooooo0_oo0005ooooo`Koo`00ooooool=ooooo`00;_ooool00ol0
003oooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`0Eooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo0?oooooo2_ooool002kooooo0_l00007ooooo`03ool00?oooooooooo00Kooooo00Goo`00
ooooooooooooooooool00005ooooo`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool0
5Oooool00ooo003oooooooooo`06ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003o
ooooooooo`3oooooo`Wooooo000Uooooo`?o00001_ooool00ol0003oooooooooo`06ooooo`03ool0
0?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00005ooooo`05ool00?oooooooooooooo
oooo00001_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00Oooooo00Coo`00oooo
ooooooooo`002Oooool00ooo003oooooooooo`3oooooo`Sooooo000Vooooo`03o`000?oooooooooo
00Gooooo0_l00007ooooo`03ool00?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00005
ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`0Cooooo`03ool00?oo
oooooooo00Oooooo1?oo0004ooooo`;o00000oooool00ooo003oooooooooo`0nooooo`Go00000ooo
ool2o`0004Gooooo0ol00004ooooo`;o0000AOooool3o`0000?ooooo0_l0000Tooooo`007_ooool5
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Booooo`03ool00?oooooo
oooo00Oooooo1?oo00001Oooooooo`00ool00?oooooo000000;ooooo00Go0000oooooooooooooooo
ool00010ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000@oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000AOooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool08Oooool002Kooooo00?o0000ooooooooool01Ooo
ool3o`0000Kooooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000Oooooo
00Goo`00ooooooooooooooooool00006ooooo`03ool00?oooooooooo01;ooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`02ool000?ooooo00Goo`00o`000?ooooooooooo`000004oooo
o`03ool00?oooooooooo03kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00017
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0@?ooool5o`0000;ooooo00Co
0000oooooooooooo00008oooool002Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03ool00?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00007ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0@ooooo`03ool0
0?oooooooooo00Gooooo0_oo0002ooooo`04ool00?oooooo0000ool000?ooooo00Coo`00oooooooo
oooo00001?ooool00ooo003oooooooooo`0Hooooo`Koo`008Oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool0@oooool2o`0000?ooooo00Co0000oooooooooooo0000@_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0002?ooooo000Uooooo`;o0000
1oooool2o`0000Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo013ooooo00?oo`00ooooooooool01Oooool02?oo003oooooooooooooooooo`00oooo
ool0003oo`000oooool01?l0003oo`00ooooool00005ooooo`03ool00?oooooooooo01Gooooo0ooo
0005ooooo`03ool00?oooooooooo00?ooooo1ooo000Aooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00017ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0002?ooooo000Voooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`05oooo
o`06ool00?oooooooooooooooooo003ooooo0_l000002?ooooooo`00oooooooooooo0000oooooooo
003o00001Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00Kooooo0_oo00000ooo
ooooo`00ool00007ooooo`;oo`003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo0000@oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
0000A?ooool2o`0000?ooooo00Co0000oooooooooooo00008oooool002kooooo0_l00006ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0>ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool01_oo003oooooooooool0003ooooo
ool000?ooooo0_l000000ooo003oooooooooo`04ooooo`03ool00?oooooooooo01;ooooo0_oo0009
ooooo`Koo`002?ooool00ooo003oooooooooo`0=ooooo`?o00001?ooool2o`0004Gooooo0ol00004
ooooo`;o0000A_ooool00ol0003oooooooooo`02ooooo`;o00009?ooool002kooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool01oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool03Oooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04?ooool0
0ooo003oooooooooo`06ooooo`?oo`0000Goooooool00?ooooooo`00ooooo`04ool000Kooooo00?o
o`00ooooooooool06_ooool2ool00;Sooooo000^ooooo`;o00001Oooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`04
ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0000Cooooo0_oo0005ooooo`03ool00?oo
oooooooo01Gooooo1Ooo00000oooooooo`00ool00002ool000?ooooo2_oo002Wooooo`00;_ooool0
0ol0003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`07ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0Booooo`;oo`002?ooool8ool000Oooooo0_oo002Uooooo`00;_ooool2o`00
00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00oooooo0_oo0007ooooo`?oo`0000Coooooool00?oo003ooooo0ooo00001?ooooooo`00ool00?oo
0006ooooo`;oo`005OoooolIool007Gooooo000^ooooo`03o`000?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Wooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00gooooo00?oo`00
ooooooooool00oooool4ool000;ooooo0_oo0006ooooo`;oo`000_ooool3ool000Gooooo00?oo`00
ooooooooool03oooool4ool000Cooooo4Ooo0003ooooo`Coo`005?oooolHool004Gooooo000^oooo
o`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool00oooool2ool000Cooooo00?oo`00oooo
ooooool02_ooool2ool000Gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`08oooo
o`;oo`000oooool3ool000?ooooo0ooo000<ooooo`;oo`001Oooool3ool000;ooooo0_oo0008oooo
o`?oo`000_ooool3ool000Cooooo1Ooo000;ooooobCoo`004?ooool6ool002Oooooo000Vooooo`ko
000000?oo`00o`000?l000001?l000000ooo003o0000o`000003o`000003ool00?l0003o000000Wo
000000?oo`00o`000?l000000ol000000ooo003o0000o`000004o`000003ool00?l0003o000000Wo
000000?oo`00o`000?l000000ol000000ooo003o0000o`000003o`000003ool00?l0003o000000Wo
000000?oo`00o`000?l000001?l000000ooo003o0000o`000003o`000003ool00?l0003o000000[o
000000?oo`00o`000?l000000_l000000ooo003o0000o`000003o`000003ool00?l0003o000000[o
000000?oo`00o`000?l000001?l000000ooo003o0000o`000002o`000003ool00?l0003o000000So
000000?oo`00o`000?l000000ol00002ool000Co00000_oo000=o`000003ool00?l0003o000000?o
00000ooo0003o`0000;oo`002?l00002ool000;o00001Ooo0002o`0000?oo`003Ol00003ool000;o
00001ooo0002o`0000;oo`000_l0000:ool000Go00000ooo000<o`0002?oo`002?l0000Oooooo`00
;_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooooooo
00000_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool00oooool01?oo003oooooooooool00007ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`07ooooo`04o`000?ooooooooooool000Kooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`08ooooo`06ool00?ooooooooooooooool0003oo`00
1Oooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool2ool00004o`000?ooooooooooool000Sooooo00Ooo`00ooooooooooooooooo`000?oooooo
o`0000Gooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`07ooooo`;oo`001?ooool0
0ol0003oooooool00002ool000;ooooo00?oo`00ooooooooool00_ooool7ool000Cooooo0ooo0005
ooooo`03o`000?oooooooooo00_ooooo1ooo0002oooooaGoo`000oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;ooooo2?oo0003ooooo`03o`000?oooooooooo00Goo`001oooool0
0ol0003oooooooooo`0Uooooo`00;_ooool2o`0000Cooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Sooooo00Co0000ooooooooooooo`001_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00gooooo0_oo0006ooooo`05ool00?oooooo
oooooooooooo00001_ooool00ooo003oooooooooo`02ooooo`;oo`001Oooool00ooo003ooooooooo
o`0Aooooo`;oo`001oooool:ool000Gooooo0ooo000Hooooo`04o`000?ooooooooooooooo`Coo`00
AOooool00ol0003oooooooooo`0Uooooo`00;_ooool00ol0003oooooooooo`03ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`07ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0<ooooo`03ool00?oo
oooooooo00Cooooo0_oo0004ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool01?oo
ool3ool00003oooooooo003ooooo00?ooooo00?oo`00ooooooooool00ooo0005ooooo`;oo`005_oo
ool;ool000;ooooo2Ooo002@ooooo`00;_ooool2o`0000Cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01_ooool0
1Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool01_ooool9ool000Kooooo0_oo
002nooooo`00;_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Kooooo00Goo`00
ooooooooooooooooool00005ooooo`03ool00?oooooooooo00;oo`001_ooool00ooo003ooooooooo
o`0Dooooo`03ool00?oooooooooo00Oooooo1Ooo0007ooooo`03ool00?oooooooooo0;kooooo000^
ooooo`;o00000oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool03?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool03oooool00ooo003oooooooooo`06ooooo`04ool00?ooooooooooool000Cooooo00Co
o`00oooooooo003oo`001oooool00ooo003oooooooooo`0Fooooo`Coo`0000?oooooool00?oo0000
0_oo0005ooooo`Ooo`00`Oooool002kooooo00?o0000ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04?ooool00ooo003ooooooooo
o`07ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo00002?ooool00ooo003ooooo
ooooo`0Jooooo`?oo`00d?ooool002Gooooo0ol00006ooooo`;o00000oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03Oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ooo003ooooooooo
o`07ooooo`Soo`001oooool00ooo003oooooooooo`3^ooooo`009_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool02Oooool2ool000[ooooo00?oo`00
ooooooooool0k_ooool002Kooooo00?o0000ooooooooool01Oooool3o`000003oooooooo003ooooo
00?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00001oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00Oooooo00Coo`00
oooooooo003oo`001oooool2ool00?7ooooo000Vooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03_oo
ool00ooo003oooooooooo`06ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05Oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00;ooooo0_oo0004ooooo`03ool00?oooooooooo0?7ooooo
000Vooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`05ool00?oooooooooooooooooo0000
1oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00Kooooo00Coo`00oooooooooooo
o`000oooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00ooooooooool05oooool2ool0
00;ooooo0ooo0006ooooo`Goo`00m?ooool002Gooooo0_l00007ooooo`05o`000?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo013ooooo00?oo`00oooo
ooooool01_ooool01ooo003oooooooooooooooooo`00oooooooo00001?ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo01Wooooo0ooo003oooooo`;ooooo000Vooooo`03o`000?oooooo
oooo00Gooooo0_l00002ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003ooooooooo
o`0@ooooo`03ool00?oooooooooo00Oooooo0_oo00001?ooooooo`00oooooooo0003ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool0oooooolNooooo`00;_ooool01?l0003ooooooooo
oooo0003ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool04Oooool00ooo003ooooo
ooooo`07ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo0008ooooo`03ool00?oooooooooo
0?oooooo7oooool002kooooo00Co0000ooooooooooooo`000oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo017ooooo00?oo`00ooooooooool02?ooool5ool000[ooooo00?oo`00oooo
ooooool0oooooolOooooo`00;_ooool2o`000005oooooooo003ooooooooooooo00002?ooool00ooo
003oooooooooo`0Booooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`3oooooob3ooooo000Tooooo`Go00001Oooool01?l0003ooooooooooooo0002oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`09oooo
o`;oo`002Oooool00ooo003oooooooooo`3oooooob7ooooo000Uooooo`04o`000?ooooooooooo`00
00Gooooo0_l000001?ooooooo`00oooooooo0009ooooo`03ool00?oooooooooo01?ooooo00?oo`00
ooooooooool02?ooool00ooo003oooooool00008ooooo`03ool00?oooooooooo0?oooooo8_ooool0
02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooool00002ooooo`03ool00?oooooooooo
00Oooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`07ooooo`04ool00?oooooooooo
ool000Oooooo00?oo`00ooooooooool0oooooolRooooo`009oooool00ol0003oooooooooo`04oooo
o`;o000000Coo`00ooooooooooooo`002Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo0?oooooo8oooool002Cooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
o`00oooooooo00002Oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`000?oooooo9_ooool002Cooooo00Go
0000ooooooooooooooooo`000005ooooo`;o000000?oo`00oooooooo00002Oooool00ooo003ooooo
ooooo`0Hooooo`05ool00?oooooooooooooooooo00002?ooool3ool00?oooooo9oooool002Gooooo
0ol00006ooooo`04o`000?ooooooo`00ool000[ooooo00?oo`00ooooooooool06?ooool4ool00?oo
oooo<oooool002kooooo00Co0000ool00?ooooooo`002_ooool00ooo003oooooooooo`3oooooodoo
oooo000^ooooo`03o`000?oo003oo`0000_ooooo00?oo`00ooooooooool0oooooom?ooooo`00;_oo
ool00ol0003oo`00ool0000:ooooo`03ool00?oooooooooo0?ooooooD?ooool002kooooo00?o0000
ool00?oo00002_ooool00ooo003oooooooooo`3ooooooe3ooooo000Uooooo`?o00001_ooool00ol0
003oo`00ooooo`0:ooooo`03ool00?oooooooooo0?ooooooD?ooool002Cooooo00Go0000oooooooo
ooooooooo`000005ooooo`;oo`002_ooool00ooo003oooooooooo`3ooooooe7ooooo000Xooooo`03
o`000?oooooooooo00?ooooo00?oo`00o`000?l000002Oooool00ooo003oooooooooo`3ooooooe7o
oooo000Vooooo`;o00001_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo0?oooooo
DOooool002Sooooo00?o0000ooooooooool00oooool00ol0003oo`00ooooo`08ooooo`03ool00?oo
oooooooo0?ooooooD_ooool002Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
003ooooo00Sooooo00?oo`00ooooooooool0oooooomBooooo`009Oooool3o`0000Kooooo00?o0000
ool00?ooool02?ooool00ooo003oooooooooo`3ooooooe;ooooo000^ooooo`;o000000?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`3ooooooe;ooooo000^ooooo`03o`000?ooooooo`0000Oo
oooo00?oo`00ooooooooool0oooooomCooooo`00;_ooool2o`000003ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0oooooomCooooo`00;_ooool00ol0003oooooool00007ooooo`03ool00?oo
oooooooo0?ooooooDoooool002Kooooo0ol00005ooooo`;o000000?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`3ooooooeCooooo000Wooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
ooooooooo`001Oooool00ooo003oooooooooo`3ooooooeCooooo000Tooooo`Go00001Oooool3o`00
0003oooooooo003ooooo00;ooooo00?oo`00ooooooooool0oooooomEooooo`009?ooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00;ooooo0ooo003ooooooeSooooo000Uooooo`03
o`000?oooooo000000Kooooo0_l0003ooooooekooooo000Vooooo`;o00001_ooool00ol0003ooooo
ooooo`3ooooooegooooo000Wooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooS_ooool0
0?ooooooS_ooool00?ooooooS_ooool00?ooooooS_ooool00?ooooooS_ooool00?ooooooS_ooool0
0;;ooooo0ol00004ooooo`?o00000_ooool4o`0000;ooooo1Ol00003ooooo`;o00000_ooool5o`00
00;ooooo0ol00002ooooo`?o000000?oooooo`000?l00000Zoooool00;?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool0Z_ooool00;?ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol00004ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`2Zooooo`00/oooool3o`0000;ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo0:[ooooo002cooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`Co
000000Coooooo`000?l0003o00000oooool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4o`00
0:gooooo002cooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0_oooool00;;o
oooo1?l0000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`2hooooo`00oooooon>ooooo`00oooooon>ooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 474.125}, {619.688, 521.375}} -> {-15.9988, \
45.6498, 0.128498, 0.0941229}}]
}, Open  ]],

Cell["Here are the corresponding velocity curves. ", "Text"],

Cell[TextData[{
  StyleBox["Recall that the partial derivative of phi with respect to t is \
obtained in ", "Note"],
  StyleBox["Mathematica", "Note",
    FontSlant->"Italic"],
  StyleBox[" with D[ phi[y0,t0,t] , t ] .", "Note"]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ Evaluate[Table[D[phi1[3,v,t],t],{v,-3,3,3}]], {t,0,40},
      PlotStyle->RGBColor[0,0,1], AspectRatio->1/4, PlotLabel->\"Velocity\" 
    ]\
\>", "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.138634 0.035138 [
[.2619 .12613 -6 -9 ]
[.2619 .12613 6 0 ]
[.5 .12613 -6 -9 ]
[.5 .12613 6 0 ]
[.7381 .12613 -6 -9 ]
[.7381 .12613 6 0 ]
[.97619 .12613 -6 -9 ]
[.97619 .12613 6 0 ]
[.01131 .03322 -12 -4.5 ]
[.01131 .03322 0 4.5 ]
[.01131 .06836 -12 -4.5 ]
[.01131 .06836 0 4.5 ]
[.01131 .1035 -12 -4.5 ]
[.01131 .1035 0 4.5 ]
[.01131 .17377 -6 -4.5 ]
[.01131 .17377 0 4.5 ]
[.01131 .20891 -6 -4.5 ]
[.01131 .20891 0 4.5 ]
[.01131 .24405 -6 -4.5 ]
[.01131 .24405 0 4.5 ]
[.5 .2625 -26 0 ]
[.5 .2625 26 12 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .13863 m
.2619 .14488 L
s
[(10)] .2619 .12613 0 1 Mshowa
.5 .13863 m
.5 .14488 L
s
[(20)] .5 .12613 0 1 Mshowa
.7381 .13863 m
.7381 .14488 L
s
[(30)] .7381 .12613 0 1 Mshowa
.97619 .13863 m
.97619 .14488 L
s
[(40)] .97619 .12613 0 1 Mshowa
.125 Mabswid
.07143 .13863 m
.07143 .14238 L
s
.11905 .13863 m
.11905 .14238 L
s
.16667 .13863 m
.16667 .14238 L
s
.21429 .13863 m
.21429 .14238 L
s
.30952 .13863 m
.30952 .14238 L
s
.35714 .13863 m
.35714 .14238 L
s
.40476 .13863 m
.40476 .14238 L
s
.45238 .13863 m
.45238 .14238 L
s
.54762 .13863 m
.54762 .14238 L
s
.59524 .13863 m
.59524 .14238 L
s
.64286 .13863 m
.64286 .14238 L
s
.69048 .13863 m
.69048 .14238 L
s
.78571 .13863 m
.78571 .14238 L
s
.83333 .13863 m
.83333 .14238 L
s
.88095 .13863 m
.88095 .14238 L
s
.92857 .13863 m
.92857 .14238 L
s
.25 Mabswid
0 .13863 m
1 .13863 L
s
.02381 .03322 m
.03006 .03322 L
s
[(-3)] .01131 .03322 1 0 Mshowa
.02381 .06836 m
.03006 .06836 L
s
[(-2)] .01131 .06836 1 0 Mshowa
.02381 .1035 m
.03006 .1035 L
s
[(-1)] .01131 .1035 1 0 Mshowa
.02381 .17377 m
.03006 .17377 L
s
[(1)] .01131 .17377 1 0 Mshowa
.02381 .20891 m
.03006 .20891 L
s
[(2)] .01131 .20891 1 0 Mshowa
.02381 .24405 m
.03006 .24405 L
s
[(3)] .01131 .24405 1 0 Mshowa
.125 Mabswid
.02381 .04025 m
.02756 .04025 L
s
.02381 .04727 m
.02756 .04727 L
s
.02381 .0543 m
.02756 .0543 L
s
.02381 .06133 m
.02756 .06133 L
s
.02381 .07539 m
.02756 .07539 L
s
.02381 .08241 m
.02756 .08241 L
s
.02381 .08944 m
.02756 .08944 L
s
.02381 .09647 m
.02756 .09647 L
s
.02381 .11052 m
.02756 .11052 L
s
.02381 .11755 m
.02756 .11755 L
s
.02381 .12458 m
.02756 .12458 L
s
.02381 .13161 m
.02756 .13161 L
s
.02381 .14566 m
.02756 .14566 L
s
.02381 .15269 m
.02756 .15269 L
s
.02381 .15972 m
.02756 .15972 L
s
.02381 .16674 m
.02756 .16674 L
s
.02381 .1808 m
.02756 .1808 L
s
.02381 .18783 m
.02756 .18783 L
s
.02381 .19485 m
.02756 .19485 L
s
.02381 .20188 m
.02756 .20188 L
s
.02381 .21594 m
.02756 .21594 L
s
.02381 .22297 m
.02756 .22297 L
s
.02381 .22999 m
.02756 .22999 L
s
.02381 .23702 m
.02756 .23702 L
s
.02381 .02619 m
.02756 .02619 L
s
.02381 .01916 m
.02756 .01916 L
s
.02381 .01214 m
.02756 .01214 L
s
.02381 .00511 m
.02756 .00511 L
s
.25 Mabswid
.02381 0 m
.02381 .25 L
s
gsave
.5 .2625 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Velocity) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .03322 m
.02605 .02582 L
.02846 .01916 L
.03053 .01447 L
.03279 .01054 L
.03416 .00873 L
.03543 .00746 L
.03665 .00661 L
.03793 .00609 L
.03908 .00595 L
.04016 .00611 L
.04135 .00659 L
.04262 .00746 L
.04393 .00874 L
.04516 .01027 L
.04793 .01492 L
.05037 .02031 L
.05297 .02728 L
.06244 .06156 L
.07287 .10934 L
.08414 .16218 L
.08932 .18378 L
.09479 .20331 L
.09945 .2167 L
.10191 .22237 L
.10458 .22741 L
.10603 .22964 L
.10737 .23138 L
.10862 .23272 L
.11001 .23389 L
.11125 .23465 L
.11241 .23512 L
.11364 .23537 L
.11433 .23539 L
.11496 .23534 L
.11561 .23522 L
.1163 .23501 L
.11755 .23444 L
.11831 .23396 L
.11903 .23342 L
.12038 .23219 L
.12312 .22883 L
.12609 .22394 L
.13116 .2129 L
.13653 .19814 L
.14616 .16656 L
.15632 .13133 L
.16596 .10163 L
.17015 .09102 L
.17461 .08174 L
Mistroke
.17718 .07742 L
.17951 .07419 L
.18185 .07163 L
.18405 .06985 L
.18518 .06917 L
.18642 .06862 L
.18771 .06824 L
.18892 .06809 L
.19005 .0681 L
.19108 .06826 L
.19227 .0686 L
.1934 .06907 L
.19462 .06976 L
.19591 .07068 L
.19824 .0728 L
.20074 .07573 L
.2035 .07969 L
.21428 .10102 L
.22439 .12604 L
.23425 .15058 L
.23962 .16253 L
.24461 .17212 L
.24925 .17939 L
.25346 .18445 L
.25587 .18663 L
.25814 .18821 L
.25939 .18887 L
.26053 .18936 L
.2618 .18975 L
.26243 .18989 L
.26313 .19 L
.26443 .19009 L
.26563 .19004 L
.26695 .18983 L
.26762 .18966 L
.26836 .18944 L
.26959 .18895 L
.27092 .18829 L
.27332 .18671 L
.27568 .18473 L
.27817 .18219 L
.28261 .17664 L
.30352 .14047 L
.31305 .12392 L
.31829 .11619 L
.32324 .11015 L
.32785 .10583 L
.33045 .10399 L
.33285 .10269 L
.33487 .10189 L
Mistroke
.33602 .10156 L
.3371 .10134 L
.33823 .10118 L
.33927 .10112 L
.34046 .10113 L
.3416 .10123 L
.34284 .10143 L
.34354 .10159 L
.34419 .10176 L
.34663 .10265 L
.34885 .10377 L
.35119 .10525 L
.35607 .10924 L
.36142 .11482 L
.37981 .13878 L
.38984 .15119 L
.39477 .15626 L
.39933 .16011 L
.40183 .16183 L
.40458 .1634 L
.40734 .16461 L
.40886 .16511 L
.41028 .16548 L
.4115 .16572 L
.41278 .16589 L
.41388 .16597 L
.41508 .166 L
.41638 .16595 L
.4171 .16588 L
.41776 .1658 L
.41904 .16559 L
.42025 .16532 L
.42265 .16459 L
.42489 .16369 L
.42999 .1609 L
.43495 .15733 L
.44028 .15279 L
.45874 .13496 L
.46888 .12652 L
.47462 .12292 L
.47735 .12156 L
.47993 .12051 L
.48239 .11973 L
.48368 .1194 L
.48504 .11913 L
.48619 .11894 L
.48746 .1188 L
.4886 .11872 L
.48967 .11868 L
.49032 .11868 L
Mistroke
.49102 .11869 L
.49229 .11876 L
.49353 .11889 L
.49468 .11905 L
.49592 .11927 L
.49728 .11957 L
.50004 .12035 L
.50523 .12243 L
.51017 .12502 L
.51944 .13102 L
.52954 .13827 L
.54031 .14538 L
.54566 .14827 L
.55069 .15044 L
.55521 .15188 L
.55776 .15246 L
.55889 .15266 L
.56011 .15284 L
.56126 .15298 L
.56231 .15307 L
.56337 .15314 L
.56437 .15318 L
.56553 .15319 L
.56661 .15316 L
.56779 .1531 L
.56905 .153 L
.57016 .15288 L
.57136 .15272 L
.57354 .15233 L
.57612 .15174 L
.57849 .15107 L
.58829 .14727 L
.59741 .14274 L
.60805 .1372 L
.61328 .13469 L
.6181 .13263 L
.62278 .13095 L
.62791 .1295 L
.63058 .12894 L
.63308 .12853 L
.63446 .12836 L
.63572 .12823 L
.63641 .12817 L
.63717 .12812 L
.63789 .12808 L
.63855 .12805 L
.63972 .12803 L
.64099 .12802 L
.64218 .12805 L
.64327 .1281 L
Mistroke
.64427 .12816 L
.64536 .12825 L
.64755 .12848 L
.64995 .12884 L
.65251 .12932 L
.65714 .13042 L
.67698 .13733 L
.68744 .14117 L
.69317 .14298 L
.69854 .14438 L
.70328 .14532 L
.70595 .14573 L
.7084 .14601 L
.70962 .14613 L
.71093 .14622 L
.71168 .14627 L
.71236 .1463 L
.71301 .14633 L
.71369 .14635 L
.71441 .14636 L
.71507 .14637 L
.71578 .14637 L
.71656 .14637 L
.71724 .14635 L
.71796 .14633 L
.71927 .14628 L
.72054 .14621 L
.72173 .14612 L
.72441 .14586 L
.72677 .14556 L
.72928 .14518 L
.73842 .14328 L
.75808 .13796 L
.7667 .13582 L
.77158 .13482 L
.77613 .13407 L
.78067 .1335 L
.78322 .13328 L
.78553 .13313 L
.7868 .13307 L
.78798 .13303 L
.78926 .133 L
.78991 .13299 L
.79063 .13299 L
.79183 .133 L
.79311 .13302 L
.79433 .13305 L
.79544 .1331 L
.79673 .13316 L
.79809 .13325 L
Mistroke
.80055 .13345 L
.80613 .13408 L
.81146 .13488 L
.81629 .13574 L
.82644 .13776 L
.83716 .13987 L
.84632 .14135 L
.85151 .14198 L
.85636 .14241 L
.85876 .14256 L
.86011 .14262 L
.86136 .14267 L
.86245 .1427 L
.86366 .14273 L
.86492 .14275 L
.8661 .14275 L
.86718 .14274 L
.86833 .14273 L
.8693 .14271 L
.87037 .14268 L
.87152 .14264 L
.87275 .14259 L
.87497 .14246 L
.88035 .14205 L
.88543 .14152 L
.89492 .14026 L
.91324 .13761 L
.91826 .137 L
.92366 .13644 L
.92627 .13622 L
.92874 .13604 L
.93118 .1359 L
.93339 .13579 L
.93579 .13571 L
.9371 .13568 L
.93833 .13565 L
.93948 .13564 L
.94053 .13563 L
.94169 .13563 L
.94291 .13564 L
.94414 .13566 L
.94484 .13567 L
.94547 .13568 L
.94785 .13575 L
.94919 .1358 L
.95064 .13586 L
.95328 .136 L
.95858 .13637 L
.96422 .13686 L
.97432 .1379 L
Mistroke
.97619 .1381 L
Mfstroke
.02381 .13863 m
.03279 .10125 L
.03793 .08307 L
.04262 .06937 L
.04758 .05831 L
.0503 .05385 L
.05156 .05221 L
.05288 .05074 L
.05402 .04972 L
.05527 .04883 L
.0564 .04825 L
.05747 .04789 L
.05872 .04771 L
.05987 .04776 L
.06119 .04808 L
.06244 .04864 L
.0631 .04903 L
.06381 .04953 L
.0651 .05062 L
.0675 .0533 L
.07031 .05746 L
.07289 .06218 L
.08259 .08626 L
.09396 .12219 L
.10458 .15611 L
.11366 .18045 L
.11876 .19093 L
.1234 .19807 L
.12604 .20102 L
.12849 .20303 L
.12976 .20379 L
.13117 .20441 L
.13187 .20463 L
.13264 .2048 L
.13336 .2049 L
.13402 .20494 L
.13523 .20488 L
.13635 .20467 L
.13759 .20427 L
.13891 .20365 L
.1403 .2028 L
.14161 .2018 L
.14407 .19946 L
.1487 .19346 L
.15379 .1848 L
.16408 .16267 L
.18253 .11999 L
.18775 .11002 L
.1927 .10218 L
.19714 .09672 L
Mistroke
.19965 .09435 L
.20198 .09263 L
.2033 .09186 L
.20472 .0912 L
.20537 .09096 L
.20606 .09074 L
.20729 .09046 L
.20848 .09031 L
.20959 .09028 L
.2108 .09037 L
.2121 .0906 L
.21282 .09078 L
.21349 .091 L
.215 .09161 L
.21774 .09318 L
.22023 .09509 L
.22287 .09759 L
.23227 .10975 L
.24238 .12651 L
.25187 .14292 L
.26068 .15651 L
.26571 .16287 L
.27027 .16751 L
.27271 .16949 L
.27534 .17124 L
.27679 .17201 L
.27813 .17261 L
.2794 .17307 L
.28009 .17328 L
.28076 .17345 L
.28208 .17371 L
.28328 .17385 L
.28441 .1739 L
.28565 .17386 L
.28629 .1738 L
.287 .17371 L
.28774 .17358 L
.28844 .17343 L
.28968 .17309 L
.29102 .17262 L
.29377 .17134 L
.29668 .16956 L
.30187 .16537 L
.32181 .14205 L
.33051 .13139 L
.33994 .12176 L
.34518 .11775 L
.34748 .11635 L
.35002 .11508 L
.3524 .11414 L
Mistroke
.35464 .11351 L
.35587 .11325 L
.35699 .11309 L
.3583 .11296 L
.35953 .11292 L
.36085 .11295 L
.36205 .11304 L
.36271 .11312 L
.36343 .11323 L
.36473 .11348 L
.36724 .11417 L
.36955 .11502 L
.37486 .11775 L
.38047 .12159 L
.40035 .13923 L
.40903 .14662 L
.41361 .14995 L
.41846 .1529 L
.42094 .15414 L
.42368 .15528 L
.42619 .15612 L
.42849 .1567 L
.42964 .15693 L
.43085 .15712 L
.43207 .15725 L
.43275 .15731 L
.43339 .15735 L
.43456 .15739 L
.43562 .15738 L
.43684 .15732 L
.43799 .15723 L
.4392 .15708 L
.44053 .15687 L
.44321 .15628 L
.4457 .15554 L
.44803 .1547 L
.45891 .14917 L
.4775 .13691 L
.48731 .13112 L
.49279 .12857 L
.49775 .12681 L
.50048 .12608 L
.50191 .12577 L
.50342 .1255 L
.50475 .1253 L
.50545 .12522 L
.5062 .12514 L
.50752 .12504 L
.50875 .12498 L
.51007 .12496 L
Mistroke
.51081 .12496 L
.51149 .12498 L
.51275 .12504 L
.51339 .12509 L
.51409 .12515 L
.51529 .12528 L
.51659 .12546 L
.51894 .12588 L
.52152 .12646 L
.52432 .12725 L
.52944 .12902 L
.53905 .13324 L
.55002 .13862 L
.56036 .14328 L
.56487 .14497 L
.56964 .14645 L
.57213 .14708 L
.57487 .14765 L
.57736 .14805 L
.57968 .14833 L
.58094 .14844 L
.58211 .14852 L
.58339 .14858 L
.58404 .14859 L
.58475 .1486 L
.58594 .1486 L
.58723 .14857 L
.58844 .14852 L
.58955 .14845 L
.59165 .14825 L
.59394 .14796 L
.59856 .14714 L
.60363 .14592 L
.60904 .14431 L
.6188 .14094 L
.62904 .13731 L
.63443 .13557 L
.64014 .13399 L
.64513 .13287 L
.64777 .1324 L
.65062 .13198 L
.65323 .1317 L
.65561 .13151 L
.65676 .13145 L
.65801 .1314 L
.65919 .13137 L
.66029 .13136 L
.66158 .13137 L
.66223 .13138 L
.66294 .1314 L
Mistroke
.6642 .13145 L
.66537 .13152 L
.66803 .13172 L
.67087 .13203 L
.67609 .13282 L
.68084 .13374 L
.69946 .13839 L
.70873 .14067 L
.71381 .14174 L
.71857 .14258 L
.7237 .14327 L
.72643 .14354 L
.72783 .14365 L
.72936 .14375 L
.73059 .14382 L
.7319 .14387 L
.73263 .1439 L
.73328 .14391 L
.73457 .14393 L
.73575 .14394 L
.73703 .14393 L
.73823 .14391 L
.73934 .14387 L
.7406 .14382 L
.74179 .14376 L
.74403 .14362 L
.74643 .14341 L
.74905 .14314 L
.75813 .14186 L
.77878 .13804 L
.78368 .13719 L
.78896 .13637 L
.79362 .13577 L
.79852 .13528 L
.80101 .1351 L
.80232 .13501 L
.80373 .13494 L
.80502 .13488 L
.8062 .13484 L
.80738 .13481 L
.8085 .13478 L
.80913 .13478 L
.80983 .13477 L
.81056 .13477 L
.81125 .13477 L
.81247 .13478 L
.81378 .1348 L
.81452 .13481 L
.81532 .13484 L
.81678 .13489 L
Mistroke
.81952 .13502 L
.82207 .13518 L
.82484 .1354 L
.82984 .13588 L
.8392 .13703 L
.8492 .13842 L
.86017 .13985 L
.86515 .14038 L
.87049 .14086 L
.87308 .14104 L
.87553 .14118 L
.87773 .14128 L
.88012 .14137 L
.88142 .1414 L
.88264 .14143 L
.88334 .14144 L
.88398 .14144 L
.88468 .14145 L
.88542 .14145 L
.8861 .14145 L
.88682 .14145 L
.88812 .14144 L
.88891 .14143 L
.88966 .14142 L
.89106 .14139 L
.89229 .14136 L
.89359 .14131 L
.89592 .14122 L
.90118 .14092 L
.90612 .14055 L
.91062 .14016 L
.92076 .13916 L
.93027 .13821 L
.93908 .13745 L
.94351 .13714 L
.94768 .13691 L
.94999 .1368 L
.95249 .13671 L
.95475 .13665 L
.95584 .13663 L
.95684 .13661 L
.95796 .1366 L
.95916 .13658 L
.96028 .13658 L
.96133 .13658 L
.96256 .13658 L
.96369 .13659 L
.96494 .1366 L
.96626 .13662 L
.96869 .13668 L
Mistroke
.97098 .13675 L
.97619 .13696 L
Mfstroke
.02381 .24405 m
.04262 .13128 L
.0522 .07784 L
.05746 .05379 L
.06244 .03573 L
.06506 .02827 L
.0679 .02185 L
.06915 .01958 L
.07047 .01756 L
.07172 .01603 L
.07286 .01493 L
.074 .01412 L
.07524 .01357 L
.07638 .01338 L
.07747 .01345 L
.07873 .01387 L
.0799 .01456 L
.08119 .01566 L
.08255 .01721 L
.08541 .02165 L
.0885 .02821 L
.09411 .04423 L
.10458 .08482 L
.12413 .17061 L
.12948 .19039 L
.13522 .20778 L
.13801 .21455 L
.14064 .21987 L
.14301 .22371 L
.14425 .22536 L
.14558 .22686 L
.14686 .22801 L
.14802 .22884 L
.14914 .22942 L
.15031 .22981 L
.1516 .22998 L
.1528 .2299 L
.15412 .22954 L
.15486 .22922 L
.15553 .22886 L
.15689 .22791 L
.15814 .2268 L
.16096 .22343 L
.16346 .21955 L
.16609 .21457 L
.17513 .19193 L
.18507 .16065 L
.19505 .12815 L
.20452 .10124 L
.20974 .0895 L
Mistroke
.2125 .08441 L
.21544 .07991 L
.21815 .07663 L
.22061 .07441 L
.2218 .07359 L
.22308 .0729 L
.2243 .07243 L
.22541 .07216 L
.22668 .07202 L
.22788 .07207 L
.22895 .07225 L
.23012 .0726 L
.2314 .07316 L
.23275 .07395 L
.23517 .07586 L
.23741 .07816 L
.2395 .08075 L
.24427 .0881 L
.25423 .1084 L
.26495 .1339 L
.27536 .15747 L
.28503 .17463 L
.28991 .18074 L
.29264 .18331 L
.29512 .18508 L
.29654 .18586 L
.29784 .18642 L
.29858 .18667 L
.29928 .18686 L
.3 .18702 L
.30079 .18714 L
.30149 .1872 L
.30214 .18721 L
.30337 .18715 L
.30406 .18705 L
.3047 .18693 L
.3054 .18676 L
.30614 .18653 L
.30852 .1855 L
.30971 .18482 L
.31102 .18394 L
.3155 .18002 L
.32072 .17383 L
.32559 .16681 L
.34386 .13564 L
.35437 .11942 L
.35953 .11311 L
.36429 .10856 L
.36653 .10688 L
.36862 .10559 L
Mistroke
.3708 .10454 L
.37196 .10411 L
.3732 .10374 L
.37444 .10346 L
.37514 .10335 L
.37579 .10328 L
.37699 .10321 L
.37826 .10324 L
.3795 .10336 L
.38068 .10356 L
.38173 .10381 L
.38287 .10416 L
.38525 .10512 L
.3878 .1065 L
.39239 .1098 L
.40283 .12046 L
.4239 .14662 L
.43408 .15674 L
.43687 .15887 L
.43983 .16078 L
.44239 .16212 L
.44374 .1627 L
.44515 .16323 L
.44638 .16361 L
.44773 .16395 L
.44895 .16418 L
.45009 .16434 L
.45126 .16443 L
.45233 .16447 L
.45356 .16444 L
.45472 .16435 L
.456 .16419 L
.45665 .16408 L
.45736 .16394 L
.45979 .16329 L
.46262 .16222 L
.46528 .16095 L
.47026 .15792 L
.4757 .15382 L
.48558 .14505 L
.49514 .13622 L
.50412 .12885 L
.5091 .12552 L
.51172 .12405 L
.51448 .12271 L
.51681 .12178 L
.51936 .12095 L
.52048 .12066 L
.52168 .12039 L
.52273 .1202 L
Mistroke
.52385 .12004 L
.52452 .11996 L
.52526 .11989 L
.52656 .11981 L
.52729 .1198 L
.52807 .1198 L
.52882 .11982 L
.5295 .11985 L
.53081 .11996 L
.53155 .12004 L
.53223 .12014 L
.53484 .12063 L
.53738 .1213 L
.53968 .12207 L
.54484 .12427 L
.5657 .13732 L
.57485 .14324 L
.57969 .14598 L
.58489 .14846 L
.5875 .1495 L
.58996 .15034 L
.59236 .15103 L
.59458 .15154 L
.59668 .15191 L
.59774 .15206 L
.59892 .15218 L
.60009 .15228 L
.60135 .15235 L
.60254 .15237 L
.60363 .15236 L
.60478 .15233 L
.60602 .15225 L
.60718 .15215 L
.60824 .15203 L
.61083 .15162 L
.61327 .15111 L
.61815 .14974 L
.62343 .14781 L
.64291 .13859 L
.65324 .13392 L
.65893 .13183 L
.66174 .13097 L
.66434 .13028 L
.66701 .1297 L
.66942 .12927 L
.67211 .12893 L
.67358 .12879 L
.67424 .12874 L
.67497 .1287 L
.67615 .12865 L
Mistroke
.6774 .12862 L
.67856 .12862 L
.67964 .12864 L
.68091 .12869 L
.68208 .12876 L
.68342 .12887 L
.68469 .129 L
.68699 .1293 L
.68943 .12971 L
.69381 .13065 L
.70373 .13356 L
.72345 .14051 L
.73209 .14309 L
.73698 .14423 L
.74152 .14505 L
.74391 .14538 L
.74609 .14561 L
.74729 .14571 L
.7486 .1458 L
.74983 .14587 L
.75096 .14591 L
.75215 .14593 L
.75326 .14594 L
.75448 .14593 L
.75579 .1459 L
.75645 .14587 L
.75716 .14584 L
.75846 .14576 L
.7609 .14557 L
.76339 .1453 L
.76615 .14492 L
.77173 .14394 L
.78176 .14162 L
.79196 .13895 L
.8027 .13632 L
.80713 .13541 L
.81187 .13459 L
.8146 .13421 L
.81708 .13391 L
.81938 .13369 L
.82069 .13359 L
.82192 .1335 L
.82318 .13343 L
.82433 .13338 L
.82555 .13334 L
.82688 .13332 L
.828 .13331 L
.82922 .13331 L
.83038 .13332 L
.83145 .13335 L
Mistroke
.8321 .13337 L
.8328 .1334 L
.83407 .13346 L
.83645 .1336 L
.83923 .13383 L
.84179 .1341 L
.85092 .13539 L
.86056 .13714 L
.87077 .13909 L
.88043 .14072 L
.88464 .14129 L
.88911 .1418 L
.89144 .14201 L
.89401 .1422 L
.89635 .14234 L
.89854 .14243 L
.89968 .14247 L
.90093 .1425 L
.90223 .14251 L
.90344 .14252 L
.90458 .14252 L
.90562 .1425 L
.90681 .14248 L
.90794 .14245 L
.90916 .14241 L
.91046 .14236 L
.91279 .14224 L
.91806 .14185 L
.92321 .14133 L
.92802 .14076 L
.93898 .13927 L
.94895 .13791 L
.95387 .13731 L
.95842 .13683 L
.96289 .13643 L
.96692 .13615 L
.96924 .13603 L
.97141 .13594 L
.97371 .13586 L
.975 .13583 L
.97619 .13582 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{402.25, 100.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006B0000I2000`400?l00000o`00003o;Oooool0
0ol0003oooooooooo`3oooooof?ooooo000]ooooo`03o`000?oooooooooo0?ooooooHoooool002go
oooo0ol000000ooooooo003oo`00o`02o`00ooooooooG_ooool002gooooo00?o0000ooooooooool0
0_l00?l2ooooo`;o003ooooooomMooooo`00;Oooool3o`000003o`00oooooooooooo00;ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`3ooooooe7ooooo000]ooooo`04o`000?oooooo
ooooo`00o`Cooooo00?o003oooooooooool01Oooool2o`00o`03ooooool00?oo003o0?ooooooDOoo
ool002gooooo0_l000000ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003o
ooooooooooooooooo`00o`3ooooooe7ooooo000]ooooo`03o`000?oooooo003o00Kooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo0?ooooooC_ooool0
02gooooo00?o0000o`00ooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool0oooooom>ooooo`009?ooool3o`0000Kooooo00?o0000o`00ool0
00001oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool0oooooom=oooo
o`008oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000o`00ooooool01oooool01Ol0
0?oooooooooooooooooo003o00Oooooo00?o003oooooooooool0oooooom=ooooo`007Oooool5o`00
00Gooooo00?o0000ooooooooool00oooool00ol00?oo0000o`000007ooooo`04o`00oooooooooooo
o`00o`Wooooo00?o003oooooooooool0oooooom<ooooo`009Oooool2o`0000Kooooo00?o0000oooo
ooooool02?ooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooooooo0?ooooooC?ooool002Oo
oooo00?o0000ooooooooool00oooool3o`0000Sooooo00?o003oooooool00?l02Oooool00ol00?oo
ooooooooo`3oooooodcooooo000Sooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooo003o00[ooooo00?o003oooooooooool0oooooom;ooooo`00
9?ooool3o`0000Kooooo00?o0000ooooooooool02Oooool2o`00o`[ooooo00?o003oooooooooool0
oooooom;ooooo`00;Oooool3o`0000Sooooo1?l00?l9ooooo`03o`00oooooooooooo0?ooooooBooo
ool002gooooo00?o0000ooooooooool01oooool01Ol00?ooooooo`00oooooooo003o00Wooooo00?o
003oooooooooool0oooooom;ooooo`00;Oooool3o`0000Kooooo00Co003ooooooooooooo003o0_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo0?ooooooB_ooool002gooooo00?o0000
ooooooooool01Oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`3ooooood[ooooo000Sooooo`Go00001Oooool3o`0000Gooooo00Co003o
oooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0oooo
oom:ooooo`009?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Gooooo00Ko
003ooooooooooooo003oooooool00?l3ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool0oooooom:ooooo`007Oooool5o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`03ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool0oooooom9ooooo`009_ooool00ol0003oooooooooo`04ooooo`?o
00001?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`07
ooooo`03o`00oooooooooooo01Wooooo1?l00?ooooooobcooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00_oo
ool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`02ooooo`;o003o1_ooool5o`00oooooooo7oooool002?ooooo00Go0000oooooooooooooooo
o`000005ooooo`?o00000oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`07ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`03ooooo`;o003o0oooool2o`00oooooooo7_ooool002Cooooo0ol00006ooooo`03
o`000?oooooooooo00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
0?oooooo6oooool002gooooo0ol00003ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`06
ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`3ooooooa_ooooo000]
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo00Kooooo00Co003ooooooooooooo003o2Oooool00ol00?ooooooooooo`3ooooooa[ooooo
000]ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Dooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l02_ooool00ol00?oooooooooo
o`3ooooooaWooooo000]ooooo`?o000000?oooooo`00ooooool00oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo00Wooooo1?l00?l9ooooo`03o`00oooooooooooo0?oooooo6Oooool0
02gooooo00Go0000ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool01oooool2o`00o`05ooooool00?ooooooooooool00?l02Oooool00ol00?oooooooooo
o`3ooooooaSooooo000Tooooo`?o00001_ooool3o`000003ooooool00?oooooo00?ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooooooo`;o003o0_oo
ool2o`00o`Oooooo00?o003oooooooooool0oooooolHooooo`009Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`00o`Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`07ooooo`06o`00ooooooooooooo`00oooooooo003o0oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo0?oooooo5oooool001gooooo1Ol00003ooooo`03o`000?oooooooooo00Gooooo
0ol000000ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
1_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`06oooo
o`03o`000?l00?oo000000Cooooo0_l0000Cooooo`Ko003o2?ooool3o`00ob7ooooo1Ol00003oooo
o`;o0000Aoooool3o`0000Cooooo0_l00017ooooo`?o00000oooool2o`0002?ooooo000Uooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo003o1Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`04o`000?oooooo
ooooo`00017ooooo0_l00?l5ooooo`;o003o1?ooool3o`00o`;ooooo0ol00?lOooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000AOooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo0000Aoooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool08?ooool002Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0?l4ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`000?l00?oooooo00;o
oooo00Co0000oooooooooooo00004?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00;o003o1_ooool00ol00?ooooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000BOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo04;ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0002;ooooo000Tooooo`;o00001oooool2o`000003o`00oooo
oooooooo00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00?ooooo00?o0000o`00ooooool00_ooool01?l0003oooooooooool0000?ooooo`03o`00
oooooooooooo00Wooooo0_l00?l9ooooo`;o003o7oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool0AOooool2o`0000?ooooo00Co0000oooooooooooo0000A?ooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0002;ooooo000Uooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00oooool00ol0003oooooo`00o`02ooooo`04o`000?oooooo
ooooo`0000oooooo00?o003oooooooooool01_ooool8o`00o`Sooooo00?o003oooooooooool06Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000BOooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooool000000oooool01?l0
003oooooooooool0000Rooooo`00;Oooool2o`000003o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`;o000000Gooooo
o`00ooooooooooooo`000002ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool01_oo
ool01?l00?ooooooooooooooool2o`00o`?ooooo0_l00?l7ooooo`03o`00oooooooooooo01Sooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004Kooooo0_l00003ooooo`04o`000?oo
ooooooooo`0002;ooooo000]ooooo`03o`000?oooooo003o00Gooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool000000_ooool00ol00?oooooo
ooooo`02o`0000kooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool00_ooool2o`00o`Kooooo00?o003oooooooooool05_ooool9o`00o`;o
00000oooool7o`00ocgooooo0ol00004ooooo`;o0000B?ooool00ol0003oooooooooo`02ooooo`;o
00008oooool002gooooo00?o0000o`00ool000001Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Dooooo`;o003o2Oooool5o`00o`Ko
oooo1?l00?neooooo`00;Oooool00ol0003o003oooooo`04ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo
0_l00?l8ooooo`_o003o1oooool00ol00?ooooooooooo`2booooo`00;Oooool00ol0003o003ooooo
o`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool2o`00o`;ooooo0_l0
0?l3ooooo`04o`00ooooooooooooooooo`?o003o1Oooool2o`00oaKooooo5ol00?n5ooooo`00;Ooo
ool00ol0003o003oo`000004ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Ooo
ool2o`00o`?ooooo00?o003oooooooooool01?ooool2o`00o`Cooooo0_l00?l5ooooo`03o`00oooo
oooooooo013ooooo0ol00?l6ooooo`go003o1?ooool5o`00oaOooooo2Ol00?l5ooooo`Ko003oEOoo
ool002gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Gooooo00Co003ooooooooooooooooo0_l00?l9ooooo`03o`00oooooooooooo00?ooooo0_l0
0?l4ooooo`03o`00oooooooooooo00gooooo0_l00?l5ooooo`Co003o0_ooool2o`00o`Gooooo0_l0
0?l2ooooo`Co003o1Oooool3o`00o`oooooo1Ol00?l3oooooaSo003o5OoooolCo`00obKooooo000U
ooooo`So000000?o003oo`000?l000001?l000000ol00?oo0000o`000009o`000003o`00ool0003o
000000?o000000?o003oo`000?l000000ol000000ol00?oo0000o`00000:o`000003o`00ool0003o
000000Co000000?o003oo`000?l000000ol000000ol00?oo0000o`000009o`000003o`00ool0003o
000000?o000000?o003oo`000?l000000ol000000ol00?oo0000o`00000;o`000003o`00ool0003o
000000?o000000?o003oo`000?l000000ol000000ol00?oo0000o`000009o`000003o`00ool0003o
000000Co000000?o003oo`000?l000000_l000000ol00?oo0000o`00000:o`000003o`00ool0003o
000000Co00000_l00?l3o`000003o`00ool0003o000000[o00000_l00?l5o`0000;o003o0ol00002
o`00o`_o00000_l00?l5o`0000;o003o0ol00003o`00o`Wo00000ol00?l3o`0000Go003o0ol00002
o`00o`[o00000ol00?l2o`0000[o003o2Ol00003o`00o`03o`000?l00?oo003o00co003o2?l0000C
o`00o`03o`000?l00?oo003o00?o003o2?l0000Nooooo`00;Oooool00ol0003oooooooooo`04oooo
o`03o`00oooooooooooo00Kooooo00Co0000oooooooooooo003o1_ooool00ol00?ooooooooooo`02
ooooo`03o`00ool0003ooooo00[ooooo00Oo003oooooooooooooooooo`000?oooooo003o00Kooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00_ooool00ol0003oooooo`00o`0;ooooo`03o`00oooooooo000000?ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
00002oooool2o`00o`;ooooo00Co0000oooooooooooo003o1?ooool00ol00?ooooooooooo`05oooo
o`03o`000?oooooo003o00Cooooo0ol00?l2ooooo`?o003o00?oooooo`000?ooool03?ooool3o`00
o`Gooooo2?l00?l2ooooo`03o`000?oooooo003o00Oo003o0oooool3o`00o`03o`000?oooooooooo
00cooooo00?o0000o`00ool00?l07ol00?l>ooooo`03o`000?oooooooooo02Cooooo000]ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`03ooooo`07
o`00ooooooooooooooooool0003oooooo`00o`0;ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00?ooooo0_l00?l4
ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`03
ooooo`?o003o0_ooool2o`00o`Gooooo0_l00?l2ooooo`?o003o0oooool2o`00oaGooooo1?l00?l6
ooooo`[o003o0_ooool6o`00oa_ooooo1Ol00?lRooooo`03o`000?oooooooooo02Cooooo000]oooo
o`?o00000oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0Booooo`;o003o1_ooool=o`00o`Gooooo00?o003ooooo
ooooool06Oooool7o`00o`Kooooo1Ol00?m_ooooo`00;Oooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool2o`00o`?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`;o003o1Oooool00ol00?ooooooooooo`0Eooooo`;o
003o1oooool7o`00o`Gooooo0ol00?nMooooo`00;Oooool3o`0000?ooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`06ooooo`;o003o0_ooool01?l00?ooooooooooool00?l3ooooo`;o
003o1_ooool00ol00?ooooooooooo`0Hooooo`So003o1Oooool6o`00oj3ooooo000]ooooo`03o`00
0?oooooooooo00?ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool04_ooool2o`00o`Sooooo2Ol00?l7ooooo`03o`00
oooooooooooo0<cooooo000]ooooo`?o00000_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Gooooo00Go003oooooooooooooooooo`00o`06ooooo`05o`00ooooooooooooooooool0
0?l01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Sooooo0_l00?l:ooooo`03
o`00oooooooooooo0<gooooo000]ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00Oooooo00?o003oooooooooool05Oooool2o`00o`Oooooo0_l00?l2oooo
o`?o003o1?ooool3o`00om3ooooo000Tooooo`?o00001_ooool00ol0003oooooooooo`02ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Co003oooooool00?oo003o2?ooool00ol00?ooooooooooo`0Gooooo`Oo003o1_ooool5
o`00om?ooooo000Uooooo`03o`000?oooooooooo00Gooooo0ol00002ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool01oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo
003o00Wooooo00?o003oooooooooool0oOooool002Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool01oooool2o`00
o`05ooooool00?oo003oooooool00?l02Oooool00ol00?ooooooooooo`3nooooo`009Oooool00ol0
003oooooooooo`05ooooo`?o000000?oooooo`00ooooool04?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08oooo
o`Ko003o2?ooool00ol00?ooooooooooo`3oooooo`009Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool00?l04Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`09ooooo`;o003o2_ooool00ol0
0?ooooooooooo`3oooooo`009?ooool2o`0000Oooooo0ol000000ooooooo003oooooo`0@ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo00Oooooo00Co003ooooooooooooo003o1oooool2o`00oooooooo0oooool002Go
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo003o017ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0ooooool3
ooooo`00;Oooool01Ol0003ooooooooooooooooo003o017ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?oo
ool6o`00oooooooo1Oooool002gooooo0ol000000ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool06Oooool5o`00oooooooo4_ooool002gooooo00Co0000
oooooooooooo003o4oooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool00?l0
0_ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo0?oooooo<?ooool002gooooo
0ol000000ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooooooo
oooo0_l00?l3ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0ooooool`ooooo`00
;Oooool01?l0003oooooooooool00?lCooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool00_l00?l2ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0oooooolaooooo`00
8oooool5o`0000Gooooo0ol000000ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool00_l00?l00ooooooo003oooooo`08ooooo`03o`00oooooooooooo0?oooooo
<Oooool002Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00?lDooooo`03
o`00oooooooooooo00Sooooo1Ol00?l:ooooo`03o`00oooooooooooo0?oooooo<Oooool002Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`00o`0Eooooo`03o`00oooooooooooo00[ooooo
0_l00?l:ooooo`03o`00oooooooooooo0?oooooo<_ooool002Kooooo00?o0000ooooooooool01?oo
ool2o`000003o`00oooooooooooo01Cooooo00?o003oooooooooool02Oooool2o`00o`[ooooo00?o
003oooooooooool0oooooolbooooo`008oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooool00?l05_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo003o00[ooooo00?o
003oooooooooool0oooooolbooooo`008oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0
00000ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Oooooo00?o003oooooool00?l02Ooo
ool00ol00?ooooooooooo`3ooooooc?ooooo000Tooooo`?o00001_ooool00ol0003oooooo`00o`0G
ooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooooooo003o1oooool00ol00?oooooooooo
o`3oooooocCooooo000]ooooo`03o`000?l00?oo000001Oooooo00?o003oooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooooooool0ooooooleooooo`00;Oooool0
0ol0003o003oooooo`0Gooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool2
o`00o`Cooooo00?o003oooooooooool0ooooooleooooo`00;Oooool00ol0003o003oooooo`0Hoooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool2o`00o`03ooooool00?oo003o
0?oooooo>?ooool002gooooo00?o0000o`00ool000006Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Oooooo0_l00?ooooooocWooooo000]ooooo`03o`000?l00?oooooo01[ooooo
1?l00?ooooooodGooooo000Tooooo`?o00001_ooool00ol00?oo0000o`00003oooooof?ooooo000S
ooooo`05o`000?ooooooooooooooool000001Oooool00ol00?ooooooooooo`3oooooof?ooooo000W
ooooo`03o`000?oooooooooo00?ooooo00?o003oo`000?l00000oooooomSooooo`009Oooool2o`00
00Kooooo00?o0000ooooooooool0oooooomSooooo`009oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0?ooooooHoooool002?ooooo00Go0000ooooooooooooooooo`00003oooooof_o
oooo000Tooooo`?o0000oooooom/ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCoooo
o`00g_ooool3o`000;7ooooo003Oooooo`03o`000?oooooooooo0;3ooooo002fooooo`03o`000?oo
oooooooo00;ooooo0ol00002ooooo`Go00000_ooool3o`0000?ooooo0ol00002ooooo`Go00000ooo
ool2o`0000Cooooo00?o0000ooooooooool0[oooool00;Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
0:oooooo002fooooo`04o`000?ooooooooooooooo`Go00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool00000/?ooool00;Gooooo00?o0000ooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool00000/?ooool00;Gooooo00?o0000ooooool000000oooool3o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000?ooooo0ol00002ooooo`?o00000oooool4o`0000;ooooo0_l0
00000ooooooo0000o`00002_ooooo`00]Oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0]_ooool00;Cooooo1Ol00007ooooo`?o00004Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0;Kooooo003ooooooi?ooooo003ooooooi?ooooo
0000\
\>"],
  ImageRangeCache->{{{77.875, 479.125}, {209.938, 110.375}} -> {-15.5843, \
5.47147, 0.125911, 0.0853176}}]
}, Open  ]],

Cell["\<\
The phase plane trajectories are drawn next, in green. (Green? \
Sure, red + blue = green.) The three initial  points have also been plotted. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
inits = ListPlot[ Table[{3,k},{k,-3,3,3}], \
PlotStyle->PointSize[0.03]];
Show[ inits, 
      ParametricPlot[ 
      Evaluate[Table[{phi1[3,v,t],D[phi1[3,v,t],t]},{v,-3,3,3}]], 
              {t,0,40}, PlotStyle->RGBColor[0,1,0] ], 
      PlotRange->{{-5,5},{-4,4}}, AspectRatio->4/5]\
\>", "Input",
  CellLabel->"In[14]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.4 0.1 [
[.1 .3875 -6 -9 ]
[.1 .3875 6 0 ]
[.3 .3875 -6 -9 ]
[.3 .3875 6 0 ]
[.7 .3875 -3 -9 ]
[.7 .3875 3 0 ]
[.9 .3875 -3 -9 ]
[.9 .3875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .1 -12 -4.5 ]
[.4875 .1 0 4.5 ]
[.4875 .2 -12 -4.5 ]
[.4875 .2 0 4.5 ]
[.4875 .3 -12 -4.5 ]
[.4875 .3 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .6 -6 -4.5 ]
[.4875 .6 0 4.5 ]
[.4875 .7 -6 -4.5 ]
[.4875 .7 0 4.5 ]
[.4875 .8 -6 -4.5 ]
[.4875 .8 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 .4 m
.1 .40625 L
s
[(-4)] .1 .3875 0 1 Mshowa
.3 .4 m
.3 .40625 L
s
[(-2)] .3 .3875 0 1 Mshowa
.7 .4 m
.7 .40625 L
s
[(2)] .7 .3875 0 1 Mshowa
.9 .4 m
.9 .40625 L
s
[(4)] .9 .3875 0 1 Mshowa
.125 Mabswid
.15 .4 m
.15 .40375 L
s
.2 .4 m
.2 .40375 L
s
.25 .4 m
.25 .40375 L
s
.35 .4 m
.35 .40375 L
s
.4 .4 m
.4 .40375 L
s
.45 .4 m
.45 .40375 L
s
.55 .4 m
.55 .40375 L
s
.6 .4 m
.6 .40375 L
s
.65 .4 m
.65 .40375 L
s
.75 .4 m
.75 .40375 L
s
.8 .4 m
.8 .40375 L
s
.85 .4 m
.85 .40375 L
s
.05 .4 m
.05 .40375 L
s
.95 .4 m
.95 .40375 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .1 m
.50625 .1 L
s
[(-3)] .4875 .1 1 0 Mshowa
.5 .2 m
.50625 .2 L
s
[(-2)] .4875 .2 1 0 Mshowa
.5 .3 m
.50625 .3 L
s
[(-1)] .4875 .3 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .6 m
.50625 .6 L
s
[(2)] .4875 .6 1 0 Mshowa
.5 .7 m
.50625 .7 L
s
[(3)] .4875 .7 1 0 Mshowa
.5 .8 m
.50625 .8 L
s
[(4)] .4875 .8 1 0 Mshowa
.125 Mabswid
.5 .02 m
.50375 .02 L
s
.5 .04 m
.50375 .04 L
s
.5 .06 m
.50375 .06 L
s
.5 .08 m
.50375 .08 L
s
.5 .12 m
.50375 .12 L
s
.5 .14 m
.50375 .14 L
s
.5 .16 m
.50375 .16 L
s
.5 .18 m
.50375 .18 L
s
.5 .22 m
.50375 .22 L
s
.5 .24 m
.50375 .24 L
s
.5 .26 m
.50375 .26 L
s
.5 .28 m
.50375 .28 L
s
.5 .32 m
.50375 .32 L
s
.5 .34 m
.50375 .34 L
s
.5 .36 m
.50375 .36 L
s
.5 .38 m
.50375 .38 L
s
.5 .42 m
.50375 .42 L
s
.5 .44 m
.50375 .44 L
s
.5 .46 m
.50375 .46 L
s
.5 .48 m
.50375 .48 L
s
.5 .52 m
.50375 .52 L
s
.5 .54 m
.50375 .54 L
s
.5 .56 m
.50375 .56 L
s
.5 .58 m
.50375 .58 L
s
.5 .62 m
.50375 .62 L
s
.5 .64 m
.50375 .64 L
s
.5 .66 m
.50375 .66 L
s
.5 .68 m
.50375 .68 L
s
.5 .72 m
.50375 .72 L
s
.5 .74 m
.50375 .74 L
s
.5 .76 m
.50375 .76 L
s
.5 .78 m
.50375 .78 L
s
.25 Mabswid
.5 0 m
.5 .8 L
s
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
.03 w
.8 .1 Mdot
.8 .4 Mdot
.8 .7 Mdot
0 1 0 r
.5 Mabswid
.8 .1 m
.77069 .07894 L
.73732 .05997 L
.70423 .04556 L
.67307 .03545 L
.65365 .03068 L
.63552 .02725 L
.61545 .02453 L
.60527 .02358 L
.59405 .02285 L
.57521 .0224 L
.55494 .02296 L
.53587 .02447 L
.5185 .02668 L
.49946 .03003 L
.47937 .03463 L
.44397 .04548 L
.4035 .06251 L
.36872 .08155 L
.33778 .10249 L
.30684 .128 L
.25835 .18066 L
.23589 .21313 L
.21824 .24484 L
.2027 .28076 L
.19583 .3011 L
.19061 .32004 L
.18634 .33987 L
.18461 .35013 L
.18307 .36143 L
.18206 .3712 L
.18137 .38034 L
.18093 .38995 L
.18077 .40026 L
.1809 .40898 L
.18131 .41846 L
.18204 .42828 L
.183 .43733 L
.18537 .45336 L
.18881 .47013 L
.19329 .48686 L
.19826 .50188 L
.21231 .53414 L
.22777 .56041 L
.247 .58573 L
.28641 .62281 L
.3117 .63972 L
.33689 .65266 L
.35032 .65819 L
.36491 .66324 L
Mistroke
.37773 .6669 L
.39177 .67012 L
.40047 .67171 L
.40851 .67293 L
.41623 .67386 L
.42439 .67459 L
.4386 .67529 L
.44668 .67536 L
.4542 .67521 L
.46902 .67432 L
.48297 .67275 L
.49541 .67076 L
.50881 .66797 L
.53824 .65945 L
.56446 .64891 L
.60713 .62489 L
.62929 .60836 L
.64845 .59121 L
.6817 .55258 L
.69698 .52896 L
.70868 .50646 L
.71856 .48209 L
.72529 .45964 L
.7281 .44714 L
.72932 .44056 L
.7304 .4336 L
.73187 .42086 L
.73261 .4092 L
.73279 .39855 L
.73244 .38724 L
.73161 .3767 L
.73043 .3672 L
.72854 .35625 L
.72587 .34457 L
.71945 .32409 L
.71047 .3035 L
.69815 .28246 L
.68283 .26264 L
.6664 .24622 L
.64955 .233 L
.63296 .22271 L
.61372 .21351 L
.60365 .20972 L
.59252 .20626 L
.58158 .20357 L
.57137 .20166 L
.56153 .20034 L
.55104 .19949 L
.54164 .1992 L
.53283 .19932 L
Mistroke
.52318 .19991 L
.51286 .20104 L
.502 .2028 L
.49028 .20538 L
.46941 .21175 L
.44987 .21995 L
.4326 .22919 L
.40128 .25179 L
.3771 .27636 L
.36566 .29132 L
.35499 .30834 L
.34658 .32509 L
.34041 .34073 L
.33535 .35793 L
.3333 .36745 L
.33185 .37645 L
.33091 .38473 L
.33041 .39235 L
.33024 .40066 L
.3305 .40939 L
.33121 .418 L
.3318 .42279 L
.33246 .42713 L
.33399 .43503 L
.33602 .44316 L
.34168 .45975 L
.34568 .46868 L
.34989 .47665 L
.3596 .49149 L
.37026 .50408 L
.38107 .51423 L
.39354 .52354 L
.40813 .53195 L
.42235 .53803 L
.4305 .5407 L
.43826 .54274 L
.44688 .54447 L
.45175 .5452 L
.45623 .54572 L
.46417 .54629 L
.47166 .54644 L
.47838 .54624 L
.48562 .54568 L
.49351 .54467 L
.49745 .54401 L
.50175 .54316 L
.51622 .53934 L
.5294 .53451 L
.54292 .52808 L
.56539 .5135 L
Mistroke
.57756 .50302 L
.58938 .49045 L
.59848 .47851 L
.60668 .46516 L
.61273 .45267 L
.61542 .44592 L
.61789 .43858 L
.61979 .43181 L
.6212 .42561 L
.62231 .41937 L
.62308 .41345 L
.62361 .4069 L
.62376 .40324 L
.6238 .39988 L
.62364 .39375 L
.62315 .38736 L
.62242 .38171 L
.6215 .37652 L
.62023 .37094 L
.61857 .36508 L
.61382 .35263 L
.60804 .34166 L
.60187 .3326 L
.5942 .32367 L
.57798 .31013 L
.56888 .30474 L
.55829 .29996 L
.54893 .29689 L
.54355 .29557 L
.53857 .29462 L
.53415 .29398 L
.52929 .29351 L
.52419 .29325 L
.51945 .29323 L
.51374 .29348 L
.51086 .29372 L
.50771 .29408 L
.50217 .29493 L
.49703 .29597 L
.48568 .29921 L
.47948 .30153 L
.47395 .30396 L
.46437 .30904 L
.45457 .31552 L
.44594 .32256 L
.43879 .32956 L
.42649 .34528 L
.4211 .35457 L
.41695 .36361 L
.41393 .37217 L
Mistroke
.41187 .38012 L
.41106 .38429 L
.4104 .38885 L
.40994 .3936 L
.40974 .398 L
.40976 .40279 L
.40987 .40519 L
.41006 .40782 L
.41059 .4124 L
.4113 .41662 L
.4124 .42147 L
.41364 .42581 L
.41727 .43514 L
.42102 .44223 L
.42588 .44937 L
.43172 .45609 L
.43777 .46159 L
.44429 .46629 L
.45083 .47002 L
.45699 .47276 L
.46389 .47507 L
.46756 .476 L
.47163 .47681 L
.4737 .47713 L
.47593 .47741 L
.47996 .47775 L
.48399 .47788 L
.48782 .4778 L
.49124 .47758 L
.49496 .47717 L
.49887 .47654 L
.50243 .4758 L
.51031 .47355 L
.51703 .47093 L
.52381 .46757 L
.53696 .4586 L
.54351 .45254 L
.54894 .44638 L
.55387 .43949 L
.55779 .43265 L
.56066 .4263 L
.56306 .41928 L
.56402 .41561 L
.56484 .41156 L
.56516 .40952 L
.56543 .40734 L
.56563 .40528 L
.56575 .4034 L
.56584 .39986 L
.5658 .39787 L
Mistroke
.56572 .39603 L
.56543 .3927 L
.56493 .38922 L
.56428 .38598 L
.56338 .3825 L
.56096 .37579 L
.55805 .36999 L
.5548 .365 L
.55035 .35968 L
.54578 .35541 L
.53997 .35125 L
.53405 .34808 L
.52862 .34595 L
.52581 .34511 L
.52266 .34436 L
.51996 .34387 L
.51702 .34349 L
.51423 .34328 L
.51166 .34321 L
.50864 .34327 L
.50584 .34348 L
.50278 .34385 L
.50108 .34414 L
.49954 .34443 L
.49645 .34516 L
.49316 .34614 L
.48736 .34837 L
.48236 .35087 L
.4773 .35403 L
.4691 .36085 L
.46478 .36559 L
.46122 .37043 L
.45825 .37544 L
.45604 .38013 L
.45421 .38528 L
.45343 .38813 L
.45285 .39081 L
.45245 .39331 L
.45219 .39559 L
.45203 .39809 L
.45199 .4007 L
.4521 .40331 L
.45223 .40476 L
.45238 .40607 L
.45278 .40858 L
.45328 .4109 L
.45402 .41354 L
.45483 .4159 L
.45715 .42097 L
.45948 .42476 L
Mistroke
.46195 .42793 L
.46491 .43102 L
.46848 .43396 L
.47203 .43626 L
.47552 .43802 L
.47899 .43937 L
.48083 .43993 L
.48281 .44043 L
.48394 .44067 L
.48519 .44089 L
.4874 .44119 L
.48865 .4413 L
.48999 .44138 L
.49126 .44141 L
.49242 .44141 L
.49466 .44131 L
.49592 .4412 L
.49709 .44107 L
.49921 .44074 L
.50145 .44027 L
.50546 .43912 L
.50911 .4377 L
.51293 .43579 L
.51681 .43334 L
.52004 .43084 L
.5232 .42788 L
.52803 .42194 L
.5304 .41801 L
.53219 .41414 L
.53344 .4106 L
.53398 .40858 L
.53438 .40671 L
.53468 .40489 L
.53489 .40294 L
.53499 .40112 L
.53501 .39946 L
.53493 .39754 L
.53483 .39647 L
.53471 .39548 L
.53443 .3937 L
.53402 .39184 L
.53348 .38995 L
.53277 .38797 L
.53118 .38458 L
.52926 .38155 L
.52722 .37903 L
.52497 .37682 L
.52266 .375 L
.51978 .37322 L
.51701 .37191 L
Mistroke
.5157 .37142 L
.51429 .37097 L
.51306 .37064 L
.51171 .37034 L
.51026 .3701 L
.50888 .36993 L
.50724 .36982 L
.50574 .3698 L
.50421 .36985 L
.50258 .37 L
.50105 .37021 L
.49968 .37047 L
.49808 .37085 L
.49637 .37135 L
.49335 .37251 L
.49034 .37403 L
.48736 .37596 L
.48484 .37799 L
.48266 .38011 L
.48079 .3823 L
.47901 .38483 L
.47763 .38727 L
.47658 .38954 L
.47561 .3923 L
.4752 .39383 L
.4749 .39527 L
.47469 .3966 L
.47456 .39783 L
.47448 .39916 L
.47447 .40056 L
.47453 .40177 L
.47463 .40286 L
.47481 .40411 L
.47503 .40526 L
.47556 .40725 L
.47633 .40932 L
.47738 .41146 L
.47873 .41355 L
.48167 .4168 L
.48353 .41827 L
.48543 .41945 L
.48722 .42033 L
.48927 .42108 L
.49045 .42141 L
.49155 .42164 L
.49216 .42175 L
.49282 .42185 L
.49403 .42197 L
.49517 .42202 L
.49638 .42201 L
Mistroke
.4974 .42195 L
.49853 .42183 L
.49965 .42165 L
.5007 .42143 L
.50264 .42089 L
.50466 .42013 L
.50676 .4191 L
.51023 .41676 L
.51299 .41413 L
.51542 .41087 L
.51651 .4089 L
.51731 .40705 L
.51786 .40538 L
.5181 .40442 L
.51829 .40355 L
.51844 .40262 L
.51855 .40164 L
.51861 .40073 L
.51862 .39988 L
.51859 .39895 L
.51851 .39795 L
.51844 .39745 L
.51836 .39692 L
.51817 .39598 L
.51793 .39507 L
.51766 .39422 L
.51703 .39269 L
.51612 .39102 L
.51512 .3896 L
.51385 .38821 L
.51235 .38692 L
.51085 .38594 L
.50918 .38512 L
.50768 .38458 L
.5068 .38435 L
.50598 .38418 L
.50552 .38411 L
.50502 .38404 L
.50454 .38399 L
.5041 .38396 L
.50326 .38394 L
.50237 .38396 L
.50191 .38399 L
.50142 .38404 L
.50095 .3841 L
.50053 .38416 L
.49956 .38435 L
.49855 .38462 L
.49701 .38515 L
.49544 .38587 L
Mistroke
.49284 .38754 L
.49142 .38877 L
.49023 .39004 L
.48922 .39136 L
.4884 .39266 L
.48773 .39402 L
.48723 .39528 L
.48681 .39671 L
.48665 .3975 L
.48653 .39825 L
.48646 .39896 L
.48642 .39972 L
.48643 .40037 L
.48646 .40107 L
.4865 .40145 L
.48654 .40181 L
.48668 .40259 L
.48683 .40326 L
.48704 .40395 L
.48745 .40505 L
.48801 .40616 L
.48927 .40794 L
.49019 .40888 L
.49115 .40965 L
.49207 .41024 L
.49312 .41077 L
.49369 .411 L
.49422 .41119 L
.49477 .41135 L
.49529 .41147 L
.49589 .41158 L
.49621 .41162 L
.49656 .41166 L
.49719 .4117 L
.49777 .41171 L
.49809 .4117 L
.49842 .41169 L
.49902 .41163 L
.49966 .41154 L
.50035 .4114 L
.50095 .41125 L
.50157 .41105 L
.50267 .41062 L
.5037 .4101 L
.50476 .40942 L
.50563 .40875 L
.50648 .40797 L
.50717 .40721 L
.50785 .40631 L
.50883 .40463 L
Mistroke
.50924 .40366 L
.50957 .40258 L
.5097 .40203 L
.50975 .40172 L
.5098 .40144 L
.50986 .40088 L
.50989 .40039 L
.5099 .39992 L
.50989 .39943 L
.50985 .39901 L
.5098 .39856 L
.50971 .39809 L
.50959 .39759 L
.50932 .39672 L
.50889 .39578 L
.50832 .39484 L
.50767 .39404 L
.507 .39339 L
.50628 .39284 L
.50555 .3924 L
.50467 .392 L
.50427 .39186 L
.50384 .39173 L
.50339 .39163 L
.50299 .39156 L
.50257 .3915 L
.50218 .39147 L
.50172 .39146 L
.5013 .39147 L
.50084 .3915 L
.50061 .39153 L
.50035 .39157 L
.49988 .39165 L
.49945 .39176 L
.49851 .39206 L
.49768 .39244 L
.49692 .39286 L
.49564 .39384 L
.49463 .39491 L
.49376 .39623 L
.49339 .39701 L
.49313 .39773 L
.49293 .39849 L
Mfstroke
.8 .4 m
.79964 .38527 L
.79868 .37202 L
.79683 .35694 L
.79438 .34294 L
.7915 .33023 L
.78834 .31873 L
.77945 .29362 L
.76815 .26975 L
.75317 .24534 L
.73491 .22219 L
.71562 .20288 L
.69348 .18532 L
.67082 .17124 L
.64936 .16086 L
.62498 .152 L
.61077 .14815 L
.59773 .14539 L
.59044 .14416 L
.58251 .14307 L
.57501 .14227 L
.56808 .14174 L
.55563 .14125 L
.54195 .14141 L
.5277 .14233 L
.51445 .1439 L
.50738 .14501 L
.4999 .1464 L
.48659 .14942 L
.45716 .15868 L
.43275 .16925 L
.40723 .1835 L
.38607 .19819 L
.36502 .21598 L
.33225 .25251 L
.3171 .27505 L
.30347 .30086 L
.2978 .31424 L
.29265 .32869 L
.28897 .34128 L
.28578 .35498 L
.28454 .36164 L
.28344 .36868 L
.28262 .37519 L
.28202 .38127 L
.28134 .393 L
.28123 .39917 L
.2813 .40577 L
.28153 .41157 L
.28196 .41784 L
Mistroke
.28321 .42913 L
.28499 .43993 L
.28714 .44975 L
.29014 .46062 L
.29393 .47176 L
.30226 .49079 L
.31333 .50979 L
.32776 .52861 L
.34199 .54305 L
.35878 .55647 L
.37591 .56708 L
.39238 .57494 L
.40096 .57825 L
.41023 .58126 L
.41835 .58345 L
.4272 .58539 L
.43676 .58697 L
.44579 .58799 L
.45105 .58838 L
.45658 .58863 L
.46648 .58867 L
.47507 .58828 L
.4842 .58744 L
.49277 .58626 L
.5005 .58485 L
.51916 .58011 L
.53623 .57403 L
.55339 .56607 L
.56863 .55726 L
.5856 .54522 L
.59982 .53288 L
.62466 .50437 L
.63569 .48718 L
.64427 .47018 L
.65013 .45524 L
.65275 .44696 L
.65482 .43914 L
.6564 .43195 L
.65756 .42534 L
.65853 .41802 L
.65922 .41016 L
.65952 .40234 L
.65947 .39512 L
.65903 .38729 L
.65813 .37904 L
.65752 .37494 L
.65672 .37053 L
.65496 .36266 L
.65056 .34843 L
.6448 .33499 L
Mistroke
.63717 .32153 L
.62871 .30989 L
.62 .30022 L
.60876 .29021 L
.59537 .28094 L
.58182 .27386 L
.56862 .26879 L
.56127 .26665 L
.55321 .26483 L
.54948 .26416 L
.54551 .26357 L
.53838 .26281 L
.53149 .26244 L
.52505 .2624 L
.51799 .26271 L
.51045 .26343 L
.50629 .26401 L
.50247 .26465 L
.49389 .26648 L
.48644 .26853 L
.47866 .27113 L
.46562 .27662 L
.45197 .28405 L
.42966 .30081 L
.41985 .3106 L
.41034 .32217 L
.40327 .33267 L
.39686 .34436 L
.39196 .35572 L
.38847 .36621 L
.3868 .3727 L
.38542 .37957 L
.38456 .38543 L
.38394 .39184 L
.38374 .39543 L
.38366 .39869 L
.38368 .40243 L
.38381 .40595 L
.3843 .41214 L
.38473 .4156 L
.38521 .41877 L
.38643 .42489 L
.38788 .43052 L
.39137 .44064 L
.3962 .45088 L
.40258 .46107 L
.40912 .4692 L
.41696 .47696 L
.42437 .48284 L
.43299 .48829 L
Mistroke
.4385 .49114 L
.44373 .49343 L
.44875 .49528 L
.45438 .49699 L
.45915 .49815 L
.46435 .49913 L
.46723 .49955 L
.46988 .49985 L
.47509 .50024 L
.48055 .50036 L
.4836 .50029 L
.48637 .50015 L
.49175 .49967 L
.49678 .49895 L
.50261 .4978 L
.50791 .49645 L
.51955 .49243 L
.52859 .48821 L
.53798 .48267 L
.54644 .47649 L
.55485 .46895 L
.56227 .46077 L
.56827 .45266 L
.57309 .44469 L
.57748 .43557 L
.58055 .42723 L
.58268 .41931 L
.58355 .41494 L
.58415 .41093 L
.58459 .40655 L
.58482 .40197 L
.5848 .3973 L
.58456 .39312 L
.58434 .39082 L
.58403 .38836 L
.58327 .38395 L
.58235 .3799 L
.58115 .37572 L
.57844 .36852 L
.57444 .36068 L
.56992 .35395 L
.5642 .34732 L
.55724 .34114 L
.55071 .33668 L
.54327 .33281 L
.53951 .33128 L
.5359 .33004 L
.53264 .3291 L
.52901 .32826 L
.52493 .32755 L
Mistroke
.52269 .32726 L
.5206 .32706 L
.51683 .32685 L
.51279 .32684 L
.51052 .32693 L
.50806 .32711 L
.50574 .32735 L
.50361 .32764 L
.4996 .32835 L
.49539 .32934 L
.48845 .33154 L
.48125 .33461 L
.46922 .34185 L
.46295 .34693 L
.45701 .35286 L
.45219 .35878 L
.44826 .36468 L
.44499 .37074 L
.44216 .37749 L
.44114 .38051 L
.44023 .38373 L
.43952 .38675 L
.439 .38951 L
.43855 .39272 L
.43825 .39615 L
.43813 .3993 L
.43817 .40227 L
.43825 .40392 L
.43839 .40567 L
.43876 .40877 L
.43904 .41046 L
.43934 .41204 L
.44019 .41557 L
.44191 .42079 L
.44423 .42598 L
.44661 .43013 L
.44961 .43436 L
.45326 .4385 L
.45761 .44241 L
.46164 .44532 L
.46637 .44802 L
.4717 .45031 L
.47472 .45129 L
.47759 .45204 L
.4803 .45259 L
.4828 .45297 L
.48571 .45325 L
.48849 .45336 L
.49005 .45337 L
.49147 .45333 L
Mistroke
.49311 .45324 L
.49464 .45311 L
.49737 .45277 L
.4989 .45252 L
.5003 .45225 L
.50638 .45063 L
.50937 .44957 L
.51256 .44821 L
.52218 .4426 L
.527 .43872 L
.53097 .43479 L
.53427 .43085 L
.5374 .4263 L
.53989 .42179 L
.54176 .41754 L
.54326 .41307 L
.54387 .4107 L
.54439 .40821 L
.54472 .40603 L
.54494 .40401 L
.54508 .40181 L
.54512 .39948 L
.54508 .39816 L
.54502 .39696 L
.54491 .39564 L
.54475 .39427 L
.54438 .39198 L
.54385 .38953 L
.54325 .3874 L
.54249 .38517 L
.54081 .38133 L
.53846 .3773 L
.53541 .37335 L
.53211 .37007 L
.52874 .36746 L
.52513 .36529 L
.52169 .36371 L
.51971 .36299 L
.51754 .36234 L
.51546 .36185 L
.51353 .36151 L
.51147 .36126 L
.50952 .36112 L
.50775 .36108 L
.50584 .36113 L
.50377 .36129 L
.50272 .36141 L
.50158 .36157 L
.49957 .36194 L
.4977 .36238 L
Mistroke
.49414 .36349 L
.49098 .36478 L
.48435 .36856 L
.48103 .37114 L
.4782 .37379 L
.47522 .37723 L
.47288 .38057 L
.47112 .38368 L
.46957 .38715 L
.46887 .38909 L
.46833 .39089 L
.46789 .39272 L
.46756 .39445 L
.46732 .39611 L
.46716 .3979 L
.4671 .39951 L
.46711 .401 L
.4672 .40258 L
.46738 .4043 L
.46751 .40516 L
.46768 .40607 L
.46804 .40769 L
.46892 .41057 L
.47015 .41344 L
.47142 .41573 L
.47304 .41806 L
.47519 .42052 L
.47747 .42256 L
.48034 .42456 L
.48313 .42602 L
.48447 .42657 L
.48591 .42708 L
.48717 .42745 L
.48855 .42778 L
.49005 .42806 L
.49146 .42824 L
.49232 .42831 L
.49314 .42836 L
.49469 .42838 L
.49617 .42832 L
.49701 .42826 L
.49777 .42817 L
.49917 .42797 L
.50064 .42768 L
.50314 .42701 L
.5058 .42603 L
.50852 .42471 L
.51127 .42302 L
.51567 .41934 L
.5175 .41732 L
Mistroke
.51925 .41498 L
.52057 .41282 L
.52175 .41044 L
.5226 .40825 L
.52297 .40707 L
.52331 .4058 L
.52355 .40463 L
.52373 .40357 L
.52386 .40255 L
.52395 .40148 L
.52399 .40022 L
.52399 .39952 L
.52397 .39888 L
.52388 .39771 L
.52373 .39649 L
.52354 .39541 L
.52332 .39443 L
.52265 .39226 L
.52169 .39005 L
.52062 .38818 L
.51916 .38621 L
.51758 .38454 L
.51608 .38327 L
.51437 .38211 L
.5128 .38126 L
.51104 .38051 L
.50992 .38014 L
.50888 .37986 L
.50787 .37965 L
.5068 .37947 L
.50583 .37937 L
.50492 .37932 L
.50392 .3793 L
.50285 .37934 L
.50179 .37943 L
.50119 .37951 L
.50062 .3796 L
.4995 .37982 L
.49831 .38012 L
.49621 .38084 L
.49436 .38167 L
.49234 .38284 L
.49029 .38433 L
.48852 .38595 L
.48709 .38755 L
.4859 .38917 L
.48481 .39101 L
.48387 .39302 L
.48353 .39394 L
.48321 .39496 L
Mistroke
.48299 .39585 L
.48279 .3968 L
.4827 .39733 L
.48264 .3978 L
.48255 .39874 L
.48251 .39959 L
.48251 .4005 L
.48255 .40135 L
.48263 .40213 L
.48276 .40296 L
.48294 .40382 L
.48336 .4053 L
.48397 .40682 L
.4848 .40836 L
.48566 .4096 L
.48669 .41079 L
.48884 .41261 L
.4903 .41348 L
.49111 .41387 L
.49198 .41422 L
.49277 .41448 L
.49364 .41471 L
.49445 .41488 L
.49521 .41499 L
.49601 .41506 L
.49677 .41509 L
.49746 .41509 L
.4982 .41504 L
.49901 .41496 L
.49946 .41489 L
.49986 .41482 L
.50064 .41465 L
.50136 .41446 L
.50276 .41398 L
.50422 .41331 L
.50558 .41252 L
.50692 .41155 L
.50808 .41054 L
.50907 .40949 L
.51063 .40736 L
.51134 .40605 L
.51194 .40462 L
.51232 .40339 L
.51248 .40268 L
.5126 .40201 L
.51266 .40163 L
.5127 .40129 L
.51273 .40092 L
.51275 .40053 L
.51276 .39988 L
Mistroke
.51273 .39919 L
.5127 .39881 L
.51266 .3984 L
.5126 .39802 L
.51254 .39767 L
.51239 .39701 L
.5122 .39634 L
.51175 .39515 L
.5112 .3941 L
.51063 .39323 L
.50992 .39235 L
.50905 .39151 L
.50804 .39074 L
.50711 .39018 L
.50602 .38969 L
.50552 .38951 L
.50498 .38935 L
.50451 .38924 L
.504 .38914 L
.50344 .38906 L
.50292 .38902 L
.5026 .389 L
.5023 .38899 L
.50174 .389 L
.50124 .38903 L
.50072 .38909 L
.50027 .38916 L
.49979 .38926 L
.49872 .38954 L
.49776 .3899 L
.49669 .39042 L
.49576 .39098 L
.49473 .39176 L
.49388 .39254 L
.49254 .39418 L
.49195 .39515 L
.4915 .3961 L
.49117 .39699 L
.49103 .39748 L
.49092 .39794 L
.49084 .39836 L
.49078 .39875 L
.49073 .39917 L
.4907 .39963 L
.4907 .40011 L
.49071 .40055 L
.49075 .40103 L
.49078 .40127 L
.49082 .40153 L
.49091 .40196 L
Mistroke
.49102 .40241 L
.49129 .4032 L
.49165 .40399 L
.49213 .40477 L
.49317 .40599 L
.49392 .4066 L
.49469 .40709 L
.49542 .40744 L
.49584 .4076 L
.49625 .40773 L
.49668 .40784 L
.49708 .40792 L
.4973 .40795 L
.49753 .40798 L
.49778 .408 L
.49802 .40802 L
.49827 .40803 L
.4985 .40803 L
.49876 .40802 L
.499 .408 L
.49944 .40796 L
.49969 .40792 L
.49991 .40788 L
.50068 .4077 L
.50111 .40757 L
.5015 .40742 L
.50232 .40704 L
.50304 .40661 L
.50433 .40557 L
.50491 .40494 L
.50545 .40422 L
.50583 .40361 L
.50616 .40292 L
.50632 .40252 L
.50645 .40216 L
.50655 .4018 L
.50664 .40143 L
.5067 .40107 L
.50675 .40074 L
.50677 .40041 L
.50679 .40011 L
.50678 .39976 L
.50676 .39943 L
.50672 .39909 L
.5067 .39891 L
.50666 .39873 L
.50651 .39813 L
.5064 .39781 L
.50629 .39752 L
.50574 .39652 L
Mistroke
.50542 .3961 L
.50502 .39567 L
.50459 .3953 L
.50409 .39496 L
.5036 .39469 L
.50312 .39449 L
.50266 .39434 L
.50242 .39428 L
.50215 .39423 L
.50184 .39418 L
.50154 .39416 L
.50127 .39415 L
.50098 .39415 L
.50067 .39417 L
.50051 .39418 L
.50033 .39421 L
.50003 .39426 L
.49974 .39432 L
.4992 .39448 L
.49871 .39467 L
.4977 .39523 L
Mfstroke
.8 .7 m
.82666 .6651 L
.85144 .62591 L
.86961 .59082 L
.88583 .5518 L
.8939 .52764 L
.90012 .50521 L
.90485 .48414 L
.90885 .46093 L
.91134 .44021 L
.91275 .42089 L
.91327 .40064 L
.91274 .37908 L
.91096 .35666 L
.90821 .33619 L
.90615 .32457 L
.90399 .31416 L
.89815 .29124 L
.88408 .25133 L
.86697 .21612 L
.84707 .18453 L
.8261 .15788 L
.79835 .12964 L
.77056 .10713 L
.73952 .08721 L
.7042 .0699 L
.68796 .06359 L
.66997 .05771 L
.65284 .05311 L
.63657 .04961 L
.61759 .04656 L
.60745 .04536 L
.59649 .04441 L
.58559 .0438 L
.5741 .04352 L
.56429 .04358 L
.55357 .04395 L
.5343 .04542 L
.52356 .04669 L
.51384 .04812 L
.49506 .05164 L
.47751 .05584 L
.4402 .06785 L
.40237 .08463 L
.37179 .10201 L
.34031 .12411 L
.30936 .15096 L
.27984 .1829 L
.25746 .21302 L
.23739 .24684 L
Mistroke
.22164 .28137 L
.21086 .31333 L
.20686 .32889 L
.20343 .34573 L
.20103 .36161 L
.19956 .37615 L
.19903 .38435 L
.1987 .39309 L
.19875 .40874 L
.19918 .41821 L
.19986 .4271 L
.20069 .43501 L
.20185 .44353 L
.20498 .46072 L
.20942 .4785 L
.22016 .509 L
.23229 .53392 L
.24804 .55872 L
.28278 .59748 L
.30609 .61599 L
.33267 .63209 L
.35671 .64299 L
.37083 .64801 L
.38407 .65185 L
.39725 .6549 L
.41132 .65734 L
.42557 .65899 L
.43369 .65957 L
.4413 .65988 L
.45506 .65987 L
.46761 .65923 L
.47453 .65862 L
.48203 .65775 L
.49561 .65563 L
.50756 .65316 L
.5206 .64982 L
.54641 .64113 L
.5694 .63089 L
.59 .61948 L
.61279 .604 L
.63488 .58553 L
.66875 .54786 L
.68417 .52482 L
.69612 .50241 L
.70649 .47707 L
.711 .46267 L
.7143 .44951 L
.71649 .43831 L
.71804 .42784 L
.71917 .41639 L
Mistroke
.71974 .40416 L
.71977 .3981 L
.71961 .39152 L
.71882 .37966 L
.71744 .3683 L
.71561 .35794 L
.71322 .34758 L
.7105 .33805 L
.70422 .32086 L
.6958 .30338 L
.68488 .28585 L
.67197 .26959 L
.65594 .25381 L
.6374 .23977 L
.6187 .22906 L
.60021 .22119 L
.58272 .21588 L
.57286 .21371 L
.56762 .21278 L
.56202 .21197 L
.55171 .21092 L
.54214 .21047 L
.53307 .21048 L
.52317 .21099 L
.51287 .21206 L
.50336 .21355 L
.4945 .21538 L
.48654 .21738 L
.46904 .22305 L
.45088 .23088 L
.43225 .24126 L
.41717 .25167 L
.40184 .26452 L
.37802 .29073 L
.36724 .30643 L
.35871 .32175 L
.35224 .33623 L
.34733 .35021 L
.34514 .35798 L
.34317 .36648 L
.34177 .3742 L
.3408 .38135 L
.34003 .39018 L
.33982 .39459 L
.33973 .39941 L
.33992 .40788 L
.3405 .41566 L
.34105 .42034 L
.34169 .42472 L
.34322 .43281 L
Mistroke
.34534 .44131 L
.34819 .45028 L
.35428 .46479 L
.36236 .47907 L
.37046 .49024 L
.38057 .50135 L
.39115 .51062 L
.40201 .51826 L
.41535 .52558 L
.42818 .53084 L
.43417 .53277 L
.44064 .53451 L
.44629 .53574 L
.45246 .5368 L
.45978 .53768 L
.46671 .53814 L
.47347 .53825 L
.47969 .53806 L
.48699 .53748 L
.49387 .53659 L
.5 .5355 L
.5066 .53401 L
.52109 .52959 L
.534 .52421 L
.55585 .51149 L
.56592 .50378 L
.57615 .4944 L
.59415 .47238 L
.60211 .45889 L
.60794 .44604 L
.61188 .4345 L
.6136 .42791 L
.61489 .42176 L
.6159 .41526 L
.61651 .40937 L
.61672 .40613 L
.61685 .40262 L
.61682 .39631 L
.61648 .39035 L
.61589 .38497 L
.61491 .37888 L
.61367 .37321 L
.61075 .36347 L
.60658 .35341 L
.6009 .34315 L
.59365 .3332 L
.58581 .32486 L
.57796 .31824 L
.56826 .31184 L
.55877 .30708 L
Mistroke
.54784 .30313 L
.54218 .30165 L
.53896 .30097 L
.5359 .30043 L
.53322 .30004 L
.5303 .29969 L
.52517 .2993 L
.52226 .2992 L
.51916 .29918 L
.51362 .29939 L
.50852 .29985 L
.50377 .30051 L
.4986 .30148 L
.4931 .30281 L
.48343 .30593 L
.47352 .31024 L
.45703 .32031 L
.448 .32776 L
.44034 .33555 L
.42851 .35171 L
.42378 .36062 L
.41985 .37032 L
.41737 .37873 L
.41633 .38354 L
.4156 .38802 L
.41529 .3905 L
.41504 .39319 L
.41487 .39572 L
.41479 .39805 L
.4148 .40243 L
.41506 .40703 L
.41529 .40937 L
.41561 .41187 L
.41639 .41633 L
.41762 .42151 L
.41905 .42612 L
.42217 .43375 L
.42567 .44025 L
.43045 .44715 L
.43562 .45303 L
.44619 .46179 L
.4528 .4657 L
.45922 .46862 L
.46268 .46988 L
.46647 .47103 L
.46978 .47184 L
.47344 .47255 L
.47567 .47288 L
.47775 .47313 L
.47975 .47331 L
Mistroke
.48188 .47344 L
.48595 .47352 L
.48964 .47339 L
.49169 .47325 L
.49386 .47303 L
.49772 .47248 L
.50183 .47167 L
.50628 .47052 L
.51405 .46783 L
.52098 .4646 L
.53374 .45627 L
.54009 .4506 L
.54534 .44485 L
.55324 .43329 L
.55632 .42709 L
.55897 .42007 L
.55988 .41697 L
.56068 .41369 L
.56122 .41089 L
.56167 .40782 L
.56199 .40453 L
.5621 .40269 L
.56215 .40103 L
.56212 .39782 L
.56194 .39483 L
.56164 .39206 L
.56118 .38918 L
.56069 .38676 L
.56002 .38414 L
.55813 .37853 L
.55585 .37357 L
.55269 .3683 L
.54928 .36385 L
.54504 .35949 L
.54003 .35548 L
.53485 .35231 L
.52968 .34994 L
.52486 .34832 L
.52208 .34762 L
.5195 .34711 L
.5171 .34677 L
.51452 .34652 L
.51207 .3464 L
.50985 .34639 L
.50723 .3465 L
.5044 .34675 L
.50174 .34713 L
.49931 .3476 L
.49453 .34884 L
.48941 .35068 L
Mistroke
.4843 .3531 L
.47976 .3558 L
.47125 .36262 L
.4671 .36709 L
.46374 .37155 L
.46103 .37598 L
.45891 .3803 L
.45698 .3854 L
.45633 .38763 L
.45574 .39009 L
.45531 .39235 L
.45501 .39446 L
.45479 .39668 L
.45468 .39904 L
.45469 .40122 L
.45479 .40326 L
.45496 .40507 L
.45523 .40702 L
.45562 .40909 L
.45617 .41134 L
.45763 .41572 L
.4594 .41952 L
.4614 .42285 L
.46652 .42895 L
.46991 .43182 L
.47334 .43408 L
.4772 .43603 L
.48087 .4374 L
.48296 .43798 L
.48526 .43847 L
.48632 .43865 L
.48745 .43881 L
.48949 .43901 L
.49136 .43909 L
.49308 .43909 L
.49507 .43899 L
.49694 .43881 L
.49866 .43857 L
.50024 .43827 L
.50377 .43738 L
.50757 .43603 L
.51088 .4345 L
.51424 .43257 L
.51768 .43013 L
.52333 .42477 L
.52592 .42149 L
.528 .41826 L
.52961 .41516 L
.53085 .41216 L
.53142 .41048 L
Mistroke
.53194 .40865 L
.53231 .4071 L
.53262 .40542 L
.53286 .4036 L
.533 .40191 L
.53304 .40093 L
.53305 .3999 L
.533 .39809 L
.53293 .39717 L
.53283 .39621 L
.53258 .3945 L
.53238 .39347 L
.53217 .39251 L
.53168 .39075 L
.53055 .3877 L
.52923 .38507 L
.5275 .38241 L
.52538 .37986 L
.52312 .37773 L
.52078 .37598 L
.51854 .37464 L
.51597 .37345 L
.51307 .37247 L
.51141 .37207 L
.50989 .3718 L
.50845 .37162 L
.50689 .37151 L
.50542 .37149 L
.50406 .37153 L
.50279 .37163 L
.50144 .3718 L
.50017 .37202 L
.49903 .37227 L
.49627 .37305 L
.49375 .37403 L
.48907 .3766 L
.48666 .37838 L
.48462 .38021 L
.48114 .38427 L
.47954 .38675 L
.47833 .38911 L
.47742 .39136 L
.47702 .39256 L
.47667 .39385 L
.47639 .39509 L
.47619 .39621 L
.47604 .39734 L
.47595 .3984 L
.4759 .39962 L
.47591 .40094 L
Mistroke
.47595 .4016 L
.47601 .40231 L
.47616 .40356 L
.47639 .40479 L
.47666 .40593 L
.47732 .40798 L
.47835 .41026 L
.47951 .41221 L
.48101 .41416 L
.48284 .41598 L
.4845 .41728 L
.48638 .41844 L
.48808 .41925 L
.49001 .41994 L
.49113 .42024 L
.49215 .42046 L
.49273 .42056 L
.49335 .42064 L
.4945 .42075 L
.49557 .42079 L
.49671 .42078 L
.49768 .42071 L
.49874 .42059 L
.49979 .42042 L
.50078 .42021 L
.5026 .41969 L
.5045 .41896 L
.50648 .41798 L
.50974 .41576 L
.51233 .41326 L
.51371 .41153 L
.51481 .40985 L
.51581 .40793 L
.51623 .40692 L
.51663 .40584 L
.51692 .40487 L
.51713 .40399 L
.51731 .40309 L
.51744 .40226 L
.51753 .4013 L
.51756 .4008 L
.51758 .40026 L
.51757 .39938 L
.51754 .39887 L
.51751 .39841 L
.51741 .39763 L
.51728 .39679 L
.51708 .39593 L
.51687 .39515 L
.51639 .3938 L
Mistroke
.51575 .39243 L
.51483 .39094 L
.51383 .38966 L
.51163 .38764 L
.51034 .38678 L
.50907 .38613 L
.5076 .38556 L
.50676 .38531 L
.50597 .38513 L
.50515 .38499 L
.50438 .3849 L
.50398 .38487 L
.50353 .38484 L
.50306 .38484 L
.50263 .38484 L
.50183 .38488 L
.50109 .38496 L
.5003 .38508 L
.49946 .38526 L
.49812 .38564 L
.49672 .38617 L
.49436 .38745 L
.49304 .3884 L
.49189 .3894 L
.49005 .39152 L
.48926 .39272 L
.48863 .39388 L
.48807 .39519 L
.48762 .39663 L
.48745 .39736 L
.48738 .39774 L
.48731 .39814 L
.48726 .39853 L
.48723 .39889 L
.48719 .39957 L
.48718 .40023 L
.48721 .40093 L
.48728 .40158 L
.48737 .40217 L
.48748 .40271 L
.48762 .40328 L
.48795 .40428 L
.48845 .40539 L
.489 .40634 L
.48967 .40725 L
.49049 .40815 L
.4922 .40948 L
.49316 .41001 L
.49368 .41025 L
.49424 .41046 L
Mistroke
.49474 .41062 L
.4953 .41077 L
.49582 .41088 L
.4963 .41096 L
.4966 .41099 L
.49692 .41102 L
.49751 .41105 L
.49809 .41105 L
.49862 .41103 L
.4992 .41097 L
.49952 .41092 L
.49982 .41087 L
.50042 .41075 L
.50106 .41057 L
.50225 .41015 L
.50332 .40963 L
.50515 .4084 L
.50607 .40757 L
.50694 .4066 L
.50759 .40571 L
.50818 .40468 L
.50864 .40366 L
.50883 .40313 L
.509 .40257 L
.50913 .40203 L
.50922 .40154 L
.50929 .40105 L
.50933 .40059 L
.50934 .40034 L
.50935 .40006 L
.50935 .39977 L
.50933 .3995 L
.5093 .39902 L
.50926 .39876 L
.50923 .39852 L
.50912 .39799 L
.50897 .39743 L
.50861 .39646 L
.50817 .39561 L
.50769 .39491 L
.50705 .39417 L
.50637 .39357 L
.50574 .39312 L
.50502 .39272 L
.50464 .39254 L
.5042 .39237 L
.50379 .39224 L
.50341 .39214 L
.50296 .39205 L
.50271 .39201 L
Mistroke
.50247 .39198 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{213.5, 170.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003E0000ZR000`400?l00000o`00003oeOooool0
0=Gooooo001Sooooo`?o0000Koooool006Cooooo00?o0000ooooooooool0K_ooool005_ooooo1Ol0
00000ooooooo0000o`000003o`0000Cooooo0_l0001Yooooo`00HOooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo06Sooooo001Rooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool0J?ooool006?ooooo0_l00005ooooo`03o`000?oooooooooo06Sooooo001Tooooo`03
o`000?oooooooooo00?ooooo0_l0001Yooooo`00J_ooool00ol0003oooooooooo`02oooooaGo0?l0
DOooool006Sooooo1ol0o`0Eooooo`So0?l0BOooool006Cooooo1?l0o`02ooooo`03o`000?oooooo
oooo01oooooo1?l0o`15ooooo`00H?ooool4o`3o00Kooooo0_l0000Tooooo`?o0?l0@_ooool005go
oooo0ol0o`0:ooooo`03o`000?oooooooooo00?ooooo4Ol0o`0Booooo`;o0?l0@?ooool005_ooooo
0_l0o`0=ooooo`03o`000?l0o`3o0?l000?o0?l04Oooool7o`3o00gooooo0_l0o`0nooooo`00FOoo
ool2o`3o00Wooooo1ol0o`0Mooooo`?o0?l03?ooool2o`3o03cooooo001Gooooo`;o0?l02?ooool3
o`3o00Kooooo0_l0000Oooooo`Co0?l02_ooool2o`3o03[ooooo001Eooooo`;o0?l02?ooool2o`3o
00Wooooo00?o0000ooooooooool08_ooool4o`3o00Sooooo0_l0o`0hooooo`00Doooool2o`3o00So
oooo0_l0o`0;ooooo`03o`000?oooooooooo02Kooooo0_l0o`08ooooo`03o`3o0?oooooooooo03Go
oooo001Booooo`03o`3o0?oooooooooo00Gooooo0ol0o`0=ooooo`03o`000?oooooooooo02Sooooo
0_l0o`07ooooo`;o0?l0=Oooool0053ooooo0_l0o`05ooooo`?o0?l04?ooool2o`0002_ooooo00?o
0?l0ooooooooool01_ooool2o`3o03?ooooo001>ooooo`;o0?l01Oooool2o`3o01?ooooo00?o0000
ooooooooool0:oooool2o`3o00Sooooo00?o0?l0ooooooooool0<?ooool004gooooo00?o0?l0oooo
ooooool01?ooool00ol0o`3oooooooooo`0;ooooo`?o00001Oooool00ol0003oooooooooo`0]oooo
o`;o0?l01oooool2o`3o00Co0000;?ooool004_ooooo0_l0o`05ooooo`;o0?l03Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0;oooool00ol0o`3oooooooooo`05oooo
o`03o`000?l0o`3o000000?o0000:oooool004[ooooo00?o0?l0ooooooooool01?ooool00ol0o`3o
ooooooooo`07ooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`;o0000<Oooool2o`3o00Go
oooo0_l000001?l0o`3o0000o`000?l0000[ooooo`00B?ooool2o`3o00Gooooo0_l0o`0Booooo`;o
00001Oooool00ol0003oooooooooo`0booooo`03o`3o0?oooooooooo00;ooooo1_l0000[ooooo`00
Aoooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo01Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0cooooo`;o0?l00_ooool6o`0002_ooooo0016ooooo`03o`3o0?oo
oooooooo00?ooooo0_l0o`0Cooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0eooooo`03o`3o0?oooooooooo00Co0000;?ooool004Gooooo00?o0?l0ooooooooool00ooo
ool00ol0o`3oooooooooo`0Dooooo`?o00001Oooool2o`0003Oooooo0_l0o`0`ooooo`00A?ooool0
0ol0o`3oooooooooo`02ooooo`;o0?l07oooool00ol0003oooooooooo`0hooooo`03o`3o0?oooooo
oooo02gooooo0013ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool07oooool00ol0
003oooooooooo`0iooooo`03o`3o0?oooooooooo02cooooo0013ooooo`05o`3o0?oooooooooooooo
ool0o`008_ooool00ol0003oooooooooo`0iooooo`03o`3o0?oooooooooo02cooooo0012ooooo`05
o`3o0?ooooooooooooooool0o`008oooool2o`0003_ooooo00?o0?l0ooooooooool0:oooool0047o
oooo00Go0?l0ooooooooooooooooo`3o000Tooooo`03o`000?l0o`3o0?l001?o0?l0:?ooool00ol0
o`3oooooooooo`0Zooooo`00@?ooool01Ol0o`3ooooooooooooooooo0?l0027ooooo1Ol0o`0Eoooo
o`?o0?l09_ooool00ol0o`3oooooooooo`0Yooooo`00?oooool01Ol0o`3ooooooooooooooooo0?l0
01oooooo0ol0o`04ooooo`03o`000?oooooooooo01Kooooo0_l0o`0Uooooo`03o`3o0?oooooooooo
02Sooooo000nooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool06_ooool3o`3o00Oo
oooo0_l0000Iooooo`?o0?l08oooool00ol0o`3oooooooooo`0Wooooo`00?Oooool00ol0o`3ooooo
ooooo`02ooooo`03o`3o0?oooooooooo01Sooooo0ol0o`0:ooooo`03o`000?oooooooooo01_ooooo
0_l0o`0Qooooo`03o`3o0?oooooooooo02Oooooo000looooo`03o`3o0?oooooooooo00;ooooo00?o
0?l0ooooooooool05oooool2o`3o00gooooo00?o0000ooooooooool07Oooool2o`3o023ooooo00?o
0?l0ooooooooool09_ooool003_ooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0F
ooooo`;o0?l03oooool00ol0003oooooooooo`0Oooooo`;o0?l07oooool00ol0o`3oooooooooo`0U
ooooo`00>_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo01Kooooo00?o0?l0oooo
ooooool03oooool2o`0002;ooooo0ol0o`0Mooooo`03o`3o0?oooooooooo02Cooooo000iooooo`03
o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool05Oooool2o`3o01;ooooo00?o0000oooooooo
ool09?ooool00ol0o`3oooooooooo`0Kooooo`03o`3o0?oooooooooo02?ooooo000iooooo`03o`3o
0?oooooooooo00;ooooo00?o0?l0ooooooooool05?ooool00ol0o`3oooooooooo`09ooooo`Go0000
1?ooool00ol0003oooooooooo`0Uooooo`03o`3o0?oooooooooo01[ooooo00?o0?l0ooooooooool0
8oooool003Sooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oo
oooooooo00_ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Vooooo`03o`3o
0?oooooooooo01[ooooo00?o0?l0ooooooooool08_ooool003Oooooo00?o0?l0ooooooooool00_oo
ool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooooooo00Gooooo1Ol00003ooooo`03o`000?oo
oooooooo00Cooooo0_l000000ooooooo0?l0o`3o0007o`3o01kooooo00?o0?l0ooooooooool06Ooo
ool00ol0o`3oooooooooo`0Rooooo`00=oooool01Ol0o`3ooooooooooooooooo0?l001Kooooo00?o
0?l0ooooooooool03oooool00ol0003oooooooooo`02ooooo`Co0?l02Oooool6o`3o01Wooooo00?o
0?l0ooooooooool06Oooool00ol0o`3oooooooooo`0Qooooo`00=_ooool01Ol0o`3ooooooooooooo
oooo0?l001Kooooo00?o0?l0ooooooooool03Oooool01Ol0003ooooooooooooooooo000000?o0?l0
00?oooooo`000?ooool04?ooool5o`3o01Gooooo00?o0?l0ooooooooool06Oooool00ol0o`3ooooo
ooooo`0Pooooo`00=Oooool01Ol0o`3ooooooooooooooooo0?l001Kooooo00?o0?l0ooooooooool0
3_ooool00ol0003o0?l0o`3o0002o`3o00Cooooo4?l0o`07ooooo`;o0?l05?ooool00ol0o`3ooooo
ooooo`0Hooooo`03o`3o0?oooooooooo023ooooo000eooooo`05o`3o0?ooooooooooooooool0o`00
5Oooool00ol0o`3oooooooooo`0=ooooo`?o0?l00ol000000ooooooo0?l0o`3o0002o`3o00;o0000
3_ooool3o`3o00Kooooo00?o0?l0ooooooooool04_ooool00ol0o`3oooooooooo`0Hooooo`03o`3o
0?oooooooooo01oooooo000dooooo`05o`3o0?ooooooooooooooool0o`005Oooool00ol0o`3ooooo
ooooo`0<ooooo`;o0?l01?ooool3o`3o00Cooooo00?o0000ooooooooool04?ooool4o`3o00?ooooo
0_l0o`0Cooooo`03o`3o0?oooooooooo01Oooooo00?o0?l0ooooooooool07oooool003?ooooo00?o
0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooooooo00_ooooo0_l0
o`04ooooo`;o0?l01oooool00ol0003oooooooooo`0Dooooo`?o0?l00_ooool2o`3o017ooooo00?o
0?l0ooooooooool06?ooool00ol0o`3oooooooooo`0Nooooo`00<oooool01Ol0o`3ooooooooooooo
oooo0?l001Cooooo00?o0?l0ooooooooool02oooool00ol0o`3oooooooooo`02ooooo`;o0?l02Ooo
ool00ol0003oooooooooo`0Gooooo`05o`3o0?ooooooooooooooool0o`004Oooool00ol0o`3ooooo
ooooo`0Gooooo`03o`3o0?oooooooooo01kooooo000booooo`05o`3o0?ooooooooooooooool0o`00
5?ooool00ol0o`3oooooooooo`0;ooooo`04o`3o0?ooooooooooooooo`;o0?l02oooool2o`0001Wo
oooo0_l0o`02ooooo`03o`3o0?oooooooooo00oooooo00?o0?l0ooooooooool05oooool00ol0o`3o
ooooooooo`0Mooooo`00<Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo017ooooo
00?o0?l0ooooooooool02oooool00ol0o`3oooooooooo`02o`3o00gooooo00?o0000ooooooooool0
6_ooool01?l0o`3oooooooooool0o`0Aooooo`03o`3o0?oooooooooo01Oooooo00?o0?l0oooooooo
ool07?ooool0037ooooo00Go0?l0ooooooooooooooooo`3o000Cooooo`03o`3o0?oooooooooo00_o
oooo00Co0?l0oooooooooooo0?l03oooool00ol0003oooooooooo`0Kooooo`04o`3o0?oooooooooo
o`3o017ooooo00?o0?l0ooooooooool05_ooool00ol0o`3oooooooooo`0Looooo`00<?ooool00ol0
o`3oooooooooo`02ooooo`03o`3o0?oooooooooo013ooooo00?o0?l0ooooooooool02oooool01?l0
o`3oooooo`3o0?l0o`0@ooooo`03o`000?oooooooooo01cooooo00Co0?l0oooooooooooo0?l04?oo
ool00ol0o`3oooooooooo`0Gooooo`03o`3o0?oooooooooo01_ooooo000`ooooo`05o`3o0?oooooo
ooooooooool0o`004oooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooo0?l001;ooooo0_l0
000Nooooo`04o`3o0?ooooooooooo`3o013ooooo00?o0?l0ooooooooool05_ooool00ol0o`3ooooo
ooooo`0Kooooo`00<?ooool01Ol0o`3ooooooooooooooooo0?l001;ooooo00?o0?l0ooooooooool0
2_ooool00ol0o`3oooooo`3o000Cooooo`co0?l05Oooool01?l0o`3oooooooooool0o`0@ooooo`03
o`3o0?oooooooooo01Kooooo00?o0?l0ooooooooool06_ooool002oooooo00Go0?l0oooooooooooo
ooooo`3o000Booooo`03o`3o0?oooooooooo00[ooooo00Co0?l0oooooooooooo0?l03oooool4o`3o
0003o`000?oooooooooo00Wooooo1?l0o`0Booooo`04o`3o0?ooooooooooo`3o013ooooo00?o0?l0
ooooooooool05Oooool00ol0o`3oooooooooo`0Jooooo`00;oooool01Ol0o`3ooooooooooooooooo
0?l001;ooooo00?o0?l0ooooooooool02Oooool01?l0o`3oooooooooool0o`0>ooooo`;o0?l01?oo
ool00ol0003oooooooooo`0=ooooo`;o0?l04?ooool01Ol0o`3ooooooooooooooooo0?l000oooooo
00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Jooooo`00;oooool01Ol0o`3ooooooooo
oooooooo0?l0017ooooo00?o0?l0ooooooooool02Oooool01?l0o`3oooooooooool0o`0=ooooo`;o
0?l01_ooool00ol0003oooooooooo`0?ooooo`03o`3o0?oooooooooo00kooooo00Go0?l0oooooooo
ooooooooo`3o000?ooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool06Oooool002ko
oooo00Go0?l0ooooooooooooooooo`3o000Booooo`03o`3o0?oooooooooo00Wooooo00?o0?l0oooo
ool0o`003?ooool2o`3o00Sooooo0_l0000Aooooo`;o0?l03oooool01Ol0o`3ooooooooooooooooo
0?l000kooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Iooooo`00;_ooool01Ol0
o`3ooooooooooooooooo0?l0017ooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooo`3o000<
ooooo`03o`3o0?oooooooooo00?o00001Oooool00ol0003oooooooooo`0Booooo`03o`3o0?oooooo
oooo00gooooo00Co0?l0oooooooooooo0?l03_ooool00ol0o`3oooooooooo`0Eooooo`03o`3o0?oo
oooooooo01Wooooo000^ooooo`04o`3o0?ooooooooooo`3o017ooooo00?o0?l0ooooooooool02Ooo
ool00ol0o`3oooooo`3o000<ooooo`03o`3o0?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003o0?l0o`3o0006o`3o00gooooo00?o0?l0ooooooooool03?ooool01Ol0o`3ooooooooo
oooooooo0?l000kooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Hooooo`00;Ooo
ool01Ol0o`3ooooooooooooooooo0?l0017ooooo00?o0?l0ooooooooool02Oooool00ol0o`3ooooo
o`3o0009ooooo`;o000000?o0?l0o`000?l000000oooool01?l0003oooooooooooooool:o`3o00;o
oooo0_l0o`0<ooooo`03o`3o0?oooooooooo00cooooo00Co0?l0oooooooooooo0?l03_ooool00ol0
o`3oooooooooo`0Eooooo`03o`3o0?oooooooooo01Sooooo000]ooooo`05o`3o0?oooooooooooooo
ool0o`004?ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooo0?l000_ooooo00?o0?l0oooo
ooooool01?ooool00ol0003o0?l0o`3o0006o`3o00Cooooo2Ol0o`09ooooo`03o`3o0?oooooooooo
00cooooo00Co0?l0oooooooooooo0?l03_ooool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooo
oooo01Sooooo000]ooooo`04o`3o0?ooooooooooo`3o017ooooo00?o0?l0ooooooooool02?ooool0
0ol0o`3oooooo`3o000;ooooo`03o`3o0?oooooooooo00Gooooo00Co0?l0ooooool0o`3o0?l00ooo
ool00ol0003oooooooooo`09ooooo`03o`3o0?oooooo0?l000[ooooo00?o0?l0ooooooooool02ooo
ool01?l0o`3oooooooooool0o`0>ooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool0
5oooool002gooooo00Co0?l0oooooooooooo0?l04?ooool00ol0o`3oooooooooo`09ooooo`03o`3o
0?oooooo0?l000[ooooo00?o0?l0ooooooooool01Oooool3o`3o00Gooooo00?o0000ooooooooool0
2_ooool4o`3o00Wooooo00?o0?l0ooooooooool02oooool01?l0o`3oooooooooool0o`0=ooooo`03
o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool05oooool002cooooo00Go0?l0oooooooooooo
ooooo`3o000@ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooool0o`002_ooool00ol0o`3o
ooooooooo`04ooooo`?o0?l000?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`04
o`3o0?oooooo0?l0o`3o00Oooooo00?o0?l0ooooooooool02oooool01?l0o`3oooooooooool0o`0>
ooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0ooooooooool05oooool002cooooo00Co0?l0oooo
oooooooo0?l04?ooool00ol0o`3oooooooooo`09ooooo`;o0?l02_ooool00ol0o`3oooooooooo`03
ooooo`Co0?l02?ooool2o`0000kooooo00Co0?l0oooooooooooo0?l01oooool00ol0o`3ooooooooo
o`0;ooooo`04o`3o0?ooooooooooo`3o00gooooo00?o0?l0ooooooooool05?ooool00ol0o`3ooooo
ooooo`0Gooooo`00;?ooool01?l0o`3oooooooooool0o`0@ooooo`03o`3o0?oooooooooo00Sooooo
00?o0?l0ooooool0o`002Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooo0?l000Sooooo
2Ol0o`0:ooooo`?o0?l01oooool00ol0o`3oooooooooo`0;ooooo`04o`3o0?ooooooooooo`3o00go
oooo00?o0?l0ooooooooool05?ooool00ol0o`3oooooooooo`0Gooooo`00;?ooool01?l0o`3ooooo
ooooool0o`0@ooooo`03o`3o0?oooooooooo00Sooooo0_l0o`09ooooo`03o`3o0?oooooooooo00Co
oooo00?o0?l0ooooool0o`001_ooool2o`3o00;ooooo00?o0000ooooooooool01?ooool3o`3o00Wo
oooo0_l0o`07ooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooool0o`003Oooool00ol0o`3o
ooooooooo`0Eooooo`03o`3o0?oooooooooo01Kooooo000[ooooo`05o`3o0?ooooooooooooooool0
o`003oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooo0?l000Wooooo00?o0?l0oooooooo
ool00oooool00ol0o`3oooooo`3o0006ooooo`03o`3o0?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0o`3oooooooooo`06ooooo`;o0?l02?ooool00ol0o`3oooooooooo`0:ooooo`04
o`3o0?ooooooooooo`3o00cooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Foooo
o`00:oooool01?l0o`3oooooooooool0o`0@ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0oooo
ool0o`002?ooool00ol0o`3oooooooooo`04ooooo`;o0?l01Oooool2o`3o00Gooooo1Ol0o`06oooo
o`;o0?l01oooool2o`3o00Oooooo00?o0?l0ooooooooool02_ooool01?l0o`3oooooooooool0o`0=
ooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0ooooooooool05_ooool001_ooooo0ol0000=oooo
o`04o`3o0?ooooooooooo`3o013ooooo00?o0?l0ooooooooool01Ol00003ooooo`;o0?l02Oooool0
0ol0o`3oooooooooo`03ooooo`;o0?l01Oooool00ol0o`3oooooooooo`02ooooo`_o0?l01Oooool0
0ol0o`3oooooooooo`04ooooo`03o`3o0?oooooo0?l000Oooooo00?o0?l0ooooooooool01?ooool5
o`000004ooooool0o`3oooooo`3o00gooooo00?o0?l0ooooooooool04Oooool3o`000003o`3o0?oo
oooooooo01Kooooo000Looooo`03o`000?oooooooooo00_ooooo00Go0?l0ooooooooooooooooo`3o
000@ooooo`05o`3o0?ooooooooooooooool000000_ooool01_l0003oooooooooool0o`3oooooo`3o
00Sooooo00?o0?l0ooooooooool00oooool2o`3o00Gooooo00Co0?l0oooooooooooooooo1?l0o`00
0ooooooo0000ooooo`04ooooo`?o0?l01Oooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooo
0?l000Kooooo00?o0?l0ooooooooool01Oooool01_l0003oooooooooool0003oooooo`3o00;ooooo
00?o0?l0ooooooooool02_ooool00ol0o`3oooooooooo`0Booooo`03o`000?oooooo0?l001Sooooo
000Cooooo`Go000000?oooooo`000?l000000ol0000<ooooo`05o`3o0?ooooooooooooooool0o`00
3Oooool3o`000003o`3o0?l0003ooooo00;ooooo00?o0000ooooooooool00_ooool00ol0o`3ooooo
o`3o0008ooooo`03o`3o0?oooooooooo00?ooooo0_l0o`04ooooo`03o`3o0?oooooooooo00;ooooo
0_l0o`03ooooo`03o`000?oooooooooo00Gooooo0_l0o`04ooooo`03o`3o0?oooooooooo00Cooooo
00?o0?l0ooooool0o`001oooool00ol0o`3oooooooooo`05ooooo`05o`000?ooooooooooooooool0
o`000_ooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo00oooooo1Ol000000ol0o`3o
ooooooooo`0Fooooo`006Oooool01?l0003oooooooooool0000=ooooo`05o`3o0?oooooooooooooo
ool0o`003oooool00ol0o`3oooooooooo`04ooooo`07o`000?ooooooooooooooool0o`3oooooo`3o
0008ooooo`03o`3o0?oooooooooo00;ooooo0_l0o`05ooooo`05o`3o0?ooooooooooooooool0o`00
1?ooool6o`3o00Gooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`04ooooo`03o`3o
0?oooooo0?l000Kooooo00?o0?l0ooooooooool01_ooool01?l0003oooooooooool0o`02ooooo`03
o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool03oooool01_l0003oooooooooool0003ooooo
o`3o01Sooooo000Jooooo`03o`000?oooooo000000gooooo00Go0?l0ooooooooooooooooo`3o000?
ooooo`05o`3o0?ooooooooooooooool000000oooool01Ol0003oooooo`3o0?oooooo0?l000Sooooo
00?o0?l0ooooooooool00oooool2o`3o00Cooooo00Go0?l0ooooooooooooooooo`3o0003ooooo`;o
0?l000?oooooo`000?ooool00oooool2o`3o00?ooooo0_l0o`04ooooo`03o`3o0?oooooooooo00?o
oooo00?o0?l0ooooool0o`001_ooool00ol0o`3oooooooooo`03ooooo`07o`000?oooooooooooooo
ool0003oooooo`3o0002ooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooooooool03oooool0
1Ol0003oooooo`000?oooooo0?l001Sooooo000Kooooo`;o00003Oooool01?l0o`3oooooooooool0
o`0@ooooo`05o`3o0?ooooooooooooooool000000oooool01Ol0003oooooo`3o0?oooooo0?l000So
oooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooo`3o0004ooooo`04o`3o0?ooooooooooo`3o
00;ooooo0_l0o`000ooooooo0?l0o`3o0005o`3o0003ooooool0o`3o0?l000?ooooo00?o0?l0oooo
ooooool00_ooool00ol0o`3oooooooooo`04ooooo`;o0?l01_ooool00ol0o`3oooooooooo`03oooo
o`07o`000?ooooooooooooooool0003oooooo`3o0002ooooo`03o`3o0?oooooooooo00_ooooo00?o
0?l0ooooooooool04?ooool2o`0000;ooooo00?o0?l0ooooooooool05Oooool001cooooo00?o0000
ooooooooool02oooool01?l0o`3oooooooooool0o`0@ooooo`03o`3o0?oooooooooo00;ooooo0ol0
0002ooooo`03o`3o0?oooooo0?l000Sooooo00?o0?l0ooooooooool00_ooool2o`3o00Cooooo00?o
0?l0ooooooooool00_l0o`02ooooo`05o`3o0?oooooo0?l0o`3o0?ooool00_l0o`001_oooooo0?l0
o`3o0?l0o`3oooooo`3o00?ooooo0_l0o`03ooooo`03o`3o0?oooooooooo00Cooooo0_l0o`06oooo
o`;o0?l01Oooool3o`0000?ooooo00?o0?l0ooooool0o`003Oooool00ol0o`3oooooooooo`0Aoooo
o`04o`000?ooooooooooo`3o01Oooooo000Zooooo`04o`3o0?ooooooooooo`3o013ooooo00?o0?l0
ooooooooool01oooool00ol0o`3oooooo`3o0008ooooo`03o`3o0?oooooooooo00;ooooo0_l0o`04
ooooo`04o`3o0?ooooooooooo`3o00;ooooo00?o0?l0ooooool0o`001ol0o`001Ooooooo0?l0o`3o
0?oooooo0?l000?ooooo00Go0?l0ooooooooooooooooo`3o0006ooooo`;o0?l01oooool00ol0o`3o
ooooooooo`09ooooo`03o`3o0?oooooo0?l000gooooo00?o0?l0ooooooooool05?ooool00ol0o`3o
ooooooooo`0Eooooo`00:_ooool01?l0o`3oooooooooool0o`0@ooooo`03o`3o0?oooooooooo00Oo
oooo00?o0?l0ooooool0o`002?ooool00ol0o`3oooooooooo`02ooooo`;o0?l01?ooool01Ol0o`3o
ooooo`3o0?l0o`3ooooo00co0?l000Coooooo`3o0?oooooo0?l00oooool2o`3o00?ooooo00?o0?l0
ooooooooool00oooool2o`3o00Oooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooo`3o000<
ooooo`04o`000?l0o`3o0000o`0001Cooooo00?o0?l0ooooooooool05Oooool002[ooooo00Co0?l0
oooooooooooo0?l04?ooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooo0?l000Oooooo00?o
0?l0ooooooooool00oooool2o`3o00?ooooo00?o0?l0ooooooooool00_l0o`000ooooooo0?l0oooo
o`0:o`3o0005ooooool0o`3o0?l0ooooool0o`000_ooool2o`3o00?ooooo00?o0?l0ooooooooool0
0oooool00ol0o`3oooooo`3o0006ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooool0o`00
2oooool2o`000004o`3o0?l0003o0000o`0001?ooooo00?o0?l0ooooooooool05Oooool002[ooooo
00Co0?l0oooooooooooo0?l04?ooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooo0?l000Oo
oooo00?o0?l0ooooooooool00oooool2o`3o00?ooooo00?o0?l0ooooooooool00_l0o`000ooooooo
0?l0ooooo`0=o`3o0004ooooool0o`3oooooooooo`;o0?l00oooool00ol0o`3oooooooooo`03oooo
o`03o`3o0?oooooo0?l000Kooooo00?o0?l0ooooooooool02Oooool01?l0o`3oooooooooool0o`0:
ooooo`;o000000Co0?l0o`000?l0003o00004oooool00ol0o`3oooooooooo`0Eooooo`001OoooolU
o`000004o`3o0?l0003o0000o`3o013o000000?o0?l0o`000?l000001ol000000ol0o`3o0000o`3o
0007o`000003o`3o0?l0003o000000?o00000_l0o`03o`000003o`3o0?l0003o000000;o0?l000?o
0000o`3o0?l000001?l0o`02o`0000?o0?l000Ko0000o`3o0?l0o`3o0?l0o`000?l0o`02o`0000;o
0?l00ol000000ol0o`3o0000o`000003o`000003o`3o0?l0003o0?l000Ko000000?o0?l0o`000?l0
00002Ol000001?l0o`3o0000o`000?l0o`0<o`000003o`3o0?l0003o000001Co000000?o0?l0o`00
0?l000003ol00006ooooo`006Oooool00ol0003oooooooooo`0>ooooo`04o`3o0?ooooooooooo`3o
013ooooo00Go0?l0ooooooooooooooooo`000005ooooo`03o`3o0?oooooo0?l000Oooooo00?o0?l0
ooooooooool00oooool2o`3o00?ooooo00?o0?l0ooooooooool00_l0o`000ooooooo0?l0ooooo`0:
o`3o0005ooooool0o`3o0?l0ooooool0o`000_ooool2o`3o00?ooooo00?o0?l0ooooooooool00ooo
ool00ol0o`3oooooo`3o0006ooooo`03o`3o0?oooooooooo00Gooooo00Oo0000oooooooooooooooo
o`3o0?oooooo0?l000_ooooo1_l0000@ooooo`04o`000?ooooooooooo`3o01Oooooo000Zooooo`04
o`3o0?ooooooooooo`3o013ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooo`3o0008oooo
o`03o`3o0?oooooooooo00;ooooo0_l0o`04ooooo`04o`3o0?oooooo0?l0o`3o00;ooooo2ol0o`00
0ooooooo0?l0ooooo`02o`3o00;ooooo0_l0o`03ooooo`03o`3o0?oooooooooo00?ooooo0_l0o`07
ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooool0o`003?ooool4o`0001Cooooo00?o0?l0
ooooooooool05Oooool002[ooooo00Co0?l0oooooooooooo0?l04?ooool00ol0o`3oooooooooo`07
ooooo`03o`3o0?oooooo0?l000Sooooo00?o0?l0ooooooooool00_ooool2o`3o00Cooooo00Co0?l0
oooooooooooo0?l00_ooool00ol0o`3oooooo`3o000:o`3o0003ooooool0o`3ooooo00;ooooo0_l0
o`03ooooo`03o`3o0?oooooooooo00?ooooo0_l0o`07ooooo`03o`3o0?oooooooooo00Wooooo00?o
0?l0ooooool0o`009?ooool00ol0o`3oooooooooo`0Eooooo`00:_ooool01?l0o`3oooooooooool0
o`0@ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooool0o`002?ooool00ol0o`3ooooooooo
o`02ooooo`;o0?l01?ooool00ol0o`3oooooooooo`02o`3o00;ooooo00?o0?l0ooooool0o`001_l0
o`001Ooooooo0?l0oooooooooooo0?l000?ooooo00Go0?l0ooooooooooooooooo`3o0006ooooo`;o
0?l01oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooo0?l002Cooooo00?o0?l0oooooooo
ool05Oooool002[ooooo00Co0?l0oooooooooooo0?l04?ooool00ol0o`3oooooooooo`07ooooo`03
o`3o0?oooooo0?l000Sooooo00?o0?l0ooooooooool00_ooool2o`3o00Gooooo00?o0?l0oooooooo
ool00_l0o`02ooooo`Ko0?l00_ooool01?l0o`3oooooooooool0o`03ooooo`;o0?l00oooool00ol0
o`3oooooooooo`04ooooo`;o0?l01_ooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooo0?l0
02Cooooo00?o0?l0ooooooooool05Oooool002[ooooo00Co0?l0oooooooooooo0?l04?ooool00ol0
o`3oooooooooo`07ooooo`03o`3o0?oooooo0?l000Sooooo00?o0?l0ooooooooool00_ooool00ol0
o`3oooooo`3o0004ooooo`04o`3o0?ooooooooooooooo`;o0?l01Oooool00ol0003oooooooooo`02
o`3o00;ooooo00?o0?l0ooooooooool00_l0o`04ooooo`03o`3o0?oooooooooo00Cooooo0_l0o`06
ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooool0o`009?ooool00ol0o`3oooooooooo`0E
ooooo`00:_ooool01Ol0o`3ooooooooooooooooo0?l0013ooooo00?o0?l0ooooooooool01_ooool0
0ol0o`3oooooo`3o0008ooooo`03o`3o0?oooooooooo00?ooooo0_l0o`05ooooo`04o`3o0?oooooo
ooooooooo`Wo0?l00_ooool2o`3o00?ooooo0_l0o`03ooooo`03o`3o0?oooooooooo00Cooooo0_l0
o`07ooooo`03o`3o0?oooooooooo00Wooooo00Co0?l0oooooooooooo0?l08oooool00ol0o`3ooooo
ooooo`0Fooooo`00:_ooool01Ol0o`3ooooooooooooooooo0?l0013ooooo00?o0?l0ooooooooool0
1oooool00ol0o`3oooooo`3o0008ooooo`03o`3o0?oooooooooo00?ooooo0_l0o`05ooooo`03o`3o
0?oooooooooo00;ooooo1Ol0o`001?l0003oooooo`3o0?l0o`04ooooo`03o`3o0?oooooo0?l000?o
oooo00?o0?l0ooooooooool01?ooool2o`3o00Oooooo00?o0?l0ooooooooool02Oooool01?l0o`3o
ooooooooool0o`0Sooooo`03o`3o0?oooooooooo01Kooooo000[ooooo`04o`3o0?ooooooooooo`3o
013ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooo`3o0008ooooo`03o`3o0?oooooooooo
00?ooooo00?o0?l0ooooool0o`001Oooool2o`3o00Kooooo00?o0000ooooool0o`001_ooool2o`3o
00?ooooo00?o0?l0ooooooooool01?ooool00ol0o`3oooooo`3o0006ooooo`03o`3o0?oooooooooo
00[ooooo00Co0?l0oooooooooooo0?l08oooool00ol0o`3oooooooooo`0Fooooo`00:oooool01?l0
o`3oooooooooool0o`0@ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooool0o`002Oooool0
0ol0o`3oooooooooo`03ooooo`03o`3o0?oooooo0?l000Kooooo2Ol0o`05ooooo`03o`3o0?oooooo
oooo00;ooooo00?o0?l0ooooooooool01Oooool2o`3o00Oooooo00?o0?l0ooooooooool02_ooool0
1?l0o`3oooooooooool0o`0Sooooo`03o`3o0?oooooooooo01Kooooo000[ooooo`04o`3o0?oooooo
ooooo`3o013ooooo00?o0?l0ooooooooool02?ooool2o`3o00Wooooo00?o0?l0ooooooooool01?oo
ool00ol0o`3oooooo`3o000;ooooo`03o`000?oooooooooo00?ooooo0_l0o`05ooooo`03o`3o0?oo
oooooooo00Cooooo00?o0?l0ooooool0o`001oooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oo
oooo0?l002Cooooo00?o0?l0ooooooooool05_ooool002_ooooo00Co0?l0oooooooooooo0?l04Ooo
ool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooo0?l000Wooooo00?o0?l0ooooooooool01?oo
ool3o`3o00[ooooo0_l00003ooooo`;o0?l01Oooool00ol0o`3oooooooooo`05ooooo`;o0?l02?oo
ool00ol0o`3oooooooooo`09ooooo`04o`3o0?ooooooooooo`3o02Cooooo00?o0?l0ooooooooool0
5_ooool002_ooooo00Co0?l0oooooooooooo0?l04Oooool00ol0o`3oooooooooo`08ooooo`;o0?l0
2Oooool00ol0o`3oooooooooo`06ooooo`Co0?l01oooool00ol0003oooooo`3o0003o`3o00Gooooo
00?o0?l0ooooooooool01Oooool00ol0o`3oooooo`3o0007ooooo`03o`3o0?oooooooooo00[ooooo
00Co0?l0oooooooooooo0?l09?ooool00ol0o`3oooooooooo`0Fooooo`00:oooool01Ol0o`3ooooo
oooooooooooo0?l0013ooooo00?o0?l0ooooooooool02?ooool2o`3o00[ooooo0_l0o`07ooooo`ko
0?l01_ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooo0?l000Oooooo00?o0?l0oooooooo
ool02Oooool01Ol0o`3ooooooooooooooooo0?l002Cooooo00?o0?l0ooooooooool05_ooool002_o
oooo00Go0?l0ooooooooooooooooo`3o000@ooooo`03o`3o0?oooooooooo00Wooooo0_l0o`0;oooo
o`;o0?l01oooool9o`3o00Oooooo0_l0o`09ooooo`;o0?l02?ooool00ol0o`3oooooooooo`09oooo
o`04o`3o0?ooooooooooo`3o02Cooooo00?o0?l0ooooooooool05oooool002cooooo00Co0?l0oooo
oooooooo0?l04Oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooo0?l000cooooo00?o0?l0
ooooooooool03?ooool2o`0000Cooooo0_l0o`0:ooooo`03o`3o0?oooooo0?l000Oooooo00?o0?l0
ooooooooool02_ooool01?l0o`3oooooooooool0o`0Tooooo`03o`3o0?oooooooooo01Oooooo000/
ooooo`05o`3o0?ooooooooooooooool0o`004?ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oo
oooo0?l000cooooo00?o0?l0ooooooooool00oooool3o`0000Gooooo00?o0000ooooooooool00_oo
ool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooo0?l000Oooooo00?o0?l0ooooooooool02_oo
ool01Ol0o`3ooooooooooooooooo0?l002Cooooo00?o0?l0ooooooooool05oooool002cooooo00Go
0?l0ooooooooooooooooo`3o000Aooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooool0o`00
3?ooool2o`3o00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02o`3o00_ooooo
0ol0o`08ooooo`03o`3o0?oooooooooo00[ooooo00Co0?l0oooooooooooo0?l09Oooool00ol0o`3o
ooooooooo`0Gooooo`00;Oooool01Ol0o`3ooooooooooooooooo0?l0013ooooo00?o0?l0oooooooo
ool02Oooool01?l0o`3oooooooooool0o`0=ooooo`Co0?l000?o0000ooooooooool01?ooool3o`3o
00_ooooo0ol0o`09ooooo`03o`3o0?oooooooooo00_ooooo00Co0?l0oooooooooooo0?l09Oooool0
0ol0o`3oooooooooo`0Gooooo`00;Oooool01Ol0o`3ooooooooooooooooo0?l0017ooooo00?o0?l0
ooooooooool02Oooool01?l0o`3oooooooooool0o`0@ooooo`Oo0?l00_l0000;ooooo`03o`3o0?oo
oooo0?l000[ooooo00?o0?l0ooooooooool02_ooool01Ol0o`3ooooooooooooooooo0?l002Cooooo
00?o0?l0ooooooooool06?ooool002gooooo00Go0?l0ooooooooooooooooo`3o000Aooooo`03o`3o
0?oooooooooo00[ooooo00Co0?l0oooooooooooo0?l03oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Wooooo00?o0?l0ooooool0o`002_ooool00ol0o`3oooooooooo`0;ooooo`04
o`3o0?ooooooooooo`3o02Gooooo00?o0?l0ooooooooool06?ooool002kooooo00Go0?l0oooooooo
ooooooooo`3o000Aooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool00_l0o`0<oooo
o`;o00001_ooool00ol0003oooooooooo`07ooooo`Co0?l02_ooool00ol0o`3oooooooooo`0;oooo
o`05o`3o0?ooooooooooooooool0o`009Oooool00ol0o`3oooooooooo`0Hooooo`00;_ooool01Ol0
o`3ooooooooooooooooo0?l001;ooooo00?o0?l0ooooooooool02_ooool2o`3o00;ooooo0_l0o`0;
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool3o`3o00_ooooo00?o0?l0
ooooooooool03?ooool01?l0o`3oooooooooool0o`0Vooooo`03o`3o0?oooooooooo01Sooooo000_
ooooo`05o`3o0?ooooooooooooooool0o`004_ooool00ol0o`3oooooooooo`0;ooooo`;o0?l00_oo
ool00ol0o`3oooooooooo`0?ooooo`;o00001_ooool2o`3o00cooooo00?o0?l0ooooooooool03Ooo
ool00ol0o`3oooooo`3o000Vooooo`03o`3o0?oooooooooo01Wooooo000_ooooo`05o`3o0?oooooo
ooooooooool0o`004oooool00ol0o`3oooooooooo`0<ooooo`03o`3o0?oooooooooo00;o0?l03ooo
ool00ol0003oooooooooo`03ooooo`?o0?l03?ooool00ol0o`3oooooooooo`0=ooooo`04o`3o0?oo
ooooooooo`3o02Kooooo00?o0?l0ooooooooool06Oooool002oooooo00Go0?l0oooooooooooooooo
o`3o000Dooooo`03o`3o0?oooooooooo00cooooo0ol0o`001?oooooo0?l0o`3o0?l0o`0<ooooo`03
o`000?oooooooooo00?o0?l000?oooooo`3o0?ooool02oooool00ol0o`3oooooooooo`0>ooooo`03
o`3o0?oooooo0?l002Oooooo00?o0?l0ooooooooool06Oooool0033ooooo00Go0?l0oooooooooooo
ooooo`3o000Dooooo`03o`3o0?oooooooooo00kooooo0_l0o`02ooooo`oo0?l00_ooool2o`3o00co
oooo00?o0?l0ooooooooool03_ooool01?l0o`3oooooooooool0o`0Vooooo`03o`3o0?oooooooooo
01[ooooo000`ooooo`05o`3o0?ooooooooooooooool0o`005Oooool00ol0o`3oooooooooo`0?oooo
o`?o0?l02oooool5o`3o00gooooo00?o0?l0ooooooooool03_ooool01?l0o`3oooooooooool0o`0W
ooooo`03o`3o0?oooooooooo01[ooooo000aooooo`05o`3o0?ooooooooooooooool0o`005Oooool0
0ol0o`3oooooooooo`0Aooooo`_o0?l000?o0000ooooooooool03Oooool2o`3o013ooooo00Co0?l0
oooooooooooo0?l0:?ooool00ol0o`3oooooooooo`0Jooooo`00<_ooool01Ol0o`3ooooooooooooo
oooo0?l001Gooooo00?o0?l0ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`3o0?oo
oooooooo013ooooo00?o0?l0ooooool0o`00:?ooool00ol0o`3oooooooooo`0Kooooo`00<_ooool0
1Ol0o`3ooooooooooooooooo0?l001Kooooo0_l0o`0Kooooo`03o`000?oooooooooo00[ooooo0_l0
o`0Booooo`04o`3o0?ooooooooooo`3o02Sooooo00?o0?l0ooooooooool06oooool003?ooooo00Go
0?l0ooooooooooooooooo`3o000Gooooo`;o0?l06Oooool2o`0000Wooooo0_l0o`0Cooooo`04o`3o
0?ooooooooooo`3o02Sooooo00?o0?l0ooooooooool07?ooool003?ooooo00?o0?l0ooooooooool0
0_ooool00ol0o`3oooooooooo`0Fooooo`;o0?l05oooool00ol0003oooooooooo`06ooooo`;o0?l0
5?ooool01?l0o`3oooooooooool0o`0Yooooo`03o`3o0?oooooooooo01cooooo000dooooo`03o`3o
0?oooooooooo00;ooooo00?o0?l0ooooooooool05oooool00ol0o`3oooooooooo`0Dooooo`03o`00
0?oooooooooo00Gooooo00?o0?l0ooooooooool04oooool01?l0o`3oooooooooool0o`0Zooooo`03
o`3o0?oooooooooo01cooooo000eooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool0
5oooool4o`3o01;ooooo00?o0000ooooooooool00oooool2o`3o01Gooooo00Go0?l0oooooooooooo
ooooo`3o000Yooooo`03o`3o0?oooooooooo01gooooo000fooooo`03o`3o0?oooooooooo00;ooooo
00?o0?l0ooooooooool06_ooool3o`3o00oooooo0_l00004o`3o01Kooooo00Go0?l0oooooooooooo
ooooo`3o000Zooooo`03o`3o0?oooooooooo01gooooo000gooooo`;o0?l00oooool00ol0o`3ooooo
ooooo`0Looooo`Ko0?l00ol00008o`3o01Sooooo0_l0o`03ooooo`03o`3o0?oooooooooo02Wooooo
00?o0?l0ooooooooool07Oooool003Wooooo00Go0?l0ooooooooooooooooo`3o000Sooooo`?o0?l0
00?oooooo`000?ooool00oooool00ol0003oooooooooo`0Fooooo`04o`3o0?ooooooooooooooo`;o
0?l0:oooool00ol0o`3oooooooooo`0Nooooo`00>_ooool01?l0o`3oooooooooooooool2o`3o02?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`05o`3o0?oooooooooooooo
ool0o`00;Oooool00ol0o`3oooooooooo`0Nooooo`00>oooool00ol0o`3oooooooooo`02ooooo`03
o`3o0?oooooooooo027ooooo00?o0000ooooooooool00oooool2o`0001Gooooo00Go0?l0oooooooo
ooooooooo`3o000]ooooo`03o`3o0?oooooooooo01oooooo000looooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool07Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool04_ooool2o`3o00;ooooo0_l0o`0^ooooo`03o`3o0?oooooooooo01oooooo000mooooo`03
o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool07?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool04Oooool01Ol0o`3ooooooooooooooooo0?l002oooooo00?o0?l0
ooooooooool08?ooool003kooooo00?o0?l0ooooooooool00_ooool2o`3o01gooooo0ol00005oooo
o`03o`000?oooooooooo013ooooo00Go0?l0ooooooooooooooooo`3o000_ooooo`03o`3o0?oooooo
oooo027ooooo000oooooo`;o0?l01?ooool2o`3o02?ooooo0_l0000?ooooo`;o0?l00oooool00ol0
o`3oooooooooo`0^ooooo`03o`3o0?oooooooooo027ooooo0011ooooo`03o`3o0?oooooooooo00?o
oooo00?o0?l0ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`;o0?l00oooool2o`3o033o
oooo00?o0?l0ooooooooool08_ooool004;ooooo00?o0?l0ooooooooool00oooool2o`3o023ooooo
00?o0000ooooooooool02_ooool2o`3o00Cooooo00?o0?l0ooooooooool0<?ooool00ol0o`3ooooo
ooooo`0Rooooo`00@oooool00ol0o`3oooooooooo`04ooooo`?o0?l07Oooool00ol0003ooooooooo
o`07ooooo`?o0?l01?ooool2o`3o03;ooooo00?o0?l0ooooooooool08oooool004Cooooo0_l0o`07
ooooo`?o0?l06_ooool2o`0000Kooooo0_l0o`05ooooo`;o0?l0<oooool00ol0o`3oooooooooo`0T
ooooo`00A_ooool3o`3o00Oooooo0_l0o`0Hooooo`03o`000?oooooooooo00;ooooo0ol0o`06oooo
o`03o`3o0?oooooooooo03?ooooo00?o0?l0ooooooooool09?ooool004Wooooo0_l0o`07ooooo`?o
0?l05Oooool5o`3o00Oooooo0_l0o`0eooooo`03o`3o0?oooooooooo02Gooooo001;ooooo`03o`3o
0?oooooooooo00Oooooo1_l0o`0;ooooo`Co0?l000?o0000ooooooooool01_ooool3o`3o03Oooooo
00?o0?l0ooooooooool09Oooool004cooooo0ol0o`0<ooooo`_o0?l01?ooool2o`0000?ooooo1?l0
o`0iooooo`03o`3o0?oooooooooo02Kooooo001?ooooo`Go0?l05_ooool00ol0003o0?l0o`3o0002
o`3o03cooooo00?o0?l0ooooooooool09oooool005Cooooo1Ol0o`0<ooooo`Ko0?l0@?ooool00ol0
o`3oooooooooo`0Wooooo`00FOooool<o`3o00Gooooo00?o0000ooooooooool0?Oooool00ol0o`3o
ooooooooo`0Xooooo`00J_ooool2o`0003gooooo00?o0?l0ooooooooool0:Oooool006;ooooo0ol0
0005ooooo`03o`000?oooooooooo03Sooooo0ol000000ol0o`3oooooooooo`0Zooooo`00HOooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0=oooool4o`000003o`3o0?l0
003ooooo02[ooooo001Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool3
o`000003o`3o0?l0003o000002_ooooo001Sooooo`;o00001Oooool2o`0003Sooooo0_l000001?l0
o`3o0000o`000?l0000[ooooo`00IOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03Oooooo1_l0000[ooooo`00HOooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0>?ooool4o`0002cooooo001Rooooo`?o00001Oooool00ol0003oooooooooo`1Xooooo`00
J_ooool2o`0006Wooooo001Zooooo`03o`000?oooooooooo06Sooooo001Zooooo`03o`000?oooooo
oooo06Sooooo001Zooooo`03o`000?oooooooooo06Sooooo001Zooooo`;o0000JOooool006[ooooo
00?o0000ooooooooool0J?ooool006[ooooo00?o0000ooooooooool0J?ooool006[ooooo00?o0000
ooooooooool0J?ooool006[ooooo0_l0001Yooooo`00J_ooool00ol0003oooooooooo`1Xooooo`00
J_ooool00ol0003oooooooooo`1Xooooo`00J_ooool00ol0003oooooooooo`1Xooooo`00J_ooool2
o`0006Wooooo001Sooooo`?o00001?ooool00ol0003oooooooooo`1Xooooo`00I?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06Sooooo001Qooooo`Go00001?ooool00ol0003ooooo
ooooo`1Xooooo`00HOooool01?l0003oooooooooool00005ooooo`;o0000JOooool006;ooooo00?o
0000ooooool00000L?ooool006?ooooo0_l0001`ooooo`00I?ooool00ol0003oooooooooo`1^oooo
o`00eOooool00001\
\>"],
  ImageRangeCache->{{{77.875, 290.375}, {513.688, 343.938}} -> {-9.16339, \
12.8928, 0.0497672, 0.0497672}}]
}, Open  ]],

Cell["The trajectories get close, but they do not intersect. ", "Text"],

Cell[TextData[StyleBox["Force it: A non-autonomous equation",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["Now force the system periodically with the cosine function. ", "Text"],

Cell[TextData[{
  StyleBox["y''",
    FontSlant->"Italic"],
  " + 0.2 ",
  StyleBox["y'",
    FontSlant->"Italic"],
  " + ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = cos(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
The equation is no longer autonomous and, as we shall see below, \
the phase plane trajectories overlap. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
DE2 = y''[t] + 0.2y'[t] + y[t] == Cos[t];
soln2 = DSolve[ {DE2, y[0]==y0, y'[0]==v0}, y[t], t]//FullSimplify\
\>", \
"Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({{y[
            t] \[Rule] \[ExponentialE]\^\(\(-0.1`\)\ t\)\ \
\((\((\((\(-6.276465692548548`*^-16\) + 
                          4.333342374871281`*^-33\ \[ImaginaryI])\) + \
\((\(\(0.`\)\(\[InvisibleSpace]\)\) + 
                            0.`\ \[ImaginaryI])\)\ v0 + \
\((\(\(1.0000000000000002`\)\(\[InvisibleSpace]\)\) + 
                            1.4017440046691755`*^-17\ \[ImaginaryI])\)\ y0)\)\
\ Cos[0.99498743710662`\ t] + \((\((\(-5.025189076296059`\) - 
                          7.148635097454183`*^-18\ \[ImaginaryI])\) + \
\((\(\(1.0050378152592123`\)\(\[InvisibleSpace]\)\) + 
                            3.4956865591156095`*^-20\ \[ImaginaryI])\)\ v0 + \
\((\(\(0.10050378152592121`\)\(\[InvisibleSpace]\)\) - 
                            6.938893903907229`*^-19\ \[ImaginaryI])\)\ y0)\)\ \
Sin[0.99498743710662`\ t] + \[ExponentialE]\^\(0.1`\ t\)\ \
\((\((6.661338147750939`*^-16 + 
                            8.881784197001252`*^-16\ \[ImaginaryI])\)\ Cos[
                          0.9999999999999999`\ t] + \((\(\(5.000000000000001`\
\)\(\[InvisibleSpace]\)\) - 2.220446049250313`*^-16\ \[ImaginaryI])\)\ Sin[
                          0.9999999999999999`\ t])\))\)}}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[TextData[{
  "The solution formula is quite complicated. Applying FullSimplify helped a \
little bit. It appears that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is using an algorithm that uses the complex roots of the characteristic \
equation."
}], "Text"],

Cell["The new phi function.", "Text"],

Cell["phi2[y0_,v0_,t] := Evaluate[ y[t]/.soln2 ]", "Input",
  CellLabel->"In[19]:="],

Cell[TextData[{
  "The time series for ",
  StyleBox["y",
    FontSlant->"Italic"],
  " with the same initial conditions: "
}], "Text"],

Cell[TextData[{
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 3, ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(0) = -3, 0, 3 ."
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Plot[ Evaluate[Table[phi2[3,v,t],{v,-3,3,3}]], {t,0,40},
      PlotStyle->RGBColor[1,0,0], AspectRatio->1/4, PlotLabel->\"Position\" ]\
\
\>", "Input",
  CellLabel->"In[20]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.124889 0.0239327 [
[.2619 .11239 -6 -9 ]
[.2619 .11239 6 0 ]
[.5 .11239 -6 -9 ]
[.5 .11239 6 0 ]
[.7381 .11239 -6 -9 ]
[.7381 .11239 6 0 ]
[.97619 .11239 -6 -9 ]
[.97619 .11239 6 0 ]
[.01131 .02916 -12 -4.5 ]
[.01131 .02916 0 4.5 ]
[.01131 .07702 -12 -4.5 ]
[.01131 .07702 0 4.5 ]
[.01131 .17275 -6 -4.5 ]
[.01131 .17275 0 4.5 ]
[.01131 .22062 -6 -4.5 ]
[.01131 .22062 0 4.5 ]
[.5 .2625 -26 0 ]
[.5 .2625 26 12 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .12489 m
.2619 .13114 L
s
[(10)] .2619 .11239 0 1 Mshowa
.5 .12489 m
.5 .13114 L
s
[(20)] .5 .11239 0 1 Mshowa
.7381 .12489 m
.7381 .13114 L
s
[(30)] .7381 .11239 0 1 Mshowa
.97619 .12489 m
.97619 .13114 L
s
[(40)] .97619 .11239 0 1 Mshowa
.125 Mabswid
.07143 .12489 m
.07143 .12864 L
s
.11905 .12489 m
.11905 .12864 L
s
.16667 .12489 m
.16667 .12864 L
s
.21429 .12489 m
.21429 .12864 L
s
.30952 .12489 m
.30952 .12864 L
s
.35714 .12489 m
.35714 .12864 L
s
.40476 .12489 m
.40476 .12864 L
s
.45238 .12489 m
.45238 .12864 L
s
.54762 .12489 m
.54762 .12864 L
s
.59524 .12489 m
.59524 .12864 L
s
.64286 .12489 m
.64286 .12864 L
s
.69048 .12489 m
.69048 .12864 L
s
.78571 .12489 m
.78571 .12864 L
s
.83333 .12489 m
.83333 .12864 L
s
.88095 .12489 m
.88095 .12864 L
s
.92857 .12489 m
.92857 .12864 L
s
.25 Mabswid
0 .12489 m
1 .12489 L
s
.02381 .02916 m
.03006 .02916 L
s
[(-4)] .01131 .02916 1 0 Mshowa
.02381 .07702 m
.03006 .07702 L
s
[(-2)] .01131 .07702 1 0 Mshowa
.02381 .17275 m
.03006 .17275 L
s
[(2)] .01131 .17275 1 0 Mshowa
.02381 .22062 m
.03006 .22062 L
s
[(4)] .01131 .22062 1 0 Mshowa
.125 Mabswid
.02381 .04112 m
.02756 .04112 L
s
.02381 .05309 m
.02756 .05309 L
s
.02381 .06506 m
.02756 .06506 L
s
.02381 .08899 m
.02756 .08899 L
s
.02381 .10096 m
.02756 .10096 L
s
.02381 .11292 m
.02756 .11292 L
s
.02381 .13685 m
.02756 .13685 L
s
.02381 .14882 m
.02756 .14882 L
s
.02381 .16079 m
.02756 .16079 L
s
.02381 .18472 m
.02756 .18472 L
s
.02381 .19669 m
.02756 .19669 L
s
.02381 .20865 m
.02756 .20865 L
s
.02381 .01719 m
.02756 .01719 L
s
.02381 .00523 m
.02756 .00523 L
s
.02381 .23259 m
.02756 .23259 L
s
.02381 .24455 m
.02756 .24455 L
s
.25 Mabswid
.02381 0 m
.02381 .25 L
s
gsave
.5 .2625 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Position) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .19669 m
.04262 .13569 L
.0522 .10759 L
.06244 .0844 L
.0679 .0756 L
.07286 .06982 L
.07525 .06779 L
.07651 .06691 L
.07784 .06612 L
.07901 .06555 L
.08029 .06505 L
.08146 .0647 L
.08255 .06447 L
.08326 .06437 L
.08391 .06431 L
.08463 .06428 L
.08539 .06429 L
.08612 .06434 L
.08681 .06442 L
.0881 .06465 L
.08936 .06499 L
.09053 .06539 L
.09317 .0666 L
.09581 .06822 L
.09872 .07041 L
.10458 .076 L
.12409 .1018 L
.145 .13304 L
.15518 .14699 L
.16624 .15984 L
.17131 .16458 L
.1767 .16862 L
.18129 .17115 L
.18255 .17168 L
.18391 .17217 L
.1852 .17255 L
.18637 .17282 L
.1876 .17304 L
.18876 .17317 L
.18999 .17323 L
.19068 .17323 L
.19132 .17321 L
.19239 .17312 L
.19356 .17296 L
.19479 .1727 L
.19594 .17238 L
.19857 .17137 L
.20098 .1701 L
.20377 .16822 L
.20641 .16602 L
Mistroke
.21164 .16048 L
.2165 .15402 L
.22751 .13537 L
.24634 .0972 L
.25624 .0792 L
.26122 .07196 L
.26408 .06854 L
.26669 .06597 L
.26948 .06382 L
.27102 .06293 L
.27247 .06227 L
.27312 .06204 L
.27382 .06184 L
.27506 .06159 L
.27575 .06152 L
.27639 .06149 L
.2771 .0615 L
.27787 .06157 L
.27912 .0618 L
.27982 .062 L
.28048 .06223 L
.28181 .06283 L
.28323 .06366 L
.2858 .06567 L
.28814 .06805 L
.29313 .07484 L
.29853 .08465 L
.30832 .10772 L
.32784 .16169 L
.33319 .17492 L
.33893 .18689 L
.34171 .19166 L
.34435 .19545 L
.3467 .19819 L
.34795 .19939 L
.34929 .20048 L
.35057 .20132 L
.35174 .2019 L
.35286 .20231 L
.35405 .20256 L
.3553 .20263 L
.35646 .20252 L
.35774 .2022 L
.35845 .20193 L
.3591 .20163 L
.36134 .20016 L
.3626 .19906 L
.36377 .19785 L
.36818 .19178 L
.37294 .18269 L
Mistroke
.37817 .16996 L
.38875 .13776 L
.39954 .10112 L
.4098 .0692 L
.41426 .05775 L
.41901 .04787 L
.42174 .04343 L
.42422 .04026 L
.42542 .03904 L
.42671 .03794 L
.42793 .03713 L
.42906 .03658 L
.43023 .0362 L
.4313 .03604 L
.43254 .03606 L
.43371 .0363 L
.43479 .0367 L
.43579 .03723 L
.43689 .03798 L
.43805 .03898 L
.44047 .0417 L
.44275 .04502 L
.44792 .05525 L
.45293 .06831 L
.45751 .08257 L
.46785 .12006 L
.47778 .15793 L
.48324 .17714 L
.48839 .19304 L
.49319 .20526 L
.49572 .21049 L
.4984 .21503 L
.50065 .21801 L
.50185 .21926 L
.50313 .22036 L
.50431 .22112 L
.50538 .22163 L
.50647 .22194 L
.50749 .22206 L
.50873 .22196 L
.5099 .22164 L
.51095 .22115 L
.51208 .22042 L
.51332 .21938 L
.51462 .21801 L
.51696 .21486 L
.52115 .20709 L
.52574 .19566 L
.53603 .16106 L
.54562 .12218 L
Mistroke
.55611 .07966 L
.56126 .06117 L
.56603 .04654 L
.57035 .03584 L
.57256 .03143 L
.57493 .02756 L
.57617 .02591 L
.57731 .02463 L
.57846 .02356 L
.57953 .02277 L
.58077 .02211 L
.58143 .02187 L
.58213 .0217 L
.58343 .02161 L
.5846 .0218 L
.5858 .02224 L
.58692 .02289 L
.58815 .02385 L
.58947 .02519 L
.59216 .02885 L
.59462 .03325 L
.59935 .04445 L
.60384 .05802 L
.62465 .14327 L
.6343 .18294 L
.63959 .20127 L
.64455 .21521 L
.64877 .22407 L
.65113 .22773 L
.65331 .23022 L
.65447 .2312 L
.65555 .23189 L
.65674 .23239 L
.65801 .23263 L
.65865 .23264 L
.65935 .23256 L
.66061 .23219 L
.66184 .23154 L
.66297 .23069 L
.66422 .22947 L
.66541 .22805 L
.66764 .2247 L
.67266 .21401 L
.677 .20157 L
.68173 .18509 L
.70236 .09494 L
.71251 .05385 L
.71749 .03782 L
.72206 .02635 L
.72464 .02143 L
Mistroke
.72736 .01754 L
.72877 .01606 L
.73008 .01502 L
.73084 .01457 L
.73153 .01426 L
.73232 .01401 L
.73307 .01389 L
.73428 .01392 L
.73556 .01427 L
.73665 .01482 L
.73785 .01569 L
.73914 .01693 L
.74053 .01862 L
.74305 .02258 L
.74802 .03372 L
.75264 .04765 L
.76312 .0891 L
.77398 .13939 L
.78423 .18458 L
.78901 .20249 L
.79406 .21809 L
.79671 .22463 L
.79961 .23043 L
.80088 .23249 L
.80225 .23436 L
.80353 .23578 L
.80472 .23682 L
.80587 .23757 L
.8071 .23807 L
.80834 .23828 L
.80904 .23826 L
.80971 .23815 L
.81089 .23774 L
.81198 .23712 L
.81318 .23616 L
.81444 .23486 L
.81663 .23185 L
.81867 .22824 L
.82331 .21726 L
.82835 .20139 L
.83381 .18032 L
.84374 .13538 L
.85333 .08998 L
.86231 .05222 L
.86724 .03548 L
.87176 .02346 L
.87433 .0182 L
.87677 .01435 L
.8781 .01272 L
.87934 .01153 L
Mistroke
.88004 .01099 L
.8807 .01057 L
.88147 .01019 L
.88216 .00996 L
.88338 .00977 L
.88407 .0098 L
.88472 .00991 L
.88602 .0104 L
.88675 .01082 L
.88742 .0113 L
.88861 .01237 L
.8899 .01386 L
.89226 .01741 L
.89501 .02288 L
.89794 .03018 L
.90319 .04678 L
.92136 .12708 L
.9309 .17206 L
.9361 .19392 L
.94095 .21135 L
.94519 .22377 L
.94737 .22894 L
.94973 .23358 L
.95108 .23575 L
.95232 .23744 L
.95348 .23875 L
.95476 .23988 L
.95591 .24061 L
.95698 .24104 L
.95812 .24125 L
.95933 .24118 L
.96046 .24085 L
.9615 .24031 L
.96264 .23947 L
.96385 .23828 L
.9661 .23531 L
.96814 .23177 L
.97229 .22218 L
.97619 .21046 L
Mfstroke
.02381 .19669 m
.02499 .19663 L
.02605 .19648 L
.02729 .19618 L
.02846 .19579 L
.03053 .19482 L
.03279 .19339 L
.03527 .19137 L
.0379 .18874 L
.04262 .18286 L
.05205 .16724 L
.06244 .1457 L
.08274 .09981 L
.0881 .08886 L
.09394 .07829 L
.09952 .06992 L
.10458 .0641 L
.1073 .06174 L
.10986 .06005 L
.11127 .05935 L
.11256 .05885 L
.1133 .05863 L
.11399 .05846 L
.1147 .05833 L
.11549 .05824 L
.1168 .0582 L
.11805 .05831 L
.11916 .05852 L
.12038 .05887 L
.1217 .0594 L
.1231 .06013 L
.12562 .06187 L
.12789 .06391 L
.13034 .06661 L
.13477 .07273 L
.14487 .09203 L
.16452 .14236 L
.17491 .16859 L
.18062 .18079 L
.18601 .19009 L
.18851 .19354 L
.19117 .19652 L
.19255 .1978 L
.19408 .19896 L
.19546 .19979 L
.19676 .20038 L
.19802 .20078 L
.19922 .20098 L
.2003 .20102 L
.20147 .20091 L
Mistroke
.20274 .20061 L
.20346 .20036 L
.2041 .20009 L
.20653 .1986 L
.20773 .19762 L
.209 .1964 L
.21126 .19376 L
.21637 .18574 L
.22079 .17667 L
.22563 .16473 L
.24682 .09923 L
.25684 .06988 L
.26125 .05921 L
.26611 .04968 L
.26835 .04618 L
.27076 .0431 L
.27209 .04172 L
.27331 .04066 L
.27447 .03985 L
.2757 .03917 L
.27696 .0387 L
.27813 .03846 L
.27885 .03841 L
.27952 .03843 L
.28079 .03864 L
.28143 .03883 L
.28212 .0391 L
.28335 .03975 L
.28467 .04069 L
.28613 .042 L
.2886 .0449 L
.29085 .04827 L
.29592 .05821 L
.30507 .08336 L
.32574 .15714 L
.33484 .18678 L
.33967 .19956 L
.34221 .20519 L
.34488 .21021 L
.34726 .21385 L
.34852 .21545 L
.34987 .21689 L
.35111 .21797 L
.35224 .21875 L
.35338 .21933 L
.35445 .21969 L
.35554 .21987 L
.35669 .21986 L
.35768 .21967 L
.35876 .21929 L
Mistroke
.35993 .21868 L
.36118 .21777 L
.36344 .21551 L
.36597 .21204 L
.36873 .20717 L
.37375 .19554 L
.38318 .16573 L
.39417 .12291 L
.40451 .08199 L
.4138 .05104 L
.41903 .03791 L
.42136 .03331 L
.42384 .02931 L
.42511 .02765 L
.4263 .02633 L
.42747 .02527 L
.42854 .02449 L
.42956 .02394 L
.43064 .02355 L
.43173 .02336 L
.43292 .02339 L
.43422 .0237 L
.4354 .02423 L
.4367 .0251 L
.43806 .02633 L
.44037 .02912 L
.44289 .03318 L
.44793 .04428 L
.45331 .06009 L
.46299 .09636 L
.48292 .17954 L
.48838 .19851 L
.49416 .21458 L
.49654 .21977 L
.49909 .22433 L
.50055 .22645 L
.50189 .22806 L
.50327 .22939 L
.50451 .23029 L
.50578 .23093 L
.50698 .23126 L
.50825 .23132 L
.50896 .23122 L
.50961 .23105 L
.51071 .23059 L
.51191 .22983 L
.51316 .22876 L
.51433 .2275 L
.51704 .22366 L
.51951 .21907 L
Mistroke
.52504 .20519 L
.53505 .16972 L
.54451 .12865 L
.5542 .08568 L
.55951 .06427 L
.56448 .04678 L
.56906 .03354 L
.57325 .02429 L
.57564 .02036 L
.57791 .01758 L
.57915 .01646 L
.5803 .01568 L
.58157 .01512 L
.58227 .01493 L
.58292 .01485 L
.58412 .01491 L
.58524 .01521 L
.58647 .01581 L
.58779 .01678 L
.58917 .01815 L
.59048 .01978 L
.59293 .02367 L
.59735 .03333 L
.60215 .04739 L
.61296 .08952 L
.62297 .13534 L
.63195 .1754 L
.64163 .21082 L
.64432 .21845 L
.64717 .22522 L
.6498 .23024 L
.65108 .23223 L
.65225 .23377 L
.65335 .235 L
.65455 .23606 L
.65582 .23688 L
.65701 .23737 L
.65833 .23758 L
.65899 .23756 L
.65972 .23743 L
.66101 .23696 L
.66222 .23621 L
.66347 .23515 L
.6648 .23368 L
.6672 .23019 L
.67005 .22467 L
.67262 .21844 L
.6825 .18522 L
.70104 .10074 L
.71041 .05992 L
Mistroke
.71553 .04138 L
.72031 .02748 L
.72302 .02128 L
.72549 .01679 L
.7268 .01486 L
.72823 .01314 L
.72901 .01236 L
.72974 .01175 L
.73043 .01127 L
.73117 .01086 L
.73235 .01042 L
.73347 .01027 L
.73411 .0103 L
.73479 .01041 L
.73601 .01085 L
.73728 .01163 L
.73846 .01264 L
.73976 .01407 L
.74114 .01595 L
.74374 .02047 L
.74648 .02658 L
.7514 .04075 L
.76252 .08477 L
.77224 .13082 L
.78268 .17912 L
.78794 .20017 L
.79293 .21681 L
.79741 .22839 L
.79994 .23335 L
.80228 .23686 L
.80333 .23809 L
.80446 .23916 L
.80552 .23994 L
.8065 .24046 L
.80758 .2408 L
.80877 .2409 L
.81001 .24071 L
.81116 .24024 L
.81239 .23945 L
.81355 .23842 L
.81573 .23578 L
.81807 .23191 L
.82061 .22654 L
.82548 .21305 L
.83005 .19707 L
.84045 .15185 L
.85123 .09964 L
.86148 .05444 L
.86617 .03758 L
.87116 .02329 L
Mistroke
.87404 .01705 L
.87665 .01274 L
.8779 .01113 L
.87927 .00975 L
.88055 .00879 L
.88173 .0082 L
.88281 .00791 L
.88396 .00787 L
.88504 .00808 L
.88603 .00848 L
.88719 .00921 L
.88845 .0103 L
.89074 .01312 L
.89314 .01717 L
.89569 .02266 L
.90026 .0354 L
.90963 .07117 L
.91974 .11878 L
.92921 .16464 L
.93802 .20194 L
.94267 .21773 L
.9469 .22905 L
.94932 .23407 L
.9516 .23779 L
.95277 .23929 L
.95401 .24059 L
.95465 .24114 L
.95536 .24165 L
.95662 .2423 L
.95792 .24262 L
.95916 .24261 L
.96028 .24232 L
.96149 .24172 L
.96281 .24072 L
.96421 .23927 L
.96673 .23567 L
.96929 .23075 L
.9717 .22501 L
.97619 .2116 L
Mfstroke
.02381 .19669 m
.02846 .20944 L
.03279 .21885 L
.03527 .22306 L
.03754 .2261 L
.03879 .22744 L
.04015 .22863 L
.04143 .22948 L
.04262 .23004 L
.04376 .23036 L
.04498 .23048 L
.04614 .23037 L
.0472 .23009 L
.04843 .22953 L
.04913 .2291 L
.04978 .22864 L
.05224 .22629 L
.05483 .22281 L
.05718 .21879 L
.06244 .20699 L
.07287 .17402 L
.08414 .12942 L
.09388 .08975 L
.09905 .07042 L
.10458 .05219 L
.10997 .03772 L
.11489 .02794 L
.11726 .02452 L
.11851 .02307 L
.11984 .02181 L
.12099 .02094 L
.12227 .02023 L
.12343 .01982 L
.12452 .01964 L
.12575 .01968 L
.12645 .01981 L
.12709 .02001 L
.12841 .02062 L
.12914 .02108 L
.12981 .02158 L
.1323 .0241 L
.13466 .0274 L
.1399 .03779 L
.14558 .0534 L
.16507 .12904 L
.1754 .1717 L
.1811 .19236 L
.1865 .20878 L
.19159 .22067 L
.19447 .22566 L
Mistroke
.19585 .22756 L
.19714 .22907 L
.19833 .2302 L
.19961 .23115 L
.20078 .23176 L
.20185 .23212 L
.20301 .23228 L
.20429 .23218 L
.20493 .23202 L
.20562 .23177 L
.20686 .23111 L
.20814 .23014 L
.20931 .229 L
.21198 .22554 L
.21433 .22151 L
.21683 .21626 L
.2259 .18964 L
.24564 .10736 L
.25427 .07122 L
.26371 .03919 L
.26608 .03294 L
.26861 .02721 L
.27079 .02309 L
.27316 .01955 L
.27455 .01791 L
.27584 .01672 L
.27707 .01585 L
.27837 .01524 L
.27953 .01495 L
.28062 .01491 L
.28181 .01511 L
.28309 .01562 L
.28377 .01601 L
.28449 .01652 L
.28577 .01767 L
.28716 .01924 L
.28869 .02137 L
.29401 .03189 L
.29914 .04629 L
.30396 .06306 L
.32242 .14334 L
.33288 .18768 L
.33798 .20567 L
.34262 .219 L
.345 .22456 L
.34759 .22951 L
.35004 .23309 L
.35112 .23434 L
.35229 .23543 L
.35353 .23631 L
Mistroke
.35468 .23687 L
.35539 .23708 L
.35606 .2372 L
.35731 .23719 L
.35863 .23685 L
.35986 .23624 L
.36056 .23575 L
.3612 .23524 L
.36263 .23379 L
.36535 .23001 L
.36785 .22536 L
.3735 .21098 L
.37847 .19436 L
.38373 .17359 L
.4036 .08303 L
.41228 .04842 L
.41686 .03382 L
.42172 .02187 L
.42419 .01735 L
.42551 .01541 L
.42693 .01368 L
.42823 .01243 L
.42941 .01158 L
.43055 .01101 L
.43175 .0107 L
.43288 .01065 L
.4341 .01089 L
.43524 .01138 L
.43628 .01204 L
.43751 .0131 L
.43883 .01456 L
.44124 .01808 L
.44376 .02291 L
.44653 .02951 L
.45213 .0466 L
.46216 .08716 L
.47299 .13812 L
.48326 .18439 L
.48772 .20166 L
.49248 .21715 L
.49521 .22448 L
.49769 .23001 L
.50018 .23445 L
.50139 .23619 L
.50252 .23755 L
.50371 .23872 L
.50478 .23954 L
.50598 .24018 L
.50726 .24055 L
.50849 .24059 L
Mistroke
.50919 .24048 L
.50983 .24029 L
.51101 .23973 L
.51226 .23884 L
.51332 .23784 L
.51445 .23652 L
.51651 .2335 L
.51896 .22887 L
.5212 .22367 L
.52614 .20924 L
.53154 .18941 L
.54137 .14565 L
.55234 .09296 L
.56267 .04901 L
.56719 .03375 L
.57195 .02111 L
.57445 .0161 L
.57577 .01392 L
.57719 .01196 L
.57849 .0105 L
.57967 .00947 L
.58087 .00871 L
.582 .00826 L
.58315 .00807 L
.58424 .00814 L
.58543 .00849 L
.58672 .00919 L
.58799 .01021 L
.58933 .01164 L
.59173 .01508 L
.59395 .01926 L
.59603 .02397 L
.60073 .03741 L
.61059 .07576 L
.62112 .12573 L
.63135 .17433 L
.63674 .19689 L
.64245 .21682 L
.64744 .23002 L
.65028 .23552 L
.65164 .23761 L
.65293 .23927 L
.6541 .24047 L
.65537 .24147 L
.65652 .24209 L
.65759 .24242 L
.65887 .24251 L
.66002 .24231 L
.66066 .24207 L
.66135 .24173 L
Mistroke
.6626 .24086 L
.66385 .23967 L
.66498 .23832 L
.66753 .23436 L
.66989 .22958 L
.67213 .22412 L
.68257 .18803 L
.70364 .08819 L
.71332 .04694 L
.7182 .03053 L
.72101 .02283 L
.72358 .01701 L
.72582 .01297 L
.72816 .00978 L
.72938 .00855 L
.73052 .00768 L
.73177 .00704 L
.73246 .00682 L
.73309 .0067 L
.73424 .00671 L
.7353 .00695 L
.73646 .00748 L
.73768 .00835 L
.73875 .00935 L
.73975 .0105 L
.74201 .01384 L
.74461 .01889 L
.74701 .02468 L
.75244 .04143 L
.76233 .08222 L
.78088 .17192 L
.7855 .19197 L
.79048 .21079 L
.79479 .22408 L
.79707 .22984 L
.79951 .23493 L
.80093 .23737 L
.80222 .23924 L
.80353 .2408 L
.80474 .24194 L
.80538 .24242 L
.80609 .24285 L
.80681 .24318 L
.80757 .24341 L
.80823 .24351 L
.80895 .24352 L
.81025 .24327 L
.81151 .24268 L
.81222 .24221 L
.81288 .24167 L
Mistroke
.8142 .24034 L
.81539 .23883 L
.81767 .23516 L
.8201 .23014 L
.82498 .21683 L
.83013 .19863 L
.83935 .15811 L
.8494 .10857 L
.86017 .05883 L
.86545 .03874 L
.87045 .02357 L
.87263 .01832 L
.87494 .01371 L
.87614 .01171 L
.87747 .00985 L
.87859 .00856 L
.87982 .00744 L
.88097 .00667 L
.88219 .00615 L
.88332 .00595 L
.88437 .00601 L
.88561 .00637 L
.88674 .00697 L
.88805 .008 L
.88928 .00929 L
.89149 .0124 L
.89354 .01612 L
.89815 .02741 L
.90283 .04256 L
.90785 .06234 L
.91692 .1044 L
.9268 .15334 L
.93201 .17775 L
.93756 .20095 L
.94296 .2196 L
.94785 .23233 L
.95021 .2369 L
.95145 .23886 L
.95276 .2406 L
.95391 .24184 L
.95517 .24288 L
.95631 .24354 L
.95738 .24391 L
.95855 .24405 L
.95982 .24387 L
.96103 .24338 L
.96214 .24267 L
.96314 .24181 L
.96424 .24062 L
.96647 .23747 L
Mistroke
.96888 .23294 L
.97149 .22682 L
.97619 .21274 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{389.5, 97.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000650000HB000`400?l00000o`00003o;Oooool0
0ol0003oooooooooo`3ooooooeKooooo000]ooooo`03o`000?oooooooooo0?ooooooE_ooool002go
oooo0_l0003Qooooo`?oo`00;Oooool3ool004;ooooo000]ooooo`03o`000?oooooooooo0:oooooo
1?oo000/ooooo`Goo`00:oooool5ool0047ooooo000]ooooo`03o`000?oooooooooo07oooooo1?oo
000/ooooo`05ool00?oooooooooooooooooo0000:oooool2ool00003oooooooo003oo`0002_ooooo
0_oo00001?ooooooo`00ool00?oo0010ooooo`00;Oooool00ol0003oooooooooo`1>ooooo`Coo`00
;?ooool01Ooo003oooooooooooooooooo`0002_ooooo1_oo000[ooooo`Koo`00:Oooool2ool000?o
oooo0_oo0010ooooo`00;Oooool2o`0001kooooo0_oo000^ooooo`04ool00?ooooooooooooooo`;o
o`00:oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02Sooooo0_oo0002ooooo`?o
o`00:Oooool2ool000?ooooo00?oo`00oooooooo0000:?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo03kooooo000Uooooo`?o00001Oooool00ol0003oooooooooo`0Looooo`Coo`00
;Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`0Vooooo`Soo`00:?ooool2ool000Gooooo0_oo000Xooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool0?Oooool002Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:Ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Sooooo00?oo`00oooooooo00000ooo
00000oooooooo`00ooooo`0Wooooo`?oo`000_ooool4ool002Oooooo0_oo0005ooooo`;oo`009ooo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo03gooooo000Mooooo`Go000000?ooooo
o`000?l000000ol00005ooooo`?o00006_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo02Sooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooo
o`0000?ooooo0_oo00000oooooooo`00ooooo`0Vooooo`;oo`001Oooool2ool002Kooooo0_oo0007
ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0l
ooooo`008oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01[ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool09Oooool2ool000Gooooo00?oo`00oooooooo00009_ooool2ool000Kooooo0_oo000V
ooooo`;oo`001oooool2ool002Gooooo0_oo0008ooooo`03ool00?oooooooooo03cooooo000Toooo
o`03o`000?oooooo000000Kooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Toooo
o`03ool00?ooooooo`0000Kooooo0_oo000Vooooo`;oo`001_ooool3ool002Gooooo00?oo`00oooo
ooooool01oooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo00Oooooo00?oo`00oooo
ooooool0??ooool002Gooooo0_l00006ooooo`03o`000?oooooooooo01Wooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0Vooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`0Tooooo`;oo`0000?oooooool00?oo00000ooo00001?ooooooo`00oooooooo000U
ooooo`;oo`001_ooool3ool002Gooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0S
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0>oooool002Kooooo00?o0000oooo
ooooool01?ooool2o`0001[ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Uoooo
o`03ool00?oooooooooo00Goo`000oooool00ooo003oooooooooo`0Sooooo`;oo`0000?oooooool0
0?ooool00_ooool00ooo003oooooooooo`02ool002Cooooo0ooo0007ooooo`;oo`009?ooool2ool0
00Wooooo0_oo000Sooooo`;oo`002_ooool00ooo003oooooooooo`0kooooo`00;Oooool00ol0003o
ooooooooo`0Hooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool09?ooool01?oo003o
ooooool00?oo0003ooooo`05ool00?oooooooooooooooooo00009?ooool2ool00003oooooooo003o
oooo00Cooooo00Coo`00oooooooo003oo`009?ooool2ool000Wooooo00?oo`00ooooooooool08_oo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooooooo`0kooooo`00;Oooool00ol0003oooooooooo`0Hooooo`03ool00?oooooo
oooo00Sooooo00?oo`00ooooooooool09?ooool2ool000Kooooo00Coo`00ooooooooooooo`009?oo
ool2ool00003oooooooo003ooooo00Gooooo0_oo00000oooooooo`00ooooo`0Rooooo`03ool00?oo
oooooooo00Sooooo0_oo000Sooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool08Ooo
ool00ooo003oooooooooo`09ooooo`;oo`00??ooool002gooooo00?o0000ooooooooool06?ooool0
0ooo003oooooooooo`08ooooo`03ool00?oooooooooo02?ooooo00?oo`00oooooooo00001oooool0
0ooo003oooooool0000Tooooo`?oo`001oooool01?oo003oooooool00?oo000Rooooo`;oo`002_oo
ool2ool002?ooooo00?oo`00ooooooooool02Oooool2ool002;ooooo00?oo`00ooooooooool02_oo
ool00ooo003oooooooooo`0jooooo`00;Oooool2o`0001Sooooo00?oo`00ooooooooool02_ooool0
0ooo003oooooooooo`0Rooooo`03ool00?ooooooo`0000Oooooo00Coo`00ooooooooooooo`008ooo
ool00ooo003oooooool00008ooooo`?oo`008_ooool2ool000_ooooo00?oo`00ooooooooool08?oo
ool2ool000_ooooo0_oo000Qooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0>_oo
ool002gooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo02;ooooo0_oo0009ooooo`03ool00?ooooooo`0002?ooooo0_oo0009ooooo`;oo`0000?ooooo
ool00?ooool08?ooool00ooo003oooooooooo`0:ooooo`;oo`008Oooool00ooo003oooooooooo`0;
ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool02oooool2ool003_ooooo000]oooo
o`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01Ooo0006ooooo`03ool00?oooooooooo
027ooooo0_oo000:ooooo`03ool00?ooooooo`0002;ooooo0_oo000:ooooo`04ool00?ooooooo`00
ool0023ooooo0_oo000<ooooo`;oo`008Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooo
oooo01oooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0iooooo`00;Oooool00ol0
003oooooooooo`0Fooooo`03ool00?ooooooo`0000Gooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Pooooo`;oo`000_ooool5ool000?ooooo00Coo`00ooooooooooooo`008Oooool2
ool000_ooooo0ooo000Pooooo`;oo`003?ooool2ool0023ooooo0_oo000=ooooo`03ool00?oooooo
oooo01oooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0iooooo`00;Oooool2o`00
00oooooo1Ooo0003ooooo`;oo`001_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
023ooooo0_oo00000oooooooo`00ool00003ooooo`;oo`000oooool00ooo003oooooool0000Qoooo
o`03ool00?oooooooooo00[ooooo0ooo000Pooooo`;oo`003?ooool2ool0023ooooo0_oo000>oooo
o`03ool00?oooooooooo01gooooo0_oo000>ooooo`03ool00?oooooooooo03Wooooo000Sooooo`Go
00001Oooool00ol0003oooooooooo`0=ooooo`;oo`001?ooool4ool000Sooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`0Oooooo`;oo`0000?oooooool00?ooool01_ooool01_oo003o
oooooooooooo003oooooool0023ooooo0_oo000=ooooo`?oo`007oooool00ooo003oooooooooo`0<
ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0M
ooooo`03ool00?oooooooooo00gooooo0_oo000jooooo`009?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo00cooooo0_oo0007ooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Oooooo`?oo`002?ooool01?oo003ooooooooooooo
0002ooooo`03ool00?oooooooooo01gooooo0_oo000=ooooo`?oo`007oooool00ooo003ooooooooo
o`0<ooooo`;oo`007oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01gooooo00?o
o`00ooooooooool03Oooool2ool003[ooooo000Mooooo`Go00000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool01_ooool3ool000[ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Nooooo`?oo`002Oooool01_oo003ooooooooooooo
003oooooool001oooooo0_oo000=ooooo`?oo`007_ooool2ool000kooooo0_oo000Nooooo`;oo`00
3oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0
>?ooool002Kooooo00?o0000ooooooooool01?ooool3o`0000_ooooo00?oo`00ooooooooool01Ooo
ool2ool000;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo01kooooo0_oo000:ooooo`06ool00?ooooooooooool00?ooooooo`007_ooool2ool000oo
oooo0_oo000Nooooo`03ool00?oooooooooo00gooooo0_oo000Nooooo`;oo`003oooool2ool001ko
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0hooooo`008oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`06ooooo`;o
o`000_ooool00ooo003oooooooooo`08ooooo`05ool00?oooooooooooooooooo00007oooool3ool0
00_ooooo00Goo`00oooooooo003oooooool0000Nooooo`;oo`003oooool2ool001kooooo00?oo`00
ooooooooool03_ooool00ooo003oooooooooo`0Looooo`;oo`004?ooool00ooo003oooooooooo`0K
ooooo`;oo`004?ooool2ool003Wooooo000Sooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Oooooo0_oo0003ooooo`03ool00?oooooo
oooo00Oooooo00Goo`00ooooooooooooooooool0000Oooooo`?oo`003?ooool01Ooo003oooooool0
0?ooooooo`0001gooooo0_oo000?ooooo`?oo`007?ooool2ool0013ooooo0_oo000Looooo`;oo`00
4Oooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo00oooooo0_oo000iooooo`009?oo
ool3o`0000Kooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`06ooooo`;oo`001Ooo
ool00ooo003oooooooooo`07ooooo`05ool00?oooooooooooooooooo00007?ooool2o`0000;oo`00
0oooool2o`0000Sooooo00Goo`00oooooooo003oooooool0000Mooooo`03ool00?oooooooooo00ko
oooo0ooo0005ooooo`Go00000oooool2o`0000gooooo0_oo000@ooooo`;oo`007?ooool2ool000Co
oooo0ol00004ooooo`;o00001?ooool2ool001cooooo00?oo`00ooooooooool03oooool2ool000oo
oooo0ol00003ooooo`;o00008_ooool002gooooo0_l00009ooooo`03ool00?oooooooooo00Oooooo
0_oo0006ooooo`03ool00?oooooooooo00Kooooo00Goo`00ooooooooooooooooool0000Mooooo`03
o`000?oo003ooooo00;ooooo00Co0000oooooooooooo00002?ooool2ool00003oooooooo003ooooo
01_ooooo0_oo000Aooooo`;oo`001_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000cooooo00?oo`00ooooooooool03oooool2ool001cooooo0_oo0003ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`;oo`007?ooool00ooo003o
ooooooooo`0@ooooo`03ool00?oooooooooo00kooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo01oooooo000]ooooo`03o`000?oooooooooo00Sooooo00?oo`00oooooooo
ool01oooool2ool000Kooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo000Moooo
o`;oo`000oooool01?l0003oooooooooool00008ooooo`04ool00?ooooooo`00ool001cooooo0_oo
000Aooooo`;oo`001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000cooooo
00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0Jooooo`;oo`001oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool06Oooool2ool001;o
oooo00?oo`00ooooooooool02oooool5o`0000;ooooo00Co0000oooooooooooo00008Oooool002go
oooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0000Oo
oooo00?oo`00ooooooooool01_ooool01?oo003ooooooooooooo000Looooo`;oo`001?ooool01?l0
003oooooooooool00008ooooo`04ool00?ooooooo`00ool001cooooo0_oo000Aooooo`;oo`002?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02Oooool2ool001;ooooo
0_oo000Kooooo`;oo`001Oooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ooo003o
ooooooooo`0Iooooo`;oo`004_ooool2ool000cooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool0000Qooooo`00;Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo
00Kooooo00?oo`00oooooooo00002Oooool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`00
01cooooo0_oo0004ooooo`04o`000?ooooooooooo`0000Wooooo0_oo00000oooooooo`00ooooo`0J
ooooo`03ool00?oooooooooo017ooooo0_oo0004ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0000;ooooo`;oo`004_ooool2ool001[ooooo0_oo0008ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Iooooo`03
ool00?oooooooooo017ooooo0_oo000=ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooo
oooo00008Oooool002gooooo0_l00008ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
00002_ooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooool001[ooooo00?oo`00o`00
0?oo00001?ooool01?l0003oooooooooool00009ooooo`04ool00?ooooooo`00ool001_ooooo00?o
o`00ooooooooool04Oooool2ool000Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000_ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Hooooo`;o
o`001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool2
ool001[ooooo00?oo`00ooooooooool04Oooool2ool000kooooo0_l00003ooooo`04o`000?oooooo
ooooo`00027ooooo000]ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool01Oooool0
1?oo003ooooooooooooo000:ooooo`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`00
6_ooool2ool00003o`000?oooooooooo00?ooooo0_l0000:ooooo`04ool00?ooooooo`00ool001[o
oooo0_oo000Cooooo`;oo`001Oooool3o`0000Cooooo0_l0000<ooooo`03ool00?oooooooooo01;o
oooo00?oo`00ooooooooool06?ooool2ool000Gooooo0ol00004ooooo`;o00001Oooool2ool001Wo
oooo0_oo000Dooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool00_ooool2o`0002;o
oooo000]ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool01?oo003ooooo
oooooooo000;ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo00006Oooool00ooo003o
ooooool0000Cooooo`?oo`006_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Oo
oooo0_oo000Dooooo`03ool00?oooooooooo01Sooooo0_oo000Dooooo`03ool00?oooooooooo01Oo
oooo0_oo000Dooooo`03ool00?oooooooooo03Kooooo000]ooooo`;o00001oooool00ooo003ooooo
ooooo`05ooooo`04ool00?ooooooooooool000gooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooool0000Iooooo`03ool00?ooooooo`0001?ooooo0_oo00000oooooooo`00ooooo`0Hooooo`03
ool00?oooooooooo01?ooooo00?oo`00ooooooooool05oooool2ool001Cooooo0_oo000Iooooo`03
ool00?oooooooooo01?ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Cooooo`;o
o`00=oooool002gooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`06ooooo`04ool0
0?ooooooooooool000gooooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo000Goooo
o`04ool00?ooooooo`00ool001Cooooo0ooo000Iooooo`03ool00?oooooooooo01?ooooo0_oo000H
ooooo`;oo`005Oooool00ooo003oooooooooo`0Fooooo`;oo`005Oooool00ooo003oooooooooo`0G
ooooo`03ool00?oooooooooo01?ooooo0_oo000gooooo`00;Oooool00ol0003oooooooooo`05oooo
o`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool0000>ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00oooooooo00005oooool00ooo003oooooool0000Eooooo`?oo`006?ooool2
ool001Gooooo0_oo000Hooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05_ooool2
ool001Gooooo0_oo000Hooooo`03ool00?oooooooooo01?ooooo0_oo000gooooo`00;Oooool00ol0
003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool0000?
ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo00005oooool00ooo003oooooool0000E
ooooo`?oo`006?ooool2ool001Kooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0D
ooooo`03ool00?oooooooooo01Kooooo0_oo000Eooooo`;oo`005oooool00ooo003oooooooooo`0E
ooooo`03ool00?oooooooooo03Gooooo000Uooooo`oo000000?oo`00o`000?l000001Ol000000ooo
003o0000o`000002o`000003ool00?l0003o000000ko000000?oo`00o`000?l000000ol00002ool0
01Ko000000Coo`00o`000?oo003oo`005_l00003ool001Oo000000?oo`00o`000?l000005Ol00000
0ooo003o0000o`00000Eo`0000;oo`005_l00002ool001Oo00000_oo000Fo`000003ool00?l0003o
000001Go000000?oo`00o`000?l000005Ol000000ooo003o0000o`00000Ho`0001gooooo000]oooo
o`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooooooooooo
o`0000[ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`03ooooo`04ool00?oooooo
o`00o`0000kooooo00?o0000ooooooooool00oooool01?oo003oooooool00?oo0005ooooo`03o`00
0?oooooooooo00gooooo00Co0000ool00?oo003oo`002oooool00ol0003oooooooooo`08ooooo`;o
o`000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?oo`00oooooooo
ool01oooool00ol0003oooooooooo`0;ooooo`;oo`003oooool00ol0003oooooooooo`04ooooo`;o
o`001_ooool00ol0003oooooooooo`0<ooooo`03o`000?ooooooo`0000cooooo00?o0000oooooooo
ool02?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Go0000oooooooo
ooooooooool0000:ooooo`03o`000?oooooooooo00[ooooo0_oo00000ooooooo0000ooooo`0=oooo
o`03o`000?oooooooooo02?ooooo000]ooooo`03o`000?oooooooooo00Cooooo00?oo`00oooooooo
ool01Oooool01Ooo003oooooooooooooooooo`0001;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooool0000Dooooo`04ool00?ooooooooooool000Kooooo00?o0000ooooooooool03oooool2
ool001Kooooo0_oo000Gooooo`;oo`002?ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooo
oooo01Kooooo00?oo`00ooooooooool05?ooool2ool000cooooo00?o0000ooooooooool02?ooool0
0ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo0_oo000@ooooo`03o`000?oooooo
oooo02?ooooo000]ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool2ool0
01Cooooo00Coo`00oooooooo003oo`006?ooool2ool001Kooooo0_oo000Hooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`;oo`005oooool2
ool001Gooooo0_oo000Gooooo`;oo`00=_ooool002gooooo0_l00004ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo
00;ooooo0_oo000Cooooo`03ool00?oooooooooo00;oo`006Oooool00ooo003oooooooooo`0Coooo
o`?oo`006?ooool00ooo003oooooooooo`0Cooooo`;oo`006?ooool2ool001Gooooo0_oo000Goooo
o`;oo`005Oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo03Cooooo000]ooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo01?ooooo00Ooo`00ooooooooooooooooool00?ooooooo`0001;ooooo00?oo`00
ooooooooool00_oo000Iooooo`;oo`005?ooool2ool001Wooooo00?oo`00ooooooooool04oooool2
ool001Sooooo0_oo000Eooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04oooool0
0ooo003oooooooooo`0Gooooo`03ool00?oooooooooo03Cooooo000]ooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
01Cooooo00Coo`00oooooooooooooooo0_oo000Aooooo`06ool00?ooooooooooool00?ooooooo`00
6Oooool2ool001Cooooo0_oo000Iooooo`;oo`005?ooool00ooo003oooooooooo`0Gooooo`;oo`00
5?ooool2ool001Wooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Gooooo`;oo`00
=Oooool002gooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`02ool0017ooooo00?o
o`00ooooooooool00_oo000Kooooo`03ool00?oooooooooo017ooooo0ooo000Iooooo`;oo`005?oo
ool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01;ooooo0_oo000Iooooo`03ool00?oo
oooooooo01;ooooo0_oo000Iooooo`;oo`00=Oooool002gooooo0_l00003ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Eooooo`04ool00?oooooo
ooooooooo`;oo`003oooool01?oo003oooooooooooooool2ool001_ooooo00?oo`00ooooooooool0
4Oooool3ool001[ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Hooooo`03ool0
0?oooooooooo01;ooooo0_oo000Iooooo`;oo`004oooool2ool001Wooooo0_oo000eooooo`00;Ooo
ool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo00;oo`003oooool01_oo003ooooooooo
oooo003oooooool001_ooooo0_oo000Booooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo
ool04Oooool2ool001[ooooo0_oo000Cooooo`;oo`006_ooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo01Wooooo00?oo`00ooooooooool0<oooool002gooooo00Go0000oooooooooooo
ooooool00006ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool06?ooool01?oo003o
ooooool00?oo000>ooooo`07ool00?oooooooooooooooooo003oooooool0000Looooo`03ool00?oo
oooooooo00oooooo0ooo000Kooooo`;oo`004_ooool2ool001[ooooo0_oo000Cooooo`03ool00?oo
oooooooo01Wooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Iooooo`03ool00?oo
oooooooo03?ooooo000]ooooo`05o`000?oooooooooooooooooo00001Oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo01Wooooo00Coo`00oooooooo003oo`003?ooool00ooo003ooooo
ooooo`02ooooo`;oo`007Oooool00ooo003oooooooooo`0?ooooo`?oo`006oooool2ool001;ooooo
00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0@ooooo`;oo`006oooool00ooo003ooooo
ooooo`0Aooooo`03ool00?oooooooooo01Wooooo0_oo000dooooo`00;Oooool2o`0000;ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01[ooooo0ooo
000;ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo00007Oooool2ool0013ooooo00?o
o`00oooooooo00007?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01[ooooo00?o
o`00ooooooooool04?ooool2ool001_ooooo00?oo`00ooooooooool04?ooool2ool001_ooooo0_oo
000dooooo`008oooool5o`0000Gooooo00Co0000ooooooooooooo`001_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo01_ooooo0_oo000:ooooo`03ool00?oooooooooo00?ooooo00?o
o`00oooooooo00007Oooool2ool0013ooooo00?oo`00oooooooo00007?ooool2ool0017ooooo00?o
o`00ooooooooool06_ooool2ool0017ooooo0_oo000Kooooo`;oo`004Oooool2ool001_ooooo0_oo
000dooooo`009?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooool000Gooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Looooo`;oo`002?ooool00ooo003ooooo
ooooo`04ooooo`03ool00?ooooooo`0001kooooo00?oo`00ooooooooool03Oooool2ool00003oooo
oooo003ooooo01_ooooo0_oo000@ooooo`;oo`007?ooool2ool0017ooooo00?oo`00ooooooooool0
6oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool0
<_ooool002Gooooo00?o0000ooooooooool01Oooool01?l0003ooooooooooooo0005ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool07Oooool4ool000Cooooo0_oo0006ooooo`03ool0
0?ooooooo`0001oooooo0_oo000>ooooo`?oo`007Oooool2ool0013ooooo00?oo`00ooooooooool0
6oooool2ool0013ooooo0_oo000Mooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0
6oooool00ooo003oooooooooo`0booooo`009_ooool00ol0003oooooooooo`04ooooo`;o000000?o
o`00ooooooooool00oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01kooooo00?o
o`00ooooooooool01?oo0008ooooo`03ool00?ooooooo`0001oooooo0_oo000>ooooo`03ool00?oo
ooooo`0001gooooo0ooo000?ooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool03_oo
ool2ool001gooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Kooooo`;oo`00<ooo
ool002?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?ooooooo`0000Cooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00_ooooo00Co
o`00ooooooooooooo`007oooool2ool000gooooo0_oo00000oooooooo`00ooooo`0Mooooo`;oo`00
3_ooool2ool001kooooo00?oo`00ooooooooool03_ooool2ool001gooooo0_oo000?ooooo`;oo`00
7Oooool2ool003?ooooo000Sooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ool00004ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool07oooool2ool000cooooo
00Coo`00ooooooooooooo`007oooool3ool000cooooo0_oo00000oooooooo`00ooooo`0Mooooo`;o
o`003_ooool2ool001kooooo0_oo000?ooooo`;oo`007_ooool00ooo003oooooooooo`0=ooooo`03
ool00?oooooooooo01gooooo00?oo`00ooooooooool0<Oooool002Cooooo0ol00006ooooo`03o`00
0?oo003ooooo00?ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Pooooo`03ool0
0?oooooooooo00Wooooo00Goo`00ooooooooooooooooool0000Pooooo`;oo`002oooool2ool00003
oooooooo003ooooo01kooooo0_oo000>ooooo`;oo`007_ooool2ool000kooooo0_oo000Oooooo`03
ool00?oooooooooo00gooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0aooooo`00
;Oooool00ol0003oo`00ooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
8?ooool2ool000[ooooo00Coo`00ooooooooooooo`008Oooool3ool000[ooooo0_oo00000ooooooo
o`00ooooo`0Oooooo`;oo`003?ooool2ool0023ooooo00?oo`00ooooooooool03?ooool2ool001oo
oooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Mooooo`;oo`00<_ooool002gooooo
00Go0000ool00?ooooooooooool00009ooooo`03ool00?oooooooooo027ooooo00?oo`00oooooooo
00002?ooool01Ooo003oooooooooooooooooo`00027ooooo0ooo0009ooooo`05ool00?ooooooo`00
oooooooo00008?ooool2ool000cooooo0_oo000Pooooo`;oo`003Oooool2ool001oooooo0_oo000=
ooooo`;oo`008?ooool00ooo003oooooooooo`0`ooooo`00;Oooool00ooo003oooooooooo`02ool0
00Wooooo00?oo`00ooooooooool08Oooool01?oo003ooooooooooooo0006ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool08?ooool00ooo003oooooool00008ooooo`;oo`0000?ooooo
ool00?ooool08?ooool2ool000cooooo0_oo000Pooooo`;oo`003Oooool2ool0023ooooo00?oo`00
ooooooooool02oooool2ool0023ooooo00?oo`00ooooooooool0<?ooool002gooooo0ooo000;oooo
o`03ool00?oooooooooo027ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool08Oooool2ool00003oooooooo003ooooo00Gooooo00Goo`00
oooooooo003oooooool0000Rooooo`03ool00?oooooooooo00Wooooo0_oo000Rooooo`03ool00?oo
oooooooo00[ooooo0_oo000Qooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool07ooo
ool00ooo003oooooooooo`0`ooooo`00;Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo02?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`001?ooool00ooo003oooooooooo`0Q
ooooo`;oo`000_ooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00oooooooo00008_oo
ool2ool000[ooooo0_oo000Rooooo`;oo`002oooool2ool0027ooooo0_oo000;ooooo`;oo`008_oo
ool00ooo003oooooooooo`0_ooooo`00;Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo02?ooooo00Coo`00oooooooooooooooo1?oo0005ooooo`03ool00?oooooooooo02;ooooo00?o
o`00ooooooooool01Ooo0003ooooo`;oo`008oooool2ool000[ooooo0_oo000Rooooo`;oo`002ooo
ool2ool0027ooooo0_oo000;ooooo`;oo`008_ooool00ooo003oooooooooo`0_ooooo`00;Oooool0
0ol0003oo`00ooooo`0:ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool02Oooool0
0ooo003oooooooooo`0Sooooo`;oo`002?ooool00ooo003oooooool0000Sooooo`?oo`002?ooool2
ool002?ooooo0_oo000;ooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool02Oooool2
ool002;ooooo00?oo`00ooooooooool0;oooool002gooooo00?o0000ool00?ooool02Oooool00ooo
003oooooooooo`0Uooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool08oooool2ool0
00Sooooo00?oo`00oooooooo00009?ooool2ool000Sooooo0_oo000Tooooo`03ool00?oooooooooo
00Sooooo0_oo000Sooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool08Oooool2ool0
033ooooo000]ooooo`03o`000?oo003ooooo00Wooooo00?oo`00ooooooooool09Oooool00ooo003o
ooooooooo`08ooooo`03ool00?oooooooooo02?ooooo00?oo`00oooooooo00001_ooool00ooo003o
ooooool0000Uooooo`03ool00?ooooooo`0000Kooooo0ooo000Tooooo`;oo`002Oooool2ool002?o
oooo0_oo0009ooooo`;oo`008oooool2ool000[ooooo00?oo`00ooooooooool08oooool002Gooooo
0ol00005ooooo`03o`000?ooooooo`0000Sooooo00?oo`00ooooooooool09oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo02Gooooo00?oo`00oooooooo00001?ooool01?oo003ooooo
oooooooo000Uooooo`?oo`001Oooool01?oo003oooooool00?oo000Tooooo`;oo`002?ooool2ool0
02Cooooo0_oo0009ooooo`;oo`009?ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo
02?ooooo000Vooooo`03o`000?oooooooooo00Cooooo00Co0000ooooooooooooo`001oooool00ooo
003oooooooooo`0Wooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09Oooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooooooool002Oooooo00?oo`00oooooooo00001?oo
ool00ooo003oooooool0000Vooooo`03ool00?oooooooooo00Kooooo0_oo000Uooooo`03ool00?oo
oooooooo00Oooooo0_oo000Tooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool08ooo
ool002?ooooo1Ol00005ooooo`?o000000?oo`00ooooooooool01Oooool00ooo003oooooooooo`0X
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09_ooool01?oo003ooooooooooooo
ool3ool000;ooooo00?oo`00ooooooooool09Oooool2ool00003oooooooo003oo`0000;oo`0000?o
ooooool00?oo00009_ooool2ool000Kooooo0ooo000Uooooo`03ool00?oooooooooo00Oooooo00?o
o`00ooooooooool08oooool2ool000Sooooo00?oo`00ooooooooool09?ooool002?ooooo00Co0000
oooooooooooo00001_ooool01Ol0003oooooooooooooooooo`0000Gooooo00?oo`00ooooooooool0
:Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0Uooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooooooo0000
9_ooool3ool000Gooooo0_oo000Wooooo`03ool00?oooooooooo00Gooooo0_oo000Uooooo`;oo`00
2?ooool00ooo003oooooooooo`0Tooooo`009?ooool00ol0003oooooo`000006ooooo`04o`000?oo
ooooooooooooo`;oo`000oooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Kooooo
00Coo`00oooooooo003oo`000oooool00ooo003oooooool0000Wooooo`03ool00?ooooooo`0000?o
oooo00?oo`00oooooooo00009oooool00ooo003oooooooooo`04ooooo`;oo`009oooool00ooo003o
ooooooooo`05ooooo`;oo`009_ooool002Gooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo
1?oo000_ooooo`04ool00?ooooooooooool002cooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0Wooooo`03ool00?ooooooo`0000?oo`0000?oooooool00?ooool09oooool4ool00003
oooooooo003oo`0000;oo`009oooool2ool000Gooooo0_oo000Wooooo`;oo`001_ooool00ooo003o
ooooooooo`0Uooooo`009_ooool00ol0003oooooooooo`04ooooo`;o0000=oooool2ool002kooooo
00Goo`00ooooooooooooooooool0000[ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool09oooool8ool002Sooooo0ooo0004ooooo`;oo`00:?ooool00ooo003oooooooooo`03ooooo`;o
o`009oooool002gooooo00?o0000ooooooooool0I_ooool4ool002cooooo0_oo0003ooooo`03ool0
0?oooooooooo02Sooooo1Ooo00000oooooooo`00ooooo`0Xooooo`?oo`0000Coooooool00?oo003o
o`00:Oooool2ool000Cooooo00?oo`00ooooooooool09_ooool002gooooo00?o0000ooooooooool0
Uoooool4ool002cooooo00Goo`00ooooooooooooooooool0000[ooooo`Goo`00:oooool2ool00003
oooooooo003oo`0002Wooooo000]ooooo`03o`000?oooooooooo0<Sooooo0ooo000/ooooo`Goo`00
;?ooool4ool002Wooooo000]ooooo`;o0000ooooool[ooooo`;oo`00:_ooool002gooooo00?o0000
ooooooooool0oooooomFooooo`00oooooon6ooooo`00oooooon6ooooo`00oooooon6ooooo`00oooo
oon6ooooo`00oooooon6ooooo`00oooooon6ooooo`00oooooon6ooooo`00[_ooool3o`0000Cooooo
0ol00002ooooo`Co00000_ooool5o`0000?ooooo0_l00002ooooo`Go00000_ooool3o`0000;ooooo
0ol000000ooooooo0000o`00002Wooooo`00[oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`2Vooooo`00[oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo0:Kooooo002_ooooo`?o00000_ooool01ol0003ooooooooooooooooo0000oooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Y_oo
ool00:oooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo1?l000001?oooooo0000o`00
0?l00003ooooo`Co00000_ooool3o`0000Cooooo0ol00002ooooo`Co0000ZOooool00:oooooo00Co
0000oooooooooooo00005?ooool00ol0003oooooooooo`2kooooo`00[_ooool4o`00013ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;Cooooo003o
ooooohKooooo003oooooohKooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 466.375}, {442.062, 345.688}} -> {-16.1045, \
39.7194, 0.130668, 0.129995}}]
}, Open  ]],

Cell["The velocity curves: ", "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ Evaluate[Table[D[phi2[3,v,t],t],{v,-3,3,3}]], {t,0,40},
      PlotStyle->RGBColor[0,0,1], AspectRatio->1/4, PlotLabel->\"Velocity\" 
    ]\
\>", "Input",
  CellLabel->"In[15]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.12484 0.0239985 [
[.2619 .11234 -6 -9 ]
[.2619 .11234 6 0 ]
[.5 .11234 -6 -9 ]
[.5 .11234 6 0 ]
[.7381 .11234 -6 -9 ]
[.7381 .11234 6 0 ]
[.97619 .11234 -6 -9 ]
[.97619 .11234 6 0 ]
[.01131 .02885 -12 -4.5 ]
[.01131 .02885 0 4.5 ]
[.01131 .07684 -12 -4.5 ]
[.01131 .07684 0 4.5 ]
[.01131 .17284 -6 -4.5 ]
[.01131 .17284 0 4.5 ]
[.01131 .22083 -6 -4.5 ]
[.01131 .22083 0 4.5 ]
[.5 .2625 -26 0 ]
[.5 .2625 26 12 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .12484 m
.2619 .13109 L
s
[(10)] .2619 .11234 0 1 Mshowa
.5 .12484 m
.5 .13109 L
s
[(20)] .5 .11234 0 1 Mshowa
.7381 .12484 m
.7381 .13109 L
s
[(30)] .7381 .11234 0 1 Mshowa
.97619 .12484 m
.97619 .13109 L
s
[(40)] .97619 .11234 0 1 Mshowa
.125 Mabswid
.07143 .12484 m
.07143 .12859 L
s
.11905 .12484 m
.11905 .12859 L
s
.16667 .12484 m
.16667 .12859 L
s
.21429 .12484 m
.21429 .12859 L
s
.30952 .12484 m
.30952 .12859 L
s
.35714 .12484 m
.35714 .12859 L
s
.40476 .12484 m
.40476 .12859 L
s
.45238 .12484 m
.45238 .12859 L
s
.54762 .12484 m
.54762 .12859 L
s
.59524 .12484 m
.59524 .12859 L
s
.64286 .12484 m
.64286 .12859 L
s
.69048 .12484 m
.69048 .12859 L
s
.78571 .12484 m
.78571 .12859 L
s
.83333 .12484 m
.83333 .12859 L
s
.88095 .12484 m
.88095 .12859 L
s
.92857 .12484 m
.92857 .12859 L
s
.25 Mabswid
0 .12484 m
1 .12484 L
s
.02381 .02885 m
.03006 .02885 L
s
[(-4)] .01131 .02885 1 0 Mshowa
.02381 .07684 m
.03006 .07684 L
s
[(-2)] .01131 .07684 1 0 Mshowa
.02381 .17284 m
.03006 .17284 L
s
[(2)] .01131 .17284 1 0 Mshowa
.02381 .22083 m
.03006 .22083 L
s
[(4)] .01131 .22083 1 0 Mshowa
.125 Mabswid
.02381 .04084 m
.02756 .04084 L
s
.02381 .05284 m
.02756 .05284 L
s
.02381 .06484 m
.02756 .06484 L
s
.02381 .08884 m
.02756 .08884 L
s
.02381 .10084 m
.02756 .10084 L
s
.02381 .11284 m
.02756 .11284 L
s
.02381 .13684 m
.02756 .13684 L
s
.02381 .14884 m
.02756 .14884 L
s
.02381 .16084 m
.02756 .16084 L
s
.02381 .18484 m
.02756 .18484 L
s
.02381 .19684 m
.02756 .19684 L
s
.02381 .20883 m
.02756 .20883 L
s
.02381 .01685 m
.02756 .01685 L
s
.02381 .00485 m
.02756 .00485 L
s
.02381 .23283 m
.02756 .23283 L
s
.02381 .24483 m
.02756 .24483 L
s
.25 Mabswid
.02381 0 m
.02381 .25 L
s
gsave
.5 .2625 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Velocity) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .05284 m
.02605 .05002 L
.02729 .04877 L
.02846 .04777 L
.02954 .04701 L
.03072 .04636 L
.0318 .04592 L
.03279 .04565 L
.03396 .04549 L
.03506 .0455 L
.03626 .04567 L
.03756 .04604 L
.03821 .04629 L
.03891 .04663 L
.0402 .04738 L
.04262 .04924 L
.04523 .05188 L
.04759 .05478 L
.0529 .06276 L
.06244 .08068 L
.08269 .12107 L
.08823 .13041 L
.09409 .13891 L
.09915 .14505 L
.10458 .15039 L
.10975 .15433 L
.11446 .15703 L
.11673 .15804 L
.11919 .15896 L
.12151 .15965 L
.12368 .16015 L
.12619 .16058 L
.12752 .16073 L
.12821 .1608 L
.12896 .16086 L
.1297 .1609 L
.13039 .16093 L
.13111 .16095 L
.13189 .16096 L
.13261 .16095 L
.13329 .16094 L
.13457 .16089 L
.13579 .1608 L
.13709 .16068 L
.13941 .16038 L
.1419 .15994 L
.14465 .15931 L
.14986 .15773 L
.15481 .15573 L
.16409 .15057 L
Mistroke
.17409 .14274 L
.18499 .13139 L
.20634 .1032 L
.21642 .09021 L
.22084 .08534 L
.22568 .08089 L
.22796 .07919 L
.23041 .07768 L
.23176 .077 L
.23298 .07647 L
.23415 .07606 L
.23539 .07572 L
.23603 .07559 L
.23673 .07547 L
.23797 .07535 L
.23867 .07532 L
.23942 .07534 L
.24013 .07539 L
.24078 .07547 L
.24196 .07569 L
.24326 .07605 L
.24461 .07657 L
.24587 .07717 L
.24835 .0787 L
.25069 .08057 L
.25506 .08516 L
.25977 .09163 L
.26487 .10026 L
.28439 .14316 L
.29474 .1661 L
.30043 .17671 L
.30324 .18112 L
.30584 .18465 L
.30826 .18741 L
.31094 .18981 L
.31233 .19077 L
.31364 .19149 L
.31501 .19206 L
.31579 .19229 L
.3165 .19244 L
.31767 .19258 L
.31876 .19257 L
.31996 .1924 L
.32124 .19204 L
.32189 .19179 L
.32259 .19147 L
.32386 .19074 L
.32623 .1889 L
.32852 .18652 L
.33105 .18325 L
Mistroke
.33615 .17463 L
.34529 .15336 L
.36635 .09087 L
.37118 .07745 L
.37633 .06491 L
.38111 .05542 L
.3856 .04876 L
.388 .04621 L
.38935 .0451 L
.39059 .0443 L
.39164 .04377 L
.39279 .04337 L
.39399 .04315 L
.39511 .04312 L
.39576 .04318 L
.39646 .04332 L
.39773 .04373 L
.39898 .04436 L
.40012 .04513 L
.40273 .04754 L
.40549 .05112 L
.41013 .05933 L
.41448 .06936 L
.42439 .09896 L
.44288 .16406 L
.44795 .18015 L
.45336 .19487 L
.45598 .20087 L
.45846 .20574 L
.46067 .20939 L
.4631 .21261 L
.46427 .21385 L
.46553 .21496 L
.46686 .21586 L
.46811 .21646 L
.46935 .21681 L
.47052 .21692 L
.47158 .21683 L
.47272 .21653 L
.47343 .21624 L
.4741 .2159 L
.47535 .21507 L
.47669 .2139 L
.47814 .21232 L
.48075 .20866 L
.48315 .20441 L
.48806 .19322 L
.49343 .17757 L
.50426 .13832 L
.51516 .09515 L
Mistroke
.52546 .05887 L
.52995 .04627 L
.53471 .0358 L
.53719 .03167 L
.53851 .02988 L
.53993 .02826 L
.54123 .02707 L
.54242 .02623 L
.54362 .02563 L
.54475 .02529 L
.54602 .02517 L
.54721 .02531 L
.54827 .02565 L
.54943 .02623 L
.55069 .02714 L
.55203 .02839 L
.55442 .03138 L
.55663 .03498 L
.55869 .03905 L
.56339 .05068 L
.57321 .08384 L
.58374 .12739 L
.5939 .16971 L
.59927 .18949 L
.60497 .2071 L
.60993 .21879 L
.61276 .2237 L
.61405 .22549 L
.61541 .22707 L
.61657 .22815 L
.61784 .22906 L
.61899 .22963 L
.62007 .22995 L
.62134 .23005 L
.62249 .22988 L
.62313 .22968 L
.62383 .22938 L
.62508 .22862 L
.62631 .22759 L
.62744 .22641 L
.62997 .22293 L
.63232 .21872 L
.63454 .21388 L
.64495 .18166 L
.66599 .09123 L
.6756 .05356 L
.68096 .03699 L
.6835 .03064 L
.68583 .02572 L
.688 .02197 L
Mistroke
.69038 .01882 L
.69162 .0176 L
.69278 .01672 L
.694 .01606 L
.6953 .01567 L
.69645 .01559 L
.6977 .0158 L
.69888 .01627 L
.69997 .01694 L
.70095 .01773 L
.70203 .01882 L
.70422 .02168 L
.70658 .02573 L
.70915 .03127 L
.71434 .04567 L
.7236 .08028 L
.73454 .12954 L
.74447 .17403 L
.74932 .19325 L
.75457 .21095 L
.75699 .21774 L
.75954 .2239 L
.76193 .22866 L
.76411 .2321 L
.7653 .2336 L
.7666 .23494 L
.76731 .23553 L
.76797 .23599 L
.76927 .23666 L
.77038 .23696 L
.77161 .23702 L
.77289 .23676 L
.77409 .23622 L
.77473 .23582 L
.77543 .23529 L
.77685 .23393 L
.77937 .23054 L
.78232 .22509 L
.78507 .21863 L
.7901 .2036 L
.79557 .18331 L
.80549 .13934 L
.82407 .056 L
.82862 .03999 L
.83351 .02619 L
.83632 .0201 L
.83888 .01579 L
.84011 .01416 L
.84146 .01272 L
.84273 .01169 L
Mistroke
.84391 .01102 L
.84523 .0106 L
.84598 .01051 L
.84666 .01053 L
.84792 .01082 L
.84855 .01108 L
.84925 .01146 L
.85046 .01236 L
.85175 .01363 L
.85409 .01677 L
.85701 .02213 L
.85977 .02863 L
.86494 .04422 L
.8746 .08283 L
.88486 .13128 L
.89447 .17595 L
.90328 .20998 L
.90785 .22337 L
.91017 .22883 L
.91265 .23358 L
.91396 .23561 L
.91515 .23717 L
.91636 .23847 L
.91748 .23941 L
.91878 .24019 L
.91947 .24046 L
.92019 .24065 L
.92141 .24071 L
.92211 .24062 L
.92276 .24044 L
.92389 .23992 L
.92512 .23906 L
.92628 .23797 L
.92736 .23672 L
.9294 .23373 L
.93157 .22967 L
.93654 .21716 L
.94104 .20235 L
.97619 .04575 L
Mfstroke
.02381 .12484 m
.03279 .10761 L
.04262 .09152 L
.04758 .08484 L
.05288 .07893 L
.05789 .07463 L
.06006 .07317 L
.06244 .07186 L
.06507 .07078 L
.0665 .07036 L
.06719 .0702 L
.06785 .07007 L
.0691 .06989 L
.07025 .0698 L
.07148 .0698 L
.07218 .06983 L
.07283 .06989 L
.07354 .06999 L
.0743 .07012 L
.07569 .07045 L
.07704 .07088 L
.07829 .07137 L
.08112 .07283 L
.0841 .07487 L
.08915 .07948 L
.09387 .08505 L
.10458 .1017 L
.12322 .13898 L
.13305 .15878 L
.14349 .1762 L
.14873 .18258 L
.15172 .18533 L
.15308 .18635 L
.15452 .18726 L
.15574 .1879 L
.15708 .18844 L
.1583 .1888 L
.15943 .18902 L
.16012 .18909 L
.16077 .18912 L
.16199 .18908 L
.16331 .18887 L
.16405 .18868 L
.16473 .18846 L
.16589 .18799 L
.16713 .18734 L
.16938 .1858 L
.17206 .18335 L
.1745 .18054 L
.17981 .17261 L
Mistroke
.18485 .16298 L
.20492 .11138 L
.21366 .08774 L
.22309 .06612 L
.22839 .05702 L
.23071 .05389 L
.23325 .05113 L
.23441 .05011 L
.23566 .04918 L
.23673 .04853 L
.2379 .04798 L
.23922 .04756 L
.24047 .04736 L
.24168 .04735 L
.24281 .0475 L
.24401 .04784 L
.24531 .04841 L
.24653 .04914 L
.24765 .04997 L
.25025 .0525 L
.25299 .05605 L
.25815 .06511 L
.26379 .07819 L
.28508 .14534 L
.29514 .17686 L
.29956 .18856 L
.30441 .19922 L
.3091 .20692 L
.31167 .20991 L
.31282 .21095 L
.31407 .21187 L
.31477 .2123 L
.31542 .21262 L
.31671 .21309 L
.31787 .2133 L
.31911 .2133 L
.31975 .21321 L
.32044 .21305 L
.32169 .21258 L
.32241 .2122 L
.32317 .21172 L
.32453 .21064 L
.3268 .20825 L
.32922 .20488 L
.33359 .19676 L
.33878 .18399 L
.3435 .16986 L
.36428 .09365 L
.37341 .06275 L
.37825 .0494 L
Mistroke
.38092 .04324 L
.38345 .03827 L
.38586 .03441 L
.38713 .03272 L
.38849 .03119 L
.38974 .03004 L
.39087 .02921 L
.39202 .02859 L
.39309 .02819 L
.39419 .02799 L
.39535 .02799 L
.39634 .02817 L
.39743 .02855 L
.3986 .02918 L
.39985 .0301 L
.40211 .03242 L
.40466 .03601 L
.40743 .04105 L
.41246 .05304 L
.42189 .08374 L
.44129 .16197 L
.4466 .18182 L
.45233 .20026 L
.45496 .20743 L
.45773 .21394 L
.46033 .21898 L
.46269 .22263 L
.46385 .22409 L
.46511 .22542 L
.4662 .22634 L
.46739 .22712 L
.46866 .22767 L
.46936 .22785 L
.47 .22794 L
.47117 .22792 L
.47241 .22763 L
.47357 .22711 L
.47484 .22627 L
.47603 .22522 L
.47714 .22402 L
.47923 .22118 L
.48146 .21735 L
.48701 .20437 L
.49223 .1882 L
.50197 .1504 L
.5204 .07187 L
.52545 .05361 L
.53086 .03746 L
.53348 .03114 L
.53596 .02618 L
Mistroke
.53818 .0226 L
.53943 .02098 L
.5406 .01972 L
.54175 .01871 L
.543 .01789 L
.54371 .01756 L
.54438 .01733 L
.54564 .01712 L
.54628 .01713 L
.54697 .01723 L
.5482 .01762 L
.54895 .018 L
.54966 .01846 L
.55099 .01956 L
.55339 .02238 L
.5556 .02588 L
.56059 .03686 L
.56548 .05135 L
.57084 .07083 L
.58167 .11754 L
.59169 .16263 L
.60117 .19979 L
.60641 .21573 L
.60917 .22246 L
.61211 .2282 L
.61457 .23183 L
.61597 .23339 L
.61729 .23452 L
.61849 .23527 L
.6196 .23571 L
.62081 .23592 L
.62208 .23583 L
.62332 .23544 L
.62401 .2351 L
.62465 .2347 L
.62583 .23375 L
.62708 .23246 L
.62924 .22953 L
.63162 .22532 L
.63689 .21251 L
.64182 .19663 L
.66018 .1169 L
.67058 .07023 L
.67571 .05039 L
.68046 .03497 L
.68475 .02404 L
.68715 .01932 L
.68932 .01596 L
.69049 .01452 L
.69172 .01329 L
Mistroke
.69236 .01276 L
.69307 .01227 L
.69431 .01166 L
.69548 .01136 L
.69673 .01133 L
.69791 .0116 L
.69899 .01208 L
.70018 .01288 L
.70128 .01388 L
.70381 .01703 L
.70627 .02128 L
.70893 .02708 L
.71372 .04058 L
.71811 .05596 L
.73888 .15 L
.74805 .19017 L
.75308 .20856 L
.75783 .22256 L
.76053 .22884 L
.76346 .23414 L
.76475 .23597 L
.76612 .23755 L
.76728 .2386 L
.76857 .23945 L
.76987 .23997 L
.77105 .24015 L
.77171 .24013 L
.77242 .24001 L
.77372 .23952 L
.77493 .23875 L
.77622 .23762 L
.77854 .23475 L
.78092 .23074 L
.78342 .22538 L
.78789 .21307 L
.79798 .17472 L
.81625 .08828 L
.82577 .04822 L
.8311 .03067 L
.83363 .02394 L
.83596 .01873 L
.83811 .0148 L
.84048 .01152 L
.84171 .01025 L
.84287 .00934 L
.84408 .00867 L
.84539 .00829 L
.84653 .00824 L
.84778 .0085 L
.84896 .00903 L
Mistroke
.85005 .00978 L
.85113 .01075 L
.85211 .01184 L
.85431 .01497 L
.85664 .0193 L
.85919 .02521 L
.86434 .04053 L
.87356 .07722 L
.88446 .12923 L
.89439 .17624 L
.89919 .1963 L
.90441 .21485 L
.9068 .22196 L
.90934 .22844 L
.91172 .23346 L
.9139 .23711 L
.91508 .23869 L
.91637 .24011 L
.91767 .24119 L
.91837 .24163 L
.91903 .24196 L
.92025 .24232 L
.92136 .24238 L
.92264 .24214 L
.92384 .2416 L
.92448 .24119 L
.92518 .24065 L
.92658 .23926 L
.92911 .23577 L
.93206 .23013 L
.93482 .22338 L
.9398 .20793 L
.94523 .18698 L
.95511 .14143 L
.97365 .05469 L
.97619 .04497 L
Mfstroke
.02381 .19684 m
.04262 .13381 L
.0522 .09764 L
.06244 .06304 L
.0679 .04822 L
.07286 .03768 L
.07525 .03372 L
.07784 .03033 L
.07903 .0291 L
.08029 .02801 L
.08137 .02727 L
.08255 .02666 L
.08326 .02639 L
.08402 .02619 L
.08474 .02608 L
.08541 .02605 L
.08668 .02618 L
.08739 .02635 L
.08803 .02658 L
.08879 .02693 L
.08949 .02733 L
.09107 .0285 L
.09246 .02983 L
.09393 .03156 L
.099 .0399 L
.10189 .04619 L
.10458 .053 L
.12322 .1179 L
.13305 .15662 L
.14349 .1928 L
.14873 .20705 L
.15152 .21322 L
.15452 .21866 L
.15727 .22246 L
.15847 .22376 L
.15979 .22492 L
.16103 .22576 L
.16219 .22632 L
.16342 .22668 L
.16473 .22678 L
.16539 .22673 L
.16608 .22659 L
.16733 .22615 L
.16802 .22579 L
.16867 .22539 L
.17015 .22421 L
.17262 .22146 L
.17527 .21743 L
.18028 .20696 L
.18485 .1944 L
Mistroke
.20548 .11526 L
.21552 .0748 L
.22461 .04472 L
.2292 .03335 L
.23161 .0286 L
.23415 .02458 L
.23639 .02193 L
.23765 .02081 L
.23883 .02 L
.23992 .01948 L
.24091 .01918 L
.24205 .01905 L
.24313 .01914 L
.24427 .01945 L
.24552 .02005 L
.24682 .02098 L
.24805 .02212 L
.25023 .02479 L
.25259 .02856 L
.25795 .04044 L
.26286 .05494 L
.28342 .13864 L
.29344 .1804 L
.30253 .21074 L
.30709 .22178 L
.30967 .22655 L
.31203 .22994 L
.31411 .23209 L
.31529 .23297 L
.31639 .23357 L
.31755 .23395 L
.31861 .23408 L
.31983 .23397 L
.32099 .23362 L
.32212 .23303 L
.32337 .23212 L
.32467 .23085 L
.32589 .22939 L
.33043 .22166 L
.333 .21574 L
.33536 .20938 L
.34069 .19217 L
.36119 .10408 L
.37119 .06189 L
.37592 .04515 L
.38028 .03235 L
.38482 .02219 L
.38721 .01827 L
.38843 .01666 L
.38975 .01524 L
Mistroke
.39089 .01426 L
.39194 .01359 L
.393 .01312 L
.394 .01287 L
.39516 .01282 L
.39624 .01301 L
.39742 .01348 L
.39869 .01427 L
.40002 .01544 L
.40124 .0168 L
.404 .0209 L
.40644 .02565 L
.40901 .03177 L
.41836 .0624 L
.43824 .15157 L
.44692 .18882 L
.45149 .20549 L
.45635 .22003 L
.45883 .22599 L
.46156 .23134 L
.46276 .23325 L
.46405 .23501 L
.46526 .23637 L
.46638 .23739 L
.46753 .23818 L
.4688 .23875 L
.47002 .23899 L
.47134 .23893 L
.47256 .23857 L
.47372 .23795 L
.47475 .23717 L
.47588 .2361 L
.4784 .2328 L
.48117 .2278 L
.48676 .2136 L
.49195 .19611 L
.4968 .1767 L
.51539 .09021 L
.5252 .04926 L
.53068 .03139 L
.53564 .01936 L
.53837 .01463 L
.5399 .01259 L
.54131 .01112 L
.54255 .01015 L
.54325 .00974 L
.5439 .00944 L
.54522 .0091 L
.54596 .00907 L
.54664 .00913 L
Mistroke
.54794 .00951 L
.54915 .01017 L
.54978 .01063 L
.55047 .01123 L
.55188 .01272 L
.55443 .01644 L
.55683 .02105 L
.56189 .03411 L
.56652 .04964 L
.57694 .09389 L
.5869 .14184 L
.59752 .18972 L
.60268 .209 L
.60754 .22364 L
.61191 .23335 L
.61437 .23725 L
.61555 .23871 L
.61663 .2398 L
.61777 .24069 L
.61884 .24129 L
.61997 .24168 L
.62121 .24179 L
.62228 .24164 L
.62343 .24123 L
.6244 .24066 L
.62548 .23981 L
.62674 .23852 L
.62789 .23706 L
.63049 .23283 L
.6352 .22195 L
.63976 .20782 L
.64475 .1889 L
.65481 .14322 L
.66574 .09016 L
.67111 .06601 L
.67606 .0463 L
.68047 .03154 L
.68532 .01896 L
.68784 .01411 L
.6902 .01068 L
.6915 .00927 L
.69269 .00827 L
.69334 .00785 L
.69406 .00748 L
.69536 .00709 L
.69664 .00704 L
.69735 .00717 L
.69801 .00737 L
.69923 .00798 L
.70051 .00896 L
Mistroke
.70166 .01012 L
.70273 .01144 L
.70517 .01528 L
.70781 .02073 L
.71021 .0268 L
.71561 .04396 L
.7344 .12852 L
.74367 .17298 L
.75351 .21226 L
.75864 .22729 L
.76156 .23378 L
.7629 .2362 L
.7643 .23838 L
.7655 .23993 L
.76681 .24129 L
.768 .24222 L
.76911 .24283 L
.77042 .24322 L
.77161 .24326 L
.77227 .24316 L
.77298 .24295 L
.77428 .24229 L
.77552 .24134 L
.77665 .24021 L
.77918 .23671 L
.78153 .23234 L
.78376 .22723 L
.78875 .21264 L
.79419 .19241 L
.81524 .09249 L
.82013 .06989 L
.82542 .0481 L
.83007 .03196 L
.83498 .01876 L
.83746 .01376 L
.83878 .0116 L
.84018 .00966 L
.84148 .00823 L
.84265 .00723 L
.84384 .00651 L
.84495 .0061 L
.84559 .00598 L
.84629 .00595 L
.84702 .00603 L
.8477 .0062 L
.84893 .00675 L
.85024 .00769 L
.85178 .00923 L
.85324 .01115 L
.85598 .01588 L
Mistroke
.85857 .02168 L
.86101 .02826 L
.86557 .0432 L
.87579 .08654 L
.89418 .17594 L
.90394 .21459 L
.90886 .22875 L
.91166 .23486 L
.9129 .23711 L
.91426 .23921 L
.91551 .24081 L
.91666 .24201 L
.91776 .2429 L
.91893 .24356 L
.91997 .24392 L
.92095 .24405 L
.92202 .24396 L
.92318 .24359 L
.92434 .24294 L
.92561 .2419 L
.92693 .24047 L
.92816 .23882 L
.93037 .2351 L
.93274 .23008 L
.93807 .21503 L
.94298 .19716 L
.95409 .14685 L
.97424 .05165 L
.97619 .04419 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{391.125, 97.75},
  ImageMargins->{{0, 0}, {0, 1.5}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007X0000NR000`400?l00000o`00003o>?ooool0
0ol0003oooooooooo`3oooooojkooooo000hooooo`03o`000?oooooooooo0?oooooo[_ooool003So
oooo0ol0003oooooojkooooo000hooooo`03o`000?oooooooooo0?oooooo3Oooool3o`00ocWooooo
1?l00?mQooooo`00>?ooool00ol0003oooooooooo`3?ooooo`Co003o>?ooool2o`00o`03ooooool0
0?oo003o03Oooooo1_l00?mPooooo`00>?ooool00ol0003oooooooooo`2Cooooo`03o`00oooooooo
oooo03Sooooo00Co003ooooooooooooooooo0_l00?lgooooo`Co003o00?oooooo`00ooooool0=Ooo
ool7o`00oeoooooo000hooooo`03o`000?oooooooooo097ooooo1Ol00?lgooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool0=?ooool2o`00o`?ooooo00?o003oooooool00?l0=?ooool2
o`00o`Cooooo0_l00?mOooooo`00>?ooool3o`00097ooooo00Co003ooooooooooooooooo0_l00?lf
ooooo`03o`00oooooooo003o00;o003o0_ooool00ol00?ooooooooooo`0cooooo`So003o=?ooool2
o`00o`Gooooo0_l00?mNooooo`00>?ooool00ol0003oooooooooo`1Dooooo`Co003o>?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo03?ooooo00Go003oooooool00?oo003oooooo`02
o`00o`03ooooool00?oooooo03?ooooo00?o003oooooool00?l00oooool2o`00o`03ooooool00?oo
oooo037ooooo0_l00?l6ooooo`;o003oG_ooool002kooooo0_l000000ol@413oooooooooo`05oooo
o`03o`000?oooooooooo05?ooooo0_l00?l2ooooo`;o003o=_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo03;ooooo0ol00?l4ooooo`03o`00oooooooo003o03?ooooo0_l00?l5oooo
o`?o003o<_ooool2o`00o`Oooooo0_l00?mMooooo`00;oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo05;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0cooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0<Oooool00ol00?ooooooo`00o`02ooooo`06
o`00ooooooooooooo`00oooooooo003o<_ooool00ol00?ooooooo`00o`05ooooo`?o003o<Oooool2
o`00o`Sooooo0_l00?mMooooo`009?ooool6o`0000;ooooo1Ol00007ooooo`03o`000?oooooooooo
01Cooooo1Ol00?liooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0<_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo033ooooo0_l00?l00ooooooo003oo`00o`03o`00
o`04ooooool00?ooooooo`00oc7ooooo0_l00?l7ooooo`?o003o<?ooool2o`00o`Wooooo0_l00?mL
ooooo`00;?ooool01?m4A4CogMgMooooool00008ooooo`Co00004_ooool2o`00o`?ooooo0_l00?lg
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`05
o`00o`;ooooo00?o003oooooooooool0<?ooool4o`00o`Cooooo0_l00?l00ooooooo003oooooo`0`
ooooo`;o003o1oooool3o`00oc3ooooo0_l00?l9ooooo`;o003oG?ooool002cooooo00CogMgMoeEE
EOoooooo00002?ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0=Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo033ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00oc3ooooo0_l00?l00ooooooo003o
ooooo`05ooooo`?o003o<?ooool2o`00o`Wooooo0_l00?l_ooooo`;o003o2_ooool2o`00oecooooo
000]ooooo`03ogMgMoo<c<co000000Sooooo00?o0000ooooooooool04_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo03Cooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0_ooooo`04o`00oooooooo003oo`00o`Gooooo00Co003ooooooooooooo003o<?ooool2o`00o`03
ooooool00?oooooo00Kooooo00?o003oooooool00?l0;oooool2o`00o`Wooooo0ol00?l^ooooo`;o
003o2oooool2o`00oe_ooooo000]ooooo`03onk^k_m4A4Co000000Sooooo00?o0000ooooooooool0
4_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0^ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooool0
0?l0<?ooool00ol00?ooooooo`00o`08ooooo`?o003o;_ooool2o`00o`_ooooo0_l00?l^ooooo`;o
003o2oooool2o`00oe_ooooo000^ooooo`03ogMgMol0003ooooo00Oooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0^ooooo`04o`00ooooooooooooo`00o`Oooooo00Co003ooooooooo
oooo003o;_ooool2o`00o`03ooooool00?oooooo00Oooooo0_l00?l00ooooooo003oooooo`0/oooo
o`;o003o2oooool2o`00obgooooo0_l00?l<ooooo`;o003oFoooool003Sooooo0ol0000Aooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo02gooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`0^ooooo`?o
003o2Oooool01?l00?ooooooo`00ool00?l]ooooo`;o003o2oooool3o`00obcooooo0_l00?l=oooo
o`;o003oF_ooool003Sooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo02oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0/ooooo`03
o`00oooooooo003o00?ooooo1Ol00?l2ooooo`03o`00oooooooo003o02kooooo00?o003oooooool0
0?l02_ooool3o`00obcooooo0_l00?l=ooooo`;o003o;?ooool2o`00o`gooooo0_l00?l[ooooo`03
o`00oooooooooooo02cooooo000hooooo`03o`000?oooooo003o00Go003o2oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo02kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo02_ooooo00?o003oooooool00?l00_ooool2o`00o`?ooooo
00Oo003oooooooooooooooooo`00oooooooo003o02cooooo0ol00?l;ooooo`;o003o00?oooooo`00
ooooool0:_ooool2o`00o`gooooo0_l00?l[ooooo`;o003o3_ooool2o`00ob_ooooo00?o003ooooo
ooooool0;?ooool003Sooooo00?o0000o`00ool00?l01Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool0;_ooool00ol00?ooooooooooo`02ooooo`;o
003o00?oooooo`00ool00?l01Oooool00ol00?ooooooooooo`0[ooooo`;o003o0_ooool00ol00?oo
ooooooooo`04ooooo`06o`00ooooooooooooo`00oooooooo003o;?ooool3o`00o`_ooooo00Co003o
ooooool00?oo003o:oooool2o`00o`gooooo0_l00?l[ooooo`;o003o3_ooool2o`00ob[ooooo0_l0
0?l^ooooo`00>?ooool00ol0003o003oooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02_ooooo0_l00?l2
ooooo`03o`00oooooooooooo00Gooooo00Go003oooooool00?ooooooo`00o`0/ooooo`;o003o3Ooo
ool3o`00ob_ooooo00?o003oooooooooool03?ooool3o`00ob[ooooo0_l00?l?ooooo`;o003o:Ooo
ool2o`00obkooooo000hooooo`03o`00ool0003o000000Oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo02cooooo00Go003oooooooooooooooooo`00
o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0:_ooool01?l00?oooooooooo
ool00?l8ooooo`06o`00ooooooooooooo`00oooooooo003o:oooool2o`00o`gooooo0ol00?lZoooo
o`;o003o3oooool2o`00ob[ooooo00?o003oooooooooool03_ooool2o`00obWooooo00?o003ooooo
ooooool0;Oooool003Sooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool0;?ooool01?l00?ooooooooooool00?l9oooo
o`05o`00ooooooooooooooooool00?l0:oooool2o`00o`;ooooo00?o003oooooooooool01oooool0
1Ol00?ooooooo`00oooooooo003o02[ooooo0ol00?l=ooooo`;o003o00?oooooo`00ooooool0:?oo
ool2o`00o`oooooo0_l00?lYooooo`;o003o4?ooool2o`00obWooooo00?o003oooooooooool0;Ooo
ool003Sooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool0;?ooool01?l00?ooooooooooool00?l9ooooo`05o`00oooo
ooooooooooooool00?l0:oooool2o`00o`;ooooo00?o003oooooooooool02?ooool01?l00?oooooo
o`00ool00?lZooooo`;o003o3oooool3o`00obWooooo0_l00?l?ooooo`;o003o:Oooool2o`00oa3o
oooo0_l00?lXooooo`;o003o;oooool003Sooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0:_ooool01?l00?oooooo
ooooool00?l;ooooo`04o`00ooooooooooooo`00ob_ooooo00Co003ooooooooooooo003o2oooool0
1Ol00?ooooooo`00oooooooo003o02Wooooo0_l00?l?ooooo`?o003o:Oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo02Oooooo0_l00?lAooooo`;o003o9oooool2o`00oboooooo000h
ooooo`03o`000?oooooooooo00Wooooo00Go003oooooooooooooooooo`00o`0Aooooo`03o`00oooo
oooooooo02[ooooo00Co003ooooooooooooo003o2oooool01Ol00?oooooooooooooooooo003o02[o
oooo00Co003ooooooooooooo003o3?ooool2o`00o`03ooooool00?oooooo02Sooooo0_l00?l?oooo
o`?o003o:?ooool2o`00oa7ooooo0_l00?lXooooo`03o`00oooooooooooo013ooooo0_l00?lWoooo
o`;o003o;oooool003Sooooo0ol00009ooooo`05o`00ooooooooooooooooool00?l04Oooool00ol0
0?ooooooooooo`0Zooooo`03o`00oooooooo003o00gooooo00Co003ooooooooooooo003o:_ooool0
0ol00?ooooooo`00o`0=ooooo`04o`00oooooooo003oo`00obSooooo0_l00?lAooooo`;o003o:?oo
ool2o`00oa7ooooo0_l00?lXooooo`03o`00oooooooooooo013ooooo0_l00?lWooooo`03o`00oooo
oooooooo02kooooo000hooooo`03o`000?oooooooooo00[ooooo00Co003ooooooooooooo003o4Ooo
ool00ol00?ooooooooooo`0Zooooo`03o`00oooooooo003o00gooooo00Co003ooooooooooooo003o
:Oooool2o`00o`03ooooool00?oooooo00gooooo0ol00?lXooooo`;o003o4Oooool3o`00obOooooo
0_l00?lAooooo`;o003o9oooool2o`00oa;ooooo0_l00?lWooooo`03o`00oooooooooooo02kooooo
000/ooooo`Go00001oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo003o00Oo003o3?oo
ool00ol00?ooooooooooo`0Yooooo`;o003o3oooool00ol00?ooooooo`00o`0Yooooo`03o`00oooo
oooo003o00oooooo0_l00?l00ooooooo003oooooo`0Vooooo`;o003o4Oooool3o`00obOooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`0Uooooo`;o003o4oooool00ol00?oooooooooo
o`0Tooooo`;o003o<?ooool002cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03o`000?oo
oooooooo00_ooooo0_l00?l7ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0:?oo
ool00ol00?ooooooo`00o`0?ooooo`04o`00ooooooooooooo`00obSooooo00?o003oooooool00?l0
4?ooool3o`00obOooooo0_l00?lBooooo`;o003o9_ooool2o`00oa?ooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`0Booooo`;o003o9Oooool2o`00oc3ooooo000Tooooo`Ko00000ooo
ool00onHV9So8B4Qonk^kP08ooooo`Co00002Oooool3o`00o`Sooooo0_l00?l9ooooo`03o`00oooo
oooooooo02Sooooo0_l00?l4ooooo`Ko003o1_ooool01?l00?ooooooooooool00?lXooooo`03o`00
oooooooo003o013ooooo0ol00?lWooooo`03o`00oooooooooooo017ooooo0_l00?lVooooo`;o003o
4oooool2o`00obKooooo00?o003oooooooooool04_ooool2o`00obGooooo00?o003oooooooooool0
;oooool002kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`09ooooo`04o`00oooo
oooo003oo`00o`[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Wooooo`;o003o
0oooool2o`00o`Gooooo0_l00?l5ooooo`03o`00oooooooo003o02Oooooo0ol00?lAooooo`?o003o
9_ooool2o`00oa?ooooo0ol00?lUooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
8oooool2o`00oaCooooo0_l00?lUooooo`03o`00oooooooooooo02oooooo000_ooooo`03ogMgMomV
IVKooooo00Kooooo00?o0000ooooooooool02Oooool01Ol00?ooooooo`00oooooooo003o00Wooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0Wooooo`;o003o0_ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l09oooool00ol00?oooooo
o`00o`0Booooo`;o003o9_ooool2o`00oaCooooo0_l00?lUooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool08oooool2o`00oaGooooo00?o003oooooooooool08oooool00ol00?oooooo
ooooo`0_ooooo`00<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00Ko
003ooooooooooooo003oooooool00?l:ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool09_ooool2o`00o`;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooo003o02Kooooo0_l00?lCooooo`?o003o9Oooool00ol00?ooooooooooo`0Cooooo`;o
003o9Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo02?ooooo0_l00?lEooooo`;o
003o8oooool2o`00oc7ooooo000/ooooo`05o`000?nj^[[ooooooiRHV?l@41001oooool00ol0003o
ooooooooo`07ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool09_ooool2o`00o`03ooooool00?oooooo
00cooooo00Oo003oooooooooooooooooo`00oooooooo003o02Kooooo0_l00?lCooooo`?o003o9Ooo
ool00ol00?ooooooooooo`0Cooooo`;o003o9?ooool2o`00oaGooooo00?o003oooooooooool08ooo
ool00ol00?ooooooooooo`0Dooooo`;o003o8oooool2o`00oc7ooooo000/ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01oooool3o`0000Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Uooooo`03o`00
oooooooo003o00kooooo00Oo003oooooooooooooooooo`00oooooooo003o02Kooooo0_l00?lDoooo
o`;o003o9?ooool2o`00oaGooooo0_l00?lTooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool08_ooool00ol00?ooooooooooo`0Dooooo`;o003o8oooool00ol00?ooooooooooo`0`oooo
o`00>?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool09Oooool2o`00o`_ooooo1?l000001Ol@413o003oooooooo^k^ko<S8b00;o003o00?ok^k^oooo
ooooool08_ooool2o`00oaGooooo0_l00?lGooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00;o003o5_ooool2o`00ob?ooooo00?o003oooooooooool04oooool01OnHV9So410@o`00oolb
<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`;o003o5oooool00ol00?oooooo
ooooo`0Pooooo`03o`000?l00?oo410@00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Yooooo`00
>?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
9?ooool00ol00?ooooooo`00o`0=ooooo`0:o`000?ooooooooooo`00ooooooooMgMgoiRHV?l00?oo
V9RHo`00obCooooo0_l00?lEooooo`?o003o5_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00KoMgMgoiRHV?ooooooV9RHogMgMol00?lGooooo`;o003o8oooool00ol00?ooooooooooo`0Coooo
o`05oa0@4?nj^[[o003oogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo0_l0
0?lGooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02Wooooo000hooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Tooooo`;o003o3_ooool02_l0003ooooooooooooooooo003ooa0@4?oo
oooo003oooooool00?lTooooo`03o`00oooooooooooo01Gooooo0_l00?lGooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Ko410@oooooooooooooooooa0@4?l00?lGooooo`;o003o8_ooool2o`00oaOooooo
00?o003oooooool000000oooool01Ol@413ooooooooooooooooo410@01Wooooo00?o003ooooooooo
ool05_ooool2o`00oaoooooo0_l00002o`00o`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0Wooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool08_ooool2o`00o`oooooo00?o0000ooooooooool00_ooool00ol00?oo
ooooooooo`02o`00obCooooo00?o003oooooooooool05Oooool2o`00oaSooooo00?oV9RHob4Q8Oo^
k^h00oooool01?l0003oooooooooooooool2o`00oaSooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`0Fooooo`;o003o00Go410@ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo01Oooooo00?o003oooooooooool05_ooool2o`00oaoooooo00CoA4A4omgMgOl00?oo003o1?oo
ool01Ol0003ooooooooooooooooo000002Wooooo000hooooo`?o00000oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo02;ooooo0_l00?l?ooooo`03o`000?oooooooooo00;ooooo00?o
0000o`00ooooool00_l00?lSooooo`;o003o5oooool2o`00oaWooooo00?oMgMgofIVI_ooool00_oo
ool01?l0003oooooooooooooool2o`00oaSooooo0_l00?lQooooo`03o`00oooooooooooo01Kooooo
00?o410@o`00oonj^[X00oooool01Ol0003ooooooooooooooooo000001Sooooo0_l00?lHooooo`;o
003o7oooool01?oMgMgoEEEEo`00ool00004ooooo`05o`000?ooooooooooooooool00000:Oooool0
03Sooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
027ooooo0_l00?l@ooooo`03o`000?oooooooooo00;ooooo00?o410@o`00ooooool00_l00?lSoooo
o`03o`00oooooooooooo01Kooooo0_l00?lJooooo`05o`000?ooooooooooooooool@41000oooool0
0ol00?ooooooooooo`0Gooooo`;o003o8Oooool00ol00?ooooooooooo`0Gooooo`03o`00oolQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@400Hooooo`;o003o6Oooool00ol00?oooooooooo
o`0Nooooo`03ogMgMol00?oo000000Cooooo00Go410@oooooooooooooooooa0@400Yooooo`00>?oo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool08?oo
ool2o`00oa3ooooo00?o0000ooooooooool00_ooool01?mgMgOoV9RHo`00oonHV9P2o`00ob;ooooo
00?o003oooooooooool05oooool2o`00oaGooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?l00?l06Oooool2o`00ob3ooooo0_l00?lFooooo`05oa0@4?nHV9Sooooo
o`00ool000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Sooooo0_l00?lIooooo`03o`00oooo
oooooooo01kooooo00?ok^k^o`00ool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo
000hooooo`05o`000?ooooooooooooooool00?l01_ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`?o003o
3_ooool00omEEEGoIVIVo`000004ooooo`04onk^k_lb<S;o003ooc8b<P;o003o8Oooool2o`00oaWo
oooo0_l00?lEooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool00oo^k^ko<S8bo`000002o`00
oa[ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0Eooooo`03ojVYZOl@413o0000
00;o003o0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Sooooo00?o003oooooooooool06?ooool2
o`00oaoooooo0_l00?l00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Ooo
ool003Sooooo00Go0000ooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o023ooooo0_l00?l00ooooooo003o
ooooo`0Fooooo`04o`00oooooooo003oo`00ob7ooooo00?o003oooooooooool06?ooool2o`00ob3o
oooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo01So
oooo0_l00?lPooooo`03o`00oooooooooooo01Sooooo0_l00?lOooooo`;o003o<oooool003Sooooo
0ol000000ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool01Ol00?oooooooooooooooooo003o01oooooo00Co003oooooool00?oo003o6Oooool00ol0
0?ooooooo`00o`0Qooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0Iooooo`;o003o7oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo
01gooooo0_l00?lJooooo`;o003o7oooool00ol00?ooooooooooo`0booooo`00>?ooool01?l0003o
ooooooooool00?l6ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooool00?ooooooo`00o`0I
ooooo`04o`00oooooooo003oo`00ob3ooooo00?o003oooooooooool06Oooool2o`00oaoooooo00?o
003oooooooooool06Oooool2o`00oakooooo0_l00?lKooooo`03o`00oooooooooooo01gooooo0_l0
0?lKooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0<_ooool003Sooooo00?o0000
ooooool00?l01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00Go003o
ooooooooooooooooo`00o`0Looooo`06o`00ooooooooooooo`00oooooooo003o6_ooool3o`00oaoo
oooo0_l00?lKooooo`;o003o7_ooool2o`00oacooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`0Jooooo`;o003o7_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool0<_ooool003Sooooo00?o0000o`00ooooool01oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`0Looooo`06
o`00ooooooooooooo`00oooooooo003o6_ooool00ol00?ooooooo`00o`0Oooooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool06_ooool2o`00oakooooo00?o003oooooooooool06_ooool2
o`00oagooooo0_l00?ldooooo`00>?ooool00ol0003o003oooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool02_ooool01?l00?ooooooooooool00?lKooooo`06o`00oooooooo
ooooo`00oooooooo003o7?ooool2o`00oakooooo0_l00?lMooooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01[ooooo
0_l00?lNooooo`03o`00oooooooooooo01[ooooo0_l00?lMooooo`;o003o=?ooool002kooooo2_l0
00000ol00?oo0000o`000006o`000003o`00ool0003o000000go000000?o003oo`000?l000002Ol0
00001Ol00?oo0000o`000?l0003o003o01Wo000000Oo003oo`000?l0003o0000o`00ool0003o003o
01co00000ol00?lMo`0000;o003o7Ol000000ol00?oo0000o`00000Lo`000003o`00ool0003o0000
01co000000?o003oo`000?l000006_l00002o`00oago000000?o003oo`000?l000006ol00002o`00
oaco00000_l00?lMo`000003o`00ool0003o000000oo00009?ooool003Sooooo00?o0000oooooooo
ool01_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o003ooooooooo
ool02_ooool01?l00?oo0000ooooool00?l@ooooo`03o`000?oooooooooo00Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooo`00o`03ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool00oooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00oooooo0_l00?lBoooo
o`03o`000?oooooooooo00Sooooo0_l00?l6ooooo`03o`000?oooooooooo017ooooo00Co0000oooo
ool00?oo003o3oooool00ol0003oooooooooo`0<ooooo`05o`00ooooooooooooooooool000004_oo
ool00ol0003oooooooooo`03ooooo`;o003o3?ooool00ol0003oooooooooo`0>ooooo`;o003o00?o
0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o
0000ooooooooool04Oooool00ol0003o003oooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o
003oooooooooool01?ooool00ol0003oooooooooo`0/ooooo`00>?ooool00ol0003oooooooooo`05
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02Oooool01?l00?ooooooooooool0
0?lGooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l05oooool00ol0003ooooooooo
o`04ooooo`;o003o7?ooool2o`00oaoooooo00?o003oooooooooool06?ooool00ol0003oooooo`00
o`0Oooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool07?ooool2o`00o`03o`000?oo
oooooooo01Wooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool0;?ooool003Sooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00Co003ooooooooooooo003o5ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o01kooooo0_l00?lLooooo`;o003o7ooo
ool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06_oo
ool00ol00?ooooooooooo`0Looooo`;o003o7?ooool00ol00?ooooooooooo`0Looooo`;o003o6ooo
ool2o`00ocGooooo000hooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`09ooooo`04o`00ooooooooooooo`00oaGooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?lOooooo`;o003o6oooool2o`00oaoooooo00?o003oooooooooool0
6Oooool2o`00oaoooooo0_l00?lKooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
6_ooool00ol00?ooooooooooo`0Looooo`;o003o6oooool2o`00ocGooooo000hooooo`?o00001Ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00Co003ooooooooooooo003o
5?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00oaoooooo0_l00?lJooooo`?o
003o7oooool2o`00oa[ooooo0_l00?lPooooo`03o`00oooooooooooo01Sooooo0_l00?lOooooo`;o
003o6_ooool2o`00oaoooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0dooooo`00
>?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01;ooooo0_l00?l:ooooo`03o`00
oooooooo003o01?ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`0Pooooo`;o003o
6_ooool2o`00ob7ooooo00?o003oooooooooool06?ooool2o`00ob3ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`0Nooooo`;o003o6_ooool00ol00?ooooooooooo`0Nooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool0=?ooool003Sooooo00?o0000ooooooooool01?oo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo00?o003oooooool00?l04Ooo
ool2o`00o`Kooooo00Co003ooooooooooooo003o8Oooool2o`00oaWooooo0_l00?lQooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo01kooooo0_l00?lJooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool0
6?ooool2o`00ocKooooo000hooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooo003o00oooooo00?o003oooooooooool01_oo
ool01?l00?ooooooooooool00?lQooooo`;o003o6?ooool3o`00ob7ooooo00?o003oooooooooool0
5oooool2o`00ob7ooooo0_l00?lIooooo`03o`00oooooooooooo01kooooo0_l00?lJooooo`03o`00
oooooooooooo01kooooo0_l00?lIooooo`;o003o=_ooool003Sooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l03_oo
ool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00ob?ooooo00?o003oooooooooool0
5_ooool3o`00ob7ooooo0_l00?lHooooo`;o003o8Oooool2o`00oaSooooo0_l00?lQooooo`03o`00
oooooooooooo01Oooooo0_l00?lPooooo`;o003o6Oooool2o`00ocKooooo000hooooo`?o00000ooo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Kooooo0_l00?l<ooooo`;o003o2Ooo
ool01?l00?ooooooooooool00?lSooooo`03o`00oooooooooooo01Kooooo0_l00?lSooooo`03o`00
oooooooooooo01Kooooo0_l00?lRooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
8?ooool2o`00oaSooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo03Gooooo000hooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`05ooooo`;o003o2_ooool2o`00o`_ooooo00Co003ooooooooooooo003o
8oooool2o`00oaKooooo0ol00?lSooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
8Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo023ooooo0_l00?lHooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0eooooo`00>?oo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01_ooooo0_l00?l6ooooo`;o003o1ooo
ool2o`00o`cooooo00Go003oooooooooooooooooo`00o`0Tooooo`03o`00oooooooooooo01Cooooo
0ol00?lSooooo`;o003o5_ooool2o`00ob?ooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`0Pooooo`;o003o6?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo01Kooooo
0_l00?lgooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01gooooo0_l0
0?l4ooooo`;o003o1Oooool2o`00o`kooooo00Co003ooooooooooooo003o9Oooool2o`00oaCooooo
00Co003oooooool00?oo003o8oooool2o`00oaKooooo0_l00?lSooooo`;o003o5oooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo01Gooooo0_l00?lRooooo`;o003o5oooool2o`00ocOo
oooo000hooooo`?o00000_ooool00ol00?ooooooooooo`0Oooooo`_o003o4?ooool01?l00?oooooo
ooooool00?lUooooo`;o003o5?ooool3o`00obGooooo00?o003oooooooooool05?ooool2o`00ob?o
oooo0_l00?lFooooo`;o003o8oooool2o`00oaKooooo0_l00?lRooooo`;o003o5oooool2o`00ocOo
oooo000hooooo`05o`000?ooooooooooooooool00?l09oooool00ol00?ooooooooooo`0Booooo`05
o`00ooooooooooooooooool00?l09Oooool3o`00oa;ooooo00Co003oooooool00?oo003o9Oooool2
o`00oaGooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo02;ooooo0_l00?lFooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0fooooo`00>?ooool01Ol0003ooooooooooooooooo003o02Sooooo00?o003o
ooooooooool04Oooool01Ol00?oooooooooooooooooo003o02Gooooo0ol00?lBooooo`04o`00oooo
oooo003oo`00obGooooo0_l00?lDooooo`;o003o9Oooool00ol00?ooooooooooo`0Dooooo`03o`00
oooooooooooo02;ooooo0_l00?lFooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0
5?ooool2o`00ocSooooo000/ooooo`Go00001oooool01Ol0003ooooooooooooooooo003o02Sooooo
00?o003oooooooooool04?ooool01Ol00?oooooooooooooooooo003o02Oooooo0ol00?lAooooo`;o
003o00?oooooo`00ooooool09?ooool2o`00oaCooooo0_l00?lUooooo`;o003o5Oooool00ol00?oo
ooooooooo`0Rooooo`;o003o5_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo01Co
oooo0_l00?lhooooo`00;?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00Go0000oooooooo
ooooooooo`00o`0Xooooo`;o003o4Oooool01Ol00?oooooooooooooooooo003o02Oooooo0ol00?l@
ooooo`04o`00oooooooo003oo`00obKooooo0ol00?lCooooo`;o003o9Oooool2o`00oaCooooo0_l0
0?lUooooo`03o`00oooooooooooo01?ooooo0_l00?lTooooo`;o003o5Oooool2o`00ocSooooo000]
ooooo`03oiRHV?lQ8B7ok^k^00Sooooo0ol000000ol00?ooooooooooo`0Xooooo`;o003o3oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Gooooo0_l00?l00ooooooo003oooooo`0>
ooooo`04o`00oooooooo003oo`00obOooooo0_l00?lCooooo`;o003o9Oooool2o`00oaCooooo0_l0
0?lUooooo`;o003o5?ooool2o`00obCooooo0_l00?lEooooo`03o`00oooooooooooo03Oooooo000^
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00Co0000oooooooooooo003o:_ooool2o`00o`oooooo00Go
003oooooooooooooooooo`00o`0Xooooo`04o`00oooooooo003oo`00o`kooooo00Go003oooooool0
0?ooooooo`00o`0Wooooo`;o003o4_ooool2o`00obOooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0Tooooo`;o003o5?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool0=oooool002oooooo00?oMgMgofIVI_ooool01_ooool01?l0003o
ooooooooool00?lZooooo`04o`00oooooooo003oo`00o`cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Wooooo`;o003o00?oooooo`00ooooool03?ooool01Ol00?ooooooo`00oooo
oooo003o02Oooooo00?o003oooooool00?l04Oooool2o`00obOooooo0_l00?lCooooo`03o`00oooo
oooooooo02Cooooo0_l00?lDooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool04_oo
ool2o`00ocWooooo000`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00?l0:oooool0
1Ol00?oooooooooooooooooo003o00[ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Wooooo`;o003o00?oooooo`00ooooool02oooool00ol00?ooooooooooo`02o`00obSooooo0ol0
0?lAooooo`;o003o9oooool2o`00oa;ooooo0_l00?lWooooo`03o`00oooooooooooo017ooooo0_l0
0?lVooooo`03o`00oooooooooooo01;ooooo0_l00?liooooo`00;?ooool01Ol0003o^[ZjoooooonH
V9So410@00Oooooo00?o0000ooooool00?l0;?ooool01Ol00?oooooooooooooooooo003o00Sooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Wooooo`05o`00oooooooo003oooooool0
0?l02_ooool01_l00?ooooooooooool00?ooooooo`00obSooooo0ol00?l@ooooo`?o003o9oooool2
o`00oa;ooooo0_l00?lWooooo`;o003o4_ooool2o`00obKooooo0_l00?lCooooo`;o003o>Oooool0
02cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c007ooooo`;o000000?o003oooooooooool0:_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Xooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool01oooool0
1_l00?ooooooooooool00?ooooooo`00obWooooo00?o003oooooool00?l03oooool2o`00obSooooo
0_l00?lBooooo`;o003o9oooool2o`00oa;ooooo0_l00?lWooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool0>?ooool003Sooooo00?o0000o`00ooooool0;?ooool00ol00?oooooooooo
o`02ooooo`;o003o0oooool2o`00o`Oooooo00?o003oooooooooool0:Oooool2o`00o`?ooooo00?o
003oooooooooool01Oooool01ol00?oooooooooooooooooo003oooooool00?l0:Oooool00ol00?oo
ooooo`00o`0?ooooo`;o003o:Oooool2o`00oa7ooooo00?o003oooooooooool09_ooool2o`00oa;o
oooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0@ooooo`;o003o>_ooool003Sooooo
00?o0000o`00ooooool0;Oooool00ol00?ooooooooooo`03ooooo`Co003o2?ooool00ol00?oooooo
ooooo`0Yooooo`03o`00oooooooo003o00?ooooo0_l00?l3ooooo`;o003o0oooool00ol00?oooooo
o`00o`0Zooooo`?o003o3_ooool00ol00?ooooooo`00o`0Yooooo`;o003o4?ooool2o`00obWooooo
0_l00?l@ooooo`;o003o:?ooool2o`00oa7ooooo0_l00?ljooooo`00>?ooool00ol0003o003ooooo
o`0]ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0:_ooool00ol00?ooooooo`00
o`04ooooo`Go003o1?ooool00ol00?ooooooo`00o`0Zooooo`;o003o00?oooooo`00ooooool03?oo
ool3o`00obWooooo0_l00?l@ooooo`;o003o:Oooool2o`00oa3ooooo0_l00?lXooooo`;o003o4Ooo
ool2o`00oc[ooooo000hooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0[ooooo`03o`00oooooooo003o00cooooo00?o003oooooool00?l0:oooool0
0ol00?ooooooo`00o`0=ooooo`;o003o:_ooool2o`00oa3ooooo0_l00?lYooooo`;o003o4?ooool2
o`00obWooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0iooooo`00>?ooool00ol0
0?oo0000o`00000^ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0:oooool00ol0
0?ooooooo`00o`0;ooooo`04o`00ooooooooooooo`00ob_ooooo0ol00?l<ooooo`?o003o:oooool2
o`00o`kooooo0_l00?lZooooo`;o003o4?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool0>Oooool003Sooooo00?o0000ooooooooool0;_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo02cooooo00Co003ooooooooooooo003o2_ooool0
0ol00?ooooooo`00o`0/ooooo`;o003o00?oooooo`00ooooool02_ooool3o`00ob_ooooo0_l00?l>
ooooo`;o003o:oooool2o`00o`oooooo00?o003oooooooooool0:?ooool2o`00o`oooooo0_l00?lk
ooooo`00>?ooool00ol0003oooooooooo`0_ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool0;Oooool00ol00?ooooooo`00o`09ooooo`04o`00ooooooooooooo`00obgooooo00?o003o
ooooool00?l02oooool3o`00ob_ooooo0_l00?l>ooooo`;o003o:oooool2o`00o`kooooo0_l00?lZ
ooooo`;o003o3oooool2o`00oc_ooooo000hooooo`03o`000?oooooooooo02oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`0]ooooo`04o`00ooooooooooooo`00o`Sooooo00Co003o
oooooooooooo003o;Oooool3o`00o`[ooooo0ol00?l/ooooo`?o003o3?ooool2o`00obcooooo0_l0
0?l>ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`0jooooo`00>?ooool00ol0003oooooooooo`0`ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool0;_ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooo003o02kooooo0_l0
0?l00ooooooo003oooooo`08ooooo`?o003o;Oooool2o`00o`cooooo0_l00?l/ooooo`;o003o3_oo
ool00ol00?ooooooooooo`0Zooooo`;o003o3Oooool2o`00occooooo000hooooo`?o0000<?ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02oooooo00Co003ooooooooooooo003o1_oo
ool01?l00?ooooooooooool00?l_ooooo`04o`00ooooooooooooo`00o`Oooooo0_l00?l00ooooooo
003oooooo`0/ooooo`;o003o3?ooool2o`00obgooooo0_l00?l<ooooo`;o003o;?ooool2o`00o`go
oooo0_l00?llooooo`00>?ooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool0<?ooool01?l00?ooooooooooooooool2o`00o`04ooooool00?oo003oo`00
o`?ooooo00?o003oooooooooool0;Oooool2o`00o`;ooooo00?o003oooooooooool00oooool01?l0
0?ooooooo`00ool00?l^ooooo`?o003o2_ooool2o`00obkooooo0_l00?l<ooooo`03o`00oooooooo
oooo02cooooo00?o003oooooooooool02oooool2o`00occooooo000^ooooo`;o000000?o410@oooo
ooooool01Oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`03ooooo`;o003o1?ooool00ol00?ooooooooooo`0^oooo
o`04o`00oooooooo003oooooo`;o003o0oooool00ol00?ooooooooooo`02o`00oboooooo0_l00?l:
ooooo`;o003o;_ooool2o`00o`cooooo00?o003oooooooooool0;?ooool2o`00o`_ooooo0_l00?lm
ooooo`00;oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool0;oooool2o`00o`;ooooo1?l00?l2ooooo`03o`00oooooooo003o02oooooo0_l00?l:oooo
o`;o003o;oooool2o`00o`[ooooo0_l00?l^ooooo`;o003o2oooool2o`00ocgooooo000/ooooo`Go
00001oooool00ol0003oooooooooo`0booooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool0<_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02oooooo00?o003oooooool0
0?l01oooool2o`00oc3ooooo0ol00?l8ooooo`;o003o<?ooool2o`00o`[ooooo00?o003ooooooooo
ool0;_ooool00ol00?ooooooooooo`09ooooo`;o003o?Oooool002cooooo00CoA4A4omgMgOoooooo
00002?ooool4o`0003;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0dooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool0<?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o037ooooo0_l00?l7ooooo`03o`00oooooooo003o033ooooo0ol00?l9oooo
o`03o`00oooooooooooo02kooooo0_l00?l9ooooo`;o003o?_ooool002cooooo00CogMgMoeEEEOoo
oooo00002?ooool00ol0003oooooooooo`0cooooo`;o003o0oooool00ol00?ooooooooooo`0eoooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<Oooool01?l00?ooooooo`00ool00?l3
ooooo`04o`00ooooooooooooo`00oc7ooooo0ol00?l6ooooo`?o003o<Oooool2o`00o`Sooooo00?o
003oooooooooool0;oooool2o`00o`Wooooo0_l00?lnooooo`00;Oooool00omgMgOoc<c<o`000008
ooooo`03o`000?oooooooooo03Gooooo0ol00?liooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0<_ooool00ol00?ooooooooooo`04o`00o`;ooooo00?o003oooooooooool0<?ooool0
1?l00?ooooooo`00ool00?l4ooooo`03o`00oooooooo003o03;ooooo0_l00?l8ooooo`03o`00oooo
oooooooo033ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0mooooo`00;Oooool0
0oo^k^koA4A4o`000008ooooo`03o`000?oooooooooo07;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0cooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`0cooooo`;o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`0booooo`?o003o1_oo
ool2o`00oc;ooooo0_l00?l7ooooo`;o003o?oooool002kooooo00?oMgMgo`000?ooool01oooool3
o`0007;ooooo00Co003ooooooooooooooooo0_l00?lfooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0<_ooool00ol00?ooooooo`00o`04ooooo`;o003o=?ooool2o`00o`Kooooo0_l0
0?lbooooo`;o003o1oooool2o`00ocoooooo000hooooo`03o`000?oooooooooo07?ooooo1?l00?lh
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0<oooool01Ol00?ooooooo`00ool0
0?oooooo00?o003o=?ooool3o`00o`?ooooo0_l00?l00ooooooo003oooooo`0booooo`;o003o1Ooo
ool2o`00od3ooooo000hooooo`03o`000?oooooooooo0;3ooooo00?o003oooooooooool00_l00?lg
ooooo`03o`00oooooooo003o00?o003o=_ooool6o`00o`03ooooool00?oooooo03Cooooo0_l00?l4
ooooo`;o003o@?ooool003Sooooo00?o0000ooooooooool0/Oooool3o`00ocSooooo0_l00?l2oooo
o`;o003o=oooool6o`00ocKooooo0ol00?l01?oooooo003oo`00ool00?m1ooooo`00>?ooool00ol0
003oooooooooo`3]ooooo`Co003o>Oooool01?l00?ooooooooooool00?lhooooo`Go003o@_ooool0
03Sooooo0ol0003oooooobcooooo0_l00?ljooooo`?o003o@oooool003Sooooo00?o0000oooooooo
ool0oooooon^ooooo`00>?ooool00ol0003oooooooooo`3oooooojkooooo003oooooonWooooo003o
ooooonWooooo003oooooonWooooo003oooooonWooooo003oooooonWooooo003oooooonWooooo003o
oooooaCooooo0ol000000ol@413oooooooooo`3?ooooo`00oooooolFooooo`03oa0@4?nj^[[ooooo
0=3ooooo003ooooooaKooooo00?oV9RHoc8b<_ooool0d?ooool00=kooooo0_lb<S84ooooo`06onk^
k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool5o`0000?ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^
k^h3ooooo`05ofIVI_l0003o0000odA4A?o<c<`00oooool5o`0000?ooooo00GoV9RHo`000?l0003o
A4A4okZj^P03ooooo`03omgMgOl0003o^[Zj0=3ooooo003Mooooo`04omgMgOl@413o410@olc<c0?o
oooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo00?ooooo00KoEEEE
ogMgMoooooooooooogMgMomEEED2ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@1Oooool00ol0
003oooooooooo`03ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00omEEEGoMgMgodA4A03@
ooooo`00gOooool2ofIVIP03ogMgMomVIVKooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GogMgMoa0@4?oooooo8B4QomgM
g@3?ooooo`00gOooool01?l0003ogMgMomgMgOl00003ooooo`Ko00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoIVIVohN7QoooooooV9RHoeEEE@3?ooooo`00
g?ooool01_nHV9So<S8boooooooooooo<S8boiRHV0;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S84ooooo`03o`000?oooooooooo00?ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06
ofIVI_mgMgOooooooooooon7QhOo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`3=ooooo`00g?ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03
o`000?oooooooooo00?ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`06onk^k_mVIVKo
0000o`000?m4A4Co00000oooool00ol@413o0000o`000003ooooo`03oa0@4?l0003o000000?o0000
0_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo0<cooooo003Kooooo`03omgM
gOl0003ooooo00?ooooo00?o0000omgMgOooool02_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo0=Sooooo003Kooooo`?o00000_ooool3o`0000_ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=Sooooo003/ooooo`03oa0@4?l0003o
000001Sooooo00?o410@ooooooooool0g_ooool00?oooooojOooool00?oooooojOooool00001\
\>"],
  ImageRangeCache->{{{77.875, 468}, {622.812, 526.062}} -> {-16.0494, \
62.6944, 0.13009, 0.129065}}]
}, Open  ]],

Cell["And the phase plane trajectories, all tangled up. ", "Text"],

Cell[CellGroupData[{

Cell["\<\
inits = ListPlot[ Table[{3,k},{k,-3,3,3}], \
PlotStyle->PointSize[0.03]];
Show[ inits, 
      ParametricPlot[ 
      Evaluate[Table[{phi2[3,v,t],D[phi2[3,v,t],t]},{v,-3,3,3}]], 
              {t,0,40}, PlotStyle->RGBColor[0,1,0] ], 
      PlotRange->{{-5,5},{-5,5}}, AspectRatio\[Rule]1/1]\
\>", "Input",
  CellLabel->"In[16]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.1 [
[.1 .4875 -6 -9 ]
[.1 .4875 6 0 ]
[.3 .4875 -6 -9 ]
[.3 .4875 6 0 ]
[.7 .4875 -3 -9 ]
[.7 .4875 3 0 ]
[.9 .4875 -3 -9 ]
[.9 .4875 3 0 ]
[.4875 .1 -12 -4.5 ]
[.4875 .1 0 4.5 ]
[.4875 .3 -12 -4.5 ]
[.4875 .3 0 4.5 ]
[.4875 .7 -6 -4.5 ]
[.4875 .7 0 4.5 ]
[.4875 .9 -6 -4.5 ]
[.4875 .9 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 .5 m
.1 .50625 L
s
[(-4)] .1 .4875 0 1 Mshowa
.3 .5 m
.3 .50625 L
s
[(-2)] .3 .4875 0 1 Mshowa
.7 .5 m
.7 .50625 L
s
[(2)] .7 .4875 0 1 Mshowa
.9 .5 m
.9 .50625 L
s
[(4)] .9 .4875 0 1 Mshowa
.125 Mabswid
.15 .5 m
.15 .50375 L
s
.2 .5 m
.2 .50375 L
s
.25 .5 m
.25 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.45 .5 m
.45 .50375 L
s
.55 .5 m
.55 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.75 .5 m
.75 .50375 L
s
.8 .5 m
.8 .50375 L
s
.85 .5 m
.85 .50375 L
s
.05 .5 m
.05 .50375 L
s
.95 .5 m
.95 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .1 m
.50625 .1 L
s
[(-4)] .4875 .1 1 0 Mshowa
.5 .3 m
.50625 .3 L
s
[(-2)] .4875 .3 1 0 Mshowa
.5 .7 m
.50625 .7 L
s
[(2)] .4875 .7 1 0 Mshowa
.5 .9 m
.50625 .9 L
s
[(4)] .4875 .9 1 0 Mshowa
.125 Mabswid
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .25 m
.50375 .25 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .75 m
.50375 .75 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .05 m
.50375 .05 L
s
.5 .95 m
.50375 .95 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.03 w
.8 .2 Mdot
.8 .5 Mdot
.8 .8 Mdot
0 1 0 r
.5 Mabswid
.8 .2 m
.77113 .18825 L
.75483 .18302 L
.73919 .17887 L
.72445 .17569 L
.70831 .17298 L
.69354 .17117 L
.67984 .17004 L
.66357 .16937 L
.64832 .16938 L
.6316 .17009 L
.61367 .17164 L
.60476 .17271 L
.59506 .1741 L
.57752 .17721 L
.54512 .18497 L
.51116 .19596 L
.48153 .20805 L
.42004 .24133 L
.37035 .27805 L
.33084 .31601 L
.29593 .35992 L
.28088 .38409 L
.26938 .40643 L
.26091 .42673 L
.25496 .4448 L
.25248 .45421 L
.25029 .46427 L
.24932 .4697 L
.24857 .47467 L
.24747 .48429 L
.24688 .4935 L
.24677 .49857 L
.24679 .50316 L
.24715 .51143 L
.24798 .5199 L
.2486 .52429 L
.24939 .5289 L
.25117 .53698 L
.25383 .5462 L
.25676 .55422 L
.26399 .56928 L
.27372 .584 L
.28453 .59636 L
.29573 .60647 L
.31817 .62151 L
.33195 .62838 L
.34515 .63374 L
.35785 .63797 L
.37212 .6418 L
Mistroke
.38591 .64472 L
.39893 .64685 L
.40697 .6479 L
.41572 .64883 L
.42402 .64951 L
.43168 .64997 L
.43864 .65027 L
.44627 .65046 L
.45425 .65051 L
.46169 .65042 L
.46587 .65032 L
.47041 .65017 L
.47865 .64977 L
.48665 .64925 L
.49401 .64864 L
.51058 .64685 L
.52791 .64433 L
.55707 .63844 L
.58254 .63134 L
.60876 .62155 L
.63389 .60885 L
.65338 .59561 L
.66906 .58142 L
.68318 .56372 L
.68951 .55285 L
.69421 .5424 L
.69781 .53155 L
.69938 .52517 L
.70052 .51906 L
.70138 .51249 L
.70185 .50637 L
.70198 .50294 L
.70201 .49917 L
.70178 .49223 L
.70128 .48624 L
.70041 .47955 L
.69913 .47247 L
.69758 .46575 L
.69397 .45364 L
.68886 .44045 L
.67227 .41013 L
.6614 .39515 L
.6476 .37922 L
.61853 .35282 L
.58663 .33132 L
.54891 .31309 L
.5261 .30517 L
.51492 .30207 L
.5043 .29958 L
.49417 .29762 L
Mistroke
.48482 .29615 L
.47436 .29492 L
.46307 .29405 L
.45222 .29369 L
.44608 .29369 L
.44038 .29382 L
.42997 .29439 L
.41891 .29549 L
.40816 .29706 L
.39835 .29894 L
.37662 .30472 L
.35808 .31159 L
.33932 .32064 L
.30928 .34066 L
.29395 .35435 L
.28096 .36858 L
.2684 .38559 L
.25705 .40522 L
.25199 .41605 L
.24714 .42843 L
.24337 .44018 L
.24051 .45124 L
.23833 .46206 L
.23663 .47365 L
.23554 .48549 L
.2352 .49228 L
.23508 .49863 L
.2353 .5103 L
.23603 .52099 L
.23748 .5334 L
.23947 .54516 L
.24174 .55566 L
.24478 .56721 L
.25267 .5904 L
.26204 .61156 L
.27256 .6309 L
.30224 .67218 L
.32232 .69345 L
.34261 .71138 L
.38833 .74224 L
.41634 .75606 L
.4429 .76623 L
.46864 .7736 L
.48341 .77678 L
.4971 .77909 L
.50922 .78061 L
.52255 .78172 L
.53652 .78226 L
.54955 .7822 L
.56485 .7814 L
Mistroke
.57346 .7806 L
.58139 .77965 L
.59587 .77734 L
.61107 .7741 L
.63688 .76661 L
.66435 .75558 L
.69217 .74073 L
.72004 .72131 L
.74403 .69989 L
.76371 .67784 L
.78081 .65392 L
.79458 .62967 L
.80743 .5999 L
.81202 .58624 L
.81613 .5715 L
.8191 .55832 L
.82166 .54363 L
.82335 .5301 L
.82436 .51735 L
.82485 .50217 L
.82463 .48824 L
.82358 .47209 L
.8218 .45677 L
.81926 .44156 L
.81558 .42482 L
.80532 .39132 L
.79253 .36103 L
.7777 .33355 L
.73503 .27652 L
.70583 .24818 L
.67615 .22505 L
.64707 .20669 L
.61799 .19188 L
.58288 .17808 L
.56693 .17315 L
.5498 .16873 L
.53465 .16556 L
.51783 .16282 L
.50244 .16103 L
.48797 .15996 L
.47089 .15945 L
.45528 .15971 L
.43729 .16087 L
.42029 .16282 L
.40189 .1659 L
.38538 .16954 L
.34919 .1806 L
.31695 .19437 L
.28805 .21033 L
.2584 .23094 L
Mistroke
.22967 .25607 L
.20161 .28732 L
.17939 .31907 L
.16171 .35163 L
.1483 .38423 L
.13913 .41473 L
.13519 .43238 L
.13237 .4489 L
.13022 .46677 L
.12904 .48366 L
.12867 .50231 L
.1289 .51282 L
.12937 .52247 L
.13099 .54081 L
.13233 .55118 L
.13384 .56081 L
.13768 .5802 L
.14295 .60073 L
.15473 .63531 L
.17132 .67156 L
.18914 .70214 L
.21106 .73276 L
.23341 .7586 L
.26057 .78478 L
.31423 .82436 L
.34936 .84365 L
.38969 .86057 L
.40874 .86683 L
.42933 .87243 L
.44736 .87638 L
.467 .8797 L
.48599 .88195 L
.5035 .8832 L
.52027 .88367 L
.53796 .88339 L
.55735 .88216 L
.57533 .88015 L
.59493 .87698 L
.61568 .87249 L
.65722 .85978 L
.67994 .85055 L
.70036 .84076 L
.73552 .82012 L
.77146 .79315 L
.82545 .73684 L
.84983 .70153 L
.86897 .66604 L
.88484 .62707 L
.89572 .58939 L
.90024 .56718 L
Mistroke
.90323 .5468 L
.90442 .53541 L
.90534 .52305 L
.90585 .51133 L
.90601 .50053 L
.90555 .48083 L
.90423 .46242 L
.90181 .44228 L
.89807 .42079 L
.8929 .39846 L
.88683 .37754 L
.87244 .3392 L
.85573 .30501 L
.83454 .27039 L
.78822 .21367 L
.75835 .18578 L
.72791 .16226 L
.68933 .1381 L
.65125 .11941 L
.61425 .10547 L
.59481 .09967 L
.57345 .09443 L
.56113 .09193 L
.54972 .08996 L
.52712 .08698 L
.50647 .08534 L
.48454 .0847 L
.46313 .08518 L
.44018 .08691 L
.41865 .08969 L
.39912 .0932 L
.37652 .09849 L
.35226 .10567 L
.30942 .12247 L
.27168 .14216 L
.23942 .16326 L
.20702 .18927 L
.17514 .22092 L
.14872 .25336 L
.12743 .28544 L
.10903 .31976 L
.09464 .35377 L
.08786 .37352 L
.08162 .39535 L
.07733 .41378 L
.07357 .43432 L
.07066 .45674 L
.06957 .46909 L
.06889 .48069 L
.06845 .50149 L
Mistroke
.06912 .52391 L
.0708 .54466 L
.07378 .56724 L
.07771 .58843 L
.08231 .60795 L
.09346 .6442 L
.10885 .68174 L
.13174 .72459 L
.16178 .76796 L
.19248 .80309 L
.22883 .83659 L
.26474 .86325 L
.30709 .88828 L
.34783 .90689 L
.38743 .92051 L
.40981 .92643 L
.43391 .93144 L
.45468 .93466 L
.47777 .93706 L
.4907 .93788 L
.50258 .9383 L
.51564 .93839 L
.52938 .93807 L
.5525 .93657 L
.56555 .93518 L
.57766 .93353 L
.60101 .92939 L
.62283 .92433 L
.66286 .9119 L
.70441 .8943 L
.74718 .87048 L
.81508 .81741 L
.84504 .78579 L
.8742 .74767 L
.89564 .71277 L
.91496 .67314 L
.92948 .63406 L
.93947 .59719 L
.9441 .57364 L
.94729 .55123 L
.94917 .53098 L
.95016 .50899 L
.94999 .48489 L
.94941 .47276 L
.9484 .45946 L
.94563 .436 L
.94194 .41424 L
.93712 .39245 L
.93156 .37205 L
.91858 .33456 L
Mistroke
.90096 .29555 L
.87769 .25515 L
.81529 .17827 L
.77776 .14493 L
.73237 .1131 L
.69097 .09046 L
.64399 .07093 L
.62171 .06371 L
.59789 .05735 L
.57547 .05258 L
.55461 .04917 L
.53111 .04651 L
.51869 .04559 L
.50553 .04499 L
.48338 .04482 L
.45906 .04588 L
.43748 .04791 L
.41445 .05122 L
.39289 .05542 L
.37341 .06015 L
.32784 .07489 L
.28027 .0963 L
.23787 .12141 L
.20122 .14867 L
.16722 .17975 L
.13827 .21201 L
.09295 .27909 L
.07295 .32002 L
.05825 .35924 L
.05152 .38211 L
.04633 .40372 L
.04203 .42652 L
.03866 .45173 L
.03673 .47616 L
.03626 .48852 L
.03612 .50215 L
.03686 .52625 L
.03871 .54879 L
.04035 .56233 L
.04228 .57516 L
.04688 .5991 L
.05324 .62458 L
.06183 .65196 L
.08008 .69681 L
.10458 .74234 L
.16082 .81657 L
.19455 .84948 L
.23458 .88112 L
.27256 .90531 L
.31502 .92682 L
Mistroke
.35508 .94249 L
.37684 .94929 L
.40051 .95541 L
.42253 .95995 L
.44277 .96316 L
.46324 .96551 L
.48272 .9669 L
.50506 .9675 L
.52915 .96695 L
.55184 .9653 L
.57256 .96282 L
.59536 .95901 L
.62007 .95354 L
.66877 .93853 L
.71504 .91855 L
.76179 .89183 L
.83707 .83081 L
.86845 .79611 L
.89836 .75512 L
.92092 .71645 L
.94067 .67331 L
.95464 .63285 L
.96092 .60932 L
.96569 .58703 L
.9691 .56639 L
.97142 .5474 L
.97313 .52537 L
.97379 .5044 L
.97337 .47969 L
.97257 .46579 L
.97147 .45304 L
.96853 .42966 L
.96418 .40516 L
.95917 .38336 L
.95358 .36326 L
.93761 .31859 L
.91537 .27224 L
.89084 .23228 L
.85738 .1889 L
.8222 .15242 L
.75059 .09728 L
.70899 .0739 L
.66252 .05374 L
.64254 .04679 L
.62072 .04031 L
.60162 .03555 L
.58055 .03124 L
.55696 .02758 L
.53198 .025 L
.50876 .02378 L
Mistroke
.48715 .02366 L
.46154 .02478 L
.44867 .02587 L
.43456 .02746 L
.40975 .03131 L
.38678 .03607 L
.33601 .05093 L
.30835 .0617 L
.28373 .07302 L
.24109 .09692 L
.19772 .12777 L
.16321 .1582 L
.12869 .19554 L
.10159 .23155 L
.0763 .27311 L
.05433 .31959 L
.04613 .34117 L
.03836 .36523 L
.03264 .3865 L
.02761 .40951 L
.02354 .43406 L
.0209 .4571 L
.01939 .48021 L
.01898 .50211 L
.01947 .52177 L
.02092 .54307 L
.02377 .56763 L
.02749 .58994 L
.03308 .61546 L
.03967 .6394 L
.05438 .68094 L
.0747 .72456 L
.10184 .7698 L
.13602 .81448 L
.20971 .88382 L
.25554 .91474 L
.30873 .94208 L
.3342 .95239 L
.3617 .96171 L
.38587 .96842 L
.41213 .97421 L
.43795 .97845 L
.46165 .98109 L
.48558 .98256 L
.50828 .98286 L
.53467 .98188 L
.559 .97969 L
.58553 .97587 L
.61342 .97022 L
.65987 .95689 L
Mistroke
.70706 .93793 L
.74559 .91788 L
.78546 .89209 L
.82549 .85995 L
.8642 .82113 L
.9219 .7411 L
.94375 .69834 L
.95351 .67501 L
.96251 .64978 L
.96922 .62733 L
.97533 .6023 L
.97973 .57927 L
.98283 .55756 L
.98501 .53477 L
.98608 .51307 L
.98622 .49355 L
.98547 .4723 L
.9836 .4493 L
.98042 .42494 L
.97628 .40212 L
.97161 .38166 L
.96354 .35324 L
.95318 .32385 L
.93001 .27311 L
.89876 .22181 L
.85755 .17044 L
Mfstroke
.8 .5 m
.79976 .49018 L
.79912 .48133 L
.79789 .47124 L
.79625 .46184 L
.7922 .44545 L
.78622 .42822 L
.77778 .40997 L
.76681 .39155 L
.74224 .36117 L
.71096 .33379 L
.67697 .31219 L
.6354 .29338 L
.61049 .28518 L
.58694 .27924 L
.56265 .2748 L
.54889 .273 L
.53632 .2718 L
.52451 .27105 L
.51785 .27079 L
.51171 .27065 L
.50041 .27065 L
.48848 .27102 L
.48174 .27139 L
.4756 .27184 L
.46186 .27321 L
.44921 .27493 L
.43733 .27696 L
.4112 .28291 L
.38371 .2916 L
.36263 .30018 L
.34047 .31129 L
.32019 .32373 L
.29998 .33886 L
.28286 .35448 L
.26877 .37001 L
.25599 .38712 L
.24599 .40357 L
.23705 .42206 L
.23039 .44026 L
.22749 .45051 L
.2253 .46012 L
.22345 .4708 L
.22273 .47624 L
.22211 .48226 L
.22148 .49241 L
.22135 .50175 L
.22172 .51259 L
.22261 .52294 L
.22388 .53249 L
Mistroke
.22546 .54136 L
.23042 .56142 L
.23409 .57273 L
.23875 .58486 L
.24901 .60652 L
.27424 .64525 L
.29194 .66586 L
.31307 .68618 L
.33456 .70335 L
.35657 .71809 L
.37905 .73068 L
.40481 .7425 L
.42713 .75074 L
.45252 .75804 L
.46697 .76127 L
.48066 .76373 L
.49523 .76571 L
.50347 .76655 L
.51103 .76714 L
.52382 .76774 L
.53781 .76784 L
.5524 .7673 L
.56591 .76621 L
.57874 .76465 L
.59252 .76237 L
.61715 .75667 L
.64052 .74921 L
.66136 .74069 L
.70559 .71555 L
.72584 .69999 L
.74623 .68079 L
.76417 .65994 L
.78108 .63517 L
.79435 .61002 L
.80415 .58541 L
.8108 .5624 L
.81365 .54896 L
.8157 .53615 L
.81718 .52255 L
.81793 .50995 L
.81809 .49601 L
.81748 .48123 L
.81603 .46602 L
.81398 .45217 L
.81076 .43621 L
.80688 .4212 L
.79796 .39478 L
.78541 .36674 L
.76823 .33697 L
.74636 .3071 L
Mistroke
.72311 .28154 L
.69846 .25924 L
.67372 .24065 L
.64477 .22274 L
.61656 .20864 L
.58989 .19796 L
.55706 .18802 L
.53864 .18387 L
.52111 .18085 L
.50469 .17882 L
.48953 .17762 L
.47283 .17704 L
.45519 .17729 L
.43975 .17823 L
.42573 .17968 L
.40965 .18205 L
.39455 .18499 L
.36812 .19187 L
.34015 .20172 L
.31058 .21535 L
.28087 .23292 L
.23288 .27199 L
.21122 .29573 L
.1911 .32301 L
.17612 .34829 L
.16274 .3768 L
.15641 .39355 L
.15148 .4091 L
.14726 .4252 L
.14411 .44026 L
.14133 .45809 L
.14025 .46757 L
.13942 .47764 L
.13871 .49469 L
.1387 .50441 L
.13894 .51352 L
.13996 .52945 L
.14194 .54681 L
.14463 .56317 L
.14783 .57827 L
.15575 .60651 L
.1668 .63599 L
.18325 .66968 L
.20196 .69996 L
.24474 .75179 L
.27162 .77661 L
.29883 .79748 L
.3336 .8192 L
.3672 .8358 L
.40417 .84978 L
Mistroke
.44034 .85956 L
.46057 .86345 L
.47941 .86611 L
.4893 .86713 L
.50022 .86797 L
.51164 .86851 L
.52236 .86872 L
.54001 .86841 L
.55923 .86716 L
.57731 .8651 L
.59398 .86242 L
.62505 .85537 L
.65737 .84501 L
.69404 .82914 L
.72683 .81066 L
.78235 .76759 L
.80804 .74075 L
.82948 .7134 L
.85147 .67832 L
.86798 .64421 L
.87494 .62642 L
.88146 .60665 L
.88619 .58924 L
.89043 .56973 L
.89378 .54882 L
.89511 .53726 L
.89603 .52636 L
.89689 .50681 L
.89693 .49577 L
.89668 .48563 L
.89565 .4685 L
.89368 .4502 L
.89102 .43299 L
.88793 .41742 L
.87762 .37972 L
.86442 .34501 L
.84729 .31031 L
.8285 .27972 L
.80282 .24573 L
.77624 .21698 L
.71572 .16765 L
.67855 .14542 L
.64122 .12791 L
.60543 .11505 L
.57127 .10605 L
.55128 .10217 L
.53303 .0995 L
.51183 .09741 L
.49181 .09644 L
.47148 .09644 L
Mistroke
.44921 .09757 L
.43802 .0986 L
.42607 .10003 L
.40465 .1035 L
.38349 .10807 L
.36373 .11342 L
.32754 .12606 L
.28665 .14524 L
.25098 .16693 L
.21465 .19484 L
.17982 .22881 L
.15417 .26013 L
.13071 .29575 L
.11376 .32806 L
.09864 .36506 L
.09183 .3863 L
.08647 .40668 L
.08162 .43052 L
.07846 .45242 L
.07656 .4733 L
.07576 .49264 L
.07593 .51392 L
.0773 .53644 L
.07951 .55605 L
.08234 .57387 L
.08657 .59431 L
.09152 .61351 L
.10255 .64706 L
.11775 .68254 L
.13812 .71987 L
.16382 .75732 L
.21956 .81741 L
.25255 .84415 L
.29003 .86881 L
.32437 .887 L
.36276 .90306 L
.38507 .91051 L
.4057 .91626 L
.42694 .92108 L
.44673 .92459 L
.47001 .92754 L
.48232 .92859 L
.4954 .92933 L
.51741 .92969 L
.52992 .92941 L
.54162 .92882 L
.56188 .92705 L
.58387 .92404 L
.60447 .92018 L
.6234 .91572 L
Mistroke
.6585 .905 L
.69477 .89034 L
.73558 .86894 L
.77171 .8449 L
.83197 .79067 L
.8597 .7572 L
.88242 .72353 L
.90356 .68423 L
.92157 .63983 L
.92873 .61681 L
.93504 .59132 L
.93741 .57951 L
.93957 .5669 L
.94251 .54408 L
.94419 .52212 L
.94475 .50141 L
.94423 .47867 L
.94342 .46589 L
.94234 .45419 L
.93983 .43456 L
.93616 .41372 L
.92704 .37665 L
.91204 .33366 L
.89462 .29602 L
.87272 .25847 L
.84495 .22027 L
.7848 .15892 L
.74965 .13207 L
.70914 .10713 L
.66866 .08754 L
.63013 .07319 L
.60776 .0666 L
.5836 .06085 L
.56956 .05813 L
.55678 .05606 L
.54373 .05432 L
.5317 .05305 L
.50807 .0515 L
.49563 .05117 L
.48249 .0512 L
.46041 .0521 L
.43629 .05432 L
.42361 .056 L
.4099 .05824 L
.38521 .06338 L
.33989 .07667 L
.31492 .08627 L
.2891 .09807 L
.24483 .12322 L
.17392 .18001 L
Mistroke
.13917 .21839 L
.11081 .25782 L
.08693 .30003 L
.06895 .3414 L
.05409 .38869 L
.04807 .4158 L
.04595 .42787 L
.04407 .4407 L
.04155 .46468 L
.04036 .48688 L
.0403 .51082 L
.04082 .52441 L
.04169 .5371 L
.04415 .56001 L
.0474 .58079 L
.05236 .60459 L
.05821 .62691 L
.07202 .6674 L
.09078 .70892 L
.13451 .7783 L
.16391 .81322 L
.19456 .84331 L
.23417 .87508 L
.27399 .90067 L
.3131 .92073 L
.35682 .93804 L
.38248 .94593 L
.40711 .95203 L
.42947 .95636 L
.45394 .95982 L
.47802 .96196 L
.49175 .96262 L
.50462 .96287 L
.51816 .96275 L
.53054 .9623 L
.54481 .96137 L
.55832 .96008 L
.58204 .95686 L
.60387 .95278 L
.62758 .94712 L
.65246 .93973 L
.69602 .92299 L
.74095 .90007 L
.77828 .87591 L
.81499 .84664 L
.84546 .81708 L
.87562 .78158 L
.91943 .71243 L
.93953 .66777 L
.9482 .64341 L
Mistroke
.95591 .61705 L
.96134 .59371 L
.96374 .5812 L
.96593 .56766 L
.96882 .54376 L
.97039 .52121 L
.97087 .49907 L
.9702 .47486 L
.96815 .44964 L
.96502 .42631 L
.96101 .40452 L
.95648 .38491 L
.94327 .34169 L
.92262 .29294 L
.89882 .25026 L
.86776 .20645 L
.82967 .16417 L
.75509 .1042 L
.70778 .07713 L
.66101 .05684 L
.63744 .04877 L
.61194 .04155 L
.5896 .03645 L
.56523 .03216 L
.55014 .03015 L
.53623 .02872 L
.5229 .02775 L
.50882 .02712 L
.48434 .02702 L
.47047 .02753 L
.45757 .02836 L
.43217 .03103 L
.40832 .03481 L
.3871 .03922 L
.36432 .04511 L
.31447 .06237 L
.27041 .08313 L
.19943 .12982 L
.16317 .16182 L
.13232 .19503 L
.08053 .27015 L
.05808 .31634 L
.04203 .36054 L
.03516 .38523 L
.02992 .4088 L
.02624 .43018 L
.02336 .45348 L
.02154 .47908 L
.02114 .49201 L
.02112 .50621 L
Mistroke
.02211 .53133 L
.02423 .55473 L
.02754 .57819 L
.03175 .60024 L
.04241 .64098 L
.05786 .68365 L
.07919 .72822 L
.1052 .77069 L
.13887 .81421 L
.17627 .85269 L
.22115 .88928 L
.26664 .91833 L
.31098 .94038 L
.35529 .95712 L
.3802 .96443 L
.40349 .96998 L
.42797 .97452 L
.44095 .9764 L
.45474 .97801 L
.47799 .97982 L
.50365 .98052 L
.52647 .97999 L
.55094 .97822 L
.57392 .97541 L
.59479 .97188 L
.62037 .96624 L
.64378 .95979 L
.69543 .94085 L
.73891 .91935 L
.78257 .89177 L
.82038 .86198 L
.85766 .82571 L
.8871 .79054 L
.91439 .75055 L
.93548 .71216 L
.95449 .66805 L
.96788 .62644 L
.97259 .60763 L
.97691 .58668 L
.98085 .56137 L
.98243 .54743 L
.98355 .53432 L
.98465 .51084 L
.98455 .48552 L
.98396 .47209 L
.98289 .45745 L
.9813 .44219 L
.97938 .42807 L
.9749 .40288 L
.96866 .3763 L
Mistroke
.95185 .32469 L
.93079 .278 L
.90776 .23815 L
.87869 .19764 L
.81206 .12918 L
.77371 .09994 L
.72846 .07234 L
.68764 .05278 L
.64203 .03608 L
.61939 .02964 L
.59765 .02454 L
.57619 .02053 L
.55636 .01769 L
.5333 .01543 L
.50834 .01422 L
.4863 .01422 L
.46311 .01529 L
.43772 .01773 L
.41422 .02121 L
.38866 .02633 L
.36168 .03331 L
.30863 .05206 L
.26081 .07529 L
.22026 .10049 L
.1793 .13219 L
.11398 .20077 L
.08641 .23987 L
.06067 .28583 L
.04278 .327 L
.03457 .35037 L
.02787 .37293 L
.02265 .39411 L
.01804 .41746 L
.01484 .43886 L
.01273 .45884 L
.01122 .48513 L
.01099 .49839 L
.01116 .51294 L
.01253 .53867 L
.01503 .56259 L
.01712 .57703 L
.01949 .59065 L
.02498 .61596 L
.03238 .64286 L
.04216 .67158 L
.06275 .71871 L
.0899 .76613 L
.11752 .80448 L
.15128 .84264 L
.18724 .87579 L
Mistroke
.22296 .90291 L
.26167 .92703 L
.29955 .94616 L
.34298 .96336 L
.36854 .97134 L
.39211 .97736 L
.41721 .98244 L
.44112 .98602 L
.46652 .98853 L
.48089 .98936 L
.49415 .98975 L
.51995 .98949 L
.54439 .98798 L
.56624 .9856 L
.58991 .98189 L
.61533 .97656 L
.64204 .96942 L
.68888 .95286 L
.73449 .93127 L
.77514 .90678 L
.84393 .85102 L
.87908 .81301 L
.91157 .76912 L
.93558 .72846 L
.9568 .6826 L
.96665 .65583 L
.97425 .63101 L
.98062 .60538 L
.98527 .58143 L
.98733 .56806 L
.98918 .55326 L
.99058 .53834 L
.99156 .52246 L
.992 .50852 L
.99203 .4935 L
.99092 .46636 L
.9891 .44607 L
.98624 .42452 L
.98266 .40432 L
.97869 .38614 L
.96605 .34225 L
.95045 .30211 L
.91369 .23372 L
.88836 .19798 L
.86231 .16719 L
Mfstroke
.8 .8 m
.8271 .77441 L
.85331 .7448 L
.8926 .68639 L
.9112 .64805 L
.91876 .62861 L
.92479 .61038 L
.93357 .57568 L
.93687 .55715 L
.93936 .53736 L
.94078 .51795 L
.94121 .50015 L
.94066 .4796 L
.9391 .4601 L
.93678 .44224 L
.93387 .42576 L
.92984 .4078 L
.92459 .38886 L
.90898 .34657 L
.8898 .30834 L
.84305 .24248 L
.81509 .21321 L
.78111 .18404 L
.74501 .15888 L
.70347 .13581 L
.66233 .11811 L
.62329 .10544 L
.60409 .10056 L
.58295 .09616 L
.56279 .0929 L
.54402 .09066 L
.52244 .08901 L
.51027 .08852 L
.4991 .08835 L
.47853 .08872 L
.45692 .09009 L
.44546 .09121 L
.43326 .09273 L
.41142 .09626 L
.38574 .10181 L
.36275 .10809 L
.31783 .12424 L
.27158 .14688 L
.23083 .17292 L
.19624 .20066 L
.14295 .25794 L
.11824 .29396 L
.09924 .32892 L
.08482 .36285 L
.0785 .38125 L
Mistroke
.07278 .40114 L
.06828 .42052 L
.06505 .43824 L
.06262 .4562 L
.06109 .47319 L
.06024 .49306 L
.06046 .5149 L
.06103 .52591 L
.06198 .53768 L
.06458 .55886 L
.0683 .57986 L
.07285 .59957 L
.08406 .63591 L
.10164 .67743 L
.12195 .71413 L
.14849 .75213 L
.18119 .78935 L
.21168 .81753 L
.24664 .84411 L
.31539 .88295 L
.35659 .8994 L
.39625 .91112 L
.41953 .91626 L
.44087 .91989 L
.45278 .92147 L
.46571 .92284 L
.47796 .9238 L
.48925 .9244 L
.5081 .92478 L
.52832 .92435 L
.54736 .92313 L
.56468 .92133 L
.58486 .9184 L
.60664 .91419 L
.64558 .90387 L
.68503 .88948 L
.72519 .87025 L
.79148 .82615 L
.82266 .79844 L
.85236 .76619 L
.89647 .70172 L
.91558 .66264 L
.92961 .62465 L
.93597 .60225 L
.94066 .58159 L
.9428 .57005 L
.94475 .55746 L
.94614 .5464 L
.94731 .53446 L
.94848 .51465 L
Mistroke
.94871 .49604 L
.94792 .4739 L
.94616 .45368 L
.9433 .43277 L
.93899 .41011 L
.93377 .38891 L
.92795 .36945 L
.89841 .29997 L
.87664 .26345 L
.85385 .23216 L
.79225 .16881 L
.75664 .14157 L
.71455 .11574 L
.67644 .09726 L
.63381 .08134 L
.6126 .07512 L
.59226 .07016 L
.57238 .06623 L
.55359 .06332 L
.5316 .0609 L
.50723 .05944 L
.48345 .05924 L
.47008 .05966 L
.45784 .06038 L
.43728 .06232 L
.41493 .06548 L
.3918 .06994 L
.37054 .07513 L
.32234 .09102 L
.28041 .10996 L
.23477 .13691 L
.19498 .16705 L
.1359 .22788 L
.10795 .26708 L
.08586 .30628 L
.0671 .34983 L
.0542 .39119 L
.04886 .41455 L
.04656 .42699 L
.04451 .4403 L
.04293 .45317 L
.04182 .46485 L
.04058 .48773 L
.0405 .50905 L
.04154 .53153 L
.04335 .55068 L
.04629 .57158 L
.05058 .59398 L
.05646 .6177 L
.07034 .65962 L
Mistroke
.08856 .70052 L
.10951 .73748 L
.15783 .80108 L
.18953 .8328 L
.22199 .85971 L
.26366 .88783 L
.30434 .90958 L
.34901 .928 L
.39308 .94123 L
.41769 .94665 L
.4408 .95051 L
.45417 .95221 L
.46634 .95343 L
.48042 .95444 L
.49371 .95501 L
.51414 .95516 L
.53656 .95431 L
.55989 .95228 L
.58155 .94935 L
.60169 .9457 L
.61989 .94161 L
.66011 .9298 L
.70185 .9132 L
.74517 .89068 L
.8168 .83861 L
.84846 .80769 L
.87904 .7711 L
.90223 .73705 L
.92394 .69756 L
.94328 .65149 L
.95164 .62553 L
.95801 .60094 L
.96272 .57755 L
.96592 .55608 L
.96834 .53112 L
.96935 .50744 L
.96914 .48435 L
.96849 .47122 L
.96755 .45896 L
.96463 .43432 L
.96241 .42055 L
.96001 .40802 L
.95487 .3859 L
.94803 .36208 L
.93228 .3197 L
.90873 .2724 L
.87785 .22516 L
.80864 .15051 L
.76854 .11926 L
.72276 .09105 L
Mistroke
.68131 .07113 L
.63383 .05393 L
.60631 .04646 L
.58089 .04108 L
.56671 .0387 L
.55123 .03659 L
.53655 .03506 L
.52294 .03405 L
.49865 .03321 L
.48482 .03328 L
.47185 .0337 L
.45824 .03453 L
.44581 .03563 L
.43219 .03721 L
.41792 .03929 L
.39352 .04388 L
.37161 .04914 L
.32354 .06465 L
.28075 .08349 L
.2423 .10504 L
.16454 .16574 L
.12692 .2067 L
.09681 .24813 L
.07341 .28876 L
.0551 .32929 L
.04669 .35235 L
.03892 .37794 L
.0336 .39955 L
.02892 .4237 L
.02571 .44648 L
.02372 .46803 L
.02271 .49086 L
.02288 .51554 L
.02411 .53721 L
.02649 .55998 L
.02941 .57932 L
.03353 .60036 L
.04017 .62686 L
.04786 .65154 L
.06586 .69653 L
.09033 .74272 L
.12251 .78957 L
.1551 .82723 L
.19378 .86329 L
.27233 .91667 L
.31764 .93837 L
.36261 .95456 L
.40418 .96528 L
.42808 .9697 L
.45045 .97273 L
Mistroke
.46309 .97398 L
.4768 .97495 L
.5017 .97573 L
.52595 .97526 L
.54821 .97376 L
.57225 .97098 L
.58582 .96886 L
.59843 .96654 L
.62347 .96089 L
.65031 .95324 L
.69471 .93676 L
.73505 .9172 L
.80494 .87081 L
.84054 .83935 L
.87471 .80225 L
.92547 .72738 L
.9461 .68468 L
.9631 .63773 L
.97363 .5964 L
.97794 .5726 L
.98085 .55029 L
.98291 .5241 L
.98352 .49931 L
.98297 .47703 L
.98119 .45294 L
.97786 .42679 L
.97563 .41368 L
.97276 .39933 L
.95962 .35099 L
.94249 .30647 L
.92302 .26742 L
.89817 .22748 L
.86677 .18688 L
.83411 .15253 L
.80094 .12364 L
.72842 .0759 L
.6798 .05311 L
.63314 .03698 L
.60811 .03042 L
.58032 .02477 L
.56619 .02253 L
.551 .0206 L
.53661 .0192 L
.52348 .01831 L
.49763 .01757 L
.47374 .01811 L
.44759 .02005 L
.43444 .02155 L
.42 .02363 L
.39601 .02806 L
Mistroke
.37047 .03416 L
.32527 .04865 L
.28105 .0678 L
.2352 .09359 L
.19732 .12033 L
.15994 .1527 L
.12644 .1883 L
.0993 .22338 L
.0753 .26117 L
.05614 .29835 L
.0386 .34181 L
.03046 .36749 L
.0243 .39128 L
.01916 .41653 L
.01554 .4407 L
.01305 .46638 L
.01225 .48094 L
.01191 .49445 L
.01216 .51661 L
.01333 .53741 L
.01564 .56015 L
.01934 .58454 L
.02423 .60851 L
.03069 .63347 L
.04552 .67715 L
.06645 .72315 L
.09399 .76968 L
.15602 .84486 L
.20094 .88426 L
.24751 .91624 L
.29224 .94025 L
.34329 .96093 L
.38954 .97424 L
.41601 .97971 L
.44045 .98344 L
.46328 .98579 L
.48827 .98715 L
.51191 .98726 L
.53382 .98635 L
.54717 .98531 L
.56156 .98378 L
.58751 .97994 L
.61253 .97487 L
.63527 .96907 L
.68581 .95186 L
.73678 .92786 L
.78045 .90108 L
.82382 .86751 L
.89147 .79553 L
.92511 .74537 L
Mistroke
.951 .69439 L
.969 .6463 L
.9769 .61838 L
.9827 .59218 L
.98668 .56838 L
.98959 .54316 L
.99103 .52152 L
.9915 .49782 L
.99071 .4722 L
.98969 .45788 L
.98839 .44492 L
.98486 .41978 L
.98035 .39627 L
.96837 .35156 L
.95363 .31151 L
.9335 .26918 L
.90788 .22669 L
.8777 .1865 L
.84089 .147 L
.76431 .08671 L
.71223 .05774 L
.68539 .04583 L
.65992 .03623 L
.61113 .02211 L
.58486 .0167 L
.57027 .01433 L
.55663 .01252 L
.53096 .01014 L
.51733 .00943 L
.50273 .00908 L
.4874 .00918 L
.47292 .00971 L
.44587 .01184 L
.42068 .01519 L
.39761 .01942 L
.37256 .02531 L
.34636 .03298 L
.29376 .05337 L
.24691 .07781 L
.19885 .11022 L
.15181 .15112 L
.11606 .19049 L
.08214 .23761 L
.05543 .2855 L
.03557 .33238 L
.02734 .357 L
.02079 .38058 L
.01587 .40226 L
.01174 .42539 L
.0085 .45084 L
Mistroke
.0067 .47438 L
.00603 .49979 L
.00624 .51421 L
.00682 .52768 L
.00897 .55357 L
.01057 .5666 L
.01275 .58092 L
.01762 .60604 L
.02338 .62937 L
.04045 .68066 L
.06505 .73352 L
.09209 .77789 L
.12545 .82129 L
.15802 .85565 L
.19629 .88876 L
.23704 .91734 L
.27639 .93966 L
.31834 .95859 L
.35843 .97253 L
.38119 .97879 L
.40655 .98441 L
.4323 .98872 L
.44647 .9905 L
.45978 .9918 L
.48431 .99324 L
.50677 .9935 L
.53268 .99254 L
.55719 .99037 L
.58283 .98678 L
.61027 .98141 L
.63586 .97492 L
.65904 .96776 L
.70195 .9511 L
.74533 .92928 L
.82763 .87084 L
.86847 .83062 L
.9021 .78909 L
.92906 .74761 L
.95061 .70607 L
.96653 .66718 L
.98001 .62356 L
.98538 .60055 L
.99001 .57491 L
.9934 .54791 L
.99522 .52245 L
.99573 .49866 L
.99519 .47687 L
.99349 .453 L
.99046 .42802 L
.98605 .4027 L
Mistroke
.9798 .37558 L
.9646 .32745 L
.94517 .2823 L
.92338 .2426 L
.86099 .16081 L
.82345 .12492 L
.77812 .09024 L
.73635 .06483 L
.69461 .04463 L
.67081 .03518 L
.64439 .02629 L
.62206 .02004 L
.59708 .01435 L
.57349 .01019 L
.55115 .00733 L
.52746 .00541 L
.50182 .00461 L
.47928 .00499 L
.45557 .00651 L
.4354 .0087 L
.41344 .01203 L
.38663 .01749 L
.36219 .02382 L
.30833 .04266 L
.26293 .0643 L
.21747 .09212 L
.14672 .15122 L
.11179 .19036 L
.083 .23017 L
.05511 .27892 L
.03388 .32788 L
.01942 .37356 L
.01321 .39996 L
.00876 .42474 L
.0068 .43878 L
.00514 .45402 L
.00401 .46846 L
.00334 .48176 L
.00305 .50702 L
.00415 .53368 L
.00529 .5475 L
.00693 .56226 L
.01102 .58876 L
.01774 .61992 L
.02559 .6479 L
.04196 .6926 L
.0649 .73986 L
.09406 .78636 L
.12594 .82683 L
.19262 .8901 L
Mistroke
.2349 .91994 L
.27619 .94331 L
.32396 .96436 L
.37015 .97934 L
.3973 .9859 L
.42224 .99053 L
.43616 .99255 L
.45129 .99429 L
.46562 .99551 L
.47886 .99626 L
.50541 .99671 L
.53023 .99586 L
.55738 .9935 L
.57255 .99152 L
.58634 .98931 L
.61382 .98371 L
.64334 .97586 L
.69561 .95698 L
.74362 .93342 L
.7923 .90236 L
.83196 .87045 L
.87002 .8326 L
.90076 .79498 L
.93005 .75054 L
.95226 .70792 L
.96939 .66582 L
.97784 .63969 L
.98537 .61083 L
.99069 .58426 L
.99432 .55948 L
.99683 .53256 L
.9976 .51719 L
.99789 .50278 L
.99774 .48761 L
.9972 .47374 L
.99609 .45776 L
.99457 .4426 L
.991 .41752 L
.98579 .39101 L
.97282 .34416 L
.96264 .31618 L
.95152 .29041 L
.92693 .24407 L
.86708 .16393 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[16]:=",
  ImageSize->{216, 216},
  ImageMargins->{{0, 0}, {0, 0.75}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>00013R000`400?l00000o`00003oQ_ooool0
0ol0003oooooooooo`25ooooo`00Q_ooool00ol0003oooooooooo`25ooooo`00N?oooolPo`3o07Ko
oooo001booooo`Ko0?l00ooooolHo`3o00Gooooo1_l0o`1`ooooo`00K?ooool6o`3o00;ooooo1ol0
o`04ooooo`ko0?l01_ooool9o`3o00;ooooo1Ol0o`1[ooooo`00I_ooool6o`3o00;ooooo:ol0o`03
ooooo`Ko0?l000Coooooo`3o0?l0o`3o0?l0J?ooool006?ooooo0ol0o`000ooooooo0?l0o`3o000C
o`3o00[ooooo00?o0000ooooooooool01_ooool8o`3o00;ooooo1Ol0o`04ooooo`So0?l0I?ooool0
063ooooo1ol0o`03ooooo`So0?l01?oooolMo`3o00Cooooo3Ol0o`03ooooo`Ko0?l0HOooool005go
oooo1Ol0o`03ooooo`So0?l01?ooool5o`3o00;ooooo8_l0o`05ooooo`?o0?l00_ooool5o`3o0003
ooooool0o`3o0?l000Co0?l0G_ooool005[ooooo1Ol0o`000ooooooo0?l0o`3o0006o`3o00?ooooo
3Ol0o`08ooooo`[o0?l02Oooool=o`3o00;ooooo1_l0o`001Ooooooo0?l0o`3o0?l0o`3ooooo00Ko
0?l0Foooool005Oooooo1Ol0o`001?oooooo0?l0o`3o0?l0o`02ooooo`?o0?l000?oooooo`3o0?l0
o`002Ol0o`05ooooo`[o0?l01_ooool01?l0003oooooooooooooool=o`3o00Gooooo2Ol0o`03oooo
o`Ko0?l00_ooool6o`3o05Sooooo001Dooooo`Go0?l00_ooool2o`3o00;ooooo0ol0o`001Ooooooo
0?l0o`3o0?l0o`3ooooo00Co0?l00_ooool9o`3o013ooooo00?o0000ooooooooool03_ooool4o`3o
00Kooooo0ol0o`000ooooooo0?l0o`3o0002o`3o00?ooooo1Ol0o`02ooooo`Go0?l0E_ooool0057o
oooo0ol0o`000ooooooo0?l0o`3o0002ooooo`;o0?l000?oooooo`3o0?l0o`001Ol0o`001Ooooooo
0?l0o`3o0?l0o`3ooooo00Go0?l06Oooool00ol0003oooooooooo`0Booooo`Ko0?l00oooool3o`3o
00;ooooo0ol0o`03ooooo`Co0?l00oooool4o`3o05Cooooo001?ooooo`;o0?l000Goooooo`3o0?l0
o`3o0?l0ooooo`09o`3o0003ooooool0o`3o0?l000;o0?l000Coooooo`3o0?l0o`3o0?l02_oooolQ
o`3o00kooooo1Ol0o`001?oooooo0?l0o`3o0?l0o`02ooooo`?o0?l00_ooool4o`3o00?ooooo1?l0
o`1Booooo`00COooool2o`3o0003ooooool0o`3o0?l000;ooooo2?l0o`001?oooooo0?l0o`3o0?l0
o`02ooooo`?o0?l01oooool6o`3o00cooooo3ol0o`06ooooo`Ko0?l03Oooool3o`3o0003ooooool0
o`3o0?l000;o0?l000Goooooo`3o0?l0o`3o0?l0ooooo`05o`3o00;ooooo1Ol0o`1?ooooo`00Booo
ool2o`3o0003ooooool0o`3o0?l000;ooooo2ol0o`02ooooo`?o0?l01_ooool4o`3o00Oooooo2ol0
o`08ooooo`03o`000?oooooooooo00Cooooo2?l0o`04ooooo`Go0?l02oooool3o`3o00;ooooo0ol0
o`000ooooooo0?l0o`3o0002ooooo`Co0?l00oooool4o`3o04gooooo0019ooooo`;o0?l000?ooooo
o`3o0?l0o`000_ooool9o`3o00?ooooo0ol0o`06ooooo`?o0?l01?ooool7o`3o00gooooo3Ol0o`08
ooooo`Oo0?l00_ooool5o`3o00Wooooo0ol0o`02ooooo`;o0?l000Goooooo`3o0?l0o`3o0?l0oooo
o`04o`3o00?ooooo1?l0o`1;ooooo`00Aoooool2o`3o0003ooooool0o`3o0?l000;ooooo2?l0o`03
ooooo`?o0?l01oooool2o`3o00Cooooo0ol0o`06ooooo`ko0?l01_ooool00ol0003oooooooooo`04
ooooo`Ko0?l02Oooool5o`3o00;ooooo0ol0o`09ooooo`?o0?l000Goooooo`3o0?l0o`3o0?l0oooo
o`02o`3o0003ooooool0o`3o0?l000?o0?l00_ooool5o`3o04Sooooo0015ooooo`Go0?l000?ooooo
o`3o0?l0o`001_l0o`03ooooo`?o0?l01oooool3o`3o00;ooooo1?l0o`03ooooo`Ko0?l05?ooool0
0ol0003oooooooooo`0:ooooo`[o0?l01?ooool9o`3o00Sooooo0_l0o`02ooooo`Go0?l000?ooooo
o`3o0?l0o`000ol0o`02ooooo`03o`3o0?oooooooooo00;o0?l0A_ooool004?ooooo1?l0o`02oooo
o`?o0?l000?oooooo`3o0?l0o`000_l0o`02ooooo`?o0?l01oooool3o`3o0003ooooool0o`3o0?l0
00;o0?l00oooool4o`3o01[ooooo00?o0000ooooooooool05?ooool4o`3o00Gooooo0ol0o`001?oo
oooo0?l0o`3o0?l0o`07ooooo`?o0?l00_ooool5o`3o0003ooooool0o`3o0?l000;o0?l000?ooooo
o`3o0?l0o`000_ooool00ol0o`3oooooooooo`13ooooo`00@_ooool3o`3o00;ooooo0ol0o`000ooo
oooo0?l0o`3o0002o`3o00;ooooo0_l0o`07ooooo`Oo0?l01?ooool3o`3o01kooooo00?o0000oooo
ooooool06?ooool3o`3o00Gooooo0_l0o`02ooooo`;o0?l02?ooool2o`3o00;ooooo1Ol0o`000ooo
oooo0?l0o`3o0002o`3o0004ooooool0o`3o0?l0ooooo`;o0?l0@oooool0043ooooo0ol0o`02oooo
o`?o0?l000?oooooo`3o0?l0o`000_l0o`02ooooo`;o0?l01_ooool6o`3o00Cooooo1?l0o`0Qoooo
o`03o`000?oooooooooo01_ooooo1?l0o`03ooooo`?o0?l000Coooooo`3o0?l0o`3o0?l01oooool2
o`3o00?ooooo0ol0o`02ooooo`Co0?l000Coooooo`3o0?l0o`3ooooo0_l0o`11ooooo`00?_ooool3
o`3o00?ooooo0ol0o`001Ooooooo0?l0o`3o0?l0o`3ooooo00?o0?l01Oooool6o`3o00Cooooo0ol0
o`0Uooooo`03o`000?oooooooooo01oooooo1?l0o`02ooooo`;o0?l00_ooool2o`3o00Oooooo0ol0
o`02ooooo`?o0?l00_ooool01_l0o`3oooooo`3o0?l0o`3oooooo`3o00;ooooo00?o0?l0oooooooo
ool0?_ooool003gooooo0ol0o`02ooooo`?o0?l000Goooooo`3o0?l0o`3o0?l0ooooo`02o`3o00Go
oooo0ol0o`000ooooooo0?l0o`3o0004ooooo`?o0?l06ooooolCo`3o023ooooo0_l0o`02ooooo`?o
0?l000?oooooo`3o0?l0o`002?ooool2o`3o0003ooooool0o`3o0?l000;o0?l000Coooooo`3o0?l0
o`3ooooo1?l0o`000ooooooo0?l0o`3o000nooooo`00>oooool3o`3o00;ooooo0ol0o`001Ooooooo
0?l0o`3o0?l0o`3ooooo00;o0?l01Oooool2o`3o00;ooooo0_l0o`03ooooo`?o0?l06?ooool6o`3o
00Cooooo5?l0o`0Mooooo`?o0?l00_ooool2o`3o0004ooooool0o`3o0?l0o`3o00Oooooo0_l0o`00
1?oooooo0?l0o`3o0?l0o`02ooooo`05o`3o0?ooooooooooo`3o0?ooool00_l0o`000ooooooo0?l0
ooooo`0looooo`00>Oooool4o`3o00;ooooo0ol0o`001_oooooo0?l0o`3o0?l0o`3oooooo`3o00Co
oooo0ol0o`001?oooooo0?l0o`3o0?l0o`02ooooo`?o0?l05_ooool?o`3o0004ooooool0003o0000
oa0@40Gooooo00?o0000ooooooooool01oooool;o`3o01Kooooo0_l0o`02ooooo`;o0?l00_ooool2
o`3o00Oooooo0_l0o`001Ooooooo0?l0o`3o0?l0o`3ooooo00;o0?l000Koooooo`3o0?l0o`3ooooo
o`3o0?ooool2o`3o03_ooooo000hooooo`03o`3o0?oooooo0?l000;ooooo0ol0o`001Ooooooo0?l0
o`3o0?l0o`3ooooo00;o0?l00oooool2o`3o00;ooooo0_l0o`03ooooo`;o0?l04oooool9o`3o00[o
oooo3Ol0o`0Aooooo`Ko0?l05?ooool2o`3o00;ooooo0ol0o`000ooooooo0?l0o`3o0007ooooo`03
o`3o0?oooooo0?l000;o0?l00_ooool00ol0o`3oooooooooo`03o`3o00;ooooo00?o0?l0oooooooo
ool0>?ooool003Oooooo00?o0?l0ooooool0o`000_ooool2o`3o0005ooooool0o`3o0?l0o`3o0?oo
ool00_l0o`03ooooo`;o0?l00_ooool2o`3o00;ooooo0ol0o`0@ooooo`Go0?l000Coooooo`3o0?l0
o`3o0?l00oooool<o`3o0003ooooool0003o000000?o00001Oooool2o`0000_o0?l02oooool4o`3o
01?ooooo0_l0o`03ooooo`;o0?l000?oooooo`3o0?l0o`001_ooool2o`3o0005ooooool0o`3o0?l0
o`3o0?ooool00_l0o`02ooooo`?o0?l000?oooooo`3o0?ooool0>?ooool003Kooooo0ol0o`001Ooo
oooo0?l0o`3o0?l0o`3ooooo00?o0?l000?oooooo`3o0?ooool00oooool00ol0o`3oooooooooo`02
o`3o00;ooooo0_l0o`0@ooooo`?o0?l00oooool3o`3o00;ooooo1?l0o`0=ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo00?o0000ooooooooool02_ooool5o`3o00[ooooo1?l0o`0Aooooo`;o0?l00ooo
ool2o`3o0003ooooool0o`3o0?l000Kooooo00?o0?l0ooooooooool00_l0o`02ooooo`;o0?l00_oo
ool2o`3o0003ooooool0o`3o0?l003Oooooo000eooooo`;o0?l00_ooool2o`3o00;ooooo0_l0o`00
0ooooooo0?l0o`3o0003ooooo`;o0?l00_ooool00ol0o`3oooooooooo`02o`3o00oooooo0ol0o`03
ooooo`?o0?l00_ooool3o`3o017ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003ooooooooo
o`0?ooooo`Co0?l02Oooool5o`3o00oooooo0ol0o`02ooooo`;o0?l000?oooooo`3o0?l0o`001Ooo
ool2o`3o0004ooooool0o`3o0?l0o`3o00;ooooo00?o0?l0ooooooooool00_l0o`02ooooo`03o`3o
0?oooooooooo03Cooooo000cooooo`?o0?l00_ooool2o`3o0006ooooool0o`3o0?l0o`3o0?oooooo
0?l00oooool2o`3o00;ooooo0_l0o`000ooooooo0?l0o`3o000>ooooo`?o0?l00oooool3o`3o0003
ooooool0o`3o0?l000;o0?l05Oooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo01?o
oooo1Ol0o`06ooooo`Oo0?l03_ooool2o`3o00;ooooo00?o0?l0ooooooooool00_l0o`05ooooo`03
o`3o0?oooooooooo00;o0?l00_ooool2o`3o0006ooooool0o`3o0?l0o`3o0?oooooo0?l0=Oooool0
03;ooooo0_l0o`02ooooo`?o0?l000?oooooo`3o0?l0o`000_ooool01Ol0o`3ooooooooooooooooo
0?l000;ooooo0_l0o`000ooooooo0?l0o`3o000=ooooo`?o0?l00oooool7o`3o01Wooooo00?ok^k^
odA4A?l000001_ooool00ol0003oooooooooo`0Hooooo`?o0?l01_ooool2o`3o00;ooooo0ol0o`0=
ooooo`;o0?l000?oooooo`3o0?l0o`000_ooool2o`3o00Cooooo0_l0o`000ooooooo0?l0o`3o0003
ooooo`03o`3o0?oooooo0?l000;o0?l000?oooooo`3o0?l0o`00<oooool0037ooooo0_l0o`02oooo
o`;o0?l000Goooooo`3o0?l0o`3o0?l0ooooo`02o`3o00;ooooo0_l0o`02ooooo`04o`3o0?oooooo
ooooo`3o00cooooo0ol0o`03ooooo`Ko0?l07_ooool00omgMgOo0000ooooo`05ooooo`03o`000?oo
oooooooo01_ooooo0ol0o`05ooooo`?o0?l00_ooool3o`3o00cooooo0_l0o`000ooooooo0?l0o`3o
0002ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooool0o`000_l0o`02ooooo`;o0?l000?o
ooooo`3o0?l0o`000_ooool00ol0o`3oooooooooo`0`ooooo`00<?ooool2o`3o0005ooooool0o`3o
0?l0o`3o0?ooool00_l0o`02ooooo`03o`3o0?oooooooooo00;o0?l00_ooool2o`3o0003ooooool0
o`3o0?l000_ooooo0_l0o`03ooooo`Ko0?l0:Oooool00ol0003oooooooooo`0Nooooo`;o0?l01_oo
ool2o`3o00?ooooo0_l0o`0<ooooo`04o`3o0?ooooooooooo`3o00;ooooo0_l0o`04ooooo`Go0?l0
0oooool01?l0o`3oooooo`3o0?l0o`02ooooo`03o`3o0?oooooooooo02oooooo000_ooooo`;o0?l0
00?oooooo`3o0?l0o`000_ooool01Ol0o`3ooooooooooooooooo0?l000;ooooo00?o0?l0oooooooo
ool00_l0o`000ooooooo0?l0o`3o000;ooooo`;o0?l00_ooool6o`3o02cooooo00?o0000oooooooo
ool08?ooool3o`3o00Gooooo0_l0o`03ooooo`?o0?l02_ooool2o`3o0003ooooool0o`3o0?l000;o
oooo00?o0?l0ooooooooool00oooool00ol0o`3oooooo`3o0002o`3o00;ooooo1Ol0o`000ooooooo
0?l0ooooo`0_ooooo`00;_ooool2o`3o0004ooooool0o`3o0?l0ooooo`;o0?l00_ooool2o`3o00;o
oooo00Co0?l0oooooooooooo0?l00_ooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo
00;o0?l000?oooooo`3o0?l0o`00;oooool00ol0003oooooooooo`0Sooooo`;o0?l01Oooool2o`3o
00Cooooo0_l0o`0:ooooo`;o0?l000Coooooo`3o0?oooooooooo0_l0o`04ooooo`05o`3o0?oooooo
0?l0ooooool0o`000oooool2o`3o0004ooooool0o`3oooooo`3o02oooooo000/ooooo`;o0?l00_oo
ool2o`3o0003ooooool0o`3ooooo00;ooooo00?o0?l0ooooooooool00_l0o`02ooooo`04o`3o0?oo
oooo0?l0o`3o00_ooooo0_l0o`001?oooooo0?l0o`3o0?ooool2o`3o037ooooo00?o0000oooooooo
ool09Oooool2o`3o00Gooooo0_l0o`04ooooo`;o0?l02_ooool01?l0o`3oooooo`3o0?l0o`02oooo
o`03o`3o0?oooooooooo00;ooooo0ol0o`000ooooooo0?l0o`3o0002ooooo`06o`3o0?oooooooooo
o`3o0?oooooo0?l0;_ooool002_ooooo0_l0o`03ooooo`03o`3o0?oooooo0?l000?ooooo00Co0?l0
oooooooooooo0?l00oooool3o`3o00_ooooo0_l0o`000ooooooo0?l0o`3o0002ooooo`03o`3o0?oo
oooooooo037ooooo00?o0000ooooooooool09oooool2o`3o00Gooooo0_l0o`04ooooo`;o0?l02Ooo
ool2o`3o0004ooooool0o`3oooooooooo`;o0?l01?ooool3o`3o0005ooooool0o`3oooooooooool0
o`000_ooool3o`3o02gooooo000Zooooo`;o0?l00oooool00ol0o`3oooooo`3o0003ooooo`04o`3o
0?ooooooooooo`3o00;ooooo0ol0o`0<ooooo`04o`3o0?oooooo0?l0o`3o00;ooooo0_l0o`0doooo
o`03o`000?oooooooooo02Wooooo0_l0o`05ooooo`;o0?l01?ooool2o`3o00Wooooo00Co0?l0oooo
ool0o`3o0?l00_ooool00ol0o`3oooooooooo`02ooooo`?o0?l000Goooooo`3o0?ooooooooooo`3o
0003ooooo`;o0?l0;?ooool002Wooooo0_l0o`03ooooo`?o0?l00_ooool2o`3o00;ooooo00Ko0?l0
oooooooooooo0?l0ooooool0o`0;ooooo`Co0?l00_ooool2o`3o03Kooooo00?o0000ooooooooool0
:oooool2o`3o00Gooooo0_l0o`04ooooo`;o0?l02?ooool2o`3o0004ooooool0o`3oooooooooo`;o
0?l01?ooool2o`3o0005ooooool0o`3o0?l0ooooool0o`000oooool2o`3o02_ooooo000Xooooo`;o
0?l00oooool3o`3o00;ooooo00?o0?l0ooooooooool00_l0o`02ooooo`?o0?l02_ooool4o`3o00;o
oooo0_l0o`0hooooo`03o`000?oooooooooo02gooooo0_l0o`05ooooo`03o`3o0?oooooooooo00?o
oooo00?o0?l0ooooooooool01oooool00ol0o`3oooooo`3o0003ooooo`03o`3o0?oooooooooo00;o
oooo0_l0o`02ooooo`03o`3o0?oooooo0?l000?ooooo0_l0o`0Zooooo`009oooool2o`3o00?ooooo
0ol0o`02ooooo`04o`3o0?ooooooooooo`3o00;ooooo0ol0o`0:ooooo`;o0?l000Coooooo`3o0?oo
oooooooo0_l0o`0jooooo`;o0000<?ooool2o`3o00Cooooo0_l0o`04ooooo`;o0?l02?ooool4o`3o
00;ooooo00?o0?l0ooooooooool00_ooool3o`3o0004ooooool0o`3oooooo`3o00;ooooo00?o0?l0
ooooool0o`00:Oooool002Oooooo0_l0o`02ooooo`?o0?l000?oooooo`3o0?l0o`000_ooool00ol0
o`3oooooooooo`03o`3o00[ooooo00Go0?l0ooooool0o`3o0?l0ooooo`02o`3o03cooooo00?o0000
ooooooooool0<Oooool00ol0o`3oooooooooo`03ooooo`;o0?l01?ooool2o`3o00Sooooo00?o0?l0
ooooool0o`000_ooool01Ol0o`3ooooooooooooooooo0?l000;ooooo0_l0o`02ooooo`06o`3o0?oo
ooooooooo`3o0?oooooo0?l0:?ooool002Kooooo0_l0o`02ooooo`?o0?l000?oooooo`3o0?ooool0
0_ooool00ol0o`3oooooooooo`02o`3o00[ooooo1?l0o`000ooooooo0?l0o`3o000`ooooo`[o0?l0
1?ooool00ol0003oooooooooo`0booooo`;o0?l01Oooool00ol0o`3oooooooooo`03ooooo`;o0?l0
1oooool00ol0o`3oooooo`3o0002ooooo`05o`3o0?ooooooooooooooool0o`000_ooool2o`3o00;o
oooo00Ko0?l0oooooooooooo0?l0ooooool0o`0Wooooo`009Oooool2o`3o00;ooooo00Go0?l0oooo
ool0o`3oooooo`3o0003ooooo`03o`3o0?oooooooooo00;o0?l02Oooool2o`3o0003ooooool0o`3o
oooo00;o0?l0:Oooool9o`3o00[ooooo3?l0o`0_ooooo`;o0?l01?ooool2o`3o00Gooooo00?o0?l0
ooooooooool01Oooool2o`3o00?ooooo00Go0?l0ooooooooooooooooo`3o0002ooooo`;o0?l00_oo
ool01_l0o`3oooooooooool0o`3oooooo`3o02Kooooo000Tooooo`;o0?l00_ooool00ol0o`3ooooo
o`3o0002o`3o00?ooooo00?o0?l0ooooool0o`000_l0o`09ooooo`03o`3o0?oooooo0?l000?o0?l0
9_ooool5o`3o01Oooooo00?o0000ooooooooool01Oooool4o`3o02gooooo00?o0?l0ooooooooool0
0oooool00ol0o`3oooooooooo`03ooooo`;o0?l01oooool01Ol0o`3ooooooooooooooooo0?l000?o
oooo00?o0?l0ooooooooool00_l0o`02ooooo`03o`3o0?oooooooooo00;o0?l000?oooooo`3o0?oo
ool08oooool002?ooooo0_l0o`02ooooo`06o`3o0?oooooo0?l0o`3o0?oooooo0?l00_ooool00ol0
o`3oooooo`3o0002ooooo`03o`3o0?oooooooooo00Kooooo00Go0?l0ooooool0o`3oooooo`3o000S
ooooo`Go0?l07?ooool00ol0003oooooooooo`09ooooo`Go0?l04?oooolBo`3o00Oooooo0_l0o`04
ooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooooooool01Oooool01Ol0o`3ooooooooooooo
oooo0?l000?ooooo00Go0?l0ooooool0o`3oooooo`3o0002ooooo`03o`3o0?oooooo0?l000?o0?l0
9?ooool002;ooooo0_l0o`02ooooo`06o`3o0?oooooo0?l0o`3o0?oooooo0?l00_ooool00ol0o`3o
ooooo`3o0002ooooo`03o`3o0?oooooooooo00Gooooo1?l0o`000ooooooo0?l0ooooo`0Pooooo`?o
0?l08Oooool00ol0003oooooooooo`0>ooooo`Co0?l00oooool9o`3o01;ooooo2?l0o`000ooooooo
0?l0ooooo`03ooooo`;o0?l01Oooool00ol0o`3oooooooooo`04ooooo`;o0?l00oooool02Ol0o`3o
oooooooooooooooo0?l0ooooool0o`3oooooo`3o0002ooooo`;o0?l000Coooooo`3o0?l0o`3o0?l0
8oooool002;ooooo0_l0o`000ooooooo0?l0ooooo`02o`3o0007ooooool0o`3oooooooooool0o`3o
ooooo`3o0002ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooool0o`000_ooool00ol0o`3o
ooooooooo`0Mooooo`?o0?l04_oooolBo`3o0003o`000?oooooooooo013ooooo1Ol0o`0Sooooo`Co
0?l01?ooool00ol0o`3oooooooooo`03ooooo`;o0?l01Oooool2o`3o00?ooooo00Wo0?l0oooooooo
ooooooooo`3o0?oooooo0?l0ooooool0o`000_ooool2o`3o0004ooooool0o`3o0?l0o`3o02;ooooo
000Qooooo`;o0?l000?oooooo`3o0?ooool00_l0o`001ooooooo0?l0oooooooooooo0?l0ooooool0
o`000_ooool00ol0o`3oooooooooo`05ooooo`?o0?l000?oooooo`3o0?l0o`007Oooool3o`3o00go
oooo2?l0o`0Booooo`Wo0?l01Oooool5o`3o00Gooooo0ol0o`0Sooooo`Oo0?l01_ooool00ol0o`3o
ooooooooo`03ooooo`;o0?l00_ooool00ol0o`3oooooooooo`02ooooo`05o`3o0?oooooo0?l0oooo
ool0o`000_ooool2o`3o0004ooooool0o`3oooooo`3o027ooooo000Pooooo`;o0?l000?oooooo`3o
0?ooool00_l0o`000ooooooo0?l0ooooo`02ooooo`05o`3o0?oooooo0?l0ooooool0o`001oooool2
o`3o00;ooooo00?o0?l0ooooooooool06oooool2o`3o00cooooo1?l0o`0Jooooo`03o`000?oooooo
oooo00Kooooo1Ol0o`0=ooooo`;o0?l08_ooool2o`3o00?ooooo1?l0o`04ooooo`;o0?l01?ooool2
o`3o00;ooooo00?o0?l0ooooooooool00_ooool01Ol0o`3oooooo`3o0?oooooo0?l000;ooooo0_l0
o`000ooooooo0?l0o`3o000Qooooo`007oooool2o`3o0003ooooool0o`3ooooo00;o0?l000?ooooo
o`3o0?ooool00_ooool01Ol0o`3oooooo`3o0?oooooo0?l000Oooooo0_l0o`02ooooo`03o`3o0?oo
oooooooo01[ooooo0_l0o`0;ooooo`?o0?l07_ooool00ol0003oooooooooo`05ooooo`?o0?l00ooo
ool4o`3o00_ooooo0ol0o`0Qooooo`03o`3o0?oooooooooo00?ooooo1?l0o`03ooooo`03o`3o0?l0
003o000000;o00000_l0o`02ooooo`03o`3o0?oooooooooo00;ooooo00Go0?l0ooooool0o`3ooooo
o`3o0002ooooo`Go0?l08?ooool001kooooo0_l0o`000ooooooo0?l0o`3o0002o`3o0003ooooool0
o`3ooooo00;ooooo00Go0?l0ooooool0o`3oooooo`3o0007ooooo`;o0?l00_ooool00ol0o`3ooooo
ooooo`0Iooooo`;o0?l02_ooool3o`3o027ooooo00?o0000ooooooooool00_ooool3o`3o00[ooooo
0ol0o`0;ooooo`;o0?l08?ooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00?o0?l0
00?o0000o`3o0?l000000ol00002o`3o00;ooooo00?o0?l0ooooooooool00_ooool01?l0o`3ooooo
o`3o0?l0o`02ooooo`;o0?l000Coooooo`3o0?l0o`3o0?l07oooool001kooooo1_l0o`000ooooooo
0?l0ooooo`02ooooo`05o`3o0?oooooo0?l0ooooool0o`001oooool2o`3o00;ooooo00?o0?l0oooo
ooooool06?ooool2o`3o00Wooooo0ol0o`0Tooooo`03o`000?oooooo0?l000;o0?l04?ooool3o`3o
00[ooooo0_l0o`0Oooooo`03o`3o0?oooooooooo00?ooooo00Go0?l0ooooooooooooooooo`000003
o`3o00Co00000_l0o`02ooooo`03o`3o0?oooooooooo00;ooooo00Co0?l0ooooool0o`3o0?l00_oo
ool2o`3o0004ooooool0o`3o0?l0o`3o01kooooo000Mooooo`Co0?l000Coooooo`3o0?l0o`3o0?l0
0oooool01Ol0o`3oooooo`3o0?oooooo0?l000Oooooo0_l0o`02ooooo`03o`3o0?oooooooooo01Oo
oooo0_l0o`08ooooo`?o0?l09_ooool3o`3o01Kooooo0_l0o`0:ooooo`;o0?l07_ooool00ol0o`3o
ooooooooo`03ooooo`03o`3o0?oooooooooo00Co000000Go0?l0o`000?l0003o0000ooooo`02o`3o
0003ooooool0o`3ooooo00Cooooo00Co0?l0ooooool0o`3o0?l00_ooool2o`3o0003ooooool0o`3o
0?l001kooooo000Looooo`Co0?l000Coooooo`3o0?l0o`3o0?l01?ooool2o`3o0003ooooool0o`3o
oooo00Oooooo00Co0?l0oooooooooooo0?l06?ooool2o`3o00Sooooo0_l0o`0Vooooo`?o0?l000?o
ooooo`000?ooool06?ooool3o`3o00Wooooo0_l0o`0Mooooo`;o0?l01?ooool00ol0o`3oooooo`00
0004o`000003o`3o0?l0003o000000;ooooo0_l0o`000ooooooo0?l0ooooo`04ooooo`04o`3o0?oo
oooo0?l0o`3o00;ooooo1Ol0o`0Mooooo`006oooool2o`3o0003ooooool0o`3ooooo00?o0?l01?oo
ool2o`3o0003ooooool0o`3ooooo00Oooooo00Co0?l0oooooooooooo0?l05oooool2o`3o00Oooooo
0ol0o`0Vooooo`;o0?l01?ooool00ol0003oooooooooo`0Jooooo`;o0?l02Oooool2o`3o01gooooo
00?o0?l0ooooooooool00_ooool00ol0o`3o0000o`000004o`000003o`3o0?l0003ooooo00;ooooo
0_l0o`000ooooooo0?l0ooooo`04ooooo`03o`3o0?oooooo0?l000;ooooo0_l0o`001?oooooo0?l0
o`3o0?l0o`0Looooo`006_ooool00ol0o`3oooooo`3o0002o`3o0004ooooool0o`3o0?l0o`3o00?o
oooo0_l0o`000ooooooo0?l0ooooo`07ooooo`04o`3o0?ooooooooooo`3o01Kooooo0_l0o`06oooo
o`?o0?l09oooool2o`3o00Kooooo00?o0000ooooooooool07?ooool2o`3o00Wooooo00?o0?l0oooo
ooooool06oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?l0003o000000Co000000?o0?l0oooo
ooooool00_ooool2o`3o0003ooooool0o`3ooooo00Cooooo0ol0o`02ooooo`;o0?l000Coooooo`3o
0?l0o`3o0?l06oooool001[ooooo1?l0o`001?oooooo0?l0o`3o0?l0o`03ooooo`;o0?l000?ooooo
o`3o0?ooool01oooool01?l0o`3oooooooooool0o`0Fooooo`03o`3o0?oooooooooo00Cooooo0_l0
o`0Xooooo`;o0?l02?ooool00ol0003oooooooooo`0Nooooo`?o0?l01oooool2o`3o01cooooo00?o
0?l0ooooooooool00_ooool00ol0o`3o0000o`000002o`0000;ooooo00?o0?l0ooooooooool00_oo
ool2o`3o0003ooooool0o`3ooooo00Cooooo0ol0o`02ooooo`;o0?l000Coooooo`3o0?oooooo0?l0
6_ooool001Wooooo0_l0o`000ooooooo0?l0ooooo`03o`3o00Cooooo00?o0?l0ooooool0o`002?oo
ool01?l0o`3oooooooooool0o`0Fooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooooooool0
9_ooool2o`3o00[ooooo00?o0000ooooooooool08Oooool3o`3o00Kooooo00?o0?l0ooooooooool0
6_ooool01Ol0o`3ooooooooooooooooo0?l000Kooooo00?o0?l0ooooooooool00oooool2o`3o0003
ooooool0o`3ooooo00Cooooo0ol0o`001Ooooooo0?l0o`3o0?l0o`3ooooo00;o0?l06_ooool001So
oooo0_l0o`000ooooooo0?l0ooooo`03o`3o00Cooooo0ol0o`08ooooo`04o`3o0?ooooooooooo`3o
01Gooooo0_l0o`05ooooo`;o0?l09oooool2o`3o00cooooo00?o0000ooooooooool09?ooool2o`3o
00Gooooo00?o0?l0ooooooooool06Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo
00Cooooo00?o0?l0ooooooooool00oooool3o`3o00Kooooo0_l0o`02ooooo`Ko0?l06Oooool001Oo
oooo00Co0?l0ooooool0o`3o0?l00_ooool3o`3o00?ooooo0ol0o`08ooooo`;o0?l000?oooooo`3o
0?ooool05?ooool00ol0o`3oooooooooo`03ooooo`;o0?l0:?ooool00ol0o`3oooooooooo`0<oooo
o`03o`000?oooooooooo02Kooooo00?o0?l0ooooooooool00oooool2o`3o01[ooooo00?o0?l0oooo
ooooool00_ooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0oooo
ool0o`001_ooool2o`3o00;ooooo0_l0o`001?oooooo0?l0o`3o0?l0o`0Hooooo`005_ooool00ol0
o`3oooooo`3o0002o`3o0004ooooool0o`3o0?l0o`3o00Cooooo0_l0o`08ooooo`;o0?l000?ooooo
o`3o0?ooool05?ooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo02Kooooo0_l0o`0?
ooooo`03o`000?oooooooooo02Oooooo0_l0o`05ooooo`03o`3o0?oooooooooo01Sooooo00?o0?l0
ooooooooool00_ooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0
ooooool0o`001Oooool3o`3o00;ooooo0_l0o`001?oooooo0?l0o`3o0?l0o`0Gooooo`005_ooool2
o`3o0003ooooool0o`3ooooo00?o0?l01?ooool00ol0o`3oooooo`3o0008ooooo`04o`3o0?oooooo
ooooo`3o01?ooooo0_l0o`04ooooo`;o0?l09oooool2o`3o017ooooo00?o0000ooooooooool0:Ooo
ool2o`3o00Cooooo00?o0?l0ooooooooool06?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oo
oooooooo00Cooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooo`3o0005ooooo`04o`3o0?oo
oooo0?l0ooooo`?o0?l000?oooooo`3o0?l0o`005oooool001Gooooo0_l0o`001?oooooo0?l0oooo
ooooool3o`3o00?ooooo0ol0o`08ooooo`04o`3o0?ooooooooooo`3o01?ooooo00?o0?l0oooooooo
ool00oooool00ol0o`3oooooooooo`0Uooooo`;o0?l04oooool00ol0003oooooooooo`0[ooooo`03
o`3o0?oooooooooo00;ooooo0_l0o`0Iooooo`05o`3o0?ooooooooooooooool0o`001oooool00ol0
o`3oooooooooo`02ooooo`04o`3o0?ooooooooooo`3o00Gooooo0_l0o`02ooooo`;o0?l000Cooooo
o`3o0?l0o`3o0?l05_ooool001Gooooo1?l0o`001?oooooo0?l0o`3o0?l0o`04ooooo`;o0?l02?oo
ool01?l0o`3oooooooooool0o`0Cooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool0
9?ooool2o`3o01Gooooo00?o0000ooooooooool0;?ooool2o`3o00Cooooo00?o0?l0ooooooooool0
5oooool01Ol0o`3ooooooooooooooooo0?l000Oooooo00?o0?l0ooooooooool00_ooool00ol0o`3o
ooooo`3o0005ooooo`?o0?l00_ooool2o`3o0004ooooool0o`3o0?l0o`3o01Gooooo000Dooooo`;o
0?l000?oooooo`3o0?ooool00ol0o`04ooooo`03o`3o0?oooooo0?l000Oooooo0_l0o`000ooooooo
0?l0ooooo`0Aooooo`;o0?l01Oooool00ol0o`3oooooooooo`0Tooooo`03o`3o0?oooooooooo01Go
oooo00?o0000ooooooooool0;_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo01Oo
oooo00Go0?l0ooooooooooooooooo`3o0007ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0oooo
ool0o`001Oooool01?l0o`3oooooo`3o0?ooool7o`3o01Cooooo000Cooooo`;o0?l000Coooooo`3o
0?l0o`3ooooo0_l0o`04ooooo`?o0?l01oooool2o`3o0003ooooool0o`3ooooo017ooooo00?o0?l0
ooooooooool01?ooool00ol0o`3oooooooooo`0Tooooo`03o`3o0?oooooooooo01Kooooo00?o0000
ooooooooool0;oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo01Oooooo00Go0?l0
ooooooooooooooooo`3o0006ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooool0o`001?oo
ool3o`3o00;ooooo0_l0o`001?oooooo0?l0o`3o0?l0o`0Dooooo`004oooool2o`3o0003ooooool0
o`3ooooo00?o0?l01?ooool2o`3o00Oooooo0_l0o`000ooooooo0?l0ooooo`0Aooooo`03o`3o0?oo
oooooooo00?ooooo0_l0o`0Uooooo`;o0?l06Oooool2o`00037ooooo00?o0?l0ooooooooool00_oo
ool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01?oo
ool00ol0o`3oooooooooo`02ooooo`04o`3o0?ooooooooooo`3o00Cooooo0ol0o`02ooooo`Ko0?l0
4oooool001;ooooo0_l0o`000ooooooo0?l0ooooo`03o`3o00Cooooo0_l0o`07ooooo`;o0?l000?o
ooooo`3o0?ooool04Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo02Cooooo00?o
0?l0ooooooooool06Oooool00ol0003oooooooooo`0aooooo`03o`3o0?oooooooooo00;ooooo00?o
0?l0ooooooooool05_ooool01Ol0o`3ooooooooooooooooo0?l000Oooooo00?o0?l0ooooooooool0
0_ooool01?l0o`3oooooooooool0o`04ooooo`03o`3o0?oooooo0?l000;ooooo00Go0?l0ooooool0
o`3oooooo`3o000Cooooo`004_ooool4o`3o0003ooooool0o`3o0?l000Cooooo00?o0?l0ooooool0
o`001_ooool01?l0o`3oooooo`3o0?l0o`0Cooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0oooo
ooooool09?ooool00ol0o`3oooooooooo`0Jooooo`03o`000?oooooooooo03;ooooo0_l0o`03oooo
o`03o`3o0?oooooooooo01Kooooo00Go0?l0ooooooooooooooooo`3o0007ooooo`03o`3o0?oooooo
oooo00;ooooo00?o0?l0ooooool0o`001?ooool3o`3o00;ooooo1_l0o`0Booooo`004Oooool2o`3o
0003ooooool0o`3ooooo00?o0?l01?ooool2o`3o00Oooooo0_l0o`000ooooooo0?l0ooooo`0Aoooo
o`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool09?ooool00ol0o`3oooooooooo`0Koooo
o`03o`000?oooooooooo03Cooooo00Go0?l0ooooooooooooooooo`3o000Hooooo`05o`3o0?oooooo
ooooooooool0o`001_ooool00ol0o`3oooooooooo`02ooooo`;o0?l000?oooooo`3o0?ooool00ooo
ool3o`3o00;ooooo1Ol0o`0Booooo`004Oooool01Ol0o`3oooooo`3o0?l0o`3ooooo00;o0?l01?oo
ool2o`3o00Oooooo0_l0o`000ooooooo0?l0ooooo`0Aooooo`03o`3o0?oooooooooo00;ooooo00?o
0?l0ooooooooool08oooool2o`3o01kooooo00?o0000ooooooooool0=Oooool01Ol0o`3ooooooooo
oooooooo0?l001Sooooo00Go0?l0ooooooooooooooooo`3o0006ooooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooool0o`001?ooool3o`3o00?ooooo1Ol0o`0Aooooo`004?ooool2o`3o0003oooo
ool0o`3ooooo00;o0?l01?ooool3o`3o00Kooooo0_l0o`000ooooooo0?l0ooooo`0Aooooo`03o`3o
0?oooooooooo00;ooooo00?o0?l0ooooooooool08oooool00ol0o`3oooooooooo`0Jooooo`ko0?l0
;oooool01Ol0o`3ooooooooooooooooo0?l001Oooooo00?o0?l0ooooooooool00_ooool00ol0o`3o
ooooooooo`04ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooool0o`001?ooool3o`3o00;o
oooo1Ol0o`0Aooooo`003oooool2o`3o0003ooooool0o`3o0?l000?o0?l01?ooool2o`3o00Oooooo
0_l0o`000ooooooo0?l0ooooo`0@ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool0
8oooool00ol0o`3oooooooooo`0@ooooo`_o0?l01?ooool00ol0003oooooooooo`07ooooo`[o0?l0
9_ooool01Ol0o`3ooooooooooooooooo0?l001Oooooo00Go0?l0ooooooooooooooooo`3o0007oooo
o`04o`3o0?ooooooooooooooo`?o0?l01Oooool3o`3o00;ooooo1Ol0o`0@ooooo`003oooool4o`3o
0003ooooool0o`3o0?l000Cooooo0ol0o`06ooooo`;o0?l000?oooooo`3o0?ooool04Oooool01Ol0
o`3ooooooooooooooooo0?l002Gooooo00?o0?l0ooooooooool03Oooool4o`3o00oooooo00?o0000
ooooooooool04Oooool3o`3o02Cooooo00Go0?l0ooooooooooooooooo`3o000Gooooo`05o`3o0?oo
ooooooooooooool0o`001oooool01ol0o`3ooooooooooooooooo0?l0ooooool0o`001?ooool3o`3o
00;ooooo1Ol0o`0@ooooo`003_ooool2o`3o0003ooooool0o`3o0?l000?o0?l00oooool3o`3o00Ko
oooo0_l0o`02ooooo`03o`3o0?oooooooooo00oooooo00Go0?l0ooooooooooooooooo`3o000Uoooo
o`03o`3o0?oooooooooo00_ooooo0ol0o`0Cooooo`03o`000?oooooooooo01Cooooo1Ol0o`0Poooo
o`04o`3o0?ooooooooooo`3o01Sooooo00Go0?l0ooooooooooooooooo`3o0006ooooo`04o`3o0?oo
ooooooooooooo`;o0?l000?oooooo`3o0?ooool00oooool3o`3o00;ooooo1Ol0o`0?ooooo`003_oo
ool01Ol0o`3oooooo`3o0?l0o`3ooooo00;o0?l01?ooool00ol0o`3oooooo`3o0005ooooo`;o0?l0
0_ooool00ol0o`3oooooooooo`0?ooooo`05o`3o0?ooooooooooooooool0o`009Oooool00ol0o`3o
ooooooooo`08ooooo`Co0?l05_ooool00ol0003oooooooooo`0Iooooo`Go0?l06oooool01Ol0o`3o
oooooooooooooooo0?l001Oooooo00Go0?l0ooooooooooooooooo`3o0007ooooo`07o`3o0?oooooo
ooooooooool0o`3oooooo`3o0004ooooo`?o0?l00_ooool5o`3o00oooooo000=ooooo`;o0?l000?o
ooooo`3o0?l0o`000_l0o`04ooooo`?o0?l01_ooool2o`3o0003ooooool0o`3ooooo013ooooo00Go
0?l0ooooooooooooooooo`3o000Uooooo`03o`3o0?oooooooooo00Kooooo0ol0o`0Jooooo`03o`00
0?oooooooooo01kooooo0ol0o`0Iooooo`05o`3o0?ooooooooooooooool0o`005oooool01Ol0o`3o
oooooooooooooooo0?l000Oooooo00Oo0?l0ooooooooooooooooo`3o0?oooooo0?l000Cooooo0ol0
o`02ooooo`Go0?l03_ooool000gooooo00Go0?l0ooooool0o`3o0?l0ooooo`02o`3o00Cooooo0_l0
o`06ooooo`;o0?l00_ooool00ol0o`3oooooooooo`0?ooooo`04o`3o0?ooooooooooo`3o02Gooooo
00?o0?l0ooooooooool01?ooool3o`3o01?ooooo1Ol00005ooooo`03o`000?oooooooooo027ooooo
0_l0o`0Hooooo`05o`3o0?ooooooooooooooool0o`005oooool01?l0o`3oooooooooool0o`08oooo
o`03o`3o0?oooooooooo00?o0?l01?ooool00ol0o`3oooooo`3o0002ooooo`Go0?l03_ooool000go
oooo00?o0?l0ooooool0o`000ol0o`04ooooo`?o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo0?l0
017ooooo00Co0?l0oooooooooooo0?l09Oooool00ol0o`3oooooooooo`02ooooo`?o0?l01_oooolH
o`3o00;ooooo00?o0000ooooooooool08oooool3o`3o01Kooooo00Go0?l0ooooooooooooooooo`3o
000Fooooo`05o`3o0?ooooooooooooooool0o`001oooool01ol0o`3ooooooooooooooooo0?l0oooo
ool0o`001?ooool3o`3o0004ooooool0o`3o0?l0ooooo`;o0?l03_ooool000cooooo1?l0o`000ooo
oooo0?l0o`3o0004ooooo`;o0?l01_ooool2o`3o00;ooooo00?o0?l0ooooooooool03_ooool01Ol0
o`3ooooooooooooooooo0?l002Cooooo00?o0?l0ooooooooool00ol0o`05ooooo`Co0?l02?ooool6
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool6o`3o02Gooooo0_l0o`0Eooooo`04o`3o0?oooooo
ooooo`3o01Oooooo00Go0?l0ooooooooooooooooo`3o0007ooooo`03o`3o0?oooooooooo00?o0?l0
1?ooool00ol0o`3oooooo`3o0002ooooo`?o0?l000?oooooo`3o0?ooool03?ooool000cooooo00?o
0?l0ooooool0o`000ol0o`04ooooo`?o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo0?l0013ooooo
00Go0?l0ooooooooooooooooo`3o000Tooooo`04o`3o0?oooooo0?l0o`3o00Cooooo1?l0o`0Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00Co0000oooooooooooooooo0ol0o`0Tooooo`;o0?l05?ooool0
1?l0o`3oooooooooool0o`0Fooooo`05o`3o0?ooooooooooooooool0o`002?ooool01_l0o`3ooooo
ooooool0o`3oooooo`3o00Cooooo0ol0o`001?oooooo0?l0o`3o0?ooool2o`3o00gooooo000;oooo
o`Co0?l000?oooooo`3o0?l0o`000oooool3o`3o00Kooooo0_l0o`02ooooo`03o`3o0?oooooooooo
00kooooo00Co0?l0oooooooooooo0?l09?ooool3o`3o00?ooooo0ol0o`0Kooooo`03ogMgMomVIVKo
oooo00Cooooo00?o0000ooooooooool01?ooool3o`3o02?ooooo0ol0o`0Booooo`04o`3o0?oooooo
ooooo`3o01Kooooo00Go0?l0ooooooooooooooooo`3o0008ooooo`03o`3o0?oooooo0?l000;o0?l0
1?ooool3o`3o00;ooooo0ol0o`000ooooooo0?l0ooooo`0;ooooo`002oooool00ol0o`3oooooo`3o
0003o`3o00Cooooo0ol0o`05ooooo`05o`3o0?oooooo0?l0ooooool0o`004?ooool01?l0o`3ooooo
ooooool0o`0Tooooo`;o0?l00oooool2o`3o01oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`07ooooo`?o0?l08oooool2o`3o013ooooo00Go0?l0ooooooooooooooooo`3o000Foooo
o`04o`3o0?ooooooooooo`3o00Sooooo00Ko0?l0oooooooooooo0?l0ooooool0o`04ooooo`?o0?l0
00Coooooo`3o0?l0o`3ooooo0_l0o`0<ooooo`002oooool01?l0o`3oooooo`3o0?ooool2o`3o00?o
oooo0ol0o`05ooooo`05o`3o0?oooooo0?l0ooooool0o`004?ooool01Ol0o`3ooooooooooooooooo
0?l002?ooooo00Co0?l0oooooooooooooooo0_l0o`0Mooooo`05o`000?nj^[[ooooooiRHV?l@4100
1Oooool00ol0003oooooooooo`0:ooooo`;o0?l08oooool00ol0o`3oooooooooo`0>ooooo`05o`3o
0?ooooooooooooooool0o`005Oooool01Ol0o`3ooooooooooooooooo0?l000Sooooo00Go0?l0oooo
ool0o`3oooooo`3o0004ooooo`?o0?l00_ooool4o`3o00cooooo000:ooooo`Oo0?l00oooool3o`3o
00Gooooo00Go0?l0ooooool0o`3oooooo`3o000?ooooo`05o`3o0?ooooooooooooooool0o`008ooo
ool01Ol0o`3ooooooooooooooooo0?l001oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03
o`000?oooooooooo00cooooo0_l0o`0Rooooo`;o0?l03oooool01?l0o`3oooooooooool0o`0Foooo
o`04o`3o0?ooooooooooo`3o00Sooooo00Ko0?l0oooooooooooo0?l0ooooool0o`04ooooo`?o0?l0
00?oooooo`3o0?l0o`000ol0o`0;ooooo`002_ooool01?l0o`3oooooo`3o0?ooool2o`3o00?ooooo
0_l0o`000ooooooo0?l0ooooo`03ooooo`05o`3o0?oooooo0?l0ooooool0o`004?ooool01?l0o`3o
ooooooooool0o`0Sooooo`;o0?l000?oooooo`3o0?l0o`00:_ooool00ol0003oooooooooo`0>oooo
o`;o0?l08_ooool00ol0o`3oooooooooo`0=ooooo`04o`3o0?ooooooooooo`3o01Gooooo00Go0?l0
ooooooooooooooooo`3o0008ooooo`05o`3o0?oooooo0?l0ooooool0o`001?ooool3o`3o0004oooo
ool0o`3o0?l0ooooo`;o0?l02oooool000[ooooo1_l0o`03ooooo`?o0?l01Oooool01Ol0o`3ooooo
o`3o0?oooooo0?l000oooooo00Go0?l0ooooooooooooooooo`3o000Qooooo`?o0?l000?oooooo`3o
0?ooool0:oooool00ol0003oooooooooo`0@ooooo`;o0?l08Oooool2o`3o00gooooo00Go0?l0oooo
ooooooooooooo`3o000Eooooo`04o`3o0?ooooooooooo`3o00Sooooo00Ko0?l0oooooooooooo0?l0
ooooool0o`04ooooo`04o`3o0?oooooo0?l0ooooo`Go0?l02_ooool000Wooooo1_l0o`03ooooo`04
o`3o0?oooooo0?l0o`3o00Cooooo00Go0?l0ooooool0o`3oooooo`3o000@ooooo`04o`3o0?oooooo
ooooo`3o027ooooo00?o0?l0ooooool0o`000_l0o`0]ooooo`03o`000?oooooooooo01;ooooo0_l0
o`0Qooooo`03o`3o0?oooooooooo00_ooooo00Go0?l0ooooooooooooooooo`3o000Eooooo`03o`3o
0?oooooo0?l000Wooooo00Go0?l0ooooool0o`3oooooo`3o0004ooooo`?o0?l000?oooooo`3o0?l0
o`000ol0o`0:ooooo`002Oooool01?l0o`3oooooo`3o0?ooool2o`3o00?ooooo0ol0o`05ooooo`05
o`3o0?oooooo0?l0ooooool0o`003oooool01Ol0o`3ooooooooooooooooo0?l001oooooo0_l0o`00
0ooooooo0?l0o`3o000_ooooo`03o`000?oooooooooo01Cooooo0_l0o`0Pooooo`03o`3o0?oooooo
oooo00_ooooo00Go0?l0ooooooooooooooooo`3o000Dooooo`04o`3o0?ooooooooooo`3o00Sooooo
00Ko0?l0oooooooooooo0?l0ooooool0o`03ooooo`?o0?l00_ooool5o`3o00Wooooo0008ooooo`Ko
0?l01?ooool3o`3o00Cooooo00Go0?l0ooooool0o`3oooooo`3o000?ooooo`05o`3o0?oooooooooo
ooooool0o`007oooool01?l0o`3oooooooooool0o`0aooooo`03o`000?oooooooooo01Kooooo0_l0
o`0Oooooo`03o`3o0?oooooooooo00_ooooo00Co0?l0oooooooooooo0?l05Oooool00ol0o`3ooooo
o`3o0008ooooo`06o`3o0?ooooooooooo`3o0?oooooo0?l01?ooool01?l0o`3oooooo`3o0?ooool5
o`3o00Wooooo0008ooooo`?o0?l000?oooooo`3o0?l0o`000oooool3o`3o00Gooooo00Go0?l0oooo
ool0o`3oooooo`3o000?ooooo`04o`3o0?ooooooooooo`3o01oooooo00Co0?l0oooooooooooo0?l0
<_ooool00ol0003oooooooooo`0Hooooo`;o0?l07_ooool00ol0o`3oooooooooo`0:ooooo`05o`3o
0?ooooooooooooooool0o`005?ooool01?l0o`3oooooooooool0o`08ooooo`03o`3o0?oooooo0?l0
00;o0?l01?ooool3o`3o00;ooooo1?l0o`09ooooo`002?ooool01?l0o`3oooooo`3o0?ooool2o`3o
00?ooooo0ol0o`04ooooo`06o`3o0?ooooooooooo`3o0?oooooo0?l03_ooool01Ol0o`3ooooooooo
oooooooo0?l001kooooo00?o0?l0ooooooooool00_l0o`0booooo`03o`000?oooooooooo01[ooooo
00?o0?l0ooooooooool07?ooool00ol0o`3oooooooooo`0:ooooo`04o`3o0?ooooooooooo`3o01Go
oooo00?o0?l0ooooool0o`002?ooool01_l0o`3oooooooooool0o`3oooooo`3o00Cooooo0_l0o`02
ooooo`Go0?l02?ooool000Oooooo1?l0o`000ooooooo0?l0ooooo`02ooooo`04o`3o0?oooooo0?l0
o`3o00Cooooo00Go0?l0ooooool0o`3oooooo`3o000?ooooo`04o`3o0?ooooooooooo`3o01kooooo
00?o0?l0ooooooooool00_l0o`0cooooo`03o`000?oooooooooo01_ooooo0_l0o`0Mooooo`03o`3o
0?oooooooooo00[ooooo00Co0?l0oooooooooooo0?l05?ooool01?l0o`3oooooooooool0o`08oooo
o`05o`3o0?oooooo0?l0ooooool0o`001?ooool3o`3o0003ooooool0o`3o0?l000?o0?l02?ooool0
00Oooooo0ol0o`000ooooooo0?l0o`3o0003ooooo`?o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo
0?l000kooooo00Go0?l0ooooooooooooooooo`3o000Mooooo`03o`3o0?oooooooooo00;o0?l0=?oo
ool2o`0001kooooo00?o0?l0ooooooooool06oooool00ol0o`3oooooooooo`09ooooo`04o`3o0?oo
ooooooooo`3o01Gooooo00?o0?l0ooooool0o`002?ooool00ol0o`3oooooooooo`02o`3o00Gooooo
0_l0o`02ooooo`04o`3o0?oooooo0?l0o`3o00Sooooo0007ooooo`04o`3o0?oooooo0?l0ooooo`;o
0?l00oooool3o`3o00Cooooo00Go0?l0ooooool0o`3oooooo`3o000?ooooo`04o`3o0?oooooooooo
o`3o01gooooo00?o0?l0ooooooooool00_l0o`0eooooo`03o`000?oooooooooo01kooooo00?o0?l0
ooooooooool06oooool00ol0o`3oooooooooo`09ooooo`04o`3o0?ooooooooooo`3o01Cooooo00?o
0?l0ooooool0o`002Oooool01Ol0o`3oooooo`3o0?oooooo0?l000Cooooo0_l0o`02ooooo`Go0?l0
1oooool000Kooooo1?l0o`000ooooooo0?l0o`3o0002ooooo`03o`3o0?oooooo0?l000Gooooo00Go
0?l0ooooool0o`3oooooo`3o000>ooooo`05o`3o0?ooooooooooooooool0o`007?ooool00ol0o`3o
ooooooooo`02o`3o03Kooooo00?o0000ooooooooool07oooool00ol0o`3oooooooooo`0Kooooo`03
o`3o0?oooooooooo00Sooooo00Co0?l0oooooooooooo0?l05?ooool01?l0o`3oooooooooool0o`08
ooooo`03o`3o0?oooooo0?l000;o0?l01?ooool3o`3o0003ooooool0o`3o0?l000?o0?l01oooool0
00Kooooo0ol0o`000ooooooo0?l0o`3o0003ooooo`?o0?l01?ooool00ol0o`3oooooo`3o0002oooo
o`03o`3o0?oooooooooo00cooooo00Co0?l0oooooooooooo0?l07?ooool01_l0o`3oooooooooool0
o`3oooooo`3o03Kooooo00?o0000ooooooooool08?ooool00ol0o`3oooooooooo`0Kooooo`03o`3o
0?oooooooooo00Sooooo00Co0?l0oooooooooooo0?l05?ooool00ol0o`3oooooo`3o0008ooooo`03
o`3o0?oooooooooo00;o0?l01Oooool2o`3o00;ooooo00Co0?l0ooooool0o`3o0?l01oooool000Ko
oooo00Co0?l0ooooool0o`3ooooo0_l0o`02ooooo`04o`3o0?oooooo0?l0o`3o00Cooooo00Go0?l0
ooooool0o`3oooooo`3o000>ooooo`05o`3o0?ooooooooooooooool0o`006oooool01_l0o`3ooooo
ooooool0o`3oooooo`3o03Oooooo00?o0000ooooooooool08Oooool00ol0o`3oooooooooo`0Joooo
o`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooool0o`005?ooool01?l0o`3oooooooooool0o`08
ooooo`04o`3o0?oooooo0?l0o`3o00Gooooo0_l0o`02ooooo`Go0?l01_ooool000Gooooo1?l0o`00
0ooooooo0?l0o`3o0002ooooo`03o`3o0?oooooo0?l000Gooooo00Go0?l0ooooool0o`3oooooo`3o
000>ooooo`04o`3o0?ooooooooooo`3o01_ooooo00Co0?l0oooooooooooo0?l00_ooool00ol0o`3o
ooooooooo`0eooooo`03o`000?oooooooooo02;ooooo00?o0?l0ooooooooool06_ooool00ol0o`3o
ooooooooo`08ooooo`04o`3o0?ooooooooooo`3o01Cooooo00?o0?l0ooooool0o`002?ooool00ol0
o`3oooooo`3o0002o`3o00Cooooo0ol0o`000ooooooo0?l0o`3o0003o`3o00Kooooo0005ooooo`Ko
0?l00oooool3o`3o00Cooooo00Go0?l0ooooool0o`3oooooo`3o000?ooooo`04o`3o0?oooooooooo
o`3o01_ooooo00Ko0?l0oooooooooooo0?l0ooooool0o`0hooooo`03o`000?oooooooooo02?ooooo
00?o0?l0ooooooooool06_ooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooo0?l001Cooooo
00?o0?l0ooooool0o`002?ooool00ol0o`3oooooooooo`02o`3o00Cooooo0ol0o`000ooooooo0?l0
o`3o0003o`3o00Kooooo0005ooooo`04o`3o0?oooooo0?l0ooooo`;o0?l00_ooool01?l0o`3ooooo
o`3o0?l0o`04ooooo`05o`3o0?oooooo0?l0ooooool0o`003_ooool01?l0o`3oooooooooool0o`0K
ooooo`06o`3o0?ooooooooooo`3o0?oooooo0?l0>Oooool00ol0003oooooooooo`0Tooooo`03o`3o
0?oooooooooo01[ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooo`3o000Dooooo`04o`3o
0?ooooooooooo`3o00Sooooo00Co0?l0ooooool0o`3o0?l01Oooool2o`3o00;ooooo1Ol0o`05oooo
o`001Oooool01?l0o`3oooooo`3o0?ooool2o`3o00;ooooo00?o0?l0ooooool0o`001Oooool2o`3o
00;ooooo00?o0?l0ooooooooool03?ooool01?l0o`3oooooooooool0o`0Jooooo`04o`3o0?oooooo
ooooo`3o00;ooooo00?o0?l0ooooooooool0=oooool00ol0003oooooooooo`0Uooooo`03o`3o0?oo
oooooooo01[ooooo00?o0?l0ooooooooool01_ooool01?l0o`3oooooooooool0o`0Dooooo`03o`3o
0?oooooo0?l000Sooooo00?o0?l0ooooool0o`000_l0o`04ooooo`?o0?l000?oooooo`3o0?l0o`00
0ol0o`05ooooo`001?ooool2o`3o0003ooooool0o`3o0?l000;o0?l00_ooool3o`3o00Gooooo0_l0
o`000ooooooo0?l0ooooo`0=ooooo`05o`3o0?ooooooooooooooool0o`006Oooool01?l0o`3ooooo
ooooool0o`02ooooo`03o`3o0?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0o`3o
ooooooooo`0Kooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooool0o`005?ooool01?l0o`3o
ooooooooool0o`07ooooo`03o`3o0?oooooo0?l000;o0?l01?ooool3o`3o0003ooooool0o`3o0?l0
00?o0?l01Oooool000Cooooo0ol0o`001?oooooo0?l0o`3o0?l0o`02ooooo`?o0?l01?ooool01Ol0
o`3oooooo`3o0?oooooo0?l000kooooo00Co0?l0oooooooooooo0?l06Oooool01Ol0o`3ooooooooo
oooooooo0?l000;ooooo00?o0?l0ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`3o
0?oooooooooo01_ooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooo`3o000Dooooo`04o`3o
0?ooooooooooo`3o00Sooooo00Co0?l0ooooool0o`3o0?l01?ooool3o`3o0003ooooool0o`3o0?l0
00Co0?l01?ooool000Cooooo0ol0o`000ooooooo0?l0o`3o0003ooooo`;o0?l01Oooool2o`3o00;o
oooo00?o0?l0ooooooooool03?ooool01?l0o`3oooooooooool0o`0Iooooo`04o`3o0?oooooooooo
o`3o00;ooooo00?o0?l0ooooooooool0>Oooool00ol0003oooooooooo`0Wooooo`03o`3o0?oooooo
oooo01_ooooo00?o0?l0ooooooooool01?ooool01?l0o`3oooooooooool0o`0Dooooo`03o`3o0?oo
oooo0?l000Sooooo00?o0?l0ooooool0o`000_l0o`04ooooo`;o0?l000Coooooo`3o0?l0o`3ooooo
0ol0o`04ooooo`000oooool2o`3o0003ooooool0o`3ooooo00;o0?l00_ooool00ol0o`3oooooo`3o
0005ooooo`;o0?l00_ooool00ol0o`3oooooooooo`0;ooooo`05o`3o0?ooooooooooooooool0o`00
6?ooool01Ol0o`3ooooooooooooooooo0?l000;ooooo00?o0?l0ooooooooool0>Oooool00ol0003o
ooooooooo`0Xooooo`03o`3o0?oooooooooo01[ooooo00?o0?l0ooooooooool01Oooool00ol0o`3o
ooooo`3o000Dooooo`04o`3o0?ooooooooooo`3o00Sooooo1?l0o`04ooooo`?o0?l000?oooooo`3o
0?l0o`000ol0o`04ooooo`000oooool2o`3o0003ooooool0o`3o0?l000;o0?l00_ooool3o`3o00Co
oooo00Go0?l0ooooool0o`3oooooo`3o000>ooooo`04o`3o0?ooooooooooo`3o01Wooooo00Co0?l0
oooooooooooo0?l00_ooool00ol0o`3oooooooooo`0jooooo`;o0000:Oooool00ol0o`3ooooooooo
o`0Kooooo`03o`3o0?oooooooooo00Cooooo00Co0?l0oooooooooooo0?l04oooool01?l0o`3ooooo
ooooool0o`08ooooo`Co0?l01?ooool3o`3o0003ooooool0o`3o0?l000?o0?l01?ooool000?ooooo
1ol0o`02ooooo`?o0?l01?ooool01Ol0o`3oooooo`3o0?oooooo0?l000kooooo00Co0?l0oooooooo
oooo0?l06?ooool01Ol0o`3ooooooooooooooooo0?l000;ooooo00?o0?l0ooooooooool0>_ooool0
0ol0003oooooooooo`0Yooooo`03o`3o0?oooooooooo01_ooooo00?o0?l0ooooooooool01?ooool0
0ol0o`3oooooo`3o000Cooooo`04o`3o0?ooooooooooo`3o00Sooooo0_l0o`000ooooooo0?l0oooo
o`04ooooo`;o0?l000?oooooo`3o0?l0o`000ol0o`04ooooo`000oooool3o`3o0003ooooool0o`3o
0?l000?ooooo0_l0o`05ooooo`;o0?l00_ooool00ol0o`3oooooooooo`0<ooooo`04o`3o0?oooooo
ooooo`3o01Sooooo00Co0?l0oooooooooooo0?l00_ooool00ol0o`3oooooooooo`0kooooo`03o`00
0?oooooooooo02[ooooo00?o0?l0ooooooooool06_ooool00ol0o`3oooooooooo`04ooooo`03o`3o
0?oooooo0?l001?ooooo00Co0?l0oooooooooooo0?l02Oooool4o`3o00Cooooo0_l0o`000ooooooo
0?l0o`3o0004o`3o00?ooooo0003ooooo`?o0?l000?oooooo`3o0?l0o`000oooool2o`3o00Gooooo
0_l0o`02ooooo`03o`3o0?oooooooooo00_ooooo00Co0?l0oooooooooooo0?l06?ooool01?l0o`3o
ooooooooool0o`03ooooo`03o`3o0?oooooooooo03_ooooo00?o0000ooooooooool0:oooool00ol0
o`3oooooooooo`0Jooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooool0o`004oooool00ol0
o`3oooooo`3o0009ooooo`Co0?l01?ooool2o`3o00;ooooo00?o0?l0ooooool0o`000_l0o`03oooo
o`000_ooool01Ol0o`3oooooo`3o0?l0o`3ooooo00;o0?l00oooool2o`3o00Cooooo00Go0?l0oooo
ool0o`3oooooo`3o000>ooooo`04o`3o0?ooooooooooo`3o01Oooooo00Co0?l0oooooooooooo0?l0
0oooool00ol0o`3oooooooooo`0looooo`03o`000?oooooooooo02_ooooo00?o0?l0ooooooooool0
6_ooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooo0?l001?ooooo00Co0?l0oooooooooooo
0?l02?ooool4o`3o00Cooooo0_l0o`02ooooo`03o`3o0?oooooo0?l000;o0?l00oooool000;ooooo
1?l0o`000ooooooo0?l0o`3o0002ooooo`?o0?l01?ooool01Ol0o`3oooooo`3o0?oooooo0?l000ko
oooo00Co0?l0oooooooooooo0?l05oooool01?l0o`3oooooooooool0o`03ooooo`03o`3o0?oooooo
oooo03cooooo00?o0000ooooooooool0;?ooool00ol0o`3oooooooooo`0Jooooo`03o`3o0?oooooo
oooo00?ooooo00?o0?l0ooooool0o`004oooool01?l0o`3oooooooooool0o`09ooooo`?o0?l01?oo
ool3o`3o0003ooooool0o`3o0?l000?o0?l00oooool000;ooooo1?l0o`000ooooooo0?l0ooooo`02
ooooo`;o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo0?l000kooooo00?o0?l0ooooool0o`005ooo
ool01Ol0o`3ooooooooooooooooo0?l000?ooooo00?o0?l0ooooooooool0??ooool00ol0003ooooo
ooooo`0]ooooo`03o`3o0?oooooooooo01Wooooo00?o0?l0ooooooooool01?ooool00ol0o`3ooooo
o`3o000Booooo`04o`3o0?ooooooooooo`3o00Wooooo0ol0o`04ooooo`?o0?l00_ooool4o`3o00?o
oooo0002ooooo`Ko0?l00oooool2o`3o00Gooooo0_l0o`000ooooooo0?l0ooooo`0=ooooo`04o`3o
0?ooooooooooo`3o01Oooooo00Co0?l0oooooooooooo0?l00oooool00ol0o`3oooooooooo`0moooo
o`03o`000?oooooooooo02gooooo00?o0?l0ooooooooool06Oooool00ol0o`3oooooooooo`04oooo
o`03o`3o0?oooooo0?l001;ooooo00Co0?l0oooooooooooo0?l02Oooool3o`3o00Cooooo0ol0o`02
ooooo`Co0?l00oooool000;ooooo1_l0o`03ooooo`;o0?l01Oooool2o`3o0003ooooool0o`3ooooo
00gooooo00Co0?l0oooooooooooo0?l05_ooool01Ol0o`3ooooooooooooooooo0?l000?ooooo00?o
0?l0ooooooooool0?Oooool00ol0003oooooooooo`0^ooooo`03o`3o0?oooooooooo01Wooooo00?o
0?l0ooooooooool00oooool00ol0o`3oooooo`3o000Cooooo`03o`3o0?oooooo0?l000Wooooo1?l0
o`04ooooo`;o0?l00_ooool4o`3o00?ooooo0002ooooo`?o0?l000?oooooo`3o0?l0o`000oooool2
o`3o00Cooooo00Go0?l0ooooool0o`3oooooo`3o000>ooooo`04o`3o0?ooooooooooo`3o01Kooooo
00Go0?l0ooooooooooooooooo`3o0002ooooo`03o`3o0?oooooooooo03kooooo00?o0000oooooooo
ool0;_ooool00ol0o`3oooooooooo`0Iooooo`03o`3o0?oooooooooo00Cooooo0_l0o`0Cooooo`04
o`3o0?ooooooooooo`3o00Sooooo1?l0o`04ooooo`;o0?l00_ooool00ol0o`3oooooo`3o0002o`3o
00;ooooo00000ooooooo0?l0ooooo`02o`3o0003ooooool0o`3o0?l000?ooooo00?o0?l0oooooooo
ool00oooool01Ol0o`3oooooo`3o0?oooooo0?l000kooooo00?o0?l0ooooool0o`005oooool01?l0
o`3oooooooooool0o`03ooooo`03o`3o0?oooooooooo03kooooo00?o0000ooooooooool0;oooool0
0ol0o`3oooooooooo`0Iooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooool0o`004_ooool0
1?l0o`3oooooooooool0o`08ooooo`Co0?l01?ooool2o`3o00;ooooo00?o0?l0ooooool0o`000_l0
o`02ooooo`0000?oooooo`3o0?l0o`000_l0o`000ooooooo0?l0o`3o0002ooooo`;o0?l01Oooool0
1Ol0o`3oooooo`3o0?oooooo0?l000kooooo00?o0?l0ooooool0o`005_ooool01Ol0o`3ooooooooo
oooooooo0?l000?ooooo00?o0?l0ooooooooool0?_ooool00ol0003oooooooooo`0`ooooo`03o`3o
0?oooooooooo01Sooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooo`3o000Booooo`04o`3o
0?ooooooooooo`3o00Sooooo1?l0o`04ooooo`;o0?l00_ooool5o`3o00;ooooo00000ooooooo0?l0
o`3o0002o`3o0003ooooool0o`3ooooo00;ooooo0_l0o`05ooooo`05o`3o0?oooooo0?l0ooooool0
o`003Oooool01?l0o`3oooooooooool0o`0Fooooo`05o`3o0?ooooooooooooooool0o`000_ooool0
0ol0o`3oooooooooo`0oooooo`03o`000?oooooooooo033ooooo00?o0?l0ooooooooool06Oooool0
0ol0o`3oooooooooo`02ooooo`03o`3o0?oooooo0?l001?ooooo00?o0?l0ooooool0o`002?ooool4
o`3o00Cooooo0ol0o`000ooooooo0?l0o`3o0003o`3o00;ooooo00000ooooooo0?l0o`3o0004o`3o
00?ooooo0_l0o`04ooooo`06o`3o0?ooooooooooo`3o0?oooooo0?l03Oooool01?l0o`3ooooooooo
ool0o`0Fooooo`04o`3o0?ooooooooooo`3o00?ooooo00?o0?l0ooooooooool0?oooool00ol0003o
ooooooooo`0`ooooo`03o`3o0?oooooooooo01Wooooo00?o0?l0ooooooooool00_ooool00ol0o`3o
ooooo`3o000Cooooo`03o`3o0?oooooo0?l000Sooooo00Co0?l0ooooool0o`3o0?l01Oooool2o`3o
0003ooooool0o`3o0?l000?o0?l00_ooool00003ooooool0o`3o0?l000Co0?l00oooool2o`3o00Co
oooo00Ko0?l0oooooooooooo0?l0ooooool0o`0=ooooo`04o`3o0?ooooooooooo`3o01Kooooo00Co
0?l0oooooooooooo0?l00_ooool00ol0o`3oooooooooo`10ooooo`;o0000<_ooool00ol0o`3ooooo
ooooo`0Hooooo`03o`3o0?oooooooooo00;ooooo00Co0?l0oooooooooooo0?l04_ooool00ol0o`3o
ooooo`3o0009ooooo`Co0?l01?ooool2o`3o0003ooooool0o`3o0?l000?o0?l00_ooool00005oooo
ool0o`3o0?l0o`3o0?ooool00_l0o`03ooooo`;o0?l01?ooool01_l0o`3oooooooooool0o`3ooooo
o`3o00Oooooo0_l000001Ol@413ooooooooooooooooo0?l000;ooooo00?o0?l0ooooooooool05?oo
ool01?l0o`3oooooooooool0o`02ooooo`03o`3o0?oooooooooo00_ooooo1Ol0000`ooooo`03o`00
0?oooooooooo033ooooo00?o0000o`3o0?l000000_l0000Hooooo`05o`3o0?ooooooooooooooool0
o`000_ooool00ol0o`3oooooooooo`0@ooooo`04o`3o0?l0003o0000o`3o00Sooooo1?l0o`04oooo
o`;o0?l000Coooooo`3o0?l0o`3ooooo0_l0o`02ooooo`0000Goooooo`3o0?l0o`3o0?l0ooooo`02
o`3o00?ooooo0_l0o`04ooooo`06o`3o0?ooooooooooo`3o0?oooooo0?l02?ooool00ol0003ooooo
ooooo`02ooooo`04o`3o0?ooooooooooo`3o01Gooooo00Go0?l0ooooooooooooooooo`3o0002oooo
o`03o`3o0?oooooooooo00_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00`ooooo`03o`000?oooooo
oooo033ooooo00GoV9RHo`3o0?o^k^koooooodA4A00Hooooo`05o`3o0?ooooooooooooooool0o`00
0_ooool00ol0o`3oooooooooo`0@ooooo`04o`3o0?oooooo0000o`3o00Sooooo1?l0o`04ooooo`;o
0?l000Coooooo`3o0?l0o`3ooooo0_l0o`02ooooo`0000Goooooo`3o0?l0o`3o0?l0ooooo`02o`3o
00?ooooo0_l0o`04ooooo`06o`3o0?ooooooooooo`3o0?l0003o0?l00ol00002ooooo`Go00000ooo
ool01?l0o`3oooooooooool0o`0Eooooo`05o`3o0?ooooooooooooooool0o`000_ooool00ol0o`3o
ooooooooo`03ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0aooooo`03o`000?oooooooooo037o
oooo00?oV9RHo`3o0?o^k^h06Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooo0?l0017o
oooo00Go0000o`3o0?l0003o0000o`3o0008ooooo`Co0?l01?ooool2o`3o0003ooooool0o`3o0?l0
00?o0?l00_ooool00005ooooool0o`3oooooo`3o0?ooool00_l0o`02ooooo`03o`3o0?oooooo0?l0
00Cooooo00Go0?l0ooooool0o`3oooooo`3o0006ooooo`04odA4A?oMgMgoooooo`0000Cooooo00?o
0?l0ooooool0o`005_ooool01Ol0o`3ooooooooooooooooo0?l000;ooooo00?o0?l0ooooooooool0
3Oooool00onHV9So8B4Qonk^kP0`ooooo`03o`000?oooooooooo03;ooooo00?o0?l0ob4Q8Oo^k^h0
6?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooo0?l0017ooooo00GoA4A4o`3o0?oooooo
0000o`3o0008ooooo`Co0?l01?ooool2o`3o00;ooooo1?l0o`02ooooo`0000Goooooo`3o0?oooooo
0?l0ooooo`02o`3o00;ooooo00?o0?l0ooooool0o`001?ooool01Ol0o`3oooooo`3o0?oooooo0?l0
00Kooooo00CogMgMoeEEEOoooooo00001?ooool00ol0o`3oooooo`3o000Fooooo`04o`3o0?oooooo
ooooo`3o00?ooooo00?o0?l0ooooooooool03_ooool00omgMgOoIVIVooooo`0_ooooo`03o`000?oo
oooooooo03;ooooo00?o0?l0ogMgMomVIVH06?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oo
oooo0?l0017ooooo00GogMgMo`3o0?oooooo0000o`3o0008ooooo`Co0?l01?ooool2o`3o00;ooooo
1Ol0o`01ooooo`0000Goooooo`3o0?oooooo0?l0ooooo`02o`3o00;ooooo00?o0?l0ooooool0o`00
1?ooool01Ol0o`3oooooo`3o0?oooooo0?l000Oooooo00?oMgMgolc<c?l000001?ooool00ol0o`3o
ooooo`3o000Fooooo`04o`3o0?ooooooooooo`3o00;ooooo00?o0?l0ooooooooool04?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo03?ooooo00?o0?l0o`000?ooool05oooool00ol0
o`3oooooooooo`02ooooo`03o`3o0?oooooo0?l001;ooooo00Co0?l0olc<c?l0003o0?l02Oooool3
o`3o00Cooooo0_l0o`02ooooo`Go0?l00Oooool000;o0?l000?oooooo`3o0?ooool00_l0o`02oooo
o`?o0?l01?ooool01Ol0o`3oooooo`3o0?oooooo0?l000Oooooo00?ok^k^odA4A?l000000oooool0
1?l0o`3oooooooooool0o`0Eooooo`05o`3o0?ooooooooooooooool0o`000_ooool00ol0o`3ooooo
ooooo`0<ooooo`05o`000?nj^[[ooooooiRHV?l@4100<?ooool00ol0003oooooooooo`0`ooooo`05
o`000?nj^[[oooooo`3o0?l@41006?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooo0?l0
01;ooooo00Co0?l0odA4A?l0003o0?l02Oooool3o`3o00Cooooo0_l0o`02ooooo`Go0?l00Oooool0
00;o0?l000?oooooo`3o0?ooool00_l0o`02ooooo`;o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo
0?l000Sooooo00?oMgMgo`000?ooool00_ooool01?l0o`3oooooooooool0o`0Eooooo`05o`3o0?oo
ooooooooooooool0o`000_ooool00ol0o`3oooooooooo`0<ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0<?ooool00ol0003oooooooooo`0`ooooo`05oiRHV?l@413o0000o`3o0?o<c<`06?ooool00ol0
o`3oooooooooo`02ooooo`03o`3o0?oooooo0?l001?ooooo00?o0?l0o`000?l0o`002Oooool3o`3o
00Cooooo0_l0o`02ooooo`Go0?l00Oooool000;o0?l000?oooooo`3o0?ooool00_l0o`02ooooo`;o
0?l01Oooool01Ol0o`3oooooo`3o0?oooooo0?l000gooooo00Co0?l0oooooooooooo0?l05Oooool0
1Ol0o`3ooooooooooooooooo0?l000;ooooo00?o0?l0ooooooooool0@Oooool00ol0003ooooooooo
o`0cooooo`03o`3o0?oooooooooo01Kooooo00Co0000o`3o0?l0003o00000_ooool00ol0o`3ooooo
o`3o000Cooooo`03o`3o0?oooooo0?l000Wooooo0ol0o`04ooooo`;o0?l00_ooool5o`3o007ooooo
0002o`3o0003ooooool0o`3ooooo00;o0?l00_ooool2o`3o00Gooooo00Go0?l0ooooool0o`3ooooo
o`3o000=ooooo`04o`3o0?ooooooooooo`3o01Gooooo00Go0?l0ooooooooooooooooo`3o0002oooo
o`03o`3o0?oooooooooo047ooooo00?o0000ooooooooool0<oooool00ol0o`3oooooooooo`0Eoooo
o`?o000000Oo0?l0o`000?l0003oooooo`3o0?oooooo0?l001?ooooo00?o0?l0ooooool0o`002Ooo
ool00ol0o`3oooooo`3o0004ooooo`;o0?l00_ooool5o`3o007ooooo0002o`3o0003ooooool0o`3o
oooo00;o0?l00_ooool2o`3o00Gooooo00Go0?l0ooooool0o`3oooooo`3o000=ooooo`04o`3o0?oo
ooooooooo`3o01Gooooo00Go0?l0ooooooooooooooooo`3o0002ooooo`03o`3o0?oooooooooo047o
oooo00?o0000ooooooooool0<oooool00ol0o`3oooooooooo`0Dooooo`Co000000Go0?l0o`000?l0
003o0000ooooo`02o`3o01?ooooo00?o0?l0ooooool0o`002Oooool3o`3o00Cooooo0_l0o`02oooo
o`Go0?l00Oooool000Co0?l000?oooooo`3o0?l0o`000_ooool2o`3o00Gooooo00Go0?l0ooooool0
o`3oooooo`3o000=ooooo`04o`3o0?ooooooooooo`3o01Gooooo00Go0?l0ooooooooooooooooo`3o
0002ooooo`03o`3o0?oooooooooo047ooooo00?o0000ooooooooool0<oooool00ol0o`3ooooooooo
o`0Dooooo`Co000000Go0?l0o`000?l0003o0000ooooo`02o`3o01?ooooo00?o0?l0ooooool0o`00
2Oooool3o`3o00Cooooo0_l0o`02ooooo`Go0?l00Oooool000Co0?l000?o0000o`3o0?l0o`000_l0
0002o`3o00Go000000Go0?l0o`000?l0o`3o0000o`3o000=o`000004o`3o0?l0003o0000o`3o01Go
000000Go0?l0o`000?l0003o0000o`3o0002o`000003o`3o0?l0003o000007Oo000000?o0?l0o`00
0?l000006?l000000ol0o`3o0000o`000002o`0000;o0?l04ol000000ol0o`3o0000o`3o0009o`00
00?o0?l01?l00002o`3o00;o00001Ol0o`01o`0000001?l0o`000ooooooo0?l0o`3o0002ooooo`;o
0?l00_ooool02?l0003oooooooooool0o`3oooooo`3o0?oooooo0?l01Oooool00ol0003ooooooooo
o`05ooooo`04o`3o0?ooooooooooo`3o00;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`03ooooo`05o`3o0?ooooooooooooooool0o`000_ooool00ol0o`3o0000ooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0o`3oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo2?l000000ooooooo0?l0o`3o0006ooooo`03o`000?oooooooooo00[o
oooo00?o0?l0o`000?l0o`002Oooool3o`3o00Cooooo0_l0o`02ooooo`Go0?l00Oooool000;o0?l0
00?oooooo`3o0?ooool00_l0o`02ooooo`;o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo0?l000Go
oooo00?o0000ooooooooool01Oooool01?l0o`3oooooooooool0o`0Eooooo`05o`3o0?oooooooooo
ooooool0o`000_ooool00ol0o`3oooooooooo`0;ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0<oooool00ol0o`3oooooooooo`0Eooooo`Ko00000_ooool2o`3o01?ooooo00?o0?l0
o`000?l0o`002Oooool3o`3o00Cooooo0_l0o`02ooooo`Go0?l00Oooool000;o0?l000?oooooo`3o
0?ooool00_l0o`02ooooo`;o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo0?l000gooooo00Co0?l0
oooooooooooo0?l05Oooool01Ol0o`3ooooooooooooooooo0?l000;ooooo00?o0?l0ooooooooool0
@Oooool00ol0003oooooooooo`0cooooo`03o`3o0?oooooooooo01Kooooo1?l00003ooooo`;o0?l0
4oooool00ol0o`3oooooo`3o0009ooooo`?o0?l01?ooool2o`3o00;ooooo1Ol0o`01ooooo`000_l0
o`000ooooooo0?l0ooooo`02o`3o00;ooooo0_l0o`05ooooo`05o`3o0?oooooo0?l0ooooool0o`00
3Oooool01?l0o`3oooooooooool0o`0Eooooo`05o`3o0?ooooooooooooooool0o`000_ooool00ol0
o`3oooooooooo`11ooooo`03o`000?oooooooooo03?ooooo00?o0?l0ooooooooool07Oooool2o`3o
01?ooooo00?o0?l0ooooool0o`002Oooool00ol0o`3oooooo`3o0004ooooo`;o0?l00_ooool5o`3o
007ooooo0002o`3o0003ooooool0o`3ooooo00;o0?l00_ooool2o`3o00Gooooo00Go0?l0ooooool0
o`3oooooo`3o000=ooooo`04o`3o0?ooooooooooo`3o01Gooooo00Go0?l0ooooooooooooooooo`3o
0002ooooo`03o`3o0?oooooooooo047ooooo00?o0000ooooooooool0<oooool00ol0o`3ooooooooo
o`0Looooo`03o`3o0?oooooo0?l001?ooooo00?o0?l0ooooool0o`002Oooool00ol0o`3oooooo`3o
0004ooooo`;o0?l00_ooool5o`3o007ooooo00001Ooooooo0?l0ooooool0o`3ooooo00;o0?l00_oo
ool3o`3o00Cooooo00Go0?l0ooooool0o`3oooooo`3o000=ooooo`04o`3o0?ooooooooooo`3o01Go
oooo00Go0?l0ooooooooooooooooo`3o0002ooooo`03o`3o0?oooooooooo047ooooo00?o0000oooo
ooooool0<oooool00ol0o`3oooooooooo`0Looooo`03o`3o0?oooooo0?l001?ooooo00?o0?l0oooo
ool0o`002Oooool00ol0o`3oooooo`3o0004ooooo`;o0?l00_ooool5o`3o007ooooo00001Ooooooo
0?l0ooooool0o`3ooooo00;o0?l00_ooool3o`3o00Cooooo00Go0?l0ooooool0o`3oooooo`3o000=
ooooo`04o`3o0?ooooooooooo`3o01Gooooo00Go0?l0ooooooooooooooooo`3o0002ooooo`03o`3o
0?oooooooooo047ooooo00?o0000ooooooooool0<oooool00ol0o`3oooooooooo`0Looooo`03o`3o
0?oooooo0?l001?ooooo00?o0?l0ooooool0o`002Oooool3o`3o00Cooooo0_l0o`02ooooo`03o`3o
0?oooooo0?l000;o0?l00Oooool00005ooooool0o`3oooooo`3o0?ooool00_l0o`02ooooo`?o0?l0
1?ooool01Ol0o`3oooooo`3o0?oooooo0?l000gooooo00Co0?l0oooooooooooo0?l05_ooool01?l0
o`3oooooooooool0o`03ooooo`03o`3o0?oooooooooo043ooooo00?o0000ooooooooool0<_ooool0
0ol0o`3oooooooooo`0Mooooo`03o`3o0?oooooo0?l001?ooooo00?o0?l0ooooool0o`002?ooool4
o`3o00Cooooo0_l0o`02ooooo`03o`3o0?oooooo0?l000;o0?l00Oooool00005ooooool0o`3ooooo
o`3o0?ooool00_l0o`02ooooo`03o`3o0?oooooo0?l000Cooooo00Go0?l0ooooool0o`3oooooo`3o
000>ooooo`03o`3o0?oooooo0?l001Kooooo00Co0?l0oooooooooooo0?l00oooool00ol0o`3ooooo
ooooo`10ooooo`03o`000?oooooooooo03;ooooo00?o0?l0ooooooooool07Oooool00ol0o`3ooooo
o`3o000Booooo`04o`3o0?ooooooooooo`3o00Sooooo1?l0o`04ooooo`;o0?l00_ooool00ol0o`3o
ooooo`3o0002o`3o007ooooo00001Ooooooo0?l0ooooool0o`3ooooo00;o0?l00_ooool00ol0o`3o
ooooo`3o0004ooooo`03o`3o0?oooooooooo00;o0?l03_ooool00ol0o`3oooooo`3o000Fooooo`04
o`3o0?ooooooooooo`3o00?ooooo00?o0?l0ooooooooool0@?ooool00ol0003oooooooooo`0aoooo
o`03o`3o0?oooooooooo01kooooo00?o0?l0ooooool0o`004_ooool01?l0o`3oooooooooool0o`08
ooooo`Co0?l01?ooool2o`3o00;ooooo00?o0?l0ooooool0o`000_l0o`01ooooo`0000Goooooo`3o
0?l0o`3o0?l0ooooo`02o`3o00?ooooo0_l0o`04ooooo`03o`3o0?oooooooooo00;o0?l03_ooool0
1?l0o`3oooooooooool0o`0Eooooo`05o`3o0?ooooooooooooooool0o`000_ooool00ol0o`3ooooo
ooooo`10ooooo`03o`000?oooooooooo037ooooo00?o0?l0ooooooooool07_ooool00ol0o`3ooooo
o`3o000Booooo`04o`3o0?ooooooooooo`3o00Sooooo1?l0o`04ooooo`;o0?l000Coooooo`3o0?l0
o`3ooooo0ol0o`01ooooo`0000Goooooo`3o0?l0o`3o0?l0ooooo`02o`3o00?ooooo0_l0o`04oooo
o`03o`3o0?oooooooooo00;o0?l03_ooool01?l0o`3oooooooooool0o`0Eooooo`05o`3o0?oooooo
ooooooooool0o`000oooool00ol0o`3oooooooooo`0oooooo`03o`000?oooooooooo037ooooo00?o
0?l0ooooooooool07Oooool01?l0o`3oooooooooool0o`0Booooo`03o`3o0?oooooo0?l000Wooooo
0ol0o`04ooooo`?o0?l000Coooooo`3o0?l0o`3ooooo0ol0o`01ooooo`0000Goooooo`3o0?l0o`3o
0?l0ooooo`02o`3o00?ooooo0_l0o`04ooooo`06o`3o0?ooooooooooo`3o0?oooooo0?l03Oooool0
1?l0o`3oooooooooool0o`0Eooooo`05o`3o0?ooooooooooooooool0o`000oooool00ol0o`3ooooo
ooooo`0oooooo`;o0000<Oooool00ol0o`3oooooooooo`0Nooooo`04o`3o0?ooooooooooo`3o01;o
oooo00?o0?l0ooooool0o`002Oooool3o`3o00Cooooo0ol0o`001?oooooo0?l0o`3o0?ooool2o`3o
00;ooooo00001?oooooo0?l0o`3o0?ooool4o`3o00;ooooo0_l0o`05ooooo`05o`3o0?oooooo0?l0
ooooool0o`003Oooool01?l0o`3oooooooooool0o`0Eooooo`03o`3o0?oooooooooo00;ooooo00Go
0?l0ooooooooooooooooo`3o0010ooooo`03o`000?oooooooooo033ooooo00?o0?l0ooooooooool0
7_ooool01?l0o`3oooooooooool0o`0Booooo`03o`3o0?oooooo0?l000Wooooo0ol0o`04ooooo`?o
0?l000Coooooo`3o0?l0o`3ooooo0_l0o`02ooooo`0000Coooooo`3o0?l0o`3ooooo1?l0o`02oooo
o`;o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo0?l000gooooo00Co0?l0oooooooooooo0?l05_oo
ool01Ol0o`3ooooooooooooooooo0?l000?ooooo00?o0?l0ooooooooool0?_ooool00ol0003ooooo
ooooo`0`ooooo`03o`3o0?oooooooooo01kooooo00?o0?l0ooooool0o`004oooool00ol0o`3ooooo
o`3o0009ooooo`?o0?l01?ooool3o`3o0004ooooool0o`3o0?l0ooooo`;o0?l00_ooool00006oooo
ool0o`3o0?l0ooooool0o`3ooooo0_l0o`02ooooo`;o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo
0?l000kooooo00?o0?l0ooooool0o`005_ooool01Ol0o`3ooooooooooooooooo0?l000?ooooo00?o
0?l0ooooooooool0?_ooool00ol0003oooooooooo`0_ooooo`03o`3o0?oooooooooo01oooooo00?o
0?l0ooooool0o`004oooool00ol0o`3oooooo`3o0009ooooo`03o`3o0?oooooo0?l000Cooooo0_l0
o`02ooooo`Go0?l00_ooool00006ooooool0o`3o0?l0ooooool0o`3ooooo0_l0o`02ooooo`?o0?l0
1?ooool01Ol0o`3oooooo`3o0?oooooo0?l000kooooo00?o0?l0ooooool0o`005_ooool01Ol0o`3o
oooooooooooooooo0?l000Cooooo00?o0?l0ooooooooool0?Oooool00ol0003oooooooooo`0^oooo
o`03o`3o0?oooooooooo023ooooo00?o0?l0ooooool0o`004_ooool01?l0o`3oooooooooool0o`09
ooooo`03o`3o0?oooooo0?l000Cooooo0_l0o`02ooooo`Go0?l00_ooool00006ooooool0o`3o0?l0
ooooool0o`3ooooo0_l0o`02ooooo`?o0?l01?ooool00ol0o`3oooooo`3o0002ooooo`03o`3o0?oo
oooooooo00_ooooo00?o0?l0ooooool0o`005_ooool01Ol0o`3ooooooooooooooooo0?l000Cooooo
00?o0?l0ooooooooool0?Oooool00ol0003oooooooooo`0^ooooo`03o`3o0?oooooooooo023ooooo
0_l0o`0Cooooo`04o`3o0?ooooooooooo`3o00Sooooo0ol0o`05ooooo`;o0?l00_ooool5o`3o00;o
oooo00001_oooooo0?l0o`3o0?oooooo0?l0ooooo`;o0?l00oooool2o`3o00Gooooo0_l0o`02oooo
o`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooool0o`005oooool01?l0o`3oooooooooool0o`05
ooooo`03o`3o0?oooooooooo03cooooo00?o0000ooooooooool0;Oooool00ol0o`3oooooooooo`0P
ooooo`03o`3o0?oooooo0?l001?ooooo00Co0?l0oooooooooooo0?l02?ooool3o`3o00Cooooo0ol0
o`02ooooo`03o`3o0?oooooo0?l000;o0?l00_ooool00004ooooool0o`3o0?l0ooooo`Co0?l00ooo
ool2o`3o00Gooooo0_l0o`02ooooo`03o`3o0?oooooooooo00cooooo00?o0?l0ooooool0o`005_oo
ool01Ol0o`3ooooooooooooooooo0?l000Cooooo00?o0?l0ooooooooool0??ooool00ol0003ooooo
ooooo`0/ooooo`03o`3o0?oooooooooo027ooooo00?o0?l0ooooool0o`004oooool00ol0o`3ooooo
o`3o0009ooooo`?o0?l01?ooool3o`3o00;ooooo00Co0?l0ooooool0o`3o0?l00oooool000;ooooo
1_l0o`03ooooo`;o0?l01Oooool2o`3o00;ooooo00?o0?l0ooooooooool03?ooool00ol0o`3ooooo
o`3o000Fooooo`05o`3o0?ooooooooooooooool0o`001Oooool00ol0o`3oooooooooo`0kooooo`03
o`000?oooooooooo02_ooooo00?o0?l0ooooooooool08_ooool00ol0o`3oooooo`3o000Cooooo`03
o`3o0?oooooo0?l000Wooooo0ol0o`04ooooo`;o0?l00_ooool2o`3o0003ooooool0o`3o0?l000?o
oooo0002ooooo`Co0?l000?oooooo`3o0?ooool00_ooool2o`3o00Gooooo00Go0?l0ooooool0o`3o
ooooo`3o000>ooooo`03o`3o0?oooooo0?l001Oooooo00Co0?l0oooooooooooo0?l01Oooool00ol0
o`3oooooooooo`0kooooo`03o`000?oooooooooo02[ooooo00?o0?l0ooooooooool08_ooool00ol0
o`3oooooo`3o000Cooooo`04o`3o0?ooooooooooo`3o00Wooooo0ol0o`04ooooo`;o0?l00_ooool5
o`3o00?ooooo0002ooooo`;o0?l000?oooooo`3o0?ooool00_l0o`02ooooo`?o0?l01?ooool00ol0
o`3oooooo`3o0002ooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooool0o`006?ooool01?l0
o`3oooooooooool0o`05ooooo`03o`3o0?oooooooooo03[ooooo00?o0000ooooooooool0:Oooool0
0ol0o`3oooooooooo`0Sooooo`03o`3o0?oooooo0?l001?ooooo00?o0?l0ooooool0o`002Oooool0
1?l0o`3oooooo`3o0?l0o`04ooooo`;o0?l00_ooool5o`3o00?ooooo0002ooooo`;o0?l000?ooooo
o`3o0?ooool00_l0o`03ooooo`;o0?l01?ooool00ol0o`3oooooo`3o0002ooooo`03o`3o0?oooooo
oooo00_ooooo00Co0?l0oooooooooooo0?l05oooool01?l0o`3oooooooooool0o`06ooooo`03o`3o
0?oooooooooo03Wooooo00?o0000ooooooooool0:?ooool00ol0o`3oooooooooo`0Tooooo`03o`3o
0?oooooo0?l001?ooooo00?o0?l0ooooool0o`002Oooool3o`3o00Gooooo0_l0o`02ooooo`Go0?l0
0oooool000;ooooo0_l0o`000ooooooo0?l0ooooo`02o`3o00?ooooo0_l0o`05ooooo`;o0?l00_oo
ool00ol0o`3oooooooooo`0<ooooo`03o`3o0?oooooo0?l001Sooooo00?o0?l0ooooool0o`001ooo
ool00ol0o`3oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo00?o0?l0ooooooooool09?oo
ool01?l0o`3oooooooooool0o`0Cooooo`03o`3o0?oooooo0?l000Wooooo0ol0o`04ooooo`?o0?l0
00Coooooo`3o0?l0o`3ooooo0ol0o`03ooooo`000_ooool01Ol0o`3oooooo`3o0?l0o`3ooooo00?o
0?l00_ooool2o`3o00Gooooo00Go0?l0ooooool0o`3oooooo`3o000>ooooo`03o`3o0?oooooo0?l0
01Sooooo00Co0?l0oooooooooooo0?l01oooool00ol0o`3oooooooooo`0gooooo`03o`000?oooooo
oooo02Gooooo0_l0o`0Wooooo`03o`3o0?oooooo0?l001Cooooo00?o0?l0ooooool0o`002?ooool0
1?l0o`3oooooo`3o0?l0o`04ooooo`?o0?l000Coooooo`3o0?l0o`3ooooo0ol0o`03ooooo`000ooo
ool7o`3o00;ooooo0ol0o`04ooooo`05o`3o0?oooooo0?l0ooooool0o`003_ooool00ol0o`3ooooo
o`3o000Hooooo`04o`3o0?ooooooooooo`3o00Sooooo00?o0?l0ooooooooool0=_ooool2o`0002Co
oooo0_l0o`0Xooooo`04o`3o0?ooooooooooo`3o01?ooooo00?o0?l0ooooool0o`002Oooool4o`3o
00Cooooo0_l0o`02ooooo`Go0?l01?ooool000?ooooo0_l0o`000ooooooo0?l0ooooo`02o`3o00;o
oooo00?o0?l0ooooool0o`001?ooool01Ol0o`3oooooo`3o0?oooooo0?l000kooooo00Co0?l0oooo
oooooooo0?l06?ooool01?l0o`3oooooooooool0o`08ooooo`03o`3o0?oooooooooo03Gooooo00?o
0000ooooooooool08_ooool00ol0o`3oooooooooo`0Xooooo`04o`3o0?ooooooooooo`3o01?ooooo
00?o0?l0ooooool0o`002Oooool4o`3o00Cooooo0_l0o`02ooooo`?o0?l000?oooooo`3o0?ooool0
0oooool000?ooooo0_l0o`000ooooooo0?l0ooooo`02o`3o00;ooooo00?o0?l0ooooool0o`001?oo
ool01_l0o`3oooooooooool0o`3oooooo`3o00kooooo00?o0?l0ooooool0o`006?ooool01?l0o`3o
ooooooooool0o`09ooooo`;o0?l0=Oooool00ol0003oooooooooo`0Pooooo`;o0?l0:oooool00ol0
o`3oooooo`3o000Dooooo`03o`3o0?oooooo0?l000Sooooo00Co0?l0ooooool0o`3o0?l01Oooool2
o`3o00;ooooo1Ol0o`04ooooo`000oooool2o`3o0003ooooool0o`3ooooo00;o0?l00oooool2o`3o
00Gooooo00Go0?l0ooooool0o`3oooooo`3o000>ooooo`03o`3o0?oooooo0?l001Sooooo00Go0?l0
ooooooooooooooooo`3o000:ooooo`03o`3o0?oooooooooo03;ooooo00?o0000ooooooooool07_oo
ool2o`3o02cooooo00Co0?l0oooooooooooo0?l05?ooool00ol0o`3oooooo`3o0008ooooo`;o0?l0
00?oooooo`3o0?ooool00oooool3o`3o0004ooooool0o`3o0?l0ooooo`?o0?l01?ooool000Cooooo
0ol0o`001?oooooo0?l0o`3o0?l0o`02ooooo`?o0?l01?ooool01Ol0o`3oooooo`3o0?oooooo0?l0
00kooooo00Co0?l0oooooooooooo0?l06?ooool01?l0o`3oooooooooool0o`0;ooooo`;o0?l0<_oo
ool00ol0003oooooooooo`0Mooooo`03o`3o0?oooooooooo02cooooo00?o0?l0ooooool0o`005?oo
ool01?l0o`3oooooooooool0o`08ooooo`;o0?l000?oooooo`3o0?ooool00oooool3o`3o0003oooo
ool0o`3o0?l000Co0?l01?ooool000Cooooo1ol0o`02ooooo`03o`3o0?oooooo0?l000Cooooo00?o
0?l0ooooooooool00_l0o`0?ooooo`03o`3o0?oooooo0?l001Wooooo00Co0?l0oooooooooooo0?l0
3?ooool00ol0o`3oooooooooo`0_ooooo`03o`000?oooooooooo01_ooooo0_l0o`0^ooooo`04o`3o
0?ooooooooooo`3o01Cooooo00?o0?l0ooooool0o`002Oooool4o`3o00Cooooo0_l0o`02ooooo`Co
0?l000?oooooo`3o0?ooool00oooool000Cooooo1?l0o`000ooooooo0?l0o`3o0003ooooo`;o0?l0
1Oooool01Ol0o`3oooooo`3o0?oooooo0?l000kooooo00?o0?l0ooooool0o`006Oooool01Ol0o`3o
oooooooooooooooo0?l000cooooo0_l0o`0_ooooo`03o`000?oooooooooo01Sooooo0ol0o`0`oooo
o`03o`3o0?oooooo0?l001Gooooo00?o0?l0ooooool0o`002?ooool00ol0o`3oooooo`3o0002o`3o
00?ooooo00?o0?l0ooooool0o`000_ooool00ol0o`3oooooo`3o0002o`3o00Gooooo0004ooooo`05
o`3o0?oooooo0?l0o`3o0?ooool00_l0o`03ooooo`;o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo
0?l000kooooo00Co0?l0oooooooooooo0?l06Oooool01?l0o`3oooooooooool0o`0>ooooo`;o0?l0
;Oooool00ol0003oooooooooo`0Eooooo`?o0?l0<_ooool01?l0o`3oooooooooool0o`0Dooooo`04
o`3o0?ooooooooooo`3o00Sooooo0_l0o`000ooooooo0?l0ooooo`03ooooo`?o0?l00_ooool00ol0
o`3oooooo`3o0002o`3o00Gooooo0005ooooo`Ko0?l00oooool3o`3o00Cooooo00?o0?l0oooooooo
ool00_l0o`0?ooooo`03o`3o0?oooooo0?l001[ooooo00Co0?l0oooooooooooo0?l03oooool3o`3o
02[ooooo00?o0000ooooooooool04Oooool4o`3o03Gooooo00?o0?l0ooooool0o`005Oooool01?l0
o`3oooooooooool0o`08ooooo`;o0?l000?oooooo`3o0?ooool00oooool2o`3o00;ooooo1?l0o`00
0ooooooo0?l0ooooo`04ooooo`001Oooool4o`3o0003ooooool0o`3ooooo00;ooooo00?o0?l0oooo
ool0o`001Oooool01Ol0o`3oooooo`3o0?oooooo0?l000kooooo00?o0?l0ooooool0o`006oooool0
0ol0o`3oooooo`3o000Booooo`?o0?l09oooool00ol0003oooooooooo`0>ooooo`?o0?l0>?ooool0
1?l0o`3oooooooooool0o`0Dooooo`04o`3o0?ooooooooooo`3o00Wooooo1?l0o`04ooooo`;o0?l0
0_ooool01_l0o`3oooooo`3o0?l0o`3oooooo`3o00Gooooo0005ooooo`;o0?l000?oooooo`3o0?oo
ool00_l0o`03ooooo`;o0?l01Oooool01Ol0o`3oooooo`3o0?oooooo0?l000kooooo00Co0?l0oooo
oooooooo0?l06_ooool01?l0o`3oooooooooool0o`0Dooooo`Co0?l08oooool00ol0003ooooooooo
o`0:ooooo`Co0?l0>oooool00ol0o`3oooooo`3o000Eooooo`04o`3o0?ooooooooooo`3o00Sooooo
0_l0o`000ooooooo0?l0o`3o0003ooooo`03o`3o0?oooooo0?l000;ooooo00?o0?l0ooooool0o`00
0_l0o`06ooooo`001Oooool00ol0o`3oooooo`3o0004o`3o00?ooooo0ol0o`04ooooo`03o`3o0?oo
oooooooo00;o0?l03oooool00ol0o`3oooooo`3o000Kooooo`04o`3o0?ooooooooooo`3o01Oooooo
1?l0o`0Oooooo`03o`000?oooooooooo00Oooooo0ol0o`0nooooo`04o`3o0?ooooooooooo`3o01Go
oooo00?o0?l0ooooool0o`002Oooool2o`3o0003ooooool0o`3ooooo00?ooooo0ol0o`02ooooo`?o
0?l000?oooooo`3o0?ooool01Oooool000Kooooo1?l0o`000ooooooo0?l0ooooo`02ooooo`03o`3o
0?oooooo0?l000Gooooo00Go0?l0ooooool0o`3oooooo`3o000>ooooo`04o`3o0?ooooooooooo`3o
01_ooooo00Co0?l0oooooooooooo0?l06_ooool3o`3o01cooooo00?o0000ooooooooool00oooool4
o`3o043ooooo00Co0?l0oooooooooooo0?l05Oooool01?l0o`3oooooooooool0o`09ooooo`Co0?l0
1?ooool2o`3o00;ooooo00Ko0?l0ooooool0o`3o0?l0ooooool0o`06ooooo`001_ooool2o`3o0003
ooooool0o`3ooooo00;o0?l00oooool2o`3o00Gooooo00Go0?l0ooooool0o`3oooooo`3o000?oooo
o`03o`3o0?oooooo0?l001_ooooo00Co0?l0oooooooooooo0?l07OoooolRo`3o04?ooooo00Go0?l0
ooooooooooooooooo`3o000Eooooo`03o`3o0?oooooo0?l000Wooooo0_l0o`000ooooooo0?l0o`3o
0003ooooo`03o`3o0?oooooo0?l000;ooooo00?o0?l0ooooool0o`000_l0o`07ooooo`001_ooool0
0ol0o`3oooooo`3o0004o`3o00?ooooo0_l0o`06ooooo`04o`3o0?oooooo0?l0o`3o00oooooo00Co
0?l0oooooooooooo0?l06oooool01?l0o`3oooooooooool0o`0hooooo`03o`000?oooooooooo04Ko
oooo00Co0?l0oooooooooooo0?l05Oooool01?l0o`3oooooooooool0o`09ooooo`Co0?l01?ooool3
o`3o00;ooooo0ol0o`000ooooooo0?l0ooooo`06ooooo`001oooool4o`3o0003ooooool0o`3ooooo
00;ooooo00?o0?l0ooooool0o`001Oooool01Ol0o`3oooooo`3o0?oooooo0?l000oooooo00Co0?l0
oooooooooooo0?l06oooool01?l0o`3oooooooooool0o`0gooooo`03o`000?oooooooooo04Gooooo
00Go0?l0ooooooooooooooooo`3o000Eooooo`04o`3o0?ooooooooooo`3o00Sooooo00?o0?l0oooo
ool0o`000_l0o`04ooooo`;o0?l00_ooool5o`3o00Sooooo0007ooooo`;o0?l000?oooooo`3o0?oo
ool00_l0o`03ooooo`;o0?l01_ooool2o`3o0003ooooool0o`3ooooo00kooooo00Co0?l0oooooooo
oooo0?l07?ooool00ol0o`3oooooo`3o000gooooo`03o`000?oooooooooo04Cooooo00Go0?l0oooo
ooooooooooooo`3o000Eooooo`04o`3o0?ooooooooooo`3o00Wooooo0_l0o`000ooooooo0?l0o`3o
0003ooooo`?o0?l00_ooool00ol0o`3oooooo`3o0002o`3o00Sooooo0007ooooo`;o0?l000?ooooo
o`3o0?l0o`000_l0o`03ooooo`;o0?l01_ooool01Ol0o`3oooooo`3o0?oooooo0?l000oooooo00Co
0?l0oooooooooooo0?l07?ooool00ol0o`3oooooo`3o000fooooo`03o`000?oooooooooo04Cooooo
00Co0?l0oooooooooooo0?l05_ooool01?l0o`3oooooooooool0o`08ooooo`03o`3o0?oooooo0?l0
00;o0?l01?ooool3o`3o0003ooooool0o`3o0?l000;o0?l000?oooooo`3o0?ooool01oooool000So
oooo1?l0o`000ooooooo0?l0ooooo`02ooooo`03o`3o0?oooooo0?l000Gooooo00Go0?l0ooooool0
o`3oooooo`3o000?ooooo`04o`3o0?ooooooooooo`3o01gooooo0ol0o`0eooooo`03o`000?oooooo
oooo04?ooooo00Co0?l0oooooooooooo0?l05oooool00ol0o`3oooooo`3o0009ooooo`03o`3o0?oo
oooo0?l000;o0?l01?ooool01?l0o`3oooooo`3o0?ooool5o`3o00Wooooo0008ooooo`;o0?l000?o
ooooo`3o0?ooool00_l0o`03ooooo`;o0?l01_ooool01?l0o`3oooooo`3o0?l0o`0@ooooo`04o`3o
0?ooooooooooo`3o01kooooo0_l0o`0dooooo`03o`000?oooooooooo04;ooooo00Go0?l0oooooooo
ooooooooo`3o000Fooooo`04o`3o0?ooooooooooo`3o00Sooooo00Ko0?l0ooooool0o`3o0?l0oooo
ool0o`03ooooo`?o0?l00_ooool5o`3o00Wooooo0009ooooo`03o`3o0?oooooo0?l000?o0?l00ooo
ool00ol0o`3oooooo`3o0005ooooo`05o`3o0?oooooo0?l0ooooool0o`003oooool01?l0o`3ooooo
ooooool0o`0Oooooo`03o`3o0?oooooooooo03;ooooo00?o0000ooooooooool0@Oooool01Ol0o`3o
oooooooooooooooo0?l001Oooooo00?o0?l0ooooool0o`002Oooool00ol0o`3oooooo`3o0002o`3o
00Cooooo00Co0?l0ooooool0o`3ooooo1Ol0o`0:ooooo`002Oooool2o`3o0003ooooool0o`3ooooo
00;o0?l00oooool2o`3o00Kooooo0_l0o`000ooooooo0?l0ooooo`0?ooooo`04o`3o0?oooooooooo
o`3o01oooooo00?o0?l0ooooooooool0<Oooool00ol0003oooooooooo`10ooooo`05o`3o0?oooooo
ooooooooool0o`005oooool01?l0o`3oooooooooool0o`08ooooo`06o`3o0?ooooooooooo`3o0?oo
oooo0?l00oooool2o`3o0003ooooool0o`3ooooo00Go0?l02_ooool000[ooooo00Co0?l0ooooool0
o`3ooooo0_l0o`03ooooo`03o`3o0?oooooo0?l000Gooooo00Go0?l0ooooool0o`3oooooo`3o000?
ooooo`05o`3o0?ooooooooooooooool0o`007oooool00ol0o`3oooooooooo`0`ooooo`03o`000?oo
oooooooo03oooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0Eooooo`03o`3o0?oo
oooo0?l000Wooooo00?o0?l0ooooool0o`000_l0o`04ooooo`?o0?l00_ooool5o`3o00[ooooo000:
ooooo`03o`3o0?oooooo0?l000Co0?l00oooool2o`3o00Kooooo0_l0o`000ooooooo0?l0ooooo`0?
ooooo`04o`3o0?ooooooooooo`3o023ooooo00?o0?l0ooooooooool0;oooool00ol0003ooooooooo
o`0nooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooo`3o
0009ooooo`03o`3o0?oooooooooo00;o0?l01?ooool2o`3o0003ooooool0o`3ooooo00Go0?l02ooo
ool000[ooooo0_l0o`000ooooooo0?l0ooooo`02o`3o00?ooooo0ol0o`05ooooo`05o`3o0?oooooo
0?l0ooooool0o`003oooool01Ol0o`3ooooooooooooooooo0?l0023ooooo00?o0?l0ooooooooool0
9?ooool5o`0000Gooooo00?o0000ooooooooool0?Oooool00ol0o`3oooooooooo`02ooooo`03o`3o
0?oooooooooo01Gooooo00Co0?l0oooooooooooo0?l02Oooool00ol0o`3oooooooooo`02o`3o00Co
oooo0ol0o`02ooooo`03o`3o0?oooooo0?l000;o0?l02oooool000_ooooo00Co0?l0ooooool0o`3o
oooo0_l0o`03ooooo`03o`3o0?oooooo0?l000Kooooo0_l0o`02ooooo`03o`3o0?oooooooooo00go
oooo00Co0?l0oooooooooooo0?l08Oooool2o`3o02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005
ooooo`03o`000?oooooooooo03cooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0F
ooooo`03o`3o0?oooooo0?l000Wooooo00?o0?l0ooooooooool00_l0o`05ooooo`04o`3o0?oooooo
0?l0ooooo`Co0?l000?oooooo`3o0?ooool02_ooool000_ooooo0_l0o`000ooooooo0?l0ooooo`02
o`3o00?ooooo0_l0o`06ooooo`05o`3o0?oooooo0?l0ooooool0o`003oooool01Ol0o`3ooooooooo
oooooooo0?l0027ooooo0_l0o`0Tooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
>oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo01Kooooo00Co0?l0oooooooooooo
0?l02?ooool00ol0o`3oooooooooo`03o`3o00Cooooo0ol0o`02ooooo`03o`3o0?oooooo0?l000;o
0?l03?ooool000cooooo00Co0?l0ooooool0o`3ooooo0_l0o`03ooooo`03o`3o0?oooooo0?l000Ko
oooo0_l0o`02ooooo`03o`3o0?oooooooooo00gooooo00Go0?l0ooooooooooooooooo`3o000Qoooo
o`;o0?l09?ooool00onHV9So8B4Qonk^kP05ooooo`?o0000>Oooool2o`3o00?ooooo0_l0o`0Hoooo
o`04o`3o0?ooooooooooo`3o00Wooooo00?o0?l0ooooooooool00_l0o`05ooooo`;o0?l00_ooool6
o`3o00cooooo000<ooooo`Co0?l000?oooooo`3o0?l0o`000oooool2o`3o00Kooooo00Go0?l0oooo
ool0o`3oooooo`3o000?ooooo`05o`3o0?ooooooooooooooool0o`008_ooool2o`3o02Cooooo00?o
MgMgofIVI_ooool01?ooool00ol0003oooooooooo`0hooooo`03o`3o0?oooooooooo00;ooooo00?o
0?l0ooooooooool06?ooool01?l0o`3oooooooooool0o`08ooooo`03o`3o0?oooooooooo00;o0?l0
1Oooool3o`3o00;ooooo00Ko0?l0ooooool0o`3o0?l0ooooool0o`0<ooooo`003Oooool00ol0o`3o
ooooo`3o0002ooooo`07o`3o0?ooooooooooooooool0o`3oooooo`3o0006ooooo`05o`3o0?oooooo
0?l0ooooool0o`003oooool01Ol0o`3ooooooooooooooooo0?l002?ooooo00?o0?l0ooooooooool0
8_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo0_l0o`04ooooo`03o`3o
0?oooooooooo01Sooooo00Co0?l0oooooooooooo0?l02?ooool01?l0o`3oooooooooooooool2o`3o
00Gooooo0_l0o`02ooooo`Ko0?l03Oooool000gooooo1?l0o`000ooooooo0?l0o`3o0003ooooo`?o
0?l01Oooool00ol0o`3oooooo`3o0002ooooo`03o`3o0?oooooooooo00gooooo00Go0?l0oooooooo
ooooooooo`3o000Sooooo`;o0?l07_ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000
ooooooooool0=Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo01Sooooo00Co0?l0
oooooooooooo0?l02Oooool00ol0o`3oooooooooo`02o`3o00Gooooo0ol0o`001?oooooo0?l0o`3o
0?ooool2o`3o0003ooooool0o`3ooooo00cooooo000>ooooo`?o0?l00_ooool2o`3o00?ooooo0_l0
o`06ooooo`05o`3o0?oooooo0?l0ooooool0o`003oooool00ol0o`3oooooooooo`02ooooo`03o`3o
0?oooooooooo02;ooooo00?o0?l0ooooooooool06oooool01OnHV9So410@o`000?lQ8B7oc<c<00Go
oooo00?o0000ooooooooool0<oooool2o`3o00Gooooo00?o0?l0ooooooooool06Oooool01?l0o`3o
ooooooooool0o`08ooooo`03o`3o0?oooooooooo00?o0?l01Oooool2o`3o00;ooooo1_l0o`0>oooo
o`003_ooool3o`3o00;ooooo0_l0o`03ooooo`03o`3o0?oooooo0?l000Gooooo00?o0?l0ooooool0
o`000_ooool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0oooooooo
ool08_ooool2o`3o02Gooooo00?o0000ooooooooool0<Oooool2o`3o00Kooooo00?o0?l0oooooooo
ool06Oooool01?l0o`3oooooooooool0o`08ooooo`04o`3o0?ooooooooooooooo`;o0?l01Oooool3
o`3o0004ooooool0o`3o0?l0ooooo`;o0?l000?oooooo`3o0?ooool03Oooool000kooooo1?l0o`02
ooooo`;o0?l00oooool2o`3o00Kooooo00Go0?l0ooooool0o`3oooooo`3o000@ooooo`05o`3o0?oo
ooooooooooooool0o`009_ooool2o`3o02?ooooo00?o0000ooooooooool0<?ooool00ol0o`3ooooo
ooooo`04ooooo`;o0?l06oooool01Ol0o`3ooooooooooooooooo0?l000Oooooo00Oo0?l0oooooooo
ooooooooo`3o0?oooooo0?l000Cooooo0ol0o`02ooooo`Ko0?l03oooool000oooooo0ol0o`02oooo
o`;o0?l00oooool00ol0o`3oooooo`3o0006ooooo`;o0?l00_ooool00ol0o`3oooooooooo`0=oooo
o`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool09?ooool3o`3o027ooooo00?o0000oooo
ooooool0;_ooool2o`3o00Kooooo00?o0?l0ooooooooool06_ooool01Ol0o`3ooooooooooooooooo
0?l000Sooooo00Co0?l0oooooooooooooooo0_l0o`05ooooo`?o0?l000Coooooo`3o0?l0o`3ooooo
0_l0o`000ooooooo0?l0ooooo`0>ooooo`003oooool2o`3o0004ooooool0o`3oooooooooo`;o0?l0
0oooool3o`3o00Gooooo00?o0?l0ooooool0o`000_ooool00ol0o`3oooooooooo`0=ooooo`03o`3o
0?oooooooooo00;ooooo00?o0?l0ooooooooool09Oooool3o`3o01oooooo00?o0000ooooooooool0
;?ooool2o`3o00Kooooo0_l0o`0Mooooo`04o`3o0?ooooooooooo`3o00Sooooo00Oo0?l0oooooooo
ooooooooo`3o0?oooooo0?l000Cooooo0ol0o`02ooooo`Ko0?l04?ooool0013ooooo1?l0o`001?oo
oooo0?l0o`3o0?l0o`03ooooo`;o0?l01_ooool01Ol0o`3oooooo`3o0?oooooo0?l0013ooooo00?o
0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0Uooooo`Go0?l07?ooool00ol0003ooooooooo
o`0[ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool07?ooool01Ol0o`3ooooooooo
oooooooo0?l000Oooooo00Oo0?l0ooooooooooooooooo`3o0?oooooo0?l000Gooooo0ol0o`001?oo
oooo0?l0o`3o0?ooool3o`3o017ooooo000@ooooo`;o0?l000Coooooo`3o0?oooooooooo0_l0o`03
ooooo`03o`3o0?oooooo0?l000Kooooo0_l0o`02ooooo`03o`3o0?oooooooooo00gooooo00?o0?l0
ooooooooool00_ooool00ol0o`3oooooooooo`0Wooooo`03o`3o0?oooooooooo00;o0?l06_ooool0
0ol0003oooooooooo`0Yooooo`;o0?l01oooool00ol0o`3oooooooooo`0Looooo`05o`3o0?oooooo
ooooooooool0o`002?ooool01ol0o`3ooooooooooooooooo0?l0ooooool0o`001?ooool3o`3o0003
ooooool0o`3o0?l000Go0?l04Oooool0017ooooo1?l0o`001?oooooo0?l0o`3o0?l0o`03ooooo`;o
0?l01oooool2o`3o00;ooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`02ooooo`03
o`3o0?oooooooooo02Oooooo0_l0o`02ooooo`?o0?l05oooool00ol0003oooooooooo`0Wooooo`;o
0?l01oooool2o`3o01kooooo00Go0?l0ooooooooooooooooo`3o0008ooooo`07o`3o0?oooooooooo
ooooool0o`3oooooo`3o0005ooooo`;o0?l00_ooool2o`3o0004ooooool0o`3o0?l0o`3o01;ooooo
000Aooooo`;o0?l000Coooooo`3o0?oooooooooo0_l0o`03ooooo`03o`3o0?oooooo0?l000Kooooo
00?o0?l0ooooool0o`000_ooool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo00;ooooo
00?o0?l0ooooooooool0:?ooool2o`3o00?ooooo0ol0o`0Dooooo`03o`000?oooooooooo02Cooooo
0ol0o`07ooooo`;o0?l07oooool01Ol0o`3ooooooooooooooooo0?l000Sooooo00Go0?l0oooooooo
ooooooooo`3o0002ooooo`03o`3o0?oooooooooo00;ooooo0ol0o`000ooooooo0?l0o`3o0005o`3o
01;ooooo000Booooo`;o0?l000Coooooo`3o0?oooooooooo0_l0o`03ooooo`03o`3o0?oooooo0?l0
00Kooooo0_l0o`02ooooo`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool00_ooool00ol0
o`3oooooooooo`0Yooooo`03o`3o0?oooooooooo00?ooooo0ol0o`0Aooooo`;o00008oooool2o`3o
00Sooooo0_l0o`0Pooooo`05o`3o0?ooooooooooooooool0o`002Oooool01ol0o`3ooooooooooooo
oooo0?l0ooooool0o`001?ooool3o`3o0005ooooool0o`3o0?l0o`3o0?ooool00ol0o`0Cooooo`00
4oooool4o`3o0004ooooool0o`3o0?l0o`3o00?ooooo0ol0o`06ooooo`;o0?l00_ooool00ol0o`3o
ooooooooo`0>ooooo`03o`3o0?oooooooooo00;ooooo0_l0o`0Zooooo`;o0?l01_ooool3o`3o00ko
oooo00?o0000ooooooooool07oooool3o`3o00Sooooo0_l0o`0Qooooo`05o`3o0?oooooooooooooo
ool0o`002Oooool01Ol0o`3ooooooooooooooooo0?l000;ooooo00?o0?l0ooooooooool00_ooool0
1?l0o`3oooooo`3o0?ooool2o`3o0003ooooool0o`3ooooo00;o0?l04oooool001?ooooo0_l0o`00
1?oooooo0?l0ooooooooool2o`3o00Cooooo0_l0o`06ooooo`03o`3o0?oooooo0?l000;ooooo00?o
0?l0ooooooooool03_ooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo02Wooooo0_l0
o`07ooooo`Co0?l02_ooool00ol0003oooooooooo`0Kooooo`Co0?l02Oooool2o`3o02;ooooo00Go
0?l0ooooooooooooooooo`3o0009ooooo`05o`3o0?ooooooooooooooool0o`000_ooool00ol0o`3o
ooooooooo`02ooooo`?o0?l000Coooooo`3o0?l0o`3ooooo1?l0o`0Dooooo`005?ooool4o`3o0004
ooooool0o`3o0?l0o`3o00?ooooo00?o0?l0ooooool0o`001_ooool2o`3o00;ooooo00?o0?l0oooo
ooooool03oooool2o`3o00Cooooo00?o0?l0ooooooooool0:_ooool3o`3o00Sooooo1?l0o`06oooo
o`03o`000?oooooooooo01Sooooo0ol0o`0:ooooo`?o0?l08oooool01Ol0o`3ooooooooooooooooo
0?l000Wooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooo`3o0004ooooo`;o0?l000?ooooo
o`3o0?l0o`000_l0o`001?oooooo0?l0o`3o0?l0o`0Eooooo`005Oooool00ol0o`3oooooo`3o0002
ooooo`;o0?l01?ooool3o`3o00Kooooo0_l0o`02ooooo`03o`3o0?oooooooooo013ooooo00?o0?l0
ooooooooool00_ooool2o`3o02gooooo0ol0o`09ooooo`Oo0?l04oooool7o`3o00_ooooo0_l0o`0U
ooooo`05o`3o0?ooooooooooooooool0o`002Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oo
oooo0?l000Gooooo00Co0?l0ooooool0o`3ooooo0_l0o`000ooooooo0?l0o`3o0002o`3o01Gooooo
000Eooooo`;o0?l000?oooooo`3o0?ooool00ol0o`04ooooo`?o0?l01_ooool2o`3o00;ooooo00?o
0?l0ooooooooool04?ooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo02gooooo0ol0
o`0<ooooo`03o`000?l0o`3o0?l0017o0?l03oooool3o`3o02Gooooo0_l0o`03ooooo`03o`3o0?oo
oooooooo00Oooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooo`3o0005ooooo`?o0?l000Co
ooooo`3o0?l0o`3ooooo1?l0o`0Fooooo`005_ooool4o`3o0004ooooool0o`3o0?l0o`3o00Cooooo
00?o0?l0ooooool0o`001_ooool01Ol0o`3ooooooooooooooooo0?l001;ooooo00?o0?l0oooooooo
ool00oooool00ol0o`3oooooooooo`0_ooooo`?o0?l02Oooool00ol0003oooooooooo`0Mooooo`?o
0?l09oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0oooooooo
ool00_ooool01?l0o`3oooooooooool0o`04ooooo`?o0?l00_ooool3o`3o0003ooooool0o`3o0?l0
01Oooooo000Gooooo`04o`3o0?oooooo0?l0ooooo`?o0?l01?ooool3o`3o00Oooooo00Go0?l0oooo
ooooooooooooo`3o000Booooo`03o`3o0?oooooooooo00?ooooo0_l0o`0booooo`So0?l000?ooooo
o`000?ooool06_ooool4o`3o02Wooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`07
ooooo`03o`3o0?oooooooooo00;ooooo00Co0?l0oooooooooooo0?l01Oooool3o`3o0004ooooool0
o`3o0?l0ooooo`Co0?l05oooool001Oooooo0_l0o`000ooooooo0?l0ooooo`03o`3o00Cooooo0ol0
o`07ooooo`05o`3o0?ooooooooooooooool0o`004_ooool00ol0o`3oooooooooo`04ooooo`03o`3o
0?oooooooooo03Oooooo1_l0o`0>ooooo`Wo0?l0;?ooool00ol0o`3oooooooooo`02ooooo`03o`3o
0?oooooooooo00Oooooo00?o0?l0ooooooooool00_ooool01?l0o`3oooooooooool0o`05ooooo`?o
0?l000Coooooo`3o0?l0o`3ooooo1?l0o`0Hooooo`006?ooool01Ol0o`3oooooo`3o0?l0o`3ooooo
00;o0?l01Oooool00ol0o`3oooooo`3o0007ooooo`05o`3o0?ooooooooooooooool0o`004_ooool0
0ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo03Oooooo00?o0000ooooooooool00_ooool>
o`3o03?ooooo0_l0o`04ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool00_ooool0
1?l0o`3oooooooooool0o`05ooooo`?o0?l00_ooool4o`3o0003ooooool0o`3ooooo01Sooooo000I
ooooo`05o`3o0?oooooo0?l0o`3o0?ooool00_l0o`05ooooo`03o`3o0?oooooo0?l000Oooooo00Go
0?l0ooooooooooooooooo`3o000Booooo`;o0?l01Oooool00ol0o`3oooooooooo`0fooooo`03o`00
0?oooooooooo04;ooooo00?o0?l0ooooooooool00oooool01?l0o`3oooooooooooooool4o`0000;o
oooo00?o0?l0ooooooooool00_ooool01?l0o`3oooooooooool0o`05ooooo`05o`3o0?oooooo0?l0
o`3o0?ooool00_l0o`000ooooooo0?l0o`3o0002o`3o01Wooooo000Iooooo`;o0?l000?oooooo`3o
0?l0o`000ol0o`04ooooo`?o0?l01oooool3o`3o00;ooooo00?o0?l0ooooooooool04Oooool00ol0
o`3oooooooooo`03ooooo`03o`3o0?oooooooooo03Gooooo00?o0000ooooooooool0@Oooool00ol0
o`3oooooooooo`03ooooo`04o`3o0?ooooooooooooooo`Ko000000Co0?l0oooooooooooooooo0_l0
o`02ooooo`03o`3o0?oooooooooo00?ooooo00Go0?l0ooooool0o`3o0?l0ooooo`02o`3o0003oooo
ool0o`3o0?l000;o0?l06_ooool001[ooooo0_l0o`000ooooooo0?l0ooooo`02o`3o00Gooooo0ol0
o`07ooooo`03o`3o0?oooooo0?l000;ooooo00?o0?l0ooooooooool04Oooool2o`3o00Cooooo00?o
0?l0ooooooooool0=?ooool00ol0003oooooooooo`10ooooo`03o`3o0?oooooooooo00;ooooo0_l0
o`03ooooo`Ko000000Co0?l0o`000?oooooooooo0_l0o`02ooooo`03o`3o0?oooooooooo00Cooooo
0ol0o`02ooooo`Co0?l000?oooooo`3o0?ooool06_ooool001_ooooo1?l0o`000ooooooo0?l0o`3o
0005ooooo`?o0?l01oooool00ol0o`3oooooo`3o0002ooooo`03o`3o0?oooooooooo01;ooooo00?o
0?l0ooooooooool00_ooool2o`3o03Cooooo00?o0000ooooooooool0?_ooool2o`3o00Cooooo00?o
0?l0ooooooooool00oooool5o`000004o`3o0?l0003o0000ooooo`;o0?l00_ooool00ol0o`3ooooo
ooooo`04ooooo`?o0?l00_ooool2o`3o0003ooooool0o`3ooooo00;o0?l06oooool001cooooo1?l0
o`000ooooooo0?l0o`3o0005ooooo`?o0?l01oooool00ol0o`3oooooo`3o0002ooooo`03o`3o0?oo
oooooooo01;ooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`0aooooo`;o0000?_oo
ool00ol0o`3oooooooooo`02ooooo`;o0?l01_ooool4o`000005o`3o0?l0003o0000o`000?l0o`00
0oooool00ol0o`3oooooooooo`04ooooo`;o0?l000?oooooo`3o0?ooool00_l0o`000ooooooo0?l0
o`3o0002o`3o01cooooo000Looooo`;o0?l000?oooooo`3o0?l0o`000ol0o`04ooooo`03o`3o0?oo
oooo0?l000Sooooo0ol0o`02ooooo`03o`3o0?oooooooooo01;ooooo0_l0o`04ooooo`;o0?l0<Ooo
ool00ol0003oooooooooo`0looooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01_oo
ool7o`000005o`3o0?ooooooooooooooool0o`001_ooool2o`3o0006ooooool0o`3oooooooooool0
o`3ooooo1?l0o`0Mooooo`007Oooool3o`3o0003ooooool0o`3o0?l000;o0?l01?ooool00ol0o`3o
ooooo`3o0009ooooo`;o0?l00_ooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo00?o
oooo00?o0?l0ooooooooool0;_ooool00ol0003oooooooooo`0kooooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool02?ooool5o`000005o`3o0?ooooooooooooooool0o`001Oooool3o`3o
0006ooooool0o`3oooooooooool0o`3ooooo1?l0o`0Nooooo`007_ooool4o`3o0004ooooool0o`3o
0?l0o`3o00Cooooo00?o0?l0ooooool0o`002Oooool2o`3o00;ooooo00?o0?l0ooooooooool04ooo
ool2o`3o00Cooooo0_l0o`0^ooooo`03o`000?oooooooooo03Wooooo0_l0o`03ooooo`;o0?l03?oo
ool3o`000005o`3o0?ooooooooooooooool0o`001Oooool01Ol0o`3oooooo`3o0?oooooo0?l000;o
oooo1_l0o`0Oooooo`007_ooool00ol0o`3oooooo`3o0002o`3o0004ooooool0o`3o0?l0o`3o00Co
oooo00?o0?l0ooooool0o`002Oooool3o`3o0003ooooool0o`3ooooo01Gooooo00?o0?l0oooooooo
ool00oooool00ol0o`3oooooooooo`0[ooooo`03o`000?oooooooooo03Oooooo0_l0o`04ooooo`03
o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool00_l0o`05ooooo`05o`3o0?oooooo0?l0oooo
ool0o`000_ooool3o`3o0004ooooool0o`3o0?l0o`3o01oooooo000Oooooo`03o`3o0?oooooo0?l0
00;o0?l00_ooool2o`3o00Cooooo00?o0?l0ooooool0o`002Oooool01Ol0o`3oooooo`3o0?oooooo
0?l001Kooooo00?o0?l0ooooooooool00oooool2o`3o02_ooooo00?o0000ooooooooool0=Oooool2
o`3o00Cooooo0_l0o`0@ooooo`04o`3o0?ooooooooooo`3o00Kooooo00Go0?l0ooooool0o`3ooooo
o`3o0002ooooo`?o0?l000Coooooo`3o0?l0o`3o0?l08?ooool0023ooooo0_l0o`000ooooooo0?l0
o`3o0002ooooo`;o0?l01?ooool00ol0o`3oooooo`3o0009ooooo`05o`3o0?oooooo0?l0ooooool0
o`005_ooool2o`3o00Gooooo0_l0o`0Yooooo`03o`000?oooooooooo03Cooooo00?o0?l0oooooooo
ool00oooool00ol0o`3oooooooooo`0?ooooo`04o`3o0?ooooooooooo`3o00Kooooo00Go0?l0oooo
ool0o`3oooooo`3o0002ooooo`?o0?l000Coooooo`3o0?l0o`3o0?l08Oooool0027ooooo0_l0o`00
0ooooooo0?l0o`3o0002ooooo`?o0?l00oooool00ol0o`3oooooo`3o0009ooooo`05o`3o0?oooooo
0?l0ooooool0o`005oooool2o`3o00Gooooo0ol0o`0Vooooo`03o`000?oooooooooo03;ooooo0_l0
o`04ooooo`;o0?l04?ooool2o`3o00;ooooo00?o0?l0ooooooooool01?ooool01Ol0o`3oooooo`3o
0?oooooo0?l000;ooooo0ol0o`001?oooooo0?l0o`3o0?l0o`0Rooooo`008oooool00ol0o`3ooooo
o`3o0003ooooo`03o`3o0?oooooo0?l000?ooooo00?o0?l0ooooool0o`002Oooool00ol0o`3ooooo
o`3o0002o`3o01Sooooo0_l0o`06ooooo`;o0?l09?ooool00ol0003oooooooooo`0`ooooo`;o0?l0
1Oooool00ol0o`3oooooooooo`0?ooooo`;o0?l000?oooooo`3o0?l0o`001_ooool00ol0o`3ooooo
o`3o0002o`3o00;ooooo00Co0?l0ooooool0o`3ooooo0ol0o`0Sooooo`009?ooool00ol0o`3ooooo
o`3o0003ooooo`03o`3o0?oooooo0?l000?ooooo00Co0?l0ooooool0o`3o0?l02?ooool00ol0o`3o
ooooooooo`02o`3o01Wooooo00?o0?l0ooooooooool01Oooool2o`3o02;ooooo00?o0000oooooooo
ool0;Oooool3o`3o00Gooooo0_l0o`0@ooooo`?o0?l000?oooooo`3o0?ooool01_ooool01?l0o`3o
ooooo`3o0?l0o`03ooooo`03o`3o0?oooooo0?l000Co0?l09?ooool002Gooooo00?o0?l0ooooool0
o`000oooool00ol0o`3oooooo`3o0003ooooo`04o`3o0?oooooo0?l0o`3o00Sooooo0_l0o`000ooo
oooo0?l0o`3o000Iooooo`;o0?l01oooool3o`3o01oooooo00?o0000ooooooooool0:oooool2o`3o
00Oooooo00?o0?l0ooooooooool03oooool01Ol0o`3oooooo`3o0?oooooo0?l000Kooooo0_l0o`00
0ooooooo0?l0o`3o0002ooooo`;o0?l000?oooooo`3o0?l0o`000ol0o`0Uooooo`009_ooool01?l0
o`3oooooo`3o0?l0o`02ooooo`03o`3o0?oooooo0?l000?ooooo00Co0?l0ooooool0o`3o0?l02Ooo
ool01?l0o`3oooooo`3o0?l0o`0Jooooo`;o0?l02?ooool2o`3o01gooooo00?o0000ooooooooool0
:?ooool3o`3o00Oooooo0_l0o`0Aooooo`03o`3o0?oooooo0?l000;o0?l01_ooool00ol0o`3ooooo
ooooo`02o`3o00;ooooo0_l0o`000ooooooo0?l0o`3o0003o`3o02Kooooo000Wooooo`04o`3o0?oo
oooo0?l0o`3o00;ooooo00?o0?l0ooooool0o`000oooool00ol0o`3oooooooooo`02o`3o00Sooooo
1Ol0o`0Jooooo`;o0?l02?ooool3o`3o01[ooooo00?o0000ooooooooool09_ooool2o`3o00Oooooo
0ol0o`0Aooooo`Go0?l01oooool01?l0o`3oooooo`3o0?l0o`03ooooo`;o0?l000?oooooo`3o0?l0
o`000ol0o`0Wooooo`00:?ooool01?l0o`3oooooooooool0o`02ooooo`?o0?l00oooool2o`3o0003
ooooool0o`3o0?l000Wooooo00?o0?l0ooooool0o`000_l0o`0Jooooo`?o0?l02?ooool3o`3o01Oo
oooo0_l0000Tooooo`?o0?l01_ooool3o`3o01?ooooo0ol0o`000ooooooo0?l0ooooo`05ooooo`;o
0?l000?oooooo`3o0?l0o`000oooool2o`3o0003ooooool0o`3o0?l000?o0?l0:?ooool002Wooooo
00Co0?l0oooooooooooo0?l00_ooool3o`3o00Cooooo00Co0?l0ooooool0o`3o0?l02Oooool00ol0
o`3oooooooooo`03o`3o01_ooooo0_l0o`09ooooo`?o0?l05?ooool00ol0003oooooooooo`0Poooo
o`?o0?l01oooool2o`3o01Cooooo0ol0o`02ooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0oooo
ooooool00_l0o`03ooooo`;o0?l000Coooooo`3o0?l0o`3ooooo0_l0o`0Yooooo`00:_ooool2o`3o
0003ooooool0o`3o0?l000;ooooo0_l0o`04ooooo`04o`3o0?oooooo0?l0o`3o00Wooooo0_l0o`02
ooooo`;o0?l07?ooool2o`3o00[ooooo0ol0o`0Aooooo`03o`000?oooooooooo01_ooooo1Ol0o`08
ooooo`;o0?l05Oooool3o`3o0003ooooool0o`3o0?l000Kooooo00Co0?l0oooooooooooo0?l01?oo
ool2o`3o0004ooooool0o`3o0?l0ooooo`;o0?l0:_ooool002_ooooo0_l0o`000ooooooo0?l0o`3o
0002ooooo`;o0?l01?ooool00ol0o`3oooooo`3o0002o`3o00Wooooo00?o0?l0ooooooooool00ol0
o`0Looooo`;o0?l02oooool5o`3o00cooooo00?o0000ooooooooool05?ooool7o`3o00[ooooo0ol0
o`0Fooooo`;o0?l00_ooool00ol0o`3oooooooooo`04ooooo`;o0?l000?oooooo`3o0?l0o`001?oo
ool5o`3o0003ooooool0o`3o0?l002_ooooo000/ooooo`;o0?l000?oooooo`3o0?l0o`000_ooool3
o`3o00?ooooo0ol0o`000ooooooo0?l0ooooo`08ooooo`;o0?l00_ooool3o`3o01cooooo0ol0o`0=
ooooo`Wo0?l00oooool00ol0003oooooooooo`0@ooooo`Co0?l03Oooool4o`3o01Oooooo0_l0o`03
ooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooooooool00_l0o`04ooooo`03o`3o0?oooooo
0?l000;o0?l000?oooooo`3o0?l0o`00;?ooool002gooooo0_l0o`000ooooooo0?l0o`3o0002oooo
o`03o`3o0?oooooo0?l000Cooooo0_l0o`000ooooooo0?l0o`3o0009ooooo`;o0?l00_ooool3o`3o
01gooooo1?l0o`0BoooooaKo0?l03_ooool3o`3o01[ooooo0_l0o`03ooooo`03o`3o0?oooooooooo
00?ooooo0_l0o`02ooooo`;o0?l01?ooool00ol0o`3oooooo`3o0002o`3o0003ooooool0o`3o0?l0
02gooooo000^ooooo`;o0?l000Goooooo`3o0?l0o`3o0?l0ooooo`04o`3o00?ooooo0_l0o`02oooo
o`;o0?l02Oooool2o`3o00;ooooo0ol0o`0Oooooo`Ko0?l03oooool00ol0003oooooooooo`0Joooo
o`Co0?l06oooool2o`3o00?ooooo0_l0o`05ooooo`05o`3o0?ooooooooooooooool0o`001?ooool5
o`3o0004ooooool0o`3o0?l0o`3o02kooooo000_ooooo`;o0?l000Goooooo`3o0?l0o`3o0?l0oooo
o`02o`3o0003ooooool0o`3ooooo00;ooooo0ol0o`02ooooo`03o`3o0?oooooooooo00Sooooo00Co
0?l0oooooooooooooooo0ol0o`0Sooooo`Go0?l02_ooool00ol0003oooooooooo`0Dooooo`Ko0?l0
7Oooool2o`3o00?ooooo0_l0o`06ooooo`03o`3o0?oooooooooo00;o0?l01?ooool5o`3o0003oooo
ool0o`3o0?l0033ooooo000`ooooo`;o0?l00_ooool2o`3o0004ooooool0o`3o0?l0ooooo`;o0?l0
0_ooool00ol0o`3oooooo`3o0002ooooo`;o0?l02Oooool2o`3o00;ooooo0ol0o`0Wooooo`Go0?l0
1Oooool00ol0003oooooooooo`0?ooooo`Go0?l08?ooool3o`3o00?ooooo0_l0o`06ooooo`;o0?l0
0_ooool2o`3o00?ooooo2Ol0o`0aooooo`00<Oooool2o`3o00;ooooo1Ol0o`02ooooo`03o`3o0?oo
oooooooo00Co0?l00_ooool00ol0o`3oooooooooo`08ooooo`;o0?l00_ooool3o`3o02[ooooo5ol0
o`0Sooooo`Co0?l00oooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo00;o0?l00ooo
ool4o`3o0006ooooool0o`3oooooo`3o0?oooooo0?l0<_ooool003;ooooo0_l0o`02ooooo`?o0?l0
00Coooooo`3o0?oooooooooo0_l0o`02ooooo`Co0?l000?oooooo`3o0?l0o`002_ooool2o`3o00;o
oooo0ol0o`0]ooooo`03o`000?oooooooooo033ooooo1?l0o`03ooooo`;o0?l01oooool00ol0o`3o
ooooooooo`02o`3o00?ooooo00Go0?l0ooooool0o`3o0?l0ooooo`05o`3o03?ooooo000cooooo`?o
0?l00_ooool2o`3o0003ooooool0o`3o0?l000;ooooo00Oo0?l0ooooooooooooooooo`3o0?oooooo
0?l000;ooooo0_l0o`0:ooooo`;o0?l00oooool3o`3o02;ooooo0_l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo02kooooo1?l0o`03ooooo`;o0?l01oooool2o`3o00;ooooo0_l0o`02
ooooo`So0?l000?oooooo`3o0?ooool0=?ooool003Gooooo0_l0o`02ooooo`Go0?l00_ooool2o`3o
00;ooooo1?l0o`02ooooo`;o0?l02_ooool3o`3o00?ooooo0ol0o`0Pooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0:oooool5o`3o00?ooooo0_l0o`07ooooo`;o0?l00_ooool2o`3o
00?ooooo00Go0?l0ooooool0o`3o0?l0ooooo`03o`3o0003ooooool0o`3ooooo03Gooooo000foooo
o`?o0?l000Goooooo`3o0?oooooo0?l0ooooo`02o`3o00;ooooo00Co0?l0oooooooooooooooo0ol0
o`03ooooo`03o`3o0?oooooooooo00[ooooo0_l0o`03ooooo`?o0?l06oooool5o`0000Gooooo00?o
0000ooooooooool0:?ooool6o`3o00?ooooo0_l0o`07ooooo`;o0?l00oooool2o`3o00;ooooo1Ol0
o`000ooooooo0?l0o`3o0002ooooo`03o`3o0?oooooooooo03Gooooo000hooooo`Ko0?l000?ooooo
o`3o0?l0o`000_ooool2o`3o00?ooooo0ol0o`02ooooo`;o0?l03?ooool2o`3o00Cooooo0ol0o`0H
ooooo`04odA4A?oMgMgoooooo`0000Kooooo0ol0000Uooooo`?o0?l000?oooooo`3o0?l0o`000ooo
ool3o`3o00Oooooo0_l0o`03ooooo`;o0?l00oooool01Ol0o`3oooooo`3o0?l0o`3ooooo00?o0?l0
00?oooooo`3o0?l0o`00>?ooool003Wooooo0ol0o`000ooooooo0?l0o`3o0004o`3o00;ooooo00Co
0?l0oooooooooooooooo1?l0o`02ooooo`;o0?l03?ooool2o`3o00Gooooo0ol0o`0Eooooo`04omgM
gOmEEEGoooooo`0000Kooooo00?o0000ooooooooool08_ooool3o`3o0004ooooool0o`3o0?l0o`3o
00?ooooo0_l0o`08ooooo`;o0?l00oooool3o`3o00;ooooo1?l0o`02ooooo`?o0?l000?oooooo`3o
0?ooool0>Oooool003_ooooo1_l0o`000ooooooo0?l0o`3o0002ooooo`;o0?l00oooool5o`3o0003
ooooool0o`3o0?l000cooooo0ol0o`05ooooo`?o0?l04oooool00omgMgOoc<c<o`000006ooooo`03
o`000?oooooooooo01gooooo1Ol0o`001?oooooo0?l0o`3o0?l0o`04ooooo`;o0?l02?ooool2o`3o
00?ooooo0ol0o`02ooooo`;o0?l000Coooooo`3o0?l0o`3ooooo0ol0o`000ooooooo0?l0o`3o000k
ooooo`00??ooool3o`3o0004ooooool0o`3o0?l0ooooo`?o0?l00_ooool00ol0o`3oooooooooo`02
ooooo`;o0?l000Coooooo`3o0?l0o`3ooooo0ol0o`0<ooooo`?o0?l01Oooool4o`3o00oooooo00?o
k^k^odA4A?l000001_ooool00ol0003oooooooooo`0Iooooo`Co0?l00oooool3o`3o00Cooooo0ol0
o`08ooooo`;o0?l00oooool4o`3o00;ooooo00Go0?l0ooooool0o`3o0?l0ooooo`04o`3o0003oooo
ool0o`3ooooo03cooooo000nooooo`?o0?l000?oooooo`3o0?l0o`000ol0o`02ooooo`;o0?l01?oo
ool00ol0o`3oooooooooo`02o`3o00;ooooo0_l0o`0=ooooo`?o0?l01Oooool7o`3o00[ooooo00?o
MgMgo`000?ooool01Oooool00ol0003oooooooooo`0Fooooo`?o0?l00oooool4o`3o00?ooooo1?l0
o`09ooooo`;o0?l00oooool2o`3o0004ooooool0o`3oooooooooo`;o0?l000Coooooo`3o0?l0o`3o
oooo0ol0o`000ooooooo0?l0o`3o000nooooo`00?oooool:o`3o00;ooooo0_l0o`03ooooo`;o0?l0
0_ooool2o`3o00;ooooo0_l0o`0>ooooo`?o0?l01_ooool;o`3o00[ooooo00?o0000ooooooooool0
3?ooool:o`3o0003ooooool0o`3o0?l000?o0?l01?ooool3o`3o00[ooooo0ol0o`03ooooo`;o0?l0
00Coooooo`3o0?l0o`3ooooo0_l0o`001?oooooo0?l0o`3o0?ooool4o`3o0003ooooool0o`3ooooo
03oooooo0011ooooo`_o0?l000?oooooo`3o0?l0o`000oooool2o`3o00;ooooo0_l0o`02ooooo`?o
0?l03_ooool3o`3o00Sooooo7ol0o`05ooooo`Ko0?l01_ooool3o`3o00_ooooo0_l0o`04ooooo`So
0?l000?oooooo`3o0?l0o`000_ooool3o`3o00;ooooo00?o0?l0ooooooooool0?oooool004?ooooo
2ol0o`000ooooooo0?l0o`3o0003ooooo`;o0?l00_ooool3o`3o00;ooooo0ol0o`0>ooooo`Co0?l0
2_ooool=o`3o00Oooooo2_l0o`09ooooo`?o0?l03?ooool2o`3o00?ooooo1Ol0o`000ooooooo0?l0
o`3o0002ooooo`?o0?l000?oooooo`3o0?l0o`000_l0o`000ooooooo0?l0o`3o0012ooooo`00AOoo
ool7o`3o0005ooooool0o`3o0?l0o`3o0?ooool00_l0o`03ooooo`?o0?l00_ooool2o`3o00?ooooo
0ol0o`0?ooooo`Ko0?l03_ooool00ol0003oooooooooo`07o`3o00kooooo1Ol0o`0<ooooo`?o0?l0
0_ooool5o`3o00;ooooo0_l0o`03ooooo`;o0?l000?oooooo`3o0?l0o`000_l0o`02ooooo`03o`3o
0?oooooooooo04;ooooo0016ooooo`So0?l000?oooooo`3o0?l0o`001?l0o`04ooooo`?o0?l000?o
ooooo`3o0?l0o`001?ooool3o`3o01;ooooo1_l0o`08ooooo`03o`000?oooooooooo00Sooooo3Ol0
o`0=ooooo`Co0?l00_ooool6o`3o00;ooooo0_l0o`03ooooo`;o0?l000?oooooo`3o0?l0o`000_l0
o`02ooooo`;o0?l0AOooool004Sooooo2?l0o`000ooooooo0?l0o`3o0005o`3o00Cooooo1_l0o`04
ooooo`?o0?l05OoooolCo`3o01Oooooo0ol0o`02ooooo`Oo0?l00_ooool3o`3o00?ooooo1ol0o`02
ooooo`;o0?l0Aoooool004[ooooo4Ol0o`04ooooo`Ko0?l01?ooool5o`3o01Sooooo00?o0000oooo
ooooool06oooool4o`3o00;ooooo0ol0o`001?oooooo0?l0o`3o0?l0o`03ooooo`;o0?l01?ooool7
o`3o00;ooooo0_l0o`19ooooo`00C?ooool6o`3o0003ooooool0o`3o0?l000;o0?l000Coooooo`3o
0?l0o`3ooooo0ol0o`04ooooo`Oo0?l01Oooool6o`3o01;ooooo00?o0000ooooooooool05_ooool5
o`3o00?ooooo0ol0o`001?oooooo0?l0o`3o0?l0o`04ooooo`;o0?l00oooool3o`3o0003ooooool0
o`3o0?l000;o0?l000Coooooo`3o0?l0o`3o0?l0Boooool004kooooo0_l0o`000ooooooo0?l0o`3o
0006o`3o0003ooooool0o`3o0?l000;ooooo0ol0o`04ooooo`?o0?l000Coooooo`3o0?l0o`3o0?l0
2?ooool5o`3o00gooooo0_l0000Aooooo`Ko0?l01Oooool3o`3o0004ooooool0o`3o0?l0o`3o00Co
oooo0ol0o`02ooooo`?o0?l00_ooool4o`3o0003ooooool0o`3o0?l004kooooo001@ooooo`oo0?l0
0_ooool3o`3o00Cooooo0ol0o`000ooooooo0?l0o`3o0003o`3o00Sooooo8?l0o`06ooooo`Wo0?l0
1?ooool3o`3o00;ooooo1?l0o`000ooooooo0?l0o`3o0003o`3o0003ooooool0o`3o0?l0053ooooo
001Cooooo`Ko0?l000?oooooo`3o0?l0o`001_l0o`02ooooo`Co0?l00oooool4o`3o00;ooooo1ol0
o`0>ooooo`03o`000?oooooooooo013ooooo2_l0o`06ooooo`?o0?l00_ooool4o`3o0003ooooool0
o`3o0?l000Co0?l000?oooooo`3o0?l0o`00D_ooool005Gooooo2_l0o`000ooooooo0?l0o`3o0003
o`3o00?ooooo0ol0o`04ooooo`Ko0?l00oooool?o`3o00;ooooo5?l0o`07ooooo`Go0?l000?ooooo
o`3o0?l0o`002_l0o`001?oooooo0?l0o`3o0?l0o`1Dooooo`00Eoooool;o`3o00;ooooo1_l0o`00
0ooooooo0?l0o`3o0004o`3o00Cooooo2ol0o`06ooooo`03o`000?l0o`3o0?l000Sooooo1_l0o`08
ooooo`Go0?l000?oooooo`3o0?l0o`001?l0o`000ooooooo0?l0o`3o0003o`3o0003ooooool0o`3o
0?l000?o0?l0Eoooool005[ooooo2ol0o`02ooooo`So0?l00_ooool6o`3o00Wooooo4Ol0o`0:oooo
o`Co0?l00oooool5o`3o00;ooooo1Ol0o`02ooooo`Co0?l0F_ooool005gooooo2ol0o`02ooooo`?o
0?l00_ooool3o`3o00Gooooo2?l0o`07ooooo`03o`000?oooooooooo00Oooooo2ol0o`02ooooo`Ko
0?l00oooool4o`3o00?ooooo1?l0o`1Mooooo`00H?ooool6o`3o0003ooooool0o`3o0?l0013o0?l0
1_oooolAo`3o00Oooooo2?l0o`02ooooo`Ko0?l000?oooooo`3o0?l0o`001?l0o`1Pooooo`00Hooo
ool8o`3o0003ooooool0o`3o0?l002co0?l000?oooooo`3o0?l0o`003_l0o`1Sooooo`00I_ooool3
o`3o00;ooooo3ol0o`06oooooa?o0?l00_ooool=o`3o0003ooooool0o`3o0?l000;o0?l0Ioooool0
06Wooooo1_l0o`03ooooobco0?l000?oooooo`3o0?l0o`000_l0o`1[ooooo`00Koooool`o`3o06oo
oooo001hooooob3o0?l0M_ooool008Gooooo1_l0o`23ooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 292.875}, {363.625, 148.625}} -> {-8.62218, \
1.91281, 0.0465121, 0.0465121}}]
}, Open  ]],

Cell[TextData[{
  "Even one phase plane trajectory gets tangled as it winds around \
overlapping itself. The trajectory for ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 3,  ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(0) = -3 is shown below. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
inits = ListPlot[ {{3,-3}}, PlotStyle->PointSize[0.02]];
Show[ inits, 
      ParametricPlot[ 
      Evaluate[{phi2[3,-3,t],D[phi2[3,-3,t],t]}], 
              {t,0,40}, PlotStyle->RGBColor[0,1,0] ], 
      PlotRange->{{-5,5},{-5,5}}, AspectRatio\[Rule]1/1]\
\>", "Input",
  CellLabel->"In[18]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.1 [
[.1 .4875 -6 -9 ]
[.1 .4875 6 0 ]
[.3 .4875 -6 -9 ]
[.3 .4875 6 0 ]
[.7 .4875 -3 -9 ]
[.7 .4875 3 0 ]
[.9 .4875 -3 -9 ]
[.9 .4875 3 0 ]
[.4875 .1 -12 -4.5 ]
[.4875 .1 0 4.5 ]
[.4875 .3 -12 -4.5 ]
[.4875 .3 0 4.5 ]
[.4875 .7 -6 -4.5 ]
[.4875 .7 0 4.5 ]
[.4875 .9 -6 -4.5 ]
[.4875 .9 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 .5 m
.1 .50625 L
s
[(-4)] .1 .4875 0 1 Mshowa
.3 .5 m
.3 .50625 L
s
[(-2)] .3 .4875 0 1 Mshowa
.7 .5 m
.7 .50625 L
s
[(2)] .7 .4875 0 1 Mshowa
.9 .5 m
.9 .50625 L
s
[(4)] .9 .4875 0 1 Mshowa
.125 Mabswid
.15 .5 m
.15 .50375 L
s
.2 .5 m
.2 .50375 L
s
.25 .5 m
.25 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.45 .5 m
.45 .50375 L
s
.55 .5 m
.55 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.75 .5 m
.75 .50375 L
s
.8 .5 m
.8 .50375 L
s
.85 .5 m
.85 .50375 L
s
.05 .5 m
.05 .50375 L
s
.95 .5 m
.95 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .1 m
.50625 .1 L
s
[(-4)] .4875 .1 1 0 Mshowa
.5 .3 m
.50625 .3 L
s
[(-2)] .4875 .3 1 0 Mshowa
.5 .7 m
.50625 .7 L
s
[(2)] .4875 .7 1 0 Mshowa
.5 .9 m
.50625 .9 L
s
[(4)] .4875 .9 1 0 Mshowa
.125 Mabswid
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .25 m
.50375 .25 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .75 m
.50375 .75 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .05 m
.50375 .05 L
s
.5 .95 m
.50375 .95 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.8 .2 Mdot
0 1 0 r
.5 Mabswid
.8 .2 m
.77113 .18825 L
.75483 .18302 L
.73919 .17887 L
.72445 .17569 L
.70831 .17298 L
.69354 .17117 L
.67984 .17004 L
.66357 .16937 L
.64832 .16938 L
.6316 .17009 L
.61367 .17164 L
.60476 .17271 L
.59506 .1741 L
.57752 .17721 L
.54512 .18497 L
.51116 .19596 L
.48153 .20805 L
.42004 .24133 L
.37035 .27805 L
.33084 .31601 L
.29593 .35992 L
.28088 .38409 L
.26938 .40643 L
.26091 .42673 L
.25496 .4448 L
.25248 .45421 L
.25029 .46427 L
.24932 .4697 L
.24857 .47467 L
.24747 .48429 L
.24688 .4935 L
.24677 .49857 L
.24679 .50316 L
.24715 .51143 L
.24798 .5199 L
.2486 .52429 L
.24939 .5289 L
.25117 .53698 L
.25383 .5462 L
.25676 .55422 L
.26399 .56928 L
.27372 .584 L
.28453 .59636 L
.29573 .60647 L
.31817 .62151 L
.33195 .62838 L
.34515 .63374 L
.35785 .63797 L
.37212 .6418 L
Mistroke
.38591 .64472 L
.39893 .64685 L
.40697 .6479 L
.41572 .64883 L
.42402 .64951 L
.43168 .64997 L
.43864 .65027 L
.44627 .65046 L
.45425 .65051 L
.46169 .65042 L
.46587 .65032 L
.47041 .65017 L
.47865 .64977 L
.48665 .64925 L
.49401 .64864 L
.51058 .64685 L
.52791 .64433 L
.55707 .63844 L
.58254 .63134 L
.60876 .62155 L
.63389 .60885 L
.65338 .59561 L
.66906 .58142 L
.68318 .56372 L
.68951 .55285 L
.69421 .5424 L
.69781 .53155 L
.69938 .52517 L
.70052 .51906 L
.70138 .51249 L
.70185 .50637 L
.70198 .50294 L
.70201 .49917 L
.70178 .49223 L
.70128 .48624 L
.70041 .47955 L
.69913 .47247 L
.69758 .46575 L
.69397 .45364 L
.68886 .44045 L
.67227 .41013 L
.6614 .39515 L
.6476 .37922 L
.61853 .35282 L
.58663 .33132 L
.54891 .31309 L
.5261 .30517 L
.51492 .30207 L
.5043 .29958 L
.49417 .29762 L
Mistroke
.48482 .29615 L
.47436 .29492 L
.46307 .29405 L
.45222 .29369 L
.44608 .29369 L
.44038 .29382 L
.42997 .29439 L
.41891 .29549 L
.40816 .29706 L
.39835 .29894 L
.37662 .30472 L
.35808 .31159 L
.33932 .32064 L
.30928 .34066 L
.29395 .35435 L
.28096 .36858 L
.2684 .38559 L
.25705 .40522 L
.25199 .41605 L
.24714 .42843 L
.24337 .44018 L
.24051 .45124 L
.23833 .46206 L
.23663 .47365 L
.23554 .48549 L
.2352 .49228 L
.23508 .49863 L
.2353 .5103 L
.23603 .52099 L
.23748 .5334 L
.23947 .54516 L
.24174 .55566 L
.24478 .56721 L
.25267 .5904 L
.26204 .61156 L
.27256 .6309 L
.30224 .67218 L
.32232 .69345 L
.34261 .71138 L
.38833 .74224 L
.41634 .75606 L
.4429 .76623 L
.46864 .7736 L
.48341 .77678 L
.4971 .77909 L
.50922 .78061 L
.52255 .78172 L
.53652 .78226 L
.54955 .7822 L
.56485 .7814 L
Mistroke
.57346 .7806 L
.58139 .77965 L
.59587 .77734 L
.61107 .7741 L
.63688 .76661 L
.66435 .75558 L
.69217 .74073 L
.72004 .72131 L
.74403 .69989 L
.76371 .67784 L
.78081 .65392 L
.79458 .62967 L
.80743 .5999 L
.81202 .58624 L
.81613 .5715 L
.8191 .55832 L
.82166 .54363 L
.82335 .5301 L
.82436 .51735 L
.82485 .50217 L
.82463 .48824 L
.82358 .47209 L
.8218 .45677 L
.81926 .44156 L
.81558 .42482 L
.80532 .39132 L
.79253 .36103 L
.7777 .33355 L
.73503 .27652 L
.70583 .24818 L
.67615 .22505 L
.64707 .20669 L
.61799 .19188 L
.58288 .17808 L
.56693 .17315 L
.5498 .16873 L
.53465 .16556 L
.51783 .16282 L
.50244 .16103 L
.48797 .15996 L
.47089 .15945 L
.45528 .15971 L
.43729 .16087 L
.42029 .16282 L
.40189 .1659 L
.38538 .16954 L
.34919 .1806 L
.31695 .19437 L
.28805 .21033 L
.2584 .23094 L
Mistroke
.22967 .25607 L
.20161 .28732 L
.17939 .31907 L
.16171 .35163 L
.1483 .38423 L
.13913 .41473 L
.13519 .43238 L
.13237 .4489 L
.13022 .46677 L
.12904 .48366 L
.12867 .50231 L
.1289 .51282 L
.12937 .52247 L
.13099 .54081 L
.13233 .55118 L
.13384 .56081 L
.13768 .5802 L
.14295 .60073 L
.15473 .63531 L
.17132 .67156 L
.18914 .70214 L
.21106 .73276 L
.23341 .7586 L
.26057 .78478 L
.31423 .82436 L
.34936 .84365 L
.38969 .86057 L
.40874 .86683 L
.42933 .87243 L
.44736 .87638 L
.467 .8797 L
.48599 .88195 L
.5035 .8832 L
.52027 .88367 L
.53796 .88339 L
.55735 .88216 L
.57533 .88015 L
.59493 .87698 L
.61568 .87249 L
.65722 .85978 L
.67994 .85055 L
.70036 .84076 L
.73552 .82012 L
.77146 .79315 L
.82545 .73684 L
.84983 .70153 L
.86897 .66604 L
.88484 .62707 L
.89572 .58939 L
.90024 .56718 L
Mistroke
.90323 .5468 L
.90442 .53541 L
.90534 .52305 L
.90585 .51133 L
.90601 .50053 L
.90555 .48083 L
.90423 .46242 L
.90181 .44228 L
.89807 .42079 L
.8929 .39846 L
.88683 .37754 L
.87244 .3392 L
.85573 .30501 L
.83454 .27039 L
.78822 .21367 L
.75835 .18578 L
.72791 .16226 L
.68933 .1381 L
.65125 .11941 L
.61425 .10547 L
.59481 .09967 L
.57345 .09443 L
.56113 .09193 L
.54972 .08996 L
.52712 .08698 L
.50647 .08534 L
.48454 .0847 L
.46313 .08518 L
.44018 .08691 L
.41865 .08969 L
.39912 .0932 L
.37652 .09849 L
.35226 .10567 L
.30942 .12247 L
.27168 .14216 L
.23942 .16326 L
.20702 .18927 L
.17514 .22092 L
.14872 .25336 L
.12743 .28544 L
.10903 .31976 L
.09464 .35377 L
.08786 .37352 L
.08162 .39535 L
.07733 .41378 L
.07357 .43432 L
.07066 .45674 L
.06957 .46909 L
.06889 .48069 L
.06845 .50149 L
Mistroke
.06912 .52391 L
.0708 .54466 L
.07378 .56724 L
.07771 .58843 L
.08231 .60795 L
.09346 .6442 L
.10885 .68174 L
.13174 .72459 L
.16178 .76796 L
.19248 .80309 L
.22883 .83659 L
.26474 .86325 L
.30709 .88828 L
.34783 .90689 L
.38743 .92051 L
.40981 .92643 L
.43391 .93144 L
.45468 .93466 L
.47777 .93706 L
.4907 .93788 L
.50258 .9383 L
.51564 .93839 L
.52938 .93807 L
.5525 .93657 L
.56555 .93518 L
.57766 .93353 L
.60101 .92939 L
.62283 .92433 L
.66286 .9119 L
.70441 .8943 L
.74718 .87048 L
.81508 .81741 L
.84504 .78579 L
.8742 .74767 L
.89564 .71277 L
.91496 .67314 L
.92948 .63406 L
.93947 .59719 L
.9441 .57364 L
.94729 .55123 L
.94917 .53098 L
.95016 .50899 L
.94999 .48489 L
.94941 .47276 L
.9484 .45946 L
.94563 .436 L
.94194 .41424 L
.93712 .39245 L
.93156 .37205 L
.91858 .33456 L
Mistroke
.90096 .29555 L
.87769 .25515 L
.81529 .17827 L
.77776 .14493 L
.73237 .1131 L
.69097 .09046 L
.64399 .07093 L
.62171 .06371 L
.59789 .05735 L
.57547 .05258 L
.55461 .04917 L
.53111 .04651 L
.51869 .04559 L
.50553 .04499 L
.48338 .04482 L
.45906 .04588 L
.43748 .04791 L
.41445 .05122 L
.39289 .05542 L
.37341 .06015 L
.32784 .07489 L
.28027 .0963 L
.23787 .12141 L
.20122 .14867 L
.16722 .17975 L
.13827 .21201 L
.09295 .27909 L
.07295 .32002 L
.05825 .35924 L
.05152 .38211 L
.04633 .40372 L
.04203 .42652 L
.03866 .45173 L
.03673 .47616 L
.03626 .48852 L
.03612 .50215 L
.03686 .52625 L
.03871 .54879 L
.04035 .56233 L
.04228 .57516 L
.04688 .5991 L
.05324 .62458 L
.06183 .65196 L
.08008 .69681 L
.10458 .74234 L
.16082 .81657 L
.19455 .84948 L
.23458 .88112 L
.27256 .90531 L
.31502 .92682 L
Mistroke
.35508 .94249 L
.37684 .94929 L
.40051 .95541 L
.42253 .95995 L
.44277 .96316 L
.46324 .96551 L
.48272 .9669 L
.50506 .9675 L
.52915 .96695 L
.55184 .9653 L
.57256 .96282 L
.59536 .95901 L
.62007 .95354 L
.66877 .93853 L
.71504 .91855 L
.76179 .89183 L
.83707 .83081 L
.86845 .79611 L
.89836 .75512 L
.92092 .71645 L
.94067 .67331 L
.95464 .63285 L
.96092 .60932 L
.96569 .58703 L
.9691 .56639 L
.97142 .5474 L
.97313 .52537 L
.97379 .5044 L
.97337 .47969 L
.97257 .46579 L
.97147 .45304 L
.96853 .42966 L
.96418 .40516 L
.95917 .38336 L
.95358 .36326 L
.93761 .31859 L
.91537 .27224 L
.89084 .23228 L
.85738 .1889 L
.8222 .15242 L
.75059 .09728 L
.70899 .0739 L
.66252 .05374 L
.64254 .04679 L
.62072 .04031 L
.60162 .03555 L
.58055 .03124 L
.55696 .02758 L
.53198 .025 L
.50876 .02378 L
Mistroke
.48715 .02366 L
.46154 .02478 L
.44867 .02587 L
.43456 .02746 L
.40975 .03131 L
.38678 .03607 L
.33601 .05093 L
.30835 .0617 L
.28373 .07302 L
.24109 .09692 L
.19772 .12777 L
.16321 .1582 L
.12869 .19554 L
.10159 .23155 L
.0763 .27311 L
.05433 .31959 L
.04613 .34117 L
.03836 .36523 L
.03264 .3865 L
.02761 .40951 L
.02354 .43406 L
.0209 .4571 L
.01939 .48021 L
.01898 .50211 L
.01947 .52177 L
.02092 .54307 L
.02377 .56763 L
.02749 .58994 L
.03308 .61546 L
.03967 .6394 L
.05438 .68094 L
.0747 .72456 L
.10184 .7698 L
.13602 .81448 L
.20971 .88382 L
.25554 .91474 L
.30873 .94208 L
.3342 .95239 L
.3617 .96171 L
.38587 .96842 L
.41213 .97421 L
.43795 .97845 L
.46165 .98109 L
.48558 .98256 L
.50828 .98286 L
.53467 .98188 L
.559 .97969 L
.58553 .97587 L
.61342 .97022 L
.65987 .95689 L
Mistroke
.70706 .93793 L
.74559 .91788 L
.78546 .89209 L
.82549 .85995 L
.8642 .82113 L
.9219 .7411 L
.94375 .69834 L
.95351 .67501 L
.96251 .64978 L
.96922 .62733 L
.97533 .6023 L
.97973 .57927 L
.98283 .55756 L
.98501 .53477 L
.98608 .51307 L
.98622 .49355 L
.98547 .4723 L
.9836 .4493 L
.98042 .42494 L
.97628 .40212 L
.97161 .38166 L
.96354 .35324 L
.95318 .32385 L
.93001 .27311 L
.89876 .22181 L
.85755 .17044 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{208.312, 208.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400044000112000`400?l00000o`00003oPOooool0
0ol0003oooooooooo`20ooooo`00POooool00ol0003oooooooooo`20ooooo`00POooool00ol0003o
ooooooooo`20ooooo`00POooool00ol0003oooooooooo`20ooooo`00POooool00ol0003ooooooooo
o`20ooooo`00POooool00ol0003oooooooooo`20ooooo`00Noooool<o`3o07gooooo001]ooooo`ko
0?l01_ooool00ol0003oooooooooo`03ooooo`go0?l0L?ooool006Oooooo1_l0o`0Dooooo`03o`00
0?oooooooooo013ooooo1_l0o`1Zooooo`00H_ooool5o`3o01[ooooo00?o0000ooooooooool05_oo
ool4o`3o06Kooooo001Oooooo`?o0?l07oooool00ol0003oooooooooo`0Jooooo`?o0?l0Hoooool0
05cooooo0ol0o`0Rooooo`03o`000?oooooooooo01gooooo1?l0o`1Oooooo`00FOooool3o`3o01So
oooo6Ol0o`0Hooooo`?o0?l0G?ooool005Kooooo0ol0o`0?ooooo`co0?l03Oooool2o`0000[ooooo
1_l0o`0Eooooo`?o0?l0FOooool005?ooooo0ol0o`0>ooooo`Co0?l06Oooool00ol0003ooooooooo
o`0?ooooo`Ko0?l04_ooool2o`3o05Oooooo001@ooooo`?o0?l03_ooool3o`3o01gooooo00?o0000
ooooooooool05Oooool5o`3o00oooooo0ol0o`1Dooooo`00C_ooool2o`3o00oooooo0_l0o`0Poooo
o`03o`000?oooooooooo01[ooooo0ol0o`0?ooooo`;o0?l0D_ooool004cooooo0_l0o`0>ooooo`?o
0?l08_ooool00ol0003oooooooooo`0Mooooo`?o0?l03_ooool2o`3o053ooooo001:ooooo`;o0?l0
3Oooool3o`3o02Gooooo00?o0000ooooooooool08?ooool3o`3o00gooooo0ol0o`1=ooooo`00B?oo
ool2o`3o00cooooo0ol0o`0Xooooo`03o`000?oooooooooo02?ooooo0_l0o`0>ooooo`;o0?l0Booo
ool004Kooooo0_l0o`0<ooooo`;o0?l0:oooool00ol0003oooooooooo`0Uooooo`?o0?l03Oooool2
o`3o04Wooooo0014ooooo`;o0?l02oooool3o`3o02gooooo00?o0000ooooooooool0:?ooool2o`3o
00gooooo0_l0o`17ooooo`00@oooool00ol0o`3oooooooooo`08ooooo`?o0?l09?oooolBo`3o02Oo
oooo0_l0o`0=ooooo`03o`3o0?oooooooooo04Cooooo0011ooooo`;o0?l02Oooool2o`3o01cooooo
2ol0o`0<ooooo`03o`000?oooooooooo00?ooooo2_l0o`0Oooooo`?o0?l02oooool2o`3o04Cooooo
000oooooo`;o0?l02?ooool3o`3o01[ooooo1?l0o`0?ooooo`;o000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`?o0?l07oooool2o`3o00_ooooo0_l0o`12ooooo`00?Oooool2
o`3o00Sooooo0_l0o`0Jooooo`?o0?l05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo1?l0o`0Mooooo`;o0?l02oooool2o`3o043ooooo000looooo`03o`3o0?oooooooooo
00Oooooo00?o0?l0ooooooooool05oooool3o`3o00cooooo1_l00002ooooo`Go00001Oooool3o`00
01Cooooo1_l0o`0Iooooo`;o0?l02oooool00ol0o`3oooooooooo`0mooooo`00>oooool00ol0o`3o
ooooooooo`06ooooo`;o0?l05oooool3o`3o01Oooooo00CoA4A4omgMgOoooooo00001_ooool00ol0
003oooooooooo`0Jooooo`?o0?l06?ooool2o`3o00[ooooo00?o0?l0ooooooooool0??ooool003Wo
oooo0_l0o`07ooooo`;o0?l05_ooool3o`3o01[ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0
003oooooooooo`0Mooooo`;o0?l06?ooool2o`3o00Wooooo00?o0?l0ooooooooool0>oooool003So
oooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0Cooooo`?o0?l07_ooool00omgMgOo
c<c<o`000006ooooo`03o`000?oooooooooo01oooooo0ol0o`0Gooooo`;o0?l02?ooool2o`3o03_o
oooo000fooooo`;o0?l01oooool2o`3o01?ooooo0ol0o`0Qooooo`03onk^k_m4A4Co000000Kooooo
00?o0000ooooooooool08_ooool2o`3o01Oooooo00?o0?l0ooooooooool01oooool00ol0o`3ooooo
ooooo`0hooooo`00=Oooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo013ooooo0ol0
o`0Uooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool09?ooool2o`3o01Kooooo00?o
0?l0ooooooooool01oooool00ol0o`3oooooooooo`0gooooo`00=?ooool00ol0o`3oooooooooo`05
ooooo`;o0?l04Oooool2o`3o033ooooo00?o0000ooooooooool09_ooool2o`3o01Gooooo0_l0o`08
ooooo`;o0?l0=oooool003;ooooo0_l0o`07ooooo`03o`3o0?oooooooooo00oooooo0_l0o`0boooo
o`03o`000?oooooooooo02Sooooo0_l0o`0Eooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0oooo
ooooool0=?ooool0037ooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0>ooooo`;o
0?l0=?ooool00ol0003oooooooooo`0Zooooo`;o0?l05?ooool00ol0o`3oooooooooo`07ooooo`03
o`3o0?oooooooooo03?ooooo000`ooooo`03o`3o0?oooooooooo00Gooooo0_l0o`0?ooooo`;o0?l0
=_ooool00ol0003oooooooooo`0/ooooo`;o0?l04oooool2o`3o00Sooooo00?o0?l0ooooooooool0
<_ooool002oooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0=ooooo`;o0?l0>?oo
ool00ol0003oooooooooo`0^ooooo`;o0?l04oooool00ol0o`3oooooooooo`06ooooo`;o0?l0<_oo
ool002kooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0<ooooo`;o0?l0>_ooool0
0ol0003oooooooooo`0`ooooo`;o0?l04_ooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooo
oooo02oooooo000]ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool03?ooool00ol0
o`3oooooooooo`0jooooo`03o`000?oooooooooo03;ooooo00?o0?l0ooooooooool04?ooool2o`3o
00Sooooo00?o0?l0ooooooooool0;_ooool002cooooo00?o0?l0ooooooooool01?ooool2o`3o00go
oooo0_l0o`0mooooo`;o0000=?ooool2o`3o01;ooooo00?o0?l0ooooooooool01_ooool00ol0o`3o
ooooooooo`0]ooooo`00:oooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo00_ooooo
0_l0o`0oooooo`03o`000?oooooooooo03Gooooo0_l0o`0Aooooo`03o`3o0?oooooooooo00Kooooo
00?o0?l0ooooooooool0;?ooool002[ooooo00?o0?l0ooooooooool01?ooool00ol0o`3ooooooooo
o`0;ooooo`03o`3o0?oooooooooo03Kooooo1Ol0o`04ooooo`03o`000?oooooooooo03Oooooo00?o
0?l0ooooooooool03oooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo02_ooooo000Z
ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool02_ooool2o`3o02cooooo3Ol0o`05
ooooo`co0?l0<oooool2o`3o013ooooo0_l0o`07ooooo`03o`3o0?oooooooooo02[ooooo000Yoooo
o`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool02_ooool00ol0o`3oooooooooo`0Woooo
o`Go0?l05_ooool00ol0003oooooooooo`05ooooo`Co0?l0<Oooool00ol0o`3oooooooooo`0?oooo
o`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool0:Oooool002Sooooo00?o0?l0oooooooo
ool00oooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo02Cooooo1?l0o`0Kooooo`03
o`000?oooooooooo00Wooooo1Ol0o`0?oooooa;o0?l03?ooool00ol0o`3oooooooooo`0?ooooo`03
o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0Sooooo`00
9oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Wooooo0_l0o`0Tooooo`?o0?l0
7oooool00ol0003oooooooooo`0>ooooo`Co0?l00_ooool9o`3o01;ooooo1ol0o`06ooooo`;o0?l0
4?ooool00ol0o`3oooooooooo`05ooooo`05o`3o0?ooooooooooooooool0o`009Oooool002Kooooo
00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo027ooooo
0ol0o`0Rooooo`03o`000?oooooooooo00oooooo1_l0o`0Qooooo`Co0?l01?ooool00ol0o`3ooooo
ooooo`0>ooooo`03o`3o0?oooooooooo00Gooooo00Go0?l0ooooooooooooooooo`3o000Tooooo`00
9Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool0
7oooool3o`3o02Gooooo00?o0000ooooooooool02oooool4o`3o00Kooooo0_l0o`0Sooooo`Co0?l0
00?oooooo`3o0?ooool03_ooool00ol0o`3oooooooooo`06ooooo`05o`3o0?ooooooooooooooool0
o`008oooool002Cooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`09ooooo`03o`3o
0?oooooooooo01kooooo0_l0o`0Xooooo`03o`000?oooooooooo00Sooooo0ol0o`0<ooooo`?o0?l0
9?ooool5o`3o00gooooo00?o0?l0ooooooooool01_ooool01Ol0o`3ooooooooooooooooo0?l002;o
oooo000Sooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool02Oooool00ol0o`3ooooo
ooooo`0Mooooo`;o0?l0:_ooool00ol0003oooooooooo`05ooooo`?o0?l04_ooool2o`3o02Gooooo
00?o0?l0ooooool0o`000_l0o`0;ooooo`03o`3o0?oooooooooo00Kooooo00Go0?l0oooooooooooo
ooooo`3o000Qooooo`008_ooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Wooooo
00?o0?l0ooooooooool07?ooool2o`3o02cooooo00?o0000ooooooooool00_ooool3o`3o01Oooooo
0_l0o`0Tooooo`04o`3o0?ooooooooooooooo`?o0?l000Coooooo`000?l0003o00001Oooool00ol0
o`3oooooooooo`05ooooo`05o`3o0?ooooooooooooooool0o`008Oooool0027ooooo00?o0?l0oooo
ooooool00oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo01_ooooo0_l0o`0^oooo
o`03o`000?oooooo0?l000;o0?l07?ooool2o`3o02?ooooo00?o0?l0ooooooooool00oooool2o`3o
00?o00001Oooool00ol0o`3oooooooooo`05ooooo`05o`3o0?ooooooooooooooool0o`008?ooool0
027ooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo
01[ooooo0_l0o`0_ooooo`?o0?l08Oooool00ol0o`3oooooooooo`0Qooooo`03o`3o0?oooooooooo
00;ooooo0_l000000ol0o`3o0000o`000005ooooo`03o`3o0?oooooooooo00Kooooo00Go0?l0oooo
ooooooooooooo`3o000Oooooo`008?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo
00Wooooo00?o0?l0ooooooooool06Oooool2o`3o02kooooo0ol0o`000ooooooo0000ooooo`0Roooo
o`;o0?l08_ooool01?l0o`3oooooooooooooool5o`0000Kooooo00?o0?l0ooooooooool01_ooool0
1Ol0o`3ooooooooooooooooo0?l001kooooo000Oooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0
ooooooooool02Oooool00ol0o`3oooooooooo`0Hooooo`;o0?l0;_ooool2o`3o00Cooooo00?o0000
ooooooooool08oooool2o`3o027ooooo00Co0?l0oooooooooooooooo0ol00008ooooo`03o`3o0?oo
oooooooo00Kooooo00Co0?l0oooooooooooo0?l07_ooool001kooooo00?o0?l0ooooooooool00_oo
ool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo01Oooooo0_l0o`0^ooooo`;o0?l01_oo
ool00ol0003oooooooooo`0Uooooo`;o0?l08?ooool00ol0o`3oooooooooo`0<ooooo`03o`3o0?oo
oooooooo00Kooooo00Co0?l0oooooooooooo0?l07Oooool001gooooo00?o0?l0ooooooooool00ooo
ool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo01Oooooo00?o0?l0ooooooooool0;Ooo
ool00ol0o`3oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo0_l0o`0Oooooo`03o`3o0?oo
oooooooo00cooooo00?o0?l0ooooooooool01Oooool01Ol0o`3ooooooooooooooooo0?l001cooooo
000Mooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool02?ooool00ol0o`3ooooooooo
o`0Fooooo`;o0?l0;_ooool2o`3o00Wooooo00?o0000ooooooooool0:Oooool2o`3o01gooooo00?o
0?l0ooooooooool03?ooool00ol0o`3oooooooooo`06ooooo`05o`3o0?ooooooooooooooool0o`00
6oooool001cooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oo
oooooooo01Gooooo00?o0?l0ooooooooool0;?ooool2o`3o00_ooooo00?o0000ooooooooool0:ooo
ool2o`3o01cooooo00?o0?l0ooooooooool03?ooool00ol0o`3oooooooooo`06ooooo`05o`3o0?oo
ooooooooooooool0o`006_ooool001_ooooo00?o0?l0ooooooooool00oooool00ol0o`3ooooooooo
o`08ooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool0:oooool2o`3o00gooooo00?o
0000ooooooooool0;Oooool00ol0o`3oooooooooo`0Jooooo`03o`3o0?oooooooooo00cooooo00?o
0?l0ooooooooool01_ooool01?l0o`3oooooooooool0o`0Jooooo`006_ooool00ol0o`3ooooooooo
o`03ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool05?ooool2o`3o02cooooo0_l0
o`0?ooooo`03o`000?oooooooooo02kooooo00?o0?l0ooooooooool06_ooool00ol0o`3ooooooooo
o`0<ooooo`03o`3o0?oooooooooo00Kooooo00Co0?l0oooooooooooo0?l06Oooool001[ooooo00?o
0?l0ooooooooool00oooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo01Cooooo00?o
0?l0ooooooooool0:oooool00ol0o`3oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo0_l0
o`0Kooooo`03o`3o0?oooooooooo00cooooo00?o0?l0ooooooooool01Oooool01Ol0o`3ooooooooo
oooooooo0?l001Sooooo000Iooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool01ooo
ool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooooooo02[ooooo0_l0o`0Booooo`03o`000?oo
oooooooo037ooooo00?o0?l0ooooooooool06Oooool00ol0o`3oooooooooo`0;ooooo`03o`3o0?oo
oooooooo00Kooooo00Co0?l0oooooooooooo0?l06?ooool001Sooooo00?o0?l0ooooooooool00ooo
ool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo01?ooooo00?o0?l0ooooooooool0:Ooo
ool2o`3o01Cooooo00?o0000ooooooooool0<_ooool00ol0o`3oooooooooo`0Iooooo`03o`3o0?oo
oooooooo00_ooooo00?o0?l0ooooooooool01Oooool01Ol0o`3ooooooooooooooooo0?l001Oooooo
000Hooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool01oooool00ol0o`3ooooooooo
o`0Cooooo`03o`3o0?oooooooooo02Wooooo00?o0?l0ooooooooool05?ooool00ol0003ooooooooo
o`0cooooo`03o`3o0?oooooooooo01Sooooo00?o0?l0ooooooooool03?ooool00ol0o`3ooooooooo
o`05ooooo`04o`3o0?ooooooooooo`3o01Oooooo000Gooooo`03o`3o0?oooooooooo00?ooooo00?o
0?l0ooooooooool01oooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo02Wooooo00?o
0?l0ooooooooool05Oooool2o`0003Cooooo00?o0?l0ooooooooool06Oooool00ol0o`3ooooooooo
o`0<ooooo`03o`3o0?oooooooooo00Cooooo00Go0?l0ooooooooooooooooo`3o000Fooooo`005_oo
ool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool04ooo
ool00ol0o`3oooooooooo`0Xooooo`;o0?l06?ooool00ol0003oooooooooo`0dooooo`03o`3o0?oo
oooooooo01Wooooo00?o0?l0ooooooooool03?ooool00ol0o`3oooooooooo`04ooooo`05o`3o0?oo
ooooooooooooool0o`005Oooool001Kooooo00?o0?l0ooooooooool00oooool00ol0o`3ooooooooo
o`07ooooo`03o`3o0?oooooooooo01;ooooo00?o0?l0ooooooooool0:?ooool00ol0o`3ooooooooo
o`0Hooooo`03o`000?oooooooooo03Gooooo00?o0?l0ooooooooool06Oooool00ol0o`3ooooooooo
o`0;ooooo`03o`3o0?oooooooooo00Gooooo00Co0?l0oooooooooooo0?l05Oooool001Gooooo00?o
0?l0ooooooooool00oooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo01?ooooo00?o
0?l0ooooooooool09oooool00ol0o`3oooooooooo`0Iooooo`03o`000?oooooooooo03Kooooo00?o
0?l0ooooooooool06Oooool00ol0o`3oooooooooo`0;ooooo`03o`3o0?oooooooooo00Cooooo00Go
0?l0ooooooooooooooooo`3o000Dooooo`005Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oo
oooooooo00Kooooo00?o0?l0ooooooooool04oooool00ol0o`3oooooooooo`0Vooooo`;o0?l07?oo
ool00ol0003oooooooooo`0gooooo`03o`3o0?oooooooooo01Wooooo00?o0?l0ooooooooool02_oo
ool00ol0o`3oooooooooo`05ooooo`04o`3o0?ooooooooooo`3o01Cooooo000Dooooo`03o`3o0?oo
oooooooo00?ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oo
oooooooo02Kooooo00?o0?l0ooooooooool07?ooool00ol0003oooooooooo`0hooooo`03o`3o0?oo
oooooooo01Wooooo00?o0?l0ooooooooool02_ooool00ol0o`3oooooooooo`04ooooo`05o`3o0?oo
ooooooooooooool0o`004oooool001?ooooo00?o0?l0ooooooooool01?ooool00ol0o`3ooooooooo
o`06ooooo`03o`3o0?oooooooooo01;ooooo00?o0?l0ooooooooool09_ooool00ol0o`3ooooooooo
o`0Mooooo`03o`000?oooooooooo03Wooooo00?o0?l0ooooooooool06?ooool00ol0o`3ooooooooo
o`0:ooooo`03o`3o0?oooooooooo00Gooooo00Go0?l0ooooooooooooooooo`3o000Booooo`004ooo
ool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool04Ooo
ool00ol0o`3oooooooooo`0Uooooo`;o0?l08?ooool00ol0003oooooooooo`0jooooo`03o`3o0?oo
oooooooo01Sooooo00?o0?l0ooooooooool02_ooool00ol0o`3oooooooooo`04ooooo`05o`3o0?oo
ooooooooooooool0o`004_ooool001;ooooo00?o0?l0ooooooooool00oooool00ol0o`3ooooooooo
o`07ooooo`03o`3o0?oooooooooo017ooooo00?o0?l0ooooooooool09Oooool00ol0o`3ooooooooo
o`0Pooooo`03o`000?oooooooooo03[ooooo00?o0?l0ooooooooool06?ooool00ol0o`3ooooooooo
o`0;ooooo`03o`3o0?oooooooooo00Cooooo00Go0?l0ooooooooooooooooo`3o000Aooooo`004_oo
ool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool04Ooo
ool00ol0o`3oooooooooo`0Uooooo`03o`3o0?oooooooooo027ooooo00?o0000ooooooooool0>ooo
ool00ol0o`3oooooooooo`0Hooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool01?oo
ool01Ol0o`3ooooooooooooooooo0?l0017ooooo000Booooo`03o`3o0?oooooooooo00;ooooo00?o
0?l0ooooooooool01oooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo02Gooooo00?o
0?l0ooooooooool06?ooool5o`0000Gooooo00?o0000ooooooooool0??ooool00ol0o`3ooooooooo
o`0Hooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool01?ooool01Ol0o`3ooooooooo
oooooooo0?l0013ooooo000Aooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01ooo
ool00ol0o`3oooooooooo`0Aooooo`03o`3o0?oooooooooo02Cooooo00?o0?l0ooooooooool04?oo
ool=o`3o0003odA4A?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool00ol0o`3ooooooooo
o`0Gooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool01?ooool01Ol0o`3ooooooooo
oooooooo0?l0013ooooo000Aooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01ooo
ool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo02Cooooo00?o0?l0ooooooooool02ooo
ool6o`3o0003ooooool0003o000000Co00000oooool00onHV9So8B4Qonk^kP07o`3o03oooooo00?o
0?l0ooooooooool06?ooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo00Cooooo00Go
0?l0ooooooooooooooooo`3o000?ooooo`004?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oo
oooooooo00Oooooo00?o0?l0ooooooooool04?ooool00ol0o`3oooooooooo`0Tooooo`03o`3o0?oo
oooooooo00Sooooo1?l0o`0Aooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000o`3o0?l0o`001?l0
o`0jooooo`03o`3o0?oooooooooo01Oooooo00?o0?l0ooooooooool02_ooool00ol0o`3ooooooooo
o`04ooooo`05o`3o0?ooooooooooooooool0o`003oooool0013ooooo00?o0?l0ooooooooool00_oo
ool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo013ooooo00?o0?l0ooooooooool09?oo
ool00ol0o`3oooooooooo`05ooooo`Co0?l05_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oo
oooooooo00Cooooo0ol0o`0hooooo`03o`3o0?oooooooooo01Oooooo00?o0?l0ooooooooool02_oo
ool00ol0o`3oooooooooo`04ooooo`04o`3o0?ooooooooooo`3o00oooooo000?ooooo`03o`3o0?oo
oooooooo00;ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oo
oooooooo02?ooooo00?o0?l0ooooooooool00oooool3o`3o01_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`07ooooo`?o0?l0=_ooool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oo
oooooooo00[ooooo00?o0?l0ooooooooool01?ooool01Ol0o`3ooooooooooooooooo0?l000kooooo
000?ooooo`05o`3o0?ooooooooooooooool0o`002Oooool00ol0o`3oooooooooo`0@ooooo`03o`3o
0?oooooooooo02?ooooo00?o0?l0ooooooooool00_ooool2o`3o01[ooooo00Go0000okZj^_oooooo
V9RHoa0@4005ooooo`03o`000?oooooooooo00[ooooo0_l0o`0dooooo`03o`3o0?oooooooooo01Oo
oooo00?o0?l0ooooooooool02_ooool00ol0o`3oooooooooo`04ooooo`04o`3o0?ooooooooooo`3o
00kooooo000?ooooo`05o`3o0?ooooooooooooooool0o`002Oooool00ol0o`3oooooooooo`0?oooo
o`03o`3o0?oooooooooo02?ooooo00Co0?l0oooooooooooooooo0_l0o`0Looooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0<ooooo`;o0?l0<oooool00ol0o`3ooooooooo
o`0Fooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool01?ooool01Ol0o`3ooooooooo
oooooooo0?l000gooooo000>ooooo`05o`3o0?ooooooooooooooool0o`002Oooool00ol0o`3ooooo
ooooo`0?ooooo`03o`3o0?oooooooooo02Cooooo00Co0?l0ooooool0o`3o0?l0:?ooool00ol0003o
ooooooooo`0>ooooo`;o0?l0<_ooool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oooooooooo00[o
oooo00?o0?l0ooooooooool01?ooool01?l0o`3oooooooooool0o`0=ooooo`003_ooool01Ol0o`3o
oooooooooooooooo0?l000Wooooo00?o0?l0ooooooooool03oooool00ol0o`3oooooooooo`0Soooo
o`03o`3o0?oooooo0?l002[ooooo00?o0000ooooooooool04?ooool2o`3o033ooooo00?o0?l0oooo
ooooool05oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00Cooooo00Go0?l0oooo
ooooooooooooo`3o000<ooooo`003Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo
00Kooooo00?o0?l0ooooooooool03oooool00ol0o`3oooooooooo`0Sooooo`?o0?l0:oooool00ol0
003oooooooooo`0Booooo`;o0?l0;oooool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oooooooooo
00[ooooo00?o0?l0ooooooooool01?ooool01?l0o`3oooooooooool0o`0<ooooo`003Oooool01Ol0
o`3ooooooooooooooooo0?l000Wooooo00?o0?l0ooooooooool03_ooool00ol0o`3oooooooooo`0S
ooooo`;o0?l0;Oooool00ol0003oooooooooo`0Dooooo`;o0?l0;_ooool00ol0o`3oooooooooo`0F
ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool01?ooool01?l0o`3oooooooooool0
o`0<ooooo`003?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0
ooooooooool03oooool00ol0o`3oooooooooo`0Rooooo`03o`3o0?oooooooooo02gooooo00?o0000
ooooooooool05_ooool00ol0o`3oooooooooo`0/ooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0
ooooooooool02_ooool00ol0o`3oooooooooo`03ooooo`05o`3o0?ooooooooooooooool0o`002ooo
ool000cooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooo
oooo00kooooo00?o0?l0ooooooooool08_ooool00ol0o`3oooooooooo`0^ooooo`03o`000?oooooo
oooo01Oooooo00?o0?l0ooooooooool0:oooool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oooooo
oooo00Wooooo00?o0?l0ooooooooool01?ooool01?l0o`3oooooooooool0o`0;ooooo`002oooool0
0ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool03_ooool0
0ol0o`3oooooooooo`0Qooooo`;o0?l0<?ooool00ol0003oooooooooo`0Hooooo`;o0?l0;?ooool0
0ol0o`3oooooooooo`0Eooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool01?ooool0
1?l0o`3oooooooooool0o`0;ooooo`002oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooo
oooo00Kooooo00?o0?l0ooooooooool03_ooool00ol0o`3oooooooooo`0Qooooo`;o0?l0<Oooool0
0ol0003oooooooooo`0Jooooo`03o`3o0?oooooooooo02Wooooo00?o0?l0ooooooooool05_ooool0
0ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0oooooooooooo0?l02ooo
ool000[ooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooo
oooo00gooooo00?o0?l0ooooooooool08Oooool2o`3o03;ooooo0_l0000Looooo`03o`3o0?oooooo
oooo02Wooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooo
oooo00Cooooo00Co0?l0oooooooooooo0?l02_ooool000[ooooo00?o0?l0ooooooooool00_ooool0
0ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool08?ooool2
o`3o03?ooooo00?o0000ooooooooool07?ooool2o`3o02[ooooo00?o0?l0ooooooooool05?ooool0
0ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00Cooooo00Co0?l0oooooooooooo0?l02_oo
ool000[ooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooo
oooo00gooooo00?o0?l0ooooooooool08?ooool2o`3o03Cooooo00?o0000ooooooooool07_ooool0
0ol0o`3oooooooooo`0Wooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool02Oooool0
0ol0o`3oooooooooo`03ooooo`04o`3o0?ooooooooooo`3o00[ooooo0009ooooo`03o`3o0?oooooo
oooo00?ooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0>ooooo`03o`3o0?oooooo
oooo01oooooo00?o0?l0ooooool0o`00=?ooool00ol0003oooooooooo`0Oooooo`03o`3o0?oooooo
oooo02Oooooo00?o0?l0ooooooooool05?ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooo
oooo00Cooooo00Co0?l0oooooooooooo0?l02Oooool000Wooooo00?o0?l0ooooooooool00_ooool0
0ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool07_ooool0
0ol0o`3oooooo`3o000eooooo`03o`000?oooooooooo023ooooo00?o0?l0ooooooooool09_ooool0
0ol0o`3oooooooooo`0Eooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool01?ooool0
1?l0o`3oooooooooool0o`09ooooo`002Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooo
oooo00Kooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0Nooooo`04o`3o0?oooooo
ooooo`3o03Gooooo00?o0000ooooooooool08Oooool00ol0o`3oooooooooo`0Vooooo`03o`3o0?oo
oooooooo01Cooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`03ooooo`05o`3o0?oo
ooooooooooooool0o`002?ooool000Wooooo00?o0?l0ooooooooool00_ooool00ol0o`3ooooooooo
o`05ooooo`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool07_ooool00ol0o`3oooooo`3o
000fooooo`03o`000?oooooooooo02;ooooo00?o0?l0ooooooooool09Oooool00ol0o`3ooooooooo
o`0Dooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooo
oooooooo0?l000Sooooo0008ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01_oo
ool00ol0o`3oooooooooo`0>ooooo`03o`3o0?oooooooooo01gooooo00?o0?l0ooooool0o`00=ooo
ool00ol0003oooooooooo`0Sooooo`03o`3o0?oooooooooo02Cooooo00?o0?l0ooooooooool05Ooo
ool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00Cooooo00Co0?l0oooooooooooo0?l0
2?ooool000Sooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oo
oooooooo00gooooo00?o0?l0ooooooooool07Oooool01?l0o`3oooooooooool0o`0gooooo`03o`00
0?oooooooooo02?ooooo00?o0?l0ooooooooool09Oooool00ol0o`3oooooooooo`0Dooooo`03o`3o
0?oooooooooo00Wooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooooooooooo0?l000Oo
oooo0008ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01_ooool00ol0o`3ooooo
ooooo`0=ooooo`03o`3o0?oooooooooo01cooooo00Co0?l0oooooooooooo0?l0>?ooool00ol0003o
ooooooooo`0Tooooo`03o`3o0?oooooooooo02Cooooo00?o0?l0ooooooooool05?ooool00ol0o`3o
ooooooooo`09ooooo`03o`3o0?oooooooooo00?ooooo00Go0?l0ooooooooooooooooo`3o0007oooo
o`002?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0oooooooo
ool03_ooool00ol0o`3oooooooooo`0Looooo`04o`3o0?ooooooooooo`3o03Sooooo00?o0000oooo
ooooool09Oooool00ol0o`3oooooooooo`0Sooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0oooo
ooooool02?ooool00ol0o`3oooooooooo`03ooooo`05o`3o0?ooooooooooooooool0o`001oooool0
00Sooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo
00kooooo00?o0?l0ooooooooool06oooool01?l0o`3oooooooooool0o`0iooooo`03o`000?oooooo
oooo02Kooooo00?o0?l0ooooooooool08oooool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooo
oooo00Wooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooooooooooo0?l000Kooooo0008
ooooo`05o`3o0?ooooooooooooooool0o`002?ooool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oo
oooooooo01_ooooo00Go0?l0ooooooooooooooooo`3o000iooooo`03o`000?oooooooooo02Oooooo
00?o0?l0ooooooooool08_ooool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooooooo00Wooooo
00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooooooooooo0?l000Kooooo0007ooooo`03o`3o
0?oooooooooo00;ooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0=ooooo`03o`3o
0?oooooooooo01_ooooo00Co0?l0oooooooooooo0?l0>_ooool2o`0002Sooooo00?o0?l0oooooooo
ool08oooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0oooooooo
ool00oooool01Ol0o`3ooooooooooooooooo0?l000Kooooo0007ooooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo01[o
oooo00Go0?l0ooooooooooooooooo`3o000jooooo`03o`000?oooooooooo02Sooooo00?o0?l0oooo
ooooool08_ooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0oooo
ooooool01?ooool01?l0o`3oooooooooool0o`06ooooo`001oooool00ol0o`3oooooooooo`02oooo
o`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool03_ooool00ol0o`3oooooooooo`0Joooo
o`04o`3o0?ooooooooooo`3o03_ooooo00?o0000ooooooooool0:Oooool00ol0o`3oooooooooo`0Q
ooooo`03o`3o0?oooooooooo01?ooooo00?o0?l0ooooooooool02_ooool00ol0o`3oooooooooo`03
ooooo`04o`3o0?ooooooooooo`3o00Kooooo0007ooooo`05o`3o0?ooooooooooooooool0o`002?oo
ool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo01[ooooo00Go0?l0oooooooooooooooo
o`3o000kooooo`03o`000?oooooooooo02[ooooo00?o0?l0ooooooooool08Oooool00ol0o`3ooooo
ooooo`0Cooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool00oooool01?l0o`3ooooo
ooooool0o`06ooooo`001oooool01Ol0o`3ooooooooooooooooo0?l000Sooooo00?o0?l0oooooooo
ool03Oooool00ol0o`3oooooooooo`0Jooooo`04o`3o0?ooooooooooo`3o03cooooo00?o0000oooo
ooooool0:_ooool00ol0o`3oooooooooo`0Qooooo`03o`3o0?oooooooooo01?ooooo00?o0?l0oooo
ooooool02Oooool00ol0o`3oooooooooo`03ooooo`05o`3o0?ooooooooooooooool0o`001Oooool0
00Oooooo00Go0?l0ooooooooooooooooo`3o0008ooooo`03o`3o0?oooooooooo00gooooo00?o0?l0
ooooooooool06_ooool01?l0o`3oooooooooool0o`0looooo`03o`000?oooooooooo02_ooooo00?o
0?l0ooooooooool08?ooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo00Wooooo00?o
0?l0ooooooooool01?ooool01?l0o`3oooooooooool0o`05ooooo`001_ooool01Ol0o`3ooooooooo
oooooooo0?l000Wooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0Iooooo`05o`3o
0?ooooooooooooooool0o`00??ooool00ol0003oooooooooo`0[ooooo`03o`3o0?oooooooooo027o
oooo00?o0?l0ooooooooool04_ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00Co
oooo00Co0?l0oooooooooooo0?l01Oooool000Kooooo00Go0?l0ooooooooooooooooo`3o0008oooo
o`03o`3o0?oooooooooo00gooooo00?o0?l0ooooooooool06_ooool01?l0o`3oooooooooool0o`0m
ooooo`03o`000?oooooooooo02cooooo00?o0?l0ooooooooool08?ooool00ol0o`3oooooooooo`0B
ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool00oooool01?l0o`3oooooooooool0
o`05ooooo`001_ooool01Ol0o`3ooooooooooooooooo0?l000Sooooo00?o0?l0ooooooooool03Ooo
ool00ol0o`3oooooooooo`0Jooooo`04o`3o0?ooooooooooo`3o03gooooo00?o0000ooooooooool0
;Oooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oooooooooo01;ooooo00?o0?l0ooooooooool0
2_ooool00ol0o`3oooooooooo`03ooooo`04o`3o0?ooooooooooo`3o00Gooooo0006ooooo`05o`3o
0?ooooooooooooooool0o`002?ooool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo01Wo
oooo00Go0?l0ooooooooooooooooo`3o000mooooo`03o`000?oooooooooo02gooooo00?o0?l0oooo
ooooool08?ooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooooooo00Wooooo00?o0?l0oooo
ooooool00oooool01?l0o`3oooooooooool0o`05ooooo`001_ooool01Ol0o`3ooooooooooooooooo
0?l000Sooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0Iooooo`04o`3o0?oooooo
ooooo`3o03kooooo00?o0000ooooooooool0;_ooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oo
oooooooo01;ooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`03ooooo`05o`3o0?oo
ooooooooooooool0o`001?ooool000Kooooo00Go0?l0ooooooooooooooooo`3o0008ooooo`03o`3o
0?oooooooooo00cooooo00?o0?l0ooooooooool06_ooool01?l0o`3oooooooooool0o`0nooooo`03
o`000?oooooooooo02kooooo00?o0?l0ooooooooool07oooool00ol0o`3oooooooooo`0Booooo`03
o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooooooooooo0?l0
00Cooooo0006ooooo`05o`3o0?ooooooooooooooool0o`002?ooool00ol0o`3oooooooooo`0<oooo
o`03o`3o0?oooooooooo01Wooooo00Go0?l0ooooooooooooooooo`3o000nooooo`03o`000?oooooo
oooo02kooooo00?o0?l0ooooooooool07oooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooo
oooo00Wooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooooooooooo0?l000Cooooo0005
ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0=
ooooo`03o`3o0?oooooooooo01Wooooo00Co0?l0oooooooooooo0?l0?oooool2o`00033ooooo00?o
0?l0ooooooooool07_ooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooooooo00Wooooo00?o
0?l0ooooooooool00oooool01Ol0o`3ooooooooooooooooo0?l000Cooooo0005ooooo`03o`3o0?oo
oooooooo00;ooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`07ooooo`;o000000Go
410@ooooooooooooooooo`3o000Kooooo`04o`3o0?ooooooooooo`3o00cooooo1Ol0000^ooooo`03
o`000?oooooooooo02kooooo00?o0000o`3o0?l000000_l0000Nooooo`03o`3o0?oooooooooo013o
oooo0_l000000ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00?ooooo00Go0?l0oooooooo
ooooooooo`3o0004ooooo`001Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Go
oooo00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo01So
oooo00Go0?l0ooooooooooooooooo`3o000<ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;_ooool0
0ol0003oooooooooo`0^ooooo`05oiRHV?l0o`3ok^k^oooooom4A4@07_ooool00ol0o`3ooooooooo
o`0Aooooo`03o`000?l0o`3ooooo00Wooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooo
oooooooo0?l000Cooooo0005ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01Ooo
ool00ol0o`3o0000o`000003o`0000;ooooo1Ol00002ooooo`03o`3o0?oooooooooo01Wooooo00Co
0?l0oooooooooooo0?l01Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0;oooool00ol0003ooooo
ooooo`0_ooooo`03oiRHV?l0o`3ok^k^01oooooo00?o0?l0ooooooooool03_ooool4o`000003o`3o
0?oooooooooo00Sooooo00?o0?l0ooooooooool01?ooool01?l0o`3oooooooooool0o`04ooooo`00
1Oooool01Ol0o`3ooooooooooooooooo0?l000Sooooo00?o0?l0ooooooooool01Oooool01?m4A4Co
gMgMooooool00003ooooo`03o`3o0?oooooooooo01Wooooo00Co0?l0oooooooooooo0?l03oooool0
0onHV9So8B4Qonk^kP0^ooooo`03o`000?oooooooooo033ooooo00?o0?l0ob4Q8Oo^k^h07_ooool0
0ol0o`3oooooooooo`0>ooooo`05odA4A?oMgMgoooooo`000?l0o`002_ooool00ol0o`3ooooooooo
o`04ooooo`04o`3o0?ooooooooooo`3o00Cooooo0005ooooo`05o`3o0?ooooooooooooooool0o`00
2?ooool00ol0o`3oooooooooo`05ooooo`04omgMgOmEEEGoooooo`0000?ooooo00?o0?l0oooooooo
ool06Oooool01?l0o`3oooooooooool0o`0@ooooo`03ogMgMomVIVKooooo02gooooo00?o0000oooo
ooooool0<?ooool00ol0o`3oMgMgofIVIP0Nooooo`03o`3o0?oooooooooo00kooooo00GogMgMoeEE
EOoooooo0000o`3o000;ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0oooooooooooo0?l01?oo
ool000Gooooo00Go0?l0ooooooooooooooooo`3o0008ooooo`03o`3o0?oooooooooo00Kooooo00?o
MgMgolc<c?l000000oooool00ol0o`3oooooooooo`0Iooooo`04o`3o0?ooooooooooo`3o017ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`3o0?l0003ooooo01gooooo
00?o0?l0ooooooooool03oooool01?mgMgOoc<c<o`000?l0o`0;ooooo`03o`3o0?oooooooooo00?o
oooo00Co0?l0oooooooooooo0?l01?ooool000Gooooo00Go0?l0ooooooooooooooooo`3o0007oooo
o`03o`3o0?oooooooooo00Oooooo00?ok^k^odA4A?l000000oooool00ol0o`3oooooooooo`0Ioooo
o`04o`3o0?ooooooooooo`3o00gooooo00Go0000okZj^_ooooooV9RHoa0@400^ooooo`03o`000?oo
oooooooo02kooooo00Go0000okZj^_oooooo0?l0oa0@400Nooooo`03o`3o0?oooooooooo00oooooo
00Cok^k^odA4A?l0003o0?l02oooool00ol0o`3oooooooooo`03ooooo`04o`3o0?ooooooooooo`3o
00Cooooo0005ooooo`05o`3o0?ooooooooooooooool0o`001oooool00ol0o`3oooooooooo`08oooo
o`03ogMgMol0003ooooo00;ooooo00?o0?l0ooooooooool06Oooool01?l0o`3oooooooooool0o`0=
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0;_ooool00ol0003oooooooooo`0^ooooo`05oiRHV?l@
413o0000o`3o0?o<c<`07_ooool00ol0o`3oooooooooo`0@ooooo`03ogMgMol0003o0?l000_ooooo
00?o0?l0ooooooooool00oooool01?l0o`3oooooooooool0o`04ooooo`001Oooool01Ol0o`3ooooo
oooooooooooo0?l000Oooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0Iooooo`04
o`3o0?ooooooooooo`3o043ooooo00?o0000ooooooooool0<Oooool00ol0o`3oooooooooo`0Moooo
o`03o`3o0?oooooooooo01;ooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`03oooo
o`04o`3o0?ooooooooooo`3o00Cooooo0005ooooo`05o`3o0?ooooooooooooooool0o`001oooool0
0ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo01Wooooo00Co0?l0oooooooooooo0?l0@?oo
ool00ol0003oooooooooo`0aooooo`03o`3o0?oooooooooo01gooooo00?o0?l0ooooooooool04_oo
ool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0oooooooooooo0?l0
1?ooool000Cooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oo
oooooooo00gooooo00?o0?l0ooooooooool06Oooool01?l0o`3oooooooooool0o`10ooooo`03o`00
0?oooooooooo03;ooooo00?o0?l0ooooooooool07?ooool00ol0o`3oooooooooo`0Booooo`03o`3o
0?oooooooooo00Wooooo00?o0?l0ooooooooool00oooool01?l0o`3oooooooooool0o`04ooooo`00
1?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool0
3Oooool00ol0o`3oooooooooo`0Hooooo`05o`3o0?ooooooooooooooool0o`00@?ooool00ol0003o
ooooooooo`0booooo`03o`3o0?oooooooooo01cooooo00?o0?l0ooooooooool04_ooool00ol0o`3o
ooooooooo`09ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0oooooooooooo0?l01?ooool000Co
000000?o0?l0o`000?l000000_l000000ol0o`3o0000o`000005o`000003o`3o0?l0003o000000go
000000?o0?l0o`000?l000006?l000001Ol0o`3o0000o`000?l0003o0?l007Go000000?o0?l0o`00
0?l000007?l000000ol0o`3o0000o`00000Bo`000003o`3o0?l0003o000000Wo000000?o0?l0o`00
0?l000000ol000001?l0o`3o0000o`000?l0o`04o`0000001?ooool00ol0o`3oooooooooo`02oooo
o`04o`3o0?ooooooooooo`0000Cooooo00?o0?l0ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`3o0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`04o`3o0?ooooooooooo`3o00cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?l0o`3ooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03o`3o0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o0?l0oooo
o`0:ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0oooooooooooo0?l01?ooool000Cooooo00?o
0?l0ooooooooool00_ooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo00gooooo00?o
0?l0ooooooooool06Oooool01?l0o`3oooooooooool0o`10ooooo`03o`000?oooooooooo03;ooooo
00?o0?l0ooooooooool07?ooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooooooo00Wooooo
00?o0?l0ooooooooool00oooool01?l0o`3oooooooooool0o`04ooooo`001Oooool01Ol0o`3ooooo
oooooooooooo0?l000Oooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0Iooooo`04
o`3o0?ooooooooooo`3o043ooooo00?o0000ooooooooool0<Oooool00ol0o`3oooooooooo`0Moooo
o`03o`3o0?oooooooooo01;ooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`03oooo
o`04o`3o0?ooooooooooo`3o00Cooooo0005ooooo`05o`3o0?ooooooooooooooool0o`001oooool0
0ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo01Wooooo00Co0?l0oooooooooooo0?l0@?oo
ool00ol0003oooooooooo`0aooooo`03o`3o0?oooooooooo01gooooo00?o0?l0ooooooooool04_oo
ool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0oooooooooooo0?l0
1?ooool000Gooooo00Go0?l0ooooooooooooooooo`3o0007ooooo`03o`3o0?oooooooooo00gooooo
00?o0?l0ooooooooool06Oooool01?l0o`3oooooooooool0o`10ooooo`03o`000?oooooooooo037o
oooo00?o0?l0ooooooooool07Oooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooooooo00Wo
oooo00?o0?l0ooooooooool00oooool01?l0o`3oooooooooool0o`04ooooo`001Oooool01Ol0o`3o
oooooooooooooooo0?l000Oooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0Ioooo
o`04o`3o0?ooooooooooo`3o043ooooo00?o0000ooooooooool0<Oooool00ol0o`3oooooooooo`0M
ooooo`03o`3o0?oooooooooo01;ooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`03
ooooo`04o`3o0?ooooooooooo`3o00Cooooo0005ooooo`05o`3o0?ooooooooooooooool0o`001ooo
ool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo01Wooooo00Co0?l0oooooooooooo0?l0
@?ooool00ol0003oooooooooo`0aooooo`03o`3o0?oooooooooo01gooooo00?o0?l0ooooooooool0
4_ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0oooooooooooo
0?l01?ooool000Gooooo00Go0?l0ooooooooooooooooo`3o0007ooooo`03o`3o0?oooooooooo00go
oooo00?o0?l0ooooooooool06Oooool01?l0o`3oooooooooool0o`10ooooo`03o`000?oooooooooo
033ooooo00?o0?l0ooooooooool07_ooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooooooo
00Wooooo00?o0?l0ooooooooool00oooool01?l0o`3oooooooooool0o`04ooooo`001Oooool01Ol0
o`3ooooooooooooooooo0?l000Sooooo00?o0?l0ooooooooool03?ooool00ol0o`3oooooooooo`0I
ooooo`05o`3o0?ooooooooooooooool0o`00?oooool00ol0003oooooooooo`0`ooooo`03o`3o0?oo
oooooooo01kooooo00?o0?l0ooooooooool04_ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oo
oooooooo00?ooooo00Co0?l0oooooooooooo0?l01?ooool000Gooooo00?o0?l0ooooooooool00_oo
ool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo00cooooo00?o0?l0ooooooooool06Ooo
ool01Ol0o`3ooooooooooooooooo0?l003oooooo00?o0000ooooooooool0<?ooool00ol0o`3ooooo
ooooo`0Nooooo`03o`3o0?oooooooooo01;ooooo00?o0?l0ooooooooool02Oooool00ol0o`3ooooo
ooooo`02ooooo`05o`3o0?ooooooooooooooool0o`001?ooool000Gooooo00?o0?l0ooooooooool0
0_ooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo00cooooo00?o0?l0ooooooooool0
6_ooool01?l0o`3oooooooooool0o`0oooooo`03o`000?oooooooooo033ooooo00?o0?l0oooooooo
ool07_ooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooooooo00Sooooo00?o0?l0oooooooo
ool00oooool01Ol0o`3ooooooooooooooooo0?l000Cooooo0005ooooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo01Wo
oooo00Co0?l0oooooooooooo0?l0?oooool00ol0003oooooooooo`0`ooooo`03o`3o0?oooooooooo
01kooooo00?o0?l0ooooooooool04_ooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo
00?ooooo00Go0?l0ooooooooooooooooo`3o0004ooooo`001Oooool00ol0o`3oooooooooo`02oooo
o`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0Ioooo
o`04o`3o0?ooooooooooo`3o03oooooo0_l0000`ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0
ooooooooool04_ooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0
oooooooooooo0?l01Oooool000Gooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`05
ooooo`03o`3o0?oooooooooo00gooooo00?o0?l0ooooooooool06Oooool01Ol0o`3ooooooooooooo
oooo0?l003kooooo00?o0000ooooooooool0;_ooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oo
oooooooo01?ooooo00?o0?l0ooooooooool02?ooool00ol0o`3oooooooooo`03ooooo`04o`3o0?oo
ooooooooo`3o00Gooooo0006ooooo`05o`3o0?ooooooooooooooool0o`002?ooool00ol0o`3ooooo
ooooo`0<ooooo`03o`3o0?oooooooooo01Wooooo00Go0?l0ooooooooooooooooo`3o000nooooo`03
o`000?oooooooooo02kooooo00?o0?l0ooooooooool07oooool00ol0o`3oooooooooo`0Booooo`03
o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool00oooool01?l0o`3oooooooooool0o`05oooo
o`001_ooool01Ol0o`3ooooooooooooooooo0?l000Sooooo00?o0?l0ooooooooool03?ooool00ol0
o`3oooooooooo`0Jooooo`05o`3o0?ooooooooooooooool0o`00?Oooool00ol0003oooooooooo`0]
ooooo`03o`3o0?oooooooooo023ooooo00?o0?l0ooooooooool04_ooool00ol0o`3oooooooooo`09
ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0oooooooooooo0?l01Oooool000Kooooo00Go0?l0
ooooooooooooooooo`3o0008ooooo`03o`3o0?oooooooooo00cooooo00?o0?l0ooooooooool06_oo
ool01Ol0o`3ooooooooooooooooo0?l003gooooo00?o0000ooooooooool0;Oooool00ol0o`3ooooo
ooooo`0Oooooo`03o`3o0?oooooooooo01?ooooo00?o0?l0ooooooooool02?ooool00ol0o`3ooooo
ooooo`04ooooo`04o`3o0?ooooooooooo`3o00Gooooo0006ooooo`05o`3o0?ooooooooooooooool0
o`002?ooool00ol0o`3oooooooooo`0<ooooo`03o`3o0?oooooooooo01[ooooo00?o0?l0oooooooo
ool00_ooool00ol0o`3oooooooooo`0jooooo`03o`000?oooooooooo02cooooo00?o0?l0oooooooo
ool08?ooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0oooooooo
ool01?ooool01?l0o`3oooooooooool0o`05ooooo`001_ooool01Ol0o`3ooooooooooooooooo0?l0
00Sooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0Jooooo`05o`3o0?oooooooooo
ooooool0o`00??ooool00ol0003oooooooooo`0[ooooo`03o`3o0?oooooooooo027ooooo00?o0?l0
ooooooooool04oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00Cooooo00Co0?l0
oooooooooooo0?l01Oooool000Kooooo00Go0?l0ooooooooooooooooo`3o0008ooooo`03o`3o0?oo
oooooooo00gooooo00?o0?l0ooooooooool06_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oo
oooooooo03Wooooo00?o0000ooooooooool0:_ooool00ol0o`3oooooooooo`0Rooooo`03o`3o0?oo
oooooooo01?ooooo00?o0?l0ooooooooool02?ooool00ol0o`3oooooooooo`03ooooo`05o`3o0?oo
ooooooooooooool0o`001Oooool000Oooooo00Co0?l0oooooooooooo0?l02Oooool00ol0o`3ooooo
ooooo`0<ooooo`03o`3o0?oooooooooo01[ooooo00?o0?l0ooooooooool00_ooool00ol0o`3ooooo
ooooo`0iooooo`03o`000?oooooooooo02Wooooo00?o0?l0ooooooooool08_ooool00ol0o`3ooooo
ooooo`0Cooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooo
oooooooooooo0?l000Gooooo0007ooooo`05o`3o0?ooooooooooooooool0o`002?ooool00ol0o`3o
ooooooooo`0<ooooo`03o`3o0?oooooooooo01_ooooo00?o0?l0ooooooooool00_ooool00ol0o`3o
ooooooooo`0hooooo`03o`000?oooooooooo02Sooooo00?o0?l0ooooooooool08oooool00ol0o`3o
ooooooooo`0Cooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool00oooool01?l0o`3o
ooooooooool0o`06ooooo`001oooool01Ol0o`3ooooooooooooooooo0?l000Sooooo00?o0?l0oooo
ooooool03Oooool00ol0o`3oooooooooo`0Jooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0oooo
ooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`3o0?oooooooooo02Cooooo00?o0?l0oooo
ooooool04oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00Cooooo00Co0?l0oooo
oooooooo0?l01_ooool000Oooooo00Go0?l0ooooooooooooooooo`3o0008ooooo`03o`3o0?oooooo
oooo00gooooo00?o0?l0ooooooooool06_ooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooo
oooo03Kooooo00?o0000ooooooooool09_ooool00ol0o`3oooooooooo`0Uooooo`03o`3o0?oooooo
oooo01?ooooo00?o0?l0ooooooooool02?ooool00ol0o`3oooooooooo`04ooooo`04o`3o0?oooooo
ooooo`3o00Kooooo0007ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01Oooool0
0ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo01_ooooo00?o0?l0ooooooooool01?ooool2
o`3o03Kooooo00?o0000ooooooooool09?ooool2o`3o02Oooooo00?o0?l0ooooooooool05?ooool0
0ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooool0o`001oooool0
00Oooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo
00gooooo00?o0?l0ooooooooool06_ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo
03?ooooo0_l0000Sooooo`;o0?l0:Oooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo
00Wooooo00?o0?l0ooooooooool00oooool01?l0o`3oooooooooool0o`07ooooo`002?ooool01Ol0
o`3ooooooooooooooooo0?l000Sooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0J
ooooo`03o`3o0?oooooooooo00Oooooo0_l0o`0cooooo`03o`000?oooooooooo027ooooo00?o0?l0
ooooooooool0:Oooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0
ooooooooool00oooool01?l0o`3oooooooooool0o`07ooooo`002?ooool01Ol0o`3ooooooooooooo
oooo0?l000Sooooo00?o0?l0ooooooooool03_ooool00ol0o`3oooooooooo`0Jooooo`03o`3o0?oo
oooooooo00Sooooo00?o0?l0ooooooooool0<?ooool00ol0003oooooooooo`0Oooooo`;o0?l0:ooo
ool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool01?oo
ool01?l0o`3oooooooooool0o`07ooooo`002?ooool01Ol0o`3ooooooooooooooooo0?l000Sooooo
00?o0?l0ooooooooool03_ooool00ol0o`3oooooooooo`0Jooooo`03o`3o0?oooooooooo00Wooooo
0_l0o`0`ooooo`03o`000?oooooooooo01cooooo0ol0o`0]ooooo`03o`3o0?oooooooooo01?ooooo
00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`04ooooo`04o`3o0?ooooooooooo`3o00Oo
oooo0008ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01_ooool00ol0o`3ooooo
ooooo`0=ooooo`03o`3o0?oooooooooo01[ooooo00?o0?l0ooooooooool02oooool00ol0o`3ooooo
ooooo`0]ooooo`03o`000?oooooooooo01[ooooo0_l0o`0_ooooo`03o`3o0?oooooooooo01Cooooo
00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`03ooooo`04o`3o0?ooooooooooo`3o00So
oooo0008ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01_ooool00ol0o`3ooooo
ooooo`0>ooooo`03o`3o0?oooooooooo01[ooooo00?o0?l0ooooooooool02oooool2o`3o02gooooo
00?o0000ooooooooool06?ooool2o`3o037ooooo00?o0?l0ooooooooool05?ooool00ol0o`3ooooo
ooooo`09ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0oooooooooooo0?l02?ooool000Wooooo
00Go0?l0ooooooooooooooooo`3o0008ooooo`03o`3o0?oooooooooo00kooooo00?o0?l0oooooooo
ool06oooool00ol0o`3oooooooooo`0<ooooo`;o0?l0:oooool00ol0003oooooooooo`0Fooooo`;o
0?l0<oooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0oooooooo
ool00oooool01?l0o`3oooooooooool0o`08ooooo`002Oooool01Ol0o`3ooooooooooooooooo0?l0
00Wooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0Kooooo`03o`3o0?oooooooooo
00kooooo0ol0o`0Xooooo`03o`000?oooooooooo01Cooooo0_l0o`0dooooo`03o`3o0?oooooooooo
01Cooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`03ooooo`05o`3o0?oooooooooo
ooooool0o`002?ooool000Wooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`06oooo
o`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool06oooool00ol0o`3oooooooooo`0@oooo
o`;o0?l09_ooool00ol0003oooooooooo`0Aooooo`?o0?l0=_ooool00ol0o`3oooooooooo`0Doooo
o`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooooooooooo
0?l000Sooooo000:ooooo`05o`3o0?ooooooooooooooool0o`002?ooool00ol0o`3oooooooooo`0>
ooooo`03o`3o0?oooooooooo01_ooooo00?o0?l0ooooooooool04_ooool00ol0o`3oooooooooo`0S
ooooo`03o`000?oooooooooo00kooooo0ol0o`0hooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0
ooooooooool02_ooool00ol0o`3oooooooooo`03ooooo`04o`3o0?ooooooooooo`3o00Wooooo000:
ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0=
ooooo`03o`3o0?oooooooooo01cooooo00?o0?l0ooooooooool04_ooool3o`3o02;ooooo00?o0000
ooooooooool02?ooool6o`3o03_ooooo00?o0?l0ooooooooool05?ooool00ol0o`3oooooooooo`0:
ooooo`03o`3o0?oooooooooo00;ooooo00Go0?l0ooooooooooooooooo`3o0009ooooo`002_ooool0
0ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool03_ooool0
0ol0o`3oooooooooo`0Looooo`03o`3o0?oooooooooo01Cooooo2?l0o`0Jooooo`03o`000?oooooo
oooo00;ooooo1_l0o`10ooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool02Oooool0
0ol0o`3oooooooooo`03ooooo`05o`3o0?ooooooooooooooool0o`002Oooool000_ooooo00Go0?l0
ooooooooooooooooo`3o0008ooooo`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool07Ooo
ool00ol0o`3oooooooooo`0Kooooo`Ko0?l04_ooool7o`3o04Gooooo00?o0?l0ooooooooool05Ooo
ool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo00?ooooo00Co0?l0oooooooooooo0?l0
2_ooool000_ooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oo
oooooooo00kooooo00?o0?l0ooooooooool07Oooool00ol0o`3oooooooooo`0Poooooa;o0?l00_oo
ool2o`0004Sooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oo
oooooooo00;ooooo00Go0?l0ooooooooooooooooo`3o000:ooooo`002oooool00ol0o`3ooooooooo
o`02ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool03_ooool00ol0o`3ooooooooo
o`0Mooooo`03o`3o0?oooooooooo03Cooooo00?o0000ooooooooool0A_ooool00ol0o`3ooooooooo
o`0Eooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooo
oooooooo0?l000[ooooo000<ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01Ooo
ool00ol0o`3oooooooooo`0>ooooo`03o`3o0?oooooooooo01kooooo00?o0?l0ooooooooool0<ooo
ool00ol0003oooooooooo`16ooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool02_oo
ool00ol0o`3oooooooooo`03ooooo`04o`3o0?ooooooooooo`3o00_ooooo000<ooooo`03o`3o0?oo
oooooooo00;ooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0>ooooo`03o`3o0?oo
oooooooo01kooooo00?o0?l0ooooooooool0<_ooool00ol0003oooooooooo`15ooooo`03o`3o0?oo
oooooooo01Kooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`03ooooo`05o`3o0?oo
ooooooooooooool0o`002oooool000cooooo00?o0?l0ooooooooool00_ooool00ol0o`3ooooooooo
o`06ooooo`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool07oooool00ol0o`3ooooooooo
o`0aooooo`03o`000?oooooooooo04Cooooo00?o0?l0ooooooooool05_ooool00ol0o`3ooooooooo
o`0:ooooo`03o`3o0?oooooooooo00?ooooo00Go0?l0ooooooooooooooooo`3o000;ooooo`003Ooo
ool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool03_oo
ool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oooooooooo033ooooo00?o0000ooooooooool0A?oo
ool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool00ooo
ool01?l0o`3oooooooooool0o`0<ooooo`003Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oo
oooooooo00Kooooo00?o0?l0ooooooooool03_ooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oo
oooooooo033ooooo00?o0000ooooooooool0@oooool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oo
oooooooo00[ooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooooooooooo0?l000cooooo
000=ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01_ooool00ol0o`3ooooooooo
o`0?ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0ooooooooool0;oooool00ol0003ooooooooo
o`12ooooo`03o`3o0?oooooooooo01Oooooo00?o0?l0ooooooooool02_ooool00ol0o`3ooooooooo
o`03ooooo`05o`3o0?ooooooooooooooool0o`003?ooool000kooooo00?o0?l0ooooooooool00_oo
ool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo00oooooo00?o0?l0ooooooooool07ooo
ool00ol0o`3oooooooooo`0^ooooo`03o`000?oooooooooo047ooooo00?o0?l0ooooooooool05ooo
ool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo00?ooooo00Go0?l0oooooooooooooooo
o`3o000=ooooo`003_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Kooooo00?o
0?l0ooooooooool03oooool00ol0o`3oooooooooo`0Pooooo`03o`3o0?oooooooooo02gooooo00?o
0000ooooooooool0@?ooool00ol0o`3oooooooooo`0Gooooo`03o`3o0?oooooooooo00_ooooo00?o
0?l0ooooooooool00oooool01Ol0o`3ooooooooooooooooo0?l000gooooo000?ooooo`05o`3o0?oo
ooooooooooooool0o`002Oooool00ol0o`3oooooooooo`0?ooooo`03o`3o0?oooooooooo023ooooo
00?o0?l0ooooooooool08_ooool5o`0000Gooooo00?o0000ooooooooool0?oooool00ol0o`3ooooo
ooooo`0Hooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool00oooool01Ol0o`3ooooo
oooooooooooo0?l000kooooo000?ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool0
1_ooool00ol0o`3oooooooooo`0?ooooo`03o`3o0?oooooooooo027ooooo00?o0?l0ooooooooool0
8Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0?_ooool00ol0o`3o
ooooooooo`0Hooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooooooool00oooool01Ol0o`3o
oooooooooooooooo0?l000kooooo000@ooooo`05o`3o0?ooooooooooooooool0o`002Oooool00ol0
o`3oooooooooo`0?ooooo`03o`3o0?oooooooooo027ooooo00?o0?l0ooooooooool08Oooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo03gooooo00?o0?l0ooooooooool06Oooool00ol0
o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo00?ooooo00Go0?l0ooooooooooooooooo`3o000?
ooooo`004?ooool01Ol0o`3ooooooooooooooooo0?l000Wooooo00?o0?l0ooooooooool04?ooool0
0ol0o`3oooooooooo`0Qooooo`03o`3o0?oooooooooo027ooooo00?oV9RHob4Q8Oo^k^h01Oooool3
o`0003_ooooo0_l0o`0Kooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooooooool00oooool0
1Ol0o`3ooooooooooooooooo0?l000oooooo000Aooooo`05o`3o0?ooooooooooooooool0o`002Ooo
ool00ol0o`3oooooooooo`0?ooooo`03o`3o0?oooooooooo02;ooooo00?o0?l0ooooooooool08Ooo
ool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo03[ooooo00?o0?l0ooooooooool06ooo
ool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo00Cooooo00Co0?l0oooooooooooo0?l0
4?ooool0017ooooo00Go0?l0ooooooooooooooooo`3o000:ooooo`03o`3o0?oooooooooo00oooooo
00?o0?l0ooooooooool08_ooool00ol0o`3oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0>Oooool00ol0o`3oooooooooo`0Kooooo`03o`3o0?oooooooooo00_ooooo
00?o0?l0ooooooooool00oooool01Ol0o`3ooooooooooooooooo0?l0013ooooo000Aooooo`03o`3o
0?oooooooooo00;ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0@ooooo`03o`3o
0?oooooooooo02;ooooo0_l0o`0Mooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003o
ooooooooo`0hooooo`03o`3o0?oooooooooo01_ooooo00?o0?l0ooooooooool02oooool00ol0o`3o
ooooooooo`04ooooo`04o`3o0?ooooooooooo`3o017ooooo000Booooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0?ooooo`03o`3o0?oooooooooo02Co
oooo00?o0?l0ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000oooo
ooooool0=oooool00ol0o`3oooooooooo`0Looooo`03o`3o0?oooooooooo00_ooooo00?o0?l0oooo
ooooool00oooool01Ol0o`3ooooooooooooooooo0?l0017ooooo000Booooo`03o`3o0?oooooooooo
00;ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo
02Cooooo0_l0o`0Tooooo`03o`000?oooooooooo03Gooooo0_l0o`0Nooooo`03o`3o0?oooooooooo
00_ooooo00?o0?l0ooooooooool01?ooool01?l0o`3oooooooooool0o`0Booooo`004oooool00ol0
o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool03oooool00ol0
o`3oooooooooo`0Vooooo`03o`3o0?oooooooooo027ooooo00?o0000ooooooooool0=?ooool00ol0
o`3oooooooooo`0Mooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooooooool01?ooool01Ol0
o`3ooooooooooooooooo0?l001;ooooo000Cooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0oooo
ooooool01oooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo02Kooooo0_l0o`0Qoooo
o`03o`000?oooooooooo03;ooooo0_l0o`0Pooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0oooo
ooooool01?ooool01Ol0o`3ooooooooooooooooo0?l001;ooooo000Dooooo`03o`3o0?oooooooooo
00;ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo
02Oooooo00?o0?l0ooooooooool07_ooool00ol0003oooooooooo`0aooooo`03o`3o0?oooooooooo
01oooooo00?o0?l0ooooooooool02oooool00ol0o`3oooooooooo`04ooooo`05o`3o0?oooooooooo
ooooool0o`004oooool001Cooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`07oooo
o`03o`3o0?oooooooooo00oooooo00?o0?l0ooooooooool0:?ooool2o`3o01kooooo00?o0000oooo
ooooool0<?ooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0oooo
ooooool01Oooool01Ol0o`3ooooooooooooooooo0?l001?ooooo000Eooooo`03o`3o0?oooooooooo
00;ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo
02Wooooo00?o0?l0ooooooooool06oooool00ol0003oooooooooo`0^ooooo`;o0?l08_ooool00ol0
o`3oooooooooo`0;ooooo`03o`3o0?oooooooooo00Cooooo00Go0?l0ooooooooooooooooo`3o000D
ooooo`005_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0oooo
ooooool04?ooool00ol0o`3oooooooooo`0Yooooo`;o0?l06oooool00ol0003oooooooooo`0/oooo
o`;o0?l08oooool00ol0o`3oooooooooo`0;ooooo`03o`3o0?oooooooooo00Gooooo00Go0?l0oooo
ooooooooooooo`3o000Dooooo`005_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo
00Sooooo00?o0?l0ooooooooool04?ooool00ol0o`3oooooooooo`0Zooooo`?o0?l06?ooool00ol0
003oooooooooo`0[ooooo`03o`3o0?oooooooooo02;ooooo00?o0?l0ooooooooool02oooool00ol0
o`3oooooooooo`05ooooo`05o`3o0?ooooooooooooooool0o`005Oooool001Oooooo00?o0?l0oooo
ooooool00_ooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo017ooooo00?o0?l0oooo
ooooool0;?ooool2o`3o01Kooooo0_l0000Zooooo`;o0?l09?ooool00ol0o`3oooooooooo`0<oooo
o`03o`3o0?oooooooooo00Gooooo00Co0?l0oooooooooooo0?l05_ooool001Oooooo00?o0?l0oooo
ooooool00oooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo017ooooo00?o0?l0oooo
ooooool0;Oooool2o`3o01Cooooo00?o0000ooooooooool09oooool2o`3o02Gooooo00?o0?l0oooo
ooooool03?ooool00ol0o`3oooooooooo`05ooooo`04o`3o0?ooooooooooo`3o01Oooooo000Hoooo
o`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0Boooo
o`03o`3o0?oooooooooo02kooooo0ol0o`0Aooooo`03o`000?oooooooooo02Cooooo0ol0o`0Voooo
o`03o`3o0?oooooooooo00cooooo00?o0?l0ooooooooool01_ooool01?l0o`3oooooooooool0o`0G
ooooo`006Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0oooo
ooooool04_ooool00ol0o`3oooooooooo`0`ooooo`;o0?l03oooool00ol0003oooooooooo`0Roooo
o`;o0?l0:?ooool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo00Gooooo00Co0?l0oooo
oooooooo0?l06?ooool001Wooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`07oooo
o`03o`3o0?oooooooooo01;ooooo00?o0?l0ooooooooool0<Oooool3o`3o00cooooo00?o0000oooo
ooooool07oooool3o`3o02Wooooo00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`05oooo
o`04o`3o0?ooooooooooo`3o01Wooooo000Jooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0oooo
ooooool01_ooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo03?ooooo0ol0o`09oooo
o`03o`000?oooooooooo01cooooo0ol0o`0[ooooo`03o`3o0?oooooooooo00gooooo00?o0?l0oooo
ooooool01Oooool01Ol0o`3ooooooooooooooooo0?l001Wooooo000Jooooo`03o`3o0?oooooooooo
00Cooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo
03Gooooo1?l0o`05ooooo`03o`000?oooooooooo01Sooooo1?l0o`0]ooooo`03o`3o0?oooooooooo
00gooooo00?o0?l0ooooooooool01_ooool01?l0o`3oooooooooool0o`0Jooooo`006oooool00ol0
o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool04oooool00ol0
o`3oooooooooo`0hooooo`Oo0?l04_ooool7o`3o033ooooo00?o0?l0ooooooooool03_ooool00ol0
o`3oooooooooo`05ooooo`04o`3o0?ooooooooooo`3o01_ooooo000Looooo`03o`3o0?oooooooooo
00?ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo
03cooooo00?o0000ooooool0o`004Ol0o`0fooooo`03o`3o0?oooooooooo00kooooo00?o0?l0oooo
ooooool01Oooool01?l0o`3oooooooooool0o`0Looooo`007Oooool00ol0o`3oooooooooo`03oooo
o`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool04oooool2o`3o03cooooo00?o0000oooo
ooooool0A_ooool00ol0o`3oooooooooo`0>ooooo`03o`3o0?oooooooooo00Kooooo00Co0?l0oooo
oooooooo0?l07?ooool001kooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`08oooo
o`03o`3o0?oooooooooo01Cooooo00?o0?l0ooooooooool0>Oooool00ol0003oooooooooo`15oooo
o`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool01_ooool01?l0o`3oooooooooool0o`0M
ooooo`007oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0oooo
ooooool05?ooool2o`3o03Wooooo00?o0000ooooooooool0@oooool2o`3o013ooooo00?o0?l0oooo
ooooool01_ooool01?l0o`3oooooooooool0o`0Nooooo`007oooool00ol0o`3oooooooooo`03oooo
o`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0foooo
o`03o`000?oooooooooo04;ooooo00?o0?l0ooooooooool03oooool00ol0o`3oooooooooo`06oooo
o`05o`3o0?ooooooooooooooool0o`007_ooool0023ooooo00?o0?l0ooooooooool00oooool00ol0
o`3oooooooooo`08ooooo`;o0?l05_ooool00ol0o`3oooooooooo`0eooooo`;o0000@Oooool2o`3o
017ooooo00?o0?l0ooooooooool01oooool01?l0o`3oooooooooool0o`0Oooooo`008Oooool00ol0
o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool05?ooool2o`3o
03Gooooo00?o0000ooooooooool0?oooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo
00Oooooo00Co0?l0oooooooooooo0?l08?ooool002;ooooo00?o0?l0ooooooooool00_ooool00ol0
o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool0<_ooool00ol0
003oooooooooo`0nooooo`03o`3o0?oooooooooo013ooooo00?o0?l0ooooooooool01oooool01?l0
o`3oooooooooool0o`0Qooooo`008oooool2o`3o00?ooooo00?o0?l0ooooooooool02_ooool00ol0
o`3oooooooooo`0Eooooo`;o0?l0<_ooool00ol0003oooooooooo`0looooo`;o0?l04_ooool00ol0
o`3oooooooooo`07ooooo`05o`3o0?ooooooooooooooool0o`008Oooool002Gooooo00Co0?l0oooo
oooooooooooo0_l0o`0;ooooo`03o`3o0?oooooooooo01Kooooo00?o0?l0ooooooooool0;oooool0
0ol0003oooooooooo`0kooooo`03o`3o0?oooooooooo013ooooo0_l0o`09ooooo`05o`3o0?oooooo
ooooooooool0o`008_ooool002Kooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`09
ooooo`03o`3o0?oooooooooo01Kooooo00?o0?l0ooooooooool0;_ooool00ol0003oooooooooo`0i
ooooo`;o0?l04_ooool00ol0o`3oooooooooo`08ooooo`05o`3o0?ooooooooooooooool0o`008ooo
ool002Oooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooo
oooo01Kooooo0_l0o`0^ooooo`03o`000?oooooooooo03Oooooo0_l0o`0Cooooo`03o`3o0?oooooo
oooo00Sooooo00Go0?l0ooooooooooooooooo`3o000Tooooo`00:?ooool00ol0o`3oooooooooo`02
ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool05oooool2o`3o02cooooo00?o0000
ooooooooool0=Oooool2o`3o01?ooooo0_l0o`0:ooooo`05o`3o0?ooooooooooooooool0o`009Ooo
ool002Wooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooo
oooo01Sooooo0_l0o`0Zooooo`03o`000?oooooooooo03Cooooo00?o0?l0ooooooooool04_ooool0
0ol0o`3oooooooooo`08ooooo`;o0?l00oooool00ol0o`3oooooooooo`0Tooooo`00:_ooool00ol0
o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Wooooo0_l0o`0Jooooo`03o`3o0?oooooooooo
02Oooooo00?o0000ooooooooool0<_ooool2o`3o01Cooooo00?o0?l0ooooooooool02?ooool00ol0
o`3oooooooooo`02ooooo`03o`3o0?oooooooooo02Gooooo000[ooooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool02_ooool00ol0o`3oooooooooo`0Hooooo`;o0?l09oooool00ol0003o
ooooooooo`0`ooooo`;o0?l05Oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool09_ooool002cooooo00?o0?l0ooooooooool00_ooool00ol0o`3ooooo
ooooo`0:ooooo`03o`3o0?oooooooooo01Wooooo0_l0o`0Uooooo`03o`000?oooooooooo02kooooo
0_l0o`0Eooooo`;o0?l02Oooool2o`3o00Cooooo00?o0?l0ooooooooool09oooool002gooooo00?o
0?l0ooooooooool00_ooool2o`3o00_ooooo0_l0o`0Kooooo`?o0?l08_ooool00ol0003ooooooooo
o`0]ooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0ooooooooool02?ooool00ol0o`3ooooooooo
o`03ooooo`03o`3o0?oooooooooo02Sooooo000^ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0
ooooooooool02_ooool00ol0o`3oooooooooo`0Kooooo`?o0?l07oooool2o`0002cooooo0_l0o`0F
ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`0Y
ooooo`00;oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0oooo
ooooool07Oooool3o`3o01cooooo00?o0000ooooooooool0:?ooool3o`3o01Kooooo0_l0o`09oooo
o`;o0?l01Oooool00ol0o`3oooooooooo`0Zooooo`00<?ooool00ol0o`3oooooooooo`03ooooo`03
o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool07oooool2o`3o01[ooooo00?o0000oooooooo
ool09?ooool4o`3o01Sooooo00?o0?l0ooooooooool02?ooool00ol0o`3oooooooooo`03ooooo`;o
0?l0;Oooool0037ooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`0:ooooo`;o0?l0
8Oooool3o`3o01Oooooo00?o0000ooooooooool08?ooool4o`3o01_ooooo00?o0?l0ooooooooool0
2?ooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo02gooooo000booooo`03o`3o0?oo
oooooooo00?ooooo00?o0?l0ooooooooool02oooool00ol0o`3oooooooooo`0Qooooo`Co0?l04ooo
ool00ol0003oooooooooo`0Mooooo`?o0?l07_ooool00ol0o`3oooooooooo`07ooooo`;o0?l01Ooo
ool00ol0o`3oooooooooo`0^ooooo`00<oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooo
oooo00_ooooo0_l0o`0Uooooo`Go0?l03_ooool00ol0003oooooooooo`0Jooooo`?o0?l07oooool2
o`3o00Wooooo00?o0?l0ooooooooool01?ooool00ol0o`3oooooooooo`0_ooooo`00=?ooool00ol0
o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00cooooo0_l0o`0Xooooo`Go0?l02Oooool00ol0
003oooooooooo`0Gooooo`?o0?l08?ooool2o`3o00[ooooo00?o0?l0ooooooooool00oooool2o`3o
03;ooooo000eooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool03Oooool00ol0o`3o
ooooooooo`0Zooooo`Go0?l01?ooool00ol0003oooooooooo`0?ooooo`So0?l08Oooool2o`3o00[o
oooo0_l0o`05ooooo`03o`3o0?oooooooooo03;ooooo000fooooo`;o0?l01?ooool2o`3o00kooooo
0_l0o`0_oooooaKo0?l0:?ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00Cooooo
00?o0?l0ooooooooool0<oooool003Sooooo00?o0?l0ooooooooool00oooool2o`3o00kooooo00?o
0?l0ooooooooool0<?ooool00ol0003oooooooooo`0eooooo`;o0?l02oooool00ol0o`3ooooooooo
o`04ooooo`03o`3o0?oooooooooo03Cooooo000iooooo`;o0?l01Oooool00ol0o`3oooooooooo`0<
ooooo`;o0?l0:?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0<oooool2
o`3o00_ooooo0_l0o`06ooooo`03o`3o0?oooooooooo03Gooooo000kooooo`03o`3o0?oooooooooo
00?ooooo0_l0o`0>ooooo`?o0?l09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
037ooooo0_l0o`0;ooooo`;o0?l01_ooool2o`3o03Sooooo000looooo`;o0?l01Oooool2o`3o00oo
oooo0ol0o`0Pooooo`Go00001Oooool00ol0003oooooooooo`0_ooooo`;o0?l03?ooool00ol0o`3o
ooooooooo`04ooooo`;o0?l0>_ooool003kooooo00?o0?l0ooooooooool01?ooool00ol0o`3ooooo
ooooo`0?ooooo`?o0?l07Oooool01?m4A4CogMgMooooool00006ooooo`?o0000;?ooool3o`3o00co
oooo0_l0o`06ooooo`03o`3o0?oooooooooo03[ooooo000oooooo`;o0?l01Oooool2o`3o01;ooooo
0_l0o`0Kooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0:_ooool2o`3o00go
oooo0_l0o`06ooooo`;o0?l0?Oooool0047ooooo00?o0?l0ooooooooool01?ooool2o`3o01;ooooo
0ol0o`0Iooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0:?ooool2o`3o00kooooo
00?o0?l0ooooooooool01?ooool2o`3o03oooooo0012ooooo`;o0?l01_ooool2o`3o01?ooooo0_l0
o`0Gooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool09Oooool3o`3o00kooooo0_l0
o`06ooooo`03o`3o0?oooooooooo03oooooo0014ooooo`;o0?l01_ooool00ol0o`3oooooooooo`0B
ooooo`?o0?l05Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo02;ooooo0ol0o`0?
ooooo`;o0?l01_ooool2o`3o04;ooooo0016ooooo`;o0?l01Oooool2o`3o01Gooooo1?l0o`0Ioooo
o`03o`000?oooooooooo01oooooo0ol0o`0@ooooo`;o0?l01_ooool2o`3o04Cooooo0018ooooo`;o
0?l01Oooool2o`3o01Oooooo1Ol0o`0Dooooo`03o`000?oooooooooo01[ooooo1Ol0o`0Aooooo`;o
0?l01_ooool2o`3o04Kooooo001:ooooo`;o0?l01Oooool2o`3o01[ooooo0ol0o`0Aooooo`03o`00
0?oooooooooo01Cooooo1_l0o`0Dooooo`;o0?l01_ooool2o`3o04Sooooo001<ooooo`;o0?l01Ooo
ool3o`3o01[ooooo1?l0o`0=ooooo`03o`000?oooooooooo013ooooo1?l0o`0Hooooo`;o0?l01_oo
ool2o`3o04[ooooo001>ooooo`;o0?l01_ooool3o`3o01_ooooo4Ol0o`02ooooo`go0?l06_ooool2
o`3o00Kooooo0_l0o`1<ooooo`00D?ooool2o`3o00Oooooo0ol0o`0Uooooo`04o`000?oooooooooo
ooooo`;o0?l09?ooool3o`3o00Gooooo0ol0o`1>ooooo`00D_ooool2o`3o00Sooooo1?l0o`0Qoooo
o`03o`000?oooooooooo02;ooooo1Ol0o`06ooooo`;o0?l0DOooool005Cooooo0_l0o`0:ooooo`Co
0?l07Oooool00ol0003oooooooooo`0Nooooo`Co0?l02Oooool2o`3o05?ooooo001Fooooo`;o0?l0
3?ooool3o`3o01[ooooo0_l0000Looooo`?o0?l02_ooool3o`3o05Gooooo001Hooooo`?o0?l03?oo
ool4o`3o01Kooooo00?o0000ooooooooool06?ooool3o`3o00_ooooo0_l0o`1Hooooo`00Foooool2
o`3o00kooooo1_l0o`0@ooooo`03o`000?oooooooooo01?ooooo1Ol0o`0;ooooo`?o0?l0F_ooool0
05gooooo1Ol0o`0?ooooo`Go0?l02oooool00ol0003oooooooooo`08ooooo`_o0?l03Oooool3o`3o
05gooooo001Rooooo`Go0?l03ooooolFo`3o01Gooooo0ol0o`1Pooooo`00Ioooool3o`3o01Oooooo
00?o0000ooooooooool05oooool6o`3o06?ooooo001Zooooo`Go0?l04_ooool00ol0003ooooooooo
o`0@ooooo`Oo0?l0JOooool006oooooo1_l0o`0<ooooo`03o`000?oooooooooo00Wooooo1ol0o`1`
ooooo`00MOoooolHo`3o07Oooooo0021ooooo`03o`000?oooooooooo083ooooo0021ooooo`03o`00
0?oooooooooo083ooooo0021ooooo`03o`000?oooooooooo083ooooo0021ooooo`03o`000?oooooo
oooo083ooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 285.188}, {355.188, 147.875}} -> {-8.75649, \
2.13297, 0.0482368, 0.0482368}}]
}, Open  ]],

Cell[TextData[{
  "Overlapping phase plane trajectories reflect the fact that solutions are \
no longer uniquely determined by position and velocity. Time must also be \
taken into account to determine the future of the system.  Geometrically this \
is accomplished by pulling the trajectory to 3 dimensional ",
  StyleBox["y,v,t",
    FontSlant->"Italic"],
  " space where time is used as  the third coordinate. This is called state \
space and the parametrized curve is called a state space trajectory. "
}], "Text"],

Cell[TextData[StyleBox["State space trajectories: The ParametricPlot3D \
function ",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
The state space trajectory for a second order differential equation \
is the parametrized curve \
\>", "Text"],

Cell[TextData[{
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), ",
  StyleBox["v",
    FontSlant->"Italic"],
  " = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = ",
  StyleBox["t",
    FontSlant->"Italic"],
  " "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "plotted in ",
  StyleBox["y,v,t",
    FontSlant->"Italic"],
  " space. Three dimensional trajectories are plotted in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " using the ParametricPlot3D procedure. The syntax for a 3 dimensional \
curve is essentially the same as for the 3 dimensional curves we have been \
plotting with one exception:"
}], "Text"],

Cell[TextData[StyleBox["The color specification for the curve must be \
included as the fourth entry in the coordinate list.", "Note"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
The last phase plane trajectory corresponds to the initial state \
\
\>", "Text"],

Cell["y0 = 3, v0 = -3, t0 = 0 .", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["The state space trajectory is plotted below. ", "Text"],

Cell["Note the application of Evaluate to the coordinate function.", "Text"],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot3D[ 
       Evaluate[{phi2[3,-3,t],D[phi2[3,-3,t],t],t,RGBColor[0,1,0]}], 
       {t,0,40}, AspectRatio->5/4 ]\
\>", "Input",
  CellLabel->"In[20]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.974091 2.9607 -0.0610294 1.31103 [
[.36425 1.26624 -6.05855 0 ]
[.36425 1.26624 5.94145 9 ]
[.52009 1.24875 -11.9886 0 ]
[.52009 1.24875 12.0114 9 ]
[.67817 1.23101 -2.96437 0 ]
[.67817 1.23101 3.03563 9 ]
[.83855 1.21301 -8.79279 0 ]
[.83855 1.21301 9.20721 9 ]
[.05857 1.15398 -24 -3.2947 ]
[.05857 1.15398 0 5.7053 ]
[.15048 1.18818 -6 -3.31601 ]
[.15048 1.18818 0 5.68399 ]
[.23996 1.22147 -18 -3.33658 ]
[.23996 1.22147 0 5.66342 ]
[.32708 1.25389 -6 -3.35645 ]
[.32708 1.25389 0 5.64355 ]
[.04592 .11924 -6 -2.80265 ]
[.04592 .11924 0 6.19735 ]
[.02848 .33256 -12 -2.90264 ]
[.02848 .33256 0 6.09736 ]
[.00959 .56382 -12 -3.01123 ]
[.00959 .56382 0 5.98877 ]
[-0.01095 .81538 -12 -3.12956 ]
[-0.01095 .81538 0 5.87044 ]
[-0.03335 1.09004 -12 -3.25903 ]
[-0.03335 1.09004 0 5.74097 ]
[ 0 0 0 0 ]
[ 1 1.25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.36333 1.25 m
1 1.17836 L
s
.36462 1.24986 m
.3648 1.24166 L
s
[(-5)] .36425 1.26624 .00976 -1 Mshowa
.52005 1.23237 m
.52004 1.22417 L
s
[(-2.5)] .52009 1.24875 -0.00095 -1 Mshowa
.67773 1.21462 m
.67751 1.20643 L
s
[(0)] .67817 1.23101 -0.01188 -1 Mshowa
.8377 1.19662 m
.83727 1.18843 L
s
[(2.5)] .83855 1.21301 -0.02302 -1 Mshowa
.125 Mabswid
.39553 1.24638 m
.39561 1.24146 L
s
.42652 1.24289 m
.42659 1.23797 L
s
.45761 1.23939 m
.45765 1.23448 L
s
.48879 1.23588 m
.4888 1.23097 L
s
.55141 1.22884 m
.55137 1.22392 L
s
.58285 1.2253 m
.58279 1.22038 L
s
.61439 1.22175 m
.6143 1.21684 L
s
.64601 1.21819 m
.64591 1.21328 L
s
.70954 1.21105 m
.70938 1.20613 L
s
.74144 1.20746 m
.74126 1.20254 L
s
.77343 1.20386 m
.77323 1.19894 L
s
.80552 1.20025 m
.80529 1.19533 L
s
.86997 1.19299 m
.86969 1.18808 L
s
.90234 1.18935 m
.90203 1.18444 L
s
.9348 1.1857 m
.93447 1.18079 L
s
.96736 1.18204 m
.967 1.17712 L
s
.25 Mabswid
0 1.11459 m
.36333 1.25 L
s
.09431 1.14974 m
.11219 1.14762 L
s
[(-2.5)] .05857 1.15398 1 -0.26784 Mshowa
.18627 1.18401 m
.20417 1.18193 L
s
[(0)] .15048 1.18818 1 -0.26311 Mshowa
.27579 1.21737 m
.2937 1.21532 L
s
[(2.5)] .23996 1.22147 1 -0.25854 Mshowa
.36295 1.24986 m
.38089 1.24784 L
s
[(5)] .32708 1.25389 1 -0.25412 Mshowa
.125 Mabswid
.01892 1.12164 m
.02963 1.12035 L
s
.03792 1.12872 m
.04864 1.12744 L
s
.05682 1.13577 m
.06754 1.13449 L
s
.07562 1.14277 m
.08634 1.1415 L
s
.11291 1.15667 m
.12363 1.1554 L
s
.1314 1.16356 m
.14213 1.1623 L
s
.14979 1.17041 m
.16052 1.16916 L
s
.16808 1.17723 m
.17881 1.17598 L
s
.20437 1.19076 m
.21511 1.18951 L
s
.22237 1.19746 m
.23311 1.19622 L
s
.24027 1.20413 m
.25101 1.2029 L
s
.25807 1.21077 m
.26882 1.20954 L
s
.2934 1.22394 m
.30416 1.22271 L
s
.31093 1.23047 m
.32168 1.22925 L
s
.32836 1.23697 m
.33912 1.23575 L
s
.3457 1.24343 m
.35646 1.24221 L
s
.25 Mabswid
.08219 .093 m
0 1.11459 L
s
.08054 .11345 m
.09786 .11056 L
s
[(0)] .04592 .11924 1 -0.37719 Mshowa
.06336 .32707 m
.0808 .32433 L
s
[(10)] .02848 .33256 1 -0.35497 Mshowa
.04473 .55867 m
.06229 .5561 L
s
[(20)] .00959 .56382 1 -0.33084 Mshowa
.02446 .81061 m
.04216 .80822 L
s
[(30)] -0.01095 .81538 1 -0.30454 Mshowa
.00233 1.08569 m
.02016 1.08351 L
s
[(40)] -0.03335 1.09004 1 -0.27577 Mshowa
.125 Mabswid
.07721 .15484 m
.08762 .15312 L
s
.07383 .19688 m
.08425 .19518 L
s
.0704 .23959 m
.08083 .23791 L
s
.06691 .28298 m
.07735 .28132 L
s
.05975 .37189 m
.07023 .37026 L
s
.05609 .41743 m
.06658 .41583 L
s
.05236 .46373 m
.06287 .46215 L
s
.04858 .5108 m
.0591 .50924 L
s
.04081 .60735 m
.05137 .60582 L
s
.03683 .65686 m
.0474 .65536 L
s
.03277 .70722 m
.04336 .70574 L
s
.02865 .75846 m
.03926 .75701 L
s
.02019 .86367 m
.03082 .86226 L
s
.01584 .91769 m
.0265 .9163 L
s
.01142 .97268 m
.02209 .97132 L
s
.00691 1.02867 m
.0176 1.02733 L
s
.25 Mabswid
.08219 .093 m
0 1.11459 L
s
0 1.11459 m
.36333 1.25 L
s
.36333 1.25 m
.38551 .25271 L
s
.38551 .25271 m
.08219 .093 L
s
.63588 0 m
.92151 .16788 L
s
.92151 .16788 m
1 1.17836 L
s
1 1.17836 m
.66178 1.03467 L
s
.66178 1.03467 m
.63588 0 L
s
.08219 .093 m
0 1.11459 L
s
0 1.11459 m
.66178 1.03467 L
s
.66178 1.03467 m
.63588 0 L
s
.63588 0 m
.08219 .093 L
s
.38551 .25271 m
.92151 .16788 L
s
.92151 .16788 m
1 1.17836 L
s
1 1.17836 m
.36333 1.25 L
s
.36333 1.25 m
.38551 .25271 L
s
0 0 m
1 0 L
1 1.25 L
0 1.25 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.41412 .25211 m
.46004 .26451 L
s
.37561 .2325 m
.41412 .25211 L
s
.35351 .20454 m
.37561 .2325 L
s
.46004 .26451 m
.50718 .27182 L
s
.3584 .16924 m
.35351 .20454 L
s
.50718 .27182 m
.55152 .27607 L
s
.39903 .13069 m
.3584 .16924 L
s
.55152 .27607 m
.58964 .27852 L
s
.47726 .09602 m
.39903 .13069 L
s
.58964 .27852 m
.61725 .27977 L
s
.58326 .07385 m
.47726 .09602 L
s
.61725 .27977 m
.62891 .28014 L
s
.62891 .28014 m
.61919 .28041 L
s
.44326 .43717 m
.53558 .45317 L
s
.37344 .41119 m
.44326 .43717 L
s
.53558 .45317 m
.62787 .45702 L
s
.61919 .28041 m
.58525 .28224 L
s
.34115 .37962 m
.37344 .41119 L
s
.62787 .45702 m
.6952 .44962 L
s
.35076 .34777 m
.34115 .37962 L
s
.58525 .28224 m
.52948 .28803 L
s
.39568 .32035 m
.35076 .34777 L
s
.52948 .28803 m
.46117 .30025 L
s
.46117 .30025 m
.39568 .32035 L
s
.6952 .44962 m
.71646 .43516 L
s
.41669 .60275 m
.54822 .61993 L
s
.31316 .56968 m
.41669 .60275 L
s
.54822 .61993 m
.67339 .61948 L
s
.71646 .43516 m
.68099 .42045 L
s
.26427 .52643 m
.31316 .56968 L
s
.67339 .61948 m
.75786 .60421 L
s
.28223 .48146 m
.26427 .52643 L
s
.68099 .42045 m
.59365 .41334 L
s
.75786 .60421 m
.77555 .58111 L
s
.36072 .44378 m
.28223 .48146 L
s
.43692 .77081 m
.59322 .78368 L
s
.30184 .73854 m
.43692 .77081 L
s
.59365 .41334 m
.4759 .42026 L
s
.59322 .78368 m
.72946 .77704 L
s
.4759 .42026 m
.36072 .44378 L
s
.22386 .69183 m
.30184 .73854 L
s
.77555 .58111 m
.71691 .56005 L
s
.72946 .77704 m
.80779 .75574 L
s
.22484 .63968 m
.22386 .69183 L
s
.71691 .56005 m
.59456 .55124 L
s
.30537 .59306 m
.22484 .63968 L
s
.48381 .94183 m
.65244 .94842 L
s
.32316 .91432 m
.48381 .94183 L
s
.80779 .75574 m
.80314 .72892 L
s
.21304 .86923 m
.32316 .91432 L
s
.65244 .94842 m
.78424 .93592 L
s
.4423 .56183 m
.30537 .59306 L
s
.59456 .55124 m
.4423 .56183 L
s
.18441 .81463 m
.21304 .86923 L
s
.78424 .93592 m
.84168 .91108 L
s
.80314 .72892 m
.71216 .70809 L
s
.24745 .76176 m
.18441 .81463 L
s
.54559 1.11715 m
.71583 1.11735 L
s
.36663 1.09611 m
.54559 1.11715 L
s
.226 1.05563 m
.36663 1.09611 L
s
.71216 .70809 m
.55796 .70387 L
s
.84168 .91108 m
.80458 .8845 L
s
.38561 .72218 m
.24745 .76176 L
s
.16241 1.00209 m
.226 1.05563 L
s
.71583 1.11735 m
.83156 1.1004 L
s
.55796 .70387 m
.38561 .72218 L
s
.19612 .94591 m
.16241 1.00209 L
s
.83156 1.1004 m
.85838 1.07462 L
s
.80458 .8845 m
.67897 .86822 L
s
.32036 .89917 m
.19612 .94591 L
s
.67897 .86822 m
.49951 .87192 L
s
.85838 1.07462 m
.78386 1.05143 L
s
.49951 .87192 m
.32036 .89917 L
s
.78386 1.05143 m
.62546 1.04247 L
s
0 g
.25 Mabswid
.63588 0 m
.92151 .16788 L
s
.92151 .16788 m
1 1.17836 L
s
1 1.17836 m
.66178 1.03467 L
s
.66178 1.03467 m
.63588 0 L
s
.08219 .093 m
0 1.11459 L
s
0 1.11459 m
.66178 1.03467 L
s
.66178 1.03467 m
.63588 0 L
s
.63588 0 m
.08219 .093 L
s
0 1.11459 m
.36333 1.25 L
s
.09431 1.14974 m
.11219 1.14762 L
s
[(-2.5)] .05857 1.15398 1 -0.26784 Mshowa
.18627 1.18401 m
.20417 1.18193 L
s
[(0)] .15048 1.18818 1 -0.26311 Mshowa
.27579 1.21737 m
.2937 1.21532 L
s
[(2.5)] .23996 1.22147 1 -0.25854 Mshowa
.36295 1.24986 m
.38089 1.24784 L
s
[(5)] .32708 1.25389 1 -0.25412 Mshowa
.125 Mabswid
.01892 1.12164 m
.02963 1.12035 L
s
.03792 1.12872 m
.04864 1.12744 L
s
.05682 1.13577 m
.06754 1.13449 L
s
.07562 1.14277 m
.08634 1.1415 L
s
.11291 1.15667 m
.12363 1.1554 L
s
.1314 1.16356 m
.14213 1.1623 L
s
.14979 1.17041 m
.16052 1.16916 L
s
.16808 1.17723 m
.17881 1.17598 L
s
.20437 1.19076 m
.21511 1.18951 L
s
.22237 1.19746 m
.23311 1.19622 L
s
.24027 1.20413 m
.25101 1.2029 L
s
.25807 1.21077 m
.26882 1.20954 L
s
.2934 1.22394 m
.30416 1.22271 L
s
.31093 1.23047 m
.32168 1.22925 L
s
.32836 1.23697 m
.33912 1.23575 L
s
.3457 1.24343 m
.35646 1.24221 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{145.938, 182.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002f0000hb000`400?l00000o`00003o]_ooool0
0;Kooooo002fooooo`00]_ooool00;Kooooo002fooooo`00Moooool5o`0003[ooooo001aooooo`Ko
00000oooool01?l0003oooooo`000?l0000hooooo`00Joooool6o`0000Wooooo00Go0000oooooooo
ooooooooo`00000gooooo`00IOooool6o`0000oooooo00?o0000ooooooooool00_ooool2o`0003Go
oooo001Oooooo`Ko00005Oooool00ol0003oooooooooo`04ooooo`;o0000<oooool005Wooooo1_l0
000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool005?ooooo1_l0000Q
ooooo`03o`000?oooooooooo00Oooooo0_l0000`ooooo`00COooool6o`0002Oooooo00?o0000oooo
ooooool02Oooool2o`0002kooooo0018ooooo`Go0000;Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02_ooooo0012ooooo`Ko0000<_ooool00ol0003oooooooooo`0<ooooo`;o0000
:oooool003cooooo1_l0000hooooo`03o`000?oooooooooo00kooooo0_l0000Yooooo`00=_ooool6
o`0003Cooooo0ol0o`07ooooo`03o`000?oooooooooo013ooooo0_l0000Wooooo`00<?ooool6o`00
03Kooooo1?l0o`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09?ooool002[o
oooo1_l0000gooooo`Go0?l03_ooool00ol0003oooooooooo`0Cooooo`;o00009?ooool002Cooooo
1_l0000iooooo`Co0?l04oooool00ol0003oooooooooo`0Eooooo`;o00008_ooool0027ooooo0ol0
000looooo`?o0?l05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01oooooo000Q
ooooo`04o`000?oooooo0000o`0003Wooooo0_l0o`0Jooooo`03o`000?oooooooooo01Sooooo0_l0
000Oooooo`008Oooool00ol0003oooooo`000003o`0003Gooooo0_l0o`0Looooo`03o`000?oooooo
oooo01[ooooo0_l0000Mooooo`008Oooool2o`0000Cooooo0_l0000`ooooo`?o0?l07_ooool00ol0
003oooooooooo`0Looooo`;o00006oooool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo00Gooooo0_l0000/ooooo`;o0?l08Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Sooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`07ooooo`;o0000:?ooool2o`3o02?ooooo00?o0000ooooooooool07oooool2o`00
01Sooooo000Dooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`09oooo
o`;o00009Oooool00ol0o`3oooooooooo`0Sooooo`03o`000?oooooooooo027ooooo0_l0000Foooo
o`005?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool03?ooool2o`00
02;ooooo00?o0?l0ooooooooool09Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01?ooooo000Dooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0>oooo
o`;o00007oooool00ol0o`3oooooooooo`0Vooooo`03o`000?oooooooooo02?ooooo0_l0000Coooo
o`005?ooool01Ol@413ooooooooooooooooo410@00Oooooo0ol0000@ooooo`;o00007?ooool00ol0
o`3oooooooooo`0Wooooo`03o`000?oooooooooo02Gooooo0_l0000Aooooo`005?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool04_ooool2o`0001Wooooo00?o0?l0oooo
ooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo000Dooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`0Dooooo`;o00005_ooool00ol0
o`3oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo0_l0000>ooooo`008?ooool00ol0003o
ooooooooo`0Fooooo`;o00004oooool00ol0o`3oooooooooo`0Zooooo`03o`000?oooooooooo02Oo
oooo1?l0000=ooooo`008?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo
00?o0?l0ooooooooool0:_ooool00ol0003oooooooooo`0Pooooo`Oo00000oooool00ol0003ooooo
ooooo`0;ooooo`008?ooool00ol0003oooooooooo`0Iooooo`;o00004?ooool00ol0o`3ooooooooo
o`0Zooooo`03o`000?oooooooooo01Wooooo1ol0000:ooooo`03o`000?oooooooooo00_ooooo000P
ooooo`03o`000?oooooooooo01_ooooo0_l0000=ooooo`03o`3o0?oooooooooo02_ooooo00?o0000
ooooooooool04oooool6o`00017ooooo00?o0000ooooooooool02oooool0023ooooo0ol0000Moooo
o`;o00002oooool00ol0o`3oooooooooo`0[ooooo`03o`000?oooooooooo00cooooo1ol0000Goooo
o`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo01oooooo0_l00009ooooo`03
o`3o0?oooooooooo02_ooooo00?o0000ooooooooool01_ooool6o`0001kooooo00?o0000oooooooo
ool02oooool0023ooooo00?o0000ooooooooool08Oooool2o`0000Oooooo00?o0?l0ooooooooool0
:oooool00ol0003oooooo`000006o`0002Cooooo00?o0000ooooooooool02oooool0023ooooo00?o
0000ooooooooool08oooool2o`0000Kooooo00?o0?l0ooooooooool09Oooool7o`0002cooooo00?o
0000ooooooooool02_ooool001oooooo00?o0000ooooooooool09_ooool2o`0000Gooooo00?o0?l0
ooooooooool07_ooool6o`0000Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:
ooooo`007oooool00ol0003oooooooooo`0Xooooo`;o00000oooool00ol0o`3oooooooooo`0Goooo
o`Oo00002oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo000Oooooo`03
o`000?oooooooooo02[ooooo0_l00002ooooo`;o0?l04Oooool6o`0001;ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0:ooooo`007oooool3o`0002cooooo0_l00002ooooo`?o0?l0
1oooool7o`0001Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`007ooo
ool00ol0003oooooooooo`0^ooooo`;o00000oooool2o`3o00Go00007oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00[ooooo000Oooooo`03o`000?oooooooooo033ooooo0ol00002
ooooo`?o0?l08Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo000Ooooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool3o`3o01kooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0:ooooo`007oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00Sooooo1_l0o`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool02_ooool001oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0>ooooo`So0?l0
4?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo000Oooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool05_ooool;o`3o00Gooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0:ooooo`007oooool3o`00033ooooo00?o0000ooooooooool06Oooool<
o`3o0003ooooool0003ooooo02cooooo00?o0000ooooooooool02_ooool001oooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Aooooo`So0?l03Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00[ooooo000Oooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool03?ooool5o`3o01Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`09ooooo`00
7_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo1Ol0o`0Jooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool02Oooool001kooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`04ooooo`?o0?l07oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Wooooo000Nooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooooooo0ol0
o`0Rooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool001kooooo00?o0000
ooooooooool0<Oooool01?l0003o0?l0o`3o0?l0o`0Uooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool02Oooool001kooooo1?l0000`ooooo`03o`3o0?oooooooooo02Kooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`09ooooo`002oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h7ooooo`03o`000?oooooooooo02oooooo0_l0o`000ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool000gooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool0
;Oooool2o`3o00;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00Wooooo000=ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4007ooooo`03o`000?oooooooooo02cooooo00?o0?l0ooooooooool00_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool000gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
:oooool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`09ooooo`003Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`0[ooooo`03o`3o0?oooooooooo00?ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Wooooo
000=ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`00
0?oooooooooo02_ooooo00?o0?l0ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool02Oooool000gooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l0000[ooooo`03o`3o0?oooooooooo00Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo
000;ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo02_ooooo00?o0?l0ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool02?ooool001gooooo00?o0000ooooooooool0:ooo
ool00ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`08ooooo`007Oooool00ol0003oooooooooo`0/ooooo`03o`3o0?oooooo
oooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Sooooo000Mooooo`03o`000?oooooooooo02gooooo00?o0?l0ooooooooool00_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?ooool001go
oooo00?o0000ooooooooool0;_ooool01Ol0o`3ooooooooooooooooo000002Wooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`08ooooo`007Oooool00ol0003oooooooooo`0_ooooo`04
o`3o0?ooooooooooo`0002Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`08oooo
o`007Oooool3o`00033ooooo0_l0o`000ol0003oooooooooo`0Foooooa7o0?l000?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`08ooooo`007Oooool00ol0003oooooooooo`0booooo`?o0?l0
2_ooool<o`3o017ooooo00?o0000o`3o0?l0o`001Ol0o`0Wooooo`03o`000?oooooooooo00Sooooo
000Mooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooooooo0ol0o`02ooooo`Go0?l0
7Oooool00ol0003oooooooooo`05ooooo`;o0?l09Oooool00ol0003oooooooooo`08ooooo`007Ooo
ool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooooooo`Ko0?l08Oooool00ol0003ooooo
ooooo`07ooooo`03o`3o0?oooooooooo02;ooooo00?o0000ooooooooool02?ooool001gooooo00?o
0000ooooooooool0<?ooool5o`3o00Kooooo1Ol0o`0Looooo`03o`000?oooooooooo00Oooooo0_l0
o`0Sooooo`03o`000?oooooooooo00Sooooo000Mooooo`03o`000?oooooooooo02gooooo0ol0o`00
0ooooooo0000ooooo`0=ooooo`Oo0?l05Oooool00ol0003oooooooooo`06ooooo`03o`3o0?oooooo
oooo02?ooooo00?o0000ooooooooool02?ooool001gooooo00?o0000ooooooooool0:oooool2o`3o
00Cooooo00?o0000ooooooooool04oooool<o`3o00Wooooo00?o0000ooooooooool01_l0o`0Woooo
o`03o`000?oooooooooo00Oooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0o`06ooooo`03
o`000?oooooooooo01oooooo2Ol0o`000ol0003o0?l0o`3o000]ooooo`03o`000?oooooooooo00Oo
oooo000Looooo`?o00009oooool3o`3o00Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Oooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0
o`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`07ooooo`007?ooool00ol0003oooooooooo`0Sooooo`;o0?l03Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01oooool001cooooo00?o0000oooo
ooooool08_ooool00ol0o`3oooooooooo`0=ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`07ooooo`007?ooool00ol0003oooooooooo`0Rooooo`03
o`3o0?oooooooooo00gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00Oooooo000Looooo`03o`000?oooooooooo02;ooooo00?o0?l0ooooooooool0
3Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
1oooool001cooooo00?o0000ooooooooool08Oooool00ol0o`3oooooooooo`0>ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`007?ooool3
o`00027ooooo00?o0?l0ooooooooool03_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool01oooool001cooooo00?o0000ooooooooool08Oooool00ol0
o`3oooooooooo`0>ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`07ooooo`007?ooool00ol0003oooooooooo`0Pooooo`03o`3o0?oooooooooo00oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Oo
oooo000Looooo`03o`000?oooooooooo023ooooo00?o0?l0ooooooooool03oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01_ooool001_ooooo00?o
0000ooooooooool08_ooool00ol0o`3oooooooooo`0>ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`06ooooo`006oooool00ol0003oooooooooo`0S
ooooo`03o`3o0?oooooooooo00gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00Kooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0?l0oooo
ooooool03?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool01_ooool001_ooooo00?o0000ooooooooool09Oooool00ol0o`3oooooooooo`0;ooooo`03
o`000?oooooooooo01[ooooo3?l0o`02ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool01_ooool001_ooooo1?l0000Uooooo`03o`3o0?oooooooooo00[ooooo00?o0000ooooooooool0
3Oooool=o`3o00cooooo0_l0o`000ol0003o0?l0o`3o0004o`3o02[ooooo00?o0000ooooooooool0
1_ooool000Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003ooooo
ooooo`0Wooooo`03o`3o0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool8o`3o01_ooooo
00?o0000ooooooooool01?ooool7o`3o02?ooooo00?o0000ooooooooool01_ooool000Oooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003o
ooooooooo`0Xooooo`;o0?l02Oooool00ol0003oooooooooo`05o`3o02?ooooo00?o0000oooooooo
ool02oooool3o`3o023ooooo00?o0000ooooooooool01_ooool000Sooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool0:_ooool3o`3o00Go
oooo1?l0o`0Xooooo`03o`000?oooooooooo00kooooo0ol0o`0Mooooo`03o`000?oooooooooo00Ko
oooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo02gooooo1Ol0o`000ooooooo0000ooooo`0Yooooo`03o`000?oooooooooo017o
oooo0_l0o`0Kooooo`03o`000?oooooooooo00Kooooo000:ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo02Wooooo1Ol0o`02ooooo`?o
0?l000?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Booooo`03o`3o0?oooooooooo01Wo
oooo00?o0000ooooooooool01_ooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Gooooo00?o0000ooooooooool09_ooool3o`3o00[ooooo0ol0o`0Xooooo`03
o`000?oooooooooo017ooooo00?o0?l0ooooooooool06_ooool00ol0003oooooooooo`06ooooo`00
1oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07oooo
o`03o`000?oooooooooo02Cooooo0_l0o`0=ooooo`03o`000?oooooooooo00?o0?l09Oooool00ol0
003oooooooooo`0@ooooo`03o`3o0?oooooooooo01_ooooo00?o0000ooooooooool01_ooool000Oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2
o`0002?ooooo0_l0o`0?ooooo`03o`000?oooooooooo00?ooooo1_l0o`0Oooooo`03o`000?oooooo
oooo00cooooo1?l0o`0Oooooo`03o`000?oooooooooo00Gooooo000Jooooo`03o`000?oooooooooo
027ooooo0_l0o`0Aooooo`03o`000?oooooooooo00Wooooo2ol0o`0Dooooo`03o`000?oooooooooo
00Gooooo1ol0o`0Sooooo`03o`000?oooooooooo00Gooooo000Jooooo`03o`000?oooooooooo023o
oooo00?o0?l0ooooooooool04Oooool00ol0003oooooooooo`0DoooooaCo0?l000?o0000o`3o0?l0
o`001Ol0o`0Zooooo`03o`000?oooooooooo00Gooooo000Jooooo`03o`000?oooooooooo01kooooo
0_l0o`0Dooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`05ooooo`006_ooool00ol0003oooooooooo`0Looooo`;o0?l05_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01Oooool001[ooooo00?o0000
ooooooooool06oooool00ol0o`3oooooooooo`0Fooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`05ooooo`006_ooool00ol0003oooooooooo`0Koooo
o`03o`3o0?oooooooooo01Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00Gooooo000Jooooo`03o`000?oooooooooo01_ooooo00?o0?l0oooooooo
ool05_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool01Oooool001[ooooo0ol0000Kooooo`03o`3o0?oooooooooo01Kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo000Jooooo`03o`000?oo
oooooooo01_ooooo00?o0?l0ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool01Oooool001[ooooo00?o0000ooooooooool06oooool0
0ol0o`3oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`05ooooo`006_ooool00ol0003oooooooooo`0Kooooo`03o`3o0?oooooooooo
01Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00Gooooo000Jooooo`03o`000?oooooooooo01_ooooo00?o0?l0ooooooooool05_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01?ooool001[ooooo
00?o0000ooooooooool06oooool00ol0o`3oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`04ooooo`006Oooool00ol0003ooooooooo
o`0Looooo`;o0?l05oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool01?ooool001Wooooo00?o0000ooooooooool07_ooool2o`3o01Gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Cooooo000Ioooo
o`?o00008?ooool2o`3o01?ooooo00?o0000ooooooooool05OoooolDo`3o0003o`000?l0o`3o0?l0
00[o0?l09Oooool00ol0003oooooooooo`04ooooo`006Oooool00ol0003oooooooooo`0Rooooo`;o
0?l04Oooool00ol0003oooooooooo`0<ooooo`Wo0?l05?ooool00ol0003oooooooooo`0:ooooo`?o
0?l08_ooool00ol0003oooooooooo`04ooooo`006Oooool00ol0003oooooooooo`0Tooooo`03o`3o
0?oooooooooo00kooooo00?o0000ooooooooool00oooool9o`3o01gooooo00?o0000ooooooooool0
3Oooool4o`3o01kooooo00?o0000ooooooooool01?ooool001Wooooo00?o0000ooooooooool09Ooo
ool2o`3o00gooooo1ol0o`0Vooooo`03o`000?oooooooooo017ooooo0ol0o`0Kooooo`03o`000?oo
oooooooo00Cooooo000Iooooo`03o`000?oooooooooo02Oooooo0_l0o`07ooooo`Co0?l000?ooooo
o`000?ooool0:_ooool00ol0003oooooooooo`0Dooooo`;o0?l06Oooool00ol0003oooooooooo`04
ooooo`006Oooool00ol0003oooooooooo`0Yooooo`?o0?l000Coooooo`3o0?l0o`3o0?l01Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?o0?l0ooooooooool05oooool0
0ol0003oooooooooo`04ooooo`006Oooool00ol0003oooooooooo`0Yooooo`Ko0?l01_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?o0?l0ooooooooool05oooool00ol0
003oooooooooo`04ooooo`006Oooool00ol0003oooooooooo`0Uooooo`Co0?l01_ooool4o`3o00;o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`03o`3o0?oooooooooo01Ko
oooo00?o0000ooooooooool01?ooool001Wooooo0_l0000Sooooo`?o0?l03_ooool3o`3o02_ooooo
00?o0000ooooooooool05?ooool3o`3o01Wooooo00?o0000ooooooooool00oooool001Wooooo00?o
0000ooooooooool07oooool3o`3o01;ooooo00?o0000ooooool0o`000ol0o`0Wooooo`03o`000?oo
oooooooo017ooooo0ol0o`0Looooo`03o`000?oooooooooo00?ooooo000Hooooo`03o`000?oooooo
oooo01oooooo00?o0?l0ooooooooool04oooool00ol0003oooooooooo`03ooooo`?o0?l09?ooool0
0ol0003oooooooooo`0>ooooo`?o0?l07oooool00ol0003oooooooooo`03ooooo`006?ooool00ol0
003oooooooooo`0Nooooo`03o`3o0?oooooooooo01Cooooo00?o0000ooooooooool01_ooool8o`3o
01cooooo00?o0000ooooooooool02oooool3o`3o02;ooooo00?o0000ooooooooool00oooool001So
oooo00?o0000ooooooooool07Oooool00ol0o`3oooooooooo`0Eooooo`03o`000?oooooooooo00ko
oooo3Ol0o`0?ooooo`03o`000?l0o`3o0?l000_o0?l09Oooool00ol0003oooooooooo`03ooooo`00
6?ooool00ol0003oooooooooo`0Looooo`03o`3o0?oooooooooo01Kooooo00?o0000ooooooooool0
6oooool?o`3o0003o`000?oooooooooo033ooooo00?o0000ooooooooool00oooool001Sooooo00?o
0000ooooooooool06oooool00ol0o`3oooooooooo`0Gooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`03ooooo`006?ooool00ol0003oooooooooo`0J
ooooo`03o`3o0?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00?ooooo000Hooooo`03o`000?oooooooooo01Wooooo00?o0?l0oooo
ooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool00oooool000?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool4o`0001Oooooo00?o0?l0ooooooooool06_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00oooool000?ooooo00Go410@okZj
^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`0Gooooo`03o`3o0?oooooooooo01_ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00?ooooo0007ooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0?l0ooooooooool06ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00ooo
ool000Kooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool06?ooool00ol0o`3oooooooooo`0Jooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol@413o0000okZj^P03
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Hooooo`03o`3o0?oo
oooooooo01[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00;ooooo0006ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo01Wooooo00?o0?l0ooooooooool06Oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00_ooool000?ooooo00Go410@
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003ooooo
ooooo`0Jooooo`03o`3o0?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00;ooooo0003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool06oooool00ol0o`3o
ooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`02ooooo`005oooool3o`0001_ooooo00?o0?l0ooooooooool06?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00_ooool001Oooooo00?o
0000ooooooooool07?ooool2o`3o01Sooooo00?o0000ooooooooool08?ooool:o`3o0003o`000?l0
o`3o0?l000Go0?l0;?ooool00ol0003oooooooooo`02ooooo`005oooool00ol0003oooooooooo`0N
ooooo`;o0?l05_ooool00ol0003oooooooooo`0>oooooa;o0?l02_ooool00ol0003oooooooooo`05
ooooo`Oo0?l09Oooool00ol0003oooooooooo`02ooooo`005oooool00ol0003oooooooooo`0Poooo
o`?o0?l04oooool00ol0003oooooooooo`07ooooo`Oo0?l07?ooool00ol0003oooooooooo`0<oooo
o`Oo0?l07_ooool00ol0003oooooooooo`02ooooo`005oooool00ol0003oooooooooo`0Sooooo`;o
0?l04Oooool00ol0003oooooooooo`07o`3o02?ooooo00?o0000ooooooooool04oooool4o`3o01[o
oooo00?o0000ooooooooool00_ooool001Oooooo00?o0000ooooooooool09Oooool2o`3o00_ooooo
1ol0o`0Zooooo`03o`000?oooooooooo01Oooooo00?o0?l0ooooooooool05oooool00ol0003ooooo
ooooo`02ooooo`005oooool00ol0003oooooooooo`0Wooooo`;o0?l01?ooool5o`3o00Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`;o0?l05oooool00ol0003ooooooooo
o`02ooooo`005oooool00ol0003oooooooooo`0Yooooo`Co0?l02Oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo01[ooooo00?o0?l0ooooooooool05?ooool00ol0003oooooooooo`02
ooooo`005oooool00ol0003oooooooooo`0Xooooo`;o0?l00_ooool2o`3o00Sooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Iooooo`;o0?l05_ooool00ol0003oooooooooo`01oooo
o`005oooool2o`0002Kooooo0ol0o`06ooooo`Co0?l01?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo01Oooooo0_l0o`0Hooooo`03o`000?oooooooooo007ooooo000Fooooo`03o`00
0?oooooooooo02Cooooo0_l0o`0=ooooo`Oo0?l0:oooool00ol0003oooooooooo`0Dooooo`?o0?l0
6_ooool00ol0003oooooooooo`01ooooo`005_ooool00ol0003oooooooooo`0Qooooo`?o0?l04ooo
ool00ol0003oooooooooo`06o`3o02Gooooo00?o0000ooooooooool04_ooool2o`3o01gooooo00?o
0000ooooooooool00Oooool001Kooooo00?o0000ooooooooool07oooool2o`3o01Kooooo00?o0000
ooooooooool01_ooool7o`3o01kooooo00?o0000ooooooooool03?ooool6o`3o01oooooo00?o0000
ooooooooool00Oooool001Kooooo00?o0000ooooooooool07?ooool3o`3o01Sooooo00?o0000oooo
ooooool03OoooolAo`3o00gooooo00Co0000oooooooooooooooo2ol0o`0Uooooo`03o`000?oooooo
oooo007ooooo000Fooooo`03o`000?oooooooooo01_ooooo00?o0?l0ooooooooool06Oooool00ol0
003oooooooooo`0Nooooo`go0?l000Co0000o`3o0?l0o`3o0?l0<?ooool00ol0003oooooooooo`01
ooooo`005_ooool00ol0003oooooooooo`0Kooooo`03o`3o0?oooooooooo01Wooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo007ooooo000Fooooo`03
o`000?oooooooooo01[ooooo00?o0?l0ooooooooool06_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool00Oooool001Kooooo00?o0000ooooooooool0
6Oooool00ol0o`3oooooooooo`0Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`01ooooo`005_ooool3o`0001Wooooo00?o0?l0ooooooooool06ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00Ooo
ool001Kooooo00?o0000ooooooooool06?ooool00ol0o`3oooooooooo`0Looooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`01ooooo`005_ooool00ol0
003oooooooooo`0Gooooo`03o`3o0?oooooooooo01gooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo007ooooo000Fooooo`03o`000?oooooooooo01Oo
oooo00?o0?l0ooooooooool07Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;o
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo01Kooooo00?o0?l0ooooooooool0
7_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo0Ol00001ooooo`7ooooo
000Eooooo`03o`000?oooooooooo01Kooooo0_l0o`0Pooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0<_ooool1o`00007ooooo0Oooool001Gooooo00?o0000ooooooooool06?ooool0
0ol0o`3oooooooooo`0Mooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool1
o`00007ooooo0Oooool001Gooooo00?o0000ooooooooool06Oooool00ol0o`3oooooooooo`0Loooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool1o`00007ooooo0Oooool001Go
oooo00?o0000ooooooooool06_ooool00ol0o`3oooooooooo`0Kooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0<_ooool1o`00007ooooo0Oooool001Gooooo0ol0000Kooooo`;o0?l0
6oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo0Ol00001ooooo`7ooooo
000Eooooo`03o`000?oooooooooo01gooooo00?o0?l0ooooooooool06?ooool00ol0003ooooooooo
o`0Wooooo`Ko0000<oooool1o`00007ooooo0Oooool001Gooooo00?o0000ooooooooool07_ooool0
0ol0o`3oooooooooo`0Gooooo`03o`000?oooooooooo01oooooo2?l00006o`3o00?o0000<?ooool1
o`00007ooooo0Oooool001Gooooo00?o0000ooooooooool07oooool00ol0o`3oooooooooo`0Foooo
o`03o`000?oooooooooo01Oooooo2?l0000>ooooo`?o0?l00_l00008o`3o02Kooooo0Ol00001oooo
o`7ooooo000Eooooo`03o`000?oooooooooo023ooooo0ol0o`0Eooooo`03o`000?oooooooooo00ko
oooo2Ol0000Kooooo`;o00001_ooool8o`3o01kooooo0Ol00001ooooo`7ooooo000Eooooo`03o`00
0?oooooooooo02?ooooo0ol0o`0Booooo`03o`000?oooooooooo00Kooooo2?l0000Vooooo`?o0000
2oooool4o`3o01[ooooo0Ol00001ooooo`7ooooo000Eooooo`03o`000?oooooooooo02Kooooo0ol0
o`0?ooooo`Wo0000<Oooool2o`0000gooooo1?l0o`0Gooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0:Oooool4o`3o00Cooooo2?l0000kooooo`?o00003_ooool2o`3o01Gooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`0Yooooo`So00001oooool00ol0003oooooooooo`0loooo
o`;o00003Oooool00ol0o`3oooooooooo`0Cooooo`7o00000Oooool000;ooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP07ooooo`Co00008Oooool8o`0000Oooooo0ol0
o`05ooooo`03o`000?oooooooooo03kooooo0_l0000:ooooo`03o`3o0?oooooooooo01Cooooo0Ol0
0001ooooo`000oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01ooo
ool00ol0003oooooooooo`0Jooooo`So00004_ooool3o`3o0003ooooool0003ooooo04;ooooo0ol0
0006ooooo`03o`3o0?oooooooooo01Gooooo0Ol00001ooooo`001Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41001oooool00ol0003oooooooooo`0Aooooo`Wo00007Oooool7o`3o047ooooo0_l0
0003ooooo`03o`3o0?oooooooooo01Kooooo0Ol00001ooooo`0000CoA4A4omgMgOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool02Oooool8o`0002Oooooo
00?o0000ooooooooool00oooool:o`3o03Kooooo0ol0o`03o`0001Wooooo0Ol00001ooooo`0000Co
gMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooooooo2?l0000_ooooo`03o`000?oooooooooo00gooooo2Ol0o`0Tooooo`Wo0?l01_ooool2o`00
01Oooooo0Ol00001ooooo`0000CoooooogMgMoo<c<co00001?ooool01Ol@413ooooooooooooooooo
410@00Oooooo1?l0000gooooo`03o`000?oooooooooo01Kooooo9?l0o`0Aooooo`;o00005Oooool1
o`00007ooooo00001?ooooook^k^odA4A?l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Ooo
ool4o`0003Gooooo00?o0000ooooooooool0COooool3o`0001;ooooo0Ol00001ooooo`000_ooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003;ooooo00?o
0000ooooooooool0D?ooool2o`00013ooooo0Ol00001ooooo`007?ooool4o`0002oooooo00?o0000
ooooooooool0D_ooool2o`0000kooooo0Ol00001ooooo`007_ooool5o`0002cooooo00?o0000oooo
ooooool0E?ooool3o`0000_ooooo0Ol00001ooooo`001oooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool6o`0002Sooooo00?o0000ooooooooool0Eoooool2o`00
00[ooooo0Ol0000000Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`06ooooo`;o000000?oooooo`000?l000009_ooool00ol0003oooooooooo`1Ioooo
o`?o00001oooool1o`0000001Ol00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool01oooool3o`000003ooooool0003o000002?ooooo00?o0000ooooooooool0G?ooool2o`0000Go
oooo0Ol0000000Wooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`0;ooooo`?o0000
8oooool00ol0003oooooooooo`1Nooooo`;o00000oooool1o`0000002_ooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool3o`00023ooooo00?o0000ooooooooool0
H?ooool4o`0000002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo1?l0
000Mooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool00oooool6o`0000001oooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool02_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Oooooo1Ol0000Iooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
2Ol00005ooooo`001oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00009ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02_ooool4o`0001Oooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`02ooooo`So00003_ooool002Gooooo00Go410@oooooooooooooooooa0@400=ooooo`Co
00005?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo2_l0000Fooooo`00
9Oooool01Ol0003ooooooooooooooooo000000oooooo1?l0000Booooo`03o`000?oooooooooo03Wo
oooo00Co0000oooooooooooooooo2?l0000Oooooo`009Oooool01Ol0003ooooooooooooooooo0000
01;ooooo1?l0000?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00_ooool9o`00
02Oooooo000Tooooo`Go000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`Go00002oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000001ol0000`ooooo`009?ooool01_nHV9So0000odi>C_oooooo1PH6
ogMgM`Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Kooooo1Ol00009ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wo0000>?ooool002Gooooo00GoCdm?o`000?l0003o<S8bonk^kP0?ooooo`03o`000?oooooo
oooo00Sooooo1Ol00006ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool8
o`00047ooooo000Vooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool03?ooool5o`00
00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`[o0000BOooool002Oo
oooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo0ol000001?oo
oooo0000ooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?l0000/
ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0@ooooo`00:?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00GoA4A4o`000?l0003o<S8bomgM
g@04ooooo`Ko000000?oooooo`000?l000001ol0000dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03oooool002Cooooo00Go0000okZj^_ooooooV9RH
oa0@400<ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01Oooool5o`0003kooooo
00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0>ooooo`009?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo1?l0000>ooooo`03o`000?oooooooooo03Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0?ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool03oooool004Kooooo
00?oMgMgoc8b<_ooool0=Oooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo00?oMgMgofIVI_oo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<013ooooo0013ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06Oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool0
1Ol@413ooooooooooooooooo410@017ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Booooo`00@oooool00ol0003oooooooooo`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01_ooool01Ol0003ooooooooooooooooo000000gooooo
00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01;ooooo0013ooooo`03o`00
0?oooooooooo01?ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<oooo
o`Co00004Oooool004?ooooo1?l0000:ooooo`05odA4A?l0003o0000oc8b<_oMgMd03Oooool00onH
V9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Kooooo00Go410@oooooooooooooooooa0@400c
ooooo`00E?ooool00omgMgOo<S8booooo`0=ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool004Sooooo1_l00007
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<oooool005Cooooo00?oMgMgoc8b<_ooool02_ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool0@Oooool0057ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`00043ooooo
001Aooooo`03o`000?oooooooooo06;ooooo001Aooooo`03o`000?oooooooooo06;ooooo001Aoooo
o`Co0000HOooool00;Kooooo002fooooo`00]_ooool00;Kooooo002fooooo`00]_ooool00001\
\>"],
  ImageRangeCache->{{{77.875, 222.812}, {291.75, 110.375}} -> {0.0809299, \
0.673087, 0.00262928, 0.00593771}}]
}, Open  ]],

Cell[TextData[{
  "As the default, ParametricPlot3d plots 70 points and choses to display the \
curve from the viewpoint of the spherical  coordinate angles theta = 67.5, \
phi = 284.7 (degrees). (Recall that in spherical coordinates, theta is the \
angle from  the positive x axis, and phi is the angle from the positive z \
axis.) This can be determined by selecting the plot and choosing ",
  StyleBox["Input/3D ViewPoint Selector... ",
    FontWeight->"Bold"],
  ".  The view of the plot box also shows labels on the three axes."
}], "Text"],

Cell["\<\
The next entry adds the setting PlotPoints-> 100 to get a smoother \
curve. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot3D[ 
       Evaluate[{phi2[3,-3,t],D[phi2[3,-3,t],t],t,RGBColor[0,1,0]}], 
       {t,0,40}, AspectRatio->5/4, PlotPoints\[Rule]100 ]\
\>", "Input",
  CellLabel->"In[21]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.970228 2.95271 -0.0610929 1.31109 [
[.51529 1.24891 -11.9924 0 ]
[.51529 1.24891 12.0076 9 ]
[.67294 1.23116 -2.96534 0 ]
[.67294 1.23116 3.03466 9 ]
[.83289 1.21316 -8.79573 0 ]
[.83289 1.21316 9.20427 9 ]
[.99517 1.19488 -2.8978 0 ]
[.99517 1.19488 3.1022 9 ]
[-0.00099 1.1326 -12 -3.28105 ]
[-0.00099 1.1326 0 5.71895 ]
[.07383 1.16051 -12 -3.29855 ]
[.07383 1.16051 0 5.70145 ]
[.14704 1.18781 -6 -3.31555 ]
[.14704 1.18781 0 5.68445 ]
[.21869 1.21453 -6 -3.33208 ]
[.21869 1.21453 0 5.66792 ]
[.28883 1.24069 -6 -3.34815 ]
[.28883 1.24069 0 5.65185 ]
[.04597 .11989 -6 -2.80295 ]
[.04597 .11989 0 6.19705 ]
[.02854 .33325 -12 -2.90294 ]
[.02854 .33325 0 6.09706 ]
[.00966 .56454 -12 -3.01152 ]
[.00966 .56454 0 5.98848 ]
[-0.01086 .81614 -12 -3.12984 ]
[-0.01086 .81614 0 5.87016 ]
[-0.03326 1.09083 -12 -3.2593 ]
[-0.03326 1.09083 0 5.7407 ]
[ 0 0 0 0 ]
[ 1 1.25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.36038 1.25 m
1 1.17782 L
s
.51527 1.23252 m
.51526 1.22433 L
s
[(-2.5)] .51529 1.24891 -0.00063 -1 Mshowa
.67252 1.21478 m
.6723 1.20658 L
s
[(0)] .67294 1.23116 -0.01155 -1 Mshowa
.83205 1.19677 m
.83163 1.18858 L
s
[(2.5)] .83289 1.21316 -0.0227 -1 Mshowa
.99391 1.1785 m
.99329 1.17032 L
s
[(5)] .99517 1.19488 -0.03407 -1 Mshowa
.125 Mabswid
.39108 1.24654 m
.39117 1.24162 L
s
.42199 1.24305 m
.42206 1.23813 L
s
.453 1.23955 m
.45304 1.23463 L
s
.48409 1.23604 m
.4841 1.23112 L
s
.54654 1.22899 m
.54651 1.22408 L
s
.5779 1.22545 m
.57784 1.22054 L
s
.60935 1.2219 m
.60927 1.21699 L
s
.64089 1.21834 m
.64078 1.21343 L
s
.70424 1.2112 m
.70409 1.20628 L
s
.73605 1.20761 m
.73588 1.20269 L
s
.76796 1.204 m
.76776 1.19909 L
s
.79996 1.20039 m
.79973 1.19548 L
s
.86423 1.19314 m
.86396 1.18822 L
s
.89651 1.1895 m
.89621 1.18458 L
s
.92888 1.18584 m
.92856 1.18093 L
s
.96135 1.18218 m
.961 1.17727 L
s
.25 Mabswid
0 1.11538 m
.36038 1.25 L
s
.03463 1.12832 m
.05244 1.12617 L
s
[(-4)] -0.00099 1.1326 1 -0.27088 Mshowa
.10949 1.15628 m
.12732 1.15416 L
s
[(-2)] .07383 1.16051 1 -0.26699 Mshowa
.18273 1.18364 m
.20058 1.18155 L
s
[(0)] .14704 1.18781 1 -0.26321 Mshowa
.25441 1.21041 m
.27228 1.20836 L
s
[(2)] .21869 1.21453 1 -0.25954 Mshowa
.32458 1.23663 m
.34246 1.23459 L
s
[(4)] .28883 1.24069 1 -0.25597 Mshowa
.125 Mabswid
.0535 1.13536 m
.06419 1.13408 L
s
.07226 1.14237 m
.08296 1.1411 L
s
.09093 1.14934 m
.10162 1.14807 L
s
.12795 1.16317 m
.13865 1.16191 L
s
.14631 1.17003 m
.15701 1.16877 L
s
.16457 1.17685 m
.17527 1.1756 L
s
.2008 1.19039 m
.21151 1.18914 L
s
.21876 1.1971 m
.22948 1.19586 L
s
.23664 1.20377 m
.24735 1.20254 L
s
.27209 1.21702 m
.28281 1.21579 L
s
.28968 1.22359 m
.30041 1.22236 L
s
.30718 1.23013 m
.3179 1.2289 L
s
.01566 1.12123 m
.02634 1.11994 L
s
.34189 1.24309 m
.35262 1.24188 L
s
.35911 1.24953 m
.36984 1.24831 L
s
.25 Mabswid
.08215 .09365 m
0 1.11538 L
s
.08051 .11411 m
.09777 .11122 L
s
[(0)] .04597 .11989 1 -0.37712 Mshowa
.06333 .32777 m
.08072 .32502 L
s
[(10)] .02854 .33325 1 -0.3549 Mshowa
.0447 .55939 m
.06222 .55682 L
s
[(20)] .00966 .56454 1 -0.33077 Mshowa
.02444 .81136 m
.0421 .80898 L
s
[(30)] -0.01086 .81614 1 -0.30448 Mshowa
.00232 1.08647 m
.02011 1.08429 L
s
[(40)] -0.03326 1.09083 1 -0.27571 Mshowa
.125 Mabswid
.07718 .1555 m
.08755 .15379 L
s
.0738 .19755 m
.08419 .19585 L
s
.07036 .24027 m
.08077 .23858 L
s
.06687 .28367 m
.07729 .282 L
s
.05972 .37258 m
.07017 .37096 L
s
.05606 .41814 m
.06653 .41653 L
s
.05234 .46444 m
.06282 .46286 L
s
.04855 .51152 m
.05905 .50996 L
s
.04079 .60808 m
.05132 .60656 L
s
.03681 .65759 m
.04735 .65609 L
s
.03276 .70797 m
.04332 .70649 L
s
.02864 .75921 m
.03921 .75776 L
s
.02018 .86443 m
.03079 .86303 L
s
.01583 .91846 m
.02646 .91707 L
s
.01141 .97345 m
.02205 .97209 L
s
.00691 1.02945 m
.01757 1.02811 L
s
.25 Mabswid
.08215 .09365 m
0 1.11538 L
s
0 1.11538 m
.36038 1.25 L
s
.36038 1.25 m
.383 .25244 L
s
.383 .25244 m
.08215 .09365 L
s
.63829 0 m
.92147 .16696 L
s
.92147 .16696 m
1 1.17782 L
s
1 1.17782 m
.6647 1.0349 L
s
.6647 1.0349 m
.63829 0 L
s
.08215 .09365 m
0 1.11538 L
s
0 1.11538 m
.6647 1.0349 L
s
.6647 1.0349 m
.63829 0 L
s
.63829 0 m
.08215 .09365 L
s
.383 .25244 m
.92147 .16696 L
s
.92147 .16696 m
1 1.17782 L
s
1 1.17782 m
.36038 1.25 L
s
.36038 1.25 m
.383 .25244 L
s
0 0 m
1 0 L
1 1.25 L
0 1.25 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.40853 .2513 m
.44239 .26124 L
s
.37882 .23729 m
.40853 .2513 L
s
.35692 .21863 m
.37882 .23729 L
s
.44239 .26124 m
.47766 .26799 L
s
.34717 .19535 m
.35692 .21863 L
s
.47766 .26799 m
.51241 .27248 L
s
.354 .16833 m
.34717 .19535 L
s
.51241 .27248 m
.54517 .27548 L
s
.38092 .13946 m
.354 .16833 L
s
.54517 .27548 m
.57454 .27748 L
s
.4293 .11162 m
.38092 .13946 L
s
.57454 .27748 m
.59884 .27875 L
s
.49709 .08834 m
.4293 .11162 L
s
.59884 .27875 m
.61595 .27941 L
s
.57805 .07328 m
.49709 .08834 L
s
.61595 .27941 m
.62347 .27964 L
s
.62347 .27964 m
.61914 .27977 L
s
.61914 .27977 m
.60144 .28043 L
s
.43245 .43518 m
.49948 .44884 L
s
.37887 .41603 m
.43245 .43518 L
s
.49948 .44884 m
.57094 .45588 L
s
.3453 .39323 m
.37887 .41603 L
s
.57094 .45588 m
.63645 .45604 L
s
.60144 .28043 m
.57027 .28251 L
s
.33504 .36897 m
.3453 .39323 L
s
.63645 .45604 m
.68565 .45012 L
s
.34783 .34547 m
.33504 .36897 L
s
.57027 .28251 m
.52751 .28711 L
s
.38009 .32462 m
.34783 .34547 L
s
.52751 .28711 m
.47729 .29526 L
s
.4257 .3077 m
.38009 .32462 L
s
.47729 .29526 m
.4257 .3077 L
s
.68565 .45012 m
.70975 .43994 L
s
.49408 .61535 m
.59356 .62141 L
s
.39829 .59941 m
.49408 .61535 L
s
.70975 .43994 m
.70306 .4282 L
s
.32021 .57475 m
.39829 .59941 L
s
.59356 .62141 m
.68184 .61783 L
s
.27117 .54377 m
.32021 .57475 L
s
.70306 .4282 m
.66437 .41813 L
s
.68184 .61783 m
.74494 .60626 L
s
.25822 .50983 m
.27117 .54377 L
s
.28292 .47675 m
.25822 .50983 L
s
.66437 .41813 m
.59776 .41303 L
s
.74494 .60626 m
.77184 .58967 L
s
.3408 .44826 m
.28292 .47675 L
s
.59776 .41303 m
.51252 .41558 L
s
.40902 .76677 m
.52478 .78061 L
s
.30856 .74223 m
.40902 .76677 L
s
.52478 .78061 m
.6387 .78313 L
s
.4219 .42733 m
.3408 .44826 L
s
.51252 .41558 m
.4219 .42733 L
s
.23843 .70914 m
.30856 .74223 L
s
.77184 .58967 m
.75643 .57201 L
s
.6387 .78313 m
.73356 .77526 L
s
.20957 .67097 m
.23843 .70914 L
s
.73356 .77526 m
.7942 .75949 L
s
.75643 .57201 m
.69909 .55772 L
s
.22691 .6321 m
.20957 .67097 L
s
.7942 .75949 m
.80971 .73963 L
s
.44568 .93786 m
.57383 .9478 L
s
.32684 .91625 m
.44568 .93786 L
s
.69909 .55772 m
.60752 .55097 L
s
.28807 .59723 m
.22691 .6321 L
s
.57383 .9478 m
.6923 .94615 L
s
.23506 .88454 m
.32684 .91625 L
s
.38312 .57052 m
.28807 .59723 L
s
.60752 .55097 m
.49601 .55482 L
s
.6923 .94615 m
.78299 .9346 L
s
.18468 .84576 m
.23506 .88454 L
s
.80971 .73963 m
.77562 .72037 L
s
.49601 .55482 m
.38312 .57052 L
s
.18437 .80419 m
.18468 .84576 L
s
.78299 .9346 m
.83101 .91632 L
s
.77562 .72037 m
.69551 .70664 L
s
.23521 .76483 m
.18437 .80419 L
s
.49747 1.11393 m
.63152 1.11952 L
s
.36478 1.09651 m
.49747 1.11393 L
s
.25309 1.06808 m
.36478 1.09651 L
s
.83101 .91632 m
.82703 .89571 L
s
.63152 1.11952 m
.74697 1.11407 L
s
.17955 1.03102 m
.25309 1.06808 L
s
.69551 .70664 m
.58136 .7027 L
s
.32962 .73255 m
.23521 .76483 L
s
.74697 1.11407 m
.82585 1.09993 L
s
.58136 .7027 m
.452 .7112 L
s
.452 .7112 m
.32962 .73255 L
s
.1564 .98914 m
.17955 1.03102 L
s
.82703 .89571 m
.76956 .87783 L
s
.18866 .94723 m
.1564 .98914 L
s
.82585 1.09993 m
.85456 1.08085 L
s
.76956 .87783 m
.66627 .86761 L
s
.27238 .91046 m
.18866 .94723 L
s
.85456 1.08085 m
.82644 1.06156 L
s
.66627 .86761 m
.53365 .86884 L
s
.39429 .88334 m
.27238 .91046 L
s
.53365 .86884 m
.39429 .88334 L
s
.82644 1.06156 m
.7439 1.04716 L
s
.7439 1.04716 m
.61922 1.0422 L
s
0 g
.25 Mabswid
.63829 0 m
.92147 .16696 L
s
.92147 .16696 m
1 1.17782 L
s
1 1.17782 m
.6647 1.0349 L
s
.6647 1.0349 m
.63829 0 L
s
.08215 .09365 m
0 1.11538 L
s
0 1.11538 m
.6647 1.0349 L
s
.6647 1.0349 m
.63829 0 L
s
.63829 0 m
.08215 .09365 L
s
0 1.11538 m
.36038 1.25 L
s
.03463 1.12832 m
.05244 1.12617 L
s
[(-4)] -0.00099 1.1326 1 -0.27088 Mshowa
.10949 1.15628 m
.12732 1.15416 L
s
[(-2)] .07383 1.16051 1 -0.26699 Mshowa
.18273 1.18364 m
.20058 1.18155 L
s
[(0)] .14704 1.18781 1 -0.26321 Mshowa
.25441 1.21041 m
.27228 1.20836 L
s
[(2)] .21869 1.21453 1 -0.25954 Mshowa
.32458 1.23663 m
.34246 1.23459 L
s
[(4)] .28883 1.24069 1 -0.25597 Mshowa
.125 Mabswid
.0535 1.13536 m
.06419 1.13408 L
s
.07226 1.14237 m
.08296 1.1411 L
s
.09093 1.14934 m
.10162 1.14807 L
s
.12795 1.16317 m
.13865 1.16191 L
s
.14631 1.17003 m
.15701 1.16877 L
s
.16457 1.17685 m
.17527 1.1756 L
s
.2008 1.19039 m
.21151 1.18914 L
s
.21876 1.1971 m
.22948 1.19586 L
s
.23664 1.20377 m
.24735 1.20254 L
s
.27209 1.21702 m
.28281 1.21579 L
s
.28968 1.22359 m
.30041 1.22236 L
s
.30718 1.23013 m
.3179 1.2289 L
s
.01566 1.12123 m
.02634 1.11994 L
s
.34189 1.24309 m
.35262 1.24188 L
s
.35911 1.24953 m
.36984 1.24831 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{160.5, 200.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000380000nR000`400?l00000o`00003ob?ooool0
0<Sooooo0038ooooo`00b?ooool00<Sooooo0038ooooo`00b?ooool00<Sooooo0038ooooo`00P_oo
ool5o`00047ooooo001looooo`Ko00000oooool00ol0003oooooo`000010ooooo`00Moooool5o`00
00Wooooo00?o0000ooooooooool00_l0000nooooo`00LOooool6o`0000kooooo00?o0000oooooooo
ool00_ooool2o`0003cooooo001[ooooo`Ko00005?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03Wooooo001Uooooo`Ko00006_ooool00ol0003oooooooooo`05ooooo`;o0000>Ooo
ool0063ooooo1Ol0000Pooooo`03o`000?oooooooooo00Oooooo0_l0000gooooo`00F_ooool6o`00
02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0dooooo`00E?ooool6o`0002_o
oooo00?o0000ooooooooool02_ooool2o`0003Cooooo001>ooooo`Ko0000<Oooool00ol0003ooooo
ooooo`0<ooooo`;o0000<_ooool004Sooooo1_l0000gooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0;oooool004?ooooo1Ol0000mooooo`03o`000?oooooooooo00oooooo0_l0000_
ooooo`00?Oooool6o`0004;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0/oooo
o`00=oooool6o`0003_ooooo0ol0o`0:ooooo`03o`000?oooooooooo01;ooooo0_l0000/ooooo`00
<Oooool6o`0003cooooo1Ol0o`0=ooooo`03o`000?oooooooooo01Cooooo0_l0000Zooooo`00;?oo
ool5o`0003gooooo1Ol0o`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09ooo
ool002Kooooo1_l0000oooooo`?o0?l05oooool00ol0003oooooooooo`0Gooooo`;o00009oooool0
02?ooooo0ol00012ooooo`?o0?l06_ooool00ol0003oooooooooo`0Iooooo`;o00009Oooool002?o
oooo00Co0000ooooool0003o0000?_ooool3o`3o01gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Rooooo`008oooool01?l0003oooooooooooooool2o`0003Wooooo0ol0o`0Poooo
o`03o`000?oooooooooo01cooooo0_l0000Rooooo`008_ooool5o`0000;ooooo0_l0000dooooo`?o
0?l08oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000Eooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`05ooooo`;o0000<?ooool2o`3o02Ko
oooo00?o0000ooooooooool07oooool2o`0001oooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo0_l0o`0Xooooo`03
o`000?oooooooooo027ooooo0_l0000Mooooo`005Oooool01Ol@413ooooooooooooooooo410@00Wo
oooo00?o0000ooooooooool02?ooool2o`0002[ooooo00?o0?l0ooooooooool0:?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01[ooooo000Eooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`0;ooooo`;o00009_ooool2o`3o02cooooo00?o0000oooooooo
ool08oooool2o`0001[ooooo000Eooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`0=ooooo`;o00008oooool00ol0o`3oooooooooo`0/ooooo`03o`000?oooooooooo02Go
oooo0_l0000Hooooo`005Oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool03oooool2o`00027ooooo00?o0?l0ooooooooool0;?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo01Gooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool3o`00017o
oooo0_l0000Nooooo`03o`3o0?oooooooooo02gooooo00?o0000ooooooooool0:?ooool2o`0001Go
oooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0Cooooo`;o
00006oooool00ol0o`3oooooooooo`0^ooooo`03o`000?oooooooooo02[ooooo0_l0000Cooooo`00
8_ooool00ol0003oooooooooo`0Eooooo`;o00006?ooool00ol0o`3oooooooooo`0_ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool05ooo
ool2o`0001Gooooo00?o0?l0ooooooooool0<?ooool00ol0003oooooooooo`0Zooooo`Co00004Ooo
ool002;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`3o0?oooooo
oooo033ooooo00?o0000ooooooooool09?ooool6o`0000?ooooo00?o0000ooooooooool03oooool0
02;ooooo00?o0000ooooooooool06_ooool2o`00017ooooo00?o0?l0ooooooooool0<Oooool00ol0
003oooooooooo`0Mooooo`Oo00002Oooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0003o
ooooooooo`0Looooo`;o00003oooool00ol0o`3oooooooooo`0aooooo`03o`000?oooooooooo01Oo
oooo1_l0000@ooooo`03o`000?oooooooooo00oooooo000Rooooo`03o`000?oooooooooo01kooooo
0_l0000=ooooo`03o`3o0?oooooooooo037ooooo00?o0000ooooooooool04Oooool6o`0001Kooooo
00?o0000ooooooooool03oooool0027ooooo0ol0000Qooooo`;o00002_ooool00ol0o`3ooooooooo
o`0booooo`03o`000?oooooooooo00_ooooo1_l0000Looooo`03o`000?oooooooooo00oooooo000Q
ooooo`03o`000?oooooooooo02?ooooo0_l00008ooooo`03o`3o0?oooooooooo03;ooooo00?o0000
ooooooooool01?ooool7o`0002;ooooo00?o0000ooooooooool03oooool0027ooooo00?o0000oooo
ooooool09Oooool2o`0000Oooooo00?o0?l0ooooooooool0<Oooool7o`0002[ooooo00?o0000oooo
ooooool03_ooool0027ooooo00?o0000ooooooooool09oooool2o`0000Gooooo00?o0?l0oooooooo
ool0;?ooool6o`00033ooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0
:Oooool2o`0000Cooooo0_l0o`0Uooooo`Oo00001Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00ooo
ool00ol0o`3oooooooooo`0Looooo`Ko00003?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00kooooo000Qooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`03o`3o0?oooooo
oooo01Gooooo1_l0000Booooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03_ooool0
027ooooo0ol0000^ooooo`;o00000oooool2o`3o00oooooo1_l0000Hooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0<?ooool2o`0000?o
oooo0ol0o`05ooooo`Oo00007_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00ko
oooo000Qooooo`03o`000?oooooooooo03;ooooo0_l00003ooooo`04o`000?l0o`3o0?l0o`3o00;o
00009Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`00
0?oooooooooo03Cooooo0ol00004ooooo`?o0?l09?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01ooo
ool4o`3o023ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0>ooooo`008Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00_ooooo1_l0o`0Jooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Aooooo`Ko0?l05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00kooooo000Pooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05ooooolAo`3o00?o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0>ooooo`008?ooool3o`0003Gooooo
00?o0000ooooooooool06_ooool;o`3o00Kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0=ooooo`008?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01;ooooo2?l0
o`0Aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0;ooooo`Oo0?l06Oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool01_ooool5o`3o023ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0=oooo
o`008?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo0ol0o`0Uooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`03o`3o02Sooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0=ooooo`008?ooool00ol0003oooooooooo`0eooooo`?o0?l0:oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00gooooo000Pooooo`Co0000<_ooool2o`3o0003o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0=ooooo`007oooool2o`00
03Cooooo00Co0?l0oooooooooooo0000;Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00gooooo000;ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPWooooo
00?o0000ooooooooool0<?ooool2o`3o00?ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo00gooooo000=ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo033ooooo00?o0?l0ooooooooool0
0oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
3Oooool000gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0;oooool00ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0=ooooo`003Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0_ooooo`03o`3o
0?oooooooooo00Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00gooooo000=ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo02kooooo00?o0?l0ooooooooool01Oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool000gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
;_ooool00ol0o`3oooooooooo`05ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool3o`0002gooooo00?o0?l0ooooooooool01_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool000_ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
;Oooool00ol0o`3oooooooooo`06ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`0^ooooo`03o`3o0?oo
oooooooo00Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00cooooo000Oooooo`03o`000?oooooooooo02kooooo00?o0?l0ooooooooool01?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool0
01oooooo00?o0000ooooooooool0;oooool2o`3o00Cooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo037o
oooo00Go0?l0ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool03?ooool001oooooo00?o0000ooooooooool0<_ooool2o`3o0003ooooool0003ooooo02ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003ooooo
ooooo`0eooooo`03o`3o0?l0003ooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0<ooooo`007_ooool3o`0003Kooooo0_l0o`0Aoooooa[o0?l00oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo03Kooooo00Co0000
ooooool0o`3o0?l01oooool8o`3o01[ooooo0ol0o`000ol0003o0?l0o`3o0002o`3o02gooooo00?o
0000ooooooooool03?ooool001kooooo00?o0000ooooooooool0=_ooool01?l0003ooooooooooooo
ool7o`3o02Gooooo00?o0000ooooooooool00_ooool3o`3o02_ooooo00?o0000ooooooooool02ooo
ool001kooooo00?o0000ooooooooool0=_ooool00ol0003oooooo`3o0002o`3o00;ooooo0_l0o`0W
ooooo`03o`000?oooooooooo00Gooooo0_l0o`0Yooooo`03o`000?oooooooooo00_ooooo000Noooo
o`03o`000?oooooooooo03Cooooo1?l0o`07ooooo`Co0?l08oooool00ol0003oooooooooo`06oooo
o`03o`3o0?oooooooooo02Oooooo00?o0000ooooooooool02oooool001kooooo00?o0000oooooooo
ool0<Oooool3o`3o00;ooooo00?o0000ooooooooool02_ooool6o`3o01gooooo00?o0000oooooooo
ool01Oooool3o`3o02Sooooo00?o0000ooooooooool02oooool001kooooo00?o0000ooooooooool0
;_ooool3o`3o00Gooooo00?o0000ooooooooool04?ooool:o`3o01?ooooo00?o0000ooooool0o`00
1Ol0o`0[ooooo`03o`000?oooooooooo00_ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0
o`08ooooo`03o`000?oooooooooo01[ooooo4ol0o`000ol0003o0?l0ooooo`0`ooooo`03o`000?oo
oooooooo00_ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0o`0:ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;ooooo`007_ooool2o`00
02Wooooo0_l0o`0<ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0;ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0?l03_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool001gooooo
00?o0000ooooooooool09_ooool00ol0o`3oooooooooo`0>ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;ooooo`007Oooool00ol0003ooooooooo
o`0Vooooo`03o`3o0?oooooooooo00kooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00_ooooo000Mooooo`03o`000?oooooooooo02Gooooo00?o0?l0
ooooooooool03oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool02oooool001gooooo00?o0000ooooooooool09?ooool00ol0o`3oooooooooo`0@oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;oooo
o`007Oooool00ol0003oooooooooo`0Tooooo`03o`3o0?oooooooooo013ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[ooooo000Mooooo`03o`00
0?oooooooooo02?ooooo00?o0?l0ooooooooool04Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool02_ooool001gooooo0ol0000Rooooo`03o`3o0?oo
oooooooo01;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00[ooooo000Mooooo`03o`000?oooooooooo02;ooooo00?o0?l0ooooooooool04_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02_ooool0
01gooooo00?o0000ooooooooool08oooool00ol0o`3oooooooooo`0Aooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`007Oooool00ol0003o
ooooooooo`0Sooooo`03o`3o0?oooooooooo017ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00[ooooo000Mooooo`03o`000?oooooooooo02?ooooo
00?o0?l0ooooooooool04Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02_ooool001gooooo00?o0000ooooooooool09?ooool00ol0o`3ooooooooo
o`0@ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0:ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o0?l04Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02_ooool001cooooo00?o0000oooo
ooooool09oooool2o`3o00oooooo00?o0000ooooooooool07?oooolAo`3o0003o`000?oooooooooo
037ooooo00?o0000ooooooooool02_ooool001cooooo00Co0000ooooool0003o0000:?ooool2o`3o
00gooooo00?o0000ooooooooool03oooool=o`3o017ooooo00?o0000o`3o0?l0o`002?l0o`0Yoooo
o`03o`000?oooooooooo00[ooooo0007ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo0_l0000/ooooo`03o`3o0?oooooooooo00[ooooo00?o0000ooooooooool02?ooool7o`3o
01kooooo00?o0000ooooooooool02?ooool3o`3o02Kooooo00?o0000ooooooooool02_ooool000Oo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`0/ooooo`;o0?l02_ooool01?l0003oooooooooooooool7o`3o02Gooooo00?o
0000ooooooooool02oooool3o`3o02?ooooo00?o0000ooooooooool02_ooool000Sooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0;_oo
ool2o`3o00Oooooo1Ol0o`0/ooooo`03o`000?oooooooooo00kooooo0_l0o`0Rooooo`03o`000?oo
oooooooo00Wooooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo033ooooo1ol0o`000ooooooo0000ooooo`0^ooooo`03o`000?oo
oooooooo013ooooo00?o0?l0ooooooooool07oooool00ol0003oooooooooo`09ooooo`002_ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`0^ooooo`So0?l00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo017ooooo00?o
0?l0ooooooooool07_ooool00ol0003oooooooooo`09ooooo`002oooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`Co0?l02?oo
ool2o`3o0003o`000?oooooooooo02gooooo00?o0000ooooooooool04Oooool2o`3o01oooooo00?o
0000ooooooooool02Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0Wooooo`?o0?l03_ooool3o`3o02gooooo
00?o0000ooooooooool03oooool2o`3o027ooooo00?o0000ooooooooool02Oooool000Oooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`0Uooooo`;o0?l04Oooool00ol0003oooooooooo`05o`3o02Sooooo00?o0000oooooooo
ool03_ooool00ol0o`3oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo000Kooooo`?o0000
9?ooool2o`3o01?ooooo00?o0000ooooooooool01Oooool9o`3o01oooooo00?o0000ooooooooool0
2_ooool4o`3o02Cooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool08ooo
ool00ol0o`3oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo3Ol0o`0Booooo`03o`000?oo
oooooooo00Gooooo1Ol0o`0Xooooo`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooo
oooo027ooooo0_l0o`0Fooooo`03o`000?oooooooooo01_ooooo4_l0o`000ol0003o0?l0o`3o0005
o`3o02gooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool07oooool2o`3o
01Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00Wooooo000Kooooo`03o`000?oooooooooo01kooooo00?o0?l0ooooooooool06?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool001_ooooo
00?o0000ooooooooool07_ooool00ol0o`3oooooooooo`0Gooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`09ooooo`006oooool00ol0003ooooooooo
o`0Mooooo`03o`3o0?oooooooooo01Sooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Sooooo000Kooooo`03o`000?oooooooooo01gooooo00?o0?l0
ooooooooool06?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool02?ooool001_ooooo00?o0000ooooooooool07?ooool00ol0o`3oooooooooo`0Ioooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`08oooo
o`006oooool3o`0001cooooo00?o0?l0ooooooooool06Oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool001_ooooo00?o0000ooooooooool0
7?ooool00ol0o`3oooooooooo`0Iooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`08ooooo`006oooool00ol0003oooooooooo`0Kooooo`03o`3o0?oo
oooooooo01[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo01cooooo00?o0?l0ooooooooool06_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool07Oooool00ol0o`3oooooooooo`0Iooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`0Nooooo`03o`3o0?oooooooooo01Sooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo01oooooo
00?o0?l0ooooooooool05oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool07oooool00ol0o`3ooooooooo
o`0Gooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`08ooooo`006_ooool3o`00023ooooo00?o0?l0ooooooooool05_ooool00ol0003oooooooooo`0G
oooooaSo0?l000?o0000o`3o0?l0o`001ol0o`0[ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo027ooooo0_l0o`0Fooooo`03o`000?oooooooooo00Sooooo3ol0o`0Hoooo
o`03o`000?oooooooooo00Oooooo1Ol0o`0Vooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo02?ooooo0_l0o`0Dooooo`03o`000?oooooooooo00?ooooo1Ol0o`0Wooooo`03
o`000?oooooooooo00cooooo1Ol0o`0Rooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`00
0?oooooooooo02Gooooo0_l0o`0Booooo`Ko0?l0;?ooool00ol0003oooooooooo`0Aooooo`?o0?l0
7oooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0Wooooo`?o0?l02_oo
ool5o`3o0003o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool2o`3o01gooooo00?o
0000ooooooooool01oooool001[ooooo00?o0000ooooooooool0:_ooool2o`3o00Cooooo1?l0o`05
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05_ooool2o`3o01_ooooo00?o0000
ooooooooool01oooool001[ooooo00?o0000ooooooooool0;?ooool4o`3o00Wooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Hooooo`03o`3o0?oooooooooo01Sooooo00?o0000oooo
ooooool01oooool001Wooooo00?o0000ooooooooool0:oooool3o`3o0004ooooool0o`3o0?l0o`3o
00Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Hooooo`03o`3o0?oooooooooo
01Sooooo00?o0000ooooooooool01oooool001Wooooo00?o0000ooooooooool0:Oooool2o`3o00Oo
oooo1?l0o`04ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05oooool00ol0o`3o
ooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo000Iooooo`?o00009_ooool3o`3o00gooooo
1Ol0o`0aooooo`03o`000?oooooooooo01Kooooo00?o0?l0ooooooooool06_ooool00ol0003ooooo
ooooo`07ooooo`006Oooool00ol0003oooooooooo`0Sooooo`?o0?l05?ooool00ol0003o0?l0o`3o
0002o`3o02gooooo00?o0000ooooooooool04oooool3o`3o01gooooo00?o0000ooooooooool01ooo
ool001Wooooo00?o0000ooooooooool08Oooool2o`3o01Oooooo00?o0000ooooooooool00_ooool7
o`3o02Kooooo00?o0000ooooooooool03oooool4o`3o023ooooo00?o0000ooooooooool01oooool0
01Wooooo00?o0000ooooooooool08?ooool00ol0o`3oooooooooo`0Gooooo`03o`000?oooooooooo
00Wooooo2ol0o`0Kooooo`03o`000?oooooooooo00cooooo0ol0o`0Tooooo`03o`000?oooooooooo
00Oooooo000Iooooo`03o`000?oooooooooo01oooooo00?o0?l0ooooooooool06?ooool00ol0003o
ooooooooo`0Dooooo`oo0?l03?ooool00ol0003oooooooooo`02ooooo`[o0?l09oooool00ol0003o
ooooooooo`07ooooo`006Oooool00ol0003oooooooooo`0Mooooo`;o0?l06oooool00ol0003ooooo
ooooo`0Sooooo`co0?l000?o0000o`3o0?l0o`000_l0o`0booooo`03o`000?oooooooooo00Kooooo
000Iooooo`03o`000?oooooooooo01cooooo00?o0?l0ooooooooool06oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01_ooool001Wooooo00?o0000
ooooooooool06oooool00ol0o`3oooooooooo`0Looooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`06ooooo`006Oooool00ol0003oooooooooo`0Joooo
o`03o`3o0?oooooooooo01gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00Kooooo000Iooooo`04o`000?oooooo0000o`0001Sooooo00?o0?l0oooo
ooooool07_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01_ooool000?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool3o`0001[ooooo00?o0?l0ooooooooool07_ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01_ooool000?ooooo00Go410@okZj
^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`0Jooooo`03o`3o0?oooooooooo01kooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00Kooooo0007ooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0?l0ooooooooool07_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01_oo
ool000Kooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool06_ooool00ol0o`3oooooooooo`0Nooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`06ooooo`001Oooool00ol@413o0000okZj^P03
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Jooooo`03o`3o0?oo
oooooooo01kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Kooooo0006ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo01[ooooo00?o0?l0ooooooooool07_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01_ooool000?ooooo00Go410@
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`0Jooooo`;o0?l07oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool01_ooool000?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0Looooo`03o`3o0?oooooooooo01co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Ko
oooo000Hooooo`03o`000?oooooooooo01gooooo00?o0?l0ooooooooool06oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool001Sooooo0ol0
000Nooooo`;o0?l06oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool08?ooool00ol0o`3oooooooooo`0H
ooooo`03o`000?oooooooooo01?ooooo7?l0o`000ol0003o0?l0o`3o0004o`3o037ooooo00?o0000
ooooooooool01Oooool001Sooooo00?o0000ooooooooool08Oooool00ol0o`3oooooooooo`0Goooo
o`03o`000?oooooooooo00Oooooo3?l0o`0Looooo`03o`000?oooooooooo00Cooooo2Ol0o`0Xoooo
o`03o`000?oooooooooo00Gooooo000Gooooo`03o`000?oooooooooo02?ooooo00?o0?l0oooooooo
ool05Oooool00ol0003oooooooooo`08o`3o02Sooooo00?o0000ooooooooool03Oooool7o`3o027o
oooo00?o0000ooooooooool01Oooool001Oooooo00?o0000ooooooooool09?ooool3o`3o01;ooooo
1Ol0o`0`ooooo`03o`000?oooooooooo01Cooooo0ol0o`0Nooooo`03o`000?oooooooooo00Gooooo
000Gooooo`03o`000?oooooooooo02Oooooo0ol0o`0;ooooo`Co0?l00_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Oooooo0ol0o`0Kooooo`03o`000?oooooooooo00Gooooo000G
ooooo`03o`000?oooooooooo02[ooooo0ol0o`04ooooo`Co0?l01_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo01[ooooo0_l0o`0Iooooo`03o`000?oooooooooo00Gooooo000Goooo
o`03o`000?oooooooooo02cooooo1Ol0o`0:ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool06oooool00ol0o`3oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo000Gooooo`03
o`000?oooooooooo02Wooooo0ol0o`04ooooo`?o0?l02?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01[ooooo00?o0?l0ooooooooool05oooool00ol0003oooooooooo`05ooooo`00
5oooool3o`0002Oooooo0_l0o`0:ooooo`Go0?l00oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo01Wooooo0_l0o`0Iooooo`03o`000?oooooooooo00Gooooo000Gooooo`03o`000?oo
oooooooo02Gooooo0_l0o`0Aooooo`Go0?l0<_ooool00ol0003oooooooooo`0Gooooo`;o0?l06ooo
ool00ol0003oooooooooo`05ooooo`005oooool00ol0003oooooooooo`0Sooooo`;o0?l05_ooool0
0ol0003oooooo`3o0004o`3o02gooooo00?o0000ooooooooool05Oooool2o`3o01gooooo00?o0000
ooooooooool01Oooool001Oooooo00?o0000ooooooooool08Oooool2o`3o01Sooooo00?o0000oooo
ooooool01?ooool5o`3o02Sooooo00?o0000ooooooooool04oooool2o`3o023ooooo00?o0000oooo
ooooool01?ooool001Oooooo00?o0000ooooooooool07oooool2o`3o01[ooooo00?o0000oooooooo
ool02Oooool9o`3o01oooooo00?o0000ooooooooool03_ooool5o`3o02;ooooo00?o0000oooooooo
ool01?ooool001Oooooo00?o0000ooooooooool07Oooool2o`3o01cooooo00?o0000ooooooooool0
4_ooool;o`3o01Cooooo00?o0000ooooooooool01_ooool8o`3o02Oooooo00?o0000ooooooooool0
1?ooool001Kooooo00?o0000ooooooooool07Oooool00ol0o`3oooooooooo`0Looooo`03o`000?oo
oooooooo01gooooo5?l0o`000ol0003o0?l0o`3o0006o`3o02oooooo00?o0000ooooooooool01?oo
ool001Kooooo00?o0000ooooooooool07Oooool00ol0o`3oooooooooo`0Looooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`04ooooo`005_ooool00ol0
003oooooooooo`0Looooo`03o`3o0?oooooooooo01gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo000Fooooo`03o`000?oooooooooo01_o
oooo00?o0?l0ooooooooool07_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01?ooool001Kooooo0ol0000Jooooo`03o`3o0?oooooooooo01oooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo
000Fooooo`03o`000?oooooooooo01Wooooo00?o0?l0ooooooooool08?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool001Kooooo00?o0000
ooooooooool06?ooool00ol0o`3oooooooooo`0Qooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`04ooooo`005_ooool00ol0003oooooooooo`0Goooo
o`03o`3o0?oooooooooo02;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Cooooo000Fooooo`03o`000?oooooooooo01Oooooo00?o0?l0oooooooo
ool08_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool01?ooool001Kooooo00?o0000ooooooooool06?ooool00ol0o`3oooooooooo`0Qooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`005_oo
ool00ol0003oooooooooo`0Hooooo`03o`3o0?oooooooooo027ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo000Fooooo`03o`000?oooooo
oooo01Wooooo00?o0?l0ooooooooool08?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool00oooool001Gooooo00?o0000ooooooooool06oooool00ol0
o`3oooooooooo`0Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`03ooooo`005Oooool00ol0003oooooooooo`0Kooooo`03o`3o0?oooooooooo01oo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?o
oooo000Eooooo`?o00007?ooool2o`3o01oooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00?ooooo000Eooooo`03o`000?oooooooooo01kooooo0_l0
o`0Mooooo`03o`000?oooooooooo02gooooo1_l0000gooooo`03o`000?oooooooooo00?ooooo000E
ooooo`03o`000?oooooooooo023ooooo0_l0o`0Kooooo`03o`000?oooooooooo02Cooooo2Ol00006
o`3o00?o0000=?ooool00ol0003oooooooooo`03ooooo`005Oooool00ol0003oooooooooo`0Roooo
o`;o0?l06Oooool00ol0003oooooooooo`0Looooo`So00004Oooool00ol0o`3o0000o`00000;o`3o
02Oooooo00?o0000ooooooooool00oooool001Gooooo00?o0000ooooooooool09?ooool00ol0o`3o
ooooooooo`0Fooooo`03o`000?oooooooooo01Cooooo2?l0000Looooo`;o00002Oooool5o`3o02;o
oooo00?o0000ooooooooool00oooool001Gooooo00?o0000ooooooooool09Oooool2o`3o01Kooooo
00?o0000ooooooooool02oooool9o`0002Kooooo0ol0000;ooooo`Go0?l07Oooool00ol0003ooooo
ooooo`03ooooo`005Oooool00ol0003oooooooooo`0Wooooo`;o0?l05?ooool00ol0003ooooooooo
o`03ooooo`So0000<_ooool2o`0000kooooo0ol0o`0Jooooo`03o`000?oooooooooo00?ooooo000E
ooooo`03o`000?oooooooooo02Wooooo0ol0o`0?ooooo`So0000??ooool2o`0000oooooo0_l0o`0H
ooooo`03o`000?oooooooooo00?ooooo000Eooooo`03o`000?oooooooooo02cooooo1?l0o`02oooo
o`Wo00000_ooool00ol0003oooooooooo`11ooooo`?o00003_ooool00ol0o`3oooooooooo`0Foooo
o`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo02[ooooo2?l00002o`3o00Wo
oooo00?o0000ooooooooool0A?ooool2o`0000cooooo0_l0o`0Gooooo`03o`000?oooooooooo00;o
oooo0002ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01oooool5
o`00027ooooo2?l0000:ooooo`?o0?l01_ooool00ol0003oooooooooo`16ooooo`;o00002Oooool0
0ol0o`3oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo0003ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo01[ooooo2Ol0000E
ooooo`Co0?l00_ooool00ol0003oooooooooo`18ooooo`?o00001?ooool2o`3o01[ooooo00?o0000
ooooooooool00_ooool000Go00000oooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000
ooooooooool04_ooool8o`0002;ooooo1_l0o`1:ooooo`;o000000?oooooo`3o0?ooool06oooool0
0ol0003oooooooooo`02ooooo`0000CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool02_ooool8o`0002cooooo00Co0000oooooooooooooooo
2?l0o`11ooooo`?o0?l00ol0000Kooooo`03o`000?oooooooooo00;ooooo00001?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooooooool9o`00
03Cooooo00?o0000ooooooooool02Oooool8o`3o03;ooooo1ol0o`06ooooo`;o00006Oooool00ol0
003oooooooooo`02ooooo`0000CoooooogMgMoo<c<co00001?ooool01Ol@413ooooooooooooooooo
410@00Oooooo1?l0000mooooo`03o`000?oooooooooo017ooooo4?l0o`0Eooooo`go0?l03oooool2
o`0001Oooooo00?o0000ooooooooool00_ooool00004ooooooo^k^koA4A4o`0000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`09ooooo`Co0000>oooool00ol0003oooooooooo`0QoooooaGo0?l07_oo
ool3o`0001Cooooo00?o0000ooooooooool00_ooool000;ooooo00?oMgMgo`000?ooool00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1_l0000fooooo`03o`000?oooooooooo05Oooooo0_l0
000Booooo`03o`000?oooooooooo00;ooooo000?ooooo`;o000000?o410@ooooooooool01_ooool4
o`0003Kooooo00?o0000ooooooooool0F_ooool2o`00013ooooo00?o0000ooooooooool00_ooool0
013ooooo00?o0000ooooooooool02oooool3o`0003?ooooo00?o0000ooooooooool0G?ooool3o`00
00gooooo00?o0000ooooooooool00_ooool000Gooooo1_l00002ooooo`Go00003oooool3o`00033o
oooo00?o0000ooooooooool0Goooool2o`0000_ooooo00?o0000ooooooooool00_ooool000gooooo
00CoA4A4omgMgOoooooo00004oooool3o`0002gooooo00?o0000ooooooooool0HOooool2o`0000[o
oooo00?o0000ooooooooool00Oooool000gooooo00CogMgMoeEEEOoooooo00002Oooool5o`0000Oo
oooo1_l0000Xooooo`03o`000?oooooooooo06?ooooo0ol00007ooooo`03o`000?oooooooooo007o
oooo000>ooooo`03ogMgMoo<c<co000000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`Go
00009_ooool00ol0003oooooooooo`1Vooooo`;o00001Oooool00ol0003oooooooooo`01ooooo`00
3_ooool01?o^k^koA4A4o`000?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h03Oooool3o`0002Ko
oooo00?o0000ooooooooool0J?ooool2o`0000?ooooo00?o0000ooooooooool00Oooool000oooooo
00?oMgMgo`000?ooool02_ooool00onHV9So8B4Qonk^kP0?ooooo`?o00008oooool00ol0003ooooo
ooooo`1Zooooo`Co00000oooool001gooooo00?oMgMgofIVI_ooool04Oooool3o`00023ooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`05o`0000?ooooo000Nooooo`03o`000?oooooo
oooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`Go00006oooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo00;ooooo2Ol00008ooooo`006_ooool01Ol0003o^[ZjoooooonH
V9So410@00Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`Go00006Oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002?l000000ooooooo0000
ooooo`0>ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Sooooo00Go410@oooooooooooo
oooooa0@400=ooooo`Go00005_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00;o
oooo2?l0000Jooooo`009oooool01Ol0003ooooooooooooooooo000000oooooo0ol0000Fooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooool000002?l000000ooooooo0000ooooo`0Oooooo`00
9oooool01Ol0003ooooooooooooooooo000001;ooooo0ol0000Cooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`So0000:oooool002Oooooo
00Go410@oooooooooooooooooa0@4008ooooo`Go00002?ooool4o`0000oooooo00?o0000oooooooo
ool0=?ooool:o`0003?ooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400_ooooo0ol0000=ooooo`03o`000?oooooooooo02Sooooo00Co0000oooo
oooooooooooo2Ol0000eooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool002Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP09ooooo`03oiRHV?lQ8B7ok^k^00kooooo1?l0000:ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Wo0000@Ooo
ool00omgMgOo<S8booooo`01ooooo`00=_ooool00onHV9So8B4Qonk^kP0@ooooo`Co00001oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wo0000B_ooool1o`00007ooooo0Oooool0
03Oooooo00?oMgMgofIVI_ooool02?ooool2o`000003oa0@4?oooooooooo00Gooooo0_l000001?oo
oooo0000o`000?l00002ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool9
o`0002[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01;ooooo00?o
MgMgoc8b<_ooool00Oooool003Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000002?l0000booooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool03_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo000dooooo`05o`000?nj
^[[ooooooiRHV?l@41001oooool5o`0000_ooooo1Ol00003ooooo`Wo0000??ooool00onHV9So8B4Q
onk^kP0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool003Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c007ooooo`04odA4A?oMgMgoooooo`0000oooooo1Ol00016ooooo`03
oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool03_ooool00ol0003oooooooooo`04ooooo`00
@?ooool01?oMgMgoEEEEooooool00014ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00omg
MgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool4o`0000?ooooo0011oooo
o`03ogMgMoo<c<co000004Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool06?ooool0047ooooo00?ok^k^odA4A?l00000A?ooool01Ol@
413ooooooooooooooooo410@00oooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo01Sooooo0012ooooo`03ogMgMol0003ooooo02?ooooo1Ol00005ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00[ooooo00Go0000ooooooooooooooooo`00000?ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`03?ooool4o`0001Oooooo001Xooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool02Oooool01Ol0003ooooooooooooooooo0000
03_ooooo001Pooooo`Ko00000oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00So
oooo00Go410@oooooooooooooooooa0@400kooooo`00J_ooool00onHV9So8B4Qonk^kP0?ooooo`03
ogMgMolb<S;ooooo00Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0kooooo`00Joooool00omgMgOo
IVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^03_ooooo001/ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0C?ooool006So
oooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo04cooooo001Xooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0004_ooooo0038ooooo`00b?ooool00<Sooooo0038
ooooo`00b?ooool00<Sooooo0038ooooo`00b?ooool00<Sooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 237.375}, {310, 110.375}} -> {0.100534, \
0.604708, 0.00241211, 0.00543233}}]
}, Open  ]],

Cell[TextData[StyleBox["Numerical solutions: NDSolve", "Subsubsection"]], \
"Text"],

Cell["\<\
The NDSolve function can be used to create phase plane pictures. If \
the equation is autonomous, tangent vectors can also be displayed using \
PlotVectorField. The display of several trajectories in the vector field is \
called a  \"flow\". \
\>", "Text"],

Cell["\<\
The following entry shows how to create the vector field, F, \
associated with the differential equation named D1.\
\>", "Text"],

Cell[CellGroupData[{

Cell["DE1", "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(y[t]\), "+", 
        RowBox[{"0.2`", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
      "0"}]], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["\<\
Note that it begins with two substitutions, the a solve, then \
another substitution.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
DE1/.{y'[t]->v,y[t]->y};
Solve[ %, {y''[t]} ];
F = {v,y''[t]}/.%[[1]]\
\>", "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({v, \(-0.2`\)\ v - 1.`\ y}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["And here is the plot of the vector field F.", "Text"],

Cell["<<Graphics`PlotField`", "Input",
  CellLabel->"In[25]:="],

Cell[CellGroupData[{

Cell["\<\
vf1 = PlotVectorField[ F, {y,-5,5}, {v,-4,4}, Axes->True, 
                       AspectRatio->5/4 ]\
\>", "Input",
  CellLabel->"In[26]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0894352 0.625 0.137131 [
[.14226 .6125 -6 -9 ]
[.14226 .6125 6 0 ]
[.32113 .6125 -6 -9 ]
[.32113 .6125 6 0 ]
[.67887 .6125 -3 -9 ]
[.67887 .6125 3 0 ]
[.85774 .6125 -3 -9 ]
[.85774 .6125 3 0 ]
[.4875 .07647 -12 -4.5 ]
[.4875 .07647 0 4.5 ]
[.4875 .35074 -12 -4.5 ]
[.4875 .35074 0 4.5 ]
[.4875 .89926 -6 -4.5 ]
[.4875 .89926 0 4.5 ]
[.4875 1.17353 -6 -4.5 ]
[.4875 1.17353 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14226 .625 m
.14226 .63125 L
s
[(-4)] .14226 .6125 0 1 Mshowa
.32113 .625 m
.32113 .63125 L
s
[(-2)] .32113 .6125 0 1 Mshowa
.67887 .625 m
.67887 .63125 L
s
[(2)] .67887 .6125 0 1 Mshowa
.85774 .625 m
.85774 .63125 L
s
[(4)] .85774 .6125 0 1 Mshowa
.125 Mabswid
.18698 .625 m
.18698 .62875 L
s
.23169 .625 m
.23169 .62875 L
s
.27641 .625 m
.27641 .62875 L
s
.36585 .625 m
.36585 .62875 L
s
.41056 .625 m
.41056 .62875 L
s
.45528 .625 m
.45528 .62875 L
s
.54472 .625 m
.54472 .62875 L
s
.58944 .625 m
.58944 .62875 L
s
.63415 .625 m
.63415 .62875 L
s
.72359 .625 m
.72359 .62875 L
s
.76831 .625 m
.76831 .62875 L
s
.81302 .625 m
.81302 .62875 L
s
.09754 .625 m
.09754 .62875 L
s
.05282 .625 m
.05282 .62875 L
s
.00811 .625 m
.00811 .62875 L
s
.90246 .625 m
.90246 .62875 L
s
.94718 .625 m
.94718 .62875 L
s
.99189 .625 m
.99189 .62875 L
s
.25 Mabswid
0 .625 m
1 .625 L
s
.5 .07647 m
.50625 .07647 L
s
[(-4)] .4875 .07647 1 0 Mshowa
.5 .35074 m
.50625 .35074 L
s
[(-2)] .4875 .35074 1 0 Mshowa
.5 .89926 m
.50625 .89926 L
s
[(2)] .4875 .89926 1 0 Mshowa
.5 1.17353 m
.50625 1.17353 L
s
[(4)] .4875 1.17353 1 0 Mshowa
.125 Mabswid
.5 .14504 m
.50375 .14504 L
s
.5 .21361 m
.50375 .21361 L
s
.5 .28217 m
.50375 .28217 L
s
.5 .4193 m
.50375 .4193 L
s
.5 .48787 m
.50375 .48787 L
s
.5 .55643 m
.50375 .55643 L
s
.5 .69357 m
.50375 .69357 L
s
.5 .76213 m
.50375 .76213 L
s
.5 .8307 m
.50375 .8307 L
s
.5 .96783 m
.50375 .96783 L
s
.5 1.03639 m
.50375 1.03639 L
s
.5 1.10496 m
.50375 1.10496 L
s
.5 .00791 m
.50375 .00791 L
s
.5 1.24209 m
.50375 1.24209 L
s
.25 Mabswid
.5 0 m
.5 1.25 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.05282 .07647 m
.02381 .14098 L
s
% Start of user PostScript
-5. -4. -5.32442 -3.52959 MAarrowhead1
% End of user PostScript
.05282 .15484 m
.02795 .21807 L
s
% Start of user PostScript
-5. -3.42857 -5.27807 -2.96743 MAarrowhead1
% End of user PostScript
.05282 .2332 m
.0321 .29516 L
s
% Start of user PostScript
-5. -2.85714 -5.23173 -2.40527 MAarrowhead1
% End of user PostScript
.05282 .31156 m
.03624 .37225 L
s
% Start of user PostScript
-5. -2.28571 -5.18538 -1.84311 MAarrowhead1
% End of user PostScript
.05282 .38992 m
.04039 .44934 L
s
% Start of user PostScript
-5. -1.71429 -5.13904 -1.28095 MAarrowhead1
% End of user PostScript
.05282 .46828 m
.04453 .52643 L
s
% Start of user PostScript
-5. -1.14286 -5.09269 -0.718795 MAarrowhead1
% End of user PostScript
.05282 .54664 m
.04868 .60352 L
s
% Start of user PostScript
-5. -0.571429 -5.04635 -0.156636 MAarrowhead1
% End of user PostScript
.05282 .625 m
.05282 .68061 L
s
% Start of user PostScript
-5. 0 -5. 0.405524 MAarrowhead1
% End of user PostScript
.05282 .70336 m
.05697 .7577 L
s
% Start of user PostScript
-5. 0.571429 -4.95365 0.967683 MAarrowhead1
% End of user PostScript
.05282 .78172 m
.06111 .83479 L
s
% Start of user PostScript
-5. 1.14286 -4.90731 1.52984 MAarrowhead1
% End of user PostScript
.05282 .86008 m
.06526 .91188 L
s
% Start of user PostScript
-5. 1.71429 -4.86096 2.092 MAarrowhead1
% End of user PostScript
.05282 .93844 m
.0694 .98897 L
s
% Start of user PostScript
-5. 2.28571 -4.81462 2.65416 MAarrowhead1
% End of user PostScript
.05282 1.0168 m
.07355 1.06606 L
s
% Start of user PostScript
-5. 2.85714 -4.76827 3.21632 MAarrowhead1
% End of user PostScript
.05282 1.09516 m
.07769 1.14315 L
s
% Start of user PostScript
-5. 3.42857 -4.72193 3.77848 MAarrowhead1
% End of user PostScript
.05282 1.17353 m
.08184 1.22024 L
s
% Start of user PostScript
-5. 4. -4.67558 4.34064 MAarrowhead1
% End of user PostScript
.11671 .07647 m
.08769 .13304 L
s
% Start of user PostScript
-4.28571 -4. -4.61013 -3.58752 MAarrowhead1
% End of user PostScript
.11671 .15484 m
.09184 .21013 L
s
% Start of user PostScript
-4.28571 -3.42857 -4.56379 -3.02537 MAarrowhead1
% End of user PostScript
.11671 .2332 m
.09598 .28722 L
s
% Start of user PostScript
-4.28571 -2.85714 -4.51744 -2.46321 MAarrowhead1
% End of user PostScript
.11671 .31156 m
.10013 .36431 L
s
% Start of user PostScript
-4.28571 -2.28571 -4.4711 -1.90105 MAarrowhead1
% End of user PostScript
.11671 .38992 m
.10427 .4414 L
s
% Start of user PostScript
-4.28571 -1.71429 -4.42475 -1.33889 MAarrowhead1
% End of user PostScript
.11671 .46828 m
.10842 .51849 L
s
% Start of user PostScript
-4.28571 -1.14286 -4.37841 -0.776727 MAarrowhead1
% End of user PostScript
.11671 .54664 m
.11256 .59558 L
s
% Start of user PostScript
-4.28571 -0.571429 -4.33206 -0.214568 MAarrowhead1
% End of user PostScript
.11671 .625 m
.11671 .67267 L
s
% Start of user PostScript
-4.28571 0 -4.28571 0.347592 MAarrowhead1
% End of user PostScript
.11671 .70336 m
.12085 .74976 L
s
% Start of user PostScript
-4.28571 0.571429 -4.23937 0.909751 MAarrowhead1
% End of user PostScript
.11671 .78172 m
.125 .82685 L
s
% Start of user PostScript
-4.28571 1.14286 -4.19302 1.47191 MAarrowhead1
% End of user PostScript
.11671 .86008 m
.12914 .90393 L
s
% Start of user PostScript
-4.28571 1.71429 -4.14668 2.03407 MAarrowhead1
% End of user PostScript
.11671 .93844 m
.13329 .98102 L
s
% Start of user PostScript
-4.28571 2.28571 -4.10033 2.59623 MAarrowhead1
% End of user PostScript
.11671 1.0168 m
.13743 1.05811 L
s
% Start of user PostScript
-4.28571 2.85714 -4.05399 3.15839 MAarrowhead1
% End of user PostScript
.11671 1.09516 m
.14158 1.1352 L
s
% Start of user PostScript
-4.28571 3.42857 -4.00764 3.72055 MAarrowhead1
% End of user PostScript
.11671 1.17353 m
.14572 1.21229 L
s
% Start of user PostScript
-4.28571 4. -3.9613 4.28271 MAarrowhead1
% End of user PostScript
.18059 .07647 m
.15157 .12509 L
s
% Start of user PostScript
-3.57143 -4. -3.89585 -3.64546 MAarrowhead1
% End of user PostScript
.18059 .15484 m
.15572 .20218 L
s
% Start of user PostScript
-3.57143 -3.42857 -3.8495 -3.0833 MAarrowhead1
% End of user PostScript
.18059 .2332 m
.15986 .27927 L
s
% Start of user PostScript
-3.57143 -2.85714 -3.80316 -2.52114 MAarrowhead1
% End of user PostScript
.18059 .31156 m
.16401 .35636 L
s
% Start of user PostScript
-3.57143 -2.28571 -3.75681 -1.95898 MAarrowhead1
% End of user PostScript
.18059 .38992 m
.16815 .43345 L
s
% Start of user PostScript
-3.57143 -1.71429 -3.71047 -1.39682 MAarrowhead1
% End of user PostScript
.18059 .46828 m
.1723 .51054 L
s
% Start of user PostScript
-3.57143 -1.14286 -3.66412 -0.834659 MAarrowhead1
% End of user PostScript
.18059 .54664 m
.17644 .58763 L
s
% Start of user PostScript
-3.57143 -0.571429 -3.61777 -0.2725 MAarrowhead1
% End of user PostScript
.18059 .625 m
.18059 .66472 L
s
% Start of user PostScript
-3.57143 0 -3.57143 0.28966 MAarrowhead1
% End of user PostScript
.18059 .70336 m
.18473 .74181 L
s
% Start of user PostScript
-3.57143 0.571429 -3.52508 0.851819 MAarrowhead1
% End of user PostScript
.18059 .78172 m
.18888 .8189 L
s
% Start of user PostScript
-3.57143 1.14286 -3.47874 1.41398 MAarrowhead1
% End of user PostScript
.18059 .86008 m
.19302 .89599 L
s
% Start of user PostScript
-3.57143 1.71429 -3.43239 1.97614 MAarrowhead1
% End of user PostScript
.18059 .93844 m
.19717 .97308 L
s
% Start of user PostScript
-3.57143 2.28571 -3.38605 2.5383 MAarrowhead1
% End of user PostScript
.18059 1.0168 m
.20131 1.05017 L
s
% Start of user PostScript
-3.57143 2.85714 -3.3397 3.10046 MAarrowhead1
% End of user PostScript
.18059 1.09516 m
.20546 1.12726 L
s
% Start of user PostScript
-3.57143 3.42857 -3.29336 3.66262 MAarrowhead1
% End of user PostScript
.18059 1.17353 m
.2096 1.20435 L
s
% Start of user PostScript
-3.57143 4. -3.24701 4.22478 MAarrowhead1
% End of user PostScript
.24447 .07647 m
.21546 .11715 L
s
% Start of user PostScript
-2.85714 -4. -3.18156 -3.70339 MAarrowhead1
% End of user PostScript
.24447 .15484 m
.2196 .19424 L
s
% Start of user PostScript
-2.85714 -3.42857 -3.13522 -3.14123 MAarrowhead1
% End of user PostScript
.24447 .2332 m
.22375 .27133 L
s
% Start of user PostScript
-2.85714 -2.85714 -3.08887 -2.57907 MAarrowhead1
% End of user PostScript
.24447 .31156 m
.22789 .34842 L
s
% Start of user PostScript
-2.85714 -2.28571 -3.04253 -2.01691 MAarrowhead1
% End of user PostScript
.24447 .38992 m
.23204 .42551 L
s
% Start of user PostScript
-2.85714 -1.71429 -2.99618 -1.45475 MAarrowhead1
% End of user PostScript
.24447 .46828 m
.23618 .5026 L
s
% Start of user PostScript
-2.85714 -1.14286 -2.94983 -0.892591 MAarrowhead1
% End of user PostScript
.24447 .54664 m
.24033 .57969 L
s
% Start of user PostScript
-2.85714 -0.571429 -2.90349 -0.330432 MAarrowhead1
% End of user PostScript
.24447 .625 m
.24447 .65678 L
s
% Start of user PostScript
-2.85714 0 -2.85714 0.231728 MAarrowhead1
% End of user PostScript
.24447 .70336 m
.24862 .73387 L
s
% Start of user PostScript
-2.85714 0.571429 -2.8108 0.793887 MAarrowhead1
% End of user PostScript
.24447 .78172 m
.25276 .81096 L
s
% Start of user PostScript
-2.85714 1.14286 -2.76445 1.35605 MAarrowhead1
% End of user PostScript
.24447 .86008 m
.25691 .88805 L
s
% Start of user PostScript
-2.85714 1.71429 -2.71811 1.91821 MAarrowhead1
% End of user PostScript
.24447 .93844 m
.26105 .96514 L
s
% Start of user PostScript
-2.85714 2.28571 -2.67176 2.48037 MAarrowhead1
% End of user PostScript
.24447 1.0168 m
.2652 1.04223 L
s
% Start of user PostScript
-2.85714 2.85714 -2.62542 3.04253 MAarrowhead1
% End of user PostScript
.24447 1.09516 m
.26934 1.11932 L
s
% Start of user PostScript
-2.85714 3.42857 -2.57907 3.60468 MAarrowhead1
% End of user PostScript
.24447 1.17353 m
.27349 1.19641 L
s
% Start of user PostScript
-2.85714 4. -2.53272 4.16684 MAarrowhead1
% End of user PostScript
.30835 .07647 m
.27934 .1092 L
s
% Start of user PostScript
-2.14286 -4. -2.46728 -3.76132 MAarrowhead1
% End of user PostScript
.30835 .15484 m
.28348 .18629 L
s
% Start of user PostScript
-2.14286 -3.42857 -2.42093 -3.19916 MAarrowhead1
% End of user PostScript
.30835 .2332 m
.28763 .26338 L
s
% Start of user PostScript
-2.14286 -2.85714 -2.37458 -2.637 MAarrowhead1
% End of user PostScript
.30835 .31156 m
.29177 .34047 L
s
% Start of user PostScript
-2.14286 -2.28571 -2.32824 -2.07484 MAarrowhead1
% End of user PostScript
.30835 .38992 m
.29592 .41756 L
s
% Start of user PostScript
-2.14286 -1.71429 -2.28189 -1.51268 MAarrowhead1
% End of user PostScript
.30835 .46828 m
.30006 .49465 L
s
% Start of user PostScript
-2.14286 -1.14286 -2.23555 -0.950523 MAarrowhead1
% End of user PostScript
.30835 .54664 m
.30421 .57174 L
s
% Start of user PostScript
-2.14286 -0.571429 -2.1892 -0.388364 MAarrowhead1
% End of user PostScript
.30835 .625 m
.30835 .64883 L
s
% Start of user PostScript
-2.14286 0 -2.14286 0.173796 MAarrowhead1
% End of user PostScript
.30835 .70336 m
.3125 .72592 L
s
% Start of user PostScript
-2.14286 0.571429 -2.09651 0.735955 MAarrowhead1
% End of user PostScript
.30835 .78172 m
.31664 .80301 L
s
% Start of user PostScript
-2.14286 1.14286 -2.05017 1.29811 MAarrowhead1
% End of user PostScript
.30835 .86008 m
.32079 .8801 L
s
% Start of user PostScript
-2.14286 1.71429 -2.00382 1.86027 MAarrowhead1
% End of user PostScript
.30835 .93844 m
.32493 .95719 L
s
% Start of user PostScript
-2.14286 2.28571 -1.95747 2.42243 MAarrowhead1
% End of user PostScript
.30835 1.0168 m
.32908 1.03428 L
s
% Start of user PostScript
-2.14286 2.85714 -1.91113 2.98459 MAarrowhead1
% End of user PostScript
.30835 1.09516 m
.33322 1.11137 L
s
% Start of user PostScript
-2.14286 3.42857 -1.86478 3.54675 MAarrowhead1
% End of user PostScript
.30835 1.17353 m
.33737 1.18846 L
s
% Start of user PostScript
-2.14286 4. -1.81844 4.10891 MAarrowhead1
% End of user PostScript
.37224 .07647 m
.34322 .10126 L
s
% Start of user PostScript
-1.42857 -4. -1.75299 -3.81925 MAarrowhead1
% End of user PostScript
.37224 .15484 m
.34737 .17835 L
s
% Start of user PostScript
-1.42857 -3.42857 -1.70664 -3.25709 MAarrowhead1
% End of user PostScript
.37224 .2332 m
.35151 .25544 L
s
% Start of user PostScript
-1.42857 -2.85714 -1.6603 -2.69493 MAarrowhead1
% End of user PostScript
.37224 .31156 m
.35566 .33253 L
s
% Start of user PostScript
-1.42857 -2.28571 -1.61395 -2.13277 MAarrowhead1
% End of user PostScript
.37224 .38992 m
.3598 .40962 L
s
% Start of user PostScript
-1.42857 -1.71429 -1.56761 -1.57061 MAarrowhead1
% End of user PostScript
.37224 .46828 m
.36395 .48671 L
s
% Start of user PostScript
-1.42857 -1.14286 -1.52126 -1.00846 MAarrowhead1
% End of user PostScript
.37224 .54664 m
.36809 .5638 L
s
% Start of user PostScript
-1.42857 -0.571429 -1.47492 -0.446296 MAarrowhead1
% End of user PostScript
.37224 .625 m
.37224 .64089 L
s
% Start of user PostScript
-1.42857 0 -1.42857 0.115864 MAarrowhead1
% End of user PostScript
.37224 .70336 m
.37638 .71798 L
s
% Start of user PostScript
-1.42857 0.571429 -1.38223 0.678023 MAarrowhead1
% End of user PostScript
.37224 .78172 m
.38053 .79507 L
s
% Start of user PostScript
-1.42857 1.14286 -1.33588 1.24018 MAarrowhead1
% End of user PostScript
.37224 .86008 m
.38467 .87216 L
s
% Start of user PostScript
-1.42857 1.71429 -1.28953 1.80234 MAarrowhead1
% End of user PostScript
.37224 .93844 m
.38882 .94925 L
s
% Start of user PostScript
-1.42857 2.28571 -1.24319 2.3645 MAarrowhead1
% End of user PostScript
.37224 1.0168 m
.39296 1.02634 L
s
% Start of user PostScript
-1.42857 2.85714 -1.19684 2.92666 MAarrowhead1
% End of user PostScript
.37224 1.09516 m
.3971 1.10343 L
s
% Start of user PostScript
-1.42857 3.42857 -1.1505 3.48882 MAarrowhead1
% End of user PostScript
.37224 1.17353 m
.40125 1.18052 L
s
% Start of user PostScript
-1.42857 4. -1.10415 4.05098 MAarrowhead1
% End of user PostScript
.43612 .07647 m
.4071 .09332 L
s
% Start of user PostScript
-0.714286 -4. -1.0387 -3.87718 MAarrowhead1
% End of user PostScript
.43612 .15484 m
.41125 .17041 L
s
% Start of user PostScript
-0.714286 -3.42857 -0.992359 -3.31502 MAarrowhead1
% End of user PostScript
.43612 .2332 m
.41539 .2475 L
s
% Start of user PostScript
-0.714286 -2.85714 -0.946013 -2.75287 MAarrowhead1
% End of user PostScript
.43612 .31156 m
.41954 .32459 L
s
% Start of user PostScript
-0.714286 -2.28571 -0.899668 -2.19071 MAarrowhead1
% End of user PostScript
.43612 .38992 m
.42368 .40168 L
s
% Start of user PostScript
-0.714286 -1.71429 -0.853322 -1.62855 MAarrowhead1
% End of user PostScript
.43612 .46828 m
.42783 .47876 L
s
% Start of user PostScript
-0.714286 -1.14286 -0.806977 -1.06639 MAarrowhead1
% End of user PostScript
.43612 .54664 m
.43197 .55585 L
s
% Start of user PostScript
-0.714286 -0.571429 -0.760631 -0.504228 MAarrowhead1
% End of user PostScript
.43612 .625 m
.43612 .63294 L
s
% Start of user PostScript
-0.714286 0 -0.714286 0.0579319 MAarrowhead1
% End of user PostScript
.43612 .70336 m
.44026 .71003 L
s
% Start of user PostScript
-0.714286 0.571429 -0.66794 0.620091 MAarrowhead1
% End of user PostScript
.43612 .78172 m
.44441 .78712 L
s
% Start of user PostScript
-0.714286 1.14286 -0.621595 1.18225 MAarrowhead1
% End of user PostScript
.43612 .86008 m
.44855 .86421 L
s
% Start of user PostScript
-0.714286 1.71429 -0.575249 1.74441 MAarrowhead1
% End of user PostScript
.43612 .93844 m
.4527 .9413 L
s
% Start of user PostScript
-0.714286 2.28571 -0.528904 2.30657 MAarrowhead1
% End of user PostScript
.43612 1.0168 m
.45684 1.01839 L
s
% Start of user PostScript
-0.714286 2.85714 -0.482558 2.86873 MAarrowhead1
% End of user PostScript
.43612 1.09516 m
.46099 1.09548 L
s
% Start of user PostScript
-0.714286 3.42857 -0.436212 3.43089 MAarrowhead1
% End of user PostScript
.43612 1.17353 m
.46513 1.17257 L
s
% Start of user PostScript
-0.714286 4. -0.389867 3.99305 MAarrowhead1
% End of user PostScript
.5 .07647 m
.47099 .08537 L
s
% Start of user PostScript
0 -4. -0.324419 -3.93512 MAarrowhead1
% End of user PostScript
.5 .15484 m
.47513 .16246 L
s
% Start of user PostScript
0 -3.42857 -0.278073 -3.37296 MAarrowhead1
% End of user PostScript
.5 .2332 m
.47928 .23955 L
s
% Start of user PostScript
0 -2.85714 -0.231728 -2.8108 MAarrowhead1
% End of user PostScript
.5 .31156 m
.48342 .31664 L
s
% Start of user PostScript
0 -2.28571 -0.185382 -2.24864 MAarrowhead1
% End of user PostScript
.5 .38992 m
.48757 .39373 L
s
% Start of user PostScript
0 -1.71429 -0.139037 -1.68648 MAarrowhead1
% End of user PostScript
.5 .46828 m
.49171 .47082 L
s
% Start of user PostScript
0 -1.14286 -0.0926911 -1.12432 MAarrowhead1
% End of user PostScript
.5 .54664 m
.49586 .54791 L
s
% Start of user PostScript
0 -0.571429 -0.0463455 -0.562159 MAarrowhead1
% End of user PostScript
.5 .625 m
.5 .625 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .70336 m
.50414 .70209 L
s
% Start of user PostScript
0 0.571429 0.0463455 0.562159 MAarrowhead1
% End of user PostScript
.5 .78172 m
.50829 .77918 L
s
% Start of user PostScript
0 1.14286 0.0926911 1.12432 MAarrowhead1
% End of user PostScript
.5 .86008 m
.51243 .85627 L
s
% Start of user PostScript
0 1.71429 0.139037 1.68648 MAarrowhead1
% End of user PostScript
.5 .93844 m
.51658 .93336 L
s
% Start of user PostScript
0 2.28571 0.185382 2.24864 MAarrowhead1
% End of user PostScript
.5 1.0168 m
.52072 1.01045 L
s
% Start of user PostScript
0 2.85714 0.231728 2.8108 MAarrowhead1
% End of user PostScript
.5 1.09516 m
.52487 1.08754 L
s
% Start of user PostScript
0 3.42857 0.278073 3.37296 MAarrowhead1
% End of user PostScript
.5 1.17353 m
.52901 1.16463 L
s
% Start of user PostScript
0 4. 0.324419 3.93512 MAarrowhead1
% End of user PostScript
.56388 .07647 m
.53487 .07743 L
s
% Start of user PostScript
0.714286 -4. 0.389867 -3.99305 MAarrowhead1
% End of user PostScript
.56388 .15484 m
.53901 .15452 L
s
% Start of user PostScript
0.714286 -3.42857 0.436212 -3.43089 MAarrowhead1
% End of user PostScript
.56388 .2332 m
.54316 .23161 L
s
% Start of user PostScript
0.714286 -2.85714 0.482558 -2.86873 MAarrowhead1
% End of user PostScript
.56388 .31156 m
.5473 .3087 L
s
% Start of user PostScript
0.714286 -2.28571 0.528904 -2.30657 MAarrowhead1
% End of user PostScript
.56388 .38992 m
.55145 .38579 L
s
% Start of user PostScript
0.714286 -1.71429 0.575249 -1.74441 MAarrowhead1
% End of user PostScript
.56388 .46828 m
.55559 .46288 L
s
% Start of user PostScript
0.714286 -1.14286 0.621595 -1.18225 MAarrowhead1
% End of user PostScript
.56388 .54664 m
.55974 .53997 L
s
% Start of user PostScript
0.714286 -0.571429 0.66794 -0.620091 MAarrowhead1
% End of user PostScript
.56388 .625 m
.56388 .61706 L
s
% Start of user PostScript
0.714286 0 0.714286 -0.0579319 MAarrowhead1
% End of user PostScript
.56388 .70336 m
.56803 .69415 L
s
% Start of user PostScript
0.714286 0.571429 0.760631 0.504228 MAarrowhead1
% End of user PostScript
.56388 .78172 m
.57217 .77124 L
s
% Start of user PostScript
0.714286 1.14286 0.806977 1.06639 MAarrowhead1
% End of user PostScript
.56388 .86008 m
.57632 .84832 L
s
% Start of user PostScript
0.714286 1.71429 0.853322 1.62855 MAarrowhead1
% End of user PostScript
.56388 .93844 m
.58046 .92541 L
s
% Start of user PostScript
0.714286 2.28571 0.899668 2.19071 MAarrowhead1
% End of user PostScript
.56388 1.0168 m
.58461 1.0025 L
s
% Start of user PostScript
0.714286 2.85714 0.946013 2.75287 MAarrowhead1
% End of user PostScript
.56388 1.09516 m
.58875 1.07959 L
s
% Start of user PostScript
0.714286 3.42857 0.992359 3.31502 MAarrowhead1
% End of user PostScript
.56388 1.17353 m
.5929 1.15668 L
s
% Start of user PostScript
0.714286 4. 1.0387 3.87718 MAarrowhead1
% End of user PostScript
.62776 .07647 m
.59875 .06948 L
s
% Start of user PostScript
1.42857 -4. 1.10415 -4.05098 MAarrowhead1
% End of user PostScript
.62776 .15484 m
.6029 .14657 L
s
% Start of user PostScript
1.42857 -3.42857 1.1505 -3.48882 MAarrowhead1
% End of user PostScript
.62776 .2332 m
.60704 .22366 L
s
% Start of user PostScript
1.42857 -2.85714 1.19684 -2.92666 MAarrowhead1
% End of user PostScript
.62776 .31156 m
.61118 .30075 L
s
% Start of user PostScript
1.42857 -2.28571 1.24319 -2.3645 MAarrowhead1
% End of user PostScript
.62776 .38992 m
.61533 .37784 L
s
% Start of user PostScript
1.42857 -1.71429 1.28953 -1.80234 MAarrowhead1
% End of user PostScript
.62776 .46828 m
.61947 .45493 L
s
% Start of user PostScript
1.42857 -1.14286 1.33588 -1.24018 MAarrowhead1
% End of user PostScript
.62776 .54664 m
.62362 .53202 L
s
% Start of user PostScript
1.42857 -0.571429 1.38223 -0.678023 MAarrowhead1
% End of user PostScript
.62776 .625 m
.62776 .60911 L
s
% Start of user PostScript
1.42857 0 1.42857 -0.115864 MAarrowhead1
% End of user PostScript
.62776 .70336 m
.63191 .6862 L
s
% Start of user PostScript
1.42857 0.571429 1.47492 0.446296 MAarrowhead1
% End of user PostScript
.62776 .78172 m
.63605 .76329 L
s
% Start of user PostScript
1.42857 1.14286 1.52126 1.00846 MAarrowhead1
% End of user PostScript
.62776 .86008 m
.6402 .84038 L
s
% Start of user PostScript
1.42857 1.71429 1.56761 1.57061 MAarrowhead1
% End of user PostScript
.62776 .93844 m
.64434 .91747 L
s
% Start of user PostScript
1.42857 2.28571 1.61395 2.13277 MAarrowhead1
% End of user PostScript
.62776 1.0168 m
.64849 .99456 L
s
% Start of user PostScript
1.42857 2.85714 1.6603 2.69493 MAarrowhead1
% End of user PostScript
.62776 1.09516 m
.65263 1.07165 L
s
% Start of user PostScript
1.42857 3.42857 1.70664 3.25709 MAarrowhead1
% End of user PostScript
.62776 1.17353 m
.65678 1.14874 L
s
% Start of user PostScript
1.42857 4. 1.75299 3.81925 MAarrowhead1
% End of user PostScript
.69165 .07647 m
.66263 .06154 L
s
% Start of user PostScript
2.14286 -4. 1.81844 -4.10891 MAarrowhead1
% End of user PostScript
.69165 .15484 m
.66678 .13863 L
s
% Start of user PostScript
2.14286 -3.42857 1.86478 -3.54675 MAarrowhead1
% End of user PostScript
.69165 .2332 m
.67092 .21572 L
s
% Start of user PostScript
2.14286 -2.85714 1.91113 -2.98459 MAarrowhead1
% End of user PostScript
.69165 .31156 m
.67507 .29281 L
s
% Start of user PostScript
2.14286 -2.28571 1.95747 -2.42243 MAarrowhead1
% End of user PostScript
.69165 .38992 m
.67921 .3699 L
s
% Start of user PostScript
2.14286 -1.71429 2.00382 -1.86027 MAarrowhead1
% End of user PostScript
.69165 .46828 m
.68336 .44699 L
s
% Start of user PostScript
2.14286 -1.14286 2.05017 -1.29811 MAarrowhead1
% End of user PostScript
.69165 .54664 m
.6875 .52408 L
s
% Start of user PostScript
2.14286 -0.571429 2.09651 -0.735955 MAarrowhead1
% End of user PostScript
.69165 .625 m
.69165 .60117 L
s
% Start of user PostScript
2.14286 0 2.14286 -0.173796 MAarrowhead1
% End of user PostScript
.69165 .70336 m
.69579 .67826 L
s
% Start of user PostScript
2.14286 0.571429 2.1892 0.388364 MAarrowhead1
% End of user PostScript
.69165 .78172 m
.69994 .75535 L
s
% Start of user PostScript
2.14286 1.14286 2.23555 0.950523 MAarrowhead1
% End of user PostScript
.69165 .86008 m
.70408 .83244 L
s
% Start of user PostScript
2.14286 1.71429 2.28189 1.51268 MAarrowhead1
% End of user PostScript
.69165 .93844 m
.70823 .90953 L
s
% Start of user PostScript
2.14286 2.28571 2.32824 2.07484 MAarrowhead1
% End of user PostScript
.69165 1.0168 m
.71237 .98662 L
s
% Start of user PostScript
2.14286 2.85714 2.37458 2.637 MAarrowhead1
% End of user PostScript
.69165 1.09516 m
.71652 1.06371 L
s
% Start of user PostScript
2.14286 3.42857 2.42093 3.19916 MAarrowhead1
% End of user PostScript
.69165 1.17353 m
.72066 1.1408 L
s
% Start of user PostScript
2.14286 4. 2.46728 3.76132 MAarrowhead1
% End of user PostScript
.75553 .07647 m
.72651 .05359 L
s
% Start of user PostScript
2.85714 -4. 2.53272 -4.16684 MAarrowhead1
% End of user PostScript
.75553 .15484 m
.73066 .13068 L
s
% Start of user PostScript
2.85714 -3.42857 2.57907 -3.60468 MAarrowhead1
% End of user PostScript
.75553 .2332 m
.7348 .20777 L
s
% Start of user PostScript
2.85714 -2.85714 2.62542 -3.04253 MAarrowhead1
% End of user PostScript
.75553 .31156 m
.73895 .28486 L
s
% Start of user PostScript
2.85714 -2.28571 2.67176 -2.48037 MAarrowhead1
% End of user PostScript
.75553 .38992 m
.74309 .36195 L
s
% Start of user PostScript
2.85714 -1.71429 2.71811 -1.91821 MAarrowhead1
% End of user PostScript
.75553 .46828 m
.74724 .43904 L
s
% Start of user PostScript
2.85714 -1.14286 2.76445 -1.35605 MAarrowhead1
% End of user PostScript
.75553 .54664 m
.75138 .51613 L
s
% Start of user PostScript
2.85714 -0.571429 2.8108 -0.793887 MAarrowhead1
% End of user PostScript
.75553 .625 m
.75553 .59322 L
s
% Start of user PostScript
2.85714 0 2.85714 -0.231728 MAarrowhead1
% End of user PostScript
.75553 .70336 m
.75967 .67031 L
s
% Start of user PostScript
2.85714 0.571429 2.90349 0.330432 MAarrowhead1
% End of user PostScript
.75553 .78172 m
.76382 .7474 L
s
% Start of user PostScript
2.85714 1.14286 2.94983 0.892591 MAarrowhead1
% End of user PostScript
.75553 .86008 m
.76796 .82449 L
s
% Start of user PostScript
2.85714 1.71429 2.99618 1.45475 MAarrowhead1
% End of user PostScript
.75553 .93844 m
.77211 .90158 L
s
% Start of user PostScript
2.85714 2.28571 3.04253 2.01691 MAarrowhead1
% End of user PostScript
.75553 1.0168 m
.77625 .97867 L
s
% Start of user PostScript
2.85714 2.85714 3.08887 2.57907 MAarrowhead1
% End of user PostScript
.75553 1.09516 m
.7804 1.05576 L
s
% Start of user PostScript
2.85714 3.42857 3.13522 3.14123 MAarrowhead1
% End of user PostScript
.75553 1.17353 m
.78454 1.13285 L
s
% Start of user PostScript
2.85714 4. 3.18156 3.70339 MAarrowhead1
% End of user PostScript
.81941 .07647 m
.7904 .04565 L
s
% Start of user PostScript
3.57143 -4. 3.24701 -4.22478 MAarrowhead1
% End of user PostScript
.81941 .15484 m
.79454 .12274 L
s
% Start of user PostScript
3.57143 -3.42857 3.29336 -3.66262 MAarrowhead1
% End of user PostScript
.81941 .2332 m
.79869 .19983 L
s
% Start of user PostScript
3.57143 -2.85714 3.3397 -3.10046 MAarrowhead1
% End of user PostScript
.81941 .31156 m
.80283 .27692 L
s
% Start of user PostScript
3.57143 -2.28571 3.38605 -2.5383 MAarrowhead1
% End of user PostScript
.81941 .38992 m
.80698 .35401 L
s
% Start of user PostScript
3.57143 -1.71429 3.43239 -1.97614 MAarrowhead1
% End of user PostScript
.81941 .46828 m
.81112 .4311 L
s
% Start of user PostScript
3.57143 -1.14286 3.47874 -1.41398 MAarrowhead1
% End of user PostScript
.81941 .54664 m
.81527 .50819 L
s
% Start of user PostScript
3.57143 -0.571429 3.52508 -0.851819 MAarrowhead1
% End of user PostScript
.81941 .625 m
.81941 .58528 L
s
% Start of user PostScript
3.57143 0 3.57143 -0.28966 MAarrowhead1
% End of user PostScript
.81941 .70336 m
.82356 .66237 L
s
% Start of user PostScript
3.57143 0.571429 3.61777 0.2725 MAarrowhead1
% End of user PostScript
.81941 .78172 m
.8277 .73946 L
s
% Start of user PostScript
3.57143 1.14286 3.66412 0.834659 MAarrowhead1
% End of user PostScript
.81941 .86008 m
.83185 .81655 L
s
% Start of user PostScript
3.57143 1.71429 3.71047 1.39682 MAarrowhead1
% End of user PostScript
.81941 .93844 m
.83599 .89364 L
s
% Start of user PostScript
3.57143 2.28571 3.75681 1.95898 MAarrowhead1
% End of user PostScript
.81941 1.0168 m
.84014 .97073 L
s
% Start of user PostScript
3.57143 2.85714 3.80316 2.52114 MAarrowhead1
% End of user PostScript
.81941 1.09516 m
.84428 1.04782 L
s
% Start of user PostScript
3.57143 3.42857 3.8495 3.0833 MAarrowhead1
% End of user PostScript
.81941 1.17353 m
.84843 1.12491 L
s
% Start of user PostScript
3.57143 4. 3.89585 3.64546 MAarrowhead1
% End of user PostScript
.88329 .07647 m
.85428 .03771 L
s
% Start of user PostScript
4.28571 -4. 3.9613 -4.28271 MAarrowhead1
% End of user PostScript
.88329 .15484 m
.85842 .1148 L
s
% Start of user PostScript
4.28571 -3.42857 4.00764 -3.72055 MAarrowhead1
% End of user PostScript
.88329 .2332 m
.86257 .19189 L
s
% Start of user PostScript
4.28571 -2.85714 4.05399 -3.15839 MAarrowhead1
% End of user PostScript
.88329 .31156 m
.86671 .26898 L
s
% Start of user PostScript
4.28571 -2.28571 4.10033 -2.59623 MAarrowhead1
% End of user PostScript
.88329 .38992 m
.87086 .34607 L
s
% Start of user PostScript
4.28571 -1.71429 4.14668 -2.03407 MAarrowhead1
% End of user PostScript
.88329 .46828 m
.875 .42315 L
s
% Start of user PostScript
4.28571 -1.14286 4.19302 -1.47191 MAarrowhead1
% End of user PostScript
.88329 .54664 m
.87915 .50024 L
s
% Start of user PostScript
4.28571 -0.571429 4.23937 -0.909751 MAarrowhead1
% End of user PostScript
.88329 .625 m
.88329 .57733 L
s
% Start of user PostScript
4.28571 0 4.28571 -0.347592 MAarrowhead1
% End of user PostScript
.88329 .70336 m
.88744 .65442 L
s
% Start of user PostScript
4.28571 0.571429 4.33206 0.214568 MAarrowhead1
% End of user PostScript
.88329 .78172 m
.89158 .73151 L
s
% Start of user PostScript
4.28571 1.14286 4.37841 0.776727 MAarrowhead1
% End of user PostScript
.88329 .86008 m
.89573 .8086 L
s
% Start of user PostScript
4.28571 1.71429 4.42475 1.33889 MAarrowhead1
% End of user PostScript
.88329 .93844 m
.89987 .88569 L
s
% Start of user PostScript
4.28571 2.28571 4.4711 1.90105 MAarrowhead1
% End of user PostScript
.88329 1.0168 m
.90402 .96278 L
s
% Start of user PostScript
4.28571 2.85714 4.51744 2.46321 MAarrowhead1
% End of user PostScript
.88329 1.09516 m
.90816 1.03987 L
s
% Start of user PostScript
4.28571 3.42857 4.56379 3.02537 MAarrowhead1
% End of user PostScript
.88329 1.17353 m
.91231 1.11696 L
s
% Start of user PostScript
4.28571 4. 4.61013 3.58752 MAarrowhead1
% End of user PostScript
.94718 .07647 m
.91816 .02976 L
s
% Start of user PostScript
5. -4. 4.67558 -4.34064 MAarrowhead1
% End of user PostScript
.94718 .15484 m
.92231 .10685 L
s
% Start of user PostScript
5. -3.42857 4.72193 -3.77848 MAarrowhead1
% End of user PostScript
.94718 .2332 m
.92645 .18394 L
s
% Start of user PostScript
5. -2.85714 4.76827 -3.21632 MAarrowhead1
% End of user PostScript
.94718 .31156 m
.9306 .26103 L
s
% Start of user PostScript
5. -2.28571 4.81462 -2.65416 MAarrowhead1
% End of user PostScript
.94718 .38992 m
.93474 .33812 L
s
% Start of user PostScript
5. -1.71429 4.86096 -2.092 MAarrowhead1
% End of user PostScript
.94718 .46828 m
.93889 .41521 L
s
% Start of user PostScript
5. -1.14286 4.90731 -1.52984 MAarrowhead1
% End of user PostScript
.94718 .54664 m
.94303 .4923 L
s
% Start of user PostScript
5. -0.571429 4.95365 -0.967683 MAarrowhead1
% End of user PostScript
.94718 .625 m
.94718 .56939 L
s
% Start of user PostScript
5. 0 5. -0.405524 MAarrowhead1
% End of user PostScript
.94718 .70336 m
.95132 .64648 L
s
% Start of user PostScript
5. 0.571429 5.04635 0.156636 MAarrowhead1
% End of user PostScript
.94718 .78172 m
.95547 .72357 L
s
% Start of user PostScript
5. 1.14286 5.09269 0.718795 MAarrowhead1
% End of user PostScript
.94718 .86008 m
.95961 .80066 L
s
% Start of user PostScript
5. 1.71429 5.13904 1.28095 MAarrowhead1
% End of user PostScript
.94718 .93844 m
.96376 .87775 L
s
% Start of user PostScript
5. 2.28571 5.18538 1.84311 MAarrowhead1
% End of user PostScript
.94718 1.0168 m
.9679 .95484 L
s
% Start of user PostScript
5. 2.85714 5.23173 2.40527 MAarrowhead1
% End of user PostScript
.94718 1.09516 m
.97205 1.03193 L
s
% Start of user PostScript
5. 3.42857 5.27807 2.96743 MAarrowhead1
% End of user PostScript
.94718 1.17353 m
.97619 1.10902 L
s
% Start of user PostScript
5. 4. 5.32442 3.52959 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1.25 L
0 1.25 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{159.938, 199.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002O0000ab000`400?l00000o`00003oCoooool0
0ol0003oooooooooo`1=ooooo`00Coooool2o`0004kooooo001?ooooo`03o`000?oooooooooo04go
oooo001?ooooo`03o`000?oooooooooo04gooooo001?ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool02oooool004oooooo00?o0000ooooooooool0?oooool2o`0000cooooo001?oooo
o`03o`000?oooooooooo03Gooooo0_l00008ooooo`?o00002oooool004oooooo00?o0000oooooooo
ool0:oooool2o`0000Sooooo0ol00008ooooo`?o00002_ooool004oooooo00?o0000ooooooooool0
8Oooool2o`0000Sooooo0ol00008ooooo`?o00001oooool2o`0000_ooooo0019ooooo`?o00000ooo
ool00ol0003oooooooooo`0Qooooo`?o00002?ooool3o`0000Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`00B_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Oooooo1?l00007ooooo`?o00002?ooool2o`0000Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`00@Oooool5o`000003ooooool0003o000000?o00000oooool00ol0
003oooooooooo`05ooooo`;o00001_ooool4o`0000Oooooo0ol00008ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool2o`0000Oo
oooo0ol000001_oooooo0000oooooooooooo0000ooooo`Go00001?ooool5o`0000Sooooo0_l00007
ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`;o00002?ooool2o`0000Cooooo00?o0000oooo
ool000001Ol00008ooooo`03o`000?oooooooooo04Cooooo0007ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo0ol00008ooooo`;o00001oooool3o`0000Gooooo0_l00004ooooo`03o`000?oooooooooo04go
oooo0007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`;o00002?ooool3o`0000Oooooo00?o0000ooooooooool01_ooool2o`0000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=ooooo`001_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00001oooool2o`0000Sooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1=ooooo`001_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o00002?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02_ooool000Gooooo00?o0000oooo
ooooool01_ooool3o`0000Sooooo0_l00007ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`07ooooo`;o00002oooool000Cooooo0_l00008ooooo`;o
00002?ooool2o`0003Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`;o
00002Oooool2o`0000[ooooo0004ooooo`;o00001oooool2o`0000Wooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo0_l00009ooooo`;o0000
2?ooool00ol0003oooooooooo`09ooooo`000oooool2o`0000Sooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0Rooooo`;o00002Oooool2o`0000Sooooo0_l00009ooooo`03o`000?oo
oooooooo00Sooooo0003ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05oooool3
o`0000Wooooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo001?ooooo`;o00003_ooool5o`0000Oooooo0ol00007ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`?o00001oooool3o`0000Gooooo1Ol00007ooooo`?o00002?ooool2o`0000[o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01_ooool4o`0000Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0jooooo`001oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooo000000Oooooo0_l00008ooooo`?o00001_ooool2o`0000;ooooo00?o
0000ooooooooool0COooool000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Oooooo1?l00006
ooooo`;o00003?ooool00ol0003oooooooooo`1=ooooo`001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool3o`0000Oooooo0_l00008oooo
o`;o00005_ooool00ol0003oooooooooo`1=ooooo`001_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo0_l00008ooooo`;o00002?ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool0
1_ooool2o`0000Sooooo0_l00007ooooo`;o0000:oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Cooooo0_l00009ooooo`;o00001ooo
ool2o`0000Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool2o`0000[ooooo0004ooooo`?o00001oooool2
o`0000Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0/ooooo`;o00002Oooool2
o`0000Sooooo0ol00009ooooo`001?ooool2o`0000Sooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0Rooooo`;o00002?ooool3o`0000Sooooo0ol00008ooooo`03o`000?oooooooooo
00Sooooo0004ooooo`03o`000?oooooooooo04Sooooo0_l0000Iooooo`;o00002?ooool3o`0000So
oooo0ol00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool004oooooo
00?o0000ooooooooool03_ooool3o`0000Oooooo0ol00008ooooo`?o00001oooool2o`0000[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`00C_ooool2o`0000Sooooo0_l0
0008ooooo`;o00001oooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00001oooool3o`0000Kooooo1?l00009
ooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0008oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07oooo
o`?o00001_ooool4o`0000Wooooo00?o0000ooooooooool0@oooool000Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool3o`0000Oooooo0ol00007ooooo`;o00002oooool00ol0003oooooooooo`1=ooooo`00
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool2o`0000Sooooo0_l00007ooooo`;o00005_ooool00ol0003oooooooooo`1=ooooo`001ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`;o00001ooo
ool2o`00023ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`09ooooo`001oooool0
0ol0003oooooooooo`05ooooo`;o00002?ooool3o`0000Oooooo0_l00008ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo0005ooooo`;o00002?ooool3o`0000Oooooo0_l00008ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`07ooooo`;o00002_ooool000Go
oooo0_l00008ooooo`;o00002?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool01oooool2o`0000Wooooo0_l00009ooooo`001Oooool2o`0000Sooooo
00?o0000ooooooooool0?Oooool2o`0002Cooooo00?o0000ooooooooool01oooool2o`0000Wooooo
0_l00008ooooo`03o`000?oooooooooo00Sooooo0005ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0000Sooooo0_l0
0009ooooo`03o`000?oooooooooo00Oooooo0005ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool06Oooool2o`0000Wooooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo001>ooooo`;o00004Oooool3o`0000Sooooo0_l00008oooo
o`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo0_l00007ooooo`?o00001_ooool5o`0000Oooooo0ol00007ooooo`;o
00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Gooooo0ol00007ooooo`?o00001_ooool5o`0000Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0iooooo`002?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`;o00002?oo
ool3o`0000Kooooo0_l0000;ooooo`03o`000?oooooooooo04gooooo0007ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o00002Oooool2
o`0000Oooooo0_l0000Eooooo`03o`000?oooooooooo04gooooo0007ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool2o`0000Sooooo0ol00007ooooo`;o00002?ooool00ol0
003oooooooooo`0<ooooo`Go00000oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
00Sooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool2o`0000So
oooo0_l00008ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00Oo
oooo0_l00008ooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`Go00000oooool00ol0003o
ooooooooo`03ooooo`;o0000>Oooool00ol0003oooooooooo`07ooooo`;o00002Oooool000Gooooo
0ol00008ooooo`;o00002?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
0ol00008ooooo`001Oooool3o`0000Oooooo0_l0000fooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool2o`0000Sooooo0_l00009ooooo`001Oooool2o`0000Sooooo00?o0000ooooooooool0=Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`07ooooo`;o00002?ooool3o`0000Sooooo00?o0000ooooooooool01oooool000Gooooo00?o
0000ooooooooool0@?ooool3o`0000Cooooo00?o0000ooooooooool06Oooool2o`0000Wooooo0_l0
0008ooooo`?o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo001?
ooooo`03o`000?oooooooooo00oooooo0ol00007ooooo`?o00002?ooool3o`0000Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0015oooo
o`03o`000?oooooooooo00Oooooo0_l00006ooooo`Co00001_ooool4o`0000Oooooo0ol00007oooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`;o
00002Oooool2o`0000Kooooo1?l00008ooooo`;o00001oooool3o`0000Oooooo0_l0000:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0ol00008ooooo`;o0000
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0iooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`?o00001ooo
ool2o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1=ooooo`001oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`;o00002?ooool2
o`0000Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1=ooooo`001oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0ol00007ooooo`;o00002Oooool00ol0
003oooooooooo`0Mooooo`;o0000A?ooool00ol0003oooooooooo`07ooooo`001oooool00ol0003o
ooooooooo`06ooooo`?o00001oooool3o`0000Oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool000Kooooo
0_l00008ooooo`?o00001oooool2o`0003?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Kooooo0ol00008ooooo`001_ooool2o`0000Sooooo0_l0
0008ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`07ooooo`?o00001oooool3o`0000Sooooo0006ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo0_l00008
ooooo`?o00002?ooool00ol0003oooooooooo`07ooooo`001_ooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool2o`0000Sooooo0ol00009oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool004oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`07ooooo`;o00002?ooool3o`0000Oooooo0_l0000:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool004Gooooo00?o0000ooooooooool0
1oooool2o`0000Oooooo0ol00007ooooo`;o00002?ooool3o`0000Oooooo0_l0000:ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`002?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`;o00002?oo
ool3o`0000Kooooo1?l00007ooooo`;o00001oooool2o`0000[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool3o`0000Sooooo0_l00008ooooo`;o00002?ooool2
o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo03Wooooo0008ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o00002?ooool3o`00
00Oooooo0_l00008ooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
04;ooooo0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`?o00001oooool2o`0000Sooooo00?o0000ooooooooool04oooool2o`0004ko
oooo0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Sooooo
0ol00007ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`07ooooo`001oooool00ol0003oooooooooo`06ooooo`?o00002?ooool2o`0000Sooooo0_l0
000Xooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`001_ooool3o`0000Oooooo0ol00008ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool2o`0000Sooooo0006ooooo`?o00002?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`07oooo
o`;o00002?ooool2o`0000Sooooo0007ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool2o`0000Sooooo00?o0000ooooooooool01oooool000Oooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool2o`0000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`00Cooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool2o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool004Gooooo00?o0000ooooooooool01oooool3o`00017ooooo00?o0000ooooooooool01oooool2
o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`00>_ooool2o`0000Wooooo0_l00008ooooo`?o00001_ooool2o`00
00Wooooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`;o00002?ooool2o`0000Sooooo0_l00008ooooo`Go00001Oooool3o`0000So
oooo0_l00008ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool000Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool2o`0000Sooooo0_l00008ooooo`03o`000?oooooooooo00Sooooo
0_l00008ooooo`?o00001oooool00ol0003oooooooooo`0iooooo`002?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo0ol000000ooooooo0000ooooo`07ooooo`?o00002?oo
ool2o`000003ooooool0003o000000?o00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03?ooool5o`0001[ooooo0ol0000Eooooo`002?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l00007
ooooo`?o00002?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`05ooooo`Go000000?o
ooooo`000?l000001_l00008ooooo`03o`000?oooooooooo00Cooooo1Ol00003ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`Go00000_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0007ooooo`03o`000?oooooo
oooo00Oooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1_ooool3o`0000Oooooo0007ooooo`;o00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000001Oooooo
00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000001Gooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool01_ooool3o`0000Oooooo0007oooo
o`;o00002?ooool00ol0003oooooooooo`04ooooo`;o00006Oooool01Ol0003ooooooooooooooooo
000001Oooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`;o00000_ooool3o`0000Sooooo00?o
0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0H
ooooo`?o00006?ooool00ol0003oooooooooo`0Gooooo`?o000000?oooooo`000?ooool02Oooool0
0ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`03o`0000Sooooo00?o0000
ooooooooool01_ooool000Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo0014ooooo`?o00002?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Oooooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool003[ooooo0_l00008ooooo`?o0000
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool009oo000000000ooooooo0000ooooo`05
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03ooooo`;o00001_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000ooooo`05ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000;o0000
0_ooool00ol0003oooooooooo`02ooooo`?o00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`7o0000
0Oooool000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo0ol00014ooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo0ol00008ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`002?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0ol00008ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
00Gooooo0008ooooo`03o`000?oooooooooo00Kooooo0ol00008ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool000Oooooo0ol00007ooooo`?o00002?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`06ooooo`;o00001oooool000Oooooo0ol00008ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l0
0008ooooo`;o00001oooool000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool3o`0000Oooooo0ol00009
ooooo`03o`000?oooooooooo00Gooooo0008ooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`06ooooo`;o00002?ooool3o`0000Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`00A?ooool2o`0000Wooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0ol00008ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`00
@oooool3o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool2o`0000Wooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`00>_ooool2o`0000Oooooo0ol00006ooooo`Go00002Ooo
ool00ol0003oooooooooo`06ooooo`;o00002?ooool2o`0000Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool2o`0000Sooooo0_l00008ooooo`;o00001_ooool4
o`0000Wooooo00?o0000ooooooooool01_ooool3o`0000Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool2o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000008ooooo`;o0000AOooool000So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o00002?ooool2o`0000Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04go
oooo0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0000Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool01Oooool000Sooooo00?o0000ooooooooool01oooool2o`0000Sooooo0_l0
0009ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo0007ooooo`?o00002?ooool2o`0000Wooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool3o`0000Kooooo0007ooooo`?o00002Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`06oooo
o`;o00002?ooool3o`0000Kooooo0008ooooo`;o00002Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool2o`0000Sooooo0_l00009ooooo`03
o`000?oooooooooo00Gooooo0009ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`06ooooo`;o00002?ooool2o`0000Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`00Coooool2o`0001Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`?o00002?ooool2o`0000Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`00A?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`00>oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool2o`0000Wooooo00?o0000ooooooooool01_ooool2o`00
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`;o00001oooool3o`0000Oooooo1?l00007ooooo`;o00002Oooool2o`0000So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool3o`0000Oooooo
0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`04ooooo`?o00002Oooool00ol0003ooooo
ooooo`13ooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01_ooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0COooool000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`?o00001oooool3o`0000Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo00Cooooo0008ooooo`03o`000?oooooooooo00Oooooo0ol00007oooo
o`?o00002?ooool2o`0002Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo0008ooooo`;o00002?ooool3o`0000Sooooo0_l00009ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`;o
00001_ooool000Sooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o0000
1_ooool000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool01_ooool2o`0000Oooooo0ol00008ooooo`03o`000?oo
oooooooo00Gooooo0009ooooo`03o`000?oooooooooo04?ooooo0_l0000Nooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool3o`0000Sooooo0_l00008ooooo`03o`000?oooooo
oooo00Gooooo001?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool004oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`06ooooo`;o00002?ooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0014ooooo`;o00002Oooool00ol0003ooooo
ooooo`08ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`?o00002Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool3o`0000Oooooo1?l00006ooooo`?o00002?ooool2o`0000Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`;o00002?ooool3o`0000Kooooo1Ol00006ooooo`;o00002Oooool00ol0003oooooooooo`13
ooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01_ooool3o`0000Oooooo0_l0000;ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0COooool000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`?o
00001oooool3o`0000Sooooo0_l0000Looooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool00oooool000Wooooo00?o0000ooooooooool01oooool2o`0000Oooooo0ol00008ooooo`;o0000
2Oooool00ol0003oooooooooo`0Booooo`Go00000oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool000Wooooo0_l00007ooooo`?o00002?oo
ool2o`0000Wooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool01_ooool2o`0000Gooooo0008ooooo`?o00002?oo
ool2o`0000Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool01oooool2o`0000Oooooo0ol00005ooooo`002?ooool3
o`0000Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`02ooooo`;o0000:Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`;o00001Oooool0
00Wooooo0_l0000looooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`002_ooool00ol0003oooooooooo`0joooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Kooooo0_l00007ooooo`?o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo0018ooooo`?o00001?ooool00ol0003oooooooooo`0Cooooo`;o00002?ooool00ol0
003oooooooooo`06ooooo`?o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool004oooooo00?o0000ooooooooool02Oooool2o`0000Oo
oooo0ol00007ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`00>oooool00ol0003ooooo
ooooo`06ooooo`?o00001oooool5o`0000Kooooo0ol00007ooooo`?o00002?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0_l0
0008ooooo`03o`000?oooooooooo00Kooooo1?l00006ooooo`?o00002?ooool2o`0000Sooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0008
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooo000000Oooooo0ol00007ooooo`?o00001oooool2o`0000Wooooo00?o0000
ooooooooool0COooool000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`;o00002?ooool2o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`03ooooo`002Oooool00ol0003oooooooooo`07ooooo`;o
00002?ooool2o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`03ooooo`002Oooool00ol0003oooooooooo`07ooooo`;o0000
2Oooool2o`0000Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo00Kooooo0_l00005ooooo`002Oooool2o`0000Sooooo0_l0000:ooooo`03o`000?oo
oooooooo02gooooo0_l0000dooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00001Ooo
ool000Wooooo0_l00009ooooo`;o0000>Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool3o`0000Sooooo0_l00005ooooo`002_ooool2o`00
00Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool01?ooool000_o
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Nooooo`;o00002?ooool00ol0003o
ooooooooo`06ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo001?ooooo`03o`000?oooooooooo01Cooooo0_l00007ooooo`?o00001oooool2o`0000Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
001?ooooo`03o`000?oooooooooo00Wooooo0_l00008ooooo`?o00001_ooool3o`0000Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool004oooooo00Co0000ooooool0003o00001_ooool4o`0000Oooooo0ol0
0007ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool2o`0000Sooooo0_l00008ooooo`?o00001oooool2o`0000Sooooo0ol00007
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool2o`0000Wooooo00?o0000ooooooooool01_ooool3o`0000Oooooo1?l00006oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@_ooool000Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`?o
00002_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04gooooo0009ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0000[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Hooooo`;o0000BOooool00ol0003oooooooooo`02ooooo`002Ooo
ool00ol0003oooooooooo`07ooooo`?o00001oooool2o`0000_ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`002_ooool2
o`0000Oooooo0ol00008ooooo`;o0000;oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool3o`0000Cooooo0009ooooo`?o00002?ooool2o`00
00Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0cooooo`;o00002?ooool00ol0
003oooooooooo`07ooooo`;o00001?ooool000[ooooo0_l00009ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0:Oooool2o`0000Oooooo0_l00008ooooo`;o00002Oooool00ol0003o
ooooooooo`03ooooo`002oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool01_ooool3o`0000Kooooo0ol00008ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool004oooooo00?o0000ooooooooool05?ooool2o`0000Sooooo0_l0
0007ooooo`?o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool004oooooo00?o0000ooooooooool02_ooool2o`0000Oooooo0ol00007
ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`00Coooool00ol0003oooooooooo`08oooo
o`Co00001_ooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000looooo`;o
00002?ooool3o`0000Kooooo1Ol00006ooooo`?o00001oooool2o`0000Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`;o0000
2?ooool4o`0000Kooooo1Ol00005ooooo`?o00001oooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`002?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool3o`0000Oooooo0ol00007ooooo`Go00001_ooool2o`0000Oooooo0_l0001>ooooo`002Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001oooool3
o`0000[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o00002Oooool2o`00
02Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
007ooooo000:ooooo`;o00002?ooool2o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0?_ooool2o`0000Sooooo00?o0000ooooooooool00_ooool000[ooooo
0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool01_ooool2o`0000Sooooo0_l00004ooooo`002oooool2o`0000Wooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo0_l0
0007ooooo`?o00002?ooool00ol0003oooooooooo`03ooooo`003?ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo01oooooo0_l00008ooooo`;o00001oooool2o`0000Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`00Coooool00ol0003oooooooooo`0Eoooo
o`;o00001oooool3o`0000Oooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`00Coooool00ol0003oooooooooo`0Dooooo`?o
00001_ooool3o`0000Sooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`04ooooo`00BOooool3o`0000?ooooo00?o0000ooooooooool0
2oooool2o`0000Kooooo0ol00007ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`00A_oo
ool3o`000003ooooool0003ooooo00?ooooo1_l00005ooooo`?o00001oooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool000Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l00009
ooooo`?o00001oooool4o`0000Kooooo1ol00003ooooo`Co00001_ooool00ol0003oooooo`000007
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool2o`0000Wooooo00?o0000ooooooooool01_ooool4o`0000Kooooo0_l00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool00000COooool000Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`?o
00004oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo04gooooo000:ooooo`03o`00
0?oooooooooo00Oooooo0_l00008ooooo`;o00002?ooool3o`0000[ooooo00?o0000ooooooooool0
4Oooool2o`0000Cooooo00?o0000ooooooooool0COooool000[ooooo00?o0000ooooooooool01ooo
ool2o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0COooool000[ooooo0_l0000:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1=ooooo`002oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0COooool000co
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1=ooooo`003Oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo04gooooo001?ooooo`03o`000?oooooooooo04gooooo001?
ooooo`03o`000?oooooooooo04gooooo001?ooooo`;o0000C_ooool004oooooo00?o0000oooooooo
ool0COooool00001\
\>"],
  ImageRangeCache->{{{77.875, 236.812}, {296.75, 97.875}} -> {-11.0693, \
-0.0716906, 0.0703509, 0.045882}}]
}, Open  ]],

Cell["\<\
The next picture displays the vector field with several \
trajectories created with its phi function.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[
     ParametricPlot[ 
     Evaluate[Table[{phi[3,v,t],D[phi[3,v,t],t]},{v,-3,3,3}]], {t,0,40} , 
                PlotStyle->{RGBColor[0,1,0]} ], 
     vf1, PlotRange->{{-5,5},{-4,4}}, AspectRatio->5/4 ]\
\>", "Input",
  CellLabel->"In[27]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.625 0.15625 [
[.1 .6125 -6 -9 ]
[.1 .6125 6 0 ]
[.3 .6125 -6 -9 ]
[.3 .6125 6 0 ]
[.7 .6125 -3 -9 ]
[.7 .6125 3 0 ]
[.9 .6125 -3 -9 ]
[.9 .6125 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .15625 -12 -4.5 ]
[.4875 .15625 0 4.5 ]
[.4875 .3125 -12 -4.5 ]
[.4875 .3125 0 4.5 ]
[.4875 .46875 -12 -4.5 ]
[.4875 .46875 0 4.5 ]
[.4875 .78125 -6 -4.5 ]
[.4875 .78125 0 4.5 ]
[.4875 .9375 -6 -4.5 ]
[.4875 .9375 0 4.5 ]
[.4875 1.09375 -6 -4.5 ]
[.4875 1.09375 0 4.5 ]
[.4875 1.25 -6 -4.5 ]
[.4875 1.25 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 .625 m
.1 .63125 L
s
[(-4)] .1 .6125 0 1 Mshowa
.3 .625 m
.3 .63125 L
s
[(-2)] .3 .6125 0 1 Mshowa
.7 .625 m
.7 .63125 L
s
[(2)] .7 .6125 0 1 Mshowa
.9 .625 m
.9 .63125 L
s
[(4)] .9 .6125 0 1 Mshowa
.125 Mabswid
.15 .625 m
.15 .62875 L
s
.2 .625 m
.2 .62875 L
s
.25 .625 m
.25 .62875 L
s
.35 .625 m
.35 .62875 L
s
.4 .625 m
.4 .62875 L
s
.45 .625 m
.45 .62875 L
s
.55 .625 m
.55 .62875 L
s
.6 .625 m
.6 .62875 L
s
.65 .625 m
.65 .62875 L
s
.75 .625 m
.75 .62875 L
s
.8 .625 m
.8 .62875 L
s
.85 .625 m
.85 .62875 L
s
.05 .625 m
.05 .62875 L
s
.95 .625 m
.95 .62875 L
s
.25 Mabswid
0 .625 m
1 .625 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .15625 m
.50625 .15625 L
s
[(-3)] .4875 .15625 1 0 Mshowa
.5 .3125 m
.50625 .3125 L
s
[(-2)] .4875 .3125 1 0 Mshowa
.5 .46875 m
.50625 .46875 L
s
[(-1)] .4875 .46875 1 0 Mshowa
.5 .78125 m
.50625 .78125 L
s
[(1)] .4875 .78125 1 0 Mshowa
.5 .9375 m
.50625 .9375 L
s
[(2)] .4875 .9375 1 0 Mshowa
.5 1.09375 m
.50625 1.09375 L
s
[(3)] .4875 1.09375 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(4)] .4875 1.25 1 0 Mshowa
.125 Mabswid
.5 .03125 m
.50375 .03125 L
s
.5 .0625 m
.50375 .0625 L
s
.5 .09375 m
.50375 .09375 L
s
.5 .125 m
.50375 .125 L
s
.5 .1875 m
.50375 .1875 L
s
.5 .21875 m
.50375 .21875 L
s
.5 .25 m
.50375 .25 L
s
.5 .28125 m
.50375 .28125 L
s
.5 .34375 m
.50375 .34375 L
s
.5 .375 m
.50375 .375 L
s
.5 .40625 m
.50375 .40625 L
s
.5 .4375 m
.50375 .4375 L
s
.5 .5 m
.50375 .5 L
s
.5 .53125 m
.50375 .53125 L
s
.5 .5625 m
.50375 .5625 L
s
.5 .59375 m
.50375 .59375 L
s
.5 .65625 m
.50375 .65625 L
s
.5 .6875 m
.50375 .6875 L
s
.5 .71875 m
.50375 .71875 L
s
.5 .75 m
.50375 .75 L
s
.5 .8125 m
.50375 .8125 L
s
.5 .84375 m
.50375 .84375 L
s
.5 .875 m
.50375 .875 L
s
.5 .90625 m
.50375 .90625 L
s
.5 .96875 m
.50375 .96875 L
s
.5 1 m
.50375 1 L
s
.5 1.03125 m
.50375 1.03125 L
s
.5 1.0625 m
.50375 1.0625 L
s
.5 1.125 m
.50375 1.125 L
s
.5 1.15625 m
.50375 1.15625 L
s
.5 1.1875 m
.50375 1.1875 L
s
.5 1.21875 m
.50375 1.21875 L
s
.25 Mabswid
.5 0 m
.5 1.25 L
s
0 0 m
1 0 L
1 1.25 L
0 1.25 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
0 1 0 r
.5 Mabswid
.8 .15625 m
.77069 .12334 L
.73732 .09371 L
.70423 .07119 L
.67307 .05539 L
.65365 .04794 L
.63552 .04257 L
.61545 .03833 L
.60527 .03684 L
.59405 .03571 L
.57521 .035 L
.55494 .03587 L
.53587 .03824 L
.5185 .04169 L
.49946 .04693 L
.47937 .05411 L
.44397 .07107 L
.4035 .09767 L
.36872 .12742 L
.33778 .16014 L
.30684 .19999 L
.25835 .28228 L
.23589 .33302 L
.21824 .38257 L
.2027 .43869 L
.19583 .47047 L
.19061 .50005 L
.18634 .53105 L
.18461 .54707 L
.18307 .56473 L
.18206 .57999 L
.18137 .59428 L
.18093 .6093 L
.18077 .6254 L
.1809 .63903 L
.18131 .65384 L
.18204 .66918 L
.183 .68333 L
.18537 .70837 L
.18881 .73458 L
.19329 .76072 L
.19826 .78418 L
.21231 .83459 L
.22777 .87565 L
.247 .91521 L
.28641 .97314 L
.3117 .99957 L
.33689 1.01977 L
.35032 1.02842 L
.36491 1.03631 L
Mistroke
.37773 1.04203 L
.39177 1.04706 L
.40047 1.04955 L
.40851 1.05145 L
.41623 1.0529 L
.42439 1.05405 L
.4386 1.05514 L
.44668 1.05525 L
.4542 1.05501 L
.46902 1.05362 L
.48297 1.05117 L
.49541 1.04806 L
.50881 1.0437 L
.53824 1.03039 L
.56446 1.01392 L
.60713 .9764 L
.62929 .95057 L
.64845 .92376 L
.6817 .8634 L
.69698 .8265 L
.70868 .79134 L
.71856 .75327 L
.72529 .71819 L
.7281 .69865 L
.72932 .68837 L
.7304 .6775 L
.73187 .6576 L
.73261 .63937 L
.73279 .62274 L
.73244 .60507 L
.73161 .58859 L
.73043 .57375 L
.72854 .55664 L
.72587 .5384 L
.71945 .50638 L
.71047 .47422 L
.69815 .44135 L
.68283 .41037 L
.6664 .38472 L
.64955 .36406 L
.63296 .34799 L
.61372 .33362 L
.60365 .32769 L
.59252 .32228 L
.58158 .31808 L
.57137 .31509 L
.56153 .31303 L
.55104 .3117 L
.54164 .31124 L
.53283 .31144 L
Mistroke
.52318 .31235 L
.51286 .31412 L
.502 .31688 L
.49028 .32091 L
.46941 .33087 L
.44987 .34367 L
.4326 .35811 L
.40128 .39343 L
.3771 .43181 L
.36566 .45519 L
.35499 .48177 L
.34658 .50795 L
.34041 .53239 L
.33535 .55927 L
.3333 .57413 L
.33185 .5882 L
.33091 .60114 L
.33041 .61305 L
.33024 .62603 L
.3305 .63967 L
.33121 .65313 L
.3318 .66061 L
.33246 .66739 L
.33399 .67973 L
.33602 .69244 L
.34168 .71836 L
.34568 .73232 L
.34989 .74477 L
.3596 .76795 L
.37026 .78762 L
.38107 .80348 L
.39354 .81804 L
.40813 .83117 L
.42235 .84067 L
.4305 .84485 L
.43826 .84804 L
.44688 .85073 L
.45175 .85187 L
.45623 .85268 L
.46417 .85358 L
.47166 .85381 L
.47838 .8535 L
.48562 .85263 L
.49351 .85105 L
.49745 .85001 L
.50175 .84869 L
.51622 .84272 L
.5294 .83517 L
.54292 .82512 L
.56539 .80234 L
Mistroke
.57756 .78596 L
.58938 .76633 L
.59848 .74768 L
.60668 .72681 L
.61273 .7073 L
.61542 .69674 L
.61789 .68528 L
.61979 .67471 L
.6212 .66501 L
.62231 .65526 L
.62308 .64601 L
.62361 .63579 L
.62376 .63006 L
.6238 .62481 L
.62364 .61524 L
.62315 .60525 L
.62242 .59643 L
.6215 .58832 L
.62023 .57959 L
.61857 .57044 L
.61382 .55098 L
.60804 .53384 L
.60187 .51969 L
.5942 .50574 L
.57798 .48458 L
.56888 .47615 L
.55829 .46869 L
.54893 .4639 L
.54355 .46183 L
.53857 .46034 L
.53415 .45935 L
.52929 .4586 L
.52419 .4582 L
.51945 .45817 L
.51374 .45856 L
.51086 .45894 L
.50771 .4595 L
.50217 .46082 L
.49703 .46246 L
.48568 .46751 L
.47948 .47114 L
.47395 .47494 L
.46437 .48287 L
.45457 .49301 L
.44594 .504 L
.43879 .51494 L
.42649 .5395 L
.4211 .55401 L
.41695 .56813 L
.41393 .58152 L
Mistroke
.41187 .59393 L
.41106 .60045 L
.4104 .60758 L
.40994 .615 L
.40974 .62188 L
.40976 .62936 L
.40987 .63311 L
.41006 .63721 L
.41059 .64437 L
.4113 .65096 L
.4124 .65855 L
.41364 .66533 L
.41727 .6799 L
.42102 .69098 L
.42588 .70215 L
.43172 .71264 L
.43777 .72123 L
.44429 .72858 L
.45083 .7344 L
.45699 .73868 L
.46389 .7423 L
.46756 .74375 L
.47163 .74501 L
.4737 .74551 L
.47593 .74595 L
.47996 .74648 L
.48399 .74668 L
.48782 .74657 L
.49124 .74622 L
.49496 .74557 L
.49887 .7446 L
.50243 .74344 L
.51031 .73992 L
.51703 .73584 L
.52381 .73059 L
.53696 .71656 L
.54351 .7071 L
.54894 .69747 L
.55387 .6867 L
.55779 .67601 L
.56066 .6661 L
.56306 .65512 L
.56402 .64939 L
.56484 .64306 L
.56516 .63988 L
.56543 .63646 L
.56563 .63325 L
.56575 .63032 L
.56584 .62478 L
.5658 .62167 L
Mistroke
.56572 .6188 L
.56543 .6136 L
.56493 .60815 L
.56428 .60309 L
.56338 .59766 L
.56096 .58717 L
.55805 .57811 L
.5548 .57031 L
.55035 .56199 L
.54578 .55534 L
.53997 .54882 L
.53405 .54387 L
.52862 .54055 L
.52581 .53924 L
.52266 .53806 L
.51996 .5373 L
.51702 .53671 L
.51423 .53638 L
.51166 .53626 L
.50864 .53636 L
.50584 .53668 L
.50278 .53727 L
.50108 .53771 L
.49954 .53818 L
.49645 .53932 L
.49316 .54084 L
.48736 .54433 L
.48236 .54824 L
.4773 .55318 L
.4691 .56382 L
.46478 .57124 L
.46122 .57879 L
.45825 .58662 L
.45604 .59396 L
.45421 .602 L
.45343 .60645 L
.45285 .61065 L
.45245 .61455 L
.45219 .61812 L
.45203 .62202 L
.45199 .62609 L
.4521 .63018 L
.45223 .63244 L
.45238 .63448 L
.45278 .6384 L
.45328 .64203 L
.45402 .64615 L
.45483 .64985 L
.45715 .65776 L
.45948 .66368 L
Mistroke
.46195 .66864 L
.46491 .67346 L
.46848 .67806 L
.47203 .68165 L
.47552 .68441 L
.47899 .68651 L
.48083 .6874 L
.48281 .68817 L
.48394 .68855 L
.48519 .68889 L
.4874 .68936 L
.48865 .68953 L
.48999 .68965 L
.49126 .68971 L
.49242 .6897 L
.49466 .68955 L
.49592 .68938 L
.49709 .68917 L
.49921 .68865 L
.50145 .68793 L
.50546 .68613 L
.50911 .68391 L
.51293 .68092 L
.51681 .67709 L
.52004 .67319 L
.5232 .66857 L
.52803 .65928 L
.5304 .65313 L
.53219 .6471 L
.53344 .64156 L
.53398 .6384 L
.53438 .63549 L
.53468 .63265 L
.53489 .6296 L
.53499 .62674 L
.53501 .62415 L
.53493 .62116 L
.53483 .61948 L
.53471 .61794 L
.53443 .61516 L
.53402 .61226 L
.53348 .6093 L
.53277 .60621 L
.53118 .60091 L
.52926 .59617 L
.52722 .59223 L
.52497 .58879 L
.52266 .58593 L
.51978 .58315 L
.51701 .58112 L
Mistroke
.5157 .58035 L
.51429 .57964 L
.51306 .57912 L
.51171 .57866 L
.51026 .57828 L
.50888 .57802 L
.50724 .57785 L
.50574 .57781 L
.50421 .5779 L
.50258 .57812 L
.50105 .57845 L
.49968 .57885 L
.49808 .57945 L
.49637 .58024 L
.49335 .58205 L
.49034 .58442 L
.48736 .58743 L
.48484 .5906 L
.48266 .59393 L
.48079 .59735 L
.47901 .6013 L
.47763 .60511 L
.47658 .60866 L
.47561 .61297 L
.4752 .61535 L
.4749 .6176 L
.47469 .61969 L
.47456 .6216 L
.47448 .62369 L
.47447 .62587 L
.47453 .62777 L
.47463 .62948 L
.47481 .63142 L
.47503 .63322 L
.47556 .63633 L
.47633 .63956 L
.47738 .6429 L
.47873 .64618 L
.48167 .65125 L
.48353 .65354 L
.48543 .65539 L
.48722 .65676 L
.48927 .65793 L
.49045 .65845 L
.49155 .65882 L
.49216 .65899 L
.49282 .65914 L
.49403 .65933 L
.49517 .65941 L
.49638 .65939 L
Mistroke
.4974 .6593 L
.49853 .65911 L
.49965 .65883 L
.5007 .65849 L
.50264 .65765 L
.50466 .65645 L
.50676 .65484 L
.51023 .65118 L
.51299 .64708 L
.51542 .64198 L
.51651 .63891 L
.51731 .63601 L
.51786 .63341 L
.5181 .63191 L
.51829 .63055 L
.51844 .6291 L
.51855 .62756 L
.51861 .62614 L
.51862 .62481 L
.51859 .62337 L
.51851 .6218 L
.51844 .62102 L
.51836 .62019 L
.51817 .61872 L
.51793 .61729 L
.51766 .61597 L
.51703 .61358 L
.51612 .61097 L
.51512 .60875 L
.51385 .60657 L
.51235 .60456 L
.51085 .60304 L
.50918 .60175 L
.50768 .60091 L
.5068 .60055 L
.50598 .60028 L
.50552 .60017 L
.50502 .60006 L
.50454 .59999 L
.5041 .59994 L
.50326 .5999 L
.50237 .59994 L
.50191 .59999 L
.50142 .60006 L
.50095 .60015 L
.50053 .60025 L
.49956 .60055 L
.49855 .60096 L
.49701 .6018 L
.49544 .60293 L
Mistroke
.49284 .60554 L
.49142 .60745 L
.49023 .60944 L
.48922 .6115 L
.4884 .61354 L
.48773 .61565 L
.48723 .61763 L
.48681 .61986 L
.48665 .62109 L
.48653 .62226 L
.48646 .62338 L
.48642 .62457 L
.48643 .62557 L
.48646 .62667 L
.4865 .62727 L
.48654 .62782 L
.48668 .62904 L
.48683 .6301 L
.48704 .63118 L
.48745 .6329 L
.48801 .63462 L
.48927 .6374 L
.49019 .63887 L
.49115 .64007 L
.49207 .64101 L
.49312 .64183 L
.49369 .6422 L
.49422 .64248 L
.49477 .64273 L
.49529 .64292 L
.49589 .64309 L
.49621 .64316 L
.49656 .64322 L
.49719 .64329 L
.49777 .6433 L
.49809 .64329 L
.49842 .64326 L
.49902 .64318 L
.49966 .64303 L
.50035 .64282 L
.50095 .64258 L
.50157 .64227 L
.50267 .6416 L
.5037 .64078 L
.50476 .63973 L
.50563 .63868 L
.50648 .63745 L
.50717 .63626 L
.50785 .63486 L
.50883 .63224 L
Mistroke
.50924 .63072 L
.50957 .62903 L
.5097 .62817 L
.50975 .62769 L
.5098 .62725 L
.50986 .62638 L
.50989 .6256 L
.5099 .62487 L
.50989 .6241 L
.50985 .62346 L
.5098 .62275 L
.50971 .62201 L
.50959 .62123 L
.50932 .61988 L
.50889 .61841 L
.50832 .61694 L
.50767 .61569 L
.507 .61467 L
.50628 .61381 L
.50555 .61313 L
.50467 .6125 L
.50427 .61228 L
.50384 .61208 L
.50339 .61192 L
.50299 .61181 L
.50257 .61172 L
.50218 .61167 L
.50172 .61165 L
.5013 .61167 L
.50084 .61172 L
.50061 .61176 L
.50035 .61182 L
.49988 .61196 L
.49945 .61212 L
.49851 .6126 L
.49768 .61318 L
.49692 .61385 L
.49564 .61537 L
.49463 .61705 L
.49376 .61911 L
.49339 .62033 L
.49313 .62146 L
.49293 .62264 L
Mfstroke
.8 .625 m
.79964 .60198 L
.79868 .58128 L
.79683 .55772 L
.79438 .53584 L
.7915 .51599 L
.78834 .49801 L
.77945 .45878 L
.76815 .42148 L
.75317 .38334 L
.73491 .34718 L
.71562 .317 L
.69348 .28956 L
.67082 .26757 L
.64936 .25134 L
.62498 .23751 L
.61077 .23148 L
.59773 .22717 L
.59044 .22524 L
.58251 .22355 L
.57501 .2223 L
.56808 .22146 L
.55563 .2207 L
.54195 .22095 L
.5277 .2224 L
.51445 .22484 L
.50738 .22658 L
.4999 .22875 L
.48659 .23347 L
.45716 .24793 L
.43275 .26446 L
.40723 .28671 L
.38607 .30967 L
.36502 .33747 L
.33225 .39455 L
.3171 .42976 L
.30347 .4701 L
.2978 .49099 L
.29265 .51358 L
.28897 .53326 L
.28578 .55466 L
.28454 .56506 L
.28344 .57607 L
.28262 .58624 L
.28202 .59574 L
.28134 .61405 L
.28123 .62371 L
.2813 .63401 L
.28153 .64307 L
.28196 .65288 L
Mistroke
.28321 .67052 L
.28499 .68739 L
.28714 .70273 L
.29014 .71971 L
.29393 .73713 L
.30226 .76687 L
.31333 .79654 L
.32776 .82595 L
.34199 .84852 L
.35878 .86948 L
.37591 .88606 L
.39238 .89835 L
.40096 .90351 L
.41023 .90822 L
.41835 .91165 L
.4272 .91467 L
.43676 .91714 L
.44579 .91874 L
.45105 .91934 L
.45658 .91973 L
.46648 .91979 L
.47507 .91919 L
.4842 .91788 L
.49277 .91603 L
.5005 .91383 L
.51916 .90643 L
.53623 .89692 L
.55339 .88448 L
.56863 .87073 L
.5856 .8519 L
.59982 .83263 L
.62466 .78808 L
.63569 .76121 L
.64427 .73466 L
.65013 .71132 L
.65275 .69838 L
.65482 .68616 L
.6564 .67491 L
.65756 .66459 L
.65853 .65316 L
.65922 .64087 L
.65952 .62866 L
.65947 .61738 L
.65903 .60515 L
.65813 .59225 L
.65752 .58584 L
.65672 .57895 L
.65496 .56665 L
.65056 .54443 L
.6448 .52342 L
Mistroke
.63717 .50239 L
.62871 .4842 L
.62 .4691 L
.60876 .45345 L
.59537 .43897 L
.58182 .42791 L
.56862 .41999 L
.56127 .41665 L
.55321 .4138 L
.54948 .41275 L
.54551 .41183 L
.53838 .41064 L
.53149 .41006 L
.52505 .41 L
.51799 .41048 L
.51045 .41162 L
.50629 .41252 L
.50247 .41352 L
.49389 .41638 L
.48644 .41958 L
.47866 .42364 L
.46562 .43222 L
.45197 .44383 L
.42966 .47002 L
.41985 .48532 L
.41034 .50338 L
.40327 .5198 L
.39686 .53806 L
.39196 .55581 L
.38847 .57221 L
.3868 .58234 L
.38542 .59307 L
.38456 .60223 L
.38394 .61225 L
.38374 .61785 L
.38366 .62295 L
.38368 .62879 L
.38381 .6343 L
.3843 .64397 L
.38473 .64937 L
.38521 .65433 L
.38643 .66389 L
.38788 .67269 L
.39137 .68849 L
.3962 .7045 L
.40258 .72042 L
.40912 .73312 L
.41696 .74525 L
.42437 .75443 L
.43299 .76296 L
Mistroke
.4385 .7674 L
.44373 .77098 L
.44875 .77388 L
.45438 .77655 L
.45915 .77837 L
.46435 .77989 L
.46723 .78054 L
.46988 .78102 L
.47509 .78163 L
.48055 .78181 L
.4836 .78171 L
.48637 .78149 L
.49175 .78073 L
.49678 .77961 L
.50261 .77781 L
.50791 .77571 L
.51955 .76942 L
.52859 .76283 L
.53798 .75417 L
.54644 .74452 L
.55485 .73273 L
.56227 .71995 L
.56827 .70728 L
.57309 .69482 L
.57748 .68057 L
.58055 .66754 L
.58268 .65517 L
.58355 .64834 L
.58415 .64208 L
.58459 .63523 L
.58482 .62807 L
.5848 .62079 L
.58456 .61424 L
.58434 .61066 L
.58403 .60681 L
.58327 .59992 L
.58235 .5936 L
.58115 .58706 L
.57844 .57581 L
.57444 .56356 L
.56992 .55305 L
.5642 .54269 L
.55724 .53304 L
.55071 .52606 L
.54327 .52002 L
.53951 .51762 L
.5359 .51568 L
.53264 .51422 L
.52901 .5129 L
.52493 .51179 L
Mistroke
.52269 .51135 L
.5206 .51103 L
.51683 .5107 L
.51279 .51068 L
.51052 .51083 L
.50806 .51111 L
.50574 .51149 L
.50361 .51194 L
.4996 .51305 L
.49539 .5146 L
.48845 .51803 L
.48125 .52283 L
.46922 .53414 L
.46295 .54208 L
.45701 .55135 L
.45219 .56059 L
.44826 .56982 L
.44499 .57928 L
.44216 .58982 L
.44114 .59455 L
.44023 .59958 L
.43952 .6043 L
.439 .60861 L
.43855 .61363 L
.43825 .61898 L
.43813 .62391 L
.43817 .62854 L
.43825 .63113 L
.43839 .63385 L
.43876 .6387 L
.43904 .64135 L
.43934 .64381 L
.44019 .64933 L
.44191 .65748 L
.44423 .66559 L
.44661 .67208 L
.44961 .67868 L
.45326 .68515 L
.45761 .69126 L
.46164 .69581 L
.46637 .70003 L
.4717 .70361 L
.47472 .70515 L
.47759 .70632 L
.4803 .70718 L
.4828 .70776 L
.48571 .7082 L
.48849 .70838 L
.49005 .70838 L
.49147 .70833 L
Mistroke
.49311 .70818 L
.49464 .70798 L
.49737 .70745 L
.4989 .70706 L
.5003 .70664 L
.50638 .70411 L
.50937 .70245 L
.51256 .70033 L
.52218 .69156 L
.527 .68549 L
.53097 .67936 L
.53427 .6732 L
.5374 .6661 L
.53989 .65905 L
.54176 .6524 L
.54326 .64542 L
.54387 .64172 L
.54439 .63782 L
.54472 .63442 L
.54494 .63127 L
.54508 .62783 L
.54512 .62418 L
.54508 .62213 L
.54502 .62024 L
.54491 .61819 L
.54475 .61604 L
.54438 .61248 L
.54385 .60864 L
.54325 .60531 L
.54249 .60183 L
.54081 .59582 L
.53846 .58954 L
.53541 .58336 L
.53211 .57824 L
.52874 .57416 L
.52513 .57077 L
.52169 .5683 L
.51971 .56718 L
.51754 .56616 L
.51546 .5654 L
.51353 .56486 L
.51147 .56446 L
.50952 .56425 L
.50775 .56419 L
.50584 .56426 L
.50377 .56451 L
.50272 .5647 L
.50158 .56496 L
.49957 .56554 L
.4977 .56623 L
Mistroke
.49414 .56795 L
.49098 .56996 L
.48435 .57587 L
.48103 .5799 L
.4782 .58405 L
.47522 .58942 L
.47288 .59464 L
.47112 .5995 L
.46957 .60492 L
.46887 .60796 L
.46833 .61077 L
.46789 .61362 L
.46756 .61633 L
.46732 .61891 L
.46716 .62171 L
.4671 .62424 L
.46711 .62656 L
.4672 .62903 L
.46738 .63172 L
.46751 .63306 L
.46768 .63448 L
.46804 .63702 L
.46892 .64152 L
.47015 .64599 L
.47142 .64958 L
.47304 .65322 L
.47519 .65706 L
.47747 .66026 L
.48034 .66337 L
.48313 .66565 L
.48447 .66652 L
.48591 .66731 L
.48717 .66789 L
.48855 .66841 L
.49005 .66884 L
.49146 .66912 L
.49232 .66924 L
.49314 .66931 L
.49469 .66934 L
.49617 .66925 L
.49701 .66915 L
.49777 .66902 L
.49917 .6687 L
.50064 .66825 L
.50314 .6672 L
.5058 .66567 L
.50852 .66361 L
.51127 .66098 L
.51567 .65522 L
.5175 .65206 L
Mistroke
.51925 .64841 L
.52057 .64503 L
.52175 .64131 L
.5226 .63789 L
.52297 .63605 L
.52331 .63406 L
.52355 .63224 L
.52373 .63057 L
.52386 .62898 L
.52395 .62731 L
.52399 .62535 L
.52399 .62425 L
.52397 .62325 L
.52388 .62142 L
.52373 .61951 L
.52354 .61784 L
.52332 .61629 L
.52265 .61291 L
.52169 .60946 L
.52062 .60653 L
.51916 .60345 L
.51758 .60084 L
.51608 .59886 L
.51437 .59705 L
.5128 .59572 L
.51104 .59455 L
.50992 .59397 L
.50888 .59353 L
.50787 .5932 L
.5068 .59293 L
.50583 .59277 L
.50492 .59268 L
.50392 .59266 L
.50285 .59272 L
.50179 .59287 L
.50119 .59299 L
.50062 .59312 L
.4995 .59347 L
.49831 .59394 L
.49621 .59506 L
.49436 .59636 L
.49234 .59818 L
.49029 .60052 L
.48852 .60305 L
.48709 .60555 L
.4859 .60808 L
.48481 .61095 L
.48387 .61409 L
.48353 .61553 L
.48321 .61712 L
Mistroke
.48299 .61851 L
.48279 .62 L
.4827 .62082 L
.48264 .62157 L
.48255 .62303 L
.48251 .62435 L
.48251 .62578 L
.48255 .62711 L
.48263 .62833 L
.48276 .62962 L
.48294 .63096 L
.48336 .63328 L
.48397 .63565 L
.4848 .63807 L
.48566 .63999 L
.48669 .64187 L
.48884 .6447 L
.4903 .64607 L
.49111 .64667 L
.49198 .64722 L
.49277 .64763 L
.49364 .64799 L
.49445 .64825 L
.49521 .64842 L
.49601 .64854 L
.49677 .64858 L
.49746 .64857 L
.4982 .64851 L
.49901 .64837 L
.49946 .64827 L
.49986 .64816 L
.50064 .64789 L
.50136 .64759 L
.50276 .64684 L
.50422 .64579 L
.50558 .64457 L
.50692 .64305 L
.50808 .64147 L
.50907 .63983 L
.51063 .63649 L
.51134 .63446 L
.51194 .63223 L
.51232 .63029 L
.51248 .62918 L
.5126 .62814 L
.51266 .62755 L
.5127 .62701 L
.51273 .62644 L
.51275 .62583 L
.51276 .62481 L
Mistroke
.51273 .62374 L
.5127 .62314 L
.51266 .6225 L
.5126 .6219 L
.51254 .62135 L
.51239 .62033 L
.5122 .61928 L
.51175 .61743 L
.5112 .61578 L
.51063 .61441 L
.50992 .61305 L
.50905 .61173 L
.50804 .61052 L
.50711 .60966 L
.50602 .6089 L
.50552 .60862 L
.50498 .60837 L
.50451 .60819 L
.504 .60803 L
.50344 .60791 L
.50292 .60784 L
.5026 .60781 L
.5023 .6078 L
.50174 .60782 L
.50124 .60787 L
.50072 .60796 L
.50027 .60806 L
.49979 .60821 L
.49872 .60866 L
.49776 .60922 L
.49669 .61002 L
.49576 .61091 L
.49473 .61212 L
.49388 .61335 L
.49254 .61591 L
.49195 .61743 L
.4915 .61891 L
.49117 .6203 L
.49103 .62106 L
.49092 .62178 L
.49084 .62244 L
.49078 .62304 L
.49073 .62371 L
.4907 .62442 L
.4907 .62518 L
.49071 .62587 L
.49075 .62661 L
.49078 .62699 L
.49082 .62739 L
.49091 .62806 L
Mistroke
.49102 .62877 L
.49129 .63 L
.49165 .63123 L
.49213 .63245 L
.49317 .63436 L
.49392 .63532 L
.49469 .63608 L
.49542 .63662 L
.49584 .63688 L
.49625 .63708 L
.49668 .63725 L
.49708 .63737 L
.4973 .63742 L
.49753 .63747 L
.49778 .63751 L
.49802 .63753 L
.49827 .63754 L
.4985 .63754 L
.49876 .63753 L
.499 .63751 L
.49944 .63744 L
.49969 .63738 L
.49991 .63732 L
.50068 .63703 L
.50111 .63682 L
.5015 .63659 L
.50232 .636 L
.50304 .63533 L
.50433 .63371 L
.50491 .63272 L
.50545 .6316 L
.50583 .63064 L
.50616 .62957 L
.50632 .62894 L
.50645 .62837 L
.50655 .62782 L
.50664 .62723 L
.5067 .62667 L
.50675 .62616 L
.50677 .62565 L
.50679 .62517 L
.50678 .62462 L
.50676 .62412 L
.50672 .62357 L
.5067 .6233 L
.50666 .62301 L
.50651 .62208 L
.5064 .62158 L
.50629 .62113 L
.50574 .61957 L
Mistroke
.50542 .6189 L
.50502 .61823 L
.50459 .61766 L
.50409 .61712 L
.5036 .6167 L
.50312 .61639 L
.50266 .61616 L
.50242 .61607 L
.50215 .61598 L
.50184 .61591 L
.50154 .61587 L
.50127 .61586 L
.50098 .61586 L
.50067 .61589 L
.50051 .61591 L
.50033 .61595 L
.50003 .61603 L
.49974 .61613 L
.4992 .61638 L
.49871 .61667 L
.4977 .61755 L
Mfstroke
.8 1.09375 m
.82666 1.03921 L
.85144 .97798 L
.86961 .92315 L
.88583 .86218 L
.8939 .82444 L
.90012 .7894 L
.90485 .75647 L
.90885 .7202 L
.91134 .68783 L
.91275 .65764 L
.91327 .626 L
.91274 .59231 L
.91096 .55728 L
.90821 .52529 L
.90615 .50714 L
.90399 .49087 L
.89815 .45506 L
.88408 .39271 L
.86697 .33768 L
.84707 .28833 L
.8261 .24669 L
.79835 .20256 L
.77056 .16739 L
.73952 .13626 L
.7042 .10922 L
.68796 .09937 L
.66997 .09017 L
.65284 .08298 L
.63657 .07752 L
.61759 .07274 L
.60745 .07088 L
.59649 .06938 L
.58559 .06843 L
.5741 .068 L
.56429 .06809 L
.55357 .06867 L
.5343 .07097 L
.52356 .07296 L
.51384 .07519 L
.49506 .08069 L
.47751 .08726 L
.4402 .10602 L
.40237 .13223 L
.37179 .15939 L
.34031 .19392 L
.30936 .23588 L
.27984 .28578 L
.25746 .33284 L
.23739 .38569 L
Mistroke
.22164 .43964 L
.21086 .48957 L
.20686 .51389 L
.20343 .5402 L
.20103 .56502 L
.19956 .58774 L
.19903 .60055 L
.1987 .61421 L
.19875 .63865 L
.19918 .65345 L
.19986 .66734 L
.20069 .67971 L
.20185 .69302 L
.20498 .71988 L
.20942 .74765 L
.22016 .79532 L
.23229 .83425 L
.24804 .87299 L
.28278 .93356 L
.30609 .96248 L
.33267 .98764 L
.35671 1.00468 L
.37083 1.01251 L
.38407 1.01851 L
.39725 1.02328 L
.41132 1.0271 L
.42557 1.02968 L
.43369 1.03058 L
.4413 1.03107 L
.45506 1.03105 L
.46761 1.03005 L
.47453 1.0291 L
.48203 1.02774 L
.49561 1.02442 L
.50756 1.02057 L
.5206 1.01535 L
.54641 1.00177 L
.5694 .98577 L
.59 .96793 L
.61279 .94375 L
.63488 .91489 L
.66875 .85603 L
.68417 .82003 L
.69612 .78501 L
.70649 .74542 L
.711 .72293 L
.7143 .70236 L
.71649 .68486 L
.71804 .6685 L
.71917 .65061 L
Mistroke
.71974 .63151 L
.71977 .62203 L
.71961 .61174 L
.71882 .59322 L
.71744 .57546 L
.71561 .55928 L
.71322 .5431 L
.7105 .5282 L
.70422 .50134 L
.6958 .47403 L
.68488 .44664 L
.67197 .42124 L
.65594 .39657 L
.6374 .37465 L
.6187 .35791 L
.60021 .34561 L
.58272 .33731 L
.57286 .33392 L
.56762 .33247 L
.56202 .3312 L
.55171 .32957 L
.54214 .32885 L
.53307 .32887 L
.52317 .32967 L
.51287 .33135 L
.50336 .33368 L
.4945 .33653 L
.48654 .33966 L
.46904 .34851 L
.45088 .36075 L
.43225 .37696 L
.41717 .39324 L
.40184 .41331 L
.37802 .45427 L
.36724 .4788 L
.35871 .50274 L
.35224 .52536 L
.34733 .5472 L
.34514 .55935 L
.34317 .57262 L
.34177 .58469 L
.3408 .59585 L
.34003 .60965 L
.33982 .61655 L
.33973 .62408 L
.33992 .63731 L
.3405 .64948 L
.34105 .65679 L
.34169 .66363 L
.34322 .67626 L
Mistroke
.34534 .68954 L
.34819 .70356 L
.35428 .72624 L
.36236 .74855 L
.37046 .766 L
.38057 .78336 L
.39115 .79785 L
.40201 .80978 L
.41535 .82122 L
.42818 .82944 L
.43417 .83245 L
.44064 .83517 L
.44629 .8371 L
.45246 .83875 L
.45978 .84012 L
.46671 .84084 L
.47347 .84101 L
.47969 .84072 L
.48699 .83981 L
.49387 .83841 L
.5 .83671 L
.5066 .8344 L
.52109 .82749 L
.534 .81907 L
.55585 .7992 L
.56592 .78716 L
.57615 .77249 L
.59415 .73809 L
.60211 .71701 L
.60794 .69694 L
.61188 .67891 L
.6136 .66861 L
.61489 .65901 L
.6159 .64885 L
.61651 .63965 L
.61672 .63457 L
.61685 .62909 L
.61682 .61923 L
.61648 .60991 L
.61589 .60152 L
.61491 .592 L
.61367 .58314 L
.61075 .56793 L
.60658 .55221 L
.6009 .53616 L
.59365 .52063 L
.58581 .5076 L
.57796 .49725 L
.56826 .48724 L
.55877 .47981 L
Mistroke
.54784 .47363 L
.54218 .47133 L
.53896 .47027 L
.5359 .46942 L
.53322 .46881 L
.5303 .46827 L
.52517 .46766 L
.52226 .4675 L
.51916 .46748 L
.51362 .4678 L
.50852 .46851 L
.50377 .46954 L
.4986 .47106 L
.4931 .47315 L
.48343 .47802 L
.47352 .48475 L
.45703 .50048 L
.448 .51212 L
.44034 .5243 L
.42851 .54955 L
.42378 .56346 L
.41985 .57862 L
.41737 .59177 L
.41633 .59927 L
.4156 .60628 L
.41529 .61015 L
.41504 .61436 L
.41487 .61831 L
.41479 .62196 L
.4148 .6288 L
.41506 .63599 L
.41529 .63964 L
.41561 .64355 L
.41639 .65052 L
.41762 .6586 L
.41905 .66581 L
.42217 .67774 L
.42567 .68789 L
.43045 .69868 L
.43562 .70786 L
.44619 .72154 L
.4528 .72766 L
.45922 .73222 L
.46268 .73419 L
.46647 .73598 L
.46978 .73726 L
.47344 .73836 L
.47567 .73888 L
.47775 .73927 L
.47975 .73955 L
Mistroke
.48188 .73975 L
.48595 .73987 L
.48964 .73968 L
.49169 .73945 L
.49386 .7391 L
.49772 .73825 L
.50183 .73698 L
.50628 .73519 L
.51405 .73098 L
.52098 .72594 L
.53374 .71292 L
.54009 .70407 L
.54534 .69508 L
.55324 .67701 L
.55632 .66733 L
.55897 .65637 L
.55988 .65151 L
.56068 .64639 L
.56122 .64201 L
.56167 .63722 L
.56199 .63207 L
.5621 .62921 L
.56215 .62661 L
.56212 .6216 L
.56194 .61693 L
.56164 .6126 L
.56118 .60809 L
.56069 .60431 L
.56002 .60022 L
.55813 .59145 L
.55585 .5837 L
.55269 .57548 L
.54928 .56852 L
.54504 .5617 L
.54003 .55544 L
.53485 .55049 L
.52968 .54678 L
.52486 .54424 L
.52208 .54315 L
.5195 .54237 L
.5171 .54182 L
.51452 .54144 L
.51207 .54125 L
.50985 .54124 L
.50723 .5414 L
.5044 .5418 L
.50174 .54239 L
.49931 .54312 L
.49453 .54506 L
.48941 .54793 L
Mistroke
.4843 .55172 L
.47976 .55593 L
.47125 .5666 L
.4671 .57358 L
.46374 .58055 L
.46103 .58746 L
.45891 .59421 L
.45698 .60219 L
.45633 .60568 L
.45574 .60952 L
.45531 .61305 L
.45501 .61634 L
.45479 .61981 L
.45468 .6235 L
.45469 .6269 L
.45479 .63009 L
.45496 .63292 L
.45523 .63596 L
.45562 .63921 L
.45617 .64272 L
.45763 .64956 L
.4594 .6555 L
.4614 .66071 L
.46652 .67023 L
.46991 .67472 L
.47334 .67825 L
.4772 .6813 L
.48087 .68343 L
.48296 .68434 L
.48526 .68512 L
.48632 .6854 L
.48745 .68564 L
.48949 .68595 L
.49136 .68608 L
.49308 .68608 L
.49507 .68593 L
.49694 .68564 L
.49866 .68526 L
.50024 .6848 L
.50377 .6834 L
.50757 .6813 L
.51088 .67891 L
.51424 .67589 L
.51768 .67207 L
.52333 .66371 L
.52592 .65858 L
.528 .65353 L
.52961 .64869 L
.53085 .644 L
.53142 .64138 L
Mistroke
.53194 .63851 L
.53231 .63609 L
.53262 .63348 L
.53286 .63063 L
.533 .62798 L
.53304 .62645 L
.53305 .62484 L
.533 .62201 L
.53293 .62059 L
.53283 .61908 L
.53258 .6164 L
.53238 .61479 L
.53217 .61329 L
.53168 .61054 L
.53055 .60579 L
.52923 .60168 L
.5275 .59751 L
.52538 .59353 L
.52312 .5902 L
.52078 .58746 L
.51854 .58538 L
.51597 .58351 L
.51307 .58199 L
.51141 .58136 L
.50989 .58094 L
.50845 .58066 L
.50689 .58049 L
.50542 .58045 L
.50406 .58052 L
.50279 .58068 L
.50144 .58094 L
.50017 .58128 L
.49903 .58167 L
.49627 .5829 L
.49375 .58443 L
.48907 .58844 L
.48666 .59123 L
.48462 .59408 L
.48114 .60042 L
.47954 .6043 L
.47833 .60799 L
.47742 .6115 L
.47702 .61338 L
.47667 .61539 L
.47639 .61732 L
.47619 .61908 L
.47604 .62084 L
.47595 .6225 L
.4759 .6244 L
.47591 .62647 L
Mistroke
.47595 .62751 L
.47601 .62861 L
.47616 .63057 L
.47639 .63248 L
.47666 .63426 L
.47732 .63747 L
.47835 .64104 L
.47951 .64408 L
.48101 .64713 L
.48284 .64997 L
.4845 .652 L
.48638 .65381 L
.48808 .65508 L
.49001 .65616 L
.49113 .65663 L
.49215 .65697 L
.49273 .65712 L
.49335 .65725 L
.4945 .65742 L
.49557 .65749 L
.49671 .65746 L
.49768 .65736 L
.49874 .65718 L
.49979 .65691 L
.50078 .65658 L
.5026 .65577 L
.5045 .65463 L
.50648 .65309 L
.50974 .64962 L
.51233 .64572 L
.51371 .64302 L
.51481 .64039 L
.51581 .63739 L
.51623 .63582 L
.51663 .63412 L
.51692 .63261 L
.51713 .63123 L
.51731 .62983 L
.51744 .62854 L
.51753 .62703 L
.51756 .62624 L
.51758 .62541 L
.51757 .62402 L
.51754 .62324 L
.51751 .62251 L
.51741 .62129 L
.51728 .61998 L
.51708 .61864 L
.51687 .61742 L
.51639 .6153 L
Mistroke
.51575 .61317 L
.51483 .61084 L
.51383 .60884 L
.51163 .60568 L
.51034 .60435 L
.50907 .60332 L
.5076 .60243 L
.50676 .60205 L
.50597 .60176 L
.50515 .60154 L
.50438 .6014 L
.50398 .60135 L
.50353 .60132 L
.50306 .60131 L
.50263 .60132 L
.50183 .60138 L
.50109 .6015 L
.5003 .60169 L
.49946 .60196 L
.49812 .60256 L
.49672 .6034 L
.49436 .60538 L
.49304 .60687 L
.49189 .60844 L
.49005 .61176 L
.48926 .61362 L
.48863 .61544 L
.48807 .61749 L
.48762 .61974 L
.48745 .62087 L
.48738 .62146 L
.48731 .6221 L
.48726 .62271 L
.48723 .62326 L
.48719 .62433 L
.48718 .62536 L
.48721 .62645 L
.48728 .62747 L
.48737 .62839 L
.48748 .62924 L
.48762 .63013 L
.48795 .63168 L
.48845 .63343 L
.489 .63491 L
.48967 .63634 L
.49049 .63773 L
.4922 .63982 L
.49316 .64064 L
.49368 .64101 L
.49424 .64134 L
Mistroke
.49474 .6416 L
.4953 .64183 L
.49582 .642 L
.4963 .64212 L
.4966 .64218 L
.49692 .64222 L
.49751 .64227 L
.49809 .64227 L
.49862 .64223 L
.4992 .64214 L
.49952 .64207 L
.49982 .64199 L
.50042 .64179 L
.50106 .64152 L
.50225 .64085 L
.50332 .64005 L
.50515 .63812 L
.50607 .63683 L
.50694 .63531 L
.50759 .63392 L
.50818 .63231 L
.50864 .63072 L
.50883 .6299 L
.509 .62901 L
.50913 .62817 L
.50922 .62741 L
.50929 .62664 L
.50933 .62592 L
.50934 .62553 L
.50935 .62509 L
.50935 .62464 L
.50933 .62422 L
.5093 .62348 L
.50926 .62306 L
.50923 .62269 L
.50912 .62186 L
.50897 .62099 L
.50861 .61947 L
.50817 .61814 L
.50769 .61704 L
.50705 .61589 L
.50637 .61495 L
.50574 .61425 L
.50502 .61362 L
.50464 .61334 L
.5042 .61308 L
.50379 .61288 L
.50341 .61272 L
.50296 .61258 L
.50271 .61252 L
Mistroke
.50247 .61247 L
Mfstroke
0 g
.0001 w
0 0 m
0 0 rlineto s
% Start of user PostScript
-5. -4. -5.32442 -3.52959 MAarrowhead1
% End of user PostScript
0 .08929 m
0 0 rlineto s
% Start of user PostScript
-5. -3.42857 -5.27807 -2.96743 MAarrowhead1
% End of user PostScript
0 .17857 m
0 0 rlineto s
% Start of user PostScript
-5. -2.85714 -5.23173 -2.40527 MAarrowhead1
% End of user PostScript
0 .26786 m
0 0 rlineto s
% Start of user PostScript
-5. -2.28571 -5.18538 -1.84311 MAarrowhead1
% End of user PostScript
0 .35714 m
0 0 rlineto s
% Start of user PostScript
-5. -1.71429 -5.13904 -1.28095 MAarrowhead1
% End of user PostScript
0 .44643 m
0 0 rlineto s
% Start of user PostScript
-5. -1.14286 -5.09269 -0.718795 MAarrowhead1
% End of user PostScript
0 .53571 m
0 0 rlineto s
% Start of user PostScript
-5. -0.571429 -5.04635 -0.156636 MAarrowhead1
% End of user PostScript
0 .625 m
0 .68836 L
s
% Start of user PostScript
-5. 0 -5. 0.405524 MAarrowhead1
% End of user PostScript
0 .71429 m
.00463 .7762 L
s
% Start of user PostScript
-5. 0.571429 -4.95365 0.967683 MAarrowhead1
% End of user PostScript
0 .80357 m
.00927 .86404 L
s
% Start of user PostScript
-5. 1.14286 -4.90731 1.52984 MAarrowhead1
% End of user PostScript
0 .89286 m
.0139 .95188 L
s
% Start of user PostScript
-5. 1.71429 -4.86096 2.092 MAarrowhead1
% End of user PostScript
0 .98214 m
.01854 1.03971 L
s
% Start of user PostScript
-5. 2.28571 -4.81462 2.65416 MAarrowhead1
% End of user PostScript
0 1.07143 m
.02317 1.12755 L
s
% Start of user PostScript
-5. 2.85714 -4.76827 3.21632 MAarrowhead1
% End of user PostScript
0 1.16071 m
.02781 1.21539 L
s
% Start of user PostScript
-5. 3.42857 -4.72193 3.77848 MAarrowhead1
% End of user PostScript
0 1.25 m
0 0 rlineto s
0 1.25 m
0 1.25 L
s
% Start of user PostScript
-5. 4. -4.67558 4.34064 MAarrowhead1
% End of user PostScript
.07143 0 m
.03899 .06445 L
s
% Start of user PostScript
-4.28571 -4. -4.61013 -3.58752 MAarrowhead1
% End of user PostScript
.07143 .08929 m
.04362 .15229 L
s
% Start of user PostScript
-4.28571 -3.42857 -4.56379 -3.02537 MAarrowhead1
% End of user PostScript
.07143 .17857 m
.04826 .24012 L
s
% Start of user PostScript
-4.28571 -2.85714 -4.51744 -2.46321 MAarrowhead1
% End of user PostScript
.07143 .26786 m
.05289 .32796 L
s
% Start of user PostScript
-4.28571 -2.28571 -4.4711 -1.90105 MAarrowhead1
% End of user PostScript
.07143 .35714 m
.05752 .4158 L
s
% Start of user PostScript
-4.28571 -1.71429 -4.42475 -1.33889 MAarrowhead1
% End of user PostScript
.07143 .44643 m
.06216 .50364 L
s
% Start of user PostScript
-4.28571 -1.14286 -4.37841 -0.776727 MAarrowhead1
% End of user PostScript
.07143 .53571 m
.06679 .59147 L
s
% Start of user PostScript
-4.28571 -0.571429 -4.33206 -0.214568 MAarrowhead1
% End of user PostScript
.07143 .625 m
.07143 .67931 L
s
% Start of user PostScript
-4.28571 0 -4.28571 0.347592 MAarrowhead1
% End of user PostScript
.07143 .71429 m
.07606 .76715 L
s
% Start of user PostScript
-4.28571 0.571429 -4.23937 0.909751 MAarrowhead1
% End of user PostScript
.07143 .80357 m
.0807 .85499 L
s
% Start of user PostScript
-4.28571 1.14286 -4.19302 1.47191 MAarrowhead1
% End of user PostScript
.07143 .89286 m
.08533 .94282 L
s
% Start of user PostScript
-4.28571 1.71429 -4.14668 2.03407 MAarrowhead1
% End of user PostScript
.07143 .98214 m
.08997 1.03066 L
s
% Start of user PostScript
-4.28571 2.28571 -4.10033 2.59623 MAarrowhead1
% End of user PostScript
.07143 1.07143 m
.0946 1.1185 L
s
% Start of user PostScript
-4.28571 2.85714 -4.05399 3.15839 MAarrowhead1
% End of user PostScript
.07143 1.16071 m
.09924 1.20634 L
s
% Start of user PostScript
-4.28571 3.42857 -4.00764 3.72055 MAarrowhead1
% End of user PostScript
.07143 1.25 m
0 0 rlineto s
.07143 1.25 m
.07143 1.25 L
s
% Start of user PostScript
-4.28571 4. -3.9613 4.28271 MAarrowhead1
% End of user PostScript
.14286 0 m
.11042 .0554 L
s
% Start of user PostScript
-3.57143 -4. -3.89585 -3.64546 MAarrowhead1
% End of user PostScript
.14286 .08929 m
.11505 .14323 L
s
% Start of user PostScript
-3.57143 -3.42857 -3.8495 -3.0833 MAarrowhead1
% End of user PostScript
.14286 .17857 m
.11968 .23107 L
s
% Start of user PostScript
-3.57143 -2.85714 -3.80316 -2.52114 MAarrowhead1
% End of user PostScript
.14286 .26786 m
.12432 .31891 L
s
% Start of user PostScript
-3.57143 -2.28571 -3.75681 -1.95898 MAarrowhead1
% End of user PostScript
.14286 .35714 m
.12895 .40675 L
s
% Start of user PostScript
-3.57143 -1.71429 -3.71047 -1.39682 MAarrowhead1
% End of user PostScript
.14286 .44643 m
.13359 .49458 L
s
% Start of user PostScript
-3.57143 -1.14286 -3.66412 -0.834659 MAarrowhead1
% End of user PostScript
.14286 .53571 m
.13822 .58242 L
s
% Start of user PostScript
-3.57143 -0.571429 -3.61777 -0.2725 MAarrowhead1
% End of user PostScript
.14286 .625 m
.14286 .67026 L
s
% Start of user PostScript
-3.57143 0 -3.57143 0.28966 MAarrowhead1
% End of user PostScript
.14286 .71429 m
.14749 .7581 L
s
% Start of user PostScript
-3.57143 0.571429 -3.52508 0.851819 MAarrowhead1
% End of user PostScript
.14286 .80357 m
.15213 .84593 L
s
% Start of user PostScript
-3.57143 1.14286 -3.47874 1.41398 MAarrowhead1
% End of user PostScript
.14286 .89286 m
.15676 .93377 L
s
% Start of user PostScript
-3.57143 1.71429 -3.43239 1.97614 MAarrowhead1
% End of user PostScript
.14286 .98214 m
.1614 1.02161 L
s
% Start of user PostScript
-3.57143 2.28571 -3.38605 2.5383 MAarrowhead1
% End of user PostScript
.14286 1.07143 m
.16603 1.10945 L
s
% Start of user PostScript
-3.57143 2.85714 -3.3397 3.10046 MAarrowhead1
% End of user PostScript
.14286 1.16071 m
.17066 1.19728 L
s
% Start of user PostScript
-3.57143 3.42857 -3.29336 3.66262 MAarrowhead1
% End of user PostScript
.14286 1.25 m
0 0 rlineto s
.14286 1.25 m
.14286 1.25 L
s
% Start of user PostScript
-3.57143 4. -3.24701 4.22478 MAarrowhead1
% End of user PostScript
.21429 0 m
.18184 .04635 L
s
% Start of user PostScript
-2.85714 -4. -3.18156 -3.70339 MAarrowhead1
% End of user PostScript
.21429 .08929 m
.18648 .13418 L
s
% Start of user PostScript
-2.85714 -3.42857 -3.13522 -3.14123 MAarrowhead1
% End of user PostScript
.21429 .17857 m
.19111 .22202 L
s
% Start of user PostScript
-2.85714 -2.85714 -3.08887 -2.57907 MAarrowhead1
% End of user PostScript
.21429 .26786 m
.19575 .30986 L
s
% Start of user PostScript
-2.85714 -2.28571 -3.04253 -2.01691 MAarrowhead1
% End of user PostScript
.21429 .35714 m
.20038 .3977 L
s
% Start of user PostScript
-2.85714 -1.71429 -2.99618 -1.45475 MAarrowhead1
% End of user PostScript
.21429 .44643 m
.20502 .48553 L
s
% Start of user PostScript
-2.85714 -1.14286 -2.94983 -0.892591 MAarrowhead1
% End of user PostScript
.21429 .53571 m
.20965 .57337 L
s
% Start of user PostScript
-2.85714 -0.571429 -2.90349 -0.330432 MAarrowhead1
% End of user PostScript
.21429 .625 m
.21429 .66121 L
s
% Start of user PostScript
-2.85714 0 -2.85714 0.231728 MAarrowhead1
% End of user PostScript
.21429 .71429 m
.21892 .74904 L
s
% Start of user PostScript
-2.85714 0.571429 -2.8108 0.793887 MAarrowhead1
% End of user PostScript
.21429 .80357 m
.22355 .83688 L
s
% Start of user PostScript
-2.85714 1.14286 -2.76445 1.35605 MAarrowhead1
% End of user PostScript
.21429 .89286 m
.22819 .92472 L
s
% Start of user PostScript
-2.85714 1.71429 -2.71811 1.91821 MAarrowhead1
% End of user PostScript
.21429 .98214 m
.23282 1.01256 L
s
% Start of user PostScript
-2.85714 2.28571 -2.67176 2.48037 MAarrowhead1
% End of user PostScript
.21429 1.07143 m
.23746 1.10039 L
s
% Start of user PostScript
-2.85714 2.85714 -2.62542 3.04253 MAarrowhead1
% End of user PostScript
.21429 1.16071 m
.24209 1.18823 L
s
% Start of user PostScript
-2.85714 3.42857 -2.57907 3.60468 MAarrowhead1
% End of user PostScript
.21429 1.25 m
0 0 rlineto s
.21429 1.25 m
.21429 1.25 L
s
% Start of user PostScript
-2.85714 4. -2.53272 4.16684 MAarrowhead1
% End of user PostScript
.28571 0 m
.25327 .03729 L
s
% Start of user PostScript
-2.14286 -4. -2.46728 -3.76132 MAarrowhead1
% End of user PostScript
.28571 .08929 m
.25791 .12513 L
s
% Start of user PostScript
-2.14286 -3.42857 -2.42093 -3.19916 MAarrowhead1
% End of user PostScript
.28571 .17857 m
.26254 .21297 L
s
% Start of user PostScript
-2.14286 -2.85714 -2.37458 -2.637 MAarrowhead1
% End of user PostScript
.28571 .26786 m
.26718 .30081 L
s
% Start of user PostScript
-2.14286 -2.28571 -2.32824 -2.07484 MAarrowhead1
% End of user PostScript
.28571 .35714 m
.27181 .38864 L
s
% Start of user PostScript
-2.14286 -1.71429 -2.28189 -1.51268 MAarrowhead1
% End of user PostScript
.28571 .44643 m
.27645 .47648 L
s
% Start of user PostScript
-2.14286 -1.14286 -2.23555 -0.950523 MAarrowhead1
% End of user PostScript
.28571 .53571 m
.28108 .56432 L
s
% Start of user PostScript
-2.14286 -0.571429 -2.1892 -0.388364 MAarrowhead1
% End of user PostScript
.28571 .625 m
.28571 .65216 L
s
% Start of user PostScript
-2.14286 0 -2.14286 0.173796 MAarrowhead1
% End of user PostScript
.28571 .71429 m
.29035 .73999 L
s
% Start of user PostScript
-2.14286 0.571429 -2.09651 0.735955 MAarrowhead1
% End of user PostScript
.28571 .80357 m
.29498 .82783 L
s
% Start of user PostScript
-2.14286 1.14286 -2.05017 1.29811 MAarrowhead1
% End of user PostScript
.28571 .89286 m
.29962 .91567 L
s
% Start of user PostScript
-2.14286 1.71429 -2.00382 1.86027 MAarrowhead1
% End of user PostScript
.28571 .98214 m
.30425 1.00351 L
s
% Start of user PostScript
-2.14286 2.28571 -1.95747 2.42243 MAarrowhead1
% End of user PostScript
.28571 1.07143 m
.30889 1.09134 L
s
% Start of user PostScript
-2.14286 2.85714 -1.91113 2.98459 MAarrowhead1
% End of user PostScript
.28571 1.16071 m
.31352 1.17918 L
s
% Start of user PostScript
-2.14286 3.42857 -1.86478 3.54675 MAarrowhead1
% End of user PostScript
.28571 1.25 m
0 0 rlineto s
.28571 1.25 m
.28571 1.25 L
s
% Start of user PostScript
-2.14286 4. -1.81844 4.10891 MAarrowhead1
% End of user PostScript
.35714 0 m
.3247 .02824 L
s
% Start of user PostScript
-1.42857 -4. -1.75299 -3.81925 MAarrowhead1
% End of user PostScript
.35714 .08929 m
.32934 .11608 L
s
% Start of user PostScript
-1.42857 -3.42857 -1.70664 -3.25709 MAarrowhead1
% End of user PostScript
.35714 .17857 m
.33397 .20392 L
s
% Start of user PostScript
-1.42857 -2.85714 -1.6603 -2.69493 MAarrowhead1
% End of user PostScript
.35714 .26786 m
.3386 .29175 L
s
% Start of user PostScript
-1.42857 -2.28571 -1.61395 -2.13277 MAarrowhead1
% End of user PostScript
.35714 .35714 m
.34324 .37959 L
s
% Start of user PostScript
-1.42857 -1.71429 -1.56761 -1.57061 MAarrowhead1
% End of user PostScript
.35714 .44643 m
.34787 .46743 L
s
% Start of user PostScript
-1.42857 -1.14286 -1.52126 -1.00846 MAarrowhead1
% End of user PostScript
.35714 .53571 m
.35251 .55527 L
s
% Start of user PostScript
-1.42857 -0.571429 -1.47492 -0.446296 MAarrowhead1
% End of user PostScript
.35714 .625 m
.35714 .6431 L
s
% Start of user PostScript
-1.42857 0 -1.42857 0.115864 MAarrowhead1
% End of user PostScript
.35714 .71429 m
.36178 .73094 L
s
% Start of user PostScript
-1.42857 0.571429 -1.38223 0.678023 MAarrowhead1
% End of user PostScript
.35714 .80357 m
.36641 .81878 L
s
% Start of user PostScript
-1.42857 1.14286 -1.33588 1.24018 MAarrowhead1
% End of user PostScript
.35714 .89286 m
.37105 .90662 L
s
% Start of user PostScript
-1.42857 1.71429 -1.28953 1.80234 MAarrowhead1
% End of user PostScript
.35714 .98214 m
.37568 .99445 L
s
% Start of user PostScript
-1.42857 2.28571 -1.24319 2.3645 MAarrowhead1
% End of user PostScript
.35714 1.07143 m
.38032 1.08229 L
s
% Start of user PostScript
-1.42857 2.85714 -1.19684 2.92666 MAarrowhead1
% End of user PostScript
.35714 1.16071 m
.38495 1.17013 L
s
% Start of user PostScript
-1.42857 3.42857 -1.1505 3.48882 MAarrowhead1
% End of user PostScript
.35714 1.25 m
0 0 rlineto s
.35714 1.25 m
.35714 1.25 L
s
% Start of user PostScript
-1.42857 4. -1.10415 4.05098 MAarrowhead1
% End of user PostScript
.42857 0 m
.39613 .01919 L
s
% Start of user PostScript
-0.714286 -4. -1.0387 -3.87718 MAarrowhead1
% End of user PostScript
.42857 .08929 m
.40076 .10703 L
s
% Start of user PostScript
-0.714286 -3.42857 -0.992359 -3.31502 MAarrowhead1
% End of user PostScript
.42857 .17857 m
.4054 .19486 L
s
% Start of user PostScript
-0.714286 -2.85714 -0.946013 -2.75287 MAarrowhead1
% End of user PostScript
.42857 .26786 m
.41003 .2827 L
s
% Start of user PostScript
-0.714286 -2.28571 -0.899668 -2.19071 MAarrowhead1
% End of user PostScript
.42857 .35714 m
.41467 .37054 L
s
% Start of user PostScript
-0.714286 -1.71429 -0.853322 -1.62855 MAarrowhead1
% End of user PostScript
.42857 .44643 m
.4193 .45838 L
s
% Start of user PostScript
-0.714286 -1.14286 -0.806977 -1.06639 MAarrowhead1
% End of user PostScript
.42857 .53571 m
.42394 .54621 L
s
% Start of user PostScript
-0.714286 -0.571429 -0.760631 -0.504228 MAarrowhead1
% End of user PostScript
.42857 .625 m
.42857 .63405 L
s
% Start of user PostScript
-0.714286 0 -0.714286 0.0579319 MAarrowhead1
% End of user PostScript
.42857 .71429 m
.43321 .72189 L
s
% Start of user PostScript
-0.714286 0.571429 -0.66794 0.620091 MAarrowhead1
% End of user PostScript
.42857 .80357 m
.43784 .80973 L
s
% Start of user PostScript
-0.714286 1.14286 -0.621595 1.18225 MAarrowhead1
% End of user PostScript
.42857 .89286 m
.44248 .89756 L
s
% Start of user PostScript
-0.714286 1.71429 -0.575249 1.74441 MAarrowhead1
% End of user PostScript
.42857 .98214 m
.44711 .9854 L
s
% Start of user PostScript
-0.714286 2.28571 -0.528904 2.30657 MAarrowhead1
% End of user PostScript
.42857 1.07143 m
.45174 1.07324 L
s
% Start of user PostScript
-0.714286 2.85714 -0.482558 2.86873 MAarrowhead1
% End of user PostScript
.42857 1.16071 m
.45638 1.16108 L
s
% Start of user PostScript
-0.714286 3.42857 -0.436212 3.43089 MAarrowhead1
% End of user PostScript
.42857 1.25 m
.46101 1.24891 L
s
% Start of user PostScript
-0.714286 4. -0.389867 3.99305 MAarrowhead1
% End of user PostScript
.5 0 m
.46756 .01014 L
s
% Start of user PostScript
0 -4. -0.324419 -3.93512 MAarrowhead1
% End of user PostScript
.5 .08929 m
.47219 .09798 L
s
% Start of user PostScript
0 -3.42857 -0.278073 -3.37296 MAarrowhead1
% End of user PostScript
.5 .17857 m
.47683 .18581 L
s
% Start of user PostScript
0 -2.85714 -0.231728 -2.8108 MAarrowhead1
% End of user PostScript
.5 .26786 m
.48146 .27365 L
s
% Start of user PostScript
0 -2.28571 -0.185382 -2.24864 MAarrowhead1
% End of user PostScript
.5 .35714 m
.4861 .36149 L
s
% Start of user PostScript
0 -1.71429 -0.139037 -1.68648 MAarrowhead1
% End of user PostScript
.5 .44643 m
.49073 .44933 L
s
% Start of user PostScript
0 -1.14286 -0.0926911 -1.12432 MAarrowhead1
% End of user PostScript
.5 .53571 m
.49537 .53716 L
s
% Start of user PostScript
0 -0.571429 -0.0463455 -0.562159 MAarrowhead1
% End of user PostScript
.5 .625 m
.5 .625 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .71429 m
.50463 .71284 L
s
% Start of user PostScript
0 0.571429 0.0463455 0.562159 MAarrowhead1
% End of user PostScript
.5 .80357 m
.50927 .80067 L
s
% Start of user PostScript
0 1.14286 0.0926911 1.12432 MAarrowhead1
% End of user PostScript
.5 .89286 m
.5139 .88851 L
s
% Start of user PostScript
0 1.71429 0.139037 1.68648 MAarrowhead1
% End of user PostScript
.5 .98214 m
.51854 .97635 L
s
% Start of user PostScript
0 2.28571 0.185382 2.24864 MAarrowhead1
% End of user PostScript
.5 1.07143 m
.52317 1.06419 L
s
% Start of user PostScript
0 2.85714 0.231728 2.8108 MAarrowhead1
% End of user PostScript
.5 1.16071 m
.52781 1.15202 L
s
% Start of user PostScript
0 3.42857 0.278073 3.37296 MAarrowhead1
% End of user PostScript
.5 1.25 m
.53244 1.23986 L
s
% Start of user PostScript
0 4. 0.324419 3.93512 MAarrowhead1
% End of user PostScript
.57143 0 m
.53899 .00109 L
s
% Start of user PostScript
0.714286 -4. 0.389867 -3.99305 MAarrowhead1
% End of user PostScript
.57143 .08929 m
.54362 .08892 L
s
% Start of user PostScript
0.714286 -3.42857 0.436212 -3.43089 MAarrowhead1
% End of user PostScript
.57143 .17857 m
.54826 .17676 L
s
% Start of user PostScript
0.714286 -2.85714 0.482558 -2.86873 MAarrowhead1
% End of user PostScript
.57143 .26786 m
.55289 .2646 L
s
% Start of user PostScript
0.714286 -2.28571 0.528904 -2.30657 MAarrowhead1
% End of user PostScript
.57143 .35714 m
.55752 .35244 L
s
% Start of user PostScript
0.714286 -1.71429 0.575249 -1.74441 MAarrowhead1
% End of user PostScript
.57143 .44643 m
.56216 .44027 L
s
% Start of user PostScript
0.714286 -1.14286 0.621595 -1.18225 MAarrowhead1
% End of user PostScript
.57143 .53571 m
.56679 .52811 L
s
% Start of user PostScript
0.714286 -0.571429 0.66794 -0.620091 MAarrowhead1
% End of user PostScript
.57143 .625 m
.57143 .61595 L
s
% Start of user PostScript
0.714286 0 0.714286 -0.0579319 MAarrowhead1
% End of user PostScript
.57143 .71429 m
.57606 .70379 L
s
% Start of user PostScript
0.714286 0.571429 0.760631 0.504228 MAarrowhead1
% End of user PostScript
.57143 .80357 m
.5807 .79162 L
s
% Start of user PostScript
0.714286 1.14286 0.806977 1.06639 MAarrowhead1
% End of user PostScript
.57143 .89286 m
.58533 .87946 L
s
% Start of user PostScript
0.714286 1.71429 0.853322 1.62855 MAarrowhead1
% End of user PostScript
.57143 .98214 m
.58997 .9673 L
s
% Start of user PostScript
0.714286 2.28571 0.899668 2.19071 MAarrowhead1
% End of user PostScript
.57143 1.07143 m
.5946 1.05514 L
s
% Start of user PostScript
0.714286 2.85714 0.946013 2.75287 MAarrowhead1
% End of user PostScript
.57143 1.16071 m
.59924 1.14297 L
s
% Start of user PostScript
0.714286 3.42857 0.992359 3.31502 MAarrowhead1
% End of user PostScript
.57143 1.25 m
.60387 1.23081 L
s
% Start of user PostScript
0.714286 4. 1.0387 3.87718 MAarrowhead1
% End of user PostScript
.64286 0 m
0 0 rlineto s
% Start of user PostScript
1.42857 -4. 1.10415 -4.05098 MAarrowhead1
% End of user PostScript
.64286 .08929 m
.61505 .07987 L
s
% Start of user PostScript
1.42857 -3.42857 1.1505 -3.48882 MAarrowhead1
% End of user PostScript
.64286 .17857 m
.61968 .16771 L
s
% Start of user PostScript
1.42857 -2.85714 1.19684 -2.92666 MAarrowhead1
% End of user PostScript
.64286 .26786 m
.62432 .25555 L
s
% Start of user PostScript
1.42857 -2.28571 1.24319 -2.3645 MAarrowhead1
% End of user PostScript
.64286 .35714 m
.62895 .34338 L
s
% Start of user PostScript
1.42857 -1.71429 1.28953 -1.80234 MAarrowhead1
% End of user PostScript
.64286 .44643 m
.63359 .43122 L
s
% Start of user PostScript
1.42857 -1.14286 1.33588 -1.24018 MAarrowhead1
% End of user PostScript
.64286 .53571 m
.63822 .51906 L
s
% Start of user PostScript
1.42857 -0.571429 1.38223 -0.678023 MAarrowhead1
% End of user PostScript
.64286 .625 m
.64286 .6069 L
s
% Start of user PostScript
1.42857 0 1.42857 -0.115864 MAarrowhead1
% End of user PostScript
.64286 .71429 m
.64749 .69473 L
s
% Start of user PostScript
1.42857 0.571429 1.47492 0.446296 MAarrowhead1
% End of user PostScript
.64286 .80357 m
.65213 .78257 L
s
% Start of user PostScript
1.42857 1.14286 1.52126 1.00846 MAarrowhead1
% End of user PostScript
.64286 .89286 m
.65676 .87041 L
s
% Start of user PostScript
1.42857 1.71429 1.56761 1.57061 MAarrowhead1
% End of user PostScript
.64286 .98214 m
.6614 .95825 L
s
% Start of user PostScript
1.42857 2.28571 1.61395 2.13277 MAarrowhead1
% End of user PostScript
.64286 1.07143 m
.66603 1.04608 L
s
% Start of user PostScript
1.42857 2.85714 1.6603 2.69493 MAarrowhead1
% End of user PostScript
.64286 1.16071 m
.67066 1.13392 L
s
% Start of user PostScript
1.42857 3.42857 1.70664 3.25709 MAarrowhead1
% End of user PostScript
.64286 1.25 m
.6753 1.22176 L
s
% Start of user PostScript
1.42857 4. 1.75299 3.81925 MAarrowhead1
% End of user PostScript
.71429 0 m
0 0 rlineto s
% Start of user PostScript
2.14286 -4. 1.81844 -4.10891 MAarrowhead1
% End of user PostScript
.71429 .08929 m
.68648 .07082 L
s
% Start of user PostScript
2.14286 -3.42857 1.86478 -3.54675 MAarrowhead1
% End of user PostScript
.71429 .17857 m
.69111 .15866 L
s
% Start of user PostScript
2.14286 -2.85714 1.91113 -2.98459 MAarrowhead1
% End of user PostScript
.71429 .26786 m
.69575 .24649 L
s
% Start of user PostScript
2.14286 -2.28571 1.95747 -2.42243 MAarrowhead1
% End of user PostScript
.71429 .35714 m
.70038 .33433 L
s
% Start of user PostScript
2.14286 -1.71429 2.00382 -1.86027 MAarrowhead1
% End of user PostScript
.71429 .44643 m
.70502 .42217 L
s
% Start of user PostScript
2.14286 -1.14286 2.05017 -1.29811 MAarrowhead1
% End of user PostScript
.71429 .53571 m
.70965 .51001 L
s
% Start of user PostScript
2.14286 -0.571429 2.09651 -0.735955 MAarrowhead1
% End of user PostScript
.71429 .625 m
.71429 .59784 L
s
% Start of user PostScript
2.14286 0 2.14286 -0.173796 MAarrowhead1
% End of user PostScript
.71429 .71429 m
.71892 .68568 L
s
% Start of user PostScript
2.14286 0.571429 2.1892 0.388364 MAarrowhead1
% End of user PostScript
.71429 .80357 m
.72355 .77352 L
s
% Start of user PostScript
2.14286 1.14286 2.23555 0.950523 MAarrowhead1
% End of user PostScript
.71429 .89286 m
.72819 .86136 L
s
% Start of user PostScript
2.14286 1.71429 2.28189 1.51268 MAarrowhead1
% End of user PostScript
.71429 .98214 m
.73282 .94919 L
s
% Start of user PostScript
2.14286 2.28571 2.32824 2.07484 MAarrowhead1
% End of user PostScript
.71429 1.07143 m
.73746 1.03703 L
s
% Start of user PostScript
2.14286 2.85714 2.37458 2.637 MAarrowhead1
% End of user PostScript
.71429 1.16071 m
.74209 1.12487 L
s
% Start of user PostScript
2.14286 3.42857 2.42093 3.19916 MAarrowhead1
% End of user PostScript
.71429 1.25 m
.74673 1.21271 L
s
% Start of user PostScript
2.14286 4. 2.46728 3.76132 MAarrowhead1
% End of user PostScript
.78571 0 m
0 0 rlineto s
% Start of user PostScript
2.85714 -4. 2.53272 -4.16684 MAarrowhead1
% End of user PostScript
.78571 .08929 m
.75791 .06177 L
s
% Start of user PostScript
2.85714 -3.42857 2.57907 -3.60468 MAarrowhead1
% End of user PostScript
.78571 .17857 m
.76254 .14961 L
s
% Start of user PostScript
2.85714 -2.85714 2.62542 -3.04253 MAarrowhead1
% End of user PostScript
.78571 .26786 m
.76718 .23744 L
s
% Start of user PostScript
2.85714 -2.28571 2.67176 -2.48037 MAarrowhead1
% End of user PostScript
.78571 .35714 m
.77181 .32528 L
s
% Start of user PostScript
2.85714 -1.71429 2.71811 -1.91821 MAarrowhead1
% End of user PostScript
.78571 .44643 m
.77645 .41312 L
s
% Start of user PostScript
2.85714 -1.14286 2.76445 -1.35605 MAarrowhead1
% End of user PostScript
.78571 .53571 m
.78108 .50096 L
s
% Start of user PostScript
2.85714 -0.571429 2.8108 -0.793887 MAarrowhead1
% End of user PostScript
.78571 .625 m
.78571 .58879 L
s
% Start of user PostScript
2.85714 0 2.85714 -0.231728 MAarrowhead1
% End of user PostScript
.78571 .71429 m
.79035 .67663 L
s
% Start of user PostScript
2.85714 0.571429 2.90349 0.330432 MAarrowhead1
% End of user PostScript
.78571 .80357 m
.79498 .76447 L
s
% Start of user PostScript
2.85714 1.14286 2.94983 0.892591 MAarrowhead1
% End of user PostScript
.78571 .89286 m
.79962 .8523 L
s
% Start of user PostScript
2.85714 1.71429 2.99618 1.45475 MAarrowhead1
% End of user PostScript
.78571 .98214 m
.80425 .94014 L
s
% Start of user PostScript
2.85714 2.28571 3.04253 2.01691 MAarrowhead1
% End of user PostScript
.78571 1.07143 m
.80889 1.02798 L
s
% Start of user PostScript
2.85714 2.85714 3.08887 2.57907 MAarrowhead1
% End of user PostScript
.78571 1.16071 m
.81352 1.11582 L
s
% Start of user PostScript
2.85714 3.42857 3.13522 3.14123 MAarrowhead1
% End of user PostScript
.78571 1.25 m
.81816 1.20365 L
s
% Start of user PostScript
2.85714 4. 3.18156 3.70339 MAarrowhead1
% End of user PostScript
.85714 0 m
0 0 rlineto s
% Start of user PostScript
3.57143 -4. 3.24701 -4.22478 MAarrowhead1
% End of user PostScript
.85714 .08929 m
.82934 .05272 L
s
% Start of user PostScript
3.57143 -3.42857 3.29336 -3.66262 MAarrowhead1
% End of user PostScript
.85714 .17857 m
.83397 .14055 L
s
% Start of user PostScript
3.57143 -2.85714 3.3397 -3.10046 MAarrowhead1
% End of user PostScript
.85714 .26786 m
.8386 .22839 L
s
% Start of user PostScript
3.57143 -2.28571 3.38605 -2.5383 MAarrowhead1
% End of user PostScript
.85714 .35714 m
.84324 .31623 L
s
% Start of user PostScript
3.57143 -1.71429 3.43239 -1.97614 MAarrowhead1
% End of user PostScript
.85714 .44643 m
.84787 .40407 L
s
% Start of user PostScript
3.57143 -1.14286 3.47874 -1.41398 MAarrowhead1
% End of user PostScript
.85714 .53571 m
.85251 .4919 L
s
% Start of user PostScript
3.57143 -0.571429 3.52508 -0.851819 MAarrowhead1
% End of user PostScript
.85714 .625 m
.85714 .57974 L
s
% Start of user PostScript
3.57143 0 3.57143 -0.28966 MAarrowhead1
% End of user PostScript
.85714 .71429 m
.86178 .66758 L
s
% Start of user PostScript
3.57143 0.571429 3.61777 0.2725 MAarrowhead1
% End of user PostScript
.85714 .80357 m
.86641 .75542 L
s
% Start of user PostScript
3.57143 1.14286 3.66412 0.834659 MAarrowhead1
% End of user PostScript
.85714 .89286 m
.87105 .84325 L
s
% Start of user PostScript
3.57143 1.71429 3.71047 1.39682 MAarrowhead1
% End of user PostScript
.85714 .98214 m
.87568 .93109 L
s
% Start of user PostScript
3.57143 2.28571 3.75681 1.95898 MAarrowhead1
% End of user PostScript
.85714 1.07143 m
.88032 1.01893 L
s
% Start of user PostScript
3.57143 2.85714 3.80316 2.52114 MAarrowhead1
% End of user PostScript
.85714 1.16071 m
.88495 1.10677 L
s
% Start of user PostScript
3.57143 3.42857 3.8495 3.0833 MAarrowhead1
% End of user PostScript
.85714 1.25 m
.88958 1.1946 L
s
% Start of user PostScript
3.57143 4. 3.89585 3.64546 MAarrowhead1
% End of user PostScript
.92857 0 m
0 0 rlineto s
% Start of user PostScript
4.28571 -4. 3.9613 -4.28271 MAarrowhead1
% End of user PostScript
.92857 .08929 m
.90076 .04366 L
s
% Start of user PostScript
4.28571 -3.42857 4.00764 -3.72055 MAarrowhead1
% End of user PostScript
.92857 .17857 m
.9054 .1315 L
s
% Start of user PostScript
4.28571 -2.85714 4.05399 -3.15839 MAarrowhead1
% End of user PostScript
.92857 .26786 m
.91003 .21934 L
s
% Start of user PostScript
4.28571 -2.28571 4.10033 -2.59623 MAarrowhead1
% End of user PostScript
.92857 .35714 m
.91467 .30718 L
s
% Start of user PostScript
4.28571 -1.71429 4.14668 -2.03407 MAarrowhead1
% End of user PostScript
.92857 .44643 m
.9193 .39501 L
s
% Start of user PostScript
4.28571 -1.14286 4.19302 -1.47191 MAarrowhead1
% End of user PostScript
.92857 .53571 m
.92394 .48285 L
s
% Start of user PostScript
4.28571 -0.571429 4.23937 -0.909751 MAarrowhead1
% End of user PostScript
.92857 .625 m
.92857 .57069 L
s
% Start of user PostScript
4.28571 0 4.28571 -0.347592 MAarrowhead1
% End of user PostScript
.92857 .71429 m
.93321 .65853 L
s
% Start of user PostScript
4.28571 0.571429 4.33206 0.214568 MAarrowhead1
% End of user PostScript
.92857 .80357 m
.93784 .74636 L
s
% Start of user PostScript
4.28571 1.14286 4.37841 0.776727 MAarrowhead1
% End of user PostScript
.92857 .89286 m
.94248 .8342 L
s
% Start of user PostScript
4.28571 1.71429 4.42475 1.33889 MAarrowhead1
% End of user PostScript
.92857 .98214 m
.94711 .92204 L
s
% Start of user PostScript
4.28571 2.28571 4.4711 1.90105 MAarrowhead1
% End of user PostScript
.92857 1.07143 m
.95174 1.00988 L
s
% Start of user PostScript
4.28571 2.85714 4.51744 2.46321 MAarrowhead1
% End of user PostScript
.92857 1.16071 m
.95638 1.09771 L
s
% Start of user PostScript
4.28571 3.42857 4.56379 3.02537 MAarrowhead1
% End of user PostScript
.92857 1.25 m
.96101 1.18555 L
s
% Start of user PostScript
4.28571 4. 4.61013 3.58752 MAarrowhead1
% End of user PostScript
1 0 m
0 0 rlineto s
% Start of user PostScript
5. -4. 4.67558 -4.34064 MAarrowhead1
% End of user PostScript
1 .08929 m
.97219 .03461 L
s
% Start of user PostScript
5. -3.42857 4.72193 -3.77848 MAarrowhead1
% End of user PostScript
1 .17857 m
.97683 .12245 L
s
% Start of user PostScript
5. -2.85714 4.76827 -3.21632 MAarrowhead1
% End of user PostScript
1 .26786 m
.98146 .21029 L
s
% Start of user PostScript
5. -2.28571 4.81462 -2.65416 MAarrowhead1
% End of user PostScript
1 .35714 m
.9861 .29812 L
s
% Start of user PostScript
5. -1.71429 4.86096 -2.092 MAarrowhead1
% End of user PostScript
1 .44643 m
.99073 .38596 L
s
% Start of user PostScript
5. -1.14286 4.90731 -1.52984 MAarrowhead1
% End of user PostScript
1 .53571 m
.99537 .4738 L
s
% Start of user PostScript
5. -0.571429 4.95365 -0.967683 MAarrowhead1
% End of user PostScript
1 .625 m
1 .56164 L
s
% Start of user PostScript
5. 0 5. -0.405524 MAarrowhead1
% End of user PostScript
1 .71429 m
0 0 rlineto s
1 .71429 m
1 .71429 L
s
% Start of user PostScript
5. 0.571429 5.04635 0.156636 MAarrowhead1
% End of user PostScript
1 .80357 m
0 0 rlineto s
1 .80357 m
1 .80357 L
s
% Start of user PostScript
5. 1.14286 5.09269 0.718795 MAarrowhead1
% End of user PostScript
1 .89286 m
0 0 rlineto s
1 .89286 m
1 .89286 L
s
% Start of user PostScript
5. 1.71429 5.13904 1.28095 MAarrowhead1
% End of user PostScript
1 .98214 m
0 0 rlineto s
1 .98214 m
1 .98214 L
s
% Start of user PostScript
5. 2.28571 5.18538 1.84311 MAarrowhead1
% End of user PostScript
1 1.07143 m
0 0 rlineto s
1 1.07143 m
1 1.07143 L
s
% Start of user PostScript
5. 2.85714 5.23173 2.40527 MAarrowhead1
% End of user PostScript
1 1.16071 m
0 0 rlineto s
1 1.16071 m
1 1.16071 L
s
% Start of user PostScript
5. 3.42857 5.27807 2.96743 MAarrowhead1
% End of user PostScript
1 1.25 m
0 0 rlineto s
1 1.25 m
1 1.25 L
s
% Start of user PostScript
5. 4. 5.32442 3.52959 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{158.938, 198.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002N0000aR000`400?l00000o`00003oW_ooool0
09kooooo0019ooooo`?o0000D_ooool004[ooooo00?o0000ooooooooool0DOooool000?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo1Ol0
00000ooooooo0000o`000007o`0000Kooooo1?l00007ooooo`;o000000?oooooo`000?ooool01_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo000>ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Cooooo00?o0000ooooooooool00ol0
00000ooooooo0000ooooo`04ooooo`Co00002_ooool00ol0003oooooooooo`0iooooo`003Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`;o00002?ooool3o`0000Gooooo00?o0000ooooool000001?l0001?
ooooo`003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool2o`0000Wooooo0_l00007ooooo`;o00002?ooool2o`0000?ooooo00?o0000oooo
ooooool0COooool000cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooo
ooooooooo`00001?ooooo`003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool2o`0004ko
oooo000;ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`02oooooa3o0?l0<oooool00ol0003ooooo
ooooo`05ooooo`002_ooool2o`0000Wooooo0_l00007ooooo`03o`000?oooooooooo02cooooo1_l0
o`0@ooooo`?o0?l09Oooool00ol0003oooooooooo`08ooooo`;o00001_ooool000[ooooo0_l00008
ooooo`;o0000=_ooool00ol0o`3oooooo`00000Gooooo`?o0?l05oooool2o`0000Wooooo0_l00009
ooooo`?o00001Oooool000Wooooo0_l00009ooooo`03o`000?oooooooooo03?ooooo0_l0o`02oooo
o`03o`000?oooooooooo01Sooooo0_l0o`0Eooooo`?o00002Oooool2o`0000Sooooo0_l00006oooo
o`002Oooool00ol0003oooooooooo`0kooooo`?o0?l01?ooool2o`0001_ooooo0_l0o`08ooooo`?o
00002Oooool3o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`00
AOooool2o`3o00Oooooo00Co0000oooooooooooooooo4Ol0o`08ooooo`;o00000_l0o`07ooooo`?o
00002?ooool2o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`00
A?ooool00ol0o`3oooooooooo`07ooooo`04o`000?oooooo0?l0o`3o00kooooo0ol00003o`3o00Ko
oooo0_l000000ooooooo0?l0ooooo`06ooooo`;o00002Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool004;ooooo0_l0o`09ooooo`?o0?l0
1oooool2o`0000Sooooo0ol00002ooooo`;o0?l01Oooool2o`000003ooooool0o`3ooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool000?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00Co0?l0o`000?l0003o00001Oooool2o`3o00?o0000
1_ooool5o`0000Sooooo00?o0000ooooool000000oooool3o`3o00Cooooo00?o0000ooooool0o`00
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooo000000Oooooo00?o0?l0o`000?l000001?ooool3o`3o00Ko00002?ooool00ol0003ooooooooo
o`0@ooooo`03o`3o0?oooooooooo00Cooooo0_l0o`0Zooooo`003Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000008
ooooo`;o00001oooool01Ol0o`3o0000o`000?l0003ooooo00?o0?l01oooool00ol0003ooooooooo
o`0Kooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool09oooool000gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0_l00008
ooooo`;o00001oooool00ol0o`3o0000o`000002ooooo`03o`3o0?oooooooooo00Sooooo00?o0000
ooooooooool07?ooool2o`3o00Kooooo00?o0?l0ooooooooool09_ooool000cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`;o00002?ooool2o`0000Wooooo00?o0000oooo
ooooool01Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Wooooo00?o0000oooo
ooooool07_ooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo02Gooooo000<ooooo`03
o`000?oooooooooo00Kooooo0_l00009ooooo`;o00002?ooool00ol0003oooooooooo`0?ooooo`03
o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool02_ooool2o`00023ooooo0_l0o`05ooooo`03
o`3o0?oooooooooo01cooooo00?o0000ooooooooool01Oooool000[ooooo00?o0000ooooool00000
2?ooool2o`0000Sooooo0_l0000Jooooo`04o`3o0?ooooooooooooooo`;o0?l03Oooool00ol0003o
ooooooooo`0Qooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool04Oooool00ol0003o
ooooooooo`07ooooo`;o00001_ooool000[ooooo0_l00008ooooo`;o00002Oooool00ol0003ooooo
ooooo`0Hooooo`05o`3o0?ooooooooooooooool0o`002Oooool3o`0000?ooooo00?o0000oooooooo
ool08_ooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo013ooooo00?o0000oooooooo
ool02?ooool2o`0000Gooooo000:ooooo`;o00002?ooool00ol0003oooooooooo`0Rooooo`05o`3o
0?ooooooooooooooool0o`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool08_ooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool2o`0000Wooooo00?o0000ooooooooool01?ooool000[ooooo00?o0000oooooooo
ool0:oooool01Ol0o`3ooooooooooooooooo0?l000Cooooo1Ol00005ooooo`04o`000?oooooooooo
o`0002Gooooo00Co0?l0ooooool0003o00000oooool00ol0o`3oooooooooo`03ooooo`;o00002Ooo
ool3o`0000Wooooo00?o0000ooooooooool00oooool003Oooooo00Go0?l0ooooooooooooooooo`3o
000=ooooo`;o00000oooool2o`0001_ooooo0_l00008ooooo`04o`3o0?l0003o0000o`0000?ooooo
00?o0?l0ooooooooool00oooool2o`0000[ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`00=_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00gooooo00Co
0000oooooooooooo00007?ooool3o`0000Sooooo00Co0?l0o`000?l0003o00002?ooool2o`0000[o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`00=_ooool01Ol0o`3ooooo
oooooooooooo0?l000cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
013ooooo1?l00007ooooo`?o00002?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`000oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00Go0?l0ooooooooooooooooo`000008oooo
o`?o00000oooool3o`0000;ooooo0_l00007ooooo`Co00002?ooool3o`0000Sooooo00?o0000oooo
ool000001oooool01?l0o`3oooooooooool00009ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`01ooooo`003_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03oooo
o`03o`3o0?oooooooooo00;o00002Oooool00ol0003oooooooooo`06ooooo`Co00002_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0?l0ooooooooool08oooool000go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00oooool01?l0o`3oooooooooooooool2o`0000Sooooo0ol0000:oooo
o`;o0000:Oooool00ol0o`3oooooooooo`0Rooooo`003Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0000Cooooo00Go0?l0oooooooo
ooooooooo`000009ooooo`;o00003?ooool00ol0003oooooooooo`0Yooooo`03o`3o0?oooooooooo
027ooooo000=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`;o00000oooool01_l0o`3ooooooooooooooooo0000o`3o01Oooooo00?o0000
ooooooooool0:_ooool00ol0o`3oooooooooo`0Pooooo`003?ooool00ol0003oooooooooo`07oooo
o`;o00002Oooool2o`0000Sooooo0_l00004ooooo`05o`3o0?ooooooooooooooool0o`006?ooool0
0ol0003oooooooooo`0Zooooo`03o`3o0?oooooooooo01Wooooo00?o0000ooooooooool01?ooool0
00cooooo00?o0000ooooooooool01oooool2o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo
00;ooooo00Go0?l0ooooooooooooooooo`3o000Iooooo`;o0000;?ooool00ol0o`3oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool000_ooooo0_l00008oooo
o`;o00002Oooool00ol0003oooooooooo`0=ooooo`05o`3o0?ooooooooooooooool0o`006Oooool0
0ol0003oooooooooo`0<o`3o023ooooo00?o0?l0ooooooooool03?ooool00ol0003oooooooooo`08
ooooo`;o00001Oooool000_ooooo0_l00008ooooo`03o`000?oooooooooo01Oooooo00Go0?l0oooo
ooooooooooooo`3o000Iooooo`Co0?l03?ooool4o`3o01gooooo00Go0?l0ooooooooooooooooo`00
0009ooooo`;o00002Oooool3o`0000Cooooo000:ooooo`;o00008_ooool01Ol0o`3ooooooooooooo
oooo0?l001Sooooo0_l0o`000ooooooo0000ooooo`0Aooooo`;o0?l05?ooool00ol0003ooooooooo
o`04ooooo`04o`3o0?ooooooooooooooo`;o00002Oooool2o`0000Wooooo00?o0000ooooooooool0
0oooool000[ooooo00?o0000ooooooooool08Oooool01Ol0o`3ooooooooooooooooo0?l001Kooooo
0_l0o`03ooooo`03o`000?oooooooooo01;ooooo0_l0o`0Booooo`;o00001_ooool00ol0o`3ooooo
ooooo`03o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`00;Ooo
ool01Ol0o`3ooooooooooooooooo0?l001Gooooo0_l0o`05ooooo`;o00005Oooool00ol0o`3ooooo
ooooo`04ooooo`?o00002Oooool2o`0000Kooooo00Co0?l0ooooool0003o00002_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00;ooooo000]ooooo`04o`3o0?ooooooooooo`3o01Co
oooo0_l0o`07ooooo`03o`000?oooooooooo013ooooo0ol00002ooooo`03o`3o0?oooooooooo00?o
oooo1?l00008ooooo`;o00001_ooool01?l0o`3oooooooooool0000:ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool002cooooo00Co0?l0oooooooooooo0?l05?ooool00ol0
o`3oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo1Ol00007ooooo`?o00000_ooool00ol0
o`3oooooooooo`03ooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`04o`3o0?oooooooooo
o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`000oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`05ooooo`05o`3o0?ooooooooooo`000?l0o`002Oooool00ol0003oooooooooo`07
ooooo`;o00002?ooool2o`0000Wooooo0ol00008ooooo`;o00000oooool2o`3o00Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`04ooooo`04o`3o0?ooooooooooo`0000[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`003_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool01?l0o`3oooooooooool0
0008ooooo`;o00002Oooool3o`0000Oooooo1?l00009ooooo`03o`000?oooooooooo00kooooo00?o
0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Iooooo`003Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool01?l0o`3oooooo`000?l0
0009ooooo`?o00001oooool2o`0000_ooooo0_l0000Kooooo`03o`3o0?oooooooooo01Cooooo00?o
0?l0ooooooooool06Oooool000gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`;o00001oooool01?l0o`3oooooo`000?l00008ooooo`;o00002?ooool00ol0o`3ooooooooo
o`0;ooooo`03o`000?oooooooooo01_ooooo00?o0?l0ooooooooool05?ooool00ol0o`3ooooooooo
o`0Hooooo`003Oooool00ol0003oooooooooo`06ooooo`;o00002Oooool2o`0000Kooooo00Co0?l0
ooooool0003o00004_ooool00ol0o`3oooooooooo`05ooooo`Go00000_ooool00ol0003ooooooooo
o`0Kooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0ooooooooool04_ooool00ol0003ooooooooo
o`03ooooo`003?ooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0000Kooooo00Co0?l0
ooooool0003o0?l04Oooool00ol0o`3oooooooooo`07ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool07?ooool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooooooo017ooooo
00?o0000ooooooooool00oooool000_ooooo0ol00008ooooo`;o00002Oooool00ol0003ooooooooo
o`05ooooo`04o`3o0?ooooooooooo`3o013ooooo00Co0?l0oooooooooooooooo1Ol00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool5o`3o01Kooooo00?o0?l0oooooooo
ool04oooool00ol0o`3oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`00
2oooool3o`0000Sooooo00?o0000ooooooooool03oooool01?l0o`3oooooooooool0o`0Aooooo`03
o`3o0?oooooooooo00[ooooo00Co0000oooooooooooooooo1Ol0o`05ooooo`Co0?l04oooool00ol0
o`3oooooooooo`0@ooooo`04o`000?ooooooooooo`3o00Oooooo0_l00009ooooo`;o00001?ooool0
00_ooooo0_l0000Kooooo`04o`3o0?ooooooooooo`3o013ooooo00?o0?l0ooooooooool02?ooool0
1Ol0003ooooooooooooooooo000000;o0?l000?o0000ooooooooool02oooool2o`3o017ooooo00?o
0?l0ooooooooool01Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`3o00Oooooo
0ol00009ooooo`03o`000?oooooooooo00;ooooo000;ooooo`03o`000?oooooooooo01[ooooo00Co
0?l0oooooooooooo0?l03oooool00ol0o`3oooooooooo`09ooooo`03o`000?oooooo0?l000;o0?l0
0_ooool00ol0003oooooo`3o0008o`3o00Gooooo0_l0o`0@ooooo`03o`3o0?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool2o`000003ooooool0o`3ooooo00Kooooo0_l0000:ooooo`03o`00
0?oooooooooo00;ooooo000Wooooo`04o`3o0?ooooooooooo`3o00oooooo00?o0?l0ooooooooool0
2oooool00ol0o`3o0000o`000002ooooo`?o0?l02Oooool4o`3o00?ooooo0_l0o`0;ooooo`05o`00
0?ooooooooooooooool0o`001Oooool2o`0000Wooooo0ol000000ooooooo0?l0ooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool002Oooooo00Co0?l0oooooooooooo
0?l03oooool00ol0o`3oooooooooo`09ooooo`;o0?l00oooool2o`3o0003ooooool0003o000000go
oooo00?o0?l0ooooooooool00_ooool2o`0000Wooooo0_l00002ooooo`03o`3o0?oooooooooo00Co
oooo0_l00009ooooo`04o`000?ooooooooooo`3o00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`02ooooo`009_ooool01?l0o`3oooooooooool0o`0?ooooo`03o`3o0?oooooooooo
00Wooooo00Co0?l0oooooooooooooooo0_l0o`03ooooo`;o00003_ooool2o`3o00;ooooo0ol00009
ooooo`;o00000_ooool00ol0o`3oooooooooo`03ooooo`;o00002_ooool00ol0003oooooo`3o0008
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo0?l00_ooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool2o`0000?ooooo00?o0?l0ooooooooool00_ooool3o`0000Oooooo1?l00005
ooooo`03o`3o0?oooooooooo00?o00002?ooool2o`0000;ooooo00?o0?l0ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`3o00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`01ooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooool0o`000oooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo0_l00009ooooo`;o000000?oooooo`3o0?l0o`001?ooool4o`0000[ooooo00?o0000
ooooooooool01?ooool01Ol0o`3oooooooooool0003o0?l000gooooo00?o0?l0ooooooooool04Ooo
ool00ol0o`3oooooooooo`0Dooooo`003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo0?l00_ooool00ol0o`3oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0?l0o`000?l000002?ooool01?l0003o0?l0ooooool0o`08ooooo`03o`00
0?oooooooooo017ooooo00Go0?l0ooooooooooooooooo`3o000=ooooo`03o`3o0?oooooooooo013o
oooo00?o0?l0ooooooooool05?ooool000gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooo`3o00;ooooo00?o0?l0ooooooooool00_ooool2o`0000So
oooo0_l00009ooooo`03o`3o0?oooooo0?l000Wooooo0_l0000Cooooo`05o`3o0?oooooooooooooo
ool0o`003?ooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo01Cooooo000=ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool2o`000005o`3o0?oooooooooooooo
ool0o`000oooool2o`0000Sooooo00?o0?l0o`000?ooool02Oooool00ol0o`3oooooo`3o0009oooo
o`03o`000?oooooooooo01?ooooo00Go0?l0ooooooooooooooooo`3o000<ooooo`03o`3o0?oooooo
oooo00oooooo00?o0?l0ooooooooool05?ooool000gooooo00?o0000ooooooooool01oooool2o`00
00Sooooo0_l000001Ooooooo0?l0oooooooooooo0?l000Cooooo00?o0000ooooooooool01oooool0
0ol0o`3oooooooooo`08ooooo`03o`3o0?oooooo0?l000[ooooo00?o0000ooooooooool05?ooool0
1?l0o`3oooooooooool0o`0<ooooo`03o`3o0?oooooooooo013ooooo00?o0?l0ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`003?ooool2o`0000Wooooo0_l00008ooooo`04o`000?oooooo
ooooo`3o00;ooooo00?o0?l0ooooooooool02oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oo
oooo0?l000_ooooo00?o0000ooooooooool05Oooool01?l0o`3oooooooooool0o`0<ooooo`03o`3o
0?oooooooooo00oooooo00?o0?l0ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;ooooo000<ooooo`;o00002?ooool2o`0000_ooooo00Co0?l0oooooooooooo0?l0
3_ooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooo0?l000_ooooo00?o0000ooooooooool0
5Oooool01?l0o`3oooooooooool0o`0<ooooo`03o`3o0?oooooooooo00[ooooo00?o0000oooooooo
ool00_ooool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`00
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00Co0?l0oooooooooooo
0?l03Oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooo0?l000cooooo0_l00005o`3o01;o
oooo00Co0?l0oooooooooooo0?l02oooool00ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00Co0?l0oooooooooooooooo0ol00008ooooo`;o00001?ooool000cooooo00?o0000oooo
ooooool05?ooool01?l0o`3oooooooooool0o`0=ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0
ooooool0o`003?ooool3o`3o00Gooooo1?l0o`0>ooooo`04o`3o0?ooooooooooo`3o00cooooo00?o
0?l0o`000?ooool02Oooool2o`0000Cooooo00Co0?l0oooooooooooooooo0ol00009ooooo`03o`00
0?oooooooooo00;ooooo000Sooooo`03o`3o0?oooooo0?l000kooooo00?o0?l0ooooooooool01ooo
ool00ol0o`3oooooo`3o000:ooooo`;o0?l000?oooooo`000?ooool02Oooool2o`3o00gooooo00Ko
0?l0oooooooooooo0?l0ooooool00009ooooo`03o`3o0?l0003o000000Wooooo0_l00004ooooo`03
o`3o0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00
8oooool00ol0o`3oooooo`3o000=ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooool0o`00
2_ooool01Ol0o`3ooooooooooooooooo000000cooooo00?o0?l0ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`06o`3o0?ooooooooooo`3o0?oooooo00002Oooool01?l0o`3o0000o`000?l0
0009ooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo007ooooo000Rooooo`04o`3o0?ooooooooooo`3o00gooooo00?o
0?l0ooooooooool01_ooool00ol0o`3oooooo`3o0009ooooo`;o0?l01?ooool2o`0000cooooo00?o
0?l0ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`3o0?oooooo0?l000;ooooo00?o
0000ooooooooool01oooool2o`0000[ooooo00?o0000ooooooooool00oooool00ol0o`3ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool002;ooooo00?o0?l0
ooooool0o`003Oooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooo0?l000Gooooo00Co0000
oooooooooooo0?l01_ooool3o`0000Oooooo0ol00002ooooo`03o`3o0?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool01Ol0o`3oooooooooool0o`3ooooo00;o00002?ooool00ol0o`3o0000
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo007ooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`3o0?l0003o0?l000Wooooo00Go
0000ooooooooooooooooo`3o0005ooooo`;o000000Coooooo`3o0?oooooo0?l01_ooool2o`000003
ooooool0o`3ooooo00Cooooo1?l00008ooooo`?o00000_ooool00ol0o`3oooooooooo`03ooooo`;o
00001?ooool00ol0o`3oooooo`3o0002ooooo`03o`000?oooooooooo00Kooooo00?o0?l0ooooool0
00002Oooool00ol0003oooooooooo`04ooooo`05o`3o0?ooooooooooooooool000002_ooool00ol0
003oooooooooo`01ooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Ko
oooo00?o0?l0o`000?l0o`002?ooool2o`0000?ooooo00?o0?l0ooooooooool00oooool2o`000003
o`3o0?oooooo0?l000Kooooo00Go0000oooooooooooo0?l0ooooo`03o`0000?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo00Sooooo00Co0?l0oooo
oooooooo0?l02oooool00ol0o`3oooooooooo`0?ooooo`03o`3o0?oooooooooo013ooooo000>oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool01?l0o`3oooooo`000?l0o`08
ooooo`;o00000_ooool00ol0o`3oooooooooo`04ooooo`05o`000?oooooo0?l0ooooool0o`001Ooo
ool01?l0003oooooooooool0o`03ooooo`04o`000?ooooooooooooooo`[o0?l02Oooool00ol0o`3o
ooooooooo`08ooooo`03o`3o0?oooooo0?l000_ooooo00?o0?l0ooooooooool03oooool00ol0o`3o
ooooooooo`0@ooooo`003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?o0?l0o`000?l000002Oooool2o`0000;ooooo00?o0?l0ooooooooool01?ooool01?l0003ooooo
o`3o0?l0o`05ooooo`?o000000?o0?l0o`000?ooool00_ooool01Ol0003oooooo`3o0?l0o`3ooooo
00So0?l000?oooooo`3o0?l0o`002?ooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooo0?l0
00_ooooo00?o0?l0ooooooooool03oooool00ol0o`3oooooooooo`0@ooooo`003Oooool00ol0003o
ooooooooo`07ooooo`;o00002?ooool00ol0o`3o0000o`000009ooooo`05o`000?oooooooooooooo
ool0o`001oooool00ol0o`3oooooo`3o0008ooooo`03o`3o0?oooooooooo00;ooooo00Ko0000o`3o
0?l0o`3oooooo`3o0?l00007ooooo`04o`3o0?ooooooooooo`3o00Oooooo00?o0?l0ooooooooool0
2?ooool00ol0o`3oooooo`3o000:ooooo`03o`3o0?oooooooooo00oooooo00?o0?l0ooooooooool0
2oooool00ol0003oooooooooo`02ooooo`003?ooool2o`0000Wooooo0_l00008ooooo`03o`3o0?l0
003o0?l000cooooo00?o0?l0ooooooooool01_ooool2o`3o00Sooooo00?o0?l0ooooooooool00ooo
ool01_l0o`3oooooo`3o0?l0o`3oooooo`0000Sooooo0_l0o`000ooooooo0?l0ooooo`06ooooo`03
o`3o0?oooooooooo00Oooooo00?o0?l0ooooool0o`002_ooool00ol0o`3oooooooooo`0?ooooo`04
o`3o0?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool000cooooo0ol00008ooooo`03
o`000?oooooooooo00Kooooo00Co0?l0ooooool0003o0?l03?ooool00ol0o`3oooooooooo`06oooo
o`;o0?l01oooool00ol0o`3oooooooooo`03ooooo`03o`000?l0o`3o0?l000?ooooo00?o0000oooo
ooooool02?ooool2o`3o00Oooooo00?o0?l0ooooooooool01oooool01?l0o`3oooooooooool0o`0:
ooooo`03o`3o0?oooooooooo00kooooo00Co0?l0oooooooooooo00002_ooool2o`0000?ooooo0003
ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo00Co0?l0
oooooooooooo0?l03?ooool00ol0o`3oooooooooo`05ooooo`;o0?l02?ooool00ol0o`3ooooooooo
o`02ooooo`?o0?l01?ooool00ol0003oooooooooo`09ooooo`;o0?l01oooool00ol0o`3ooooooooo
o`07ooooo`03o`3o0?oooooo0?l000[ooooo00?o0?l0ooooooooool01oooool00ol0003ooooooooo
o`04ooooo`03o`3o0?oooooooooo00;o00002Oooool2o`0000?ooooo0003ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04Oooool01?l0o`3oooooooooool0o`0<ooooo`03o`3o0?oo
oooooooo00Gooooo0_l0o`07ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooool0o`001Ooo
ool2o`0000[ooooo00?o0?l0ooooool0o`001_ooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oo
oooo0?l000Wooooo00?o0000o`3o0?ooool02?ooool00ol0003oooooooooo`05ooooo`04o`3o0?oo
oooo0000o`0000Wooooo00?o0000ooooooooool00_ooool0023ooooo00?o0?l0ooooool0o`003?oo
ool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooo0?l000Oooooo00?o0?l0ooooooooool00_oo
ool00ol0o`3oooooo`3o0005ooooo`03o`000?oooooo0?l000;o0?l02?ooool00ol0o`3oooooo`3o
0005ooooo`03o`3o0?oooooooooo00Oooooo00Co0?l0o`000?oooooo0?l02?ooool00ol0003o0?l0
ooooo`07ooooo`?o00001_ooool00ol0o`3oooooo`00000;ooooo`03o`000?oooooooooo007ooooo
000Pooooo`03o`3o0?oooooo0?l000cooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooo`3o
0006ooooo`03o`3o0?oooooooooo00;ooooo0ol0o`06ooooo`;o0?l00_ooool3o`3o00Oooooo0_l0
o`06ooooo`03o`3o0?oooooooooo00Kooooo00Co0?l0o`000?oooooo0?l02?ooool2o`0000Sooooo
0ol00006ooooo`04o`3o0?ooooooooooo`0000[ooooo00?o0000ooooooooool00Oooool001oooooo
00Co0?l0oooooooooooo0?l03?ooool00ol0o`3oooooooooo`05ooooo`;o0?l01oooool00ol0o`3o
ooooooooo`02ooooo`03o`3o0?oooooooooo00Cooooo0_l0o`000ol0003oooooooooo`04ooooo`03
o`3o0?oooooooooo00Gooooo0_l0o`04ooooo`03o`000?l0o`3ooooo00Sooooo0_l000000ol0o`3o
ooooooooo`06ooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`04o`3o0?ooooooooooo`00
00[ooooo00?o0000ooooooooool00Oooool001oooooo00Co0?l0oooooooooooo0?l03?ooool00ol0
o`3oooooooooo`04ooooo`03o`3o0?oooooo0?l000Oooooo00Co0?l0oooooooooooooooo0_l00005
ooooo`03o`3o0?oooooooooo00?o00001Oooool01?l0o`3oooooooooool00003ooooo`;o0?l01?oo
ool2o`0000Wooooo0_l000000ooooooo0?l0ooooo`07ooooo`03o`000?l0o`3ooooo00Oooooo00?o
0000ooooooooool01Oooool01?l0o`3oooooooooool0000:ooooo`03o`000?oooooooooo007ooooo
0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`05o`3o0?ooooooooooo`3o0?l000002_ooool00ol0003o0?l0ooooo`05ooooo`03o`3o
0?oooooo000000;o00001?ooool00ol0o`3oooooooooo`02ooooo`;o00001?ooool01?l0o`3ooooo
ooooooooool4o`0000Gooooo00Co0?l0ooooool0003o00000oooool2o`3o00?ooooo0ol00008oooo
o`04o`3o0?l0003oooooo`3o00Sooooo00?o0000o`3o0?ooool01oooool00ol0003oooooooooo`05
ooooo`04o`3o0?ooooooooooo`0000[ooooo00?o0000ooooooooool00Oooool000kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`05o`3o0?ooooooooooo`3o0?l000002Ooo
ool2o`000003o`3o0?oooooooooo00Cooooo0_l0o`03o`0000Cooooo00Co0?l0oooooooooooooooo
0_l00004ooooo`04o`3o0?ooooooooooooooo`So0?l00oooool01?l0o`3o0000o`000?l00002oooo
o`;o0?l00oooool00ol0003oooooo`3o0009ooooo`03o`3o0?oooooo0?l000Wooooo00?o0?l0oooo
ooooool03_ooool00ol0o`3oooooooooo`0?ooooo`003_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00?ooooo00Go0?l0oooooooooooo0?l0o`000009ooooo`?o00001_ooool2o`3o
00;o00001Oooool01_l0o`3ooooooooooooooooo0000o`3o00Cooooo00?o0?l0ooooooooool00ol0
o`04ooooo`?o0?l00_ooool00ol0o`3o0000ooooo`04ooooo`;o0?l01?ooool00ol0o`3ooooooooo
o`07ooooo`03o`3o0?oooooo0?l000Wooooo00?o0?l0ooooooooool03_ooool00ol0o`3ooooooooo
o`0?ooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0?l0
ooooooooool00ol00008ooooo`?o00001_ooool2o`3o0003o`000?oooooooooo00?ooooo00?o0?l0
ooooooooool00_ooool2o`3o00?ooooo00?o0?l0ooooooooool00_l0o`000ooooooo0000ooooo`05
ooooo`05o`3o0?ooooooooooooooool0o`001Oooool2o`3o00Cooooo00?o0?l0ooooooooool01ooo
ool00ol0o`3oooooo`3o0009ooooo`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool03ooo
ool000kooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0?l0ooooool0o`000ol00008
ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0?l0o`3o0006ooooo`03o`3o0?oooooo
oooo00;ooooo00Go0?l0ooooooooooooooooo`3o0002ooooo`;o0?l00_ooool2o`0000Gooooo0_l0
o`03ooooo`03o`3o0?oooooooooo00;ooooo0_l0o`05ooooo`04o`3o0?ooooooooooooooo`Go0000
00?o0?l0ooooool0o`002Oooool00ol0o`3oooooooooo`0<ooooo`;o000000?o0?l0ooooooooool0
2oooool00ol0003oooooooooo`01ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooo000000;o00001Oooool01Ol0o`3oooooo`3o0?oooooo000000Wooooo00Go0000o`3o0?oooooo
ooooo`000002ooooo`04o`000?oooooo0?l0o`3o00Kooooo00Co0?l0oooooooooooooooo0_l0o`03
ooooo`04o`3o0?ooooooooooo`3o00;ooooo1_l0o`03ooooo`;o0?l00_ooool00ol0o`3ooooooooo
o`02ooooo`;o0?l01Oooool00ol0o`3oooooooooo`02ooooo`07o`000?ooooooooooo`000?l0o`3o
ooooo`3o0009ooooo`03o`3o0?oooooooooo00gooooo00Go0000o`3o0?ooooooooooo`00000:oooo
o`03o`000?oooooooooo007ooooo000<ooooo`Go000000?oooooo`000?l000000ol000000ooooooo
0000ooooo`05ooooo`05o`3o0?oooooo0?l0ooooool000001_ooool4o`000005o`3o0?oooooooooo
ooooool000000_ooool00ol0o`3oooooo`3o0006ooooo`05o`3o0?ooooooooooooooool0o`001?oo
ool02?l0o`3oooooo`3o0?l0o`3oooooo`3o0?oooooo00000oooool2o`3o00;ooooo0_l0o`02oooo
o`03o`3o0?oooooooooo00;ooooo0_l0o`05ooooo`03o`3o0?oooooooooo00?ooooo00Ko0000oooo
oooooooo0?l0ooooool0o`0:ooooo`03o`3o0?oooooooooo00Wooooo1?l000001?l0o`3ooooooooo
ool00009ooooo`;o00000oooool000?ooooo00?o0000ooooooooool01oooool2o`0000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04o`3o0?ooooooooooo`3o00co
oooo00?o0?l0ooooooooool00_ooool01Ol0003oooooo`3o0?oooooo0?l000Gooooo00Co0?l0oooo
oooooooooooo0_l0o`03ooooo`04o`3o0?ooooooooooo`3o00;ooooo1_l0o`000ooooooo0?l0o`3o
0002ooooo`04o`3o0?ooooooooooo`3o00Gooooo0_l0o`04ooooo`03o`3o0?oooooooooo00Cooooo
00Go0000ooooool0o`3oooooo`3o000:ooooo`03o`3o0?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?oooooo0?l0ooooool000002Oooool2o`0000?ooooo0003oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`000008oooo
o`04o`3o0?ooooooooooo`3o00cooooo00?o0?l0ooooool000000oooool01?l0003o0?l0ooooool0
o`05ooooo`04o`3o0?ooooooooooooooo`;o0?l00oooool01Ol0o`3oooooo`3o0?l0o`3ooooo00Co
0?l00_ooool2o`3o0004ooooool0o`3oooooooooo`;o0?l00_ooool00ol0o`3oooooooooo`02oooo
o`;o0?l01?ooool01Ol0o`3ooooooooooooooooo000000?ooooo00Co0000o`3o0?oooooo0?l02?oo
ool00ol0003oooooo`3o0007ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003ooooo
o`3o0003o`0000Wooooo00?o0000ooooooooool00Oooool000gooooo00?o0000ooooooooool01?oo
ool2o`0000Sooooo00Co0?l0oooooooooooo0?l03?ooool00ol0o`3oooooo`000003ooooo`03o`00
0?l0o`3o0?l000Kooooo00Co0?l0oooooooooooooooo0_l0o`03ooooo`08o`3o0?oooooo0?l0oooo
ool0o`3oooooo`3o0?ooool6o`3o0003ooooool0o`3ooooo00;o0?l00_ooool00ol0o`3ooooooooo
o`02ooooo`;o0?l01?ooool01Ol0o`3ooooooooooooooooo000000?ooooo00Co0000o`3o0?oooooo
0?l02?ooool00ol0003oooooo`3o0007ooooo`;o00001?ooool2o`000003ooooool0o`3o000000;o
00002Oooool00ol0003oooooooooo`01ooooo`005Oooool00ol0003oooooooooo`06ooooo`04o`3o
0?ooooooooooo`3o00cooooo00?o0?l0ooooooooool00ol000000ooooooo0?l0o`3o0006ooooo`04
o`3o0?ooooooooooooooo`;o0?l00_ooool01Ol0o`3oooooooooool0o`3ooooo00So0?l000Cooooo
o`3o0?oooooo0?l00_ooool01?l0o`3oooooooooool0o`04ooooo`;o0?l01?ooool00ol0o`3ooooo
ooooo`02ooooo`?o000000Goooooo`000?ooooooooooo`3o0006ooooo`;o000000?oooooo`3o0?oo
ool01_ooool2o`0000Gooooo00Go0000ooooool0o`3oooooo`00000:ooooo`03o`000?oooooooooo
007ooooo000Nooooo`04o`3o0?ooooooooooo`3o00_ooooo00?o0?l0ooooooooool01Oooool2o`3o
00Kooooo00Co0?l0oooooooooooooooo0_l0o`02ooooo`05o`3o0?oooooo0?l0o`3o0?ooool03?l0
o`02ooooo`04o`3o0?ooooooooooo`3o00Cooooo0_l0o`02ooooo`03o`000?oooooo0?l000Sooooo
00Co0000o`3o0?oooooo0?l01_ooool2o`000003ooooool0o`3ooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0o`3oooooo`00000:ooooo`03o`000?oooooooooo007ooooo000Nooooo`04o`3o
0?ooooooooooo`3o00_ooooo00?o0?l0ooooooooool01Oooool2o`3o00Kooooo00Co0?l0oooooooo
oooooooo0_l0o`02o`000005o`3o0?oooooo0?l0o`3o0?ooool03?l0o`02ooooo`04o`3o0?l0003o
ooooo`3o00Cooooo0_l0o`02ooooo`03o`000?oooooo0?l000Oooooo0ol000000ooooooo0?l0oooo
o`06ooooo`03o`000?oooooo0?l000Oooooo00?o0000ooooooooool01_ooool00ol0o`3oooooo`00
000:ooooo`03o`000?oooooooooo007ooooo000Nooooo`04o`3o0?ooooooooooo`3o00_ooooo00?o
0?l0ooooooooool01Oooool2o`3o0004ooooool0003o0000o`0000;ooooo00Co0?l0oooooooooooo
oooo0_l0o`02o`000005o`3o0?oooooo0?l0o`3o0?ooool03?l0o`02ooooo`04o`3o0?l0003ooooo
o`3o00Cooooo0_l0o`001_oooooo0000o`000?l0003oooooo`3o00Kooooo0ol000000ooooooo0?l0
ooooo`06ooooo`03o`000?oooooo0?l000Oooooo00?o0000ooooooooool01_ooool00ol0o`3ooooo
o`00000:ooooo`03o`000?oooooooooo007ooooo0003oooooa_o000000Co0?l0o`000?l0003o0?l0
2ol000000ol0o`3o0000o`000005o`0000;o0?l01_l000001?l0o`3o0000o`000?l00002o`3o00;o
000000Go0?l0o`000?l0o`3o0?l0o`000004o`3o0003o`000?l0o`3o0?l000Go0?l01Ol000000ol0
o`3o0000o`000002o`0000;o0?l01Ol000000ol0o`3o0000o`000006o`000003o`3o0?l0003o0?l0
00Wo000000?o0?l0o`000?l000003_l000000ol0o`3o0000o`00000;o`0000?ooooo0003ooooo`03
o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00Ko0?l0oooooooooooo0?l0ooooool00009ooooo`Co00001?ooool2o`3o00;ooooo00Go
0000ooooooooooooooooo`3o0003ooooo`;o0?l000Coooooo`000?l0o`3ooooo0_l0o`000ooooooo
0?l0o`3o000:o`3o00;ooooo0ol000000ol0o`3oooooooooo`02ooooo`;o0?l01Oooool00ol0o`3o
ooooooooo`03ooooo`06o`000?ooooooooooo`3o0?oooooo0?l06?ooool00ol0003oooooo`3o000@
ooooo`000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool01Ol0o`3oooooooooool0o`3ooooo00;o00002?ooool3o`0000Gooooo0_l0o`02
ooooo`05o`000?ooooooooooooooool0o`000oooool2o`3o00;ooooo00Go0?l0ooooool0o`3o0?l0
ooooo`0<o`3o00;ooooo00Co0?l0oooooooooooo0?l01?ooool2o`3o00Cooooo00?o0?l0oooooooo
ool01oooool00ol0o`3oooooo`3o000Jooooo`03o`3o0?oooooooooo00kooooo0003ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`05o`3o
0?ooooooooooo`3o0?ooool00_l00009ooooo`03o`000?oooooooooo00Cooooo0_l0o`06ooooo`04
o`3o0?ooooooooooooooo`;o0?l00_ooool01Ol0o`3oooooooooool0o`3ooooo00[o0?l000Gooooo
o`3o0?ooooooooooo`3o0002ooooo`03o`3o0?oooooooooo00;ooooo0_l0o`04ooooo`03o`3o0?oo
oooooooo00Oooooo00?o0?l0ooooool0o`006_ooool00ol0o`3oooooooooo`0>ooooo`000oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`06o`3o0?oooooo
ooooo`3o0?oooooo00002_ooool00ol0003oooooooooo`04ooooo`;o0?l01_ooool01?l0o`3ooooo
ooooooooool2o`3o00;ooooo00Oo0?l0oooooooooooo0?l0ooooool0o`3ooooo00;o0?l000Wo0000
o`3o0?l0o`3o0?l0ooooool0o`3oooooo`3o0?ooool00_l0o`02ooooo`03o`3o0?oooooooooo00;o
oooo0_l0o`04ooooo`03o`3o0?oooooooooo00Oooooo0_l0o`0Kooooo`03o`3o0?oooooooooo00ko
oooo0003ooooo`03o`000?oooooooooo00Oooooo0ol00008ooooo`;o00001?ooool01_l0o`3ooooo
ooooool0o`3oooooo`0000[ooooo00?o0?l0ooooooooool01?ooool2o`3o00Kooooo00Co0?l0oooo
oooooooooooo0_l0o`03ooooo`05o`3o0?oooooo0?l0o`3o0?ooool01_l0o`001?oooooo0?l0o`3o
0?l0o`02ooooo`;o0?l00_ooool00ol0o`3oooooooooo`02ooooo`;o0?l01?ooool00ol0o`3ooooo
ooooo`07ooooo`;o0?l06oooool01?l0o`3oooooooooool00009ooooo`03o`000?oooooooooo007o
oooo0003ooooo`;o00002?ooool3o`0000Wooooo00?o0000ooooooooool00_ooool01?l0o`3ooooo
ooooool0o`0<ooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooool0o`001Oooool01?l0o`3o
ooooooooooooool2o`3o00?ooooo00Co0?l0ooooool0o`3o0?l00_ooool5o`3o0004ooooool0o`3o
ooooo`3o00;ooooo0_l0o`02ooooo`03o`3o0?oooooooooo00;ooooo0_l0o`04ooooo`03o`3o0?oo
oooooooo00Kooooo00?o0?l0ooooool0o`004oooool00ol0003oooooooooo`05ooooo`04o`3o0?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00Oooool000?ooooo0_l00009ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0o`3oooooooooool0o`0<ooooo`03o`3o
0?oooooooooo00Cooooo00?o0?l0ooooool0o`001_ooool00ol0o`3oooooooooo`02o`3o00?ooooo
00?o0?l0ooooooooool00_l0o`03ooooo`04o`000?ooooooooooo`3o00;ooooo00Co0?l0oooooooo
oooo0?l00oooool00ol0o`3oooooooooo`02ooooo`;o0?l01?ooool00ol0o`3oooooooooo`06oooo
o`03o`3o0?oooooo0?l000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05oooo
o`04o`3o0?oooooo0000o`0000gooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool03_ooool00ol0o`3oooooo`3o000<ooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0oooo
ool0o`001_ooool01?l0o`3oooooooooooooool2o`3o00?ooooo00?o0?l0ooooooooool00_l0o`02
ooooo`06o`000?l0o`3o0?l0o`3o0?oooooo0?l00oooool01?l0o`3oooooooooool0o`04ooooo`03
o`3o0?oooooo0?l000Cooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooo`3o0008ooooo`03
o`000?oooooooooo00Oooooo0_l00007ooooo`04o`3o0?oooooo0000o`0000gooooo0003ooooo`03
o`000?oooooooooo01Wooooo00?o0?l0ooooool0o`003?ooool00ol0o`3oooooooooo`04ooooo`03
o`3o0?oooooo0?l000Kooooo00Co0?l0oooooooooooooooo0_l0o`03ooooo`04o`3o0?oooooooooo
ooooo`Ko0?l00_ooool00ol0o`3oooooooooo`02o`3o00;ooooo00?o0?l0ooooooooool00_ooool2
o`3o00Gooooo00?o0?l0ooooooooool01_ooool00ol0o`3o0000o`3o0007ooooo`;o00002Oooool2
o`0000Oooooo00Co0?l0oooooooooooo00003Oooool001oooooo00?o0?l0ooooool0o`003?ooool0
0ol0o`3oooooooooo`05ooooo`;o0?l01_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooo
oooo00;ooooo0_l0o`04ooooo`03o`000?oooooooooo00;o0?l00_ooool01Ol0o`3oooooo`3o0?oo
oooo0?l000Gooooo0_l0o`04ooooo`03o`000?l0o`3ooooo00Oooooo00?o0?l0o`000?l0o`001ooo
ool3o`0000Sooooo00?o0000ooooooooool01_ooool00ol0o`3oooooo`00000>ooooo`007oooool0
0ol0o`3oooooo`3o000<ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooool0o`001_ooool0
1_l0o`3ooooooooooooooooo0000o`3o00Cooooo00?o0?l0ooooooooool00_ooool00ol0003ooooo
o`3o0004ooooo`;o0?l00_ooool00ol0o`3oooooooooo`03ooooo`;o0?l01?ooool00ol0003o0?l0
ooooo`07ooooo`;o000000?o0?l0ooooooooool01_ooool2o`0000Sooooo00?o0000ooooooooool0
1_ooool00ol0o`3oooooo`00000>ooooo`007oooool00ol0o`3oooooo`3o000<ooooo`03o`3o0?oo
oooooooo00Gooooo00?o0?l0ooooool0o`001_ooool00ol0o`3oooooooooo`02o`000003ooooool0
o`3ooooo00?ooooo1_l0o`05ooooo`06o`3o0?ooooooooooooooool0o`3o00001?ooool00ol0o`3o
ooooooooo`02ooooo`;o000000?o0?l0ooooooooool01Oooool3o`000003o`3o0?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`04o`3o0?ooooooooooo`00
00kooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`05o`3o0?ooooooooooo`3o0?l000002_ooool00ol0003o0?l0ooooo`06oooo
o`03o`3o0?l0003o000000Gooooo00Co0?l0oooooooooooooooo0_l000000ol0o`3oooooooooo`04
ooooo`Co00001?ooool2o`3o00?ooooo0_l00003ooooo`;o0?l00oooool3o`0000Sooooo00?o0?l0
o`000?l0o`002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00Co0?l0
oooooooooooo00002_ooool00ol0003oooooooooo`01ooooo`000oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool01Ol0o`3oooooooooool0
o`3o000000[ooooo0_l00007ooooo`03o`3o0?l0003o000000Kooooo00Go0?l0oooooooooooooooo
o`000002o`3o00Gooooo1?l00003ooooo`;o0?l00oooool2o`0000Cooooo0_l0o`05ooooo`03o`3o
0?oooooooooo00Kooooo00?o0?l0ooooool0o`006oooool00ol0o`3oooooooooo`0?ooooo`000ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool00ol0o`3oooooo`3o0002o`0000Wooooo0_l00007ooooo`;o0?l00_l00005ooooo`03o`3o0?oo
oooooooo00?ooooo0_l0o`04ooooo`03o`000?oooooo000000?ooooo0_l0o`04ooooo`03o`3o0?l0
003ooooo00?ooooo0_l0o`04ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooool0o`006ooo
ool00ol0o`3oooooooooo`0?ooooo`000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01?ooool00ol0o`3oooooo`3o0002o`0000[ooooo00?o0000
ooooooooool01Oooool2o`3o0003ooooool0003ooooo00Gooooo00?o0?l0ooooooooool00oooool3
o`3o00Cooooo00?o0000o`3o0?l0o`000_l0o`04ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0
ooooool0o`001?ooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooo0?l001_ooooo00?o0?l0
ooooooooool03oooool000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`?o00001Oooool00ol0o`3oooooooooo`02o`0000[ooooo00?o0000ooooooooool01Oooool00ol0
o`3oooooo`3o0007ooooo`03o`3o0?oooooooooo00Cooooo2Ol0o`05ooooo`03o`3o0?oooooooooo
00Cooooo0_l0o`05ooooo`03o`3o0?oooooooooo00Oooooo0_l0o`0Looooo`03o`3o0?oooooooooo
00oooooo0003ooooo`03o`000?oooooooooo00Oooooo0ol00008ooooo`?o00001Oooool01Ol0o`3o
ooooooooool0o`3o000000[ooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooo`3o0007oooo
o`03o`3o0?oooooooooo00Gooooo1_l0o`05ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0oooo
ooooool01?ooool00ol0o`3oooooooooo`07ooooo`;o0?l07?ooool00ol0o`3oooooooooo`02oooo
o`03o`000?oooooooooo00[ooooo0004ooooo`03o`000?oooooooooo00Kooooo0ol00009ooooo`03
o`000?oooooooooo00Cooooo00Co0?l0oooooooooooo0?l03?ooool00ol0o`3oooooooooo`05oooo
o`03o`3o0?oooooo0?l000Sooooo00?o0?l0ooooooooool02?ooool2o`0000Cooooo00?o0?l0oooo
ooooool01Oooool2o`3o00Gooooo00?o0?l0ooooooooool02?ooool2o`3o01Kooooo00?o0000oooo
ooooool00oooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00Oooool000?ooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool01?l0o`3oooooooooool0o`0<ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0oooo
ool0o`001oooool00ol0o`3oooooooooo`08ooooo`04o`000?ooooooooooooooo`;o0?l01oooool2
o`3o00Kooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooo`3o000Fooooo`03o`000?oooooo
oooo00?ooooo00Co0?l0oooooooooooooooo0_l00008ooooo`03o`000?oooooooooo007ooooo0003
ooooo`;o00002Oooool00ol0003oooooooooo`0?ooooo`04o`3o0?ooooooooooo`3o00gooooo00?o
0?l0ooooooooool01Oooool00ol0o`3oooooo`3o0008ooooo`;o0?l00_ooool3o`0000?ooooo00Co
0000oooooooooooo0?l02Oooool2o`3o00Kooooo00?o0?l0ooooooooool01oooool00ol0o`3ooooo
o`3o000;ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`03o`3o0?oooooooooo00?o0000
3?ooool000Cooooo00?o0000ooooooooool06Oooool01Ol0o`3ooooooooooooooooo0?l000cooooo
00?o0?l0ooooooooool01Oooool00ol0o`3oooooo`3o000:ooooo`;o0?l000?oooooo`000?ooool0
0oooool00ol0003oooooo`3o0009ooooo`03o`3o0?oooooo0?l000Gooooo00?o0?l0ooooooooool0
2?ooool01?l0o`3oooooo`3o0?l0000:ooooo`03o`000?oooooooooo00Kooooo0ol00005ooooo`05
o`3o0?ooooooooooooooool000003Oooool000Cooooo00?o0000ooooooooool06_ooool01?l0o`3o
ooooooooool0o`0<ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooool0o`002oooool8o`3o
00Wooooo00?o0?l0ooooool0o`001_ooool01?l0o`3oooooooooool00006ooooo`05o`3o0?oooooo
0?l0ooooool000002Oooool2o`0000Wooooo00?o0000ooooooooool00oooool00ol0o`3ooooooooo
o`02ooooo`03o`000?oooooooooo00_ooooo000Qooooo`04o`3o0?ooooooooooo`3o00gooooo00?o
0?l0ooooooooool01_ooool2o`3o00cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`3o0?oooooo0?l000Kooooo00Go0?l0ooooooooooooooooo`000006ooooo`03o`3o
0?oooooo0?l000;o00002Oooool2o`0000Wooooo00?o0000ooooooooool00oooool00ol0o`3ooooo
ooooo`02ooooo`03o`000?oooooooooo00_ooooo000Qooooo`04o`3o0?ooooooooooo`3o00gooooo
00?o0?l0ooooooooool01_ooool00ol0o`3oooooo`3o0005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`;o0?l00_l00005ooooo`03o`3o
0?oooooooooo00;o00001_ooool00ol0o`3oooooo`3o0002o`0000Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo00;ooooo00?o0000ooooooooool0
2oooool0027ooooo00Co0?l0oooooooooooo0?l03Oooool00ol0o`3oooooooooo`04ooooo`06o`00
0?ooooooooooo`3o0?oooooo0?l01?ooool00ol0003oooooooooo`02ooooo`;o00000oooool4o`00
00Kooooo0_l0o`03o`0000Cooooo00?o0?l0ooooooooool00ol00005ooooo`05o`3o0?oooooooooo
o`3o0?l000002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00Go0?l0
ooooooooooooooooo`00000>ooooo`000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01_ooool01?l0o`3o0000ooooool0o`08ooooo`;o00000_oo
ool00ol0o`3oooooooooo`03ooooo`;o00000oooool00ol0o`3oooooo`3o0002ooooo`?o00001?oo
ool01?l0003oooooooooooooool2o`0000Oooooo00?o0?l0ooooool000000_l00005ooooo`04o`3o
0?ooooooooooooooo`;o00001Oooool01Ol0o`3oooooo`3o0?oooooo000000[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`05o`3o0?ooooooooooooooool000002_ooool0
0ol0003oooooooooo`01ooooo`000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01_ooool01?l0o`3o0000ooooool0o`08ooooo`;o00000oooool0
0ol0o`3oooooooooo`03ooooo`;o00000_ooool00ol0o`3oooooooooo`02o`3o00?ooooo00?o0000
ooooooooool01Oooool3o`0000Gooooo00Go0?l0ooooool0o`3oooooo`000005ooooo`03o`3o0?oo
oooooooo00Wooooo00?o0?l0ooooool0o`007?ooool00ol0o`3oooooooooo`0Aooooo`000oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
1?l0o`3o0000o`000?l00009ooooo`;o00000_ooool00ol0o`3oooooooooo`04ooooo`04o`000?oo
ooooooooooooo`;o0?l00_ooool00ol0o`3oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo
0_l0o`000ooooooo0?l0ooooo`07ooooo`03o`3o0?oooooooooo00Sooooo00Co0?l0oooooooooooo
0?l07?ooool00ol0o`3oooooooooo`0Aooooo`000oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo0_l00008ooooo`?o000000?o0?l0ooooooooool01oooool01Ol0003ooooo
oooooooooooo0?l000_ooooo00Co0?l0oooooooooooo0?l02_ooool00ol0003oooooooooo`02o`3o
0003ooooool0o`3o0?l000Wooooo00?o0?l0ooooooooool02?ooool00ol0o`3oooooo`3o000Moooo
o`03o`3o0?oooooooooo017ooooo0003ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool2o`0000Sooooo00Co0?l0o`000?l0003o0?l03_ooool00ol0o`3oooooooooo`09oooo
o`;o0?l000Coooooo`3o0?l0o`3o0?l01oooool00ol0003o0?l0o`3o0002ooooo`03o`3o0?oooooo
oooo00Sooooo00?o0?l0ooooooooool02?ooool01?l0o`3oooooooooool0o`0Mooooo`03o`3o0?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool000Cooooo00?o0000ooooooooool01oooool2
o`0000[ooooo00?o0000ooooooooool01_ooool01?l0o`3oooooo`000?l0o`0?ooooo`03o`3o0?oo
oooooooo00[ooooo00?o0?l0ooooooooool02Ol0o`03ooooo`03o`3o0?oooooooooo00Sooooo00?o
0?l0ooooooooool02Oooool00ol0o`3oooooo`3o000Nooooo`03o`3o0?oooooooooo00Cooooo00?o
0000ooooooooool02_ooool000?ooooo0ol00008ooooo`;o00002_ooool00ol0003oooooooooo`06
ooooo`05o`3o0?ooooooooooooooool0o`003oooool00ol0o`3oooooooooo`0:ooooo`;o0?l02?oo
ool01?l0003o0?l0o`3o0?l0o`0:ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooool0o`00
6_ooool01?l0003oooooooooool0o`06ooooo`;o00003?ooool000?ooooo0ol00009ooooo`03o`00
0?oooooooooo01;ooooo00Co0?l0oooooooooooo0?l03oooool00ol0o`3oooooooooo`0<ooooo`Wo
0?l03?ooool00ol0o`3oooooooooo`0:ooooo`04o`3o0?ooooooooooo`3o013ooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool0o`06ooooo`;o00003?ooool000Cooooo00?o0000oooo
ooooool07Oooool01?l0o`3oooooooooool0o`0@ooooo`03o`3o0?oooooooooo01?ooooo00?o0000
ooooooooool02_ooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooo0?l000Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`;o00000_ooool00ol0o`3oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo0004ooooo`03o`000?oooooooooo01gooooo00Go0?l0oooo
ooooooooooooo`3o000?ooooo`03o`3o0?oooooooooo01?ooooo00?o0000ooooooooool02Oooool0
0ol0o`3oooooooooo`0;ooooo`03o`3o0?oooooo0?l000Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`;o00000_ooool00ol0o`3oooooooooo`04ooooo`03o`000?oooooo
oooo00_ooooo000Uooooo`04o`3o0?ooooooooooo`3o013ooooo0_l0o`0Cooooo`;o00002Oooool0
0ol0o`3oooooooooo`0:ooooo`05o`000?l0o`3oooooooooool0o`001Oooool00ol0003ooooooooo
o`07ooooo`;o00002Oooool01Ol0003ooooooooooooooooo0?l000Kooooo00?o0000ooooooooool0
2oooool002Gooooo00Co0?l0oooooooooooo0?l04_ooool00ol0o`3oooooooooo`0@ooooo`03o`00
0?oooooooooo00Oooooo00Co0?l0oooooooooooo00002Oooool2o`0000;ooooo00?o0?l0oooooooo
ool00oooool2o`0000[ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0o`07oooo
o`03o`000?oooooooooo00_ooooo000Uooooo`05o`3o0?ooooooooooooooool0o`004_ooool00ol0
o`3oooooooooo`04ooooo`;o00002Oooool4o`0000Cooooo0_l0o`02ooooo`;o00002?ooool2o`00
0004o`3o0?ooooooooooo`3o00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool0o`001_ooool00ol0003oooooooooo`0<ooooo`000oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool0o`03ooooo`05o`3o0?ooooooooooooooool000002_ooool01Ol0003ooooo
oooooooooooo0?l000Gooooo0ol00007ooooo`?o00001Oooool01?l0o`3oooooooooooooool2o`00
00Wooooo0_l00002ooooo`03o`3o0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`05o`000?ooooooooooooooool0o`001_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo007ooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0o`000_ooool0
1?l0o`3oooooooooooooool2o`0000Sooooo0ol00003ooooo`;o0?l00oooool4o`0000Oooooo00?o
0000ooooooooool00_ooool2o`3o00Gooooo00?o0000ooooooooool02?ooool00ol0o`3oooooo`3o
000Oooooo`03o`3o0?oooooooooo01Cooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`3o0?ooool00_ooool0
0ol0o`3oooooooooo`02o`0000_ooooo00?o0000ooooooooool00_ooool2o`3o00cooooo0_l00003
o`3o017ooooo00Co0?l0oooooooooooo0?l07oooool00ol0o`3oooooooooo`0Dooooo`001?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool2
o`0000;ooooo00Go0?l0ooooooooooooooooo`3o0002ooooo`;o00004Oooool3o`3o00Wooooo0_l0
o`0Cooooo`04o`3o0?ooooooooooo`3o023ooooo00?o0?l0ooooooooool05?ooool000Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0000;ooooo00Go
0?l0ooooooooooooooooo`3o0003ooooo`03o`000?oooooooooo01;ooooo2Ol0o`000ol0003ooooo
ooooo`0Booooo`04o`3o0?ooooooooooo`3o01oooooo00?o0?l0ooooooooool05Oooool000Cooooo
00?o0000ooooooooool01oooool3o`0000Wooooo0_l00009ooooo`05o`000?ooooooooooooooool0
o`000oooool00ol0o`3oooooooooo`0Hooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool04Oooool01?l0o`3oooooooooool0o`0Pooooo`03o`3o0?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool000Cooooo0_l00008ooooo`?o00002_ooool00ol0003oooooooooo`0<oooo
o`05o`3o0?ooooooooooooooool0o`006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo013ooooo00Go0?l0ooooooooooooooooo`3o000Pooooo`03o`3o0?l0003ooooo00Sooooo0_l0
000;ooooo`001?ooool2o`0000Wooooo0_l0000Iooooo`05o`3o0?ooooooooooooooool0o`006ooo
ool01?l0003oooooooooooooool2o`00013ooooo00Go0?l0ooooooooooooooooo`3o000Gooooo`03
o`000?oooooooooo00Oooooo0_l00008ooooo`?o00002oooool000Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Hooooo`05o`3o0?ooooooooooooooool0o`005oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool03_ooool01Ol0o`3ooooooooooooooooo
0?l001Sooooo00?o0000ooooooooool01_ooool3o`0000Wooooo0_l0000;ooooo`001Oooool00ol0
003oooooooooo`0Tooooo`05o`3o0?ooooooooooooooool0o`005_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool03Oooool01Ol0o`3ooooooooooooooooo0?l000kooooo
0_l00008ooooo`;o00002?ooool00ol0o`3o0000o`000009ooooo`03o`000?oooooooooo00[ooooo
000/ooooo`05o`3o0?ooooooooooooooool0o`005oooool3o`0000?ooooo00?o0000ooooooooool0
3?ooool00ol0o`3oooooooooo`02ooooo`04o`3o0?ooooooooooooooo`;o00002?ooool3o`0000Oo
oooo0ol00008ooooo`03o`3o0?l0003ooooo00Sooooo00?o0000ooooooooool02oooool002gooooo
00Co0?l0oooooooooooooooo0_l0o`0Kooooo`03o`000?oooooooooo00[ooooo0_l00004ooooo`04
o`3o0?ooooooooooooooo`?o00001oooool3o`0000Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000^ooooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool06?ooool2o`0000[ooooo0ol00003ooooo`04o`3o0?oooooooooooooo
o`?o00002Oooool2o`0000Wooooo00?o0000ooooooooool01_ooool00ol0o`3o0000ooooo`09oooo
o`03o`000?oooooooooo00_ooooo000_ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`;o00002?ooool4o`0000Oooooo0ol00002ooooo`;o
0?l01Oooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`3o0?l0003ooooo00Sooooo00?o0000ooooooooool03?ooool000?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool2o`000003o`3o0?oooooooooo00;ooooo0_l0o`02ooooo`?o00001oooool4o`0000Oooooo
0_l00008ooooo`03o`3o0?l0003o000000;ooooo00?o0?l0ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool000?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooool000002?ooool2o`000003ooooool0o`3ooooo00Cooooo00?o0?l0ooooooooool00_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00Co0?l0oooooooooooooooo
0_l0o`0Vooooo`03o`3o0?oooooooooo01Sooooo0004ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`;o00002_ooool01?l0003oooooo`3o
0?l0o`04ooooo`03o`3o0?oooooooooo01?ooooo0_l00006ooooo`05o`3o0?ooooooooooooooool0
o`00:?ooool00ol0o`3oooooooooo`0Hooooo`001?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo0ol00009ooooo`;o00002_ooool01?l0003oooooooooool0o`04ooooo`;o
0?l04oooool00ol0003oooooooooo`03ooooo`;o0?l00oooool00ol0o`3oooooooooo`0Vooooo`03
o`3o0?oooooooooo01Wooooo0004ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`?o0000
2_ooool00ol0003oooooooooo`0<ooooo`03o`3o0?oooooooooo00?ooooo0_l0o`0Aooooo`03o`00
0?oooooooooo00;ooooo00Co0?l0oooooooooooooooo0_l0o`0Yooooo`03o`3o0?oooooooooo00ko
oooo00?o0000ooooooooool02?ooool000Gooooo0_l00008ooooo`;o00002Oooool2o`0001[ooooo
00?o0?l0ooooooooool01?ooool2o`3o00oooooo00?o0000o`3o0?l0o`000_l0o`03ooooo`03o`3o
0?oooooooooo02Wooooo00?o0?l0ooooooooool00oooool00ol0003oooooooooo`07ooooo`;o0000
2_ooool000Cooooo0ol00009ooooo`;o00002Oooool00ol0003oooooooooo`0Iooooo`03o`3o0?oo
oooooooo00Gooooo1?l0o`09ooooo`?o0?l01_ooool00ol0o`3oooooooooo`0Uooooo`05o`000?oo
ooooooooooooool0o`001_ooool00ol0003oooooooooo`06ooooo`;o00002oooool000Gooooo0_l0
000:ooooo`03o`000?oooooooooo02Cooooo0_l0o`09ooooo`Wo0?l00_ooool2o`0000?ooooo0_l0
o`0Xooooo`05o`000?ooooooooooooooool0o`001Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo037ooooo0_l0o`0Booooo`03o`000?oo
oooooooo00;o0?l07oooool00ol0003oooooooooo`07ooooo`;o00000_ooool00ol0o`3ooooooooo
o`03ooooo`;o00002Oooool00ol0003oooooooooo`0:ooooo`00??ooool3o`3o00oooooo00?o0000
o`3o0?l0o`005_ooool2o`0000Sooooo0_l00008ooooo`;o00000oooool00ol0o`3oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool003oooooo1_l0o`04oooo
o`Ko0?l05oooool3o`0000Oooooo0_l00009ooooo`;o00000_ooool00ol0o`3oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004Gooooo1?l0o`05ooooo`03
o`000?oooooooooo00_ooooo0_l00007ooooo`?o00002?ooool2o`0000Wooooo00Go0000oooooooo
ooooooooo`3o0005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool004Co
oooo0ol00007ooooo`Go00001oooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooo0?l01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`;o00002Oooool4o`0000Ko
oooo0ol00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool0o`001Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`?o00002?ooool2o`0000;ooooo0ol00003ooooo`;o
0000;Oooool00ol0o`3oooooooooo`0Nooooo`001?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000Sooooo0ol0000:ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo02co
oooo00?o0?l0ooooooooool07_ooool000Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`;o00002?ooool3o`0000_ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`02o`0002cooooo00?o0?l0ooooooooool07oooool000Gooooo00?o0000ooooooooool02?oo
ool2o`0000Sooooo0_l0000;ooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool02?ooool000Gooooo0_l00008ooooo`?o00002Oooool2
o`0002kooooo00Co0000oooooooooooo0000>_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo0005ooooo`;o00002Oooool2o`0000[ooooo00?o0000ooooooooool0:?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0=oooool2o`0000Sooooo0_l0
000:ooooo`001Oooool2o`0000[ooooo00?o0000ooooooooool0=?ooool3o`0000?ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`06ooooo`;o00002?ooool3o`0000[ooooo0006oooo
o`;o0000A_ooool2o`0002?ooooo00?o0000ooooooooool01oooool2o`0000Oooooo0ol00009oooo
o`03o`000?oooooooooo00Wooooo0007ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool05_ooool2o`0000Wooooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo01Gooooo0ol00008ooooo`;o0000
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool004kooooo00?o0000ooooooooool02oooool2o`0000Oooooo0ol00009ooooo`;o00002Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ooo
ool004kooooo00?o0000ooooool000000ol00006ooooo`?o00002Oooool2o`0000Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool003[ooooo0_l00009ooooo`?o00001_ooool4o`0000Sooooo0_l00009oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l00009ooooo`?o
00002?ooool4o`0000Oooooo1Ol00005ooooo`03o`000?oooooo000000Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00Oooool000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo0_l00008ooooo`?o00002?ooool4o`00013ooooo00?o0000ooooooooool0
COooool000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`?o00002?oo
ool2o`0000_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1=ooooo`001?ooool0
0ol0003oooooooooo`09ooooo`;o00002?ooool3o`0000[ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Oooooo0005ooooo`03o`000?oooooooooo
00Sooooo0_l0000:ooooo`;o00002_ooool00ol0003oooooooooo`0Sooooo`;o0000A?ooool00ol0
003oooooooooo`07ooooo`001Oooool2o`0000[ooooo0_l0000:ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo0005ooooo`;o00002oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool01oooool2o`0000Sooooo0_l0000:ooooo`001_ooool2o`0004Kooooo00?o
0000ooooooooool08_ooool2o`0000Sooooo0_l00008ooooo`;o00002Oooool00ol0003ooooooooo
o`09ooooo`001oooool00ol0003oooooooooo`14ooooo`;o00008_ooool3o`0000Oooooo0_l00009
ooooo`;o00002Oooool00ol0003oooooooooo`09ooooo`00C_ooool00ol0003oooooooooo`0Goooo
o`;o00001oooool3o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo0019ooooo`?o00000_ooool00ol0003oooooooooo`0<ooooo`;o
00001oooool3o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004[ooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o00001oooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_o
oooo0016ooooo`Ko00000_ooool5o`0000Oooooo00?o0000ooooool000002?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00_ooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooo`000002o`0000Kooooo1ol00003ooooo`;o000000?o
ooooo`000?ooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00B?ooool00ol0003oooooo`00001C
ooooo`00BOooool2o`0005?ooooo001:ooooo`03o`000?oooooooooo057ooooo002Nooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 235.812}, {601.875, 404.25}} -> {-10.394, \
12.9544, 0.0662697, 0.0424126}}]
}, Open  ]],

Cell["\<\
Here is the same picture created using NDSolve. The trajectories \
are plotted using the interpolation functions generated by NDSolve.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell["\<\
nsolns = Evaluate[ Table[
      NDSolve[{DE1,y[0]==3,y'[0]==v0}, y, {t,0,40}], {v0,-3,3,3}] ];
Show[
    ParametricPlot[ 
    Evaluate[Table[{y[t],y'[t]}/.nsolns[[k]],{k,3}]], {t,0,40} ,  
             PlotStyle->{RGBColor[0,1,0]} ], 
    vf1, PlotRange->{{-5,5},{-4,4}}, AspectRatio->5/4 ]\
\>", "Input",
  CellLabel->"In[28]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.625 0.15625 [
[.1 .6125 -6 -9 ]
[.1 .6125 6 0 ]
[.3 .6125 -6 -9 ]
[.3 .6125 6 0 ]
[.7 .6125 -3 -9 ]
[.7 .6125 3 0 ]
[.9 .6125 -3 -9 ]
[.9 .6125 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .15625 -12 -4.5 ]
[.4875 .15625 0 4.5 ]
[.4875 .3125 -12 -4.5 ]
[.4875 .3125 0 4.5 ]
[.4875 .46875 -12 -4.5 ]
[.4875 .46875 0 4.5 ]
[.4875 .78125 -6 -4.5 ]
[.4875 .78125 0 4.5 ]
[.4875 .9375 -6 -4.5 ]
[.4875 .9375 0 4.5 ]
[.4875 1.09375 -6 -4.5 ]
[.4875 1.09375 0 4.5 ]
[.4875 1.25 -6 -4.5 ]
[.4875 1.25 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 .625 m
.1 .63125 L
s
[(-4)] .1 .6125 0 1 Mshowa
.3 .625 m
.3 .63125 L
s
[(-2)] .3 .6125 0 1 Mshowa
.7 .625 m
.7 .63125 L
s
[(2)] .7 .6125 0 1 Mshowa
.9 .625 m
.9 .63125 L
s
[(4)] .9 .6125 0 1 Mshowa
.125 Mabswid
.15 .625 m
.15 .62875 L
s
.2 .625 m
.2 .62875 L
s
.25 .625 m
.25 .62875 L
s
.35 .625 m
.35 .62875 L
s
.4 .625 m
.4 .62875 L
s
.45 .625 m
.45 .62875 L
s
.55 .625 m
.55 .62875 L
s
.6 .625 m
.6 .62875 L
s
.65 .625 m
.65 .62875 L
s
.75 .625 m
.75 .62875 L
s
.8 .625 m
.8 .62875 L
s
.85 .625 m
.85 .62875 L
s
.05 .625 m
.05 .62875 L
s
.95 .625 m
.95 .62875 L
s
.25 Mabswid
0 .625 m
1 .625 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .15625 m
.50625 .15625 L
s
[(-3)] .4875 .15625 1 0 Mshowa
.5 .3125 m
.50625 .3125 L
s
[(-2)] .4875 .3125 1 0 Mshowa
.5 .46875 m
.50625 .46875 L
s
[(-1)] .4875 .46875 1 0 Mshowa
.5 .78125 m
.50625 .78125 L
s
[(1)] .4875 .78125 1 0 Mshowa
.5 .9375 m
.50625 .9375 L
s
[(2)] .4875 .9375 1 0 Mshowa
.5 1.09375 m
.50625 1.09375 L
s
[(3)] .4875 1.09375 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(4)] .4875 1.25 1 0 Mshowa
.125 Mabswid
.5 .03125 m
.50375 .03125 L
s
.5 .0625 m
.50375 .0625 L
s
.5 .09375 m
.50375 .09375 L
s
.5 .125 m
.50375 .125 L
s
.5 .1875 m
.50375 .1875 L
s
.5 .21875 m
.50375 .21875 L
s
.5 .25 m
.50375 .25 L
s
.5 .28125 m
.50375 .28125 L
s
.5 .34375 m
.50375 .34375 L
s
.5 .375 m
.50375 .375 L
s
.5 .40625 m
.50375 .40625 L
s
.5 .4375 m
.50375 .4375 L
s
.5 .5 m
.50375 .5 L
s
.5 .53125 m
.50375 .53125 L
s
.5 .5625 m
.50375 .5625 L
s
.5 .59375 m
.50375 .59375 L
s
.5 .65625 m
.50375 .65625 L
s
.5 .6875 m
.50375 .6875 L
s
.5 .71875 m
.50375 .71875 L
s
.5 .75 m
.50375 .75 L
s
.5 .8125 m
.50375 .8125 L
s
.5 .84375 m
.50375 .84375 L
s
.5 .875 m
.50375 .875 L
s
.5 .90625 m
.50375 .90625 L
s
.5 .96875 m
.50375 .96875 L
s
.5 1 m
.50375 1 L
s
.5 1.03125 m
.50375 1.03125 L
s
.5 1.0625 m
.50375 1.0625 L
s
.5 1.125 m
.50375 1.125 L
s
.5 1.15625 m
.50375 1.15625 L
s
.5 1.1875 m
.50375 1.1875 L
s
.5 1.21875 m
.50375 1.21875 L
s
.25 Mabswid
.5 0 m
.5 1.25 L
s
0 0 m
1 0 L
1 1.25 L
0 1.25 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
0 1 0 r
.5 Mabswid
.8 .15625 m
.77069 .12334 L
.73732 .09371 L
.70423 .07119 L
.67307 .05539 L
.65365 .04794 L
.63552 .04257 L
.61545 .03833 L
.60527 .03684 L
.59405 .03571 L
.57521 .035 L
.55494 .03587 L
.53587 .03824 L
.5185 .04169 L
.49946 .04693 L
.47937 .05411 L
.44397 .07107 L
.4035 .09767 L
.36872 .12742 L
.33778 .16014 L
.30684 .19999 L
.25835 .28228 L
.23589 .33302 L
.21824 .38257 L
.2027 .43869 L
.19583 .47047 L
.19061 .50005 L
.18634 .53105 L
.18461 .54707 L
.18307 .56473 L
.18206 .57999 L
.18137 .59428 L
.18093 .6093 L
.18077 .6254 L
.1809 .63903 L
.18131 .65384 L
.18204 .66918 L
.183 .68333 L
.18537 .70837 L
.18881 .73458 L
.19329 .76072 L
.19826 .78418 L
.21231 .83459 L
.22777 .87565 L
.247 .91521 L
.28641 .97314 L
.3117 .99957 L
.33689 1.01977 L
.35032 1.02842 L
.36491 1.03631 L
Mistroke
.37773 1.04203 L
.39177 1.04706 L
.40047 1.04955 L
.40851 1.05145 L
.41623 1.0529 L
.42439 1.05405 L
.4386 1.05514 L
.44668 1.05525 L
.4542 1.05501 L
.46902 1.05362 L
.48297 1.05117 L
.49541 1.04806 L
.50881 1.0437 L
.53824 1.03039 L
.56446 1.01392 L
.60713 .9764 L
.62929 .95057 L
.64845 .92376 L
.6817 .8634 L
.69698 .8265 L
.70868 .79134 L
.71856 .75327 L
.72529 .71819 L
.7281 .69865 L
.72932 .68837 L
.7304 .6775 L
.73187 .6576 L
.73261 .63937 L
.73279 .62274 L
.73244 .60507 L
.73161 .58859 L
.73043 .57375 L
.72854 .55664 L
.72587 .5384 L
.71945 .50638 L
.71047 .47422 L
.69815 .44135 L
.68283 .41037 L
.6664 .38472 L
.64955 .36406 L
.63296 .34799 L
.61372 .33362 L
.60365 .32769 L
.59252 .32228 L
.58158 .31808 L
.57137 .31509 L
.56153 .31303 L
.55104 .3117 L
.54164 .31124 L
.53283 .31144 L
Mistroke
.52318 .31235 L
.51286 .31412 L
.502 .31688 L
.49028 .32091 L
.46941 .33087 L
.44987 .34367 L
.4326 .35811 L
.40128 .39343 L
.3771 .43181 L
.36566 .45519 L
.35499 .48177 L
.34658 .50795 L
.34041 .53239 L
.33535 .55927 L
.3333 .57413 L
.33185 .5882 L
.33091 .60114 L
.33041 .61305 L
.33024 .62603 L
.3305 .63967 L
.33121 .65313 L
.3318 .66061 L
.33246 .66739 L
.33399 .67973 L
.33602 .69244 L
.34168 .71836 L
.34568 .73232 L
.34989 .74477 L
.3596 .76795 L
.37026 .78762 L
.38107 .80348 L
.39354 .81804 L
.40813 .83117 L
.42235 .84067 L
.4305 .84485 L
.43826 .84804 L
.44688 .85073 L
.45175 .85187 L
.45623 .85268 L
.46417 .85358 L
.47166 .85381 L
.47838 .8535 L
.48562 .85263 L
.49351 .85105 L
.49745 .85001 L
.50175 .84869 L
.51622 .84272 L
.5294 .83517 L
.54292 .82512 L
.56539 .80234 L
Mistroke
.57756 .78596 L
.58938 .76633 L
.59848 .74768 L
.60668 .72681 L
.61273 .7073 L
.61542 .69674 L
.61789 .68528 L
.61979 .67471 L
.6212 .66501 L
.62231 .65526 L
.62308 .64601 L
.62361 .63579 L
.62376 .63006 L
.6238 .62481 L
.62364 .61524 L
.62315 .60525 L
.62242 .59643 L
.6215 .58832 L
.62023 .57959 L
.61857 .57044 L
.61382 .55098 L
.60804 .53384 L
.60187 .51969 L
.5942 .50574 L
.57798 .48458 L
.56888 .47615 L
.55829 .46869 L
.54893 .4639 L
.54355 .46183 L
.53857 .46034 L
.53415 .45935 L
.52929 .4586 L
.52419 .4582 L
.51945 .45817 L
.51374 .45856 L
.51086 .45894 L
.50771 .4595 L
.50217 .46082 L
.49703 .46246 L
.48568 .46751 L
.47948 .47114 L
.47395 .47494 L
.46437 .48287 L
.45457 .49301 L
.44594 .504 L
.43879 .51494 L
.42649 .5395 L
.4211 .55401 L
.41695 .56813 L
.41393 .58152 L
Mistroke
.41187 .59393 L
.41106 .60045 L
.4104 .60758 L
.40994 .615 L
.40974 .62188 L
.40976 .62936 L
.40987 .63311 L
.41006 .63721 L
.41059 .64437 L
.4113 .65096 L
.4124 .65855 L
.41364 .66533 L
.41727 .6799 L
.42102 .69098 L
.42588 .70215 L
.43172 .71264 L
.43777 .72123 L
.44429 .72858 L
.45083 .7344 L
.45699 .73868 L
.46389 .7423 L
.46756 .74375 L
.47163 .74501 L
.4737 .74551 L
.47593 .74595 L
.47996 .74648 L
.48399 .74668 L
.48782 .74657 L
.49124 .74622 L
.49496 .74557 L
.49887 .7446 L
.50243 .74344 L
.51031 .73992 L
.51703 .73584 L
.52381 .73059 L
.53696 .71656 L
.54351 .7071 L
.54894 .69747 L
.55387 .6867 L
.55779 .67601 L
.56066 .6661 L
.56306 .65512 L
.56402 .64939 L
.56484 .64306 L
.56516 .63988 L
.56543 .63646 L
.56563 .63325 L
.56575 .63032 L
.56584 .62478 L
.5658 .62167 L
Mistroke
.56572 .6188 L
.56543 .6136 L
.56493 .60815 L
.56428 .60309 L
.56338 .59766 L
.56096 .58717 L
.55805 .57811 L
.5548 .57031 L
.55035 .56199 L
.54578 .55534 L
.53997 .54882 L
.53405 .54387 L
.52862 .54055 L
.52581 .53924 L
.52266 .53806 L
.51996 .5373 L
.51702 .53671 L
.51423 .53638 L
.51166 .53626 L
.50864 .53636 L
.50584 .53668 L
.50278 .53727 L
.50108 .53771 L
.49954 .53818 L
.49645 .53932 L
.49316 .54084 L
.48736 .54433 L
.48236 .54824 L
.4773 .55318 L
.4691 .56382 L
.46478 .57124 L
.46122 .57879 L
.45825 .58662 L
.45604 .59396 L
.45421 .602 L
.45343 .60645 L
.45285 .61065 L
.45245 .61455 L
.45219 .61812 L
.45203 .62202 L
.45199 .62609 L
.4521 .63018 L
.45223 .63244 L
.45238 .63448 L
.45278 .6384 L
.45328 .64203 L
.45402 .64615 L
.45483 .64985 L
.45715 .65776 L
.45948 .66368 L
Mistroke
.46195 .66864 L
.46491 .67346 L
.46848 .67806 L
.47203 .68165 L
.47552 .68441 L
.47899 .68651 L
.48083 .6874 L
.48281 .68817 L
.48394 .68855 L
.48519 .68889 L
.4874 .68936 L
.48865 .68953 L
.48999 .68965 L
.49126 .68971 L
.49242 .6897 L
.49466 .68955 L
.49592 .68938 L
.49709 .68917 L
.49921 .68865 L
.50145 .68793 L
.50546 .68613 L
.50911 .68391 L
.51293 .68092 L
.51681 .67709 L
.52004 .67319 L
.5232 .66857 L
.52803 .65928 L
.5304 .65313 L
.53219 .6471 L
.53344 .64156 L
.53398 .6384 L
.53438 .63549 L
.53468 .63265 L
.53489 .6296 L
.53499 .62674 L
.53501 .62415 L
.53493 .62116 L
.53483 .61948 L
.53471 .61794 L
.53443 .61516 L
.53402 .61226 L
.53348 .6093 L
.53277 .60621 L
.53118 .60091 L
.52926 .59617 L
.52722 .59223 L
.52497 .58879 L
.52266 .58593 L
.51978 .58315 L
.51701 .58112 L
Mistroke
.5157 .58035 L
.51429 .57964 L
.51306 .57912 L
.51171 .57866 L
.51026 .57828 L
.50888 .57802 L
.50724 .57785 L
.50574 .57781 L
.50421 .5779 L
.50258 .57812 L
.50105 .57845 L
.49968 .57885 L
.49808 .57945 L
.49637 .58024 L
.49335 .58205 L
.49034 .58442 L
.48736 .58743 L
.48484 .5906 L
.48266 .59393 L
.48079 .59735 L
.47901 .6013 L
.47763 .60511 L
.47658 .60866 L
.47561 .61297 L
.4752 .61535 L
.4749 .6176 L
.47469 .61969 L
.47456 .6216 L
.47448 .62369 L
.47447 .62587 L
.47453 .62777 L
.47463 .62948 L
.47481 .63142 L
.47503 .63322 L
.47556 .63633 L
.47633 .63956 L
.47738 .6429 L
.47873 .64618 L
.48167 .65125 L
.48353 .65354 L
.48543 .65539 L
.48722 .65676 L
.48927 .65793 L
.49045 .65845 L
.49155 .65882 L
.49216 .65899 L
.49282 .65914 L
.49403 .65933 L
.49517 .65941 L
.49638 .65939 L
Mistroke
.4974 .6593 L
.49853 .65911 L
.49965 .65883 L
.5007 .65849 L
.50264 .65765 L
.50466 .65645 L
.50676 .65484 L
.51023 .65118 L
.51299 .64708 L
.51542 .64198 L
.51651 .63891 L
.51731 .63601 L
.51786 .63341 L
.5181 .63191 L
.51829 .63055 L
.51844 .6291 L
.51855 .62756 L
.51861 .62614 L
.51862 .62481 L
.51859 .62337 L
.51851 .6218 L
.51844 .62102 L
.51836 .62019 L
.51817 .61872 L
.51793 .61729 L
.51766 .61597 L
.51703 .61358 L
.51612 .61097 L
.51512 .60875 L
.51385 .60657 L
.51235 .60456 L
.51085 .60304 L
.50918 .60175 L
.50768 .60091 L
.5068 .60055 L
.50598 .60028 L
.50552 .60017 L
.50502 .60006 L
.50454 .59999 L
.5041 .59994 L
.50326 .5999 L
.50237 .59994 L
.50191 .59999 L
.50142 .60006 L
.50095 .60015 L
.50053 .60025 L
.49956 .60055 L
.49855 .60096 L
.49701 .6018 L
.49544 .60293 L
Mistroke
.49284 .60554 L
.49142 .60745 L
.49023 .60944 L
.48922 .6115 L
.4884 .61354 L
.48773 .61565 L
.48723 .61763 L
.48681 .61986 L
.48665 .62109 L
.48653 .62226 L
.48646 .62338 L
.48642 .62457 L
.48643 .62557 L
.48646 .62667 L
.4865 .62727 L
.48654 .62782 L
.48668 .62904 L
.48683 .6301 L
.48704 .63118 L
.48745 .6329 L
.48801 .63462 L
.48927 .6374 L
.49019 .63887 L
.49115 .64007 L
.49207 .64101 L
.49312 .64183 L
.49369 .6422 L
.49422 .64248 L
.49477 .64273 L
.49529 .64292 L
.49589 .64309 L
.49621 .64316 L
.49656 .64322 L
.49719 .64329 L
.49777 .6433 L
.49809 .64329 L
.49842 .64326 L
.49902 .64318 L
.49966 .64303 L
.50035 .64282 L
.50095 .64258 L
.50157 .64227 L
.50267 .6416 L
.5037 .64078 L
.50476 .63973 L
.50563 .63868 L
.50648 .63745 L
.50717 .63626 L
.50785 .63486 L
.50883 .63224 L
Mistroke
.50924 .63072 L
.50957 .62903 L
.5097 .62817 L
.50975 .62769 L
.5098 .62725 L
.50986 .62638 L
.50989 .6256 L
.5099 .62487 L
.50989 .6241 L
.50985 .62346 L
.5098 .62275 L
.50971 .62201 L
.50959 .62123 L
.50932 .61988 L
.50889 .61841 L
.50832 .61694 L
.50767 .61569 L
.507 .61467 L
.50628 .61381 L
.50555 .61313 L
.50467 .6125 L
.50427 .61228 L
.50384 .61208 L
.50339 .61192 L
.50299 .61181 L
.50257 .61172 L
.50218 .61167 L
.50172 .61165 L
.5013 .61167 L
.50084 .61172 L
.50061 .61176 L
.50035 .61182 L
.49988 .61196 L
.49945 .61212 L
.49851 .6126 L
.49768 .61318 L
.49692 .61385 L
.49564 .61537 L
.49463 .61705 L
.49376 .61911 L
.49339 .62033 L
.49313 .62146 L
.49293 .62264 L
Mfstroke
.8 .625 m
.79964 .60198 L
.79868 .58128 L
.79683 .55772 L
.79438 .53584 L
.7915 .51599 L
.78834 .49801 L
.77945 .45878 L
.76815 .42148 L
.75317 .38334 L
.73491 .34718 L
.71562 .317 L
.69348 .28956 L
.67082 .26757 L
.64936 .25134 L
.62498 .23751 L
.61077 .23148 L
.59773 .22717 L
.59044 .22524 L
.58251 .22355 L
.57501 .2223 L
.56808 .22146 L
.55563 .2207 L
.54195 .22095 L
.5277 .2224 L
.51445 .22484 L
.50738 .22658 L
.4999 .22875 L
.48659 .23347 L
.45716 .24793 L
.43275 .26446 L
.40723 .28671 L
.38607 .30967 L
.36502 .33747 L
.33225 .39455 L
.3171 .42976 L
.30347 .4701 L
.2978 .49099 L
.29265 .51358 L
.28897 .53326 L
.28578 .55466 L
.28454 .56506 L
.28344 .57607 L
.28262 .58624 L
.28202 .59574 L
.28134 .61405 L
.28123 .62371 L
.2813 .63401 L
.28153 .64307 L
.28196 .65288 L
Mistroke
.28321 .67052 L
.28499 .68739 L
.28714 .70273 L
.29014 .71971 L
.29393 .73713 L
.30226 .76687 L
.31333 .79654 L
.32776 .82595 L
.34199 .84852 L
.35878 .86948 L
.37591 .88606 L
.39238 .89835 L
.40096 .90351 L
.41023 .90822 L
.41835 .91165 L
.4272 .91467 L
.43676 .91714 L
.44579 .91874 L
.45105 .91934 L
.45658 .91973 L
.46648 .91979 L
.47507 .91919 L
.4842 .91788 L
.49277 .91603 L
.5005 .91383 L
.51916 .90643 L
.53623 .89692 L
.55339 .88448 L
.56863 .87073 L
.5856 .8519 L
.59982 .83263 L
.62466 .78808 L
.63569 .76121 L
.64427 .73466 L
.65013 .71132 L
.65275 .69838 L
.65482 .68616 L
.6564 .67491 L
.65756 .66459 L
.65853 .65316 L
.65922 .64087 L
.65952 .62866 L
.65947 .61738 L
.65903 .60515 L
.65813 .59225 L
.65752 .58584 L
.65672 .57895 L
.65496 .56665 L
.65056 .54443 L
.6448 .52342 L
Mistroke
.63717 .50239 L
.62871 .4842 L
.62 .4691 L
.60876 .45345 L
.59537 .43897 L
.58182 .42791 L
.56862 .41999 L
.56127 .41665 L
.55321 .4138 L
.54948 .41275 L
.54551 .41183 L
.53838 .41064 L
.53149 .41006 L
.52505 .41 L
.51799 .41048 L
.51045 .41162 L
.50629 .41252 L
.50247 .41352 L
.49389 .41638 L
.48644 .41958 L
.47866 .42364 L
.46562 .43222 L
.45197 .44383 L
.42966 .47002 L
.41985 .48532 L
.41034 .50338 L
.40327 .5198 L
.39686 .53806 L
.39196 .55581 L
.38847 .57221 L
.3868 .58234 L
.38542 .59307 L
.38456 .60223 L
.38394 .61225 L
.38374 .61785 L
.38366 .62295 L
.38368 .62879 L
.38381 .6343 L
.3843 .64397 L
.38473 .64937 L
.38521 .65433 L
.38643 .66389 L
.38788 .67269 L
.39137 .68849 L
.3962 .7045 L
.40258 .72042 L
.40912 .73312 L
.41696 .74525 L
.42437 .75443 L
.43299 .76296 L
Mistroke
.4385 .7674 L
.44373 .77098 L
.44875 .77388 L
.45438 .77655 L
.45915 .77837 L
.46435 .77989 L
.46723 .78054 L
.46988 .78102 L
.47509 .78163 L
.48055 .78181 L
.4836 .78171 L
.48637 .78149 L
.49175 .78073 L
.49678 .77961 L
.50261 .77781 L
.50791 .77571 L
.51955 .76942 L
.52859 .76283 L
.53798 .75417 L
.54644 .74452 L
.55485 .73273 L
.56227 .71995 L
.56827 .70728 L
.57309 .69482 L
.57748 .68057 L
.58055 .66754 L
.58268 .65517 L
.58355 .64834 L
.58415 .64208 L
.58459 .63523 L
.58482 .62807 L
.5848 .62079 L
.58456 .61424 L
.58434 .61066 L
.58403 .60681 L
.58327 .59992 L
.58235 .5936 L
.58115 .58706 L
.57844 .57581 L
.57444 .56356 L
.56992 .55305 L
.5642 .54269 L
.55724 .53304 L
.55071 .52606 L
.54327 .52002 L
.53951 .51762 L
.5359 .51568 L
.53264 .51422 L
.52901 .5129 L
.52493 .51179 L
Mistroke
.52269 .51135 L
.5206 .51103 L
.51683 .5107 L
.51279 .51068 L
.51052 .51083 L
.50806 .51111 L
.50574 .51149 L
.50361 .51194 L
.4996 .51305 L
.49539 .5146 L
.48845 .51803 L
.48125 .52283 L
.46922 .53414 L
.46295 .54208 L
.45701 .55135 L
.45219 .56059 L
.44826 .56982 L
.44499 .57928 L
.44216 .58982 L
.44114 .59455 L
.44023 .59958 L
.43952 .6043 L
.439 .60861 L
.43855 .61363 L
.43825 .61898 L
.43813 .62391 L
.43817 .62854 L
.43825 .63113 L
.43839 .63385 L
.43876 .6387 L
.43904 .64135 L
.43934 .64381 L
.44019 .64933 L
.44191 .65748 L
.44423 .66559 L
.44661 .67208 L
.44961 .67868 L
.45326 .68515 L
.45761 .69126 L
.46164 .69581 L
.46637 .70003 L
.4717 .70361 L
.47472 .70515 L
.47759 .70632 L
.4803 .70718 L
.4828 .70776 L
.48571 .7082 L
.48849 .70838 L
.49005 .70838 L
.49147 .70833 L
Mistroke
.49311 .70818 L
.49464 .70798 L
.49737 .70745 L
.4989 .70706 L
.5003 .70664 L
.50638 .70411 L
.50937 .70245 L
.51256 .70033 L
.52218 .69156 L
.527 .68549 L
.53097 .67936 L
.53427 .6732 L
.5374 .6661 L
.53989 .65905 L
.54176 .6524 L
.54326 .64542 L
.54387 .64172 L
.54439 .63782 L
.54472 .63442 L
.54494 .63127 L
.54508 .62783 L
.54512 .62418 L
.54508 .62213 L
.54502 .62024 L
.54491 .61819 L
.54475 .61604 L
.54438 .61248 L
.54385 .60864 L
.54325 .60531 L
.54249 .60183 L
.54081 .59582 L
.53846 .58954 L
.53541 .58336 L
.53211 .57824 L
.52874 .57416 L
.52513 .57077 L
.52169 .5683 L
.51971 .56718 L
.51754 .56616 L
.51546 .5654 L
.51353 .56486 L
.51147 .56446 L
.50952 .56425 L
.50775 .56419 L
.50584 .56426 L
.50377 .56451 L
.50272 .5647 L
.50158 .56496 L
.49957 .56554 L
.4977 .56623 L
Mistroke
.49414 .56795 L
.49098 .56996 L
.48435 .57587 L
.48103 .5799 L
.4782 .58405 L
.47522 .58942 L
.47288 .59464 L
.47112 .5995 L
.46957 .60492 L
.46887 .60796 L
.46833 .61077 L
.46789 .61362 L
.46756 .61633 L
.46732 .61891 L
.46716 .62171 L
.4671 .62424 L
.46711 .62656 L
.4672 .62903 L
.46738 .63172 L
.46751 .63306 L
.46768 .63448 L
.46804 .63702 L
.46892 .64152 L
.47015 .64599 L
.47142 .64958 L
.47304 .65322 L
.47519 .65706 L
.47747 .66026 L
.48034 .66337 L
.48313 .66565 L
.48447 .66652 L
.48591 .66731 L
.48717 .66789 L
.48855 .66841 L
.49005 .66884 L
.49146 .66912 L
.49232 .66924 L
.49314 .66931 L
.49469 .66934 L
.49617 .66925 L
.49701 .66915 L
.49777 .66902 L
.49917 .6687 L
.50064 .66825 L
.50314 .6672 L
.5058 .66567 L
.50852 .66361 L
.51127 .66098 L
.51567 .65522 L
.5175 .65206 L
Mistroke
.51925 .64841 L
.52057 .64503 L
.52175 .64131 L
.5226 .63789 L
.52297 .63605 L
.52331 .63406 L
.52355 .63224 L
.52373 .63057 L
.52386 .62898 L
.52395 .62731 L
.52399 .62535 L
.52399 .62425 L
.52397 .62325 L
.52388 .62142 L
.52373 .61951 L
.52354 .61784 L
.52332 .61629 L
.52265 .61291 L
.52169 .60946 L
.52062 .60653 L
.51916 .60345 L
.51758 .60084 L
.51608 .59886 L
.51437 .59704 L
.5128 .59572 L
.51104 .59455 L
.50992 .59397 L
.50888 .59353 L
.50787 .5932 L
.5068 .59293 L
.50583 .59277 L
.50492 .59268 L
.50392 .59266 L
.50285 .59272 L
.50179 .59287 L
.50119 .59299 L
.50062 .59312 L
.4995 .59347 L
.49831 .59394 L
.49621 .59506 L
.49436 .59636 L
.49234 .59818 L
.49029 .60052 L
.48852 .60305 L
.48709 .60555 L
.4859 .60808 L
.48481 .61095 L
.48387 .61409 L
.48353 .61553 L
.48321 .61712 L
Mistroke
.48299 .61851 L
.48279 .62 L
.4827 .62082 L
.48264 .62157 L
.48255 .62303 L
.48251 .62435 L
.48251 .62578 L
.48255 .62711 L
.48263 .62833 L
.48276 .62962 L
.48294 .63096 L
.48336 .63328 L
.48397 .63565 L
.4848 .63807 L
.48566 .63999 L
.48669 .64187 L
.48884 .6447 L
.4903 .64607 L
.49111 .64667 L
.49198 .64722 L
.49277 .64763 L
.49364 .64799 L
.49445 .64825 L
.49521 .64842 L
.49601 .64854 L
.49677 .64858 L
.49746 .64857 L
.4982 .64851 L
.49901 .64837 L
.49946 .64827 L
.49986 .64816 L
.50064 .64789 L
.50136 .64759 L
.50276 .64684 L
.50422 .64579 L
.50558 .64457 L
.50692 .64305 L
.50808 .64147 L
.50907 .63983 L
.51063 .63649 L
.51134 .63446 L
.51194 .63223 L
.51232 .63029 L
.51248 .62918 L
.5126 .62814 L
.51266 .62755 L
.5127 .62701 L
.51273 .62644 L
.51275 .62583 L
.51276 .62481 L
Mistroke
.51273 .62374 L
.5127 .62314 L
.51266 .6225 L
.5126 .6219 L
.51254 .62135 L
.51239 .62033 L
.5122 .61928 L
.51175 .61743 L
.5112 .61578 L
.51063 .61441 L
.50992 .61305 L
.50905 .61173 L
.50804 .61052 L
.50711 .60966 L
.50602 .6089 L
.50552 .60862 L
.50498 .60837 L
.50451 .60819 L
.504 .60803 L
.50344 .60791 L
.50292 .60784 L
.5026 .60781 L
.5023 .6078 L
.50174 .60782 L
.50124 .60787 L
.50072 .60796 L
.50027 .60806 L
.49979 .60821 L
.49872 .60866 L
.49776 .60922 L
.49669 .61002 L
.49576 .61091 L
.49473 .61212 L
.49388 .61335 L
.49254 .61591 L
.49195 .61743 L
.4915 .61891 L
.49117 .6203 L
.49103 .62106 L
.49092 .62178 L
.49084 .62244 L
.49078 .62304 L
.49073 .62371 L
.4907 .62442 L
.4907 .62518 L
.49071 .62587 L
.49075 .62661 L
.49078 .62699 L
.49082 .62739 L
.49091 .62806 L
Mistroke
.49102 .62877 L
.49129 .63 L
.49165 .63123 L
.49213 .63245 L
.49317 .63436 L
.49392 .63532 L
.49469 .63608 L
.49542 .63662 L
.49584 .63688 L
.49625 .63708 L
.49668 .63725 L
.49708 .63737 L
.4973 .63742 L
.49753 .63747 L
.49778 .63751 L
.49802 .63753 L
.49827 .63754 L
.4985 .63754 L
.49876 .63753 L
.499 .63751 L
.49944 .63744 L
.49969 .63738 L
.49991 .63732 L
.50068 .63703 L
.50111 .63682 L
.5015 .63659 L
.50232 .636 L
.50304 .63533 L
.50433 .63371 L
.50491 .63272 L
.50545 .6316 L
.50583 .63064 L
.50616 .62957 L
.50632 .62894 L
.50645 .62837 L
.50655 .62782 L
.50664 .62723 L
.5067 .62667 L
.50675 .62616 L
.50677 .62565 L
.50679 .62517 L
.50678 .62462 L
.50676 .62412 L
.50672 .62357 L
.5067 .6233 L
.50666 .62301 L
.50651 .62208 L
.5064 .62157 L
.50629 .62113 L
.50574 .61957 L
Mistroke
.50542 .6189 L
.50502 .61823 L
.50459 .61766 L
.50409 .61712 L
.5036 .6167 L
.50312 .61639 L
.50266 .61616 L
.50242 .61607 L
.50215 .61598 L
.50184 .61591 L
.50154 .61587 L
.50127 .61585 L
.50098 .61586 L
.50067 .61589 L
.50051 .61591 L
.50033 .61595 L
.50003 .61603 L
.49974 .61613 L
.4992 .61638 L
.49871 .61667 L
.4977 .61755 L
Mfstroke
.8 1.09375 m
.82666 1.03921 L
.85144 .97798 L
.86961 .92315 L
.88583 .86218 L
.8939 .82444 L
.90012 .7894 L
.90485 .75647 L
.90885 .7202 L
.91134 .68783 L
.91275 .65764 L
.91327 .626 L
.91274 .59231 L
.91096 .55728 L
.90821 .52529 L
.90615 .50714 L
.90399 .49087 L
.89815 .45506 L
.88408 .39271 L
.86697 .33769 L
.84707 .28833 L
.8261 .24669 L
.79835 .20256 L
.77056 .16739 L
.73952 .13626 L
.7042 .10922 L
.68796 .09937 L
.66997 .09017 L
.65284 .08298 L
.63657 .07752 L
.61759 .07274 L
.60745 .07088 L
.59649 .06938 L
.58559 .06843 L
.5741 .068 L
.56429 .06809 L
.55357 .06867 L
.5343 .07097 L
.52356 .07296 L
.51384 .07519 L
.49506 .08069 L
.47751 .08726 L
.4402 .10602 L
.40237 .13223 L
.37179 .15939 L
.34031 .19392 L
.30936 .23588 L
.27984 .28578 L
.25746 .33284 L
.23739 .38569 L
Mistroke
.22164 .43964 L
.21086 .48957 L
.20686 .51389 L
.20343 .5402 L
.20103 .56502 L
.19956 .58774 L
.19903 .60055 L
.1987 .61421 L
.19875 .63865 L
.19918 .65345 L
.19986 .66734 L
.20069 .67971 L
.20185 .69302 L
.20498 .71988 L
.20942 .74765 L
.22016 .79532 L
.23229 .83425 L
.24804 .87299 L
.28278 .93356 L
.30609 .96248 L
.33267 .98764 L
.35671 1.00468 L
.37083 1.01251 L
.38407 1.01851 L
.39725 1.02328 L
.41132 1.0271 L
.42557 1.02968 L
.43369 1.03058 L
.4413 1.03107 L
.45506 1.03105 L
.46761 1.03005 L
.47453 1.0291 L
.48203 1.02774 L
.49561 1.02442 L
.50756 1.02057 L
.5206 1.01535 L
.54641 1.00177 L
.5694 .98577 L
.59 .96793 L
.61279 .94375 L
.63488 .91489 L
.66875 .85603 L
.68417 .82003 L
.69612 .78501 L
.70649 .74542 L
.711 .72293 L
.7143 .70236 L
.71649 .68486 L
.71804 .6685 L
.71917 .65061 L
Mistroke
.71974 .63151 L
.71977 .62203 L
.71961 .61174 L
.71882 .59322 L
.71744 .57546 L
.71561 .55928 L
.71322 .5431 L
.7105 .5282 L
.70422 .50134 L
.6958 .47403 L
.68488 .44664 L
.67197 .42124 L
.65594 .39657 L
.6374 .37465 L
.6187 .35791 L
.60021 .34561 L
.58272 .33731 L
.57286 .33392 L
.56762 .33247 L
.56202 .3312 L
.55171 .32957 L
.54214 .32885 L
.53307 .32887 L
.52317 .32967 L
.51287 .33135 L
.50336 .33368 L
.4945 .33653 L
.48654 .33966 L
.46904 .34851 L
.45088 .36075 L
.43225 .37696 L
.41717 .39324 L
.40184 .41331 L
.37802 .45427 L
.36724 .4788 L
.35871 .50274 L
.35224 .52536 L
.34733 .5472 L
.34514 .55935 L
.34317 .57262 L
.34177 .58469 L
.3408 .59585 L
.34003 .60965 L
.33982 .61655 L
.33973 .62408 L
.33992 .63731 L
.3405 .64948 L
.34105 .65679 L
.34169 .66363 L
.34322 .67626 L
Mistroke
.34534 .68954 L
.34819 .70356 L
.35428 .72624 L
.36236 .74855 L
.37046 .766 L
.38057 .78336 L
.39115 .79785 L
.40201 .80978 L
.41535 .82122 L
.42818 .82944 L
.43417 .83245 L
.44064 .83517 L
.44629 .8371 L
.45246 .83875 L
.45978 .84012 L
.46671 .84084 L
.47347 .84101 L
.47969 .84072 L
.48699 .83981 L
.49387 .83841 L
.5 .83671 L
.5066 .8344 L
.52109 .82749 L
.534 .81907 L
.55585 .7992 L
.56592 .78716 L
.57615 .77249 L
.59415 .73809 L
.60211 .71701 L
.60794 .69694 L
.61188 .67891 L
.6136 .66861 L
.61489 .65901 L
.6159 .64885 L
.61651 .63965 L
.61672 .63457 L
.61685 .62909 L
.61682 .61923 L
.61648 .60991 L
.61589 .60152 L
.61491 .592 L
.61367 .58314 L
.61075 .56793 L
.60658 .55221 L
.6009 .53616 L
.59365 .52063 L
.58581 .5076 L
.57796 .49725 L
.56826 .48724 L
.55877 .47981 L
Mistroke
.54784 .47363 L
.54218 .47133 L
.53896 .47027 L
.5359 .46942 L
.53322 .46881 L
.5303 .46827 L
.52517 .46766 L
.52226 .4675 L
.51916 .46748 L
.51362 .4678 L
.50852 .46851 L
.50377 .46954 L
.4986 .47106 L
.4931 .47315 L
.48343 .47802 L
.47352 .48475 L
.45703 .50048 L
.448 .51212 L
.44034 .5243 L
.42851 .54955 L
.42378 .56346 L
.41985 .57862 L
.41737 .59177 L
.41633 .59927 L
.4156 .60628 L
.41529 .61015 L
.41504 .61436 L
.41487 .61831 L
.41479 .62196 L
.4148 .6288 L
.41506 .63599 L
.41529 .63964 L
.41561 .64355 L
.41639 .65052 L
.41762 .6586 L
.41905 .66581 L
.42217 .67774 L
.42567 .68789 L
.43045 .69868 L
.43562 .70786 L
.44619 .72154 L
.4528 .72766 L
.45922 .73222 L
.46268 .73419 L
.46647 .73598 L
.46978 .73726 L
.47344 .73836 L
.47567 .73888 L
.47775 .73927 L
.47975 .73955 L
Mistroke
.48188 .73975 L
.48595 .73987 L
.48964 .73968 L
.49169 .73945 L
.49386 .7391 L
.49772 .73825 L
.50183 .73698 L
.50628 .73519 L
.51405 .73098 L
.52098 .72594 L
.53374 .71292 L
.54009 .70407 L
.54534 .69508 L
.55324 .67701 L
.55632 .66733 L
.55897 .65637 L
.55988 .65151 L
.56068 .64639 L
.56122 .64201 L
.56167 .63722 L
.56199 .63207 L
.5621 .62921 L
.56215 .62661 L
.56212 .6216 L
.56194 .61693 L
.56164 .6126 L
.56118 .60809 L
.56069 .60431 L
.56002 .60022 L
.55813 .59145 L
.55585 .5837 L
.55269 .57548 L
.54928 .56852 L
.54504 .5617 L
.54003 .55544 L
.53485 .55049 L
.52968 .54678 L
.52486 .54424 L
.52208 .54315 L
.5195 .54237 L
.5171 .54182 L
.51452 .54144 L
.51207 .54125 L
.50985 .54124 L
.50723 .5414 L
.5044 .5418 L
.50174 .54239 L
.49931 .54312 L
.49453 .54506 L
.48941 .54793 L
Mistroke
.4843 .55172 L
.47976 .55593 L
.47125 .5666 L
.4671 .57358 L
.46374 .58055 L
.46103 .58746 L
.45891 .59421 L
.45698 .60219 L
.45633 .60568 L
.45574 .60952 L
.45531 .61305 L
.45501 .61634 L
.45479 .61981 L
.45468 .6235 L
.45469 .6269 L
.45479 .63009 L
.45496 .63292 L
.45523 .63596 L
.45562 .63921 L
.45617 .64272 L
.45763 .64956 L
.4594 .6555 L
.4614 .66071 L
.46652 .67023 L
.46991 .67472 L
.47334 .67825 L
.4772 .6813 L
.48087 .68343 L
.48296 .68434 L
.48526 .68512 L
.48632 .6854 L
.48745 .68564 L
.48949 .68595 L
.49136 .68608 L
.49308 .68608 L
.49507 .68593 L
.49694 .68564 L
.49866 .68526 L
.50024 .6848 L
.50377 .6834 L
.50757 .6813 L
.51088 .67891 L
.51424 .67589 L
.51768 .67207 L
.52333 .66371 L
.52592 .65858 L
.528 .65353 L
.52961 .64869 L
.53085 .644 L
.53142 .64138 L
Mistroke
.53194 .63851 L
.53231 .63609 L
.53262 .63348 L
.53286 .63063 L
.533 .62798 L
.53304 .62645 L
.53305 .62484 L
.533 .62201 L
.53293 .62059 L
.53283 .61908 L
.53258 .6164 L
.53238 .61479 L
.53217 .61329 L
.53168 .61054 L
.53055 .60579 L
.52923 .60168 L
.5275 .59751 L
.52538 .59353 L
.52312 .5902 L
.52078 .58746 L
.51854 .58538 L
.51597 .58351 L
.51307 .58199 L
.51141 .58136 L
.50989 .58094 L
.50845 .58066 L
.50689 .58049 L
.50542 .58045 L
.50406 .58052 L
.50279 .58068 L
.50144 .58094 L
.50017 .58128 L
.49903 .58167 L
.49627 .5829 L
.49375 .58443 L
.48907 .58844 L
.48666 .59123 L
.48462 .59408 L
.48114 .60042 L
.47954 .6043 L
.47833 .60799 L
.47742 .6115 L
.47702 .61338 L
.47667 .61539 L
.47639 .61732 L
.47619 .61908 L
.47604 .62084 L
.47595 .6225 L
.4759 .6244 L
.47591 .62647 L
Mistroke
.47595 .62751 L
.47601 .62861 L
.47616 .63057 L
.47639 .63248 L
.47666 .63426 L
.47732 .63747 L
.47835 .64104 L
.47951 .64408 L
.48101 .64713 L
.48284 .64997 L
.4845 .652 L
.48638 .65381 L
.48808 .65508 L
.49001 .65616 L
.49113 .65663 L
.49215 .65697 L
.49273 .65712 L
.49335 .65725 L
.4945 .65742 L
.49557 .65749 L
.49671 .65746 L
.49768 .65736 L
.49874 .65718 L
.49979 .65691 L
.50078 .65658 L
.5026 .65577 L
.5045 .65463 L
.50648 .65309 L
.50974 .64962 L
.51233 .64572 L
.51371 .64302 L
.51481 .64039 L
.51581 .63739 L
.51623 .63582 L
.51663 .63412 L
.51692 .63261 L
.51713 .63123 L
.51731 .62983 L
.51744 .62854 L
.51753 .62703 L
.51756 .62624 L
.51758 .62541 L
.51757 .62402 L
.51754 .62324 L
.51751 .62251 L
.51741 .62129 L
.51728 .61998 L
.51708 .61864 L
.51687 .61742 L
.51639 .6153 L
Mistroke
.51575 .61317 L
.51483 .61084 L
.51383 .60884 L
.51163 .60568 L
.51034 .60435 L
.50907 .60332 L
.5076 .60243 L
.50676 .60205 L
.50597 .60176 L
.50515 .60154 L
.50438 .6014 L
.50398 .60135 L
.50353 .60132 L
.50306 .60131 L
.50263 .60132 L
.50183 .60138 L
.50109 .6015 L
.5003 .60169 L
.49946 .60196 L
.49812 .60256 L
.49672 .6034 L
.49436 .60538 L
.49304 .60687 L
.49189 .60844 L
.49005 .61176 L
.48926 .61362 L
.48863 .61544 L
.48807 .61749 L
.48762 .61974 L
.48745 .62087 L
.48738 .62146 L
.48731 .6221 L
.48726 .62271 L
.48723 .62326 L
.48719 .62433 L
.48718 .62536 L
.48721 .62645 L
.48728 .62747 L
.48737 .62839 L
.48748 .62924 L
.48762 .63013 L
.48795 .63168 L
.48845 .63343 L
.489 .63491 L
.48967 .63634 L
.49049 .63773 L
.4922 .63982 L
.49316 .64064 L
.49368 .64101 L
.49424 .64134 L
Mistroke
.49474 .6416 L
.4953 .64183 L
.49582 .642 L
.4963 .64212 L
.4966 .64218 L
.49692 .64222 L
.49751 .64227 L
.49809 .64227 L
.49862 .64223 L
.4992 .64214 L
.49952 .64207 L
.49982 .64199 L
.50042 .64179 L
.50106 .64152 L
.50225 .64085 L
.50332 .64005 L
.50515 .63812 L
.50607 .63683 L
.50694 .63531 L
.50759 .63392 L
.50818 .63231 L
.50864 .63072 L
.50883 .6299 L
.509 .62901 L
.50913 .62817 L
.50922 .62741 L
.50929 .62664 L
.50933 .62592 L
.50934 .62553 L
.50935 .62509 L
.50935 .62464 L
.50933 .62422 L
.5093 .62348 L
.50926 .62306 L
.50923 .62269 L
.50912 .62186 L
.50897 .62099 L
.50861 .61947 L
.50817 .61814 L
.50769 .61704 L
.50705 .61589 L
.50637 .61495 L
.50574 .61425 L
.50502 .61362 L
.50464 .61334 L
.5042 .61308 L
.50379 .61288 L
.50341 .61272 L
.50296 .61258 L
.50271 .61252 L
Mistroke
.50247 .61247 L
Mfstroke
0 g
.0001 w
0 0 m
0 0 rlineto s
% Start of user PostScript
-5. -4. -5.32442 -3.52959 MAarrowhead1
% End of user PostScript
0 .08929 m
0 0 rlineto s
% Start of user PostScript
-5. -3.42857 -5.27807 -2.96743 MAarrowhead1
% End of user PostScript
0 .17857 m
0 0 rlineto s
% Start of user PostScript
-5. -2.85714 -5.23173 -2.40527 MAarrowhead1
% End of user PostScript
0 .26786 m
0 0 rlineto s
% Start of user PostScript
-5. -2.28571 -5.18538 -1.84311 MAarrowhead1
% End of user PostScript
0 .35714 m
0 0 rlineto s
% Start of user PostScript
-5. -1.71429 -5.13904 -1.28095 MAarrowhead1
% End of user PostScript
0 .44643 m
0 0 rlineto s
% Start of user PostScript
-5. -1.14286 -5.09269 -0.718795 MAarrowhead1
% End of user PostScript
0 .53571 m
0 0 rlineto s
% Start of user PostScript
-5. -0.571429 -5.04635 -0.156636 MAarrowhead1
% End of user PostScript
0 .625 m
0 .68836 L
s
% Start of user PostScript
-5. 0 -5. 0.405524 MAarrowhead1
% End of user PostScript
0 .71429 m
.00463 .7762 L
s
% Start of user PostScript
-5. 0.571429 -4.95365 0.967683 MAarrowhead1
% End of user PostScript
0 .80357 m
.00927 .86404 L
s
% Start of user PostScript
-5. 1.14286 -4.90731 1.52984 MAarrowhead1
% End of user PostScript
0 .89286 m
.0139 .95188 L
s
% Start of user PostScript
-5. 1.71429 -4.86096 2.092 MAarrowhead1
% End of user PostScript
0 .98214 m
.01854 1.03971 L
s
% Start of user PostScript
-5. 2.28571 -4.81462 2.65416 MAarrowhead1
% End of user PostScript
0 1.07143 m
.02317 1.12755 L
s
% Start of user PostScript
-5. 2.85714 -4.76827 3.21632 MAarrowhead1
% End of user PostScript
0 1.16071 m
.02781 1.21539 L
s
% Start of user PostScript
-5. 3.42857 -4.72193 3.77848 MAarrowhead1
% End of user PostScript
0 1.25 m
0 0 rlineto s
0 1.25 m
0 1.25 L
s
% Start of user PostScript
-5. 4. -4.67558 4.34064 MAarrowhead1
% End of user PostScript
.07143 0 m
.03899 .06445 L
s
% Start of user PostScript
-4.28571 -4. -4.61013 -3.58752 MAarrowhead1
% End of user PostScript
.07143 .08929 m
.04362 .15229 L
s
% Start of user PostScript
-4.28571 -3.42857 -4.56379 -3.02537 MAarrowhead1
% End of user PostScript
.07143 .17857 m
.04826 .24012 L
s
% Start of user PostScript
-4.28571 -2.85714 -4.51744 -2.46321 MAarrowhead1
% End of user PostScript
.07143 .26786 m
.05289 .32796 L
s
% Start of user PostScript
-4.28571 -2.28571 -4.4711 -1.90105 MAarrowhead1
% End of user PostScript
.07143 .35714 m
.05752 .4158 L
s
% Start of user PostScript
-4.28571 -1.71429 -4.42475 -1.33889 MAarrowhead1
% End of user PostScript
.07143 .44643 m
.06216 .50364 L
s
% Start of user PostScript
-4.28571 -1.14286 -4.37841 -0.776727 MAarrowhead1
% End of user PostScript
.07143 .53571 m
.06679 .59147 L
s
% Start of user PostScript
-4.28571 -0.571429 -4.33206 -0.214568 MAarrowhead1
% End of user PostScript
.07143 .625 m
.07143 .67931 L
s
% Start of user PostScript
-4.28571 0 -4.28571 0.347592 MAarrowhead1
% End of user PostScript
.07143 .71429 m
.07606 .76715 L
s
% Start of user PostScript
-4.28571 0.571429 -4.23937 0.909751 MAarrowhead1
% End of user PostScript
.07143 .80357 m
.0807 .85499 L
s
% Start of user PostScript
-4.28571 1.14286 -4.19302 1.47191 MAarrowhead1
% End of user PostScript
.07143 .89286 m
.08533 .94282 L
s
% Start of user PostScript
-4.28571 1.71429 -4.14668 2.03407 MAarrowhead1
% End of user PostScript
.07143 .98214 m
.08997 1.03066 L
s
% Start of user PostScript
-4.28571 2.28571 -4.10033 2.59623 MAarrowhead1
% End of user PostScript
.07143 1.07143 m
.0946 1.1185 L
s
% Start of user PostScript
-4.28571 2.85714 -4.05399 3.15839 MAarrowhead1
% End of user PostScript
.07143 1.16071 m
.09924 1.20634 L
s
% Start of user PostScript
-4.28571 3.42857 -4.00764 3.72055 MAarrowhead1
% End of user PostScript
.07143 1.25 m
0 0 rlineto s
.07143 1.25 m
.07143 1.25 L
s
% Start of user PostScript
-4.28571 4. -3.9613 4.28271 MAarrowhead1
% End of user PostScript
.14286 0 m
.11042 .0554 L
s
% Start of user PostScript
-3.57143 -4. -3.89585 -3.64546 MAarrowhead1
% End of user PostScript
.14286 .08929 m
.11505 .14323 L
s
% Start of user PostScript
-3.57143 -3.42857 -3.8495 -3.0833 MAarrowhead1
% End of user PostScript
.14286 .17857 m
.11968 .23107 L
s
% Start of user PostScript
-3.57143 -2.85714 -3.80316 -2.52114 MAarrowhead1
% End of user PostScript
.14286 .26786 m
.12432 .31891 L
s
% Start of user PostScript
-3.57143 -2.28571 -3.75681 -1.95898 MAarrowhead1
% End of user PostScript
.14286 .35714 m
.12895 .40675 L
s
% Start of user PostScript
-3.57143 -1.71429 -3.71047 -1.39682 MAarrowhead1
% End of user PostScript
.14286 .44643 m
.13359 .49458 L
s
% Start of user PostScript
-3.57143 -1.14286 -3.66412 -0.834659 MAarrowhead1
% End of user PostScript
.14286 .53571 m
.13822 .58242 L
s
% Start of user PostScript
-3.57143 -0.571429 -3.61777 -0.2725 MAarrowhead1
% End of user PostScript
.14286 .625 m
.14286 .67026 L
s
% Start of user PostScript
-3.57143 0 -3.57143 0.28966 MAarrowhead1
% End of user PostScript
.14286 .71429 m
.14749 .7581 L
s
% Start of user PostScript
-3.57143 0.571429 -3.52508 0.851819 MAarrowhead1
% End of user PostScript
.14286 .80357 m
.15213 .84593 L
s
% Start of user PostScript
-3.57143 1.14286 -3.47874 1.41398 MAarrowhead1
% End of user PostScript
.14286 .89286 m
.15676 .93377 L
s
% Start of user PostScript
-3.57143 1.71429 -3.43239 1.97614 MAarrowhead1
% End of user PostScript
.14286 .98214 m
.1614 1.02161 L
s
% Start of user PostScript
-3.57143 2.28571 -3.38605 2.5383 MAarrowhead1
% End of user PostScript
.14286 1.07143 m
.16603 1.10945 L
s
% Start of user PostScript
-3.57143 2.85714 -3.3397 3.10046 MAarrowhead1
% End of user PostScript
.14286 1.16071 m
.17066 1.19728 L
s
% Start of user PostScript
-3.57143 3.42857 -3.29336 3.66262 MAarrowhead1
% End of user PostScript
.14286 1.25 m
0 0 rlineto s
.14286 1.25 m
.14286 1.25 L
s
% Start of user PostScript
-3.57143 4. -3.24701 4.22478 MAarrowhead1
% End of user PostScript
.21429 0 m
.18184 .04635 L
s
% Start of user PostScript
-2.85714 -4. -3.18156 -3.70339 MAarrowhead1
% End of user PostScript
.21429 .08929 m
.18648 .13418 L
s
% Start of user PostScript
-2.85714 -3.42857 -3.13522 -3.14123 MAarrowhead1
% End of user PostScript
.21429 .17857 m
.19111 .22202 L
s
% Start of user PostScript
-2.85714 -2.85714 -3.08887 -2.57907 MAarrowhead1
% End of user PostScript
.21429 .26786 m
.19575 .30986 L
s
% Start of user PostScript
-2.85714 -2.28571 -3.04253 -2.01691 MAarrowhead1
% End of user PostScript
.21429 .35714 m
.20038 .3977 L
s
% Start of user PostScript
-2.85714 -1.71429 -2.99618 -1.45475 MAarrowhead1
% End of user PostScript
.21429 .44643 m
.20502 .48553 L
s
% Start of user PostScript
-2.85714 -1.14286 -2.94983 -0.892591 MAarrowhead1
% End of user PostScript
.21429 .53571 m
.20965 .57337 L
s
% Start of user PostScript
-2.85714 -0.571429 -2.90349 -0.330432 MAarrowhead1
% End of user PostScript
.21429 .625 m
.21429 .66121 L
s
% Start of user PostScript
-2.85714 0 -2.85714 0.231728 MAarrowhead1
% End of user PostScript
.21429 .71429 m
.21892 .74904 L
s
% Start of user PostScript
-2.85714 0.571429 -2.8108 0.793887 MAarrowhead1
% End of user PostScript
.21429 .80357 m
.22355 .83688 L
s
% Start of user PostScript
-2.85714 1.14286 -2.76445 1.35605 MAarrowhead1
% End of user PostScript
.21429 .89286 m
.22819 .92472 L
s
% Start of user PostScript
-2.85714 1.71429 -2.71811 1.91821 MAarrowhead1
% End of user PostScript
.21429 .98214 m
.23282 1.01256 L
s
% Start of user PostScript
-2.85714 2.28571 -2.67176 2.48037 MAarrowhead1
% End of user PostScript
.21429 1.07143 m
.23746 1.10039 L
s
% Start of user PostScript
-2.85714 2.85714 -2.62542 3.04253 MAarrowhead1
% End of user PostScript
.21429 1.16071 m
.24209 1.18823 L
s
% Start of user PostScript
-2.85714 3.42857 -2.57907 3.60468 MAarrowhead1
% End of user PostScript
.21429 1.25 m
0 0 rlineto s
.21429 1.25 m
.21429 1.25 L
s
% Start of user PostScript
-2.85714 4. -2.53272 4.16684 MAarrowhead1
% End of user PostScript
.28571 0 m
.25327 .03729 L
s
% Start of user PostScript
-2.14286 -4. -2.46728 -3.76132 MAarrowhead1
% End of user PostScript
.28571 .08929 m
.25791 .12513 L
s
% Start of user PostScript
-2.14286 -3.42857 -2.42093 -3.19916 MAarrowhead1
% End of user PostScript
.28571 .17857 m
.26254 .21297 L
s
% Start of user PostScript
-2.14286 -2.85714 -2.37458 -2.637 MAarrowhead1
% End of user PostScript
.28571 .26786 m
.26718 .30081 L
s
% Start of user PostScript
-2.14286 -2.28571 -2.32824 -2.07484 MAarrowhead1
% End of user PostScript
.28571 .35714 m
.27181 .38864 L
s
% Start of user PostScript
-2.14286 -1.71429 -2.28189 -1.51268 MAarrowhead1
% End of user PostScript
.28571 .44643 m
.27645 .47648 L
s
% Start of user PostScript
-2.14286 -1.14286 -2.23555 -0.950523 MAarrowhead1
% End of user PostScript
.28571 .53571 m
.28108 .56432 L
s
% Start of user PostScript
-2.14286 -0.571429 -2.1892 -0.388364 MAarrowhead1
% End of user PostScript
.28571 .625 m
.28571 .65216 L
s
% Start of user PostScript
-2.14286 0 -2.14286 0.173796 MAarrowhead1
% End of user PostScript
.28571 .71429 m
.29035 .73999 L
s
% Start of user PostScript
-2.14286 0.571429 -2.09651 0.735955 MAarrowhead1
% End of user PostScript
.28571 .80357 m
.29498 .82783 L
s
% Start of user PostScript
-2.14286 1.14286 -2.05017 1.29811 MAarrowhead1
% End of user PostScript
.28571 .89286 m
.29962 .91567 L
s
% Start of user PostScript
-2.14286 1.71429 -2.00382 1.86027 MAarrowhead1
% End of user PostScript
.28571 .98214 m
.30425 1.00351 L
s
% Start of user PostScript
-2.14286 2.28571 -1.95747 2.42243 MAarrowhead1
% End of user PostScript
.28571 1.07143 m
.30889 1.09134 L
s
% Start of user PostScript
-2.14286 2.85714 -1.91113 2.98459 MAarrowhead1
% End of user PostScript
.28571 1.16071 m
.31352 1.17918 L
s
% Start of user PostScript
-2.14286 3.42857 -1.86478 3.54675 MAarrowhead1
% End of user PostScript
.28571 1.25 m
0 0 rlineto s
.28571 1.25 m
.28571 1.25 L
s
% Start of user PostScript
-2.14286 4. -1.81844 4.10891 MAarrowhead1
% End of user PostScript
.35714 0 m
.3247 .02824 L
s
% Start of user PostScript
-1.42857 -4. -1.75299 -3.81925 MAarrowhead1
% End of user PostScript
.35714 .08929 m
.32934 .11608 L
s
% Start of user PostScript
-1.42857 -3.42857 -1.70664 -3.25709 MAarrowhead1
% End of user PostScript
.35714 .17857 m
.33397 .20392 L
s
% Start of user PostScript
-1.42857 -2.85714 -1.6603 -2.69493 MAarrowhead1
% End of user PostScript
.35714 .26786 m
.3386 .29175 L
s
% Start of user PostScript
-1.42857 -2.28571 -1.61395 -2.13277 MAarrowhead1
% End of user PostScript
.35714 .35714 m
.34324 .37959 L
s
% Start of user PostScript
-1.42857 -1.71429 -1.56761 -1.57061 MAarrowhead1
% End of user PostScript
.35714 .44643 m
.34787 .46743 L
s
% Start of user PostScript
-1.42857 -1.14286 -1.52126 -1.00846 MAarrowhead1
% End of user PostScript
.35714 .53571 m
.35251 .55527 L
s
% Start of user PostScript
-1.42857 -0.571429 -1.47492 -0.446296 MAarrowhead1
% End of user PostScript
.35714 .625 m
.35714 .6431 L
s
% Start of user PostScript
-1.42857 0 -1.42857 0.115864 MAarrowhead1
% End of user PostScript
.35714 .71429 m
.36178 .73094 L
s
% Start of user PostScript
-1.42857 0.571429 -1.38223 0.678023 MAarrowhead1
% End of user PostScript
.35714 .80357 m
.36641 .81878 L
s
% Start of user PostScript
-1.42857 1.14286 -1.33588 1.24018 MAarrowhead1
% End of user PostScript
.35714 .89286 m
.37105 .90662 L
s
% Start of user PostScript
-1.42857 1.71429 -1.28953 1.80234 MAarrowhead1
% End of user PostScript
.35714 .98214 m
.37568 .99445 L
s
% Start of user PostScript
-1.42857 2.28571 -1.24319 2.3645 MAarrowhead1
% End of user PostScript
.35714 1.07143 m
.38032 1.08229 L
s
% Start of user PostScript
-1.42857 2.85714 -1.19684 2.92666 MAarrowhead1
% End of user PostScript
.35714 1.16071 m
.38495 1.17013 L
s
% Start of user PostScript
-1.42857 3.42857 -1.1505 3.48882 MAarrowhead1
% End of user PostScript
.35714 1.25 m
0 0 rlineto s
.35714 1.25 m
.35714 1.25 L
s
% Start of user PostScript
-1.42857 4. -1.10415 4.05098 MAarrowhead1
% End of user PostScript
.42857 0 m
.39613 .01919 L
s
% Start of user PostScript
-0.714286 -4. -1.0387 -3.87718 MAarrowhead1
% End of user PostScript
.42857 .08929 m
.40076 .10703 L
s
% Start of user PostScript
-0.714286 -3.42857 -0.992359 -3.31502 MAarrowhead1
% End of user PostScript
.42857 .17857 m
.4054 .19486 L
s
% Start of user PostScript
-0.714286 -2.85714 -0.946013 -2.75287 MAarrowhead1
% End of user PostScript
.42857 .26786 m
.41003 .2827 L
s
% Start of user PostScript
-0.714286 -2.28571 -0.899668 -2.19071 MAarrowhead1
% End of user PostScript
.42857 .35714 m
.41467 .37054 L
s
% Start of user PostScript
-0.714286 -1.71429 -0.853322 -1.62855 MAarrowhead1
% End of user PostScript
.42857 .44643 m
.4193 .45838 L
s
% Start of user PostScript
-0.714286 -1.14286 -0.806977 -1.06639 MAarrowhead1
% End of user PostScript
.42857 .53571 m
.42394 .54621 L
s
% Start of user PostScript
-0.714286 -0.571429 -0.760631 -0.504228 MAarrowhead1
% End of user PostScript
.42857 .625 m
.42857 .63405 L
s
% Start of user PostScript
-0.714286 0 -0.714286 0.0579319 MAarrowhead1
% End of user PostScript
.42857 .71429 m
.43321 .72189 L
s
% Start of user PostScript
-0.714286 0.571429 -0.66794 0.620091 MAarrowhead1
% End of user PostScript
.42857 .80357 m
.43784 .80973 L
s
% Start of user PostScript
-0.714286 1.14286 -0.621595 1.18225 MAarrowhead1
% End of user PostScript
.42857 .89286 m
.44248 .89756 L
s
% Start of user PostScript
-0.714286 1.71429 -0.575249 1.74441 MAarrowhead1
% End of user PostScript
.42857 .98214 m
.44711 .9854 L
s
% Start of user PostScript
-0.714286 2.28571 -0.528904 2.30657 MAarrowhead1
% End of user PostScript
.42857 1.07143 m
.45174 1.07324 L
s
% Start of user PostScript
-0.714286 2.85714 -0.482558 2.86873 MAarrowhead1
% End of user PostScript
.42857 1.16071 m
.45638 1.16108 L
s
% Start of user PostScript
-0.714286 3.42857 -0.436212 3.43089 MAarrowhead1
% End of user PostScript
.42857 1.25 m
.46101 1.24891 L
s
% Start of user PostScript
-0.714286 4. -0.389867 3.99305 MAarrowhead1
% End of user PostScript
.5 0 m
.46756 .01014 L
s
% Start of user PostScript
0 -4. -0.324419 -3.93512 MAarrowhead1
% End of user PostScript
.5 .08929 m
.47219 .09798 L
s
% Start of user PostScript
0 -3.42857 -0.278073 -3.37296 MAarrowhead1
% End of user PostScript
.5 .17857 m
.47683 .18581 L
s
% Start of user PostScript
0 -2.85714 -0.231728 -2.8108 MAarrowhead1
% End of user PostScript
.5 .26786 m
.48146 .27365 L
s
% Start of user PostScript
0 -2.28571 -0.185382 -2.24864 MAarrowhead1
% End of user PostScript
.5 .35714 m
.4861 .36149 L
s
% Start of user PostScript
0 -1.71429 -0.139037 -1.68648 MAarrowhead1
% End of user PostScript
.5 .44643 m
.49073 .44933 L
s
% Start of user PostScript
0 -1.14286 -0.0926911 -1.12432 MAarrowhead1
% End of user PostScript
.5 .53571 m
.49537 .53716 L
s
% Start of user PostScript
0 -0.571429 -0.0463455 -0.562159 MAarrowhead1
% End of user PostScript
.5 .625 m
.5 .625 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .71429 m
.50463 .71284 L
s
% Start of user PostScript
0 0.571429 0.0463455 0.562159 MAarrowhead1
% End of user PostScript
.5 .80357 m
.50927 .80067 L
s
% Start of user PostScript
0 1.14286 0.0926911 1.12432 MAarrowhead1
% End of user PostScript
.5 .89286 m
.5139 .88851 L
s
% Start of user PostScript
0 1.71429 0.139037 1.68648 MAarrowhead1
% End of user PostScript
.5 .98214 m
.51854 .97635 L
s
% Start of user PostScript
0 2.28571 0.185382 2.24864 MAarrowhead1
% End of user PostScript
.5 1.07143 m
.52317 1.06419 L
s
% Start of user PostScript
0 2.85714 0.231728 2.8108 MAarrowhead1
% End of user PostScript
.5 1.16071 m
.52781 1.15202 L
s
% Start of user PostScript
0 3.42857 0.278073 3.37296 MAarrowhead1
% End of user PostScript
.5 1.25 m
.53244 1.23986 L
s
% Start of user PostScript
0 4. 0.324419 3.93512 MAarrowhead1
% End of user PostScript
.57143 0 m
.53899 .00109 L
s
% Start of user PostScript
0.714286 -4. 0.389867 -3.99305 MAarrowhead1
% End of user PostScript
.57143 .08929 m
.54362 .08892 L
s
% Start of user PostScript
0.714286 -3.42857 0.436212 -3.43089 MAarrowhead1
% End of user PostScript
.57143 .17857 m
.54826 .17676 L
s
% Start of user PostScript
0.714286 -2.85714 0.482558 -2.86873 MAarrowhead1
% End of user PostScript
.57143 .26786 m
.55289 .2646 L
s
% Start of user PostScript
0.714286 -2.28571 0.528904 -2.30657 MAarrowhead1
% End of user PostScript
.57143 .35714 m
.55752 .35244 L
s
% Start of user PostScript
0.714286 -1.71429 0.575249 -1.74441 MAarrowhead1
% End of user PostScript
.57143 .44643 m
.56216 .44027 L
s
% Start of user PostScript
0.714286 -1.14286 0.621595 -1.18225 MAarrowhead1
% End of user PostScript
.57143 .53571 m
.56679 .52811 L
s
% Start of user PostScript
0.714286 -0.571429 0.66794 -0.620091 MAarrowhead1
% End of user PostScript
.57143 .625 m
.57143 .61595 L
s
% Start of user PostScript
0.714286 0 0.714286 -0.0579319 MAarrowhead1
% End of user PostScript
.57143 .71429 m
.57606 .70379 L
s
% Start of user PostScript
0.714286 0.571429 0.760631 0.504228 MAarrowhead1
% End of user PostScript
.57143 .80357 m
.5807 .79162 L
s
% Start of user PostScript
0.714286 1.14286 0.806977 1.06639 MAarrowhead1
% End of user PostScript
.57143 .89286 m
.58533 .87946 L
s
% Start of user PostScript
0.714286 1.71429 0.853322 1.62855 MAarrowhead1
% End of user PostScript
.57143 .98214 m
.58997 .9673 L
s
% Start of user PostScript
0.714286 2.28571 0.899668 2.19071 MAarrowhead1
% End of user PostScript
.57143 1.07143 m
.5946 1.05514 L
s
% Start of user PostScript
0.714286 2.85714 0.946013 2.75287 MAarrowhead1
% End of user PostScript
.57143 1.16071 m
.59924 1.14297 L
s
% Start of user PostScript
0.714286 3.42857 0.992359 3.31502 MAarrowhead1
% End of user PostScript
.57143 1.25 m
.60387 1.23081 L
s
% Start of user PostScript
0.714286 4. 1.0387 3.87718 MAarrowhead1
% End of user PostScript
.64286 0 m
0 0 rlineto s
% Start of user PostScript
1.42857 -4. 1.10415 -4.05098 MAarrowhead1
% End of user PostScript
.64286 .08929 m
.61505 .07987 L
s
% Start of user PostScript
1.42857 -3.42857 1.1505 -3.48882 MAarrowhead1
% End of user PostScript
.64286 .17857 m
.61968 .16771 L
s
% Start of user PostScript
1.42857 -2.85714 1.19684 -2.92666 MAarrowhead1
% End of user PostScript
.64286 .26786 m
.62432 .25555 L
s
% Start of user PostScript
1.42857 -2.28571 1.24319 -2.3645 MAarrowhead1
% End of user PostScript
.64286 .35714 m
.62895 .34338 L
s
% Start of user PostScript
1.42857 -1.71429 1.28953 -1.80234 MAarrowhead1
% End of user PostScript
.64286 .44643 m
.63359 .43122 L
s
% Start of user PostScript
1.42857 -1.14286 1.33588 -1.24018 MAarrowhead1
% End of user PostScript
.64286 .53571 m
.63822 .51906 L
s
% Start of user PostScript
1.42857 -0.571429 1.38223 -0.678023 MAarrowhead1
% End of user PostScript
.64286 .625 m
.64286 .6069 L
s
% Start of user PostScript
1.42857 0 1.42857 -0.115864 MAarrowhead1
% End of user PostScript
.64286 .71429 m
.64749 .69473 L
s
% Start of user PostScript
1.42857 0.571429 1.47492 0.446296 MAarrowhead1
% End of user PostScript
.64286 .80357 m
.65213 .78257 L
s
% Start of user PostScript
1.42857 1.14286 1.52126 1.00846 MAarrowhead1
% End of user PostScript
.64286 .89286 m
.65676 .87041 L
s
% Start of user PostScript
1.42857 1.71429 1.56761 1.57061 MAarrowhead1
% End of user PostScript
.64286 .98214 m
.6614 .95825 L
s
% Start of user PostScript
1.42857 2.28571 1.61395 2.13277 MAarrowhead1
% End of user PostScript
.64286 1.07143 m
.66603 1.04608 L
s
% Start of user PostScript
1.42857 2.85714 1.6603 2.69493 MAarrowhead1
% End of user PostScript
.64286 1.16071 m
.67066 1.13392 L
s
% Start of user PostScript
1.42857 3.42857 1.70664 3.25709 MAarrowhead1
% End of user PostScript
.64286 1.25 m
.6753 1.22176 L
s
% Start of user PostScript
1.42857 4. 1.75299 3.81925 MAarrowhead1
% End of user PostScript
.71429 0 m
0 0 rlineto s
% Start of user PostScript
2.14286 -4. 1.81844 -4.10891 MAarrowhead1
% End of user PostScript
.71429 .08929 m
.68648 .07082 L
s
% Start of user PostScript
2.14286 -3.42857 1.86478 -3.54675 MAarrowhead1
% End of user PostScript
.71429 .17857 m
.69111 .15866 L
s
% Start of user PostScript
2.14286 -2.85714 1.91113 -2.98459 MAarrowhead1
% End of user PostScript
.71429 .26786 m
.69575 .24649 L
s
% Start of user PostScript
2.14286 -2.28571 1.95747 -2.42243 MAarrowhead1
% End of user PostScript
.71429 .35714 m
.70038 .33433 L
s
% Start of user PostScript
2.14286 -1.71429 2.00382 -1.86027 MAarrowhead1
% End of user PostScript
.71429 .44643 m
.70502 .42217 L
s
% Start of user PostScript
2.14286 -1.14286 2.05017 -1.29811 MAarrowhead1
% End of user PostScript
.71429 .53571 m
.70965 .51001 L
s
% Start of user PostScript
2.14286 -0.571429 2.09651 -0.735955 MAarrowhead1
% End of user PostScript
.71429 .625 m
.71429 .59784 L
s
% Start of user PostScript
2.14286 0 2.14286 -0.173796 MAarrowhead1
% End of user PostScript
.71429 .71429 m
.71892 .68568 L
s
% Start of user PostScript
2.14286 0.571429 2.1892 0.388364 MAarrowhead1
% End of user PostScript
.71429 .80357 m
.72355 .77352 L
s
% Start of user PostScript
2.14286 1.14286 2.23555 0.950523 MAarrowhead1
% End of user PostScript
.71429 .89286 m
.72819 .86136 L
s
% Start of user PostScript
2.14286 1.71429 2.28189 1.51268 MAarrowhead1
% End of user PostScript
.71429 .98214 m
.73282 .94919 L
s
% Start of user PostScript
2.14286 2.28571 2.32824 2.07484 MAarrowhead1
% End of user PostScript
.71429 1.07143 m
.73746 1.03703 L
s
% Start of user PostScript
2.14286 2.85714 2.37458 2.637 MAarrowhead1
% End of user PostScript
.71429 1.16071 m
.74209 1.12487 L
s
% Start of user PostScript
2.14286 3.42857 2.42093 3.19916 MAarrowhead1
% End of user PostScript
.71429 1.25 m
.74673 1.21271 L
s
% Start of user PostScript
2.14286 4. 2.46728 3.76132 MAarrowhead1
% End of user PostScript
.78571 0 m
0 0 rlineto s
% Start of user PostScript
2.85714 -4. 2.53272 -4.16684 MAarrowhead1
% End of user PostScript
.78571 .08929 m
.75791 .06177 L
s
% Start of user PostScript
2.85714 -3.42857 2.57907 -3.60468 MAarrowhead1
% End of user PostScript
.78571 .17857 m
.76254 .14961 L
s
% Start of user PostScript
2.85714 -2.85714 2.62542 -3.04253 MAarrowhead1
% End of user PostScript
.78571 .26786 m
.76718 .23744 L
s
% Start of user PostScript
2.85714 -2.28571 2.67176 -2.48037 MAarrowhead1
% End of user PostScript
.78571 .35714 m
.77181 .32528 L
s
% Start of user PostScript
2.85714 -1.71429 2.71811 -1.91821 MAarrowhead1
% End of user PostScript
.78571 .44643 m
.77645 .41312 L
s
% Start of user PostScript
2.85714 -1.14286 2.76445 -1.35605 MAarrowhead1
% End of user PostScript
.78571 .53571 m
.78108 .50096 L
s
% Start of user PostScript
2.85714 -0.571429 2.8108 -0.793887 MAarrowhead1
% End of user PostScript
.78571 .625 m
.78571 .58879 L
s
% Start of user PostScript
2.85714 0 2.85714 -0.231728 MAarrowhead1
% End of user PostScript
.78571 .71429 m
.79035 .67663 L
s
% Start of user PostScript
2.85714 0.571429 2.90349 0.330432 MAarrowhead1
% End of user PostScript
.78571 .80357 m
.79498 .76447 L
s
% Start of user PostScript
2.85714 1.14286 2.94983 0.892591 MAarrowhead1
% End of user PostScript
.78571 .89286 m
.79962 .8523 L
s
% Start of user PostScript
2.85714 1.71429 2.99618 1.45475 MAarrowhead1
% End of user PostScript
.78571 .98214 m
.80425 .94014 L
s
% Start of user PostScript
2.85714 2.28571 3.04253 2.01691 MAarrowhead1
% End of user PostScript
.78571 1.07143 m
.80889 1.02798 L
s
% Start of user PostScript
2.85714 2.85714 3.08887 2.57907 MAarrowhead1
% End of user PostScript
.78571 1.16071 m
.81352 1.11582 L
s
% Start of user PostScript
2.85714 3.42857 3.13522 3.14123 MAarrowhead1
% End of user PostScript
.78571 1.25 m
.81816 1.20365 L
s
% Start of user PostScript
2.85714 4. 3.18156 3.70339 MAarrowhead1
% End of user PostScript
.85714 0 m
0 0 rlineto s
% Start of user PostScript
3.57143 -4. 3.24701 -4.22478 MAarrowhead1
% End of user PostScript
.85714 .08929 m
.82934 .05272 L
s
% Start of user PostScript
3.57143 -3.42857 3.29336 -3.66262 MAarrowhead1
% End of user PostScript
.85714 .17857 m
.83397 .14055 L
s
% Start of user PostScript
3.57143 -2.85714 3.3397 -3.10046 MAarrowhead1
% End of user PostScript
.85714 .26786 m
.8386 .22839 L
s
% Start of user PostScript
3.57143 -2.28571 3.38605 -2.5383 MAarrowhead1
% End of user PostScript
.85714 .35714 m
.84324 .31623 L
s
% Start of user PostScript
3.57143 -1.71429 3.43239 -1.97614 MAarrowhead1
% End of user PostScript
.85714 .44643 m
.84787 .40407 L
s
% Start of user PostScript
3.57143 -1.14286 3.47874 -1.41398 MAarrowhead1
% End of user PostScript
.85714 .53571 m
.85251 .4919 L
s
% Start of user PostScript
3.57143 -0.571429 3.52508 -0.851819 MAarrowhead1
% End of user PostScript
.85714 .625 m
.85714 .57974 L
s
% Start of user PostScript
3.57143 0 3.57143 -0.28966 MAarrowhead1
% End of user PostScript
.85714 .71429 m
.86178 .66758 L
s
% Start of user PostScript
3.57143 0.571429 3.61777 0.2725 MAarrowhead1
% End of user PostScript
.85714 .80357 m
.86641 .75542 L
s
% Start of user PostScript
3.57143 1.14286 3.66412 0.834659 MAarrowhead1
% End of user PostScript
.85714 .89286 m
.87105 .84325 L
s
% Start of user PostScript
3.57143 1.71429 3.71047 1.39682 MAarrowhead1
% End of user PostScript
.85714 .98214 m
.87568 .93109 L
s
% Start of user PostScript
3.57143 2.28571 3.75681 1.95898 MAarrowhead1
% End of user PostScript
.85714 1.07143 m
.88032 1.01893 L
s
% Start of user PostScript
3.57143 2.85714 3.80316 2.52114 MAarrowhead1
% End of user PostScript
.85714 1.16071 m
.88495 1.10677 L
s
% Start of user PostScript
3.57143 3.42857 3.8495 3.0833 MAarrowhead1
% End of user PostScript
.85714 1.25 m
.88958 1.1946 L
s
% Start of user PostScript
3.57143 4. 3.89585 3.64546 MAarrowhead1
% End of user PostScript
.92857 0 m
0 0 rlineto s
% Start of user PostScript
4.28571 -4. 3.9613 -4.28271 MAarrowhead1
% End of user PostScript
.92857 .08929 m
.90076 .04366 L
s
% Start of user PostScript
4.28571 -3.42857 4.00764 -3.72055 MAarrowhead1
% End of user PostScript
.92857 .17857 m
.9054 .1315 L
s
% Start of user PostScript
4.28571 -2.85714 4.05399 -3.15839 MAarrowhead1
% End of user PostScript
.92857 .26786 m
.91003 .21934 L
s
% Start of user PostScript
4.28571 -2.28571 4.10033 -2.59623 MAarrowhead1
% End of user PostScript
.92857 .35714 m
.91467 .30718 L
s
% Start of user PostScript
4.28571 -1.71429 4.14668 -2.03407 MAarrowhead1
% End of user PostScript
.92857 .44643 m
.9193 .39501 L
s
% Start of user PostScript
4.28571 -1.14286 4.19302 -1.47191 MAarrowhead1
% End of user PostScript
.92857 .53571 m
.92394 .48285 L
s
% Start of user PostScript
4.28571 -0.571429 4.23937 -0.909751 MAarrowhead1
% End of user PostScript
.92857 .625 m
.92857 .57069 L
s
% Start of user PostScript
4.28571 0 4.28571 -0.347592 MAarrowhead1
% End of user PostScript
.92857 .71429 m
.93321 .65853 L
s
% Start of user PostScript
4.28571 0.571429 4.33206 0.214568 MAarrowhead1
% End of user PostScript
.92857 .80357 m
.93784 .74636 L
s
% Start of user PostScript
4.28571 1.14286 4.37841 0.776727 MAarrowhead1
% End of user PostScript
.92857 .89286 m
.94248 .8342 L
s
% Start of user PostScript
4.28571 1.71429 4.42475 1.33889 MAarrowhead1
% End of user PostScript
.92857 .98214 m
.94711 .92204 L
s
% Start of user PostScript
4.28571 2.28571 4.4711 1.90105 MAarrowhead1
% End of user PostScript
.92857 1.07143 m
.95174 1.00988 L
s
% Start of user PostScript
4.28571 2.85714 4.51744 2.46321 MAarrowhead1
% End of user PostScript
.92857 1.16071 m
.95638 1.09771 L
s
% Start of user PostScript
4.28571 3.42857 4.56379 3.02537 MAarrowhead1
% End of user PostScript
.92857 1.25 m
.96101 1.18555 L
s
% Start of user PostScript
4.28571 4. 4.61013 3.58752 MAarrowhead1
% End of user PostScript
1 0 m
0 0 rlineto s
% Start of user PostScript
5. -4. 4.67558 -4.34064 MAarrowhead1
% End of user PostScript
1 .08929 m
.97219 .03461 L
s
% Start of user PostScript
5. -3.42857 4.72193 -3.77848 MAarrowhead1
% End of user PostScript
1 .17857 m
.97683 .12245 L
s
% Start of user PostScript
5. -2.85714 4.76827 -3.21632 MAarrowhead1
% End of user PostScript
1 .26786 m
.98146 .21029 L
s
% Start of user PostScript
5. -2.28571 4.81462 -2.65416 MAarrowhead1
% End of user PostScript
1 .35714 m
.9861 .29812 L
s
% Start of user PostScript
5. -1.71429 4.86096 -2.092 MAarrowhead1
% End of user PostScript
1 .44643 m
.99073 .38596 L
s
% Start of user PostScript
5. -1.14286 4.90731 -1.52984 MAarrowhead1
% End of user PostScript
1 .53571 m
.99537 .4738 L
s
% Start of user PostScript
5. -0.571429 4.95365 -0.967683 MAarrowhead1
% End of user PostScript
1 .625 m
1 .56164 L
s
% Start of user PostScript
5. 0 5. -0.405524 MAarrowhead1
% End of user PostScript
1 .71429 m
0 0 rlineto s
1 .71429 m
1 .71429 L
s
% Start of user PostScript
5. 0.571429 5.04635 0.156636 MAarrowhead1
% End of user PostScript
1 .80357 m
0 0 rlineto s
1 .80357 m
1 .80357 L
s
% Start of user PostScript
5. 1.14286 5.09269 0.718795 MAarrowhead1
% End of user PostScript
1 .89286 m
0 0 rlineto s
1 .89286 m
1 .89286 L
s
% Start of user PostScript
5. 1.71429 5.13904 1.28095 MAarrowhead1
% End of user PostScript
1 .98214 m
0 0 rlineto s
1 .98214 m
1 .98214 L
s
% Start of user PostScript
5. 2.28571 5.18538 1.84311 MAarrowhead1
% End of user PostScript
1 1.07143 m
0 0 rlineto s
1 1.07143 m
1 1.07143 L
s
% Start of user PostScript
5. 2.85714 5.23173 2.40527 MAarrowhead1
% End of user PostScript
1 1.16071 m
0 0 rlineto s
1 1.16071 m
1 1.16071 L
s
% Start of user PostScript
5. 3.42857 5.27807 2.96743 MAarrowhead1
% End of user PostScript
1 1.25 m
0 0 rlineto s
1 1.25 m
1 1.25 L
s
% Start of user PostScript
5. 4. 5.32442 3.52959 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ImageSize->{156.25, 195.312},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002L0000`b000`400?l00000o`00003oW?ooool0
09cooooo0017ooooo`?o0000D_ooool004Sooooo00?o0000ooooooooool0DOooool003oooooo1Ol0
00000ooooooo0000o`000003o`0005;ooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool2o`0000Oooooo00Ko0000ooooool0003o0000ooooool00002ooooo`03o`00
0?oooooo000000Co00001?ooool6o`0000Oooooo00?o0000ooooool000002_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo000>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0_l0
0009ooooo`;o00001?ooool00ol0003oooooo`000003o`000003ooooool0003ooooo04gooooo000=
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`?o00001Oooool2o`0000Cooooo00?o0000
ooooooooool0C?ooool000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo0_l00008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool000cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Oooooo0_l0001=ooooo`002oooool00ol0003oooooooooo`06ooooo`;o0000
2Oooool2o`0000Sooooo00?o0000ooooooooool08Oooool01?l0003oooooooooooooool@o`3o03;o
oooo00?o0000ooooooooool01_ooool000Wooooo0ol00008ooooo`;o00002?ooool2o`0002gooooo
00Co0000ooooool0o`3o0?l04?ooool3o`3o02Gooooo00?o0000ooooooooool01oooool2o`0000Oo
oooo0009ooooo`?o00001oooool2o`0000Wooooo00?o0000ooooooooool0:oooool3o`3o01Gooooo
0ol0o`0Rooooo`;o00002Oooool2o`0000Kooooo0009ooooo`;o00002?ooool00ol0003ooooooooo
o`0cooooo`?o0?l000?oooooo`000?ooool06?ooool2o`3o01Gooooo0_l00009ooooo`?o00002?oo
ool00ol0003oooooooooo`05ooooo`002Oooool00ol0003oooooooooo`0jooooo`?o0?l01?ooool2
o`0001[ooooo0_l0o`08ooooo`?o00002?ooool3o`0000Sooooo0_l0000:ooooo`03o`000?oooooo
oooo00Cooooo0014ooooo`;o0?l01oooool00ol0003oooooooooo`02ooooo`oo0?l02?ooool3o`00
0003o`3o0?oooooooooo00Gooooo0ol00008ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`00@oooool00ol0o`3oooooooooo`07ooooo`03
o`000?l0o`3o0?l000;o0?l03oooool3o`3o00Kooooo0ol000000ol0o`3oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo0011ooooo`;o0?l02?ooool3o`3o00Sooooo0_l00006ooooo`Co0000
0_ooool2o`3o00Gooooo0_l000000ooooooo0?l0ooooo`06ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`04o`000?oooooo0000o`0000Gooooo0_l0o`03o`0000Kooooo1Ol00008ooooo`;o0000
0oooool3o`3o00Cooooo00?o0000ooooool0o`001oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`003_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Oooooo00?o0?l0o`000?l000001?oo
ool3o`3o00Ko00002?ooool00ol0003oooooooooo`0?ooooo`03o`3o0?oooooooooo00Cooooo0_l0
o`0Zooooo`003Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01Oooool3o`0000Sooooo0_l00007ooooo`05o`3o0?l0003o0000o`000?ooool00ol0
o`07ooooo`03o`000?oooooooooo01[ooooo00?o0?l0ooooooooool01Oooool00ol0o`3ooooooooo
o`0Wooooo`003Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01Oooool3o`0000Oooooo0_l00007ooooo`03o`3o0?l0003o000000;ooooo00?o0?l0
ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`;o0?l01_ooool00ol0o`3oooooooooo`0V
ooooo`003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l00007oooo
o`;o00002Oooool00ol0003oooooooooo`05ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0oooo
ooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0oooo
ooooool09Oooool000_ooooo00?o0000ooooooooool01oooool2o`0000Wooooo0_l00007ooooo`03
o`000?oooooooooo00oooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0:ooooo`;o
00007oooool2o`3o00Gooooo00?o0?l0ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00
2_ooool2o`0000Wooooo0_l00008ooooo`;o00006?ooool2o`3o00?ooooo0_l0o`0=ooooo`03o`00
0?oooooooooo023ooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`0@ooooo`03o`00
0?oooooooooo00Sooooo0_l00006ooooo`002_ooool2o`0000Sooooo0_l00009ooooo`03o`000?oo
oooooooo01Kooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`06ooooo`?o00001?oo
ool00ol0003oooooooooo`0Qooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`?o00001Oooool000Wooooo0_l00009ooooo`03o`000?oooooo
oooo023ooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0Qooooo`03o`3o0?oooooooooo00Cooooo00?o
0?l0ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l0
0006ooooo`002Oooool00ol0003oooooooooo`0Zooooo`03o`3o0?oooooooooo00;ooooo00Co0?l0
oooooooooooooooo1Ol00005ooooo`05o`000?ooooooooooooooool000009?ooool00ol0o`3ooooo
o`000004ooooo`03o`3o0?oooooooooo00?ooooo0_l00009ooooo`;o00002Oooool00ol0003ooooo
ooooo`04ooooo`00=Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00[ooooo0_l0
0004ooooo`;o00006_ooool2o`0000Sooooo00?o0?l0o`000?l000001?ooool00ol0o`3ooooooooo
o`03ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo000e
ooooo`05o`3o0?ooooooooooooooool0o`003oooool01Ol0003ooooooooooooooooo000001_ooooo
0ol00008ooooo`03o`3o0?l0003o000000[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo000dooooo`05o`3o0?ooooooooooooooool0o`00
3?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool2o`0000Oo
oooo1?l00007ooooo`?o00002?ooool2o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0003ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool01_l0o`3ooooooooooooooooo0?l0o`0000Sooooo0ol00002oooo
o`?o00000_ooool3o`0000Kooooo1Ol00008ooooo`;o00002?ooool00ol0003oooooo`000007oooo
o`03o`3o0?oooooo000000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo000>ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Oo0?l0oooooooo
ooooooooo`000?oooooo000000Sooooo00?o0000ooooooooool01_ooool5o`0000Sooooo00?o0000
ooooooooool07?ooool00ol0o`3oooooooooo`0Sooooo`003Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool2o`0000Cooooo00Go0?l0oooo
ooooooooooooo`3o0002o`0000Sooooo0ol0000:ooooo`03o`000?oooooooooo02Oooooo00?o0?l0
ooooooooool08_ooool000gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Kooooo0_l00003ooooo`03o`3o0?oooooooooo00;ooooo0_l00008oooo
o`;o00003?ooool00ol0003oooooooooo`0Xooooo`03o`3o0?oooooooooo027ooooo000<ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool2o`0000Sooooo0_l00004ooooo`06
o`3o0?ooooooooooooooool0o`3o00005oooool00ol0003oooooooooo`0Yooooo`03o`3o0?oooooo
oooo023ooooo000<ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`;o00002?ooool00ol0
003oooooooooo`02ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool05_ooool00ol0
003oooooooooo`0Yooooo`03o`3o0?oooooooooo01Wooooo00?o0000ooooooooool01?ooool000[o
oooo0ol00008ooooo`?o00001oooool2o`0000kooooo00Go0?l0ooooooooooooooooo`3o000Ioooo
o`;o00000oooool5o`3o02?ooooo00?o0?l0ooooooooool03Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Cooooo000:ooooo`?o00002?ooool2o`0000Sooooo00?o0000oooooooo
ool03?ooool01Ol0o`3ooooooooooooooooo0?l001[ooooo00?o0000o`3o0?l0o`000_l0o`05oooo
o`Oo0?l07Oooool00ol0o`3oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0_l00005oooo
o`002_ooool2o`0000Wooooo00?o0000ooooooooool05_ooool01Ol0o`3ooooooooooooooooo0?l0
01Oooooo1?l0o`0@ooooo`;o0?l06oooool01Ol0o`3ooooooooooooooooo000000[ooooo0_l00009
ooooo`;o00001Oooool000[ooooo00?o0000ooooooooool08?ooool01Ol0o`3ooooooooooooooooo
0?l001Kooooo0_l0o`03ooooo`03o`000?oooooooooo013ooooo0_l0o`0Cooooo`03o`000?oooooo
oooo00Cooooo00?o0?l0ooooooooool00_l00009ooooo`?o00002Oooool00ol0003oooooooooo`03
ooooo`00;?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo01;ooooo0_l0o`05oooo
o`03o`000?oooooooooo01;ooooo00?o0?l0ooooooooool01Oooool2o`0000Wooooo0_l00006oooo
o`03o`3o0?oooooooooo00;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00?ooooo000/ooooo`05o`3o0?ooooooooooooooool0o`005?ooool00ol0o`3oooooooooo`05oooo
o`;o00005?ooool2o`3o00Gooooo0ol00009ooooo`;o00001Oooool00ol0o`3oooooooooo`02o`00
00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`00:oooool01Ol0o`3o
oooooooooooooooo0?l001Cooooo00?o0?l0ooooooooool01_ooool00ol0003oooooooooo`0@oooo
o`;o00000oooool00ol0o`3oooooooooo`03ooooo`?o00002?ooool00ol0003oooooooooo`05oooo
o`04o`3o0?ooooooooooo`0000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`05ooooo`04o`3o0?oooooo0000o`3o00Wooooo00?o0000
ooooooooool01oooool2o`0000Sooooo0_l00007ooooo`Co00002?ooool2o`0000?ooooo00?o0?l0
ooooooooool00oooool2o`0000Wooooo00?o0000ooooooooool01Oooool01?l0o`3oooooooooool0
000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool000kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00Go0?l0
oooooooooooo0000o`3o0007ooooo`?o00002?ooool00ol0o`3o0000o`000006ooooo`Co00002_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool05Ooo
ool00ol0o`3oooooooooo`0Jooooo`003Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01?l0o`3o0000o`000?l0o`08ooooo`?o00001ooo
ool00ol0o`3o0000ooooo`0:ooooo`;o00006Oooool00ol0o`3oooooooooo`0Eooooo`03o`3o0?oo
oooooooo01Wooooo000=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`04ooooo`03o`3o0?oooooo000000;o00001oooool2o`0000Sooooo00?o0?l0
o`000?ooool02oooool00ol0003oooooooooo`0Iooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0
ooooooooool06?ooool000gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`;o00001_ooool01?l0o`3oooooo`000?l00008ooooo`03o`000?oooooooooo00Oooooo00?o0?l0
ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0
ooooooooool06?ooool000cooooo00?o0000ooooooooool01oooool2o`0000Wooooo0_l00005oooo
o`04o`3o0?ooooooooooo`0001;ooooo00?o0?l0ooooooooool01?ooool5o`0000?ooooo00?o0000
ooooooooool06_ooool00ol0o`3oooooooooo`0Eooooo`03o`3o0?oooooooooo013ooooo00?o0000
ooooooooool01?ooool000_ooooo0_l00009ooooo`;o00002?ooool2o`0000Kooooo00Co0?l0oooo
oooooooo0?l04Oooool00ol0o`3oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool06oooool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`002oooool2o`0000Sooooo0_l00009
ooooo`03o`000?oooooooooo00Cooooo00Co0?l0oooooooooooo0?l04Oooool00ol0o`3ooooooooo
o`05o`0000?ooooo00?o0000ooooooooool00oooool00ol0003o0?l0o`3o0009o`3o01?ooooo00?o
0?l0ooooooooool04oooool00ol0o`3oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo0_l0
0005ooooo`002oooool2o`0000Sooooo00?o0000ooooooooool03oooool01?l0o`3oooooooooool0
o`0Aooooo`03o`3o0?oooooooooo00Wooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l04Ooo
ool00ol0o`3oooooooooo`0@ooooo`04o`000?ooooooooooo`3o00Oooooo0_l00008ooooo`?o0000
1?ooool000_ooooo00?o0000ooooooooool06Oooool01?l0o`3oooooooooool0o`0@ooooo`03o`3o
0?oooooooooo00Oooooo00Ko0000ooooooooooooooooo`000?l0o`02ooooo`03o`000?oooooooooo
00;ooooo0ol0o`07ooooo`;o0?l03oooool00ol0o`3oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo0_l000000ooooooo0?l0ooooo`06ooooo`;o00002Oooool00ol0003oooooooooo`03oooo
o`009_ooool01?l0o`3oooooooooool0o`0@ooooo`03o`3o0?oooooooooo00Sooooo00?o0000oooo
ooooool00_l0o`03ooooo`Go0?l00oooool4o`3o00Gooooo0_l0o`0;ooooo`04o`000?oooooooooo
o`3o00Kooooo0_l00009ooooo`?o000000?o0?l0ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00?ooooo000Vooooo`04o`3o0?ooooooooooo`3o00oooooo00?o0?l0
ooooooooool02_ooool01?l0003o0?l0o`000?ooool3o`3o0003o`000?oooooooooo00Wooooo0ol0
o`04ooooo`03o`3o0?oooooooooo00Sooooo0_l00002ooooo`03o`3o0?oooooooooo00Cooooo0_l0
0008ooooo`;o00000_ooool00ol0o`3oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool002Gooooo00Co0?l0oooooooooooo0?l04?ooool00ol0o`3ooooooooo
o`09ooooo`;o0?l000?oooooo`3o0?l0o`000oooool2o`0000gooooo0_l0o`02ooooo`?o00002Ooo
ool2o`0000;ooooo00?o0?l0ooooooooool00oooool00ol0003oooooooooo`08ooooo`04o`000?oo
ooooooooo`3o00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`009Ooo
ool01?l0o`3oooooooooool0o`0?ooooo`03o`3o0?oooooooooo00Oooooo00?o0000ooooool0o`00
0_ooool00ol0o`3oooooooooo`03ooooo`;o00001oooool4o`0000Cooooo00?o0?l0ooooooooool0
0ol00008ooooo`05o`000?ooooooooooooooool0o`001Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooo0?l000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`00
0oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003o0?l0ooooo`02ooooo`03o`3o0?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool2o`0000Wooooo0_l00002ooooo`03o`3o0?oooooooooo00;ooooo1?l00008ooooo`?o0000
1Oooool01?l0o`3oooooooooool0000:ooooo`05o`000?ooooooooooooooool0o`001Oooool00ol0
003oooooooooo`08ooooo`04o`000?ooooooooooo`3o00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00Go0000o`3o0?ooooooooooo`3o0004ooooo`;o00002Oooool2o`0000Sooooo00Go0000
o`3o0?ooooooooooo`3o0007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Ooo
ool01?l0o`3oooooooooool0o`0=ooooo`03o`3o0?oooooooooo017ooooo00?o0?l0ooooooooool0
5?ooool000kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooo0?l000;ooooo00?o0?l0ooooooooool00_ooool2o`0000Sooooo0_l00008ooooo`05o`000?l0
o`3oooooooooool0o`002?ooool2o`0001;ooooo00Co0?l0oooooooooooo0?l03Oooool00ol0o`3o
ooooooooo`0@ooooo`03o`3o0?oooooooooo01Cooooo000=ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool2o`000005o`3o0?ooooooooooooooool0o`000oooool2o`0000Wo
oooo00?o0000ooooooooool01oooool01?l0o`3oooooooooool0o`09ooooo`03o`000?oooooooooo
01;ooooo00Co0?l0oooooooooooo0?l03?ooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooo
oooo01Cooooo000=ooooo`03o`000?oooooooooo00Kooooo0ol00008ooooo`;o000000Co0?l0oooo
oooooooo0?l01?ooool00ol0003oooooooooo`07ooooo`03o`3o0?oooooooooo00Oooooo00Co0?l0
oooooooooooo0?l02_ooool00ol0003oooooooooo`0Cooooo`04o`3o0?ooooooooooo`3o00cooooo
00?o0?l0ooooooooool04?ooool00ol0o`3oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
000;ooooo`?o00002?ooool3o`0000Sooooo00?o0000ooooool0o`000_ooool00ol0o`3ooooooooo
o`0;ooooo`03o`3o0?oooooooooo00Oooooo00Co0?l0oooooooooooo0?l02oooool00ol0003ooooo
ooooo`0Dooooo`03o`3o0?oooooo0?l000cooooo00?o0?l0ooooooooool04?ooool00ol0o`3ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool000_ooooo0ol0
0008ooooo`;o00002Oooool00ol0003o0?l0ooooo`02ooooo`03o`3o0?oooooooooo00_ooooo00?o
0?l0ooooooooool01oooool01?l0o`3oooooooooool0o`0;ooooo`03o`000?oooooooooo01Cooooo
00Co0?l0oooooooooooo0?l03?ooool00ol0o`3oooooooooo`0?ooooo`03o`3o0?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool2o`0000Cooooo000<ooooo`;o00002?ooool00ol0003ooooo
ooooo`09ooooo`04o`3o0?ooooooooooo`3o00gooooo00?o0?l0ooooooooool01oooool01?l0o`3o
ooooooooool0o`0<ooooo`;o00000_ooool2o`3o01;ooooo00?o0?l0ooooool0o`003?ooool00ol0
o`3oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool00_ooool2o`00
00Wooooo0_l00004ooooo`003?ooool00ol0003oooooooooo`0Cooooo`04o`3o0?ooooooooooo`3o
00gooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooo`3o000<ooooo`Go0?l00_ooool4o`3o
00oooooo00?o0?l0ooooool0o`002oooool00ol0o`3oooooo`00000:ooooo`03o`000?oooooooooo
00?ooooo00Co0?l0oooooooooooooooo0ol00008ooooo`03o`000?oooooooooo00?ooooo000Roooo
o`04o`3o0?ooooooooooo`3o00gooooo00?o0?l0ooooooooool01_ooool01?l0o`3oooooooooool0
o`0:ooooo`;o0?l000?oooooo`000?ooool02?ooool2o`3o00kooooo0_l0o`03ooooo`03o`000?oo
oooooooo00Kooooo00?o0?l0o`000?ooool02Oooool2o`0000Cooooo00?o0?l0ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo000Rooooo`04o`3o0?oooooo
ooooo`3o00cooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooo`3o000:ooooo`05o`3o0?oo
ooooooooooooool000002oooool00ol0o`3oooooooooo`0;ooooo`03o`3o0?oooooo0?l000;ooooo
00?o0000ooooooooool01_ooool00ol0o`3o0000o`000009ooooo`03o`000?oooooooooo00?ooooo
00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
000Qooooo`04o`3o0?ooooooooooo`3o00gooooo00?o0?l0ooooooooool01_ooool00ol0o`3ooooo
o`3o0009ooooo`;o0?l01?ooool00ol0003oooooooooo`0:ooooo`03o`3o0?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool01?l0o`3oooooo`3o0?ooool2o`0000Sooooo0ol00009ooooo`03
o`000?oooooooooo00;ooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo000Qooooo`04o`3o0?ooooooooooo`3o00cooooo00?o0?l0oooooooo
ool01oooool00ol0o`3oooooo`3o0004ooooo`;o00000_ooool00ol0o`3oooooooooo`04ooooo`;o
00001oooool3o`0000;ooooo00?o0?l0ooooooooool00oooool2o`0000Gooooo00Co0?l0oooooooo
oooo0?l00_l00008ooooo`03o`3o0?l0003ooooo00Wooooo00?o0000ooooooooool00_ooool00ol0
o`3oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool000?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00Co0?l0ooooool0003o0?l02?ooool01Ol0003ooooooooooooooooo0?l000Gooooo0_l00000
1?oooooo0?l0ooooool0o`05ooooo`?o000000?oooooo`3o0?ooool01?ooool4o`0000Oooooo0ol0
0002ooooo`03o`3o0?oooooooooo00?ooooo0_l00005ooooo`05o`3o0?oooooo0?l0ooooool00000
2?ooool00ol0o`3o0000ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo000>ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool01?l0o`3oooooo`000?l0o`07ooooo`;o0000
0oooool00ol0o`3oooooooooo`03ooooo`;o000000?o0?l0ooooool0o`001Oooool2o`0000;ooooo
00Co0?l0o`000?l0003o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
oooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`3o0?oooooo0?l000_o
oooo00?o0?l0ooooooooool03_ooool00ol0o`3oooooooooo`0Aooooo`003_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Gooooo00Co0?l0ooooool0003o0?l02?ooool3o`000003
ooooool0o`3ooooo00Gooooo0_l000000ol0o`3oooooo`3o0005ooooo`04o`000?ooooooooooo`3o
00;ooooo00?o0000ooooooooool00_ooool:o`3o00Sooooo00?o0?l0ooooooooool02?ooool01?l0
o`3oooooooooool0o`0:ooooo`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool04Oooool0
00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`04o`3o0?l0003o0000
o`0000Sooooo0_l00002ooooo`03o`3o0?oooooooooo00Cooooo00Co0000ooooool0o`3o0?l01?oo
ool4o`000005o`3o0?ooooooooooooooool000000oooool00ol0o`3oooooo`000006o`3o00;ooooo
00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooo0?l000[ooooo
00?o0?l0ooooooooool03_ooool00ol0o`3oooooooooo`0Aooooo`003Oooool00ol0003ooooooooo
o`07ooooo`;o00001oooool01?l0o`3o0000o`000?l00008ooooo`05o`000?ooooooooooooooool0
o`001oooool00ol0o`3oooooo`3o0008ooooo`06o`3o0?ooooooooooooooool0003ooooo0_l0o`00
0ooooooo0?l0o`3o0005ooooo`?o0?l000?oooooo`3o0?ooool01_ooool00ol0o`3oooooooooo`08
ooooo`03o`3o0?oooooo0?l000[ooooo00?o0?l0ooooooooool03oooool00ol0o`3oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo000<ooooo`;o00002Oooool2o`0000Oooooo00?o0?l0o`00
0?l000003?ooool00ol0o`3oooooooooo`06ooooo`;o0?l02?ooool00ol0o`3oooooooooo`02oooo
o`03o`000?l0o`3ooooo00;o0?l000?oooooo`000?ooool01oooool00ol0o`3oooooo`3o0007oooo
o`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooool0o`002_ooool00ol0o`3oooooooooo`0?oooo
o`04o`3o0?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool000cooooo0_l00009oooo
o`03o`000?oooooooooo00Gooooo00Co0?l0ooooool0003o0?l03?ooool00ol0o`3oooooooooo`06
ooooo`;o0?l01oooool00ol0o`3oooooooooo`02ooooo`04o`000?l0o`3oooooo`3o00?ooooo00?o
0000ooooooooool01oooool3o`3o00Kooooo00?o0?l0ooooooooool01oooool01?l0o`3ooooooooo
ool0o`0:ooooo`03o`3o0?oooooooooo00kooooo00Co0?l0oooooooooooo00002Oooool2o`0000Co
oooo0003ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`03o`000?oooooooooo00Gooooo
00Co0?l0oooooooooooo0?l03?ooool00ol0o`3oooooooooo`05ooooo`;o0?l02?ooool00ol0o`3o
ooooooooo`02ooooo`03o`3o0?l0003o0?l000Cooooo00?o0000ooooooooool02Oooool00ol0o`3o
ooooooooo`05ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooool0o`002_ooool00ol0o`3o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0?l0ooooool000000_l00008ooooo`;o
00001?ooool000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`04o`3o
0?ooooooooooo`3o00cooooo00?o0?l0ooooooooool01Oooool2o`3o00Oooooo00?o0?l0oooooooo
ool00_ooool00ol0o`3oooooo`3o0005ooooo`;o00002_ooool2o`3o00Kooooo00?o0?l0oooooooo
ool01oooool00ol0o`3oooooo`3o0009ooooo`03o`000?l0o`3ooooo00Oooooo00?o0000oooooooo
ool01Oooool00ol0o`3oooooo`000002o`0000Wooooo00?o0000ooooooooool00_ooool001oooooo
00Co0?l0oooooooooooo0?l02oooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooo0?l000Oo
oooo00?o0?l0ooooooooool00_ooool2o`3o00Kooooo00Co0000o`3o0?l0o`3o0?l02Oooool2o`3o
00Gooooo00?o0?l0ooooooooool01oooool01?l0o`3o0000ooooool0o`08ooooo`03o`000?l0o`3o
oooo00Oooooo0_l00006ooooo`04o`3o0?ooooooooooo`0000[ooooo00?o0000ooooooooool00_oo
ool001oooooo00Co0?l0oooooooooooo0?l02oooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oo
oooo0?l000Kooooo00?o0?l0ooooooooool00_ooool2o`3o00Gooooo1?l0o`02ooooo`?o0?l01_oo
ool2o`3o00Kooooo00?o0?l0ooooooooool01_ooool01?l0o`3o0000ooooool0o`07ooooo`?o0000
2?ooool00ol0003oooooooooo`05ooooo`05o`3o0?ooooooooooooooool000002Oooool00ol0003o
ooooooooo`02ooooo`007oooool01?l0o`3oooooooooool0o`0;ooooo`03o`3o0?oooooooooo00Go
oooo0_l0o`07ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool00oooool01?l0o`3o
ooooooooool00006ooooo`03o`3o0?oooooooooo00Cooooo0_l0o`05ooooo`03o`000?l0o`3ooooo
00Oooooo0_l000000ol0o`3oooooooooo`05ooooo`?o00002Oooool00ol0003oooooooooo`05oooo
o`04o`3o0?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool001oooooo00Co0?l0oooo
oooooooo0?l02oooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooo0?l000Oooooo00?o0?l0
ooooooooool00ol00005ooooo`03o`3o0?oooooooooo00?o00001Oooool00ol0o`3oooooo`000003
ooooo`;o0?l01Oooool00ol0003o0?l0ooooo`07ooooo`;o000000?oooooo`3o0?ooool01_ooool0
0ol0003oooooo`3o0008ooooo`03o`000?oooooooooo00Gooooo00Co0?l0oooooooooooo00002Ooo
ool00ol0003oooooooooo`02ooooo`000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool01Ol0o`3oooooo`3o0?oooooo000000Wooooo00?o
0000o`3o0?ooool01Oooool00ol0o`3oooooo`000002o`0000Cooooo00Co0?l0oooooooooooooooo
0ol00004ooooo`03o`3o0?oooooooooo00Co000000?o0?l0ooooooooool00oooool00ol0o`3o0000
o`000003ooooo`;o0?l01?ooool2o`0000Sooooo00Co0?l0o`000?oooooo0?l01oooool00ol0003o
ooooo`3o0008ooooo`03o`000?oooooooooo00Gooooo00Co0?l0oooooooooooo00002Oooool00ol0
003oooooooooo`02ooooo`003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o
oooo00Ko0?l0oooooooooooo0?l0ooooool00008ooooo`;o000000?o0?l0ooooooooool01?ooool2
o`3o00?o00001?ooool01?l0o`3oooooooooooooool2o`0000Cooooo00?o0?l0ooooooooool02?l0
o`04ooooo`03o`3o0?l0003o000000;ooooo0_l0o`04ooooo`03o`000?l0o`3ooooo00Sooooo00?o
0?l0ooooool0o`002Oooool00ol0o`3oooooooooo`0>ooooo`03o`3o0?oooooooooo00oooooo000>
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01_l0o`3oooooooooool0
o`3oooooo`0000Sooooo0ol00006ooooo`;o0?l00_l00004ooooo`03o`3o0?oooooooooo00;ooooo
00?o0000o`3o0?ooool00_ooool01?l0o`3oooooooooooooool2o`3o0003o`000?oooooooooo00;o
oooo0_l0o`03ooooo`03o`3o0?l0003ooooo00?ooooo0_l0o`04ooooo`03o`3o0?oooooooooo00Oo
oooo00?o0?l0ooooool0o`002Oooool00ol0o`3oooooooooo`0>ooooo`03o`3o0?oooooooooo00oo
oooo000>ooooo`03o`000?oooooooooo00?ooooo0ol000000ooooooo0000ooooo`04ooooo`04o`3o
0?ooooooooooo`3o00;o00002Oooool7o`000004ooooool0o`3o0?l0o`0000Gooooo00Oo0?l0oooo
ooooooooooooo`3o0?oooooo0?l000?ooooo00Co0?l0oooooooooooo0?l00_ooool00ol0003ooooo
ooooo`03ooooo`;o0?l00_ooool00ol0o`3oooooooooo`03ooooo`;o0?l01?ooool00ol0o`3ooooo
ooooo`02ooooo`Go000000?o0?l0ooooool0o`002Oooool00ol0o`3oooooooooo`0;ooooo`?o0000
00?o0?l0ooooooooool03oooool000kooooo00?o0000ooooooooool01?ooool01?l0003oooooo`00
0?l00005ooooo`04o`3o0?ooooooooooo`3o00;o00002Oooool01?l0003oooooooooool00002oooo
o`04o`000?oooooo0?l0o`3o00Kooooo00Co0?l0oooooooooooooooo0_l0o`03ooooo`03o`3o0?oo
oooooooo00;o0?l00_ooool3o`3o00Cooooo0_l0o`02ooooo`03o`3o0?oooooooooo00;ooooo00?o
0?l0ooooool0o`001?ooool00ol0o`3oooooooooo`02ooooo`07o`000?ooooooooooo`000?l0o`3o
ooooo`3o0009ooooo`03o`3o0?oooooooooo00cooooo00?o0000ooooool0o`003?ooool00ol0003o
ooooooooo`02ooooo`003?ooool5o`000003ooooool0003o000000Go00001Oooool01Ol0o`3ooooo
ooooool0o`3o000000Kooooo1?l000001Ol0o`3ooooooooooooooooo000000?ooooo0_l0o`06oooo
o`04o`3o0?ooooooooooooooo`;o0?l00_ooool00ol0o`3oooooooooo`02o`3o00;ooooo0_l0o`00
1?oooooo0?l0o`3o0?l0o`02ooooo`;o0?l00_ooool00ol0o`3oooooooooo`03ooooo`;o0?l01?oo
ool00ol0o`3oooooooooo`03ooooo`06o`000?ooooooooooo`3o0?oooooo0?l02Oooool00ol0o`3o
ooooooooo`09ooooo`Go000000Co0?l0oooooooooooo00002Oooool00ol0003oooooooooo`02oooo
o`003?ooool3o`0000?ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`05o`3o0?oooooo
ooooo`3o0?l000002_ooool00ol0o`3oooooooooo`02ooooo`05o`000?oooooo0?l0ooooool0o`00
1_ooool01Ol0o`3ooooooooooooooooo0?l000?ooooo00Co0?l0ooooool0o`3o0?l00_ooool00ol0
o`3oooooo`3o0002o`3o0003ooooool0o`3o0?l000;ooooo0_l0o`02ooooo`03o`3o0?oooooooooo
00;ooooo0_l0o`04ooooo`03o`3o0?oooooooooo00Cooooo00Go0000ooooool0o`3oooooo`3o0009
ooooo`03o`3o0?oooooooooo00Wooooo00Ko0000oooooooooooo0000ooooool0o`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool000?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`05o`000?oooooo0000ooooool000001_ooool01?l0o`3ooooo
ooooool0o`0;ooooo`03o`3o0?oooooo000000?ooooo00Co0000o`3o0?oooooo0?l01Oooool01?l0
o`3oooooooooooooool2o`3o00?ooooo00Oo0?l0ooooool0o`3o0?l0ooooool0o`3ooooo00Go0?l0
00Coooooo`3o0?oooooooooo0_l0o`02ooooo`03o`3o0?oooooooooo00;ooooo0_l0o`04ooooo`05
o`3o0?ooooooooooooooool000000oooool01?l0003o0?l0ooooool0o`09ooooo`03o`3o0?oooooo
oooo00Kooooo00[o0000ooooooooooooooooo`000?oooooo0000ooooool0o`3ooooo0_l00009oooo
o`03o`000?oooooooooo00;ooooo0003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool2o`0000Sooooo00Co0?l0oooooooooooo0?l02oooool00ol0o`3oooooo`000003oooo
o`04o`000?l0o`3oooooo`3o00Gooooo00Co0?l0oooooooooooooooo0_l0o`03ooooo`06o`3o0?oo
oooo0?l0ooooool0o`3ooooo0_l0o`000ol0003oooooooooo`02o`3o0005ooooool0o`3ooooooooo
ool0o`000_ooool00ol0o`3oooooooooo`02ooooo`;o0?l01?ooool2o`3o00;ooooo00Ko0000oooo
ooooooooooooo`000?ooool2o`3o00Oooooo00?o0000ooooool0o`002?ooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`3o0?ooool00_l00009ooooo`03o`000?oooooooooo00;ooooo000E
ooooo`03o`000?oooooooooo00Kooooo00Co0?l0oooooooooooo0?l02oooool00ol0o`3ooooooooo
o`03o`000004ooooool0o`3oooooo`3o00Gooooo00Co0?l0oooooooooooooooo0_l0o`02ooooo`05
o`3o0?ooooooooooo`3o0?ooool02Ol0o`001?oooooo0?l0ooooooooool2o`3o0003ooooool0o`3o
oooo00?ooooo0_l0o`05ooooo`04o`3o0?ooooooooooooooo`?o000000Coooooo`000?l0o`3o0?l0
1oooool01?l0003oooooooooool0o`06ooooo`?o00001?ooool00ol0003oooooo`3o0002ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool001kooooo00Co0?l0oooooooooooo
0?l02oooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooo0?l000Gooooo00Co0?l0oooooooo
oooooooo0_l0o`02ooooo`05o`3o0?oooooo0?l0o`3o0?ooool03?l0o`001Ooooooo0?l0o`3o0?oo
oooo0?l000Cooooo0_l0o`05ooooo`03o`3o0?oooooooooo00Gooooo00Co0000o`3o0?oooooo0?l0
1_ooool2o`000003ooooool0o`3ooooo00Gooooo0ol00006ooooo`04o`3o0?ooooooooooo`0000Wo
oooo00?o0000ooooooooool00_ooool001kooooo00Co0?l0oooooooooooo0?l02oooool00ol0o`3o
ooooooooo`04ooooo`;o0?l01_ooool01?l0o`3oooooooooooooool2o`3o00;ooooo00?o0?l0oooo
ool0o`002_l0o`001Ooooooo0?l0ooooool0o`3ooooo00;o0?l00_ooool01?l0o`3ooooooooooooo
ool2o`3o00;ooooo00Co0000oooooooooooo0?l01_ooool3o`000003ooooool0o`3ooooo00Gooooo
0_l000000ooooooo0?l0ooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0?l0oooooooooooo
00002Oooool00ol0003oooooooooo`02ooooo`007_ooool00ol0o`3oooooo`3o000<ooooo`03o`3o
0?oooooooooo00Cooooo0_l0o`06ooooo`04o`3o0?ooooooooooooooo`;o0?l00_l000000ol0o`3o
ooooo`3o000<o`3o0003ooooool0o`3ooooo00;o0?l000?o0000ooooool0o`000oooool2o`3o00;o
oooo00Co0000oooooooooooo0?l01_ooool3o`000003ooooool0o`3ooooo00Gooooo00Co0000oooo
oooooooo0?l01oooool00ol0003oooooooooo`05ooooo`04o`3o0?ooooooooooo`0000Wooooo00?o
0000ooooooooool00_ooool000?ooooo6ol000000ol0o`3o0000o`3o000Co`0000;o0?l01_l00000
1Ol0o`3o0000o`000?l0003o0?l000?o000000Co0?l0o`000?l0o`3o00001Ol0o`000ol0003o0?l0
o`3o0003o`3o0003o`000?l0o`3o000000;o0?l00_l000001?l0o`3o0000o`000?l00002o`3o00Go
000000?o0?l0o`000?l000001_l000000ol0o`3o0000o`3o0009o`000003o`3o0?l0003o000000go
000000?o0?l0o`000?l000002ol00004ooooo`000oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`;o00001?ooool01_l0o`3o
ooooo`3o0?l0003oooooo`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0o`00
1?oooooo0000o`000?l00002ooooo`05o`3o0?oooooo0000ooooool0o`000_ooool01Ol0003o0?l0
ooooool0o`3ooooo00Go0?l000?o0000o`3o0?l0o`000ol0o`001?oooooo0?l0o`000?l0o`02o`00
0005ooooool0o`3oooooo`000?ooool00_l0o`02ooooo`;o000000?oooooo`3o0?ooool01?ooool0
2?l0003oooooooooool0o`3oooooo`3o0?oooooo00001oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooool0o`001Oooool00ol0003oooooooooo`09ooooo`00
0oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0o`3oooooo`3o0002ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o0?l0
0_ooool01Ol0003ooooooooooooooooo0?l000?ooooo0_l0o`001?oooooo0000o`3o0?ooool=o`3o
0004ooooool0o`3oooooo`3o00;o000000?oooooo`3o0?ooool00_ooool2o`3o00Gooooo00?o0?l0
ooooooooool01_ooool00ol0o`3oooooo`3o000Iooooo`03o`3o0?oooooooooo00oooooo0003oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03oooo
o`04o`3o0?oooooo0?l0ooooo`;o00002Oooool00ol0003oooooooooo`04ooooo`;o0?l00_ooool0
1Ol0003ooooooooooooooooo0?l000?ooooo0_l0o`02ooooo`05o`3o0?oooooo0?l0o`3o0?ooool0
2?l0o`001Ooooooo0?l0ooooool0o`3ooooo00;o0?l00_ooool01?l0o`3oooooooooooooool2o`3o
00Gooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooo`3o000Iooooo`03o`3o0?oooooooooo
00oooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool3o`0000Co
oooo00Co0?l0oooooooooooo0?l00_l00009ooooo`03o`000?oooooooooo00Cooooo0_l0o`06oooo
o`04o`3o0?ooooooooooooooo`;o0?l00_ooool01Ol0o`3oooooo`3o0?l0o`3ooooo00So0?l000?o
ooooo`3o0?l0o`000_ooool2o`3o00;ooooo00Co0?l0oooooooooooooooo0_l0o`05ooooo`03o`3o
0?oooooooooo00Kooooo00?o0?l0ooooool0o`006Oooool00ol0o`3oooooooooo`0?ooooo`000ooo
ool00ol0003oooooooooo`07ooooo`;o00002?ooool3o`0000Cooooo00Ko0?l0oooooooooooo0?l0
ooooool00009ooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooool0o`001Oooool01?l0o`3o
ooooooooooooool2o`3o00?ooooo00Ko0?l0ooooool0o`3oooooo`3o0?ooool5o`3o0004ooooool0
o`3o0?l0o`3o00;ooooo00Co0?l0oooooooooooo0?l01?ooool2o`3o00Gooooo00?o0?l0oooooooo
ool01_ooool00ol0o`3oooooo`3o000Iooooo`04o`3o0?ooooooooooo`0000kooooo0003ooooo`03
o`000?oooooooooo00Oooooo0_l00009ooooo`03o`000?oooooooooo00?ooooo00Ko0?l0oooooooo
oooo0?l0ooooool00009ooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooool0o`001Oooool0
1?l0o`3oooooooooooooool2o`3o00?ooooo00?o0?l0ooooool0o`000_ooool2o`3o0008ooooool0
003o0?l0o`3o0?oooooo0?l0ooooool0o`02ooooo`04o`3o0?ooooooooooo`3o00Cooooo0_l0o`04
ooooo`03o`3o0?oooooooooo00Kooooo00Co0?l0oooooooooooo0?l06Oooool01?l0o`3ooooooooo
ool00009ooooo`03o`000?oooooooooo00;ooooo0003ooooo`;o00002Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00Co0?l0oooooooooooo0?l02oooool00ol0o`3ooooo
ooooo`04ooooo`03o`3o0?oooooo0?l000Kooooo00?o0?l0ooooooooool00_l0o`03ooooo`04o`3o
0?oooooo0?l0o`3o00;ooooo1?l0o`001?oooooo0?l0o`3o0?l0o`02ooooo`;o0?l00_ooool00ol0
o`3oooooooooo`02ooooo`;o0?l01?ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooo0?l0
01?ooooo00?o0000ooooooooool01?ooool00ol0o`3oooooo`000002o`0000Sooooo00?o0000oooo
ooooool00_ooool000?ooooo0_l00009ooooo`03o`000?oooooooooo00gooooo00Co0?l0oooooooo
oooo0?l02oooool00ol0o`3oooooooooo`05ooooo`;o0?l01_ooool01?l0o`3oooooooooooooool2
o`3o00?ooooo00Co0?l0ooooool0o`3o0?l00oooool01_l0003oooooo`3o0?l0o`3oooooo`3o00;o
oooo0_l0o`02ooooo`03o`3o0?oooooooooo00;ooooo0_l0o`04ooooo`03o`3o0?oooooooooo00Ko
oooo00?o0?l0ooooool0o`002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Co
oooo00?o0?l0ooooool000000_l0000=ooooo`000oooool00ol0003oooooooooo`0Hooooo`04o`3o
0?ooooooooooo`3o00_ooooo00?o0?l0ooooooooool01Oooool2o`3o00Kooooo00Co0?l0oooooooo
oooooooo0_l0o`03ooooo`03o`3o0?oooooooooo00Oo0?l000?oooooo`3o0?ooool00_ooool01Ol0
o`3ooooooooooooooooo0?l000Cooooo0_l0o`04ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0
o`000?l0o`002?ooool00ol0003oooooooooo`07ooooo`;o00001_ooool01?l0o`3oooooooooool0
000>ooooo`000oooool00ol0003oooooooooo`0Hooooo`04o`3o0?ooooooooooo`3o00_ooooo00?o
0?l0ooooooooool01Oooool2o`3o00Kooooo00Co0?l0oooooooooooooooo0_l0o`04ooooo`03o`3o
0?oooooooooo00Co0?l000?o0000ooooool0o`000oooool2o`3o00?ooooo00Oo0?l0oooooooooooo
ooooo`3o0?oooooo0?l000Cooooo00?o0?l0ooooooooool01_ooool00ol0o`3o0000o`3o0007oooo
o`?o00002?ooool2o`0000Kooooo00Co0?l0oooooooooooo00003_ooool001kooooo00Co0?l0oooo
oooooooo0?l02oooool00ol0o`3oooooooooo`05ooooo`;o0?l01_ooool01ol0o`3ooooooooooooo
oooo0?l0ooooool0o`000oooool2o`3o00Cooooo00Co0000oooooooooooo0?l00oooool01Ol0o`3o
oooooooooooooooo0?l000Cooooo0_l0o`04ooooo`03o`000?l0o`3ooooo00Oooooo0_l000000ol0
o`3oooooooooo`05ooooo`?o00002?ooool00ol0003oooooooooo`05ooooo`04o`3o0?oooooooooo
o`0000kooooo000Nooooo`04o`3o0?ooooooooooo`3o00cooooo00?o0?l0ooooooooool01?ooool0
0ol0o`3oooooo`3o0006ooooo`06o`3o0?ooooooooooooooool0003o0?l01Oooool2o`3o00;ooooo
0ol0o`03ooooo`;o0?l00oooool00ol0003oooooooooo`02ooooo`;o0?l01?ooool00ol0003o0?l0
ooooo`06ooooo`?o000000?o0?l0ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Gooooo00Co0?l0oooooooooooo00003_ooool001kooooo00Co0?l0oooooooooooo
0?l03?ooool00ol0o`3oooooooooo`05ooooo`04o`3o0?l0003o0000o`0000Cooooo00?o0?l0oooo
ooooool00_l00002o`3o00Gooooo0ol0o`02o`0000?ooooo00?o0?l0ooooool0o`000_ooool00ol0
o`3o0000ooooo`02ooooo`03o`3o0?oooooo0?l000?ooooo0_l00009ooooo`03o`000?oooooo0?l0
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`04o`3o0?oooooooooo
o`0000kooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`06o`3o0?ooooooooooo`3o0?oooooo00002Oooool2o`0000Oooooo00Co
0?l0o`000?l0003o00001Oooool00ol0o`3oooooooooo`02o`000003o`3o0?oooooooooo00Cooooo
1?l00002ooooo`03o`3o0?oooooo0?l000;ooooo00?o0?l0o`000?l000000oooool00ol0o`3ooooo
o`3o0003ooooo`;o00002?ooool01?l0o`3o0000ooooool0o`07ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01Oooool01?l0o`3oooooooooool00009ooooo`03o`000?oooooooooo
00;ooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`06o`3o0?ooooooooooo`3o0?oooooo00002Oooool2o`0000Oooooo00Co0?l0
ooooool0003o00001Oooool01Ol0o`3ooooooooooooooooo000000;o0?l01Oooool00ol0003ooooo
o`000002ooooo`03o`3o0?oooooo0?l000?ooooo00?o0?l0ooooool000000oooool2o`3o00Gooooo
00?o0?l0ooooooooool01_ooool01?l0o`3oooooooooool0o`0Jooooo`03o`3o0?oooooooooo00oo
oooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`04ooooo`03o`3o0?oooooo0?l000?o00002?ooool2o`000003o`3o0?oooooooooo00Cooooo
00Co0?l0ooooool0o`3o00001_ooool00ol0o`3oooooooooo`02ooooo`?o0?l01Oooool01Ol0003o
ooooo`3o0?oooooo0?l000?ooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooo`3o0005oooo
o`03o`3o0?oooooooooo00Kooooo00Co0?l0oooooooooooo0?l06_ooool00ol0o`3oooooooooo`0?
ooooo`000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l00005oooo
o`03o`3o0?oooooooooo00?o00002Oooool00ol0003o0?l0ooooo`05ooooo`03o`3o0?oooooo0?l0
00Oooooo00?o0?l0ooooooooool00oooool;o`3o00Cooooo00?o0?l0ooooooooool00oooool00ol0
o`3oooooo`3o0005ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooool0o`006oooool00ol0
o`3oooooooooo`0?ooooo`000oooool00ol0003oooooooooo`08ooooo`;o00002?ooool2o`0000Go
oooo00Go0?l0oooooooooooo0?l0o`00000;ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0oooo
ool0o`001oooool00ol0o`3oooooooooo`04ooooo`Ko0?l01_ooool00ol0o`3oooooooooo`04oooo
o`;o0?l01_ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooo0?l001[ooooo00?o0?l0oooo
ooooool00_ooool00ol0003oooooooooo`0;ooooo`001?ooool00ol0003oooooooooo`06ooooo`?o
00002Oooool00ol0003oooooooooo`04ooooo`04o`3o0?oooooo0?l0o`0000_ooooo00?o0?l0oooo
ooooool01Oooool00ol0o`3oooooo`3o0007ooooo`03o`3o0?oooooooooo00Wooooo0_l00004oooo
o`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooool0o`001Oooool00ol0o`3oooooooooo`07oooo
o`03o`3o0?oooooo0?l001[ooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`000oooool2o`0000Sooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo00?o0?l0ooooool0
o`003Oooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooo0?l000Sooooo00?o0?l0oooooooo
ool02?ooool00ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooool0
o`001_ooool00ol0o`3oooooooooo`06ooooo`04o`3o0?ooooooooooo`3o01Cooooo00?o0000oooo
ooooool00oooool01?l0o`3oooooooooooooool2o`0000Sooooo00?o0000ooooooooool00_ooool0
00?ooooo0_l00009ooooo`03o`000?oooooooooo00oooooo00?o0?l0ooooool0o`003Oooool00ol0
o`3oooooooooo`05ooooo`03o`3o0?oooooo0?l000Sooooo0_l0o`001?oooooo0000o`000?l00004
ooooo`05o`000?ooooooooooooooool0o`001oooool2o`3o00Kooooo00?o0?l0ooooooooool01ooo
ool00ol0o`3oooooo`3o000;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool01?l0o`3oooooooooooooool2o`0000gooooo0004ooooo`03o`000?oooooooooo01Wooooo00Co
0?l0oooooooooooo0?l03?ooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooo0?l000[ooooo
0_l0o`000ol0003oooooooooo`03ooooo`04o`000?oooooo0?l0o`3o00Oooooo00?o0?l0ooooool0
o`001_ooool00ol0o`3oooooooooo`07ooooo`04o`3o0?oooooo0?l0o`0000[ooooo00?o0000oooo
ooooool01_ooool3o`0000Cooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`001?ooool00ol0003oooooooooo`0Iooooo`04o`3o0?ooooooooooo`3o00cooooo00?o0?l0oooo
ooooool01_ooool00ol0o`3oooooo`3o000:ooooo`Co0?l00_ooool3o`3o00Wooooo0_l0o`07oooo
o`03o`3o0?oooooooooo00Kooooo00Go0?l0oooooooooooo0?l0o`000009ooooo`;o00002Oooool2
o`0000?ooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`008?ooool01?l0
o`3oooooooooool0o`0=ooooo`03o`3o0?oooooooooo00Kooooo0_l0o`0;ooooo`03o`000?oooooo
0?l000;o0?l000?oooooo`000?l000002?ooool00ol0o`3oooooo`3o0006ooooo`05o`3o0?oooooo
ooooooooool000001Oooool00ol0o`3oooooo`3o0002o`0000Sooooo0ol00008ooooo`03o`000?oo
oooooooo00?ooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`008?ooool0
1Ol0o`3ooooooooooooooooo0?l000cooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooo`3o
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01?l0o`3ooooooooo
ool00006ooooo`03o`3o0?oooooooooo00;o00001Oooool00ol0o`3oooooo`3o0002o`0000Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool0023ooooo00Go0?l0ooooooooooooooooo`3o000<ooooo`03o`3o
0?oooooooooo00Cooooo00Ko0000oooooooooooo0?l0ooooool0o`04ooooo`04o`000?oooooooooo
ooooo`;o00001Oooool3o`0000Gooooo00?o0?l0ooooooooool00_l00006ooooo`04o`3o0?oooooo
0000o`0000Gooooo00Go0?l0oooooooooooo0?l0o`000009ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo00cooooo
0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`04o`3o0?oooooo0000o`3o00Sooooo0_l00002ooooo`03o`3o0?oooooooooo00?ooooo
0_l00002ooooo`04o`3o0?ooooooooooo`3o00;ooooo0ol00003ooooo`04o`000?oooooooooooooo
o`?o00001_ooool00ol0o`3oooooo`3o0002o`0000Kooooo00?o0?l0ooooooooool00_l00005oooo
o`05o`3o0?oooooo0?l0ooooool000002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`04o`3o0?oooooo0000o`3o00Sooooo0_l00003ooooo`03o`3o0?oooooo
oooo00?ooooo0_l00002ooooo`03o`3o0?oooooooooo00;o0?l00oooool00ol0003oooooooooo`05
ooooo`?o00001?ooool00ol0o`3oooooo`3o0002ooooo`03o`000?oooooooooo00?ooooo00?o0?l0
ooooooooool02?ooool00ol0o`3oooooo`3o000Looooo`03o`3o0?oooooooooo017ooooo0003oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05oooo
o`05o`3o0?oooooo0000o`000?l0o`002?ooool2o`0000?ooooo00?o0?l0ooooooooool00oooool0
1?l0003oooooooooooooool2o`3o00;ooooo00?o0?l0ooooooooool02Oooool01?l0003ooooooooo
ooooool2o`3o0003ooooool0o`3ooooo00Sooooo00?o0?l0ooooooooool01oooool01?l0o`3ooooo
ooooool0o`0Looooo`03o`3o0?oooooooooo017ooooo0003ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool3o`0000Oooooo00Co0?l0o`000?l0003o0?l02Oooool00ol0003o
ooooooooo`02ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooool0o`002oooool01Ol0003o
ooooo`3o0?l0o`3ooooo00;o0?l02Oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooo0?l0
01gooooo00?o0?l0ooooooooool04Oooool000?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`06ooooo`?o00001oooool01?l0o`3oooooo`000?l0o`0>ooooo`03o`3o0?oooooooooo
00Wooooo1Ol0o`08ooooo`05o`000?l0o`3oooooooooool0o`002_ooool00ol0o`3oooooooooo`08
ooooo`04o`3o0?ooooooooooo`3o01gooooo00?o0?l0ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`001?ooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0000Oooooo00Co0?l0
ooooool0003o0?l03oooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo00Wo0?l00ooo
ool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooool0o`007Ooo
ool00ol0o`3oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo0003ooooo`?o00002?ooool2
o`0000[ooooo00?o0000ooooooooool01_ooool01?l0o`3oooooooooool0o`0?ooooo`03o`3o0?oo
oooooooo00[ooooo0_l0o`08ooooo`;o00000_l0o`0:ooooo`03o`3o0?oooooooooo00Wooooo00?o
0?l0ooooool0o`006_ooool01?l0003oooooooooool0o`06ooooo`;o00003?ooool000?ooooo0ol0
0009ooooo`03o`000?oooooooooo017ooooo00Co0?l0oooooooooooo0?l03oooool00ol0o`3ooooo
ooooo`0<ooooo`[o0?l02oooool00ol0o`3oooooooooo`09ooooo`04o`3o0?ooooooooooo`3o013o
oooo00?o0000ooooooooool01oooool01?l0003oooooooooool0o`05ooooo`?o00003?ooool000Co
oooo00?o0000ooooooooool07Oooool01?l0o`3oooooooooool0o`0?ooooo`03o`3o0?oooooooooo
01?ooooo00?o0000ooooooooool02Oooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooo0?l0
00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`3o
0?ooool01_ooool00ol0003oooooooooo`0;ooooo`001?ooool00ol0003oooooooooo`0Mooooo`04
o`3o0?ooooooooooo`3o00oooooo00?o0?l0ooooooooool04oooool00ol0003oooooooooo`08oooo
o`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooool0o`001_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo0_l000000ooooooo0?l0ooooo`06ooooo`03o`000?oooooooooo
00_ooooo000Tooooo`05o`3o0?ooooooooooooooool0o`003oooool2o`3o01?ooooo0_l00008oooo
o`03o`3o0?oooooooooo00[ooooo00Go0000o`3o0?ooooooooooo`3o0005ooooo`03o`000?oooooo
oooo00Oooooo0_l00009ooooo`04o`000?ooooooooooo`3o00Oooooo00?o0000ooooooooool02ooo
ool002Gooooo00Co0?l0oooooooooooo0?l04Oooool00ol0o`3oooooooooo`0@ooooo`03o`000?oo
oooooooo00Kooooo00?o0?l0ooooooooool00_l00008ooooo`;o00000_ooool00ol0o`3ooooooooo
o`03ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`3o00Oooooo
00?o0000ooooooooool02oooool002Gooooo00Go0?l0ooooooooooooooooo`3o000Aooooo`03o`3o
0?oooooooooo00Cooooo0_l00009ooooo`?o00001?ooool2o`3o00;ooooo0ol00007ooooo`;o0000
00Co0?l0oooooooooooo0?l01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo0?l01oooool00ol0003oooooooooo`0<ooooo`000oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool01?l0003o
ooooooooool0o`02ooooo`05o`3o0?ooooooooooooooool000002_ooool01Ol0003ooooooooooooo
oooo0?l000Gooooo0ol00007ooooo`?o00001?ooool01?l0o`3oooooooooooooool3o`0000Sooooo
0_l00002ooooo`03o`3o0?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`04o`000?ooooooooooo`3o00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0?l000;ooooo00?o0?l0oooooooo
ool00_l00008ooooo`?o00000oooool00ol0o`3oooooooooo`02ooooo`Co00001oooool01?l0003o
ooooooooooooool2o`3o00Gooooo00?o0000ooooooooool02?ooool00ol0o`3oooooo`3o000Ooooo
o`03o`3o0?oooooooooo01Cooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`;o00000_ooool01Ol0o`3ooooooooooooooooo0?l0
00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool3o`3o00cooooo0_l00002
o`3o017ooooo00Co0?l0oooooooooooo0?l07oooool00ol0o`3oooooooooo`0Dooooo`001?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o00000oooool0
1?l0o`3oooooooooool0o`03ooooo`03o`000?oooooooooo00oooooo0ol0o`08ooooo`?o0?l04_oo
ool01?l0o`3oooooooooool0o`0Pooooo`03o`3o0?oooooooooo01Cooooo0004ooooo`03o`000?oo
oooooooo00Sooooo0_l00008ooooo`;o00002Oooool2o`0000;ooooo00Go0?l0oooooooooooooooo
o`3o000Gooooo`So0?l000?oooooo`000?ooool04_ooool01?l0o`3oooooooooool0o`0Oooooo`03
o`3o0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool000Cooooo00?o0000ooooooooool0
1oooool3o`0000Sooooo0_l0000:ooooo`05o`000?ooooooooooooooool0o`000_ooool00ol0o`3o
ooooooooo`0Gooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04?ooool01?l0
o`3oooooooooool0o`0Pooooo`03o`3o0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
00Cooooo0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`0<ooooo`05o`3o0?oooooooooo
ooooool0o`006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00Go0?l0
ooooooooooooooooo`3o000Pooooo`03o`3o0?l0003ooooo00Oooooo0_l0000<ooooo`001?ooool2
o`0000[ooooo00?o0000ooooooooool05oooool01?l0o`3oooooooooool0o`0Jooooo`03o`000?oo
oooooooo00;ooooo0_l0000@ooooo`04o`3o0?ooooooooooo`3o01Oooooo00?o0000ooooooooool0
1_ooool00ol0o`3o0000o`000008ooooo`;o00003?ooool000Gooooo00?o0000ooooooooool08ooo
ool01?l0o`3oooooooooool0o`0Fooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`0=ooooo`;o0?l00_ooool00ol0o`3oooooooooo`0<ooooo`03o`000?oooooooooo00Ko
oooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`001Oooool00ol0003ooooo
ooooo`0Sooooo`05o`3o0?ooooooooooooooool0o`005Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool03?ooool01Ol0o`3ooooooooooooooooo0?l000oooooo00?o0000
ooooooooool01Oooool3o`0000Sooooo00?o0?l0o`000?ooool02?ooool00ol0003oooooooooo`0;
ooooo`00;?ooool01Ol0o`3ooooooooooooooooo0?l001Gooooo0ol00004ooooo`03o`000?oooooo
oooo00_ooooo00Go0?l0ooooooooooooooooo`3o0005ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool2o`0000Oooooo00?o0?l0o`000?ooool02Oooool00ol0003ooooooooo
o`0;ooooo`00;?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo01Wooooo0_l0000:
ooooo`;o00000oooool00ol0o`3oooooooooo`03ooooo`;o00002?ooool2o`0000Sooooo00?o0000
ooooooooool01oooool00ol0o`3o0000ooooo`09ooooo`03o`000?oooooooooo00_ooooo000]oooo
o`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool06?ooool01?l0003oooooo`000?l00007
ooooo`?o00000_ooool00ol0o`3oooooooooo`03ooooo`;o00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0?l0o`000?ooool02?ooool00ol0003oooooooooo`0<
ooooo`000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?l0o`3ooooo00?ooooo00?o0?l0oooo
ooooool00_ooool2o`0000Sooooo0ol00008ooooo`;o00002Oooool2o`0000;ooooo00?o0?l0oooo
ooooool00oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0o`3o0000ooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000Cooooo0_l0o`02ooooo`?o
00001oooool4o`0000Oooooo00?o0000ooooooooool01_ooool2o`3o0004ooooool0003oooooo`3o
02Gooooo00?o0?l0ooooooooool06?ooool000Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o000000?o0?l0oooooooo
ool00oooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo02?ooooo00?o0?l0oooooooo
ool06Oooool000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`;o0000
2?ooool3o`0000[ooooo00?o0000o`3o0?l0o`001?ooool00ol0o`3oooooooooo`0Cooooo`;o0000
1?ooool2o`3o00Cooooo00?o0?l0ooooooooool09?ooool00ol0o`3oooooooooo`0Iooooo`001?oo
ool00ol0003oooooooooo`08ooooo`;o00002?ooool2o`0000[ooooo0_l0000<ooooo`03o`3o0?oo
oooooooo00;ooooo0_l0o`0Cooooo`04o`000?ooooooooooooooo`;o0?l01Oooool00ol0o`3ooooo
ooooo`0Uooooo`03o`3o0?oooooooooo00gooooo00?o0000ooooooooool02Oooool000Gooooo00?o
0000ooooooooool01oooool2o`0000Wooooo0_l0000:ooooo`03o`000?oooooooooo00_ooooo00?o
0?l0ooooooooool00oooool2o`3o017ooooo00Co0000ooooool0o`3o0?l01Oooool2o`3o02Oooooo
00?o0?l0ooooooooool03_ooool00ol0003oooooooooo`09ooooo`001?ooool3o`0000Sooooo0_l0
000:ooooo`03o`000?oooooooooo01Oooooo0_l0o`05ooooo`Co0?l03Oooool2o`3o00Gooooo0_l0
o`0Yooooo`03o`3o0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool2o`0000_ooooo0004
ooooo`?o00002Oooool00ol0003oooooooooo`0Tooooo`;o0?l01oooool4o`3o00?ooooo1_l0o`00
0ol0003oooooooooo`02ooooo`;o0?l09oooool01Ol0003ooooooooooooooooo0?l000Gooooo0_l0
0007ooooo`?o00002oooool000Gooooo0_l0000booooo`;o0?l02Oooool3o`3o00Kooooo0_l00003
o`3o01kooooo00?o0000ooooooooool01oooool2o`0000;ooooo00?o0?l0ooooooooool00oooool2
o`0000Wooooo00?o0000ooooooooool02_ooool000Kooooo00?o0000ooooooooool0<_ooool2o`3o
013ooooo0_l0o`0Pooooo`;o00002?ooool2o`0000?ooooo00?o0?l0ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo000mooooo`?o0?l03?ooool00ol0o`3o
0000ooooo`0Fooooo`;o00001oooool2o`0000[ooooo00Go0000ooooooooooooooooo`3o0005oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool0043ooooo3?l0o`000ooooooo
0000ooooo`0;ooooo`;o00001oooool3o`0000Wooooo00?o0000ooooooooool01oooool01Ol0003o
oooooooooooooooo0?l000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;oooo
o`00COooool5o`0000Kooooo0ol00009ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0;ooooo`00>Oooool00ol0003oooooooooo`07ooooo`?o0000
1oooool3o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00Go0000ooooooooooooooooo`3o0006ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03?ooool000?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool3o`0000Sooooo
0ol00008ooooo`Ko00001?ooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0o`3ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooo`000008ooooo`?o00001oooool4o`0000Wooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02_ooooo00?o0?l0ooooooooool0
7_ooool000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`?o00002?oo
ool2o`0000_ooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000002gooooo
00?o0?l0ooooooooool07_ooool000Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`?o00002Oooool2o`00023ooooo0_l00004ooooo`;o0000:oooool00ol0o`3ooooooooo
o`0Dooooo`03o`000?oooooooooo00Sooooo0004ooooo`03o`000?oooooooooo00Sooooo0_l0000:
ooooo`;o00002Oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool00000@ooo
ool00ol0003oooooooooo`08ooooo`001Oooool2o`0000Sooooo0_l0000;ooooo`03o`000?oooooo
oooo02Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`001Oooool2o`0000Wooooo0_l0000d
ooooo`?o00001?ooool00ol0003oooooooooo`0[ooooo`;o00002?ooool2o`0000Sooooo0_l0000;
ooooo`001Oooool2o`0000[ooooo00?o0000ooooooooool0>Oooool2o`0002;ooooo00?o0000oooo
ooooool01_ooool3o`0000Oooooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool08?ooool2o`0000Oooooo0ol00009ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool004gooooo00?o0000ooooooooool0
5Oooool2o`0000Sooooo0_l00009ooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo001=ooooo`03o`000?oooooooooo00_ooooo0_l00007ooooo`?o00002?oo
ool2o`0000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00_ooooo001=ooooo`03o`000?oooooooooo00;o00001oooool3o`0000Sooooo0_l00009
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00_ooooo0014ooooo`?o00001_ooool4o`0000Sooooo0_l00008oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool3o`0000Sooooo1?l00007ooooo`Go00001Oooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;ooooo0003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`09ooooo`;o00002Oooool2o`0000Sooooo1?l00007ooooo`;o0000
1oooool00ol0003oooooooooo`1<ooooo`001?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooool000002?ooool2o`0000Wooooo0ol0000Kooooo`03o`000?oo
oooooooo04cooooo0004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2
o`0000[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00Sooooo0005ooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`;o00002_ooool00ol0
003oooooooooo`0Sooooo`;o0000@_ooool00ol0003oooooooooo`08ooooo`001Oooool2o`0000Wo
oooo0_l0000:ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`06ooooo`;o00002_ooool000Gooooo0_l0000:ooooo`;o0000>_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`?o00002_ooool000Kooooo0_l0
000:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool08Oooool2o`0000Sooooo0_l0
0008ooooo`;o00002Oooool00ol0003oooooooooo`09ooooo`001oooool00ol0003oooooooooo`13
ooooo`;o00008Oooool3o`0000Oooooo0_l00009ooooo`;o00002?ooool00ol0003oooooooooo`0:
ooooo`00COooool00ol0003oooooooooo`0Fooooo`;o00001oooool3o`0000Sooooo0_l00009oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool004Oooooo0ol00003ooooo`03
o`000?oooooooooo00cooooo0_l00006ooooo`?o00002Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`00
B?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00001oooool2o`0000So
oooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00_ooooo0014ooooo`Ko00000oooool4o`0000Sooooo
0_l00008ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000;o00001_oo
ool6o`0000Cooooo0ol00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0016ooooo`03o`000?oooooo
000005?ooooo0017ooooo`;o0000Doooool004Sooooo00?o0000ooooooooool0DOooool009cooooo
0000\
\>"],
  ImageRangeCache->{{{78.625, 233.875}, {354.688, 160.375}} -> {-10.5397, \
2.7292, 0.0674543, 0.0431708}}]
}, Open  ]],

Cell["\<\
The following plot shows the state space trajectories for the same \
solutions.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot3D[ 
      Evaluate[Table[{y[t],y'[t],t,RGBColor[0,1,0]}/.nsolns[[k,1]],{k,3}]], 
      {t,0,40} , PlotPoints->200, AspectRatio->5/3 ]\
\>", "Input",
  CellLabel->"In[37]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.6355 6.27588 -0.118383 1.78505 [
[.36878 1.6872 -6.02391 0 ]
[.36878 1.6872 5.97609 9 ]
[.51729 1.67627 -5.99734 0 ]
[.51729 1.67627 6.00266 9 ]
[.66666 1.66528 -2.98528 0 ]
[.66666 1.66528 3.01472 9 ]
[.81692 1.65422 -2.97178 0 ]
[.81692 1.65422 3.02822 9 ]
[.96806 1.6431 -2.95817 0 ]
[.96806 1.6431 3.04183 9 ]
[.72179 -0.00443 0 -6.17559 ]
[.72179 -0.00443 12 2.82441 ]
[.79036 .02066 0 -6.16558 ]
[.79036 .02066 12 2.83442 ]
[.85829 .04552 0 -6.1557 ]
[.85829 .04552 6 2.8443 ]
[.9256 .07015 0 -6.14593 ]
[.9256 .07015 6 2.85407 ]
[.99229 .09455 0 -6.13628 ]
[.99229 .09455 6 2.86372 ]
[.00586 .09741 -6 -2.83258 ]
[.00586 .09741 0 6.16742 ]
[-0.01162 .41556 -12 -2.93195 ]
[-0.01162 .41556 0 6.06805 ]
[-0.03054 .76027 -12 -3.03969 ]
[-0.03054 .76027 0 5.96031 ]
[-0.05108 1.13503 -12 -3.15692 ]
[-0.05108 1.13503 0 5.84308 ]
[-0.07345 1.54395 -12 -3.28495 ]
[-0.07345 1.54395 0 5.71505 ]
[ 0 0 0 0 ]
[ 1 1.66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.34492 1.66667 m
1 1.61836 L
s
.36909 1.66488 m
.36925 1.65373 L
s
[(-2)] .36878 1.6872 .00398 -1 Mshowa
.51725 1.65396 m
.51723 1.6428 L
s
[(-1)] .51729 1.67627 -0.00044 -1 Mshowa
.66628 1.64297 m
.66608 1.63181 L
s
[(0)] .66666 1.66528 -0.00491 -1 Mshowa
.81618 1.63191 m
.81581 1.62076 L
s
[(1)] .81692 1.65422 -0.00941 -1 Mshowa
.96696 1.62079 m
.96642 1.60964 L
s
[(2)] .96806 1.6431 -0.01394 -1 Mshowa
.125 Mabswid
.39865 1.6627 m
.39873 1.65601 L
s
.42825 1.66052 m
.4283 1.65383 L
s
.45788 1.65834 m
.45792 1.65164 L
s
.48755 1.65615 m
.48756 1.64945 L
s
.54699 1.65176 m
.54696 1.64507 L
s
.57676 1.64957 m
.5767 1.64288 L
s
.60656 1.64737 m
.60649 1.64068 L
s
.6364 1.64517 m
.63631 1.63848 L
s
.69619 1.64076 m
.69605 1.63407 L
s
.72613 1.63855 m
.72597 1.63186 L
s
.75611 1.63634 m
.75593 1.62965 L
s
.78613 1.63413 m
.78593 1.62744 L
s
.84627 1.62969 m
.84602 1.623 L
s
.87639 1.62747 m
.87612 1.62078 L
s
.90654 1.62525 m
.90626 1.61856 L
s
.93674 1.62302 m
.93643 1.61633 L
s
.99723 1.61856 m
.99688 1.61187 L
s
.25 Mabswid
.63908 0 m
.9204 .10284 L
s
.64827 .00336 m
.61151 .00725 L
s
[(-2)] .72179 -0.00443 -1 .37235 Mshowa
.71678 .02841 m
.68 .03228 L
s
[(-1)] .79036 .02066 -1 .37013 Mshowa
.78467 .05322 m
.74785 .05708 L
s
[(0)] .85829 .04552 -1 .36793 Mshowa
.85192 .07781 m
.81509 .08164 L
s
[(1)] .9256 .07015 -1 .36576 Mshowa
.91857 .10217 m
.8817 .10599 L
s
[(2)] .99229 .09455 -1 .36362 Mshowa
.125 Mabswid
.66202 .00839 m
.63997 .01072 L
s
.67575 .01341 m
.65369 .01574 L
s
.68946 .01842 m
.66739 .02075 L
s
.70313 .02342 m
.68106 .02574 L
s
.73041 .03339 m
.70834 .03571 L
s
.74401 .03836 m
.72193 .04068 L
s
.75759 .04332 m
.73551 .04564 L
s
.77114 .04828 m
.74906 .05059 L
s
.79817 .05816 m
.77608 .06047 L
s
.81164 .06309 m
.78955 .06539 L
s
.82509 .068 m
.803 .07031 L
s
.83852 .07291 m
.81642 .07521 L
s
.8653 .0827 m
.84319 .085 L
s
.87865 .08758 m
.85654 .08988 L
s
.89198 .09245 m
.86987 .09475 L
s
.90529 .09732 m
.88317 .09961 L
s
.25 Mabswid
.08105 .05915 m
0 1.58114 L
s
.07942 .08966 m
.1162 .08578 L
s
[(0)] .00586 .09741 1 -0.37054 Mshowa
.06246 .40821 m
.0995 .40454 L
s
[(10)] -0.01162 .41556 1 -0.34846 Mshowa
.04408 .75339 m
.08139 .74994 L
s
[(20)] -0.03054 .76027 1 -0.32451 Mshowa
.0241 1.12865 m
.06168 1.12546 L
s
[(30)] -0.05108 1.13503 1 -0.29846 Mshowa
.00229 1.53813 m
.04016 1.53522 L
s
[(40)] -0.07345 1.54395 1 -0.27001 Mshowa
.125 Mabswid
.07613 .15139 m
.09823 .14909 L
s
.0728 .21409 m
.09493 .21181 L
s
.0694 .27777 m
.09157 .27552 L
s
.06596 .34247 m
.08815 .34025 L
s
.0589 .47502 m
.08116 .47284 L
s
.05529 .54291 m
.07757 .54076 L
s
.05161 .61191 m
.07393 .60979 L
s
.04788 .68206 m
.07023 .67997 L
s
.04022 .82591 m
.06263 .82387 L
s
.03629 .89967 m
.05874 .89766 L
s
.03229 .97469 m
.05478 .97271 L
s
.02823 1.051 m
.05075 1.04906 L
s
.01989 1.20767 m
.04247 1.20579 L
s
.01561 1.28808 m
.03822 1.28624 L
s
.01125 1.36994 m
.0339 1.36813 L
s
.00681 1.45328 m
.0295 1.4515 L
s
.25 Mabswid
.08105 .05915 m
0 1.58114 L
s
0 1.58114 m
.34492 1.66667 L
s
.34492 1.66667 m
.36985 .15977 L
s
.36985 .15977 m
.08105 .05915 L
s
.63908 0 m
.9204 .10284 L
s
.9204 .10284 m
1 1.61836 L
s
1 1.61836 m
.6657 1.53058 L
s
.6657 1.53058 m
.63908 0 L
s
.08105 .05915 m
0 1.58114 L
s
0 1.58114 m
.6657 1.53058 L
s
.6657 1.53058 m
.63908 0 L
s
.63908 0 m
.08105 .05915 L
s
.36985 .15977 m
.9204 .10284 L
s
.9204 .10284 m
1 1.61836 L
s
1 1.61836 m
.34492 1.66667 L
s
.34492 1.66667 m
.36985 .15977 L
s
0 0 m
1 0 L
1 1.66667 L
0 1.66667 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.37647 .33539 m
.36264 .33373 L
s
.36701 .28453 m
.42129 .29357 L
s
.31602 .27323 m
.36701 .28453 L
s
.27048 .25977 m
.31602 .27323 L
s
.42129 .29357 m
.47666 .30034 L
s
.24375 .24892 m
.27048 .25977 L
s
.47666 .30034 m
.53095 .30491 L
s
.53095 .30491 m
.58214 .30746 L
s
.20357 .22692 m
.1862 .20872 L
s
.58214 .30746 m
.62836 .30819 L
s
.18076 .18933 m
.1862 .20872 L
s
.62836 .30819 m
.66802 .30739 L
s
.18832 .16951 m
.18076 .18933 L
s
.816 .28618 m
.82672 .2837 L
s
.66802 .30739 m
.6998 .30541 L
s
.82672 .2837 m
.84408 .27593 L
s
.2092 .14981 m
.18832 .16951 L
s
.2303 .138 m
.2092 .14981 L
s
.6998 .30541 m
.72273 .30259 L
s
.84408 .27593 m
.8474 .26817 L
s
.79074 .33687 m
.8138 .3315 L
s
.72273 .30259 m
.7362 .29935 L
s
.65631 .05977 m
.63792 .06009 L
s
.60256 .06221 m
.63792 .06009 L
s
.8138 .3315 m
.82832 .32461 L
s
.83928 .26258 m
.8474 .26817 L
s
.7362 .29935 m
.74 .29606 L
s
.74 .29606 m
.73427 .29313 L
s
.82832 .32461 m
.82949 .31782 L
s
.73427 .29313 m
.71957 .29089 L
s
.82949 .31782 m
.81769 .31165 L
s
.71957 .29089 m
.69678 .28969 L
s
.38489 .44614 m
.42755 .45525 L
s
.3453 .43531 m
.38489 .44614 L
s
.31047 .42285 m
.3453 .43531 L
s
.42755 .45525 m
.47149 .46261 L
s
.28203 .40893 m
.31047 .42285 L
s
.47149 .46261 m
.515 .46827 L
s
.2614 .39376 m
.28203 .40893 L
s
.81769 .31165 m
.79377 .30658 L
s
.69678 .28969 m
.66708 .28979 L
s
.515 .46827 m
.5564 .47233 L
s
.24976 .37765 m
.2614 .39376 L
s
.74624 .24853 m
.73391 .24782 L
s
.24801 .36093 m
.24976 .37765 L
s
.5564 .47233 m
.59418 .47496 L
s
.73391 .24782 m
.6815 .24751 L
s
.66708 .28979 m
.63191 .2914 L
s
.25665 .344 m
.24801 .36093 L
s
.79377 .30658 m
.75909 .30305 L
s
.59418 .47496 m
.627 .47637 L
s
.63191 .2914 m
.59287 .29465 L
s
.38968 .44997 m
.41644 .45972 L
s
.36644 .43912 m
.38968 .44997 L
s
.27582 .32728 m
.25665 .344 L
s
.3478 .42729 m
.36644 .43912 L
s
.41644 .45972 m
.44555 .46831 L
s
.6815 .24751 m
.62383 .24964 L
s
.33474 .41466 m
.3478 .42729 L
s
.44555 .46831 m
.47577 .47569 L
s
.328 .40142 m
.33474 .41466 L
s
.35835 .487 m
.3965 .49742 L
s
.3245 .47502 m
.35835 .487 L
s
.627 .47637 m
.65377 .4768 L
s
.3965 .49742 m
.43733 .50623 L
s
.47577 .47569 m
.50591 .48191 L
s
.30519 .3112 m
.27582 .32728 L
s
.32816 .38783 m
.328 .40142 L
s
.29651 .46163 m
.3245 .47502 L
s
.59287 .29465 m
.55168 .29962 L
s
.43733 .50623 m
.47914 .51339 L
s
.75909 .30305 m
.71538 .3014 L
s
.33549 .37416 m
.32816 .38783 L
s
.62383 .24964 m
.56343 .25429 L
s
.27577 .44705 m
.29651 .46163 L
s
.50591 .48191 m
.53478 .48701 L
s
.47914 .51339 m
.52029 .51897 L
s
.34399 .29619 m
.30519 .3112 L
s
.35002 .36069 m
.33549 .37416 L
s
.55168 .29962 m
.51009 .3063 L
s
.26343 .43153 m
.27577 .44705 L
s
.37145 .34773 m
.35002 .36069 L
s
.56343 .25429 m
.50287 .26145 L
s
.65377 .4768 m
.67365 .47655 L
s
.39102 .28266 m
.34399 .29619 L
s
.52029 .51897 m
.55922 .52306 L
s
.53478 .48701 m
.56133 .49111 L
s
.51009 .3063 m
.46979 .31462 L
s
.3992 .33555 m
.37145 .34773 L
s
.26038 .4154 m
.26343 .43153 L
s
.46979 .31462 m
.43236 .32444 L
s
.50287 .26145 m
.44464 .27098 L
s
.44464 .27098 m
.39102 .28266 L
s
.43236 .32444 m
.3992 .33555 L
s
.71538 .3014 m
.66473 .3019 L
s
.55922 .52306 m
.59451 .52583 L
s
.56133 .49111 m
.58459 .49434 L
s
.26716 .39902 m
.26038 .4154 L
s
.67365 .47655 m
.6861 .47589 L
s
.28394 .38277 m
.26716 .39902 L
s
.58459 .49434 m
.60378 .49689 L
s
.59451 .52583 m
.62492 .52748 L
s
.66473 .3019 m
.60943 .30472 L
s
.31047 .36707 m
.28394 .38277 L
s
.6861 .47589 m
.69087 .47515 L
s
.60378 .49689 m
.6183 .49892 L
s
.60943 .30472 m
.55191 .30991 L
s
.62492 .52748 m
.64944 .52826 L
s
.34609 .35232 m
.31047 .36707 L
s
.55191 .30991 m
.4946 .31745 L
s
.3897 .33891 m
.34609 .35232 L
s
.43982 .32719 m
.3897 .33891 L
s
.4946 .31745 m
.43982 .32719 L
s
.6183 .49892 m
.62774 .50066 L
s
.69087 .47515 m
.68804 .4746 L
s
.64944 .52826 m
.66732 .52843 L
s
.62774 .50066 m
.6319 .50231 L
s
.66732 .52843 m
.67808 .52827 L
s
.68804 .4746 m
.67797 .47455 L
s
.6319 .50231 m
.63081 .50407 L
s
.67808 .52827 m
.68153 .52807 L
s
.67797 .47455 m
.66131 .47524 L
s
.63081 .50407 m
.62469 .50614 L
s
.66131 .47524 m
.63896 .47688 L
s
.68153 .52807 m
.6778 .5281 L
s
.62469 .50614 m
.61397 .5087 L
s
.63896 .47688 m
.612 .47964 L
s
.61397 .5087 m
.59922 .51188 L
s
.6778 .5281 m
.66727 .52863 L
s
.612 .47964 m
.58168 .48365 L
s
.59922 .51188 m
.58119 .51582 L
s
.66727 .52863 m
.65059 .52989 L
s
.58168 .48365 m
.54934 .48896 L
s
.58119 .51582 m
.56071 .5206 L
s
.54934 .48896 m
.51636 .49559 L
s
.56071 .5206 m
.53868 .52627 L
s
.39061 .61658 m
.40825 .62693 L
s
.37684 .60552 m
.39061 .61658 L
s
.65059 .52989 m
.62864 .53207 L
s
.36766 .59388 m
.37684 .60552 L
s
.40825 .62693 m
.4289 .63646 L
s
.36363 .58183 m
.36766 .59388 L
s
.4289 .63646 m
.45165 .64511 L
s
.51636 .49559 m
.48409 .50348 L
s
.36514 .56956 m
.36363 .58183 L
s
.53868 .52627 m
.51606 .53284 L
s
.37237 .55729 m
.36514 .56956 L
s
.45165 .64511 m
.47554 .65284 L
s
.48409 .50348 m
.45379 .51255 L
s
.38526 .54523 m
.37237 .55729 L
s
.40352 .53361 m
.38526 .54523 L
s
.45379 .51255 m
.42662 .52265 L
s
.42662 .52265 m
.40352 .53361 L
s
.47554 .65284 m
.49958 .65967 L
s
.51606 .53284 m
.49376 .54029 L
s
.62864 .53207 m
.60248 .53533 L
s
.49376 .54029 m
.47266 .54855 L
s
.49958 .65967 m
.52283 .66564 L
s
.47266 .54855 m
.45357 .55753 L
s
.45357 .55753 m
.43715 .56713 L
s
.60248 .53533 m
.57332 .53977 L
s
.52283 .66564 m
.54443 .67083 L
s
.43715 .56713 m
.42397 .57721 L
s
.42397 .57721 m
.41441 .58763 L
s
.41441 .58763 m
.40872 .59822 L
s
.40872 .59822 m
.40695 .60884 L
s
.40695 .60884 m
.40903 .61935 L
s
.40903 .61935 m
.41471 .6296 L
s
.41471 .6296 m
.42364 .63948 L
s
.42364 .63948 m
.43533 .64889 L
s
.54443 .67083 m
.56358 .67533 L
s
.43533 .64889 m
.44922 .65775 L
s
.57332 .53977 m
.54243 .54545 L
s
.44922 .65775 m
.46467 .66602 L
s
.46467 .66602 m
.48103 .67367 L
s
.54243 .54545 m
.51113 .55235 L
s
.56358 .67533 m
.57963 .67927 L
s
.48103 .67367 m
.49761 .68071 L
s
.51113 .55235 m
.48068 .56043 L
s
.38475 .66121 m
.39841 .67202 L
s
.37535 .64983 m
.38475 .66121 L
s
.39841 .67202 m
.41564 .68214 L
s
.37079 .63805 m
.37535 .64983 L
s
.41564 .68214 m
.43561 .69149 L
s
.37145 .62604 m
.37079 .63805 L
s
.49761 .68071 m
.51377 .68715 L
s
.43561 .69149 m
.45745 .7 L
s
.37753 .61399 m
.37145 .62604 L
s
.48068 .56043 m
.45227 .5696 L
s
.38901 .60211 m
.37753 .61399 L
s
.57963 .67927 m
.59207 .6828 L
s
.45227 .5696 m
.42696 .57972 L
s
.40565 .59062 m
.38901 .60211 L
s
.45745 .7 m
.48023 .70765 L
s
.42696 .57972 m
.40565 .59062 L
s
.51377 .68715 m
.52888 .69304 L
s
.48023 .70765 m
.50302 .71446 L
s
.59207 .6828 m
.60053 .68607 L
s
.52888 .69304 m
.5424 .69846 L
s
.50302 .71446 m
.52494 .72047 L
s
.52494 .72047 m
.54517 .72576 L
s
.5424 .69846 m
.55385 .70348 L
s
.60053 .68607 m
.60482 .68923 L
s
.54517 .72576 m
.56298 .73042 L
s
.55385 .70348 m
.56286 .70821 L
s
.60482 .68923 m
.60492 .69245 L
s
.56298 .73042 m
.57776 .73457 L
s
.56286 .70821 m
.56916 .71274 L
s
.60492 .69245 m
.60097 .69588 L
s
.56916 .71274 m
.57261 .71718 L
s
.57776 .73457 m
.58904 .73836 L
s
.60097 .69588 m
.59328 .69965 L
s
.57261 .71718 m
.57317 .72166 L
s
.58904 .73836 m
.59651 .74192 L
s
.59328 .69965 m
.58229 .70388 L
s
.57317 .72166 m
.57092 .72626 L
s
.59651 .74192 m
.6 .74541 L
s
.57092 .72626 m
.56606 .73108 L
s
.58229 .70388 m
.56854 .70867 L
s
.6 .74541 m
.59952 .74898 L
s
.56606 .73108 m
.55886 .73621 L
s
.56854 .70867 m
.5527 .71409 L
s
.59952 .74898 m
.59522 .75276 L
s
.55886 .73621 m
.54972 .74172 L
s
.5527 .71409 m
.53546 .72019 L
s
.53546 .72019 m
.51757 .72697 L
s
.54972 .74172 m
.53905 .74766 L
s
.59522 .75276 m
.58743 .75689 L
s
.51757 .72697 m
.49976 .73444 L
s
.53905 .74766 m
.52734 .75405 L
s
.58743 .75689 m
.57656 .76146 L
s
.49976 .73444 m
.48275 .74254 L
s
.52734 .75405 m
.51509 .76092 L
s
.48275 .74254 m
.46717 .75121 L
s
.46717 .75121 m
.45359 .76038 L
s
.57656 .76146 m
.56317 .76657 L
s
.51509 .76092 m
.50281 .76826 L
s
.45359 .76038 m
.44249 .76994 L
s
.44249 .76994 m
.43418 .77978 L
s
.43418 .77978 m
.42891 .7898 L
s
.50281 .76826 m
.49099 .77604 L
s
.42891 .7898 m
.42675 .79986 L
s
.56317 .76657 m
.54788 .77229 L
s
.42675 .79986 m
.42767 .80987 L
s
.42767 .80987 m
.43151 .81971 L
s
.49099 .77604 m
.48008 .78422 L
s
.43151 .81971 m
.43801 .82929 L
s
.43801 .82929 m
.4468 .83854 L
s
.48008 .78422 m
.47048 .79276 L
s
.54788 .77229 m
.53137 .77863 L
s
.4468 .83854 m
.45745 .84738 L
s
.47048 .79276 m
.46252 .80158 L
s
.45745 .84738 m
.46947 .85578 L
s
.46252 .80158 m
.45645 .81061 L
s
.53137 .77863 m
.51434 .78563 L
s
.46947 .85578 m
.48233 .86372 L
s
.45645 .81061 m
.45244 .81978 L
s
.45244 .81978 m
.45056 .82901 L
s
.48233 .86372 m
.49551 .87118 L
s
.51434 .78563 m
.49749 .79326 L
s
.45056 .82901 m
.45081 .8382 L
s
.45081 .8382 m
.4531 .84731 L
s
.49749 .79326 m
.48148 .80148 L
s
.49551 .87118 m
.50847 .8782 L
s
.4531 .84731 m
.45725 .85625 L
s
.48148 .80148 m
.46692 .81023 L
s
.45725 .85625 m
.46304 .86497 L
s
.50847 .8782 m
.52072 .88479 L
s
.46692 .81023 m
.45434 .81944 L
s
.46304 .86497 m
.47016 .87343 L
s
.45434 .81944 m
.44416 .82899 L
s
.44416 .82899 m
.43668 .8388 L
s
.52072 .88479 m
.5318 .891 L
s
.47016 .87343 m
.47829 .8816 L
s
.43668 .8388 m
.43209 .84876 L
s
.43209 .84876 m
.43047 .85874 L
s
.47829 .8816 m
.48706 .88945 L
s
.43047 .85874 m
.43176 .86866 L
s
.43176 .86866 m
.43579 .87841 L
s
.5318 .891 m
.54131 .89691 L
s
.43579 .87841 m
.4423 .88791 L
s
.48706 .88945 m
.49612 .89699 L
s
.4423 .88791 m
.45094 .89708 L
s
.45094 .89708 m
.46128 .90586 L
s
.49612 .89699 m
.5051 .90422 L
s
.54131 .89691 m
.54895 .90257 L
s
.46128 .90586 m
.47286 .91423 L
s
.5051 .90422 m
.51364 .91115 L
s
.47286 .91423 m
.48516 .92217 L
s
.54895 .90257 m
.55448 .90807 L
s
.51364 .91115 m
.52142 .91783 L
s
.48516 .92217 m
.49769 .92966 L
s
.55448 .90807 m
.55775 .91349 L
s
.49769 .92966 m
.50994 .93673 L
s
.52142 .91783 m
.52818 .9243 L
s
.50994 .93673 m
.52144 .94341 L
s
.55775 .91349 m
.55874 .91892 L
s
.52818 .9243 m
.53367 .93059 L
s
.52144 .94341 m
.53177 .94975 L
s
.53367 .93059 m
.53774 .93676 L
s
.55874 .91892 m
.55747 .92443 L
s
.53177 .94975 m
.54057 .95581 L
s
.53774 .93676 m
.54027 .94288 L
s
.55747 .92443 m
.55408 .9301 L
s
.54057 .95581 m
.54755 .96166 L
s
.54027 .94288 m
.54122 .949 L
s
.55408 .9301 m
.54879 .93599 L
s
.54755 .96166 m
.5525 .96736 L
s
.54122 .949 m
.54061 .95516 L
s
.54879 .93599 m
.54187 .94216 L
s
.5525 .96736 m
.5553 .973 L
s
.54061 .95516 m
.53853 .96143 L
s
.54187 .94216 m
.53365 .94865 L
s
.5553 .973 m
.55591 .97866 L
s
.53853 .96143 m
.5351 .96785 L
s
.53365 .94865 m
.52452 .95549 L
s
.5351 .96785 m
.53052 .97446 L
s
.55591 .97866 m
.5544 .98441 L
s
.52452 .95549 m
.51486 .96269 L
s
.53052 .97446 m
.52501 .98129 L
s
.51486 .96269 m
.50508 .97025 L
s
.5544 .98441 m
.55091 .99032 L
s
.50508 .97025 m
.49558 .97816 L
s
.52501 .98129 m
.51883 .98835 L
s
.55091 .99032 m
.54563 .99644 L
s
.49558 .97816 m
.48672 .98639 L
s
.51883 .98835 m
.51223 .99567 L
s
.48672 .98639 m
.47882 .9949 L
s
.54563 .99644 m
.53885 1.00284 L
s
.51223 .99567 m
.50551 1.00324 L
s
.47882 .9949 m
.47217 1.00364 L
s
.47217 1.00364 m
.46697 1.01256 L
s
.50551 1.00324 m
.49892 1.01105 L
s
.53885 1.00284 m
.53089 1.00954 L
s
.46697 1.01256 m
.46339 1.0216 L
s
.49892 1.01105 m
.49273 1.01909 L
s
.46339 1.0216 m
.46149 1.0307 L
s
.53089 1.00954 m
.52211 1.01658 L
s
.46149 1.0307 m
.46128 1.0398 L
s
.49273 1.01909 m
.48717 1.02733 L
s
.46128 1.0398 m
.46272 1.04884 L
s
.52211 1.01658 m
.5129 1.02395 L
s
.48717 1.02733 m
.48243 1.03573 L
s
.46272 1.04884 m
.46568 1.05777 L
s
.48243 1.03573 m
.47867 1.04428 L
s
.5129 1.02395 m
.50362 1.03167 L
s
.46568 1.05777 m
.46998 1.06656 L
s
.47867 1.04428 m
.476 1.05291 L
s
.46998 1.06656 m
.4754 1.07515 L
s
.50362 1.03167 m
.49466 1.0397 L
s
.476 1.05291 m
.47448 1.06159 L
s
.4754 1.07515 m
.48169 1.08353 L
s
.49466 1.0397 m
.48635 1.04803 L
s
.47448 1.06159 m
.47414 1.07029 L
s
.48169 1.08353 m
.48857 1.09168 L
s
.48635 1.04803 m
.479 1.05662 L
s
.47414 1.07029 m
.47493 1.07896 L
s
.48857 1.09168 m
.49574 1.09959 L
s
.479 1.05662 m
.47287 1.06542 L
s
.47493 1.07896 m
.47678 1.08757 L
s
.47287 1.06542 m
.46815 1.07439 L
s
.49574 1.09959 m
.50292 1.10727 L
s
.47678 1.08757 m
.47958 1.09608 L
s
.46815 1.07439 m
.46497 1.08345 L
s
.47958 1.09608 m
.48319 1.10447 L
s
.50292 1.10727 m
.50981 1.11473 L
s
.46497 1.08345 m
.4634 1.09257 L
s
.48319 1.10447 m
.48742 1.11273 L
s
.4634 1.09257 m
.46344 1.10168 L
s
.50981 1.11473 m
.51616 1.12199 L
s
.46344 1.10168 m
.46502 1.11073 L
s
.48742 1.11273 m
.4921 1.12083 L
s
.46502 1.11073 m
.46803 1.11967 L
s
.51616 1.12199 m
.52174 1.12908 L
s
.4921 1.12083 m
.49701 1.12877 L
s
.46803 1.11967 m
.47228 1.12846 L
s
.52174 1.12908 m
.52636 1.13603 L
s
.49701 1.12877 m
.50196 1.13656 L
s
.47228 1.12846 m
.47758 1.13708 L
s
.47758 1.13708 m
.48365 1.14549 L
s
.50196 1.13656 m
.50675 1.1442 L
s
.52636 1.13603 m
.52987 1.1429 L
s
.48365 1.14549 m
.49025 1.15369 L
s
.50675 1.1442 m
.5112 1.1517 L
s
.52987 1.1429 m
.53217 1.14971 L
s
.49025 1.15369 m
.49709 1.16167 L
s
.5112 1.1517 m
.51515 1.15909 L
s
.49709 1.16167 m
.50388 1.16942 L
s
.53217 1.14971 m
.53323 1.15652 L
s
.51515 1.15909 m
.51845 1.16639 L
s
.50388 1.16942 m
.51037 1.17698 L
s
.53323 1.15652 m
.53303 1.16336 L
s
.51845 1.16639 m
.521 1.17363 L
s
.51037 1.17698 m
.51632 1.18436 L
s
.53303 1.16336 m
.53165 1.17027 L
s
.521 1.17363 m
.52274 1.18083 L
s
.51632 1.18436 m
.5215 1.19158 L
s
.53165 1.17027 m
.52917 1.1773 L
s
.52274 1.18083 m
.52362 1.18802 L
s
.5215 1.19158 m
.52574 1.19868 L
s
.52917 1.1773 m
.52574 1.18446 L
s
.52362 1.18802 m
.52363 1.19524 L
s
.52574 1.19868 m
.52892 1.20571 L
s
.52574 1.18446 m
.52152 1.19179 L
s
.52363 1.19524 m
.52282 1.20251 L
s
.52892 1.20571 m
.53094 1.21269 L
s
.52152 1.19179 m
.51671 1.1993 L
s
.52282 1.20251 m
.52124 1.20985 L
s
.53094 1.21269 m
.53176 1.21967 L
s
.51671 1.1993 m
.51153 1.20701 L
s
.52124 1.20985 m
.51899 1.21729 L
s
.53176 1.21967 m
.53141 1.2267 L
s
.51153 1.20701 m
.5062 1.21491 L
s
.51899 1.21729 m
.51617 1.22485 L
s
.53141 1.2267 m
.52994 1.23379 L
s
.5062 1.21491 m
.50092 1.223 L
s
.51617 1.22485 m
.51293 1.23253 L
s
.50092 1.223 m
.49591 1.23126 L
s
.52994 1.23379 m
.52744 1.241 L
s
.51293 1.23253 m
.5094 1.24035 L
s
.49591 1.23126 m
.49136 1.23969 L
s
.52744 1.241 m
.52405 1.24834 L
s
.5094 1.24035 m
.50574 1.2483 L
s
.49136 1.23969 m
.48742 1.24826 L
s
.52405 1.24834 m
.51995 1.25585 L
s
.50574 1.2483 m
.50209 1.25639 L
s
.48742 1.24826 m
.48424 1.25694 L
s
.48424 1.25694 m
.4819 1.2657 L
s
.50209 1.25639 m
.49861 1.26461 L
s
.51995 1.25585 m
.51532 1.26352 L
s
.4819 1.2657 m
.48048 1.27451 L
s
.49861 1.26461 m
.49541 1.27294 L
s
.51532 1.26352 m
.51036 1.27138 L
s
.48048 1.27451 m
.47998 1.28334 L
s
.49541 1.27294 m
.49262 1.28138 L
s
.47998 1.28334 m
.48039 1.29216 L
s
.51036 1.27138 m
.50528 1.27942 L
s
.49262 1.28138 m
.49034 1.2899 L
s
.48039 1.29216 m
.48167 1.30094 L
s
.50528 1.27942 m
.50029 1.28764 L
s
.49034 1.2899 m
.48862 1.29848 L
s
.48167 1.30094 m
.48372 1.30966 L
s
.50029 1.28764 m
.49558 1.29603 L
s
.48862 1.29848 m
.48752 1.30711 L
s
.48372 1.30966 m
.48645 1.3183 L
s
.49558 1.29603 m
.49133 1.30456 L
s
.48752 1.30711 m
.48707 1.31576 L
s
.48645 1.3183 m
.48971 1.32684 L
s
.49133 1.30456 m
.48769 1.31322 L
s
.48707 1.31576 m
.48724 1.32441 L
s
.48971 1.32684 m
.49335 1.33527 L
s
.48769 1.31322 m
.48477 1.32198 L
s
.48724 1.32441 m
.48802 1.33305 L
s
.49335 1.33527 m
.49723 1.34359 L
s
.48477 1.32198 m
.48268 1.33082 L
s
.48802 1.33305 m
.48934 1.34165 L
s
.49723 1.34359 m
.50117 1.35179 L
s
.48268 1.33082 m
.48145 1.3397 L
s
.48934 1.34165 m
.49114 1.3502 L
s
.50117 1.35179 m
.50503 1.35989 L
s
.48145 1.3397 m
.4811 1.3486 L
s
.49114 1.3502 m
.49332 1.35869 L
s
.4811 1.3486 m
.48162 1.35748 L
s
.50503 1.35989 m
.50864 1.36788 L
s
.49332 1.35869 m
.49579 1.36711 L
s
.48162 1.35748 m
.48294 1.36633 L
s
.50864 1.36788 m
.51188 1.37579 L
s
.49579 1.36711 m
.49844 1.37545 L
s
.48294 1.36633 m
.485 1.37511 L
s
.51188 1.37579 m
.51464 1.38363 L
s
.49844 1.37545 m
.50115 1.38373 L
s
.485 1.37511 m
.48767 1.38382 L
s
.48767 1.38382 m
.49083 1.39244 L
s
.50115 1.38373 m
.50382 1.39193 L
s
.51464 1.38363 m
.51682 1.39143 L
s
.49083 1.39244 m
.49434 1.40095 L
s
.50382 1.39193 m
.50635 1.40007 L
s
.51682 1.39143 m
.51835 1.39919 L
s
.49434 1.40095 m
.49804 1.40936 L
s
.50635 1.40007 m
.50863 1.40816 L
s
.51835 1.39919 m
.51922 1.40695 L
s
.49804 1.40936 m
.50179 1.41767 L
s
.50863 1.40816 m
.51059 1.4162 L
s
.51922 1.40695 m
.51939 1.41473 L
s
.50179 1.41767 m
.50543 1.42587 L
s
.51059 1.4162 m
.51216 1.42421 L
s
.51939 1.41473 m
.5189 1.42254 L
s
.50543 1.42587 m
.50882 1.43398 L
s
.51216 1.42421 m
.5133 1.4322 L
s
.5189 1.42254 m
.51778 1.43041 L
s
.50882 1.43398 m
.51184 1.44202 L
s
.5133 1.4322 m
.51398 1.44019 L
s
.51778 1.43041 m
.51611 1.43836 L
s
.51184 1.44202 m
.51439 1.45 L
s
.51398 1.44019 m
.51418 1.4482 L
s
.51611 1.43836 m
.51397 1.44639 L
s
.51439 1.45 m
.51637 1.45793 L
s
.51418 1.4482 m
.51392 1.45623 L
s
.51397 1.44639 m
.51147 1.45453 L
s
.51637 1.45793 m
.51774 1.46585 L
s
.51392 1.45623 m
.51323 1.46431 L
s
.51147 1.45453 m
.5087 1.46276 L
s
.51774 1.46585 m
.51847 1.47376 L
s
.51323 1.46431 m
.51214 1.47243 L
s
.5087 1.46276 m
.50581 1.47111 L
s
.51847 1.47376 m
.51854 1.48169 L
s
.51214 1.47243 m
.51072 1.48063 L
s
.50581 1.47111 m
.5029 1.47956 L
s
.51854 1.48169 m
.51798 1.48967 L
s
.51072 1.48063 m
.50903 1.48889 L
s
.5029 1.47956 m
.50008 1.48812 L
s
.51798 1.48967 m
.51684 1.4977 L
s
.50903 1.48889 m
.50716 1.49723 L
s
.50008 1.48812 m
.49748 1.49676 L
s
.51684 1.4977 m
.51518 1.5058 L
s
.50716 1.49723 m
.50518 1.50565 L
s
.49748 1.49676 m
.49518 1.5055 L
s
.51518 1.5058 m
.51309 1.51399 L
s
.50518 1.50565 m
.50317 1.51415 L
s
.49518 1.5055 m
.49326 1.5143 L
s
.49326 1.5143 m
.49178 1.52316 L
s
.50317 1.51415 m
.50122 1.52272 L
s
.51309 1.51399 m
.51066 1.52227 L
s
.49178 1.52316 m
.49079 1.53206 L
s
.50122 1.52272 m
.4994 1.53136 L
s
.51066 1.52227 m
.50801 1.53066 L
s
.49079 1.53206 m
.4903 1.54099 L
s
.4994 1.53136 m
.49777 1.54007 L
s
.50801 1.53066 m
.50525 1.53914 L
s
.4903 1.54099 m
.49032 1.54993 L
s
.49777 1.54007 m
.4964 1.54883 L
s
.50525 1.53914 m
.50249 1.54773 L
s
.49032 1.54993 m
.49083 1.55886 L
s
.4964 1.54883 m
.49533 1.55764 L
s
.50249 1.54773 m
.49984 1.55641 L
s
0 g
.25 Mabswid
.63908 0 m
.9204 .10284 L
s
.9204 .10284 m
1 1.61836 L
s
1 1.61836 m
.6657 1.53058 L
s
.6657 1.53058 m
.63908 0 L
s
.08105 .05915 m
0 1.58114 L
s
0 1.58114 m
.6657 1.53058 L
s
.6657 1.53058 m
.63908 0 L
s
.63908 0 m
.08105 .05915 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{151.375, 252.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002G0000o2000`400?l00000o`00003oUoooool0
09Oooooo002Gooooo`00Uoooool009Oooooo002Gooooo`00Uoooool009Oooooo002Gooooo`00Uooo
ool009Oooooo002Gooooo`00Uoooool009Oooooo002Gooooo`00M?ooool5o`0001kooooo001eoooo
o`04o`000?ooooooooooo`0001kooooo001^ooooo`Go00000oooool00ol0003oooooooooo`0Noooo
o`00Moooool00ol0003oooooooooo`04ooooo`?o00005_ooool007Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo01Gooooo001Oooooo`Oo00003_ooool00ol0003ooooo
ooooo`05o`0000?ooooo00?o0000ooooooooool05Oooool005Gooooo2_l00002ooooo`;o000000?o
ooooo`000?l000000ol0000<ooooo`?o00001oooool01?l0003oooooo`000?l0000Dooooo`00Booo
ool:o`0000oooooo00?o0000ooooool000001Ol0000Cooooo`;o00000_ooool00ol0003ooooooooo
o`0Aooooo`00@Oooool:o`0001Wooooo00Co0000oooooooooooooooo1ol0000?ooooo`?o00000_oo
ool00ol0003oooooooooo`0Aooooo`00>?ooool9o`0002?ooooo00?o0000ooooooooool00_ooool3
o`000003ooooool0003o000000;o00003_ooool2o`0000;ooooo00?o0000ooooooooool00oooool3
o`0000_ooooo000^ooooo`[o0000;?ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00[ooooo000Tooooo`[o0000=_ooool00ol0
003oooooooooo`09ooooo`Oo00002Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00[ooooo000Oooooo`Go0000?_ooool2o`3o0003o`000?l0o`3o0?l000_ooooo1ol00008oooo
o`;o00001oooool00ol0003oooooooooo`03ooooo`Go00000_ooool001oooooo00?o0000ooooool0
00000_l0000kooooo`?o0?l00_ooool00ol0003oooooooooo`0@ooooo`Go00003_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo000Oooooo`03o`000?oooooooooo00;o
oooo0ol0000mooooo`03o`000?oooooooooo017ooooo1ol0000:ooooo`;o00001oooool00ol0003o
ooooooooo`02ooooo`007oooool00ol0003oooooooooo`05ooooo`?o0000>_ooool00ol0003ooooo
ooooo`0Cooooo`Oo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo007ooooo
000Nooooo`Ko00001_ooool2o`0003Sooooo00?o0000ooooooooool05_ooool7o`0000cooooo00Go
0000ooooooooooooooooo`000002ooooo`004Oooool2o`0000cooooo00?o0000ooooooooool02_oo
ool3o`0003Gooooo00?o0000ooooooooool06_ooool6o`0000Wooooo00Go0000oooooooooooooooo
o`000002ooooo`004?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00gooooo
0ol0000booooo`03o`000?oooooooooo01_ooooo1_l00009ooooo`?o00000oooool0013ooooo00Co
0000oooooooooooo00002oooool00ol0003oooooooooo`0@ooooo`?o0000;oooool00ol0003ooooo
ooooo`0Aooooo`[o00001Oooool00ol0003oooooooooo`0=ooooo`004?ooool01?l0003ooooooooo
ool0000;ooooo`03o`000?oooooooooo01?ooooo0ol0000/ooooo`03o`000?oooooooooo00Sooooo
2Ol0000?ooooo`03o`000?oooooooooo00gooooo000@ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool05_ooool2o`0002[ooooo2ol0000Hooooo`03o`000?oooooooooo00gooooo
000@ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool04?ooool00ol0o`3ooooo
ooooo`06ooooo`?o00007_ooool:o`0002;ooooo00?o0000ooooooooool03Oooool0017ooooo0_l0
000;ooooo`04o`000?oooooo0000o`0000kooooo00?o0?l0ooooooooool02_ooool3o`0001;ooooo
2Ol00009ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03Oooool001kooooo0_l0
000>ooooo`;o0?l04?ooool3o`0000Gooooo2_l0000Booooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool03Oooool001kooooo00?o0000ooooooooool03?ooool00ol0o`3oooooooooo`0C
ooooo`Go00007?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00gooooo000Noooo
o`03o`000?oooooooooo00_ooooo00?o0?l0ooooooooool05?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool03Oooool001kooooo00?o0000oooooooo
ool02oooool00ol0o`3oooooooooo`0Dooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0=ooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`3o
0?oooooooooo01Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00[ooooo00?o0?l0ooooooooool05Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?oo
ool001kooooo00?o0000ooooooooool02oooool00ol0o`3oooooooooo`0Dooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0<ooooo`007_ooool3o`00
00_ooooo00?o0?l0ooooooooool05?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03?ooool00ol0o`3o
ooooooooo`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`3o0?oooooooooo01;ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo
000Nooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo000Noooo
o`03o`000?oooooooooo01;ooooo0ol0o`0=ooooo`03o`000?oooooooooo01Wooooo1Ol0o`000ol0
003o0?l0o`3o000;o`3o01Kooooo00?o0000ooooooooool03?ooool001kooooo00?o0000oooooooo
ool05Oooool3o`3o00[ooooo00?o0000ooooooooool02oooool>o`3o00Gooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0Hooooo`?o0?l0
1oooool00ol0003oooooooooo`08ooooo`?o0?l05?ooool00ol0003oooooooooo`0Eooooo`;o0?l0
2Oooool00ol0003oooooooooo`0<ooooo`007Oooool4o`0001_ooooo1?l0o`03ooooo`03o`000?oo
oooooooo00?ooooo1Ol0o`0Gooooo`03o`000?oooooooooo01Cooooo0_l0o`0:ooooo`03o`000?oo
oooooooo00cooooo000Nooooo`03o`000?oooooooooo01oooooo2Ol0o`0Looooo`03o`000?oooooo
oooo01;ooooo0_l0o`0<ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo
027ooooo0ol0o`03ooooo`Oo0?l04oooool4o`3o0003o`000?l0o`3o0?l000Wo0?l05oooool00ol0
003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`0Nooooo`?o0?l00_ooool00ol0003o
ooooooooo`08ooooo`Oo0?l00_ooool:o`3o00?ooooo00?o0?l0o`000?l0o`002ol0o`0Fooooo`03
o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo01cooooo0_l0o`05ooooo`03o`00
0?oooooooooo00cooooo4ol0o`000ol0003o0?l0o`3o0007o`3o00;ooooo2Ol0o`0>ooooo`03o`00
0?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo01[ooooo0_l0o`07ooooo`03o`000?oo
oooooooo00Oooooo2Ol0o`0?ooooo`03o`000?oooooooooo01;ooooo0ol0o`0;ooooo`03o`000?oo
oooooooo00cooooo000Mooooo`03o`000?oooooooooo01Sooooo0_l0o`09ooooo`03o`000?oooooo
oooo00?ooooo1ol0o`0Eooooo`03o`000?oooooooooo01?ooooo0_l0o`0;ooooo`03o`000?oooooo
oooo00cooooo000Mooooo`03o`000?oooooooooo01Oooooo00?o0?l0ooooooooool02?ooool00ol0
o`3o0000ooooo`02ooooo`Ko0?l06?ooool00ol0003oooooooooo`0Aooooo`;o0?l03Oooool00ol0
003oooooooooo`0<ooooo`007Oooool4o`0001Gooooo00?o0?l0ooooooooool02_ooool5o`3o01go
oooo00?o0000ooooooooool03oooool2o`3o013ooooo00?o0000ooooooooool02oooool001gooooo
00?o0000ooooooooool05Oooool00ol0o`3oooooooooo`09ooooo`Co0?l08?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00_ooooo000Mooooo`03o`000?oooooooooo01Cooooo00?o
0?l0ooooooooool02?ooool3o`3o0003o`000?oooooooooo023ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0;ooooo`007Oooool00ol0003oooooooooo`0Cooooo`03o`3o0?oooooo
oooo00Kooooo1Ol0o`000ooooooo0000ooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02oooool001gooooo00?o0000ooooooooool04oooool00ol0o`3oooooooooo`04oooo
o`;o0?l00_ooool01Ol0o`3ooooooooooooooooo000002;ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0;ooooo`007Oooool00ol0003oooooooooo`0Dooooo`04o`3o0?oooooooooo
ooooo`;o0?l01?ooool01Ol0o`3ooooooooooooooooo000002;ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0;ooooo`007Oooool00ol0003oooooooooo`0Dooooo`05o`3o0?oooooo
ooooooooool0o`001?ooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`007Oooool00ol0003oooooooooo`0E
ooooo`?o0?l01Oooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`007Oooool00ol0003oooooo`000002o`00
01Cooooo0_l0o`05ooooo`03o`3o0?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00_ooooo0008ooooo`?o00001?ooool2o`0000_o
oooo0ol0000Gooooo`03o`3o0?oooooo0?l000;o0?l00oooool01Ol0o`3ooooooooooooooooo0000
02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`002Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool05Oooool00ol0
o`3oooooooooo`03ooooo`;o0?l00_ooool01?l0o`3oooooooooool0000Rooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02oooool000Wooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000;ooooo`03o`000?oooooooooo01Gooooo00?o0?l0ooooooooool01Oooool5
o`3o0003o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;
ooooo`002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool05Oooool2o`3o00Wooooo1?l0o`0Qooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02oooool000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo01Sooooo00?o0?l0ooooooooool02?ooool00ol0003o0?l0o`3o0003
o`3o01gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`002?ooool2o`00
00Cooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Iooooo`03o`3o0?oooooo
oooo00Oooooo00?o0000ooooooooool02Ol0o`0Gooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02oooool000Wooooo00?o0000ooooooooool00oooool2o`0000_ooooo00?o0000oooo
ooooool06_ooool2o`3o00Oooooo00?o0000ooooooooool00oooool3o`3o00?ooooo1Ol0o`0Boooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool02oooool001cooooo00?o0000oooooooo
ool07?ooool2o`3o00Gooooo00?o0000ooooooooool01_ooool4o`3o00Cooooo1_l0o`0<ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool02oooool001cooooo1?l0000Mooooo`?o0?l0
0_ooool00ol0003oooooooooo`0:ooooo`Co0?l01_ooool<o`3o0003o`000?l0o`3o0?l000?o0?l0
7_ooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`0Qooooo`?o0?l04?oo
ool7o`3o0003ooooool0o`3o0?l000Ko0?l00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00_ooooo000Looooo`03o`000?oooooooooo02?ooooo00Co0000o`3o0?l0o`3o0?l04Ooo
ool9o`3o00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`007?ooool0
0ol0003oooooooooo`0Sooooo`04o`000?ooooooooooooooo`Co0?l01_ooool7o`3o00Wooooo1?l0
o`000ooooooo0000ooooo`0Sooooo`03o`000?oooooooooo00[ooooo000Looooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool01Oooool6o`3o013ooooo1?l0o`000ooooooo0000ooooo`0S
ooooo`03o`000?oooooooooo00[ooooo000Looooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01oooool2o`3o0003ooooool0o`3o0?l000So0?l00oooool4o`3o00Gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Cooooo0ol0o`0;ooooo`ko0?l000?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooooooo`?o
0?l02oooool3o`3o00Oooooo1ol0o`000ol0003o0?l0o`3o0002o`3o023ooooo00?o0000oooooooo
ool02_ooool001_ooooo1?l0000Sooooo`04o`000?ooooooooooo`3o00_ooooo0ol0o`06ooooo`Co
0?l01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Looooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooool0o`002Oooool3o`3o00Gooooo1?l0o`0;ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool02_ooool001cooooo00?o0000ooooooooool08ooo
ool00ol0003o0?l0ooooo`07ooooo`;o0?l01?ooool4o`3o00oooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0Sooooo`03o`000?l0o`3o
oooo00Kooooo00Co0?l0oooooooooooooooo0ol0o`0Cooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02_ooool001cooooo00?o0000ooooooooool08oooool00ol0o`3oooooooooo`05
ooooo`03o`3o0?oooooo0?l000;o0?l05_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00[ooooo000Looooo`03o`000?oooooooooo02?ooooo00?o0?l0ooooooooool01?ooool3o`3o
01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003o
ooooooooo`0Sooooo`03o`3o0?oooooooooo00;ooooo0_l0o`0Looooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool09?ooool01?l0o`3ooooo
ooooooooool2o`3o01gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`00
6oooool00ol0003oooooooooo`0Tooooo`06o`000?l0o`3oooooo`3o0?oooooo0?l07Oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Kooooo`Co00008oooool00ol0003o
ooooo`3o0002ooooo`03o`3o0?oooooooooo01_ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo0?l000?o0?l0
7Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oo
oooooooo02Cooooo00?o0000o`3o0?ooool00_ooool3o`3o01_ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0:ooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?l0o`3o
oooo00Cooooo1?l0o`0Hooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool0
01_ooooo00?o0000ooooooooool09?ooool00ol0003o0?l0ooooo`05ooooo`03o`3o0?oooooooooo
00?o0?l05Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo000Kooooo`03
o`000?oooooooooo02Cooooo00?o0000o`3o0?ooool01_ooool00ol0o`3oooooooooo`02ooooo`?o
0?l04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo000Kooooo`03o`00
0?oooooooooo02Cooooo00Co0000ooooool0o`3o0?l01_ooool2o`3o00Gooooo0ol0o`0?ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0
9?ooool01Ol0003ooooooooooooooooo0?l000Oooooo0_l0o`06ooooo`Go0?l02_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo000Kooooo`?o00009?ooool00ol0003ooooo
ooooo`02ooooo`03o`3o0?oooooooooo00Kooooo0_l0o`09ooooo`?o0?l01oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool00oooool3o`3o00Oooooo1?l0o`08ooooo`;o0?l01Oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool01_ooool2o`3o00Wooooo0_l0o`07ooooo`;o0?l01?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02?ooool3o`3o00Sooooo0ol0o`001?oooooo0?l0o`3o0?l0o`06ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0;ooooo`?o0?l01oooool2o`3o00Wooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`09ooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00ko
oooo1ol0o`02ooooo`03o`3o0?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`09ooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo
0_l0o`02ooooo`?o0?l000?oooooo`3o0?ooool01oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_oo
ool2o`3o00Kooooo1?l0o`07ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Ooo
ool001_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`;o0?l01oooool0
0ol0o`3oooooooooo`02ooooo`;o0?l01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Wooooo000Jooooo`03o`000?oooooooooo00?o00008Oooool00ol0003oooooooooo`0:oooo
o`;o0?l01oooool2o`3o00Kooooo00?o0?l0ooooooooool00oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Wooooo0005ooooo`Go00000oooool2o`0000_ooooo0ol0000Tooooo`03
o`000?oooooooooo00Wooooo00?o0?l0ooooooooool01?ooool3o`3o00Kooooo0_l0o`06ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool000Kooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Cooooo0ol0o`08oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool000Oooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02?ooool00ol0o`3oooooooooo`02ooooo`;o0?l01Oooool2o`3o00cooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`09ooooo`002?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Oooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`03ooooo`;o0?l03_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo0005ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool01_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Co0?l04?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo0005ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooo0?l001Cooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`001_ooool3o`0000Cooooo0_l0000;
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool01ol0o`3ooooooooooooo
oooo0?l0ooooool0o`005Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0o`3ooooooooo
o`03o`3o01Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`006_ooool3
o`0002Cooooo00?o0000ooooooooool01_ooool01?l0o`3oooooooooool0o`0Hooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`07ooooo`?o0?l06?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool3o`3o
01Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0?l0ooooooooool00_l0o`0Gooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`06ooooo`05o`3o0?ooooooooooo`3o0?ooool00_l0o`0Eooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`06ooooo`05o`3o0?ooooooooooooooool0o`000_ooool00ol0o`3o
ooooooooo`0Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`3o0?oooooooooo00;ooooo
00?o0?l0ooooooooool00_l0o`0Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`03o`3o0?oo
oooooooo00;ooooo00Go0?l0ooooooooooooooooo`3o000Aooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`08ooooo`03o`3o0?oooooooooo00;ooooo00Co0?l0oooooooooooooooo0_l0o`0?ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool02?ooool001[ooooo0ol0000Tooooo`03o`000?oo
oooooooo00Wooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`02ooooo`;o0?l03Ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo000Iooooo`;o00009_ooool0
0ol0003oooooooooo`0:ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool00oooool0
0ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool0
01Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`3o0?oooooooooo
00?ooooo00?o0?l0ooooooooool00_ooool2o`3o00_ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`08ooooo`006Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00_o
oooo0ol0o`03ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool02Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo000Iooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool03_ooool2o`3o00;ooooo00?o0?l0ooooooooool00_l0o`0;ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool02?ooool001Wooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0@ooooo`06o`3o0?ooooooooooo`3o0?oooooo0?l03?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo000Iooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool04Oooool2o`3o0003ooooool0o`3ooooo00cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`07ooooo`006Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01?ooooo0_l0o`0=ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01ooo
ool001Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`04o`3o0?oooooo
0?l0o`3o00cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`006Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00oooooo0ol0o`001?oooooo0?l0ooooool0
o`0<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool001Wooooo0ol0000U
ooooo`03o`000?oooooooooo00kooooo00?o0?l0ooooooooool00_ooool01?l0o`3oooooooooool0
o`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool001Wooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0
ooooooooool00_l0o`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool0
01Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`05o`3o0?oooooooooo
ooooool0o`000oooool00ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool01oooool001Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0<oooo
o`05o`3o0?ooooooooooooooool0o`000oooool00ol0o`3oooooooooo`0;ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool01oooool001Wooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0;ooooo`05o`3o0?ooooooooooooooool0o`000_ooool3o`3o00gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`07ooooo`006Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00_ooooo00Oo0?l0ooooooooooooooooo`3o0?oooooo0?l0013ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`006Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00[ooooo00Oo0?l0ooooooooooooooooo`3o0?oooooo0?l0017ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`006Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00[ooooo00Ko0?l0oooooooooooo0?l0ooooool0o`0Booooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool001Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0:ooooo`03o`3o0?oooooooooo00;o0?l04oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Oooooo000Hooooo`Co00009Oooool00ol0003ooooooooo
o`0:ooooo`04o`3o0?oooooo0?l0o`3o01Cooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`07ooooo`006?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo00?o
0?l0ooooool0o`005Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo000H
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02oooool2o`3o01Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00_ooooo0_l0o`0Eooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool01oooool001Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;ooooo`;o
0?l05Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo000Hooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0o`3oooooo`3o000Eooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool01oooool001Sooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0:ooooo`04o`3o0?oooooo0?l0o`3o01Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`06ooooo`006?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00[ooooo00?o0?l0ooooooooool00ol0o`0Booooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool01_ooool001Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0;
ooooo`04o`3o0?ooooooooooo`3o00;ooooo00?o0?l0ooooooooool03oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Kooooo000Hooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool03?ooool01?l0o`3oooooooooool0o`02ooooo`03o`3o0?oooooooooo00kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`000oooool3o`0000Cooooo0_l0000<
ooooo`Go00008oooool00ol0003oooooooooo`0<ooooo`04o`3o0?ooooooooooo`3o00;ooooo00?o
0?l0ooooooooool03_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo0002
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool03Oooool01?l0o`3oooooooooool0o`02ooooo`03
o`3o0?oooooooooo00gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`00
1_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0>ooooo`06o`3o0?ooooooooooo`3o0?oooooo0?l03oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo0004ooooo`;o00000oooool01?l0
003oooooooooool0000;ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03oooool0
0ol0o`3oooooo`3o0002ooooo`03o`3o0?oooooooooo00cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`06ooooo`001_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0?ooooo`06o`3o0?oooooo
ooooo`3o0?oooooo0?l03_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo
0002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool01Ol0o`3oooooo`3o0?oooooo0?l0
00kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`000oooool3o`0000Co
oooo0_l0000<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool3o`3o00oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`006?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01;ooooo0_l0o`0?ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01_ooool001Sooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Booooo`;o0?l03oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo000H
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_ooool2o`3o00oooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`06ooooo`005oooool4o`0002Gooooo00?o0000oooo
ooooool04Oooool3o`3o00oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06oooo
o`005oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00Go0?l0ooooool0
o`3oooooo`3o000>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool001Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`05o`3o0?oooooo0?l0oooo
ool0o`003_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo000Gooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool01Ol0o`3oooooo`3o0?oooooo0?l0
00oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`005oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00Go0?l0ooooool0o`3oooooo`3o000?oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool001Oooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0>ooooo`03o`3o0?oooooo0?l000;ooooo00?o0?l0oooooooo
ool03Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo000Gooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool03_ooool01Ol0o`3oooooo`3o0?oooooo0?l0013o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`005oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00gooooo00Ko0?l0oooooooooooo0?l0ooooool0o`0@oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool001Oooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0=ooooo`05o`3o0?oooooo0?l0ooooool0o`004Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo000Gooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool03Oooool01?l0o`3oooooo`3o0?l0o`0Cooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool01Oooool001Oooooo0ol0000Vooooo`03o`000?oooooooooo00go
oooo00Co0?l0ooooool0o`3o0?l04oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Gooooo000Gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool3o`3o01Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`005oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00gooooo0ol0o`0Dooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01Oooool001Oooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0>ooooo`03o`3o0?oooooooooo01?ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`05ooooo`005oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00kooooo00?o0?l0
ooooooooool04oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000Goooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03_ooool00ol0o`3oooooooooo`0Coooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool001Oooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0=ooooo`?o0?l05?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Gooooo000Gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
3Oooool3o`3o01Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`005ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00gooooo00Co0?l0ooooool0o`3o0?l0
4oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000Fooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool03Oooool01?l0o`3oooooo`3o0?l0o`0Cooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool01Oooool001Kooooo1?l0000Vooooo`03o`000?oo
oooooooo00kooooo0_l0o`000ooooooo0?l0ooooo`0Aooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool01Oooool001Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>
ooooo`04o`3o0?oooooo0?l0o`3o01;ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`05ooooo`005_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00Go0?l0
ooooool0o`3oooooo`3o000Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Ooo
ool001Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`;o0?l000?ooooo
o`3o0?ooool04?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000Foooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool01?l0o`3oooooo`3o0?l0o`0A
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool001Kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0?ooooo`04o`3o0?oooooo0?l0o`3o017ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`04ooooo`005_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo013ooooo0ol0o`0Aooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool01?ooool001Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0@ooooo`?o
0?l04Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo000Fooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool04Oooool2o`3o017ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`04ooooo`005_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo017ooooo0_l0o`0Aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?oo
ool001Gooooo1?l0000Wooooo`03o`000?oooooooooo017ooooo0_l0o`0Aooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01?ooool001Kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Aooooo`;o0?l04Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Cooooo000Fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool2o`3o017o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`005_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo013ooooo0ol0o`0Aooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool01?ooool001Kooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0@ooooo`?o0?l04Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo000F
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool3o`3o017ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`04ooooo`005_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo013ooooo00Co0?l0ooooool0o`3o0?l04Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Cooooo000Fooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool2o`3o0003ooooool0o`3ooooo013ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo013o
oooo0ol0o`0Booooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool001Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0@ooooo`?o0?l04_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool04?ooool3o`3o00_ooooo2_l0000Vooooo`03o`000?oooooooooo00Cooooo0002
ooooo`?o00000oooool2o`0000_ooooo1_l0000Tooooo`03o`000?oooooooooo013ooooo3_l0000:
ooooo`Co00008_ooool00ol0003oooooooooo`04ooooo`000oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00?ooooo3Ol00002o`3o01[ooooo1?l0000Nooooo`03o`000?oooooooooo00Cooooo0005o`00
00;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`ko00003Oooool2
o`3o01kooooo0ol0000Looooo`03o`000?oooooooooo00?ooooo00001?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool04Oooool>o`0000Sooooo00?o
0000ooooooooool04?ooool00ol0o`3oooooooooo`0Pooooo`Co00006?ooool00ol0003ooooooooo
o`03ooooo`0000Coooooo`000?oooooo00000oooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00Cooooo3Ol0000Fooooo`03o`000?oooooooooo03Oooooo1?l0000Dooooo`03o`00
0?oooooooooo00?ooooo0002ooooo`;o00000oooool01?l0003oooooooooool0000:ooooo`Oo0000
8oooool00ol0003oooooooooo`0kooooo`Co00004?ooool00ol0003oooooooooo`03ooooo`000ooo
ool00ol0003oooooooooo`02ooooo`;o00003_ooool4o`0002?ooooo00?o0000ooooooooool0?ooo
ool4o`0000cooooo00?o0000ooooooooool00oooool001cooooo1?l0000Oooooo`03o`000?oooooo
oooo04?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo000Pooooo`?o00007?ooool00ol0
003oooooooooo`16ooooo`Co00001Oooool00ol0003oooooooooo`03ooooo`008oooool4o`0001So
oooo00?o0000ooooooooool0B_ooool6o`0000Gooooo000Wooooo`Co00005?ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`Wo
00001Oooool002_ooooo1?l0000@ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooo`00000=o`0000gooooo000_ooooo`Co00003?ooool00ol0003ooooo
ooooo`0Rooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo3Ol0000Koooo
o`00<oooool3o`0000Wooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooooooo3ol0000Xooooo`00=_ooool4o`0000Gooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000003Ol0
000fooooo`00>_ooool4o`000005ooooool0003oooooooooool000000oooool=o`0004Cooooo000n
ooooo`So0000A?ooool5o`0000Sooooo001hooooo`?o00004?ooool01?l0003oooooooooool00008
ooooo`00NOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo001Vooooo`;o
00004Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo001Fooooo`?o0000
3?ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooo
ooooooooo`000008ooooo`00Eoooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`00
013ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000Sooooo0012oooo
o`Go00002?ooool5o`0000?ooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000?
ooooo`;o00004Oooool3o`0000Wooooo0013ooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool02oooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo01_ooooo000l
ooooo`Go00000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00Co0000
oooooooooooo0000;_ooool004Gooooo00?o0000ooooooooool03_ooool2o`0000kooooo0_l0000_
ooooo`00@_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool0?Oooool0
04;ooooo00Go0000ooooooooooooooooo`00001@ooooo`00@oooool3o`00057ooooo002Gooooo`00
Uoooool009Oooooo002Gooooo`00Uoooool009Oooooo002Gooooo`00Uoooool009Oooooo002Goooo
o`00Uoooool009Oooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 228.25}, {361.625, 110.375}} -> {0.292941, \
0.475258, 0.00128285, 0.00451024}}]
}, Open  ]],

Cell["\<\
The state space trajectories for the family of forced (tangled) \
trajectories for DE2 are shown next. They are plotted as above, using the \
numerical solutions. These curves do not intersect in state space.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell["\<\
nsolns2 = Evaluate[ Table[
      NDSolve[{DE2,y[0]==3,y'[0]==v0}, y, {t,0,40}], {v0,-3,3,3}] ];
ParametricPlot3D[ 
      Evaluate[Table[{y[t],y'[t],t,RGBColor[0,1,0]}/.nsolns2[[k,1]],{k,3}]], 
      {t,0,40} , PlotPoints->200, AspectRatio->5/3 ]\
\>", "Input",
  CellLabel->"In[38]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.925865 2.8647 -0.0788684 1.74554 [
[.37528 1.68659 -6.05621 0 ]
[.37528 1.68659 5.94379 9 ]
[.52506 1.66349 -11.984 0 ]
[.52506 1.66349 12.016 9 ]
[.677 1.64006 -2.96327 0 ]
[.677 1.64006 3.03673 9 ]
[.83115 1.61628 -8.78962 0 ]
[.83115 1.61628 9.21038 9 ]
[.98755 1.59215 -2.8958 0 ]
[.98755 1.59215 3.1042 9 ]
[-0.02721 1.49026 -12 -3.27271 ]
[-0.02721 1.49026 0 5.72729 ]
[.06375 1.53672 -24 -3.2948 ]
[.06375 1.53672 0 5.7052 ]
[.15227 1.58193 -6 -3.31611 ]
[.15227 1.58193 0 5.68389 ]
[.23844 1.62594 -18 -3.33668 ]
[.23844 1.62594 0 5.66332 ]
[.32235 1.6688 -6 -3.35655 ]
[.32235 1.6688 0 5.64345 ]
[.04711 .16307 -6 -2.80065 ]
[.04711 .16307 0 6.19935 ]
[.02967 .44547 -12 -2.90068 ]
[.02967 .44547 0 6.09932 ]
[.01077 .75162 -12 -3.00932 ]
[.01077 .75162 0 5.99068 ]
[-0.00977 1.08467 -12 -3.12773 ]
[-0.00977 1.08467 0 5.87227 ]
[-0.03219 1.44831 -12 -3.25729 ]
[-0.03219 1.44831 0 5.74271 ]
[ 0 0 0 0 ]
[ 1 1.66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.36339 1.66667 m
1 1.56823 L
s
.37561 1.66478 m
.37578 1.65387 L
s
[(-5)] .37528 1.68659 .00937 -1 Mshowa
.52501 1.64168 m
.52499 1.63077 L
s
[(-2.5)] .52506 1.66349 -0.00133 -1 Mshowa
.67656 1.61824 m
.67634 1.60733 L
s
[(0)] .677 1.64006 -0.01224 -1 Mshowa
.83031 1.59447 m
.82989 1.58356 L
s
[(2.5)] .83115 1.61628 -0.02338 -1 Mshowa
.9863 1.57035 m
.98568 1.55944 L
s
[(5)] .98755 1.59215 -0.03473 -1 Mshowa
.125 Mabswid
.40532 1.66018 m
.4054 1.65364 L
s
.43512 1.65558 m
.43517 1.64903 L
s
.465 1.65096 m
.46503 1.64441 L
s
.49496 1.64632 m
.49497 1.63978 L
s
.55515 1.63702 m
.55511 1.63047 L
s
.58537 1.63234 m
.58531 1.6258 L
s
.61568 1.62766 m
.6156 1.62111 L
s
.64608 1.62296 m
.64597 1.61641 L
s
.70713 1.61351 m
.70698 1.60697 L
s
.73779 1.60877 m
.73762 1.60223 L
s
.76854 1.60402 m
.76834 1.59747 L
s
.79938 1.59925 m
.79916 1.59271 L
s
.86133 1.58967 m
.86105 1.58313 L
s
.89244 1.58486 m
.89214 1.57832 L
s
.92363 1.58004 m
.92331 1.57349 L
s
.95492 1.5752 m
.95458 1.56866 L
s
.25 Mabswid
0 1.48077 m
.36339 1.66667 L
s
.00733 1.48452 m
.02461 1.48165 L
s
[(-5)] -0.02721 1.49026 1 -0.27273 Mshowa
.09834 1.53108 m
.11564 1.52826 L
s
[(-2.5)] .06375 1.53672 1 -0.26782 Mshowa
.1869 1.57638 m
.20422 1.57361 L
s
[(0)] .15227 1.58193 1 -0.26309 Mshowa
.27311 1.62048 m
.29044 1.61775 L
s
[(2.5)] .23844 1.62594 1 -0.25852 Mshowa
.35706 1.66343 m
.37441 1.66074 L
s
[(5)] .32235 1.6688 1 -0.2541 Mshowa
.125 Mabswid
.02574 1.49394 m
.0361 1.49222 L
s
.04404 1.5033 m
.05441 1.50159 L
s
.06224 1.51261 m
.07261 1.5109 L
s
.08034 1.52187 m
.09072 1.52017 L
s
.11625 1.54024 m
.12663 1.53855 L
s
.13406 1.54935 m
.14444 1.54767 L
s
.15177 1.55841 m
.16215 1.55673 L
s
.16938 1.56742 m
.17977 1.56575 L
s
.20433 1.5853 m
.21472 1.58364 L
s
.22166 1.59416 m
.23206 1.59251 L
s
.2389 1.60298 m
.2493 1.60133 L
s
.25605 1.61176 m
.26645 1.61011 L
s
.29008 1.62916 m
.30048 1.62753 L
s
.30695 1.6378 m
.31736 1.63617 L
s
.32374 1.64638 m
.33415 1.64476 L
s
.34044 1.65493 m
.35085 1.65331 L
s
.25 Mabswid
.08226 .12828 m
0 1.48077 L
s
.08061 .15536 m
.09736 .15151 L
s
[(0)] .04711 .16307 1 -0.37763 Mshowa
.06341 .43816 m
.08028 .4345 L
s
[(10)] .02967 .44547 1 -0.3554 Mshowa
.04476 .74476 m
.06176 .74133 L
s
[(20)] .01077 .75162 1 -0.33126 Mshowa
.02448 1.0783 m
.0416 1.07512 L
s
[(30)] -0.00977 1.08467 1 -0.30495 Mshowa
.00233 1.4425 m
.01959 1.4396 L
s
[(40)] -0.03219 1.44831 1 -0.27616 Mshowa
.125 Mabswid
.07728 .21015 m
.08734 .20786 L
s
.07389 .2658 m
.08397 .26354 L
s
.07046 .32234 m
.08055 .3201 L
s
.06696 .37979 m
.07707 .37757 L
s
.0598 .49748 m
.06994 .49531 L
s
.05614 .55778 m
.06629 .55564 L
s
.05241 .61907 m
.06258 .61696 L
s
.04862 .68139 m
.0588 .67931 L
s
.04084 .8092 m
.05106 .80717 L
s
.03686 .87475 m
.04709 .87275 L
s
.0328 .94143 m
.04305 .93946 L
s
.02868 1.00927 m
.03894 1.00733 L
s
.02021 1.14856 m
.0305 1.14668 L
s
.01586 1.22007 m
.02616 1.21823 L
s
.01143 1.29288 m
.02175 1.29106 L
s
.00692 1.36701 m
.01726 1.36523 L
s
.25 Mabswid
.08226 .12828 m
0 1.48077 L
s
0 1.48077 m
.36339 1.66667 L
s
.36339 1.66667 m
.38556 .34759 L
s
.38556 .34759 m
.08226 .12828 L
s
.63665 0 m
.92157 .23098 L
s
.92157 .23098 m
1 1.56823 L
s
1 1.56823 m
.6627 1.37048 L
s
.6627 1.37048 m
.63665 0 L
s
.08226 .12828 m
0 1.48077 L
s
0 1.48077 m
.6627 1.37048 L
s
.6627 1.37048 m
.63665 0 L
s
.63665 0 m
.08226 .12828 L
s
.38556 .34759 m
.92157 .23098 L
s
.92157 .23098 m
1 1.56823 L
s
1 1.56823 m
.36339 1.66667 L
s
.36339 1.66667 m
.38556 .34759 L
s
0 0 m
1 0 L
1 1.66667 L
0 1.66667 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.74748 .23683 m
.76113 .22372 L
s
.46451 .45202 m
.51455 .45837 L
s
.41619 .44212 m
.46451 .45202 L
s
.37124 .42882 m
.41619 .44212 L
s
.76113 .22372 m
.76614 .21017 L
s
.51455 .45837 m
.56459 .46112 L
s
.33119 .41239 m
.37124 .42882 L
s
.56459 .46112 m
.6129 .46035 L
s
.29743 .3932 m
.33119 .41239 L
s
.6129 .46035 m
.65777 .45624 L
s
.40039 .33149 m
.41525 .34009 L
s
.38696 .32143 m
.40039 .33149 L
s
.41525 .34009 m
.43111 .34734 L
s
.37541 .30983 m
.38696 .32143 L
s
.27113 .3717 m
.29743 .3932 L
s
.43111 .34734 m
.44762 .35338 L
s
.76614 .21017 m
.76219 .1968 L
s
.36626 .29667 m
.37541 .30983 L
s
.44762 .35338 m
.46449 .35836 L
s
.36005 .28198 m
.36626 .29667 L
s
.46449 .35836 m
.48145 .36244 L
s
.65777 .45624 m
.69759 .44909 L
s
.4583 .40085 m
.48812 .40833 L
s
.43061 .39165 m
.4583 .40085 L
s
.40584 .38088 m
.43061 .39165 L
s
.35731 .26586 m
.36005 .28198 L
s
.48812 .40833 m
.51923 .41395 L
s
.38464 .36874 m
.40584 .38088 L
s
.25323 .34843 m
.27113 .3717 L
s
.48145 .36244 m
.4983 .36577 L
s
.36752 .35545 m
.38464 .36874 L
s
.51923 .41395 m
.55066 .41766 L
s
.35856 .24852 m
.35731 .26586 L
s
.4983 .36577 m
.51486 .36849 L
s
.35486 .34125 m
.36752 .35545 L
s
.66491 .17194 m
.65192 .16926 L
s
.55066 .41766 m
.58143 .41944 L
s
.76219 .1968 m
.74929 .18425 L
s
.34692 .32638 m
.35486 .34125 L
s
.51486 .36849 m
.53096 .37071 L
s
.36428 .2302 m
.35856 .24852 L
s
.69759 .44909 m
.73084 .4393 L
s
.24441 .324 m
.25323 .34843 L
s
.58143 .41944 m
.61051 .41932 L
s
.3438 .31111 m
.34692 .32638 L
s
.53096 .37071 m
.54644 .37253 L
s
.65192 .16926 m
.63542 .16798 L
s
.37484 .21128 m
.36428 .2302 L
s
.34546 .29568 m
.3438 .31111 L
s
.61051 .41932 m
.63687 .41741 L
s
.54644 .37253 m
.56115 .37402 L
s
.24502 .29906 m
.24441 .324 L
s
.63542 .16798 m
.61584 .1682 L
s
.35173 .28034 m
.34546 .29568 L
s
.74929 .18425 m
.72775 .17315 L
s
.39048 .19219 m
.37484 .21128 L
s
.73084 .4393 m
.75621 .42738 L
s
.56115 .37402 m
.57488 .37523 L
s
.36235 .26532 m
.35173 .28034 L
s
.63687 .41741 m
.65954 .41389 L
s
.61584 .1682 m
.59369 .16996 L
s
.4113 .17344 m
.39048 .19219 L
s
.37692 .25083 m
.36235 .26532 L
s
.57488 .37523 m
.58745 .37621 L
s
.25509 .2743 m
.24502 .29906 L
s
.59369 .16996 m
.56952 .1733 L
s
.39499 .23707 m
.37692 .25083 L
s
.65954 .41389 m
.6776 .40897 L
s
.43716 .15559 m
.4113 .17344 L
s
.58745 .37621 m
.5986 .37696 L
s
.56952 .1733 m
.54389 .17819 L
s
.72775 .17315 m
.69822 .1641 L
s
.41601 .22421 m
.39499 .23707 L
s
.75621 .42738 m
.77262 .41393 L
s
.54389 .17819 m
.51743 .18461 L
s
.4394 .21241 m
.41601 .22421 L
s
.46453 .2018 m
.4394 .21241 L
s
.51743 .18461 m
.49076 .1925 L
s
.49076 .1925 m
.46453 .2018 L
s
.4677 .13924 m
.43716 .15559 L
s
.5986 .37696 m
.60808 .37752 L
s
.27429 .2504 m
.25509 .2743 L
s
.6776 .40897 m
.69026 .40297 L
s
.50232 .12502 m
.4677 .13924 L
s
.60808 .37752 m
.61561 .3779 L
s
.69822 .1641 m
.66166 .15762 L
s
.54014 .1135 m
.50232 .12502 L
s
.58001 .10522 m
.54014 .1135 L
s
.44692 .64157 m
.50186 .64967 L
s
.39438 .62958 m
.44692 .64157 L
s
.50186 .64967 m
.55724 .6538 L
s
.30197 .22804 m
.27429 .2504 L
s
.34613 .61394 m
.39438 .62958 L
s
.61561 .3779 m
.62089 .37812 L
s
.77262 .41393 m
.77929 .39963 L
s
.55724 .6538 m
.61105 .65401 L
s
.69026 .40297 m
.69687 .39623 L
s
.30391 .59496 m
.34613 .61394 L
s
.66166 .15762 m
.6193 .15419 L
s
.62089 .37812 m
.62364 .37823 L
s
.33712 .20782 m
.30197 .22804 L
s
.61105 .65401 m
.66134 .65047 L
s
.2693 .57312 m
.30391 .59496 L
s
.47054 .62088 m
.51514 .62816 L
s
.42787 .61059 m
.47054 .62088 L
s
.62364 .37823 m
.62359 .3783 L
s
.38862 .59746 m
.42787 .61059 L
s
.69687 .39623 m
.69696 .38916 L
s
.6193 .15419 m
.57266 .15414 L
s
.51514 .62816 m
.56007 .63231 L
s
.37847 .19029 m
.33712 .20782 L
s
.35418 .58181 m
.38862 .59746 L
s
.77929 .39963 m
.77575 .38521 L
s
.56007 .63231 m
.6037 .63336 L
s
.66134 .65047 m
.70621 .6435 L
s
.62359 .3783 m
.62052 .37839 L
s
.57266 .15414 m
.52341 .1577 L
s
.24359 .54897 m
.2693 .57312 L
s
.42447 .1759 m
.37847 .19029 L
s
.32573 .564 m
.35418 .58181 L
s
.52341 .1577 m
.47339 .16498 L
s
.47339 .16498 m
.42447 .1759 L
s
.6037 .63336 m
.64441 .63141 L
s
.69696 .38916 m
.69029 .38218 L
s
.62052 .37839 m
.61425 .37864 L
s
.30425 .54449 m
.32573 .564 L
s
.46165 .59142 m
.49439 .6 L
s
.43145 .58086 m
.46165 .59142 L
s
.49439 .6 m
.52855 .60643 L
s
.40475 .56857 m
.43145 .58086 L
s
.52855 .60643 m
.56293 .6106 L
s
.70621 .6435 m
.74395 .63353 L
s
.3824 .55483 m
.40475 .56857 L
s
.22782 .52319 m
.24359 .54897 L
s
.61425 .37864 m
.60471 .37916 L
s
.64441 .63141 m
.68063 .6267 L
s
.36502 .53999 m
.3824 .55483 L
s
.56293 .6106 m
.59628 .6125 L
s
.77575 .38521 m
.76193 .37142 L
s
.29046 .52379 m
.30425 .54449 L
s
.69029 .38218 m
.67683 .37577 L
s
.35308 .52439 m
.36502 .53999 L
s
.60471 .37916 m
.59191 .38011 L
s
.59628 .6125 m
.62733 .61217 L
s
.34679 .50841 m
.35308 .52439 L
s
.28479 .50246 m
.29046 .52379 L
s
.68063 .6267 m
.71091 .61957 L
s
.22263 .4965 m
.22782 .52319 L
s
.59191 .38011 m
.57598 .38167 L
s
.74395 .63353 m
.773 .6211 L
s
.62733 .61217 m
.65485 .60977 L
s
.34617 .49242 m
.34679 .50841 L
s
.67683 .37577 m
.65686 .37038 L
s
.57598 .38167 m
.55718 .38402 L
s
.76193 .37142 m
.73815 .35903 L
s
.28739 .48108 m
.28479 .50246 L
s
.35104 .47678 m
.34617 .49242 L
s
.55718 .38402 m
.53592 .38734 L
s
.71091 .61957 m
.73397 .61045 L
s
.65485 .60977 m
.67766 .60553 L
s
.22832 .46968 m
.22263 .4965 L
s
.36099 .4618 m
.35104 .47678 L
s
.65686 .37038 m
.63088 .36647 L
s
.53592 .38734 m
.51273 .39179 L
s
.29808 .46023 m
.28739 .48108 L
s
.37548 .44776 m
.36099 .4618 L
s
.773 .6211 m
.79212 .60688 L
s
.51273 .39179 m
.48825 .39753 L
s
.3938 .43489 m
.37548 .44776 L
s
.48825 .39753 m
.46325 .40467 L
s
.67766 .60553 m
.69474 .59975 L
s
.41512 .42336 m
.3938 .43489 L
s
.73815 .35903 m
.70515 .34878 L
s
.46325 .40467 m
.43858 .41327 L
s
.43858 .41327 m
.41512 .42336 L
s
.63088 .36647 m
.59967 .36445 L
s
.31637 .44046 m
.29808 .46023 L
s
.24473 .44355 m
.22832 .46968 L
s
.73397 .61045 m
.74874 .59987 L
s
.45838 .84089 m
.51774 .84836 L
s
.40099 .82932 m
.45838 .84089 L
s
.34147 .42228 m
.31637 .44046 L
s
.59967 .36445 m
.56427 .36468 L
s
.51774 .84836 m
.57689 .85168 L
s
.34764 .81383 m
.40099 .82932 L
s
.69474 .59975 m
.70522 .59284 L
s
.79212 .60688 m
.80038 .5916 L
s
.70515 .34878 m
.66407 .34133 L
s
.27131 .41891 m
.24473 .44355 L
s
.30033 .79474 m
.34764 .81383 L
s
.57689 .85168 m
.63366 .85094 L
s
.37233 .40613 m
.34147 .42228 L
s
.56427 .36468 m
.52592 .36745 L
s
.4679 .82986 m
.52159 .83716 L
s
.41605 .81889 m
.4679 .82986 L
s
.36792 .80445 m
.41605 .81889 L
s
.74874 .59987 m
.75444 .58842 L
s
.52159 .83716 m
.57513 .84075 L
s
.40768 .39238 m
.37233 .40613 L
s
.52592 .36745 m
.48602 .37295 L
s
.32528 .78684 m
.36792 .80445 L
s
.26083 .7725 m
.30033 .79474 L
s
.63366 .85094 m
.68595 .84639 L
s
.57513 .84075 m
.62656 .84068 L
s
.70522 .59284 m
.70844 .58523 L
s
.44608 .38127 m
.40768 .39238 L
s
.48602 .37295 m
.44608 .38127 L
s
.30706 .3965 m
.27131 .41891 L
s
.47748 .81877 m
.52546 .82591 L
s
.43119 .80841 m
.47748 .81877 L
s
.66407 .34133 m
.61644 .33725 L
s
.38829 .79502 m
.43119 .80841 L
s
.52546 .82591 m
.57337 .82976 L
s
.28971 .76647 m
.32528 .78684 L
s
.35033 .7789 m
.38829 .79502 L
s
.62656 .84068 m
.67393 .83716 L
s
.80038 .5916 m
.79722 .57608 L
s
.2307 .74768 m
.26083 .7725 L
s
.57337 .82976 m
.61943 .83037 L
s
.75444 .58842 m
.75061 .57676 L
s
.68595 .84639 m
.73176 .83838 L
s
.35057 .377 m
.30706 .3965 L
s
.31868 .76043 m
.35033 .7789 L
s
.61644 .33725 m
.5641 .33697 L
s
.70844 .58523 m
.70402 .57744 L
s
.26257 .74388 m
.28971 .76647 L
s
.61943 .83037 m
.66186 .82789 L
s
.40012 .36096 m
.35057 .377 L
s
.67393 .83716 m
.7154 .83051 L
s
.29449 .74008 m
.31868 .76043 L
s
.5641 .33697 m
.50911 .34079 L
s
.21115 .72095 m
.2307 .74768 L
s
.4537 .34881 m
.40012 .36096 L
s
.50911 .34079 m
.4537 .34881 L
s
.24489 .71968 m
.26257 .74388 L
s
.73176 .83838 m
.76928 .82742 L
s
.66186 .82789 m
.69899 .8226 L
s
.70402 .57744 m
.69184 .57002 L
s
.75061 .57676 m
.73715 .5656 L
s
.27865 .71842 m
.29449 .74008 L
s
.79722 .57608 m
.78255 .56117 L
s
.7154 .83051 m
.74931 .82117 L
s
.20307 .69308 m
.21115 .72095 L
s
.23739 .69455 m
.24489 .71968 L
s
.27169 .69603 m
.27865 .71842 L
s
.69899 .8226 m
.72929 .81489 L
s
.69184 .57002 m
.67212 .5635 L
s
.76928 .82742 m
.79693 .81412 L
s
.73715 .5656 m
.71435 .55562 L
s
.78255 .56117 m
.75673 .54771 L
s
.27385 .67355 m
.27169 .69603 L
s
.74931 .82117 m
.77421 .80968 L
s
.2404 .66923 m
.23739 .69455 L
s
.20688 .66491 m
.20307 .69308 L
s
.67212 .5635 m
.64539 .55843 L
s
.72929 .81489 m
.75143 .80524 L
s
.28498 .65162 m
.27385 .67355 L
s
.71435 .55562 m
.6829 .54751 L
s
.25383 .64448 m
.2404 .66923 L
s
.79693 .81412 m
.81349 .7992 L
s
.64539 .55843 m
.6125 .55532 L
s
.22257 .63731 m
.20688 .66491 L
s
.75673 .54771 m
.72059 .53653 L
s
.77421 .80968 m
.78894 .79672 L
s
.30458 .63086 m
.28498 .65162 L
s
.48732 1.04865 m
.54991 1.05436 L
s
.42558 1.03877 m
.48732 1.04865 L
s
.75143 .80524 m
.76436 .79423 L
s
.36697 1.0248 m
.42558 1.03877 L
s
.54991 1.05436 m
.61108 1.05592 L
s
.6829 .54751 m
.64389 .54189 L
s
.31367 1.00702 m
.36697 1.0248 L
s
.27717 .62103 m
.25383 .64448 L
s
.43203 1.03316 m
.49069 1.04287 L
s
.37638 1.0196 m
.43203 1.03316 L
s
.49069 1.04287 m
.55021 1.04863 L
s
.6125 .55532 m
.57462 .5546 L
s
.33179 .61184 m
.30458 .63086 L
s
.3258 1.00244 m
.37638 1.0196 L
s
.55021 1.04863 m
.6084 1.05044 L
s
.24964 .61115 m
.22257 .63731 L
s
.43849 1.02753 m
.49408 1.03707 L
s
.38581 1.01438 m
.43849 1.02753 L
s
.49408 1.03707 m
.55052 1.04287 L
s
.61108 1.05592 m
.66854 1.0535 L
s
.26767 .98578 m
.31367 1.00702 L
s
.72059 .53653 m
.67547 .52837 L
s
.33797 .99786 m
.38581 1.01438 L
s
.81349 .7992 m
.81807 .78347 L
s
.57462 .5546 m
.53317 .55663 L
s
.55052 1.04287 m
.60572 1.04495 L
s
.36545 .59507 m
.33179 .61184 L
s
.28221 .98206 m
.3258 1.00244 L
s
.30949 .59959 m
.27717 .62103 L
s
.78894 .79672 m
.7927 .78299 L
s
.6084 1.05044 m
.66308 1.04848 L
s
.64389 .54189 m
.59877 .53928 L
s
.76436 .79423 m
.76732 .78251 L
s
.29678 .97833 m
.33797 .99786 L
s
.53317 .55663 m
.48975 .56164 L
s
.40411 .58095 m
.36545 .59507 L
s
.60572 1.04495 m
.65761 1.04345 L
s
.23078 .96162 m
.26767 .98578 L
s
.66854 1.0535 m
.72014 1.04741 L
s
.28707 .58726 m
.24964 .61115 L
s
.48975 .56164 m
.44613 .56975 L
s
.44613 .56975 m
.40411 .58095 L
s
.24728 .95895 m
.28221 .98206 L
s
.34948 .58078 m
.30949 .59959 L
s
.59877 .53928 m
.54932 .54012 L
s
.66308 1.04848 m
.71217 1.04303 L
s
.67547 .52837 m
.6231 .52386 L
s
.26379 .95628 m
.29678 .97833 L
s
.65761 1.04345 m
.70419 1.03864 L
s
.39545 .56513 m
.34948 .58078 L
s
.54932 .54012 m
.49751 .54466 L
s
.2045 .93515 m
.23078 .96162 L
s
.33339 .5664 m
.28707 .58726 L
s
.81807 .78347 m
.81026 .7678 L
s
.7927 .78299 m
.78509 .7693 L
s
.76732 .78251 m
.75994 .7708 L
s
.2224 .93371 m
.24728 .95895 L
s
.72014 1.04741 m
.76386 1.03811 L
s
.4455 .55301 m
.39545 .56513 L
s
.49751 .54466 m
.4455 .55301 L
s
.6231 .52386 m
.56559 .52348 L
s
.24031 .93227 m
.26379 .95628 L
s
.71217 1.04303 m
.75375 1.0345 L
s
.38674 .5492 m
.33339 .5664 L
s
.70419 1.03864 m
.74362 1.0309 L
s
.56559 .52348 m
.50534 .52754 L
s
.18997 .90713 m
.2045 .93515 L
s
.44487 .53615 m
.38674 .5492 L
s
.20863 .90706 m
.2224 .93371 L
s
.50534 .52754 m
.44487 .53615 L
s
.22728 .90698 m
.24031 .93227 L
s
.76386 1.03811 m
.79791 1.02614 L
s
.75994 .7708 m
.74226 .75983 L
s
.78509 .7693 m
.76618 .75645 L
s
.81026 .7678 m
.79014 .75306 L
s
.75375 1.0345 m
.7861 1.02344 L
s
.74362 1.0309 m
.77426 1.02074 L
s
.18793 .87837 m
.18997 .90713 L
s
.2066 .87975 m
.20863 .90706 L
s
.22527 .88114 m
.22728 .90698 L
s
.74226 .75983 m
.71476 .75032 L
s
.79791 1.02614 m
.82083 1.01221 L
s
.76618 .75645 m
.7365 .74525 L
s
.7861 1.02344 m
.80779 1.01049 L
s
.79014 .75306 m
.7583 .74016 L
s
.77426 1.02074 m
.79474 1.00878 L
s
.23443 .8555 m
.22527 .88114 L
s
.21653 .85263 m
.2066 .87975 L
s
.1986 .84975 m
.18793 .87837 L
s
.71476 .75032 m
.67835 .74297 L
s
.46181 1.25739 m
.52685 1.26505 L
s
.39853 1.24563 m
.46181 1.25739 L
s
.33937 1.22991 m
.39853 1.24563 L
s
.25443 .83085 m
.23443 .8555 L
s
.52685 1.26505 m
.59129 1.26858 L
s
.7365 .74525 m
.69707 .73645 L
s
.46435 1.25444 m
.52771 1.26207 L
s
.40273 1.24281 m
.46435 1.25444 L
s
.34514 1.22735 m
.40273 1.24281 L
s
.2381 .82652 m
.21653 .85263 L
s
.82083 1.01221 m
.8315 .99707 L
s
.52771 1.26207 m
.5905 1.26569 L
s
.46689 1.25147 m
.52858 1.25908 L
s
.40693 1.23999 m
.46689 1.25147 L
s
.80779 1.01049 m
.81777 .99639 L
s
.7583 .74016 m
.71585 .72991 L
s
.22174 .82217 m
.1986 .84975 L
s
.35091 1.22478 m
.40693 1.23999 L
s
.28653 1.21053 m
.33937 1.22991 L
s
.52858 1.25908 m
.58971 1.26279 L
s
.79474 1.00878 m
.80404 .99571 L
s
.59129 1.26858 m
.65274 1.26811 L
s
.29372 1.20834 m
.34514 1.22735 L
s
.5905 1.26569 m
.65038 1.26541 L
s
.30092 1.20615 m
.35091 1.22478 L
s
.67835 .74297 m
.63436 .7384 L
s
.58971 1.26279 m
.64802 1.26271 L
s
.28451 .80794 m
.25443 .83085 L
s
.24204 1.18791 m
.28653 1.21053 L
s
.25045 1.1862 m
.29372 1.20834 L
s
.69707 .73645 m
.64937 .73075 L
s
.27054 .80224 m
.2381 .82652 L
s
.65274 1.26811 m
.7089 1.26389 L
s
.25886 1.1845 m
.30092 1.20615 L
s
.65038 1.26541 m
.70511 1.26149 L
s
.25653 .79653 m
.22174 .82217 L
s
.71585 .72991 m
.66443 .72306 L
s
.64802 1.26271 m
.70131 1.25908 L
s
.63436 .7384 m
.58452 .73713 L
s
.32344 .78745 m
.28451 .80794 L
s
.8315 .99707 m
.82926 .98159 L
s
.20768 1.1626 m
.24204 1.18791 L
s
.81777 .99639 m
.8154 .98195 L
s
.80404 .99571 m
.80154 .98231 L
s
.21704 1.16148 m
.25045 1.1862 L
s
.31256 .78055 m
.27054 .80224 L
s
.22641 1.16035 m
.25886 1.1845 L
s
.64937 .73075 m
.59529 .72868 L
s
.7089 1.26389 m
.75761 1.25633 L
s
.58452 .73713 m
.53084 .73952 L
s
.70511 1.26149 m
.75256 1.25429 L
s
.36961 .76998 m
.32344 .78745 L
s
.30164 .77363 m
.25653 .79653 L
s
.70131 1.25908 m
.74751 1.25226 L
s
.66443 .72306 m
.60611 .7202 L
s
.36245 .76212 m
.31256 .78055 L
s
.42105 .75599 m
.36961 .76998 L
s
.53084 .73952 m
.47557 .74579 L
s
.59529 .72868 m
.53707 .73066 L
s
.1849 1.13527 m
.20768 1.1626 L
s
.19489 1.13481 m
.21704 1.16148 L
s
.47557 .74579 m
.42105 .75599 L
s
.20488 1.13436 m
.22641 1.16035 L
s
.35526 .75422 m
.30164 .77363 L
s
.4181 .74745 m
.36245 .76212 L
s
.53707 .73066 m
.47715 .73691 L
s
.60611 .7202 m
.54332 .72177 L
s
.75761 1.25633 m
.79692 1.24593 L
s
.80154 .98231 m
.78707 .96938 L
s
.8154 .98195 m
.8005 .96802 L
s
.82926 .98159 m
.81394 .96666 L
s
.75256 1.25429 m
.79083 1.24434 L
s
.47715 .73691 m
.4181 .74745 L
s
.74751 1.25226 m
.78474 1.24274 L
s
.41514 .73887 m
.35526 .75422 L
s
.54332 .72177 m
.47874 .72799 L
s
.17475 1.10669 m
.1849 1.13527 L
s
.47874 .72799 m
.41514 .73887 L
s
.18499 1.10696 m
.19489 1.13481 L
s
.19524 1.10723 m
.20488 1.13436 L
s
.79692 1.24593 m
.82516 1.23333 L
s
.78707 .96938 m
.76098 .95774 L
s
.79083 1.24434 m
.81828 1.23223 L
s
.8005 .96802 m
.77345 .95546 L
s
.78474 1.24274 m
.8114 1.23113 L
s
.81394 .96666 m
.78592 .95317 L
s
.19799 1.07977 m
.19524 1.10723 L
s
.18791 1.07873 m
.18499 1.10696 L
s
.17781 1.07769 m
.17475 1.10669 L
s
.76098 .95774 m
.72413 .94819 L
s
.21317 1.0528 m
.19799 1.07977 L
s
.82516 1.23333 m
.84102 1.21926 L
s
.20367 1.05099 m
.18791 1.07873 L
s
.77345 .95546 m
.73513 .94509 L
s
.81828 1.23223 m
.83364 1.21869 L
s
.19417 1.04918 m
.17781 1.07769 L
s
.8114 1.23113 m
.82626 1.21811 L
s
.43875 1.47638 m
.50571 1.4857 L
s
.37441 1.46309 m
.43875 1.47638 L
s
.78592 .95317 m
.74615 .94199 L
s
.50571 1.4857 m
.57282 1.491 L
s
.44052 1.47489 m
.50656 1.48417 L
s
.37707 1.46169 m
.44052 1.47489 L
s
.50656 1.48417 m
.57276 1.48949 L
s
.44229 1.47339 m
.50742 1.48264 L
s
.37973 1.46029 m
.44229 1.47339 L
s
.31506 1.44602 m
.37441 1.46309 L
s
.50742 1.48264 m
.57271 1.48799 L
s
.31855 1.44478 m
.37707 1.46169 L
s
.32203 1.44353 m
.37973 1.46029 L
s
.57282 1.491 m
.63762 1.49236 L
s
.57276 1.48949 m
.63668 1.49093 L
s
.57271 1.48799 m
.63575 1.4895 L
s
.26295 1.42549 m
.31506 1.44602 L
s
.26716 1.42446 m
.31855 1.44478 L
s
.24027 1.02716 m
.21317 1.0528 L
s
.27138 1.42344 m
.32203 1.44353 L
s
.72413 .94819 m
.67785 .94144 L
s
.23181 1.0246 m
.20367 1.05099 L
s
.63762 1.49236 m
.6977 1.48998 L
s
.22333 1.02205 m
.19417 1.04918 L
s
.73513 .94509 m
.68697 .93768 L
s
.63668 1.49093 m
.69594 1.48868 L
s
.63575 1.4895 m
.69419 1.48738 L
s
.74615 .94199 m
.69611 .93391 L
s
.84102 1.21926 m
.84364 1.20455 L
s
.22009 1.40195 m
.26295 1.42549 L
s
.83364 1.21869 m
.83605 1.20451 L
s
.82626 1.21811 m
.82846 1.20447 L
s
.22492 1.4012 m
.26716 1.42446 L
s
.22975 1.40044 m
.27138 1.42344 L
s
.27827 1.00364 m
.24027 1.02716 L
s
.6977 1.48998 m
.75076 1.48422 L
s
.27126 1.00041 m
.23181 1.0246 L
s
.67785 .94144 m
.62398 .93811 L
s
.69594 1.48868 m
.74828 1.48309 L
s
.26425 .99717 m
.22333 1.02205 L
s
.69419 1.48738 m
.7458 1.48196 L
s
.68697 .93768 m
.63089 .93386 L
s
.18825 1.37598 m
.22009 1.40195 L
s
.19353 1.37554 m
.22492 1.4012 L
s
.19881 1.3751 m
.22975 1.40044 L
s
.69611 .93391 m
.63781 .9296 L
s
.32564 .98298 m
.27827 1.00364 L
s
.32048 .97916 m
.27126 1.00041 L
s
.62398 .93811 m
.56473 .93868 L
s
.31531 .97534 m
.26425 .99717 L
s
.84364 1.20455 m
.83263 1.19006 L
s
.83605 1.20451 m
.82514 1.19055 L
s
.82846 1.20447 m
.81766 1.19104 L
s
.63089 .93386 m
.5692 .93413 L
s
.75076 1.48422 m
.79473 1.47553 L
s
.74828 1.48309 m
.79162 1.47461 L
s
.38042 .96578 m
.32564 .98298 L
s
.7458 1.48196 m
.78851 1.4737 L
s
.63781 .9296 m
.57368 .92957 L
s
.16881 1.34826 m
.18825 1.37598 L
s
.56473 .93868 m
.5026 .94344 L
s
.17435 1.34817 m
.19353 1.37554 L
s
.17989 1.34809 m
.19881 1.3751 L
s
.37742 .96152 m
.32048 .97916 L
s
.44026 .95251 m
.38042 .96578 L
s
.5692 .93413 m
.50453 .9388 L
s
.37441 .95725 m
.31531 .97534 L
s
.5026 .94344 m
.44026 .95251 L
s
.43966 .94796 m
.37742 .96152 L
s
.57368 .92957 m
.50646 .93414 L
s
.50453 .9388 m
.43966 .94796 L
s
.43906 .9434 m
.37441 .95725 L
s
.50646 .93414 m
.43906 .9434 L
s
.79473 1.47553 m
.82775 1.4645 L
s
.79162 1.47461 m
.82415 1.46383 L
s
.16272 1.31955 m
.16881 1.34826 L
s
.78851 1.4737 m
.82056 1.46315 L
s
.16831 1.31986 m
.17435 1.34817 L
s
.1739 1.32016 m
.17989 1.34809 L
s
.81766 1.19104 m
.79403 1.17865 L
s
.82514 1.19055 m
.8011 1.17766 L
s
.83263 1.19006 m
.80819 1.17667 L
s
.18126 1.29212 m
.1739 1.32016 L
s
.17585 1.29142 m
.16831 1.31986 L
s
.17043 1.29072 m
.16272 1.31955 L
s
.82775 1.4645 m
.84836 1.45182 L
s
.82415 1.46383 m
.84442 1.45141 L
s
.82056 1.46315 m
.84047 1.451 L
s
.79403 1.17865 m
.75829 1.16814 L
s
.8011 1.17766 m
.76468 1.16671 L
s
.80819 1.17667 m
.77108 1.16527 L
s
.20185 1.26482 m
.18126 1.29212 L
s
.19685 1.26373 m
.17585 1.29142 L
s
.19186 1.26263 m
.17043 1.29072 L
s
.75829 1.16814 m
.71174 1.1603 L
s
.76468 1.16671 m
.7172 1.15848 L
s
.84836 1.45182 m
.85549 1.43825 L
s
.84442 1.45141 m
.85136 1.43811 L
s
.77108 1.16527 m
.72265 1.15667 L
s
.84047 1.451 m
.84724 1.43798 L
s
.23497 1.23911 m
.20185 1.26482 L
s
.23064 1.23764 m
.19685 1.26373 L
s
.2263 1.23617 m
.19186 1.26263 L
s
.71174 1.1603 m
.65621 1.15578 L
s
.7172 1.15848 m
.66052 1.15367 L
s
.72265 1.15667 m
.66483 1.15157 L
s
.27938 1.2158 m
.23497 1.23911 L
s
.27594 1.214 m
.23064 1.23764 L
s
.27249 1.21219 m
.2263 1.23617 L
s
.85549 1.43825 m
.84857 1.42463 L
s
.85136 1.43811 m
.84443 1.42477 L
s
.84724 1.43798 m
.84029 1.42491 L
s
.65621 1.15578 m
.59397 1.15513 L
s
.66052 1.15367 m
.59699 1.15283 L
s
.33329 1.19559 m
.27938 1.2158 L
s
.66483 1.15157 m
.60001 1.15053 L
s
.33093 1.19352 m
.27594 1.214 L
s
.32857 1.19144 m
.27249 1.21219 L
s
.59397 1.15513 m
.52767 1.15872 L
s
.59699 1.15283 m
.52931 1.15633 L
s
.39443 1.17909 m
.33329 1.19559 L
s
.39332 1.17682 m
.33093 1.19352 L
s
.60001 1.15053 m
.53095 1.15393 L
s
.3922 1.17454 m
.32857 1.19144 L
s
.52767 1.15872 m
.46018 1.16672 L
s
.46018 1.16672 m
.39443 1.17909 L
s
.84029 1.42491 m
.81964 1.41263 L
s
.84443 1.42477 m
.82363 1.41223 L
s
.52931 1.15633 m
.46042 1.16434 L
s
.84857 1.42463 m
.82762 1.41182 L
s
.46042 1.16434 m
.39332 1.17682 L
s
.53095 1.15393 m
.46065 1.16195 L
s
.46065 1.16195 m
.3922 1.17454 L
s
.81964 1.41263 m
.78586 1.40198 L
s
.82363 1.41223 m
.78954 1.40134 L
s
.82762 1.41182 m
.79322 1.40069 L
s
.78586 1.40198 m
.74015 1.39376 L
s
.78954 1.40134 m
.74337 1.3929 L
s
.79322 1.40069 m
.74659 1.39204 L
s
.74015 1.39376 m
.68427 1.38866 L
s
.74337 1.3929 m
.6869 1.38764 L
s
.74659 1.39204 m
.68954 1.38661 L
s
.68427 1.38866 m
.6205 1.38728 L
s
.6869 1.38764 m
.62246 1.38613 L
s
.68954 1.38661 m
.62441 1.38498 L
s
0 g
.25 Mabswid
.63665 0 m
.92157 .23098 L
s
.92157 .23098 m
1 1.56823 L
s
1 1.56823 m
.6627 1.37048 L
s
.6627 1.37048 m
.63665 0 L
s
.08226 .12828 m
0 1.48077 L
s
0 1.48077 m
.6627 1.37048 L
s
.6627 1.37048 m
.63665 0 L
s
.63665 0 m
.08226 .12828 L
s
0 1.48077 m
.36339 1.66667 L
s
.00733 1.48452 m
.02461 1.48165 L
s
[(-5)] -0.02721 1.49026 1 -0.27273 Mshowa
.09834 1.53108 m
.11564 1.52826 L
s
[(-2.5)] .06375 1.53672 1 -0.26782 Mshowa
.1869 1.57638 m
.20422 1.57361 L
s
[(0)] .15227 1.58193 1 -0.26309 Mshowa
.27311 1.62048 m
.29044 1.61775 L
s
[(2.5)] .23844 1.62594 1 -0.25852 Mshowa
.35706 1.66343 m
.37441 1.66074 L
s
[(5)] .32235 1.6688 1 -0.2541 Mshowa
.125 Mabswid
.02574 1.49394 m
.0361 1.49222 L
s
.04404 1.5033 m
.05441 1.50159 L
s
.06224 1.51261 m
.07261 1.5109 L
s
.08034 1.52187 m
.09072 1.52017 L
s
.11625 1.54024 m
.12663 1.53855 L
s
.13406 1.54935 m
.14444 1.54767 L
s
.15177 1.55841 m
.16215 1.55673 L
s
.16938 1.56742 m
.17977 1.56575 L
s
.20433 1.5853 m
.21472 1.58364 L
s
.22166 1.59416 m
.23206 1.59251 L
s
.2389 1.60298 m
.2493 1.60133 L
s
.25605 1.61176 m
.26645 1.61011 L
s
.29008 1.62916 m
.30048 1.62753 L
s
.30695 1.6378 m
.31736 1.63617 L
s
.32374 1.64638 m
.33415 1.64476 L
s
.34044 1.65493 m
.35085 1.65331 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{143.75, 239.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002?0000kb000`400?l00000o`00003oSoooool0
08oooooo002?ooooo`00Soooool008oooooo002?ooooo`00Soooool008oooooo002?ooooo`00GOoo
ool4o`0002kooooo001Iooooo`Co00000_ooool00ol0003oooooo`00000]ooooo`00E?ooool5o`00
00Kooooo00Co0000oooooooooooo0000;?ooool0053ooooo1?l0000;ooooo`05o`000?oooooooooo
ooooool00000:oooool004cooooo1?l0000?ooooo`03o`000?oooooooooo00;ooooo0_l0000Yoooo
o`00Aoooool5o`0001?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`00
@oooool4o`0001Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`00?ooo
ool4o`0001cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`00>_ooool5
o`00023ooooo00?o0000ooooooooool01oooool2o`0002Cooooo000fooooo`Co00009Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo000booooo`Co0000:Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo023ooooo000]ooooo`Go0000;Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01oooooo000Yooooo`Co0000<_ooool00ol0003ooooooooo
o`0<ooooo`;o00007oooool002Gooooo1?l0000]ooooo`?o0?l01_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01cooooo000Pooooo`Go0000;Oooool4o`3o00Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Kooooo`007?ooool4o`0002oooooo0ol0o`0=ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool06_ooool001[ooooo0_l0000aooooo`;o0?l0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oo
oooo000002kooooo0_l0o`0Booooo`03o`000?oooooooooo01;ooooo0_l0000Iooooo`006_ooool0
1?l0003oooooooooool0000[ooooo`;o0?l05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01Kooooo000Jooooo`?o000000?oooooo`000?l000009oooool2o`3o00_ooooo2ol0o`00
0ol0003o0?l0ooooo`0Eooooo`03o`000?oooooooooo01Gooooo000Aooooo`;o00001oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo0_l0o`07ooooo`Ko0?l02oooool00ol0
003oooooo`3o0004o`3o01;ooooo00?o0000ooooooooool05?ooool0013ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo00Co0?l0oooo
oooooooooooo1_l0o`0;ooooo`Ko0?l000Co0000o`3o0?l0o`3o0?l00oooool4o`3o00oooooo0_l0
000Dooooo`004?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Gooooo0_l0
000Nooooo`Ko0?l02_ooool7o`3o00Kooooo00Go0000ooooooooooooooooo`3o0006ooooo`?o0?l0
3_ooool00ol0003oooooooooo`0Aooooo`004?ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool06_ooool3o`3o00_ooooo0ol0o`0=ooooo`03o`00
0?oooooooooo00_ooooo00?o0?l0ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`004?oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo0_l0000Gooooo`?o0?l0
2oooool3o`3o013ooooo00?o0000ooooooooool03?ooool00ol0o`3oooooooooo`0<ooooo`03o`00
0?oooooooooo00oooooo000@ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Aooooo`?o0?l00_ooool00ol0o`3oooooooooo`06ooooo`?o0?l0
4oooool00ol0003oooooooooo`0=ooooo`03o`3o0?oooooooooo00cooooo0_l0000?ooooo`004Ooo
ool2o`0000Kooooo0_l0000=ooooo`03o`000?oooooooooo00kooooo0_l0o`04ooooo`03o`3o0?oo
oooooooo00Kooooo00?o0?l0ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`3o0?oo
oooooooo00kooooo00?o0000ooooooooool03?ooool001Wooooo00?o0000ooooooooool03Oooool2
o`0000cooooo0_l0o`05ooooo`03o`3o0?oooooooooo00Gooooo0_l0o`0Gooooo`03o`000?oooooo
oooo00gooooo00?o0?l0ooooooooool03oooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0?l0ooooooooool01Oooool00ol0
o`3oooooooooo`02ooooo`?o0?l06Oooool00ol0003oooooooooo`0=ooooo`03o`3o0?oooooooooo
013ooooo00?o0000ooooooooool02_ooool001Wooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`06ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool00_ooool00ol0o`3o
ooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0?l0ooooooooool04?ooool3o`0000_o
oooo000Iooooo`03o`000?oooooooooo017ooooo0_l00005ooooo`03o`3o0?oooooooooo00Kooooo
00Go0?l0ooooooooooooooooo`3o000Nooooo`03o`000?oooooooooo00[ooooo00?o0?l0oooooooo
ool03?ooool5o`0000;ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool0
4oooool01Ol0003ooooooooooooooooo0?l000Sooooo00Go0?l0ooooooooooooooooo`3o000Ooooo
o`03o`000?oooooooooo01Gooooo1?l00007ooooo`03o`000?oooooooooo00Wooooo000Iooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooool0o`002Oooool01?l0o`3oooooo`3o0?l0o`0Poooo
o`03o`000?oooooooooo013ooooo1Ol0000;ooooo`03o`000?oooooooooo00Wooooo000Iooooo`;o
00005_ooool00ol0o`3o0000ooooo`08ooooo`;o0?l08_ooool00ol0003oooooooooo`0<ooooo`Co
00004?ooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0Dooooo`04o`3o
0?ooooooooooo`0000Sooooo0_l0o`0Rooooo`03o`000?oooooooooo00Oooooo1Ol0000Dooooo`03
o`000?oooooooooo00Wooooo000Iooooo`03o`000?oooooooooo01?ooooo00?o0?l0ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`;o0?l08_ooool00ol0003oooooooooo`03ooooo`Co0000
6Oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0Cooooo`03o`3o0?oo
oooooooo00?ooooo0_l00005ooooo`;o0?l08_ooool6o`0001gooooo00?o0000ooooooooool02Ooo
ool001Wooooo00?o0000ooooooooool04_ooool00ol0o`3oooooooooo`06ooooo`07o`000?oooooo
ooooooooool0o`3oooooo`3o000Oooooo`Co00008_ooool00ol0003oooooooooo`09ooooo`006Ooo
ool00ol0003oooooooooo`0Booooo`03o`3o0?oooooooooo00Oooooo0_l000001Ooooooo0?l0oooo
oooooooo0?l001[ooooo1?l00003ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2?ooool001Wooooo00?o0000ooooooooool04_ooool00ol0o`3oooooooooo`09ooooo`03o`000?l0
o`3ooooo00;ooooo00?o0?l0ooooooooool04_ooool5o`0000Oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`08ooooo`006Oooool2o`0001?ooooo00?o0?l0ooooooooool02_ooool0
0ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00gooooo1?l0000<ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02?ooool001Sooooo0_l0000Dooooo`03o`3o0?oooooooooo
00[ooooo00?o0?l0o`000?l000000oooool00ol0o`3oooooooooo`07ooooo`Go00004?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo01?o
oooo00?o0?l0ooooooooool02_ooool01?l0o`3oooooooooool00003ooooo`;o0?l00oooool4o`00
00Sooooo3Ol0o`000ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo000Hooooo`03
o`000?oooooooooo01Cooooo00?o0?l0ooooooooool02_ooool01?l0o`3oooooooooool00002oooo
o`;o000000?o0?l0o`000?l000001Oooool7o`3o00gooooo00?o0000o`3o0?l0o`001?l0o`0Moooo
o`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo01Cooooo00?o0?l0oooooooo
ool02oooool00ol0o`3oooooooooo`02o`0000?ooooo1ol0o`0Dooooo`03o`000?oooooooooo00Co
oooo1?l0o`0Iooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo01Cooooo
00?o0?l0ooooooooool03?ooool7o`3o00Gooooo0_l0o`0Dooooo`03o`000?oooooooooo00Sooooo
0ol0o`0Fooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo01Gooooo00?o
0?l0ooooooooool02_ooool4o`3o00_ooooo5?l0o`000ol0003o0?l0ooooo`0;ooooo`03o`3o0?oo
oooooooo01?ooooo00?o0000ooooooooool02?ooool001Sooooo0_l0000Gooooo`;o0?l01oooool3
o`3o00?ooooo00?o0000o`3o0?ooool01oooool5o`3o00?ooooo3Ol0o`000ooooooo0000ooooo`04
o`3o00Wooooo0_l0o`0Cooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo
01Sooooo0_l0o`03ooooo`;o0?l01_ooool00ol0003oooooo`3o0007o`3o00[ooooo2ol0o`000ooo
oooo0000ooooo`04ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool04?ooool00ol0
003oooooooooo`08ooooo`006?ooool00ol0003oooooooooo`0Jooooo`?o0?l02?ooool00ol0003o
ooooo`3o0005o`3o00Oooooo1Ol0o`0<ooooo`03o`000?oooooooooo00Cooooo00?o0?l0oooooooo
ool01oooool00ol0o`3oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`00
0?oooooooooo01[ooooo0ol0o`07ooooo`?o0?l01_ooool7o`3o017ooooo00?o0000ooooooooool0
1?ooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo013ooooo00?o0000ooooooooool0
2?ooool001Sooooo00?o0000ooooooooool06?ooool2o`3o00?ooooo00?o0?l0ooooooooool00_oo
ool2o`3o0003ooooool0003ooooo00Kooooo2?l0o`0@ooooo`03o`000?oooooooooo00Co0?l02_oo
ool00ol0o`3oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooo
oooo01Oooooo00?o0?l0ooooooooool01?ooool4o`3o00?ooooo00?o0000ooooooooool00_ooool3
o`3o00Sooooo1ol0o`07ooooo`;o0?l000?o0000o`3o0?l0o`003Oooool00ol0o`3oooooooooo`0A
ooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo01Kooooo00?o0?l0oooo
ooooool01Oooool5o`3o00;ooooo00?o0000ooooooooool00_l0o`0Booooo`Oo0?l00_ooool00ol0
003oooooooooo`0<ooooo`03o`3o0?oooooooooo01;ooooo00?o0000ooooooooool02?ooool001So
oooo00?o0000ooooooooool05Oooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo00?o
oooo0ol0o`000ooooooo0?l0ooooo`0Looooo`03o`000?oooooooooo00[ooooo0_l0o`0Eooooo`03
o`000?oooooooooo00Sooooo0008ooooo`?o00001?ooool2o`0000Kooooo1?l0000Dooooo`03o`3o
0?oooooooooo00Gooooo00?o0?l0ooooooooool01_ooool4o`3o01cooooo00?o0000ooooooooool0
1_ooool4o`3o01Sooooo00?o0000ooooooooool01oooool000Wooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01?ooooo00?o0?l0ooooooooool0
1_ooool00ol0o`3oooooooooo`05ooooo`03o`3o0?l0003ooooo00;ooooo1?l0o`0Hooooo`03o`00
0?oooooooooo00;ooooo1?l0o`0Looooo`03o`000?oooooooooo00Oooooo0009ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Cooooo`03o`3o
0?oooooooooo00Gooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooo`000007ooooo`Ko0?l0
4Oooool00ol0o`3o0000o`3o0003o`3o023ooooo00?o0000ooooooooool01oooool000Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01;ooooo
00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`05ooooo`04o`3o0?ooooooooooo`0000go
oooo4Ol0o`000ooooooo0000ooooo`0Sooooo`03o`000?oooooooooo00Oooooo0009ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Booooo`03
o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool01?ooool01Ol0o`3ooooooooooooooooo0000
01oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`002?ooool2o`0000Co
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Booooo`03o`3o0?oooooooooo
00Gooooo00?o0?l0ooooooooool01?ooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`002Oooool00ol0003o
ooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`03o`3o0?oooooooooo00Ko
oooo00?o0?l0ooooooooool01?ooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`005oooool2o`0001;ooooo
00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo00;ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo
000Gooooo`03o`000?oooooooooo017ooooo00?o0?l0ooooooooool01Oooool00ol0o`3ooooooooo
o`05ooooo`03o`3o0?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Oooooo000Gooooo`03o`000?oooooooooo017ooooo00?o0?l0
ooooooooool01Oooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo00;ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo000Goooo
o`03o`000?oooooooooo01;ooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`04oooo
o`03o`3o0?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Oooooo000Gooooo`03o`000?oooooooooo01;ooooo00?o0?l0oooooooo
ool01Oooool00ol0o`3oooooooooo`05ooooo`05o`3o0?ooooooooooooooool000002_oooolEo`3o
0003o`000?l0o`3o0?l000Go0?l07Oooool00ol0003oooooooooo`07ooooo`005oooool00ol0003o
ooooooooo`0Booooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool01?ooool01Ol0o`3o
oooooooooooooooo000000Cooooo1_l0o`0Eooooo`03o`000?oooooooooo00Gooooo1?l0o`0Ioooo
o`03o`000?oooooooooo00Oooooo000Gooooo`03o`000?oooooooooo01?ooooo00?o0?l0oooooooo
ool01_ooool00ol0o`3oooooooooo`04ooooo`05o`3o0?ooooooooooo`000?ooool00ol0o`06oooo
oaGo0?l000Co0000o`3o0?l0o`3o0?l02?ooool2o`3o01Oooooo00?o0000ooooooooool01oooool0
01Oooooo00?o0000ooooooooool05?ooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo
00Gooooo1?l0o`04ooooo`Go0?l05Oooool01?l0003oooooooooooooool4o`3o00Kooooo0ol0o`0D
ooooo`03o`000?oooooooooo00Oooooo000Gooooo`;o00005_ooool00ol0o`3oooooooooo`05oooo
o`04o`3o0?ooooooooooooooo`?o0?l000Goooooo`3o0?l0o`3o0?l0ooooo`03o`3o00Kooooo5?l0
o`000ol0003o0?l0o`3o0005ooooo`Co0?l01Oooool00ol0o`3oooooooooo`0Aooooo`03o`000?oo
oooooooo00Oooooo000Gooooo`03o`000?oooooooooo01Kooooo00?o0?l0ooooooooool01Oooool3
o`3o00Gooooo1?l0o`05ooooo`?o0?l05?ooool00ol0003oooooooooo`03o`3o00Kooooo00?o0?l0
ooooooooool00oooool00ol0o`3oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo000Goooo
o`03o`000?oooooooooo01Oooooo0_l0o`03ooooo`;o0?l00_ooool2o`3o0004ooooool0o`3o0?l0
o`3o00Cooooo1Ol0o`0Gooooo`03o`000?oooooooooo00?ooooo0ol0o`04ooooo`03o`3o0?oooooo
oooo00?ooooo00?o0?l0ooooooooool04?ooool00ol0003oooooooooo`06ooooo`005oooool00ol0
003oooooooooo`0Iooooo`?o0?l01?ooool4o`3o0003ooooool0003ooooo00Co0?l000Coooooo`3o
0?l0o`3o0?l05oooool00ol0003oooooooooo`05ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0
ooooooooool00oooool00ol0o`3oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo000Goooo
o`03o`000?oooooooooo01Sooooo0_l0o`000ooooooo0?l0ooooo`03o`3o00Cooooo0ol0o`08oooo
o`?o0?l05?ooool00ol0003oooooooooo`04ooooo`;o0?l01Oooool00ol0o`3oooooooooo`03oooo
o`03o`3o0?oooooooooo00oooooo00?o0000ooooooooool01_ooool001Oooooo00?o0000oooooooo
ool05oooool01?l0o`3oooooooooooooool3o`3o00Cooooo0_l0o`001?oooooo0000o`3o0?l0o`0:
ooooo`Go0?l03oooool00ol0003oooooooooo`02ooooo`;o0?l01_ooool00ol0o`3oooooooooo`04
ooooo`03o`3o0?oooooooooo00oooooo00?o0000ooooooooool01_ooool001Kooooo00?o0000oooo
ooooool05oooool01Ol0o`3ooooooooooooooooo0?l000?ooooo1?l0o`03ooooo`03o`000?oooooo
oooo00?o0?l03?ooool4o`3o00_ooooo00?o0000ooooooooool00_l0o`07ooooo`03o`3o0?oooooo
oooo00?ooooo0_l0o`0Booooo`03o`000?oooooooooo00Kooooo000Fooooo`;o00005_ooool2o`3o
00?ooooo00?o0?l0ooooooooool00_ooool2o`3o0006ooooool0o`3o0?l0o`3o0?oooooo00001Ooo
ool4o`3o00cooooo2ol0o`000ol0003o0?l0o`3o0007ooooo`;o0?l01Oooool00ol0o`3ooooooooo
o`0Booooo`03o`000?oooooooooo00Kooooo000Fooooo`03o`000?oooooooooo01Cooooo00?o0?l0
ooooooooool00_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Cooooo0ol0o`08
ooooo`Go0?l04_ooool00ol0003oooooooooo`04ooooo`?o0?l01Oooool2o`3o01Gooooo00?o0000
ooooooooool01_ooool001Kooooo00?o0000ooooooooool04oooool00ol0o`3oooooooooo`02oooo
o`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01_ooool00ol0003oooooo`3o0003o`3o
00Wooooo4_l0o`000ol0003o0?l0o`3o0004o`3o00Gooooo0ol0o`0Gooooo`03o`000?oooooooooo
00Kooooo000Fooooo`03o`000?oooooooooo01;ooooo00?o0?l0ooooooooool00_ooool00ol0o`3o
ooooooooo`02ooooo`03o`3o0?oooooooooo00Oooooo00?o0000ooooooooool00oooool5o`3o01Ko
oooo00?o0000ooooooooool01_ooool3o`3o01[ooooo00?o0000ooooooooool01_ooool001Kooooo
00?o0000ooooooooool04_ooool01Ol0o`3ooooooooooooooooo0?l000Cooooo00?o0?l0oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`?o0?l04oooool00ol0003oooooooooo`02ooooo`Co
0?l07Oooool00ol0003oooooooooo`06ooooo`005_ooool00ol0003oooooooooo`0Aooooo`03o`3o
0?oooooooooo00;ooooo00Go0?l0ooooooooooooooooo`3o000;ooooo`03o`000?oooooooooo00_o
oooo4ol0o`000ol0003o0?l0o`3o0002o`3o027ooooo00?o0000ooooooooool01_ooool001Kooooo
00?o0000ooooooooool04?ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00;ooooo
00?o0?l0ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool01_ooool001Kooooo00?o0000ooooooooool04?ooool00ol0o`3ooooooooo
o`02ooooo`05o`3o0?ooooooooooooooool0o`003?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool01_ooool001Kooooo0_l0000Aooooo`03o`3o0?oo
oooooooo00;ooooo00Go0?l0ooooooooooooooooo`3o000<ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`005_ooool00ol0003ooooooooo
o`0@ooooo`05o`3o0?ooooooooooooooool0o`001?ooool00ol0o`3oooooooooo`0:ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`005_oo
ool00ol0003oooooooooo`0@ooooo`05o`3o0?ooooooooooooooool0o`001?ooool00ol0o`3ooooo
ooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`06ooooo`005_ooool00ol0003oooooooooo`0@ooooo`05o`3o0?ooooooooooooooool0o`00
1?ooool00ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`05ooooo`005_ooool00ol0003oooooooooo`0Aooooo`05o`3o0?oo
ooooooooooooool0o`000oooool00ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`05ooooo`005_ooool00ol0003ooooooooo
o`0Aooooo`05o`3o0?ooooooooooooooool0o`000oooool00ol0o`3oooooooooo`0:ooooo`03o`00
0?oooooooooo01Kooooo2?l0o`000ooooooo0000ooooo`0Tooooo`03o`000?oooooooooo00Gooooo
000Fooooo`03o`000?oooooooooo017ooooo00Go0?l0ooooooooooooooooo`3o0003ooooo`03o`3o
0?oooooooooo00[ooooo00?o0000ooooooooool01ooooolFo`3o0003ooooool0o`3o000000Go0?l0
8?ooool00ol0003oooooooooo`05ooooo`005_ooool00ol0003oooooooooo`0Booooo`05o`3o0?oo
ooooooooooooool0o`000oooool00ol0o`3oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
6?l0o`02ooooo`;o0?l000?o0000o`3o0?l0o`002Ol0o`0Jooooo`03o`000?oooooooooo00Gooooo
000Eooooo`?o00004oooool00ol0o`3oooooooooo`02ooooo`;o0?l00_ooool2o`3o00Wooooo00?o
0000ooooool0o`000ol0o`001?oooooo0?l0o`3o0?l0o`06ooooo`Oo0?l01oooool4o`3o0003o`00
0?l0o`3o0?l000Co0?l00oooool6o`3o01Kooooo00?o0000ooooooooool01Oooool000Gooooo1Ol0
0003ooooo`;o00001_ooool00ol0003oooooooooo`0Dooooo`;o0?l01?ooool01Ol0o`3ooooooooo
oooooooo0?l000Oooooo0ol0o`000ooooooo0?l0o`3o0002o`3o00;ooooo1ol0o`0Booooo`03o`00
0?oooooooooo00Cooooo1?l0o`02ooooo`03o`3o0?oooooooooo00?o0?l04oooool00ol0003ooooo
ooooo`05ooooo`001_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool05_ooool00ol0o`3oooooooooo`02ooooo`04o`3o0?oooooooooooooo
o`;o0?l000?oooooo`3o0?l0o`000_l0o`001Ooooooo0?l0o`3o0?l0o`3ooooo00Go0?l06Oooool0
0ol0003oooooooooo`08ooooo`;o0?l000Coooooo`3o0?l0o`3o0?l00_ooool00ol0o`3ooooooooo
o`0@ooooo`03o`000?oooooooooo00Gooooo0007ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`0Gooooo`03o`3o0?oooooooooo00;ooooo0_l0
o`001?oooooo0?l0o`3o0?l0o`02ooooo`?o0?l000Co0000o`3o0?l0o`3o0?l07_ooool00ol0003o
ooooooooo`0:ooooo`05o`3o0?ooooooooooooooool0o`000_ooool00ol0o`3oooooooooo`0?oooo
o`03o`000?oooooooooo00Gooooo0008ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo0_l0o`02ooooo`?o0?l00_ooool3o`3o
0004ooooool0o`3o0?l0o`3o027ooooo00?o0000ooooooooool02oooool01?l0o`3oooooooooool0
o`02ooooo`03o`3o0?oooooooooo00oooooo00?o0000ooooooooool01Oooool000Gooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
6_ooool2o`3o00;ooooo0ol0o`001?oooooo0?l0o`3o0?l0o`02ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool03?ooool01?l0o`3oooooooooool0o`02ooooo`03o`3o0?oooooooooo
00kooooo00?o0000ooooooooool01Oooool000Gooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool06Oooool00ol0o`3oooooooooo`02
o`3o0003ooooool0o`3o0?l000;o0?l00_ooool3o`3o027ooooo00?o0000ooooooooool03?ooool0
1?l0o`3oooooooooool0o`02ooooo`03o`3o0?oooooooooo00kooooo00?o0000ooooooooool01Ooo
ool000Kooooo0ol00004ooooo`;o00001_ooool00ol0003oooooooooo`0Gooooo`;o0?l000?ooooo
o`3o0?l0o`001?l0o`03ooooo`?o0?l000?oooooo`000?l0o`000ol0o`0Mooooo`03o`000?oooooo
oooo00_ooooo00Co0?l0oooooooooooo0?l00_ooool00ol0o`3oooooooooo`0?ooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`;o00005_ooool2o`3o0003ooooool0o`3o0?l000;o0?l01?ooool3
o`3o00?ooooo0ol0o`03ooooo`Co0?l06Oooool00ol0003oooooooooo`09ooooo`;o0?l00_ooool0
1?l0o`3oooooooooool0o`0Booooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooo
oooo01Cooooo00Ko0?l0oooooooooooo0?l0ooooool0o`09ooooo`?o0?l000?oooooo`000?ooool0
0ol0o`04ooooo`?o0?l05_ooool00ol0003oooooooooo`05ooooo`Co0?l00_ooool2o`3o0003oooo
ool0o`3o0?l001?ooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool04ooo
ool01_l0o`3oooooooooool0o`3oooooo`3o00gooooo0ol0o`03ooooo`Co0?l00oooool4o`3o01;o
oooo00Co0000oooooooooooooooo1?l0o`02ooooo`Co0?l00_ooool00ol0o`3oooooooooo`0Coooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo01?ooooo00Go0?l0ooooool0
o`3oooooo`3o000?ooooo`03o`000?oooooo0?l000Go0?l000?oooooo`3o0?l0o`005ol0o`001?l0
003o0?l0o`3o0?l0o`02ooooo`Co0?l00oooool3o`3o01Kooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool04_ooool01_l0o`3oooooooooool0o`3oooooo`3o00oooooo00?o
0000ooooooooool01Oooool7o`3o0003ooooool0o`3o0?l0013o0?l000?o0000o`3o0?l0o`000ol0
o`000ooooooo0?l0o`3o0004o`3o01[ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000
ooooooooool04Oooool01_l0o`3oooooooooool0o`3oooooo`3o013ooooo00?o0000ooooooooool0
3?ooool7o`3o00cooooo00?o0000o`3o0?l0o`001?l0o`0Pooooo`03o`000?oooooooooo00Cooooo
000Eooooo`03o`000?oooooooooo013ooooo00Ko0?l0oooooooooooo0?l0ooooool0o`0Aooooo`03
o`000?oooooooooo01?ooooo3?l0o`000ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Co
oooo000Eooooo`03o`000?oooooooooo013ooooo00Ko0?l0oooooooooooo0?l0ooooool0o`0Aoooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`04oooo
o`005Oooool00ol0003oooooooooo`0?ooooo`06o`3o0?ooooooooooo`3o0?oooooo0?l04_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool0
01Cooooo00?o0000ooooooooool04?ooool00ol0o`3oooooo`3o0002ooooo`03o`3o0?oooooooooo
013ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Cooooo000Dooooo`03o`000?oooooooooo013ooooo00?o0?l0ooooool0o`000_ooool00ol0o`3o
ooooooooo`0@ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`04ooooo`005?ooool00ol0003oooooooooo`0@ooooo`03o`3o0?oooooo0?l000;ooooo
00?o0?l0ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01?ooool001Cooooo00?o0000ooooooooool04?ooool01_l0o`3ooooooooo
ool0o`3oooooo`3o01;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo00Cooooo000Dooooo`03o`000?oooooooooo013ooooo00Ko0?l0oooooooooooo
0?l0ooooool0o`0Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`04ooooo`005?ooool00ol0003oooooooooo`0@ooooo`06o`3o0?ooooooooooo`3o
0?oooooo0?l04_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool01?ooool001Cooooo00?o0000ooooooooool04Oooool01_l0o`3oooooooooool0o`3o
ooooo`3o017ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00Cooooo000Dooooo`03o`000?oooooooooo01;ooooo00?o0?l0ooooool0o`000_ooool0
0ol0o`3oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo5_l0o`000ol0003o0?l0o`3o0007
o`3o01gooooo00?o0000ooooooooool01?ooool001Cooooo0_l0000Cooooo`04o`3o0?oooooooooo
o`3o00;ooooo00?o0?l0ooooooooool03Oooool00ol0003oooooooooo`02oooooago0?l000?o0000
o`3o0?l0o`002ol0o`0Iooooo`03o`000?oooooooooo00Cooooo000Dooooo`03o`000?oooooooooo
01?ooooo00Co0?l0oooooooooooo0?l00_ooool00ol0o`3oooooooooo`0<ooooo`03o`000?l0o`3o
0?l000;o0?l000?oooooo`3o0?l0o`001?l0o`0Fooooo`03o`000?oooooooooo00Cooooo2_l0o`0F
ooooo`03o`000?oooooooooo00Cooooo000Dooooo`03o`000?oooooooooo01Cooooo00?o0?l0oooo
ooooool00_l0o`000ooooooo0?l0o`3o0009ooooo`Co0?l000?oooooo`3o0?l0o`000_l0o`0Loooo
o`03o`000?oooooooooo00[ooooo1ol0o`0Cooooo`03o`000?oooooooooo00Cooooo000Dooooo`03
o`000?oooooooooo01Gooooo0_l0o`02ooooo`;o0?l000?oooooo`3o0?ooool01?ooool3o`3o0003
ooooool0o`3o0?l000;o0?l08?ooool00ol0003oooooooooo`0=ooooo`03o`3o0?oooooo0?l000;o
0?l04_ooool00ol0003oooooooooo`04ooooo`005?ooool00ol0003oooooooooo`0Gooooo`;o0?l0
0_ooool01?l0o`3oooooo`3o0?ooool3o`3o0004ooooool0o`3o0?l0o`3o00;ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0>ooooo`;o0?l000?oooooo`3o0?l0o`004_ooool00ol0
003oooooooooo`03ooooo`005?ooool00ol0003oooooooooo`0Iooooo`03o`3o0?oooooooooo00Oo
0?l01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo013ooooo00Co0?l0ooooool0
o`3o0?l04Oooool00ol0003oooooooooo`03ooooo`005?ooool00ol0003oooooooooo`0Jooooo`Wo
0?l01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo013ooooo00Co0?l0ooooool0
o`3o0?l04Oooool00ol0003oooooooooo`03ooooo`005?ooool00ol0003oooooooooo`0Iooooo`So
0?l00_ooool3o`3o00;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@ooooo`05
o`3o0?oooooo0?l0ooooool0o`004?ooool00ol0003oooooooooo`03ooooo`005?ooool00ol0003o
ooooooooo`0Gooooo`;o0?l000?oooooo`3o0?l0o`001?ooool4o`3o00;ooooo0ol0o`0Qooooo`03
o`000?oooooooooo00kooooo0_l0o`02ooooo`;o0?l04Oooool00ol0003oooooooooo`03ooooo`00
4oooool00ol0003oooooooooo`0Fooooo`?o0?l000?oooooo`3o0?ooool02?ooool4o`3o0003o`00
0?oooooo0?l000;o0?l07_ooool00ol0003oooooooooo`0=ooooo`03o`3o0?oooooooooo00?o0?l0
4_ooool00ol0003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0Eooooo`05o`3o0?oo
oooo0?l0ooooool0o`003Oooool5o`3o0004ooooool0o`3o0?l0o`3o01_ooooo00?o0000oooooooo
ool02oooool6o`3o01Cooooo00?o0000ooooooooool00oooool001?ooooo00?o0000ooooooooool0
5Oooool4o`3o00oooooo00?o0000ooooool0o`001?l0o`000ooooooo0?l0o`3o0003o`3o01Kooooo
00?o0000ooooooooool01oooool9o`3o01Gooooo00?o0000ooooooooool00oooool001?ooooo00?o
0000ooooooooool05?ooool3o`3o017ooooo00?o0000ooooooooool00oooool>o`3o00oooooo00Co
0000oooooooooooooooo1_l0o`000ooooooo0?l0o`3o0003o`3o01Sooooo00?o0000ooooooooool0
0oooool001?ooooo00?o0000ooooooooool04oooool3o`3o01;ooooo00?o0000ooooooooool02Ooo
oolGo`3o0003o`000?l0o`3o0?l000Wo0?l07?ooool00ol0003oooooooooo`03ooooo`004oooool0
0ol0003oooooooooo`0Booooo`?o0?l04oooool00ol0003oooooooooo`0Aooooo`oo0?l000?o0000
o`3o0?l0o`000ol0o`0Rooooo`03o`000?oooooooooo00?ooooo000Cooooo`03o`000?oooooooooo
01;ooooo0ol0o`0Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`03ooooo`004oooool00ol0003oooooooooo`0Aooooo`?o0?l05?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool000?ooooo
0ol00004ooooo`;o00001oooool3o`00013ooooo0ol0o`0Eooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0@ooooo`?o
0?l05Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00oooool000Kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo013ooooo0ol0o`0Eooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`03ooooo`001?ooool2o`0000?ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0?ooooo`04o`3o0?oooooo0?l0o`3o01Gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo0006ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?oooo
o`04o`3o0?oooooo0?l0o`3o01Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00;ooooo0002ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo00oooooo00Co0?l0ooooool0o`3o0?l0
5Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
0_ooool000?ooooo0ol00004ooooo`;o00001oooool00ol0003oooooooooo`0@ooooo`04o`3o0?oo
oooo0?l0o`3o01Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00;ooooo000Cooooo`03o`000?oooooooooo017ooooo0ol0o`0Dooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`004oooool0
0ol0003oooooooooo`0Aooooo`;o0?l000?oooooo`3o0?ooool04_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00_ooool001;ooooo0_l0000Doooo
o`;o0?l000?oooooo`3o0?ooool04Oooool00ol0003oooooooooo`0Eooooo`co0?l000?o0000o`3o
0?l0o`000ol0o`0Rooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo01Co
oooo0_l0o`000ooooooo0?l0o`3o000@ooooo`03o`000?oooooooooo00gooooo5?l0o`000ol0003o
0?l0o`3o0009o`3o01cooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000ooooooooool0
5Oooool3o`3o0003ooooool0o`3ooooo00kooooo00?o0000ooooooooool01?ooool9o`3o01Cooooo
00?o0000ooooooooool02?ooool7o`3o01Kooooo00?o0000ooooooooool00_ooool001;ooooo00?o
0000ooooooooool05oooool2o`3o0003ooooool0o`3ooooo00gooooo00?o0000o`3o0?l0o`001_l0
o`0Kooooo`03o`000?oooooooooo00_ooooo1ol0o`0Cooooo`03o`000?oooooooooo00;ooooo000B
ooooo`03o`000?oooooooooo01Sooooo0_l0o`000ooooooo0?l0o`3o0009ooooo`So0?l07oooool0
0ol0003oooooooooo`0>ooooo`Go0?l04_ooool00ol0003oooooooooo`02ooooo`004_ooool00ol0
003oooooooooo`0Iooooo`?o0?l000?oooooo`3o0?l0o`001?ooool7o`3o02?ooooo00?o0000oooo
ooooool04Oooool3o`3o017ooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000oooooooo
ool06oooool;o`3o00?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Aooooo`?o
0?l04Oooool00ol0003oooooooooo`02ooooo`004_ooool00ol0003oooooooooo`0Mooooo`Ko0?l0
1_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo0ol0o`0@ooooo`03o`00
0?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo01cooooo2_l0o`03ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool04_ooool3o`3o013ooooo00?o0000ooooooooool00_oo
ool001;ooooo0_l0000Kooooo`?o0?l01?ooool8o`3o0003o`000?oooooooooo027ooooo00?o0000
ooooooooool04Oooool4o`3o013ooooo00?o0000ooooooooool00_ooool001;ooooo00?o0000oooo
ooooool06?ooool3o`3o00Wooooo2?l0o`0Qooooo`03o`000?oooooooooo00oooooo0ol0o`000ooo
oooo0?l0ooooo`0@ooooo`03o`000?oooooooooo00;ooooo000Booooo`03o`000?oooooooooo01Ko
oooo0ol0o`0?ooooo`So0?l07Oooool00ol0003oooooooooo`0>ooooo`Go0?l04oooool00ol0003o
ooooooooo`01ooooo`004_ooool00ol0003oooooooooo`0Eooooo`03o`3o0?oooooo0?l0017ooooo
00?o0000ooooool0o`002?l0o`0Iooooo`03o`000?oooooooooo00_ooooo1Ol0o`0Fooooo`03o`00
0?oooooooooo007ooooo000Booooo`03o`000?oooooooooo01Cooooo00?o0?l0ooooool0o`004_oo
ool00ol0003oooooooooo`03ooooo`_o0?l04oooool00ol0003oooooooooo`05ooooo`Oo0?l06_oo
ool00ol0003oooooooooo`01ooooo`004_ooool00ol0003oooooooooo`0Cooooo`03o`3o0?oooooo
0?l001?ooooo00?o0000ooooooooool01oooool6o`3o0003ooooool0o`3o0?l0017o0?l000?o0000
o`3o0?l0o`001_l0o`0Pooooo`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo
01?ooooo0_l0o`0Dooooo`03o`000?oooooooooo00gooooo5?l0o`000ol0003o0?l0o`3o000Voooo
o`03o`000?oooooooooo007ooooo000Booooo`03o`000?oooooooooo01;ooooo0_l0o`0Eooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`0Booooo`;o0?l05_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Booooo`;o0?l05ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool04Oooool2o`3o01Oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
013ooooo0_l0o`0Hooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0@ooooo`;o0?l06?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool04?ooool2o`3o01Sooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo013ooooo0_l0
o`0Hooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0Aooooo`;o0?l05oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool04Oooool2o`3o01Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo017ooooo0_l0o`0Gooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`01ooooo`00
4?ooool3o`0001?ooooo0_l0o`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Cooooo`?o0?l05?oo
ool00ol0003oooooooooo`0Nooooo`Go0000:?ooool1o`00007ooooo0Oooool0017ooooo00?o0000
ooooooooool05?ooool3o`3o01?ooooo00?o0000ooooooooool06?ooool6o`0000Gooooo0_l0000V
ooooo`7o00000Oooool1ooooo`004Oooool00ol0003oooooooooo`0Eooooo`?o0?l04_ooool00ol0
003oooooooooo`0Booooo`Ko00001?ooool9o`3o0003o`000?l0o`3o0?l000Oo0?l07?ooool1o`00
007ooooo0Oooool0017ooooo00?o0000ooooooooool05_ooool4o`3o013ooooo00?o0000oooooooo
ool03?ooool6o`0001Cooooo0_l000000ooooooo0?l0o`3o0007o`3o01Wooooo0Ol00001ooooo`7o
oooo000Aooooo`03o`000?oooooooooo01Oooooo1Ol0o`0>ooooo`03o`000?oooooooooo00Oooooo
1Ol0000Looooo`;o00001Oooool6o`3o01Kooooo0Ol00001ooooo`7ooooo000Aooooo`03o`000?oo
oooooooo01Wooooo1Ol0o`0<ooooo`04o`000?ooooooooooooooo`Ko00008oooool2o`0000Sooooo
1?l0o`0Cooooo`7o00000Oooool1ooooo`004?ooool00ol0003oooooooooo`0Looooo`03o`3o0?oo
oooo0?l000;o0?l02?ooool6o`0002_ooooo0_l00009ooooo`;o0?l04_ooool1o`00007ooooo0Ooo
ool0013ooooo00?o0000ooooooooool07Oooool6o`3o00Ko00000_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00Oooooo0_l0o`0Aooooo`7o00000Oooool1ooooo`004?ooool3o`00
01gooooo1_l00002o`3o00Kooooo00?o0000ooooooooool0;oooool2o`0000Sooooo0_l0o`0@oooo
o`7o00000Oooool1ooooo`000_ooool3o`0000?ooooo0_l00006ooooo`03o`000?oooooooooo01Oo
oooo1_l00006ooooo`Go0?l00oooool00ol0003oooooooooo`0aooooo`;o00001_ooool2o`3o013o
oooo0Ol00001ooooo`7ooooo0003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo017ooooo1_l0000@ooooo`Co0?l0=_ooool2o`0000;o
oooo0ol0o`0Aooooo`7o00000Oooool1ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool03?ooool5o`0001Wooooo1Ol0o`0cooooo`04o`3o0?l0003o0000o`3o
01?ooooo0Ol00001ooooo`7ooooo00001?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool01_ooool6o`0001kooooo00Co0000oooooooooooooooo1Ol0
o`0]ooooo`Go0?l000?o0000ooooooooool04Oooool1o`00007ooooo0Oooool00004ooooool0003o
ooooo`0000?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06o`0002Cooooo
00?o0000ooooooooool01Oooool7o`3o02Cooooo1Ol0o`04ooooo`;o00004Oooool1o`00007ooooo
0Oooool000;ooooo0_l00003ooooo`Co00001Oooool4o`0002Wooooo00?o0000ooooooooool03?oo
ool@o`3o00Oooooo3_l0o`0:ooooo`;o00003oooool1o`00007ooooo0Oooool000?ooooo00Go0000
oooooooooooo0000ooooo`03o`0000Oooooo0ol0000Xooooo`03o`000?oooooooooo01Cooooo5ol0
o`0Booooo`;o00003Oooool1o`00007ooooo0Oooool000Go00001Oooool00ol0003oooooooooo`07
ooooo`?o00009_ooool00ol0003oooooooooo`0oooooo`;o00002oooool1o`00007ooooo0Oooool0
00[ooooo00?o0000ooooooooool02Oooool4o`0002?ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`09ooooo`7o00000Oooool000Kooooo1?l0000=ooooo`?o000000?oooooo`000?oo
ool08?ooool00ol0003oooooooooo`12ooooo`;o00002Oooool1o`00007ooooo0006ooooo`03o`00
0?oooooooooo017ooooo0_l000000ooooooo0000o`00000Nooooo`03o`000?oooooooooo04Cooooo
0_l00007ooooo`7o00000Oooool000Kooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0
0006ooooo`;o00007oooool00ol0003oooooooooo`16ooooo`;o00001Oooool1o`00007ooooo0007
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000
7Oooool00ol0003oooooooooo`18ooooo`;o00000oooool1o`00007ooooo0005o`0000?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`?o00006_ooool00ol0003ooooooooo
o`1:ooooo`04o`000?ooooooooooo`00007ooooo0009ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool3o`0001Sooooo00?o0000ooooooooool0Boooool3o`00007ooooo0006
ooooo`05o`000?ooooooooooooooool000001oooool4o`0000kooooo0ol0000Fooooo`03o`000?oo
oooooooo04[ooooo1?l00001ooooo`001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool02_ooool2o`0000Gooooo1?l0000Cooooo`03o`000?oooooooooo04?ooooo1ol0
00000ooooooo0000ooooo`02ooooo`001oooool3o`0000Sooooo1Ol00007ooooo`04o`000?oooooo
ooooo`0000Gooooo0_l000000ooooooo0000ooooo`0Aooooo`03o`000?oooooooooo03Oooooo00Go
0000ooooooooooooooooo`000002ooooo`Ko00002oooool001kooooo00Co0000oooooooooooo0000
1oooool2o`0001;ooooo00?o0000ooooooooool0=oooool7o`000003ooooool0003ooooo00kooooo
000Nooooo`04o`000?ooooooooooo`0000Wooooo0ol0000?ooooo`03o`000?oooooooooo033ooooo
2?l0000Gooooo`007_ooool01?l0003oooooooooool0000;ooooo`?o00003Oooool00ol0003ooooo
ooooo`0Tooooo`05o`000?ooooooooooooooool000000_ooool6o`0001kooooo000Nooooo`04o`00
0?ooooooooooo`0000gooooo0ol0000;ooooo`03o`000?oooooooooo02Cooooo1ol000000ooooooo
0000ooooo`0Kooooo`?o00000oooool001_ooooo1_l00002ooooo`03o`000?oooooooooo00;ooooo
0ol00006ooooo`Co00002?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000Go0000
8oooool01Ol0003ooooooooooooooooo000000;ooooo000Looooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`?o00001oooool00ol0003oooooooooo`0Aoooo
o`05o`000?ooooooooooooooool000000oooool6o`0002gooooo0Ol00001ooooo`7ooooo000Moooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000Gooooo00?o0000oooo
ooooool03Oooool01_l0003ooooooooooooooooo0000ooooo`Oo0000<_ooool1o`00007ooooo0Ooo
ool001kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`?o00000oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooo000000Ko00007?ooool5o`0000?ooooo00?o0000
ooooooooool00_ooool3o`0000Wooooo1?l00003ooooo`006oooool01Ol0003ooooooooooooooooo
000000Oooooo1?l0000>ooooo`?o000000Coooooo`000?oooooo00000_ooool01?l0003ooooooooo
ooooool6o`0002Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ooooooooool01?ooool001_ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00Wooooo0ol00005ooooo`_o00007Oooool2o`0000cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`Go00000_ooool001cooooo0ol00008ooooo`Go
00001_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Rooooo`04o`000?oooooooooo
o`0000cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`00=_ooool00ol0
003oooooooooo`0Yooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`Co00004?ooool003Kooooo00?o0000ooooooooool04_ooool5o`0000?ooooo00?o0000
ooooooooool00_ooool3o`0000Oooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool04Oooool003;ooooo1?l0000Fooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
00[ooooo0ol00008ooooo`Go00003oooool003;ooooo00?o0000ooooooooool04?ooool5o`0000?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
02Wooooo000booooo`Go00002?ooool3o`0000cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`05ooooo`;o0000:_ooool003kooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001oooool4o`0003Cooooo000hooooo`Go00001Oooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0eoooo
o`00@_ooool00ol0003oooooooooo`07ooooo`?o00002?ooool5o`0003?ooooo000nooooo`Co0000
COooool003kooooo00?o0000ooooooooool0C_ooool003kooooo1Ol0001<ooooo`00Soooool008oo
oooo002?ooooo`00Soooool008oooooo002?ooooo`00Soooool008oooooo002?ooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 220.625}, {373.875, 135.375}} -> {0.0613213, \
0.622692, 0.00278874, 0.00457675}}]
}, Open  ]],

Cell[TextData[StyleBox["Numerical output",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "Finally, the following input shows how to get a nice display of numerical \
solution values. We use DE2 with the initial conditions ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 3 and ",
  StyleBox["y'",
    FontSlant->"Italic"],
  "(0) = -3."
}], "Text"],

Cell[CellGroupData[{

Cell["nsoln = NDSolve[ {DE2, y[0]==3, y'[0]==-3}, y, {t,0,5}]", "Input",
  CellLabel->"In[52]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"y", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 5.`}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Join[   {{t,y[t],y'[t]}},
        Evaluate[Table[{t,y[t],y'[t]},{t,0,5,0.5}]]/.nsoln[[1]] 
    ]//MatrixForm\
\>", "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"t", \(y[t]\), 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]},
            {"0", "3.`", \(-3.`\)},
            {"0.5`", "1.3918711741848826`", \(-3.303189933177879`\)},
            {"1.`", \(-0.18779077230876054`\), \(-2.9181242620087495`\)},
            {"1.5`", \(-1.4509355500247672`\), \(-2.0822787401328102`\)},
            {"2.`", \(-2.2406476289125474`\), \(-1.0684338843043595`\)},
            {"2.5`", \(-2.528964661547245`\), \(-0.1091563023964113`\)},
            {"3.`", \(-2.3839489683026436`\), "0.6485191614972868`"},
            {"3.5`", \(-1.9232626713698049`\), "1.151757528569233`"},
            {"4.`", \(-1.2715941522584588`\), "1.4196808462252302`"},
            {"4.5`", \(-0.5340444608086956`\), "1.5046047783032332`"},
            {"5.`", "0.21060494535366384`", "1.4540810967388473`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[53]//MatrixForm="]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{691, 784},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->81,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 198, 6, 66, "Text"],
Cell[1955, 59, 61, 0, 28, "Text"],
Cell[2019, 61, 352, 18, 28, "Text"],
Cell[2374, 81, 179, 4, 48, "Text"],
Cell[2556, 87, 169, 8, 28, "Text"],
Cell[2728, 97, 31, 0, 28, "Text"],
Cell[2762, 99, 229, 11, 28, "Text"],
Cell[2994, 112, 192, 4, 48, "Text"],
Cell[3189, 118, 338, 6, 68, "Text"],
Cell[3530, 126, 86, 3, 28, "Text"],
Cell[3619, 131, 494, 15, 68, "Text"],
Cell[4116, 148, 196, 9, 28, "Text"],
Cell[4315, 159, 251, 8, 28, "Text"],
Cell[4569, 169, 215, 8, 28, "Text"],
Cell[4787, 179, 147, 2, 27, "Text"],
Cell[4937, 183, 236, 12, 28, "Text"],
Cell[5176, 197, 141, 2, 27, "Text"],
Cell[5320, 201, 152, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[5497, 208, 138, 4, 51, "Input"],
Cell[5638, 214, 345, 7, 55, "Output"]
}, Open  ]],
Cell[5998, 224, 230, 5, 48, "Text"],
Cell[6231, 231, 85, 1, 31, "Input"],
Cell[6319, 234, 268, 11, 22, "Text"],

Cell[CellGroupData[{
Cell[6612, 249, 93, 4, 36, "Input"],
Cell[6708, 255, 194, 3, 18, "Output"],
Cell[6905, 260, 17637, 496, 126, 4817, 333, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[24557, 759, 303, 5, 50, "Text"],
Cell[24863, 766, 196, 9, 22, "Text"],
Cell[25062, 777, 60, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[25147, 781, 186, 5, 36, "Input"],
Cell[25336, 788, 41456, 1475, 110, 18599, 1188, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[66807, 2266, 60, 0, 22, "Text"],
Cell[66870, 2268, 240, 6, 20, "Text"],

Cell[CellGroupData[{
Cell[67135, 2278, 194, 5, 48, "Input"],
Cell[67332, 2285, 43609, 1517, 111, 18937, 1207, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[110956, 3805, 168, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[111149, 3813, 334, 9, 86, "Input"],
Cell[111486, 3824, 60470, 2354, 181, 29388, 1965, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[171971, 6181, 71, 0, 22, "Text"],
Cell[172045, 6183, 116, 2, 22, "Text"],
Cell[172164, 6187, 76, 0, 22, "Text"],
Cell[172243, 6189, 289, 15, 22, "Text"],
Cell[172535, 6206, 129, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[172689, 6213, 160, 5, 36, "Input"],
Cell[172852, 6220, 1254, 21, 86, "Output"]
}, Open  ]],
Cell[174121, 6244, 278, 7, 36, "Text"],
Cell[174402, 6253, 37, 0, 22, "Text"],
Cell[174442, 6255, 84, 1, 23, "Input"],
Cell[174529, 6258, 135, 5, 22, "Text"],
Cell[174667, 6265, 196, 9, 22, "Text"],

Cell[CellGroupData[{
Cell[174888, 6278, 186, 5, 36, "Input"],
Cell[175077, 6285, 46699, 1503, 108, 18114, 1145, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[221791, 7791, 37, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[221853, 7795, 194, 5, 48, "Input"],
Cell[222050, 7802, 54063, 1571, 110, 17660, 1117, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[276128, 9376, 66, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[276219, 9380, 339, 9, 86, "Input"],
Cell[276561, 9391, 117181, 2943, 227, 27826, 1835, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[393757, 12337, 268, 9, 36, "Text"],

Cell[CellGroupData[{
Cell[394050, 12350, 306, 8, 86, "Input"],
Cell[394359, 12360, 72306, 1491, 219, 10441, 722, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[466680, 13854, 518, 9, 64, "Text"],
Cell[467201, 13865, 139, 3, 22, "Text"],
Cell[467343, 13870, 120, 3, 22, "Text"],
Cell[467466, 13875, 478, 27, 22, "Text"],
Cell[467947, 13904, 384, 10, 50, "Text"],
Cell[468334, 13916, 193, 3, 20, "Text"],
Cell[468530, 13921, 91, 3, 22, "Text"],
Cell[468624, 13926, 90, 2, 22, "Text"],
Cell[468717, 13930, 61, 0, 22, "Text"],
Cell[468781, 13932, 76, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[468882, 13936, 174, 5, 48, "Input"],
Cell[469059, 13943, 39922, 1036, 193, 8369, 642, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[508996, 14982, 545, 9, 64, "Text"],
Cell[509544, 14993, 100, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[509669, 15000, 196, 5, 48, "Input"],
Cell[509868, 15007, 43519, 1148, 211, 9319, 721, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[553402, 16158, 83, 1, 21, "Text"],
Cell[553488, 16161, 266, 5, 50, "Text"],
Cell[553757, 16168, 138, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[553920, 16175, 45, 1, 23, "Input"],
Cell[553968, 16178, 400, 11, 18, "Output"]
}, Open  ]],
Cell[554383, 16192, 109, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[554517, 16199, 119, 5, 48, "Input"],
Cell[554639, 16206, 85, 2, 18, "Output"]
}, Open  ]],
Cell[554739, 16211, 59, 0, 22, "Text"],
Cell[554801, 16213, 63, 1, 23, "Input"],

Cell[CellGroupData[{
Cell[554889, 16218, 150, 4, 36, "Input"],
Cell[555042, 16224, 69414, 2052, 210, 32659, 1593, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[624471, 18279, 125, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[624621, 18286, 258, 7, 73, "Input"],
Cell[624882, 18295, 114864, 4059, 209, 59826, 3375, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[739761, 22357, 160, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[739946, 22365, 340, 9, 98, "Input"],
Cell[740289, 22376, 114471, 4055, 206, 59826, 3375, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[854775, 26434, 103, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[854903, 26441, 223, 6, 44, "Input"],
Cell[855129, 26449, 56725, 2387, 263, 23525, 1972, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[911869, 28839, 234, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[912128, 28848, 320, 8, 66, "Input"],
Cell[912451, 28858, 63972, 2692, 250, 26674, 2227, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[976438, 31553, 97, 2, 22, "Text"],
Cell[976538, 31557, 282, 9, 36, "Text"],

Cell[CellGroupData[{
Cell[976845, 31570, 122, 2, 23, "Input"],
Cell[976970, 31574, 249, 7, 18, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[977256, 31586, 158, 5, 48, "Input"],
Cell[977417, 31593, 1127, 21, 165, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

