(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    506784,      17531]*)
(*NotebookOutlinePosition[    509129,      17602]*)
(*  CellTagsIndexPosition[    509038,      17596]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part IV. Linear Differential Equations", "Section"],
  "\n",
  StyleBox["Section 3. Two Dimensional Systems", "Subsection"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["A second order differential equation in normal form ", "Text"],

Cell[TextData[{
  StyleBox["y''",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y' ",
    FontSlant->"Italic"],
  ")"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
can always be converted into an equivalent system of two first \
order equations  \
\>", "Text"],

Cell[TextData[{
  StyleBox["y'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["v           \nv'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "( ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["v ",
    FontSlant->"Italic"],
  ")"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "If the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  " does not depend upon ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", then the second order equation (and the system) is called autonomous. \
More generally, a two dimensional system is a pair of first order \
differential equations of the form "
}], "Text"],

Cell[TextData[{
  StyleBox["x'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "( ",
  StyleBox["x, y, t ",
    FontSlant->"Italic"],
  ")",
  StyleBox["\ny'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["g ",
    FontSlant->"Italic"],
  "( ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["t ",
    FontSlant->"Italic"],
  ")"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "The primes denote differentiation with respect to ",
  StyleBox["t",
    FontSlant->"Italic"],
  ". If neither ",
  StyleBox["f",
    FontSlant->"Italic"],
  " nor ",
  StyleBox["g",
    FontSlant->"Italic"],
  " depend upon ",
  StyleBox["t",
    FontSlant->"Italic"],
  " the system is autonomous. In this section ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is used to analyze the solutions to such systems. By now you are familiar \
with the tools we need: DSolve, NDSolve, PlotVectorField, and ParametricPlot. \
"
}], "Text"],

Cell["<<Graphics`PlotField`", "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "The solution to a two dimensional system is a pair of functions ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "). Solution behavior is analyzed using time series and plots of phase \
plane trajectories of the form ( ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") ) when the system is autonomous. State space trajectories ( ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), ",
  StyleBox["t ",
    FontSlant->"Italic"],
  ") can be used when the system is not. We consider the autonomous case \
first"
}], "Text"],

Cell[TextData[{
  StyleBox["x'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "( ",
  StyleBox["x, y ",
    FontSlant->"Italic"],
  ")",
  StyleBox["\ny'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["g ",
    FontSlant->"Italic"],
  "( ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y ",
    FontSlant->"Italic"],
  ")"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["See Ledder, Chapter 5, Section 3. ", "Text"],

Cell[TextData[StyleBox["Fields and flows ", "Subsubsection"]], "Text"],

Cell["\<\
Either DSolve (or NSSolve) will output time series for a two \
dimensional system. Trajectories can be obtained using the phi function (or \
Table) with ParametricPlot. If the system is autonomous PlotVectorField will \
also draw a direction field. Consider the following example derived from the  \
Lotka-Volterra predator prey model (Ledder, page 306, Example 2). \
\>", \
"Text"],

Cell[CellGroupData[{

Cell["\<\
DEsystem = {x'[t] == x[t]*(1 - y[t]),
            y'[t] == y[t]*(x[t] - 1)}\
\>", "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(x[t]\ \((1 - y[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\((\(-1\) + x[t])\)\ y[t]\)}]}], "}"}]], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell[TextData[{
  "This is a non-linear system and exact solution formulas are very hard to \
obtain. ",
  StyleBox["Mathematica'",
    FontSlant->"Italic"],
  "s DSolve function is unable to obtain solutions for the initial conditions \
",
  StyleBox["x",
    FontSlant->"Italic"],
  "(0) = 0.4 and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 0.4.."
}], "Text"],

Cell[CellGroupData[{

Cell["DSolve[ {DEsystem, x[0]==0.4, y[0]==0.4}, {x, y}, t ]", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{\(InverseFunction::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse \
functions are being used. Values may be lost for multivalued inverses. \\!\\(\
\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"InverseFunction::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[3]:="],

Cell[BoxData[
    RowBox[{\(Solve::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse functions are \
being used by \\!\\(Solve\\), so some solutions may not be found; use Reduce \
for complete solution information. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[3]:="],

Cell[BoxData[
    RowBox[{\(Solve::"tdep"\), \(\(:\)\(\ \)\), "\<\"The equations appear to \
involve the variables to be solved for in an essentially non-algebraic way. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::tdep\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[3]:="],

Cell[BoxData[
    RowBox[{\(Solve::"tdep"\), \(\(:\)\(\ \)\), "\<\"The equations appear to \
involve the variables to be solved for in an essentially non-algebraic way. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::tdep\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[3]:="],

Cell[BoxData[
    \($Aborted\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[TextData[{
  "We turn to NDSolve, requesting a numerical solution for the interval from \
",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0 to ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 20.. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
soln = NDSolve[ {DEsystem,x[0]==0.4,y[0]==0.4}, {x, y}, {t,0,20} \
]\
\>", "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"x", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 20.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"y", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 20.`}}, "<>"]\),
              False,
              Editable->False]}]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "The following plot displays the time series, ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "). We get fancy with informative axes labels."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ Evaluate[{x[t],y[t]}/.soln], {t,0,20}, AspectRatio->1/4,
      PlotStyle->{{RGBColor[1,0,0]},{RGBColor[0,0,1]}},
      AxesLabel->{\"Time (years)\",\"x (red) y (blue)\"} ]\
\>", "Input",
  CellLabel->"In[5]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.00595238 0.0922633 [
[.2619 -0.00655 -3 -9 ]
[.2619 -0.00655 3 0 ]
[.5 -0.00655 -6 -9 ]
[.5 -0.00655 6 0 ]
[.7381 -0.00655 -6 -9 ]
[.7381 -0.00655 6 0 ]
[.97619 -0.00655 -6 -9 ]
[.97619 -0.00655 6 0 ]
[1.025 .00595 0 -6 ]
[1.025 .00595 76 6 ]
[.01131 .05208 -18 -4.5 ]
[.01131 .05208 0 4.5 ]
[.01131 .09822 -6 -4.5 ]
[.01131 .09822 0 4.5 ]
[.01131 .14435 -18 -4.5 ]
[.01131 .14435 0 4.5 ]
[.01131 .19048 -6 -4.5 ]
[.01131 .19048 0 4.5 ]
[.01131 .23661 -18 -4.5 ]
[.01131 .23661 0 4.5 ]
[.02381 .275 -50 0 ]
[.02381 .275 50 12 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .00595 m
.2619 .0122 L
s
[(5)] .2619 -0.00655 0 1 Mshowa
.5 .00595 m
.5 .0122 L
s
[(10)] .5 -0.00655 0 1 Mshowa
.7381 .00595 m
.7381 .0122 L
s
[(15)] .7381 -0.00655 0 1 Mshowa
.97619 .00595 m
.97619 .0122 L
s
[(20)] .97619 -0.00655 0 1 Mshowa
.125 Mabswid
.07143 .00595 m
.07143 .0097 L
s
.11905 .00595 m
.11905 .0097 L
s
.16667 .00595 m
.16667 .0097 L
s
.21429 .00595 m
.21429 .0097 L
s
.30952 .00595 m
.30952 .0097 L
s
.35714 .00595 m
.35714 .0097 L
s
.40476 .00595 m
.40476 .0097 L
s
.45238 .00595 m
.45238 .0097 L
s
.54762 .00595 m
.54762 .0097 L
s
.59524 .00595 m
.59524 .0097 L
s
.64286 .00595 m
.64286 .0097 L
s
.69048 .00595 m
.69048 .0097 L
s
.78571 .00595 m
.78571 .0097 L
s
.83333 .00595 m
.83333 .0097 L
s
.88095 .00595 m
.88095 .0097 L
s
.92857 .00595 m
.92857 .0097 L
s
.25 Mabswid
0 .00595 m
1 .00595 L
s
gsave
1.025 .00595 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(H) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(years) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
129.000 13.000 moveto
(L) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05208 m
.03006 .05208 L
s
[(0.5)] .01131 .05208 1 0 Mshowa
.02381 .09822 m
.03006 .09822 L
s
[(1)] .01131 .09822 1 0 Mshowa
.02381 .14435 m
.03006 .14435 L
s
[(1.5)] .01131 .14435 1 0 Mshowa
.02381 .19048 m
.03006 .19048 L
s
[(2)] .01131 .19048 1 0 Mshowa
.02381 .23661 m
.03006 .23661 L
s
[(2.5)] .01131 .23661 1 0 Mshowa
.125 Mabswid
.02381 .01518 m
.02756 .01518 L
s
.02381 .02441 m
.02756 .02441 L
s
.02381 .03363 m
.02756 .03363 L
s
.02381 .04286 m
.02756 .04286 L
s
.02381 .06131 m
.02756 .06131 L
s
.02381 .07054 m
.02756 .07054 L
s
.02381 .07976 m
.02756 .07976 L
s
.02381 .08899 m
.02756 .08899 L
s
.02381 .10744 m
.02756 .10744 L
s
.02381 .11667 m
.02756 .11667 L
s
.02381 .12589 m
.02756 .12589 L
s
.02381 .13512 m
.02756 .13512 L
s
.02381 .15357 m
.02756 .15357 L
s
.02381 .1628 m
.02756 .1628 L
s
.02381 .17203 m
.02756 .17203 L
s
.02381 .18125 m
.02756 .18125 L
s
.02381 .19971 m
.02756 .19971 L
s
.02381 .20893 m
.02756 .20893 L
s
.02381 .21816 m
.02756 .21816 L
s
.02381 .22738 m
.02756 .22738 L
s
.02381 .24584 m
.02756 .24584 L
s
.25 Mabswid
.02381 0 m
.02381 .25 L
s
gsave
.02381 .275 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(red) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(L) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(H) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(blue) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
153.000 13.000 moveto
(L) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .04286 m
.03279 .04744 L
.04262 .0535 L
.06244 .06972 L
.07298 .08099 L
.08426 .09549 L
.10458 .12895 L
.12445 .17097 L
.13492 .19544 L
.14603 .22023 L
.15079 .22935 L
.15591 .23729 L
.15741 .23913 L
.15884 .24065 L
.16023 .24188 L
.16152 .24279 L
.16274 .24343 L
.16404 .24387 L
.16478 .244 L
.16548 .24405 L
.16679 .24391 L
.1679 .24356 L
.16912 .24293 L
.17039 .24197 L
.17158 .24081 L
.17371 .23805 L
.17599 .23412 L
.1812 .22147 L
.18596 .20596 L
.19599 .16545 L
.20665 .12196 L
.21575 .09191 L
.22099 .07835 L
.2258 .06816 L
.23531 .05322 L
.24031 .04757 L
.24557 .04287 L
.25443 .03714 L
.25946 .03482 L
.26413 .03312 L
.26918 .03171 L
.27184 .03112 L
.27465 .03059 L
.27711 .0302 L
.27982 .02985 L
.28231 .0296 L
.28459 .02942 L
.28572 .02934 L
.28696 .02928 L
.28815 .02922 L
Mistroke
.28922 .02919 L
.29047 .02916 L
.29115 .02915 L
.2918 .02914 L
.29295 .02913 L
.29419 .02914 L
.29528 .02915 L
.29647 .02918 L
.29771 .02922 L
.29887 .02926 L
.30095 .02937 L
.30318 .02951 L
.30848 .03 L
.31338 .03061 L
.31875 .03147 L
.32446 .03258 L
.33403 .03497 L
.34459 .0384 L
.36397 .04726 L
.37487 .054 L
.38484 .06153 L
.40381 .08019 L
.42452 .10868 L
.44417 .14502 L
.46513 .19238 L
.4754 .21574 L
.48081 .22664 L
.48376 .23185 L
.48652 .23607 L
.48914 .23937 L
.49152 .2417 L
.49288 .24269 L
.49417 .24339 L
.49488 .24367 L
.49553 .24387 L
.49625 .244 L
.49702 .24405 L
.49816 .24394 L
.49939 .24357 L
.50055 .24298 L
.50161 .24222 L
.50279 .24114 L
.50408 .23964 L
.50668 .23566 L
.50921 .23053 L
.51196 .22363 L
.51694 .20784 L
.52627 .1707 L
.53624 .12932 L
.54153 .10992 L
Mistroke
.54721 .09207 L
.55257 .07822 L
.55746 .06787 L
.56706 .05292 L
.57222 .04717 L
.57785 .04227 L
.58317 .03868 L
.5881 .03607 L
.59318 .03397 L
.59868 .03223 L
.60386 .03101 L
.60864 .0302 L
.61295 .02968 L
.6154 .02947 L
.61769 .02932 L
.61893 .02925 L
.6201 .02921 L
.62116 .02918 L
.6223 .02915 L
.62355 .02914 L
.62418 .02913 L
.62487 .02913 L
.6261 .02914 L
.62725 .02916 L
.62843 .02919 L
.62968 .02923 L
.63195 .02934 L
.63464 .02951 L
.63709 .02971 L
.64242 .03028 L
.64745 .03099 L
.65633 .03266 L
.66596 .03509 L
.67543 .03816 L
.68585 .0424 L
.69685 .04803 L
.70689 .05436 L
.72636 .07059 L
.73708 .08225 L
.74725 .09544 L
.76711 .12802 L
.78552 .16649 L
.80437 .21016 L
.80953 .2212 L
.81498 .23136 L
.81963 .23817 L
.8209 .23965 L
.82226 .24102 L
.82346 .24203 L
.82472 .24289 L
Mistroke
.82541 .24326 L
.82616 .24359 L
.82685 .24381 L
.82749 .24396 L
.82825 .24404 L
.82894 .24403 L
.82974 .24393 L
.8305 .24372 L
.83115 .24347 L
.83185 .24311 L
.83311 .24224 L
.8346 .24082 L
.83596 .23916 L
.83849 .23513 L
.84123 .22938 L
.84619 .2155 L
.8567 .17529 L
.86638 .13476 L
.87545 .10194 L
.88519 .07569 L
.89078 .06457 L
.89587 .05651 L
.90071 .05038 L
.90585 .04518 L
.91056 .04139 L
.91576 .03806 L
.92054 .03565 L
.92493 .03388 L
.93008 .03226 L
.93563 .03096 L
.94053 .03015 L
.94299 .02984 L
.94568 .02957 L
.94759 .02942 L
.94966 .02929 L
.9506 .02925 L
.95161 .02921 L
.95248 .02918 L
.95341 .02916 L
.95431 .02914 L
.95514 .02914 L
.95596 .02913 L
.95675 .02913 L
.95767 .02914 L
.95851 .02916 L
.95944 .02918 L
.96043 .02921 L
.96248 .02929 L
.96469 .02941 L
.9687 .02972 L
Mistroke
.9726 .03012 L
.97619 .03058 L
Mfstroke
0 0 1 r
.02381 .04286 m
.03279 .03906 L
.04262 .0357 L
.05288 .03298 L
.06244 .03111 L
.06792 .03032 L
.07062 .03 L
.0731 .02975 L
.07532 .02956 L
.07775 .02939 L
.0802 .02927 L
.08155 .02921 L
.0828 .02918 L
.0835 .02916 L
.08415 .02915 L
.08485 .02914 L
.08561 .02913 L
.08633 .02913 L
.08701 .02914 L
.08828 .02915 L
.08954 .02918 L
.09069 .02921 L
.09196 .02927 L
.09329 .02934 L
.09608 .02953 L
.09867 .02978 L
.10152 .03013 L
.10458 .0306 L
.10986 .03169 L
.11475 .03305 L
.12012 .035 L
.12582 .03774 L
.13075 .04079 L
.13538 .04437 L
.14046 .04929 L
.14594 .05603 L
.15551 .07253 L
.16094 .08526 L
.16598 .09966 L
.18708 .18208 L
.19213 .20212 L
.1976 .22053 L
.20011 .22739 L
.20277 .2334 L
.20504 .23747 L
.20632 .23932 L
.20754 .2408 L
.2087 .24194 L
.20996 .24289 L
.2111 .24351 L
Mistroke
.21217 .24387 L
.21343 .24404 L
.21458 .24397 L
.2159 .24363 L
.21714 .24306 L
.21824 .24237 L
.21939 .24147 L
.22146 .23943 L
.22613 .23308 L
.23563 .21491 L
.2458 .1917 L
.26415 .14992 L
.284 .11216 L
.29446 .09607 L
.30556 .08168 L
.31543 .07096 L
.3263 .06112 L
.34546 .04794 L
.35558 .04274 L
.36485 .03885 L
.37566 .03524 L
.38572 .03269 L
.39489 .03097 L
.40002 .03025 L
.40468 .02975 L
.40734 .02952 L
.4098 .02936 L
.41119 .02929 L
.41249 .02923 L
.41385 .02919 L
.41457 .02917 L
.41534 .02915 L
.41663 .02914 L
.41736 .02913 L
.41804 .02913 L
.41928 .02914 L
.4206 .02917 L
.42177 .0292 L
.42288 .02924 L
.42539 .02937 L
.42782 .02955 L
.43008 .02977 L
.43276 .03009 L
.43521 .03046 L
.44021 .03142 L
.44555 .03282 L
.45011 .03439 L
.45506 .03655 L
.46405 .04207 L
.46893 .0462 L
Mistroke
.4735 .05099 L
.47893 .05815 L
.4839 .06638 L
.49404 .08951 L
.49962 .10651 L
.50493 .12551 L
.51526 .16802 L
.52498 .207 L
.52923 .22085 L
.53371 .23221 L
.53605 .23665 L
.5373 .23858 L
.53863 .24031 L
.53985 .24161 L
.54096 .24254 L
.54209 .24325 L
.54315 .24371 L
.54428 .24399 L
.54552 .24404 L
.54683 .24381 L
.54805 .24337 L
.54919 .24275 L
.55023 .24202 L
.55258 .23986 L
.55497 .23699 L
.55758 .23318 L
.56283 .22381 L
.58381 .17648 L
.60508 .13083 L
.62439 .09834 L
.64449 .07345 L
.66346 .05673 L
.67319 .05018 L
.68349 .04447 L
.70194 .03687 L
.71139 .03408 L
.7166 .03283 L
.72153 .03181 L
.72612 .03101 L
.73111 .0303 L
.73565 .0298 L
.73985 .02945 L
.74115 .02937 L
.74251 .0293 L
.74369 .02925 L
.74495 .0292 L
.74566 .02918 L
.74631 .02916 L
.74758 .02914 L
.74829 .02914 L
Mistroke
.74906 .02913 L
.74979 .02913 L
.75046 .02914 L
.75165 .02916 L
.75276 .02918 L
.75398 .02922 L
.7553 .02928 L
.75798 .02944 L
.76043 .02965 L
.76499 .03019 L
.76758 .0306 L
.76998 .03105 L
.77437 .03206 L
.77905 .03346 L
.78441 .03554 L
.78933 .03801 L
.79474 .04147 L
.80046 .04621 L
.80543 .05148 L
.81007 .0576 L
.81512 .06585 L
.82062 .0771 L
.83107 .10628 L
.84097 .14351 L
.85053 .18385 L
.85952 .21715 L
.86404 .22956 L
.86658 .23491 L
.86891 .23873 L
.87008 .24024 L
.87133 .24157 L
.87269 .2427 L
.87396 .24343 L
.87465 .24371 L
.8754 .24392 L
.8761 .24402 L
.87675 .24405 L
.87798 .2439 L
.87928 .24349 L
.88059 .24282 L
.88177 .242 L
.88445 .23947 L
.88693 .23638 L
.88929 .23287 L
.90029 .21134 L
.9188 .16845 L
.93852 .12718 L
.95829 .09495 L
.97619 .07326 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{436, 109},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006d0000KB000`400?l00000o`00003ooooooone
ooooo`00ooooooneooooo`00NOooool3o`0004?ooooo0ol00004ooooo`;o0000@Oooool3o`0000?o
oooo0ol0000oooooo`Go00000oooool2o`0005Wooooo001hooooo`05o`000?ooooooooooooooool0
0000@oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00047ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo03gooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0001Hooooo`00O?ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000@Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001Hooooo`00
O?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000@Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo05Kooooo001hooooo`Co0000A?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`00047ooooo00Co0000oooooooooooooooo1?l0000o
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001Hooooo`00N?oo
ool00ol0003oooooooooo`14ooooo`;o00001?ooool01?l0003oooooooooool00010ooooo`;o0000
0oooool00ol0003oooooooooo`10ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0001Hooooo`00N?ooool5o`0004?ooooo00?o0000ooooooooool00oooool2o`0004;o
oooo00Co0000oooooooooooooooo1Ol0000oooooo`?o00001?ooool2o`0005Wooooo003oooooohco
oooo00?o0000ooooool000000_l0000Looooo`03o`000?oooooooooo00Gooooo003ooooooh_ooooo
00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00Cooooo003oooooof_ooooo
0ol00002ooooo`Go000000Koooooo`000?oooooo0000ooooool00002ooooo`?o00002_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Co000000Coooooo`00
0?l0003o00000oooool4o`0000Gooooo00?o0000ooooooooool00oooool003;ooooo00?o0000oooo
ooooool0oooooolgooooo`03o`000?oooooooooo00?ooooo00_o0000ooooooooooooooooo`000?oo
oooo0000ooooool0003oooooo`00000=ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo000Zoooooooo0000=ol0000;oooo
o`03o`000?oooooooooo00?ooooo00[o0000ooooooooooooooooo`000?oooooo0000ooooool0003o
oooo1Ol00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool5o`0000;o
oooo0ol00003ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`03o`000?oooooooooo00?o
oooo000booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo00_o0000ooooooooooooooooo`000?oooooo0000
ooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`04
o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo000booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0?ooooo`06o`000?oooooo0000ooooool0003ooooo0ol00003ooooo`;o000000?ooooo
o`000?ooool00_ooool3o`0000_ooooo00?o0000ooooooooool00_l000000ooooooo0000o`000002
ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Co00000oooool0
0ol0003oooooooooo`04ooooo`00<_ooool2o`000?oooooo=_ooool01Ol0003oooooo`000?oooooo
000001gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`00<_ooool00ol0
003oooooooooo`3oooooocGooooo1Ol00003ooooo`03o`000?oooooooooo043ooooo000booooo`03
o`000?oooooooooo0?ooooooP?ooool003;ooooo0_l0003ooooooh7ooooo000booooo`03o`000?oo
oooooooo0?ooooooP?ooool003;ooooo00?o0000ooooooooool01ooooolBo`00oboooooo4Ooo000E
oooooa7o003o<?oooolAool001?ooooo4ol00?l_ooooo`koo`00G?ooool003;ooooo0_l00005oooo
o`?o003o4_ooool3o`00obWooooo0ooo000Aooooo`Koo`002Oooool6o`00oa7ooooo0ol00?lZoooo
o`?oo`004Oooool6ool000[ooooo0ol00?lCooooo`03o`00oooooooooooo02Wooooo0ooo001Zoooo
o`00<_ooool01?l0003oooooooooooooool3o`00oaSooooo0_l00?lUooooo`;oo`006_ooool3ool0
00Gooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Uooooo`;oo`006_ooool2ool0
00Gooooo0ol00?lGooooo`?o003o9Oooool3ool006gooooo000booooo`04o`000?l00?oo003oo`00
oagooooo00?o003oooooooooool08Oooool00ooo003oooooooooo`0Mooooo`;oo`0000?oooooo`00
ool00?l07?ooool00ol00?ooooooooooo`0Rooooo`;oo`007_ooool00ooo003oooooo`00o`02o`00
oagooooo00?o003oooooooooool08Oooool00ooo003oooooooooo`1^ooooo`007_ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o003oool00?ooool07oooool00ol00?oo
ooooooooo`0Nooooo`;oo`008?ooool3o`00oaoooooo0_l00?lQooooo`03ool00?oooooooooo01go
oooo0ol00?l2ool001oooooo00?o003oooooooooool08?ooool00ooo003oooooooooo`1^ooooo`00
7Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooool00?oo000Oooooo`03o`00oooooooooooo01cooooo00?oo`00ooooooooool07Oooool3
o`00o`?ooooo0_oo000Oooooo`03o`00oooooooooooo01gooooo00?oo`00ooooooooool07Oooool0
0ol00?ooooooooooo`03ooooo`;oo`007_ooool2o`00oakooooo0_oo001aooooo`007Oooool01?l0
003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooool0
000Oooooo`03o`00oooooooooooo01_ooooo00?oo`00ooooooooool07?ooool00ol00?oooooooooo
o`06ooooo`;oo`007_ooool00ol00?ooooooooooo`0Kooooo`03ool00?oooooooooo01cooooo0_l0
0?l8ooooo`03ool00?oooooooooo01gooooo00?o003oooooooooool06_ooool00ooo003ooooooooo
o`1aooooo`007Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo0_l0
0003ooooo`;oo`007Oooool00ol00?ooooooooooo`0Jooooo`03ool00?oooooooooo01_ooooo0_l0
0?l;ooooo`03ool00?oooooooooo01_ooooo00?o003oooooooooool06_ooool00ooo003ooooooooo
o`0Looooo`03o`00oooooooooooo00Wooooo0_oo000Mooooo`03o`00oooooooooooo01[ooooo00?o
o`00ooooooooool0LOooool001gooooo00Co0000oooooooooooo00001oooool4o`0000Kooooo00?o
0000ooooooooool01?ooool00ooo003oooooooooo`0Kooooo`03o`00oooooooooooo01Wooooo00?o
o`00ooooooooool06_ooool00ol00?ooooooooooo`0<ooooo`03ool00?oooooooooo01_ooooo00?o
003oooooooooool06Oooool00ooo003oooooooooo`0Jooooo`;o003o3_ooool00ooo003ooooooooo
o`0Kooooo`03o`00oooooooooooo01Sooooo00?oo`00ooooooooool0L_ooool001gooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`07ooooo`;o00001_ooool00ooo003ooooooooo
o`0Jooooo`03o`00oooooooooooo01Sooooo00?oo`00ooooooooool06_ooool00ol00?oooooooooo
o`0>ooooo`03ool00?oooooooooo01_ooooo00?o003oooooooooool05oooool00ooo003ooooooooo
o`0Jooooo`03o`00oooooooooooo00oooooo00?oo`00ooooooooool06_ooool00ol00?oooooooooo
o`0Hooooo`03ool00?oooooooooo07;ooooo000Nooooo`;o00002?ooool5o`0000Gooooo00?o0000
ooooooooool01_ooool00ooo003oooooooooo`0Jooooo`03o`00oooooooooooo01Kooooo00?oo`00
ooooooooool06_ooool00ol00?ooooooooooo`0@ooooo`;oo`007?ooool00ol00?ooooooooooo`0E
ooooo`03ool00?oooooooooo01[ooooo00?o003oooooooooool04Oooool00ooo003oooooooooo`0J
ooooo`03o`00oooooooooooo01Kooooo00?oo`00ooooooooool0Loooool003;ooooo00?o0000oooo
ooooool01oooool00ooo003oooooooooo`0Jooooo`03o`00oooooooooooo01Gooooo00?oo`00oooo
ooooool06Oooool00ol00?ooooooooooo`0Cooooo`03ool00?oooooooooo01[ooooo00?o003ooooo
ooooool05?ooool00ooo003oooooooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?oo`00oooo
ooooool06_ooool00ol00?ooooooooooo`0Dooooo`03ool00?oooooooooo07Cooooo000booooo`;o
00002Oooool00ooo003oooooooooo`0Iooooo`03o`00oooooooooooo01Cooooo00?oo`00oooooooo
ool06Oooool00ol00?ooooooooooo`0Eooooo`03ool00?oooooooooo01Wooooo00?o003ooooooooo
ool04oooool00ooo003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?oo`00oooooooo
ool06Oooool00ol00?ooooooooooo`0Dooooo`03ool00?oooooooooo07Cooooo000booooo`03o`00
0?oooooooooo00Wooooo00?oo`00ooooooooool06Oooool00ol00?ooooooooooo`0Cooooo`03ool0
0?oooooooooo01Sooooo00?o003oooooooooool05oooool00ooo003oooooooooo`0Iooooo`03o`00
oooooooooooo01;ooooo00?oo`00ooooooooool06?ooool00ol00?ooooooooooo`0Gooooo`03ool0
0?oooooooooo01Wooooo00?o003oooooooooool04_ooool00ooo003oooooooooo`0Hooooo`03o`00
oooooooooooo05[ooooo000booooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool06?oo
ool00ol00?ooooooooooo`0Booooo`03ool00?oooooooooo01Sooooo00?o003oooooooooool06Ooo
ool00ooo003oooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?oo`00ooooooooool06Ooo
ool00ol00?ooooooooooo`0Hooooo`03ool00?oooooooooo01Sooooo00?o003oooooooooool04Ooo
ool00ooo003oooooooooo`0Iooooo`03o`00oooooooooooo05[ooooo000booooo`;o00003?ooool0
0ooo003oooooooooo`0Hooooo`03o`00oooooooooooo013ooooo00?oo`00ooooooooool06?ooool0
0ol00?ooooooooooo`0Kooooo`03ool00?oooooooooo01Sooooo00?o003oooooooooool04?ooool0
0ooo003oooooooooo`0Hooooo`03o`00oooooooooooo01[ooooo00?oo`00ooooooooool05oooool0
0ol00?ooooooooooo`0Aooooo`03ool00?oooooooooo01Sooooo00?o003oooooooooool0Foooool0
03;ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo
013ooooo00?oo`00ooooooooool05oooool00ol00?ooooooooooo`0Looooo`03ool00?oooooooooo
01Sooooo00?o003oooooooooool04?ooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo
01cooooo00?oo`00ooooooooool05oooool00ol00?ooooooooooo`0?ooooo`03ool00?oooooooooo
01Sooooo00?o003oooooooooool0G?ooool003;ooooo00?o0000ooooooooool03?ooool00ooo003o
ooooooooo`0Hooooo`03o`00oooooooooooo00oooooo00?oo`00ooooooooool05oooool00ol00?oo
ooooooooo`0Mooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool03oooool00ooo003o
ooooooooo`0Gooooo`03o`00oooooooooooo01gooooo00?oo`00ooooooooool05oooool00ol00?oo
ooooooooo`0?ooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool0GOooool002Wooooo
0ol00006ooooo`;o00003_ooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo00kooooo
00?oo`00ooooooooool05oooool00ol00?ooooooooooo`0Oooooo`03ool00?oooooooooo01Oooooo
00?o003oooooooooool03_ooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo01kooooo
00?oo`00ooooooooool05oooool00ol00?ooooooooooo`0>ooooo`03ool00?oooooooooo01Oooooo
00?o003oooooooooool0GOooool002[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0>ooooo`03ool00?oooooooooo01Kooooo00?o003oooooooooool03_ooool00ooo003ooooooooo
o`0Fooooo`03o`00oooooooooooo023ooooo00?oo`00ooooooooool05oooool00ol00?oooooooooo
o`0=ooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool08?ooool00ooo003ooooooooo
o`0Fooooo`03o`00oooooooooooo00gooooo00?oo`00ooooooooool05oooool00ol00?oooooooooo
o`1Nooooo`00:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?oo`00
ooooooooool05_ooool00ol00?ooooooooooo`0=ooooo`03ool00?oooooooooo01Gooooo00?o003o
ooooooooool08_ooool00ooo003oooooooooo`0Fooooo`03o`00oooooooooooo00gooooo00?oo`00
ooooooooool05_ooool00ol00?ooooooooooo`0Rooooo`03ool00?oooooooooo01Gooooo00?o003o
ooooooooool03Oooool00ooo003oooooooooo`0Fooooo`03o`00oooooooooooo05oooooo000Zoooo
o`03o`000?oooooooooo00Gooooo0_l0000@ooooo`03ool00?oooooooooo01Kooooo00?o003ooooo
ooooool03?ooool00ooo003oooooooooo`0Fooooo`03o`00oooooooooooo02?ooooo00?oo`00oooo
ooooool05_ooool00ol00?ooooooooooo`0;ooooo`03ool00?oooooooooo01Kooooo00?o003ooooo
ooooool08oooool00ooo003oooooooooo`0Fooooo`03o`00oooooooooooo00cooooo00?oo`00oooo
ooooool05_ooool00ol00?ooooooooooo`1Oooooo`00:_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo013ooooo00?oo`00ooooooooool05Oooool00ol00?ooooooooooo`0<ooooo`03
ool00?oooooooooo01Gooooo00?o003oooooooooool09?ooool00ooo003oooooooooo`0Fooooo`03
o`00oooooooooooo00_ooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`0Tooooo`03
ool00?oooooooooo01Gooooo00?o003oooooooooool02oooool00ooo003oooooooooo`0Fooooo`03
o`00oooooooooooo063ooooo000Yooooo`;o00001oooool00ol0003oooooooooo`0Aooooo`03ool0
0?oooooooooo01Cooooo00?o003oooooooooool03?ooool00ooo003oooooooooo`0Dooooo`03o`00
oooooooooooo02Kooooo00?oo`00ooooooooool05Oooool00ol00?ooooooooooo`0;ooooo`03ool0
0?oooooooooo01Gooooo00?o003oooooooooool09_ooool00ooo003oooooooooo`0Eooooo`03o`00
oooooooooooo00[ooooo00?oo`00ooooooooool05Oooool00ol00?ooooooooooo`1Qooooo`00:_oo
ool00ol0003oooooooooo`05ooooo`;o00004_ooool00ooo003oooooooooo`0Eooooo`03o`00oooo
oooooooo00[ooooo00?oo`00ooooooooool05Oooool00ol00?ooooooooooo`0Wooooo`03ool00?oo
oooooooo01Cooooo00?o003oooooooooool02_ooool00ooo003oooooooooo`0Eooooo`03o`00oooo
oooooooo02Oooooo00?oo`00ooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03ool00?oo
oooooooo01Gooooo00?o003oooooooooool0HOooool003;ooooo00?o0000ooooooooool04_ooool0
0ooo003oooooooooo`0Dooooo`03o`00oooooooooooo00[ooooo00?oo`00ooooooooool05?ooool0
0ol00?ooooooooooo`0Xooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool02Oooool0
0ooo003oooooooooo`0Eooooo`03o`00oooooooooooo02Sooooo00?oo`00ooooooooool05?ooool0
0ol00?ooooooooooo`09ooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool0H_ooool0
03;ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo
00[ooooo00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`0Yooooo`03ool00?oooooooooo
01Cooooo00?o003oooooooooool02Oooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo
02Wooooo00?oo`00ooooooooool05Oooool00ol00?ooooooooooo`08ooooo`03ool00?oooooooooo
01Gooooo00?o003oooooooooool0H_ooool003;ooooo0_l0000Dooooo`03ool00?oooooooooo01?o
oooo00?o003oooooooooool02Oooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo02[o
oooo00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`09ooooo`03ool00?oooooooooo01Co
oooo00?o003oooooooooool0:_ooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo00So
oooo00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`1Sooooo`00<_ooool00ol0003ooooo
ooooo`0Dooooo`03ool00?oooooooooo01?ooooo00?o003oooooooooool02?ooool00ooo003ooooo
ooooo`0Dooooo`03o`00oooooooooooo02_ooooo00?oo`00ooooooooool05?ooool00ol00?oooooo
ooooo`07ooooo`03ool00?oooooooooo01Cooooo00?o003oooooooooool0;?ooool00ooo003ooooo
ooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?oo`00ooooooooool04oooool00ol00?oooooo
ooooo`1Tooooo`00<_ooool2o`0001Gooooo00?oo`00ooooooooool04oooool00ol00?oooooooooo
o`08ooooo`03ool00?oooooooooo01?ooooo00?o003oooooooooool0;?ooool00ooo003ooooooooo
o`0Dooooo`03o`00oooooooooooo00Oooooo00?oo`00ooooooooool04oooool00ol00?oooooooooo
o`0]ooooo`03ool00?oooooooooo01?ooooo00?o003oooooooooool02?ooool00ooo003ooooooooo
o`0Cooooo`03o`00oooooooooooo06Cooooo000booooo`03o`000?oooooooooo01Gooooo00?oo`00
ooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03ool00?oooooooooo01?ooooo00?o003o
ooooooooool0;Oooool00ooo003oooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?oo`00
ooooooooool04oooool00ol00?ooooooooooo`0^ooooo`03ool00?oooooooooo01?ooooo00?o003o
ooooooooool01_ooool00ooo003oooooooooo`0Cooooo`03o`00oooooooooooo06Gooooo000boooo
o`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`06oooo
o`03ool00?oooooooooo01?ooooo00?o003oooooooooool0;oooool00ooo003oooooooooo`0Boooo
o`03o`00oooooooooooo00Oooooo00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`0_oooo
o`03ool00?oooooooooo01?ooooo00?o003oooooooooool01_ooool00ooo003oooooooooo`0Coooo
o`03o`00oooooooooooo06Gooooo000booooo`;o00005oooool00ooo003oooooooooo`0Booooo`03
o`00oooooooooooo00Kooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`0_ooooo`03
ool00?oooooooooo01?ooooo00?o003oooooooooool01_ooool00ooo003oooooooooo`0Booooo`03
o`00oooooooooooo033ooooo00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`06ooooo`03
ool00?oooooooooo01;ooooo00?o003oooooooooool0I_ooool001gooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00006ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0
4_ooool00ol00?ooooooooooo`06ooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0
<Oooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?oo`00ooooooooool0
4_ooool00ol00?ooooooooooo`0aooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0
1_ooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo06Kooooo000Nooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Oooooo
00?oo`00ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03ool00?oooooooooo01;ooooo
00?o003oooooooooool0<Oooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo00Gooooo
00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`0booooo`03ool00?oooooooooo01;ooooo
00?o003oooooooooool01Oooool00ooo003oooooooooo`0Aooooo`03o`00oooooooooooo06Oooooo
000Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2o`0001Sooooo00?o
o`00ooooooooool04_ooool00ol00?ooooooooooo`05ooooo`03ool00?oooooooooo017ooooo00?o
003oooooooooool0<oooool00ooo003oooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o
o`00ooooooooool04Oooool00ol00?ooooooooooo`0cooooo`03ool00?oooooooooo01;ooooo00?o
003oooooooooool01?ooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo06Oooooo000N
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0H
ooooo`03ool00?oooooooooo017ooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`0B
ooooo`03o`00oooooooooooo03?ooooo00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`04
ooooo`03ool00?oooooooooo017ooooo00?o003oooooooooool0=?ooool00ooo003oooooooooo`0A
ooooo`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ol00?ooooooooooo`1X
ooooo`007_ooool00ol0003oooooooooo`07ooooo`Co00001_ooool00ol0003oooooooooo`0Ioooo
o`03ool00?oooooooooo013ooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`0Aoooo
o`03o`00oooooooooooo03Gooooo00?oo`00ooooooooool04Oooool00ol00?ooooooooooo`03oooo
o`03ool00?oooooooooo017ooooo00?o003oooooooooool0=Oooool00ooo003oooooooooo`0Aoooo
o`03o`00oooooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ol00?ooooooooooo`1Xoooo
o`007Oooool2o`0000Wooooo00?o0000ooooooooool01oooool2o`0001[ooooo00?oo`00oooooooo
ool04?ooool00ol00?ooooooooooo`04ooooo`03ool00?oooooooooo017ooooo00?o003ooooooooo
ool0=Oooool00ooo003oooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?oo`00oooooooo
ool04Oooool00ol00?ooooooooooo`0fooooo`03ool00?oooooooooo017ooooo00?o003ooooooooo
ool00oooool00ooo003oooooooooo`0Aooooo`03o`00oooooooooooo06Sooooo000Nooooo`03o`00
0?oooooooooo00Oooooo1Ol00005ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0
4?ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?o003oooooooooool0
=oooool00ooo003oooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool0
4?ooool00ol00?ooooooooooo`0gooooo`03ool00?oooooooooo017ooooo00?o003oooooooooool0
0_ooool00ooo003oooooooooo`0Aooooo`03o`00oooooooooooo06Wooooo000booooo`03o`000?oo
oooooooo01[ooooo00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03ool00?oo
oooooooo013ooooo00?o003oooooooooool0=oooool00ooo003oooooooooo`0@ooooo`03o`00oooo
oooooooo00?ooooo00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`0hooooo`03ool00?oo
oooooooo013ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03o`00oooo
oooooooo06Wooooo000booooo`;o00007?ooool00ooo003oooooooooo`0?ooooo`03o`00oooooooo
oooo00;ooooo00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`0iooooo`03ool00?oooooo
oooo013ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`0?ooooo`03o`00oooooooo
oooo03Wooooo00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03ool00?oooooo
oooo013ooooo00?o003oooooooooool0J_ooool003;ooooo00?o0000ooooooooool06oooool00ooo
003oooooooooo`0@ooooo`05o`00oooooooooooooooooooo00004_ooool00ol00?ooooooooooo`0i
ooooo`03ool00?oooooooooo013ooooo00Go003oooooooooooooooooool0000Booooo`03o`00oooo
oooooooo03[ooooo00?oo`00ooooooooool04?ooool01Ol00?ooooooooooooooooooo`0001;ooooo
00?o003oooooooooool0J_ooool003;ooooo00?o0000ooooooooool07?ooool00ooo003ooooooooo
o`0?ooooo`05o`00oooooooooooooooooooo00004Oooool00ol00?ooooooooooo`0kooooo`03ool0
0?oooooooooo00oooooo00Go003oooooooooooooooooool0000Aooooo`03o`00oooooooooooo03_o
oooo00?oo`00ooooooooool04?ooool01Ol00?ooooooooooooooooooo`00017ooooo00?o003ooooo
ooooool0Joooool003;ooooo0_l0000Mooooo`03ool00?oooooooooo00oooooo00Go003ooooooooo
ooooooooool0000Aooooo`03o`00oooooooooooo03_ooooo00?oo`00ooooooooool03oooool01Ol0
0?ooooooooooooooooooo`00017ooooo00?o003oooooooooool0??ooool00ooo003oooooooooo`0?
ooooo`04o`00ooooooooooooool001;ooooo00?o003oooooooooool0Joooool003;ooooo00?o0000
ooooooooool07Oooool00ooo003oooooooooo`0>ooooo`04o`00ooooooooooooool001;ooooo00?o
003oooooooooool0>oooool00ooo003oooooooooo`0@ooooo`04o`00ooooooooooooool0013ooooo
00?o003oooooooooool0?Oooool00ooo003oooooooooo`0?ooooo`04o`00ooooooooooooool0017o
oooo00?o003oooooooooool0K?ooool003;ooooo00?o0000ooooooooool07Oooool00ooo003ooooo
ooooo`0?ooooo`03o`00ooooooooo`00017ooooo00?o003oooooooooool0?Oooool00ooo003ooooo
ooooo`0?ooooo`03o`00ooooooooo`00017ooooo00?o003oooooooooool0?Oooool00ooo003ooooo
ooooo`0@ooooo`03o`00ooooooooo`00017ooooo00?o003oooooooooool0K?ooool002Sooooo1Ol0
0005ooooo`;o00007_ooool00ooo003oooooooooo`0?ooooo`03o`00ooooooooo`00017ooooo00?o
003oooooooooool0?Oooool00ooo003oooooooooo`0?ooooo`03o`00ooooooooo`00013ooooo00?o
003oooooooooool0?oooool00ooo003oooooooooo`0?ooooo`03o`00oooo003ooooo013ooooo00?o
003oooooooooool0KOooool002Wooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`0Nooooo`03ool00?oooooooooo00kooooo00?o003ooooooooo00004?ooool00ol00?oooooooooo
o`0oooooo`03ool00?oooooooooo00kooooo00?o003ooooooooo00004?ooool00ol00?oooooooooo
o`0oooooo`03ool00?oooooooooo00oooooo00?o003oool00?ooool04?ooool00ol00?oooooooooo
o`1]ooooo`00:_ooool00ol0003oooooooooo`05ooooo`;o00007oooool00ooo003oooooooooo`0>
ooooo`03o`00oooo003ooooo013ooooo00?o003oooooooooool0?oooool00ooo003oooooooooo`0?
ooooo`03o`00oooo003ooooo00oooooo00?o003oooooooooool0@?ooool00ooo003oooooooooo`0>
ooooo`03o`00oooo003ooooo00oooooo00?o003oooooooooool0K_ooool002_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo00kooooo00?o003oool0
0?ooool03oooool00ol00?ooooooooooo`11ooooo`03ool00?oooooooooo00kooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`11ooooo`03ool00?oooooooooo00kooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`1^ooooo`00:?ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0>ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool0@Oooool00ooo003oooooooooo`0>ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool0@Oooool00ooo003oooooooooo`0>ooooo`03ool00?l00?oooooo
00oooooo00?o003oooooooooool0K_ooool002Sooooo00Go0000ooooooooooooooooo`000005oooo
o`;o00008?ooool00ooo003oooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool0@oooool00ooo003oooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool0@oooool00ooo003oooooooooo`0=ooooo`03ool00?l00?oooooo00kooooo00?o003ooooo
ooooool0Koooool002Wooooo0ol00006ooooo`03o`000?oooooooooo023ooooo00?oo`00oooooooo
ool03?ooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo04?ooooo00?oo`00oooooooo
ool03Oooool00ooo003o003oooooo`0=ooooo`03o`00oooooooooooo04?ooooo00?oo`00oooooooo
ool03?ooool00ooo003oooooo`00o`0?ooooo`03o`00oooooooooooo06oooooo000booooo`03o`00
0?oooooooooo023ooooo00?oo`00ooooooooool03?ooool00ooo003o003oooooo`0=ooooo`03o`00
oooooooooooo04Gooooo00?oo`00ooooooooool02oooool00ooo003oooooo`00o`0>ooooo`03o`00
oooooooooooo04?ooooo00?oo`00ooooooooool03?ooool00ooo003oooooo`00o`0>ooooo`03o`00
oooooooooooo073ooooo000booooo`;o00008Oooool00ooo003oooooooooo`0<ooooo`03ool00?oo
oooo003o00gooooo00?o003oooooooooool0AOooool00ooo003oooooooooo`0;ooooo`03ool00?oo
oooo003o00gooooo00?o003oooooooooool0AOooool00ooo003oooooooooo`0;ooooo`03ool00?oo
oooo003o00kooooo00?o003oooooooooool0L?ooool003;ooooo00?o0000ooooooooool08Oooool0
0ooo003oooooooooo`0:ooooo`04ool00?ooooooooooo`00o`gooooo00?o003oooooooooool0AOoo
ool00ooo003oooooooooo`0;ooooo`03ool00?oooooo003o00gooooo00?o003oooooooooool0AOoo
ool00ooo003oooooooooo`0:ooooo`05ool00?ooooooooooooooool00?l03?ooool00ol00?oooooo
ooooo`1aooooo`00<_ooool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo00[ooooo00Co
o`00oooooooooooo003o3?ooool00ol00?ooooooooooo`17ooooo`03ool00?oooooooooo00Wooooo
00Goo`00ooooooooooooooooo`00o`0;ooooo`03o`00oooooooooooo04Oooooo00?oo`00oooooooo
ool02Oooool01Ooo003ooooooooooooooooo003o00cooooo00?o003oooooooooool0LOooool003;o
oooo0_l0000Rooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooo`00o`0;oooo
o`03o`00oooooooooooo04Oooooo00?oo`00ooooooooool02Oooool01Ooo003ooooooooooooooooo
003o00_ooooo00?o003oooooooooool0Aoooool00ooo003oooooooooo`09ooooo`05ool00?oooooo
ooooooooool00?l02oooool00ol00?ooooooooooo`1booooo`00<_ooool00ol0003oooooooooo`0R
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo04Wooooo00?oo`00ooooooooool02?ooool01Ooo003ooooooooooooo
oooo003o00_ooooo00?o003oooooooooool0B?ooool00ooo003oooooooooo`08ooooo`05ool00?oo
ooooooooooooool00?l02oooool00ol00?ooooooooooo`1booooo`00<_ooool00ol0003ooooooooo
o`0Sooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo04Wooooo00?oo`00ooooooooool01oooool00ooo003ooooooooo
o`02ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0BOooool00ooo003ooooooooo
o`07ooooo`03ool00?oooooooooo00?ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`1cooooo`007?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Kooooo0_l0000U
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo04_ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`03
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0B_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`1c
ooooo`007Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04_ooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0C?oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`1dooooo`007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool09Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1=ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo04gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`06ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0M?ooool001oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`03ooooo`;o00009_ooool2ool000Cooooo00?oo`00ooooooooool01_ooool2o`00
o`Cooooo00?o003oooooooooool0Coooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1?ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool01oooool00ol00?ooooooooooo`02ooooo`;o003oMoooool001co
oooo00Go0000ooooooooooooooooo`000007ooooo`Co00001_ooool00ol0003oooooooooo`0Voooo
o`;oo`000_ooool00ooo003oooooooooo`08ooooo`;o003o0_ooool00ol00?ooooooooooo`1Aoooo
o`03ool00?oooooooooo00;oo`002Oooool2o`00o`;ooooo0_l00?mBooooo`03ool00?oooooooooo
00;oo`002_ooool01?l00?ooooooooooool00?miooooo`007?ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool01oooool2o`0002Sooooo0ooo000<ooooo`?o003oEOooool3
ool000_ooooo0ol00?mEooooo`?oo`003?ooool3o`00ogWooooo000Mooooo`?o00002?ooool5o`00
00Gooooo00?o0000ooooooooool0oooooon0ooooo`00<_ooool00ol0003oooooooooo`3ooooooh3o
oooo003ooooookGooooo003ooooookGooooo003ooooookGooooo003ooooookGooooo003ooooookGo
oooo003ooooookGooooo003ooooookGooooo003ooooookGooooo000Booooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02?ooool3o`0000gooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`3ooooooeGooooo000Aooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0oooooomDooooo`000_ooool2o`000003ooooool0003o000000Wooooo00Co0000oooooooooooo
oooo0ol00004ooooo`?o00000oooool4o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooooooo`Co00000_ooool5o`0000?ooooo0_l000000ooo
oooo0000ooooo`03o`0000Gooooo00?o0000ooooooooool0oooooomCooooo`000oooool00ol0003o
ooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003ooooo
ooooo`3ooooooe?ooooo0004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`Go000000Goooooo`000?ooooooooooo`000005ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003ooooo
00Go00001?ooool00ol0003oooooooooo`3ooooooe?ooooo0003ooooo`03o`000?oooooo000000[o
oooo00?o0000ooooooooool00_ooool2o`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
000000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0oooooomCooooo`000_ooool2o`000003ooooool0003o000000[ooooo
00?o0000ooooooooool00_l000000ooooooo0000o`000002ooooo`?o00000oooool3o`0000Cooooo
00?o0000ooooooooool01oooool2o`000003ooooool0003o000000[ooooo00Co0000oooooooooooo
oooo0ol00004ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_ooool3o`00
00Cooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0003oooooooooo`0>ooooo`05
o`000?ooooooooooooooool000006_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0oooooomEooooo`008_ooool2o`00023ooooo0_l00004oooo
o`?o0000oooooomXooooo`00ooooooneooooo`00ooooooneooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 512.875}, {512.375, 404.375}} -> {-8.70107, \
13.7475, 0.0680428, 0.0351183}}]
}, Open  ]],

Cell["\<\
The system is autonomous so PlotVectorField can be used to display \
the vector field:\
\>", "Text"],

Cell[TextData[{
  " At point ( ",
  StyleBox["x ",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y ",
    FontSlant->"Italic"],
  ") plot the vector  < ( ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "(1 - ",
  StyleBox["y ",
    FontSlant->"Italic"],
  ") , ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "(",
  StyleBox["x ",
    FontSlant->"Italic"],
  "- 1 ) >",
  " "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
The plot is named  \"vf\" so it can be displayed with the \
trajectory below.. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
vf = PlotVectorField[ {x*(1-y),y*(x-1)}, {x,0,2.8}, {y,0,2.8}, \
Axes->True, PlotLabel->\"Vector field for DEsystem\" ]\
\>", "Input",
  CellLabel->"In[6]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.02184 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.330852 0.0243294 0.330852 [
[.18924 .01183 -9 -9 ]
[.18924 .01183 9 0 ]
[.35466 .01183 -3 -9 ]
[.35466 .01183 3 0 ]
[.52009 .01183 -9 -9 ]
[.52009 .01183 9 0 ]
[.68551 .01183 -3 -9 ]
[.68551 .01183 3 0 ]
[.85094 .01183 -9 -9 ]
[.85094 .01183 9 0 ]
[.01131 .18976 -18 -4.5 ]
[.01131 .18976 0 4.5 ]
[.01131 .35518 -6 -4.5 ]
[.01131 .35518 0 4.5 ]
[.01131 .52061 -18 -4.5 ]
[.01131 .52061 0 4.5 ]
[.01131 .68603 -6 -4.5 ]
[.01131 .68603 0 4.5 ]
[.01131 .85146 -18 -4.5 ]
[.01131 .85146 0 4.5 ]
[.01131 1.01689 -6 -4.5 ]
[.01131 1.01689 0 4.5 ]
[.5 1.03434 -77.0625 0 ]
[.5 1.03434 77.0625 12 ]
[ 0 0 0 0 ]
[ 1 1.02184 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18924 .02433 m
.18924 .03058 L
s
[(0.5)] .18924 .01183 0 1 Mshowa
.35466 .02433 m
.35466 .03058 L
s
[(1)] .35466 .01183 0 1 Mshowa
.52009 .02433 m
.52009 .03058 L
s
[(1.5)] .52009 .01183 0 1 Mshowa
.68551 .02433 m
.68551 .03058 L
s
[(2)] .68551 .01183 0 1 Mshowa
.85094 .02433 m
.85094 .03058 L
s
[(2.5)] .85094 .01183 0 1 Mshowa
.125 Mabswid
.05689 .02433 m
.05689 .02808 L
s
.08998 .02433 m
.08998 .02808 L
s
.12307 .02433 m
.12307 .02808 L
s
.15615 .02433 m
.15615 .02808 L
s
.22232 .02433 m
.22232 .02808 L
s
.25541 .02433 m
.25541 .02808 L
s
.28849 .02433 m
.28849 .02808 L
s
.32158 .02433 m
.32158 .02808 L
s
.38775 .02433 m
.38775 .02808 L
s
.42083 .02433 m
.42083 .02808 L
s
.45392 .02433 m
.45392 .02808 L
s
.487 .02433 m
.487 .02808 L
s
.55317 .02433 m
.55317 .02808 L
s
.58626 .02433 m
.58626 .02808 L
s
.61934 .02433 m
.61934 .02808 L
s
.65243 .02433 m
.65243 .02808 L
s
.7186 .02433 m
.7186 .02808 L
s
.75168 .02433 m
.75168 .02808 L
s
.78477 .02433 m
.78477 .02808 L
s
.81786 .02433 m
.81786 .02808 L
s
.88403 .02433 m
.88403 .02808 L
s
.91711 .02433 m
.91711 .02808 L
s
.9502 .02433 m
.9502 .02808 L
s
.98328 .02433 m
.98328 .02808 L
s
.25 Mabswid
0 .02433 m
1 .02433 L
s
.02381 .18976 m
.03006 .18976 L
s
[(0.5)] .01131 .18976 1 0 Mshowa
.02381 .35518 m
.03006 .35518 L
s
[(1)] .01131 .35518 1 0 Mshowa
.02381 .52061 m
.03006 .52061 L
s
[(1.5)] .01131 .52061 1 0 Mshowa
.02381 .68603 m
.03006 .68603 L
s
[(2)] .01131 .68603 1 0 Mshowa
.02381 .85146 m
.03006 .85146 L
s
[(2.5)] .01131 .85146 1 0 Mshowa
.02381 1.01689 m
.03006 1.01689 L
s
[(3)] .01131 1.01689 1 0 Mshowa
.125 Mabswid
.02381 .05741 m
.02756 .05741 L
s
.02381 .0905 m
.02756 .0905 L
s
.02381 .12359 m
.02756 .12359 L
s
.02381 .15667 m
.02756 .15667 L
s
.02381 .22284 m
.02756 .22284 L
s
.02381 .25593 m
.02756 .25593 L
s
.02381 .28901 m
.02756 .28901 L
s
.02381 .3221 m
.02756 .3221 L
s
.02381 .38827 m
.02756 .38827 L
s
.02381 .42135 m
.02756 .42135 L
s
.02381 .45444 m
.02756 .45444 L
s
.02381 .48752 m
.02756 .48752 L
s
.02381 .55369 m
.02756 .55369 L
s
.02381 .58678 m
.02756 .58678 L
s
.02381 .61986 m
.02756 .61986 L
s
.02381 .65295 m
.02756 .65295 L
s
.02381 .71912 m
.02756 .71912 L
s
.02381 .7522 m
.02756 .7522 L
s
.02381 .78529 m
.02756 .78529 L
s
.02381 .81838 m
.02756 .81838 L
s
.02381 .88455 m
.02756 .88455 L
s
.02381 .91763 m
.02756 .91763 L
s
.02381 .95072 m
.02756 .95072 L
s
.02381 .9838 m
.02756 .9838 L
s
.25 Mabswid
.02381 0 m
.02381 1.02184 L
s
gsave
.5 1.03434 -138.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Vector) show
105.000 13.000 moveto
(field) show
141.000 13.000 moveto
(for) show
165.000 13.000 moveto
(DEsystem) show
213.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.02381 .02433 m
.02381 .02433 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.02381 .0905 m
.02381 .08864 L
s
% Start of user PostScript
0 0.2 0 0.194388 MAarrowhead1
% End of user PostScript
.02381 .15667 m
.02381 .15296 L
s
% Start of user PostScript
0 0.4 0 0.388776 MAarrowhead1
% End of user PostScript
.02381 .22284 m
.02381 .21727 L
s
% Start of user PostScript
0 0.6 0 0.583164 MAarrowhead1
% End of user PostScript
.02381 .28901 m
.02381 .28158 L
s
% Start of user PostScript
0 0.8 0 0.777552 MAarrowhead1
% End of user PostScript
.02381 .35518 m
.02381 .3459 L
s
% Start of user PostScript
0 1. 0 0.97194 MAarrowhead1
% End of user PostScript
.02381 .42135 m
.02381 .41021 L
s
% Start of user PostScript
0 1.2 0 1.16633 MAarrowhead1
% End of user PostScript
.02381 .48752 m
.02381 .47453 L
s
% Start of user PostScript
0 1.4 0 1.36072 MAarrowhead1
% End of user PostScript
.02381 .55369 m
.02381 .53884 L
s
% Start of user PostScript
0 1.6 0 1.5551 MAarrowhead1
% End of user PostScript
.02381 .61986 m
.02381 .60315 L
s
% Start of user PostScript
0 1.8 0 1.74949 MAarrowhead1
% End of user PostScript
.02381 .68603 m
.02381 .66747 L
s
% Start of user PostScript
0 2. 0 1.94388 MAarrowhead1
% End of user PostScript
.02381 .7522 m
.02381 .73178 L
s
% Start of user PostScript
0 2.2 0 2.13827 MAarrowhead1
% End of user PostScript
.02381 .81838 m
.02381 .79609 L
s
% Start of user PostScript
0 2.4 0 2.33266 MAarrowhead1
% End of user PostScript
.02381 .88455 m
.02381 .86041 L
s
% Start of user PostScript
0 2.6 0 2.52704 MAarrowhead1
% End of user PostScript
.02381 .95072 m
.02381 .92472 L
s
% Start of user PostScript
0 2.8 0 2.72143 MAarrowhead1
% End of user PostScript
.08998 .02433 m
.09184 .02433 L
s
% Start of user PostScript
0.2 0 0.205612 0 MAarrowhead1
% End of user PostScript
.08998 .0905 m
.09147 .08901 L
s
% Start of user PostScript
0.2 0.2 0.20449 0.19551 MAarrowhead1
% End of user PostScript
.08998 .15667 m
.09109 .1537 L
s
% Start of user PostScript
0.2 0.4 0.203367 0.391021 MAarrowhead1
% End of user PostScript
.08998 .22284 m
.09072 .21838 L
s
% Start of user PostScript
0.2 0.6 0.202245 0.586531 MAarrowhead1
% End of user PostScript
.08998 .28901 m
.09035 .28307 L
s
% Start of user PostScript
0.2 0.8 0.201122 0.782042 MAarrowhead1
% End of user PostScript
.08998 .35518 m
.08998 .34775 L
s
% Start of user PostScript
0.2 1. 0.2 0.977552 MAarrowhead1
% End of user PostScript
.08998 .42135 m
.08961 .41244 L
s
% Start of user PostScript
0.2 1.2 0.198878 1.17306 MAarrowhead1
% End of user PostScript
.08998 .48752 m
.08924 .47713 L
s
% Start of user PostScript
0.2 1.4 0.197755 1.36857 MAarrowhead1
% End of user PostScript
.08998 .55369 m
.08887 .54181 L
s
% Start of user PostScript
0.2 1.6 0.196633 1.56408 MAarrowhead1
% End of user PostScript
.08998 .61986 m
.08849 .6065 L
s
% Start of user PostScript
0.2 1.8 0.19551 1.75959 MAarrowhead1
% End of user PostScript
.08998 .68603 m
.08812 .67118 L
s
% Start of user PostScript
0.2 2. 0.194388 1.9551 MAarrowhead1
% End of user PostScript
.08998 .7522 m
.08775 .73587 L
s
% Start of user PostScript
0.2 2.2 0.193266 2.15061 MAarrowhead1
% End of user PostScript
.08998 .81838 m
.08738 .80055 L
s
% Start of user PostScript
0.2 2.4 0.192143 2.34613 MAarrowhead1
% End of user PostScript
.08998 .88455 m
.08701 .86524 L
s
% Start of user PostScript
0.2 2.6 0.191021 2.54164 MAarrowhead1
% End of user PostScript
.08998 .95072 m
.08664 .92992 L
s
% Start of user PostScript
0.2 2.8 0.189898 2.73715 MAarrowhead1
% End of user PostScript
.15615 .02433 m
.15986 .02433 L
s
% Start of user PostScript
0.4 0 0.411224 0 MAarrowhead1
% End of user PostScript
.15615 .0905 m
.15912 .08939 L
s
% Start of user PostScript
0.4 0.2 0.408979 0.196633 MAarrowhead1
% End of user PostScript
.15615 .15667 m
.15838 .15444 L
s
% Start of user PostScript
0.4 0.4 0.406734 0.393266 MAarrowhead1
% End of user PostScript
.15615 .22284 m
.15764 .2195 L
s
% Start of user PostScript
0.4 0.6 0.40449 0.589898 MAarrowhead1
% End of user PostScript
.15615 .28901 m
.15689 .28456 L
s
% Start of user PostScript
0.4 0.8 0.402245 0.786531 MAarrowhead1
% End of user PostScript
.15615 .35518 m
.15615 .34961 L
s
% Start of user PostScript
0.4 1. 0.4 0.983164 MAarrowhead1
% End of user PostScript
.15615 .42135 m
.15541 .41467 L
s
% Start of user PostScript
0.4 1.2 0.397755 1.1798 MAarrowhead1
% End of user PostScript
.15615 .48752 m
.15467 .47972 L
s
% Start of user PostScript
0.4 1.4 0.39551 1.37643 MAarrowhead1
% End of user PostScript
.15615 .55369 m
.15392 .54478 L
s
% Start of user PostScript
0.4 1.6 0.393266 1.57306 MAarrowhead1
% End of user PostScript
.15615 .61986 m
.15318 .60984 L
s
% Start of user PostScript
0.4 1.8 0.391021 1.7697 MAarrowhead1
% End of user PostScript
.15615 .68603 m
.15244 .67489 L
s
% Start of user PostScript
0.4 2. 0.388776 1.96633 MAarrowhead1
% End of user PostScript
.15615 .7522 m
.15169 .73995 L
s
% Start of user PostScript
0.4 2.2 0.386531 2.16296 MAarrowhead1
% End of user PostScript
.15615 .81838 m
.15095 .80501 L
s
% Start of user PostScript
0.4 2.4 0.384287 2.35959 MAarrowhead1
% End of user PostScript
.15615 .88455 m
.15021 .87006 L
s
% Start of user PostScript
0.4 2.6 0.382042 2.55623 MAarrowhead1
% End of user PostScript
.15615 .95072 m
.14947 .93512 L
s
% Start of user PostScript
0.4 2.8 0.379797 2.75286 MAarrowhead1
% End of user PostScript
.22232 .02433 m
.22789 .02433 L
s
% Start of user PostScript
0.6 0 0.616836 0 MAarrowhead1
% End of user PostScript
.22232 .0905 m
.22678 .08976 L
s
% Start of user PostScript
0.6 0.2 0.613469 0.197755 MAarrowhead1
% End of user PostScript
.22232 .15667 m
.22566 .15518 L
s
% Start of user PostScript
0.6 0.4 0.610102 0.39551 MAarrowhead1
% End of user PostScript
.22232 .22284 m
.22455 .22061 L
s
% Start of user PostScript
0.6 0.6 0.606734 0.593266 MAarrowhead1
% End of user PostScript
.22232 .28901 m
.22344 .28604 L
s
% Start of user PostScript
0.6 0.8 0.603367 0.791021 MAarrowhead1
% End of user PostScript
.22232 .35518 m
.22232 .35147 L
s
% Start of user PostScript
0.6 1. 0.6 0.988776 MAarrowhead1
% End of user PostScript
.22232 .42135 m
.22121 .4169 L
s
% Start of user PostScript
0.6 1.2 0.596633 1.18653 MAarrowhead1
% End of user PostScript
.22232 .48752 m
.22009 .48232 L
s
% Start of user PostScript
0.6 1.4 0.593266 1.38429 MAarrowhead1
% End of user PostScript
.22232 .55369 m
.21898 .54775 L
s
% Start of user PostScript
0.6 1.6 0.589898 1.58204 MAarrowhead1
% End of user PostScript
.22232 .61986 m
.21786 .61318 L
s
% Start of user PostScript
0.6 1.8 0.586531 1.7798 MAarrowhead1
% End of user PostScript
.22232 .68603 m
.21675 .67861 L
s
% Start of user PostScript
0.6 2. 0.583164 1.97755 MAarrowhead1
% End of user PostScript
.22232 .7522 m
.21564 .74404 L
s
% Start of user PostScript
0.6 2.2 0.579797 2.17531 MAarrowhead1
% End of user PostScript
.22232 .81838 m
.21452 .80946 L
s
% Start of user PostScript
0.6 2.4 0.57643 2.37306 MAarrowhead1
% End of user PostScript
.22232 .88455 m
.21341 .87489 L
s
% Start of user PostScript
0.6 2.6 0.573063 2.57082 MAarrowhead1
% End of user PostScript
.22232 .95072 m
.21229 .94032 L
s
% Start of user PostScript
0.6 2.8 0.569695 2.76857 MAarrowhead1
% End of user PostScript
.28849 .02433 m
.29592 .02433 L
s
% Start of user PostScript
0.8 0 0.822448 0 MAarrowhead1
% End of user PostScript
.28849 .0905 m
.29443 .09013 L
s
% Start of user PostScript
0.8 0.2 0.817958 0.198878 MAarrowhead1
% End of user PostScript
.28849 .15667 m
.29295 .15593 L
s
% Start of user PostScript
0.8 0.4 0.813469 0.397755 MAarrowhead1
% End of user PostScript
.28849 .22284 m
.29146 .22173 L
s
% Start of user PostScript
0.8 0.6 0.808979 0.596633 MAarrowhead1
% End of user PostScript
.28849 .28901 m
.28998 .28753 L
s
% Start of user PostScript
0.8 0.8 0.80449 0.79551 MAarrowhead1
% End of user PostScript
.28849 .35518 m
.28849 .35333 L
s
% Start of user PostScript
0.8 1. 0.8 0.994388 MAarrowhead1
% End of user PostScript
.28849 .42135 m
.28701 .41912 L
s
% Start of user PostScript
0.8 1.2 0.79551 1.19327 MAarrowhead1
% End of user PostScript
.28849 .48752 m
.28552 .48492 L
s
% Start of user PostScript
0.8 1.4 0.791021 1.39214 MAarrowhead1
% End of user PostScript
.28849 .55369 m
.28404 .55072 L
s
% Start of user PostScript
0.8 1.6 0.786531 1.59102 MAarrowhead1
% End of user PostScript
.28849 .61986 m
.28255 .61652 L
s
% Start of user PostScript
0.8 1.8 0.782042 1.7899 MAarrowhead1
% End of user PostScript
.28849 .68603 m
.28106 .68232 L
s
% Start of user PostScript
0.8 2. 0.777552 1.98878 MAarrowhead1
% End of user PostScript
.28849 .7522 m
.27958 .74812 L
s
% Start of user PostScript
0.8 2.2 0.773063 2.18765 MAarrowhead1
% End of user PostScript
.28849 .81838 m
.27809 .81392 L
s
% Start of user PostScript
0.8 2.4 0.768573 2.38653 MAarrowhead1
% End of user PostScript
.28849 .88455 m
.27661 .87972 L
s
% Start of user PostScript
0.8 2.6 0.764083 2.58541 MAarrowhead1
% End of user PostScript
.28849 .95072 m
.27512 .94552 L
s
% Start of user PostScript
0.8 2.8 0.759594 2.78429 MAarrowhead1
% End of user PostScript
.35466 .02433 m
.36395 .02433 L
s
% Start of user PostScript
1. 0 1.02806 0 MAarrowhead1
% End of user PostScript
.35466 .0905 m
.36209 .0905 L
s
% Start of user PostScript
1. 0.2 1.02245 0.2 MAarrowhead1
% End of user PostScript
.35466 .15667 m
.36023 .15667 L
s
% Start of user PostScript
1. 0.4 1.01684 0.4 MAarrowhead1
% End of user PostScript
.35466 .22284 m
.35838 .22284 L
s
% Start of user PostScript
1. 0.6 1.01122 0.6 MAarrowhead1
% End of user PostScript
.35466 .28901 m
.35652 .28901 L
s
% Start of user PostScript
1. 0.8 1.00561 0.8 MAarrowhead1
% End of user PostScript
.35466 .35518 m
.35466 .35518 L
s
% Start of user PostScript
1. 1. MAarrowzero1
% End of user PostScript
.35466 .42135 m
.35281 .42135 L
s
% Start of user PostScript
1. 1.2 0.994388 1.2 MAarrowhead1
% End of user PostScript
.35466 .48752 m
.35095 .48752 L
s
% Start of user PostScript
1. 1.4 0.988776 1.4 MAarrowhead1
% End of user PostScript
.35466 .55369 m
.34909 .55369 L
s
% Start of user PostScript
1. 1.6 0.983164 1.6 MAarrowhead1
% End of user PostScript
.35466 .61986 m
.34724 .61986 L
s
% Start of user PostScript
1. 1.8 0.977552 1.8 MAarrowhead1
% End of user PostScript
.35466 .68603 m
.34538 .68603 L
s
% Start of user PostScript
1. 2. 0.97194 2. MAarrowhead1
% End of user PostScript
.35466 .7522 m
.34352 .7522 L
s
% Start of user PostScript
1. 2.2 0.966328 2.2 MAarrowhead1
% End of user PostScript
.35466 .81838 m
.34166 .81838 L
s
% Start of user PostScript
1. 2.4 0.960716 2.4 MAarrowhead1
% End of user PostScript
.35466 .88455 m
.33981 .88455 L
s
% Start of user PostScript
1. 2.6 0.955104 2.6 MAarrowhead1
% End of user PostScript
.35466 .95072 m
.33795 .95072 L
s
% Start of user PostScript
1. 2.8 0.949492 2.8 MAarrowhead1
% End of user PostScript
.42083 .02433 m
.43197 .02433 L
s
% Start of user PostScript
1.2 0 1.23367 0 MAarrowhead1
% End of user PostScript
.42083 .0905 m
.42974 .09087 L
s
% Start of user PostScript
1.2 0.2 1.22694 0.201122 MAarrowhead1
% End of user PostScript
.42083 .15667 m
.42752 .15741 L
s
% Start of user PostScript
1.2 0.4 1.2202 0.402245 MAarrowhead1
% End of user PostScript
.42083 .22284 m
.42529 .22395 L
s
% Start of user PostScript
1.2 0.6 1.21347 0.603367 MAarrowhead1
% End of user PostScript
.42083 .28901 m
.42306 .2905 L
s
% Start of user PostScript
1.2 0.8 1.20673 0.80449 MAarrowhead1
% End of user PostScript
.42083 .35518 m
.42083 .35704 L
s
% Start of user PostScript
1.2 1. 1.2 1.00561 MAarrowhead1
% End of user PostScript
.42083 .42135 m
.4186 .42358 L
s
% Start of user PostScript
1.2 1.2 1.19327 1.20673 MAarrowhead1
% End of user PostScript
.42083 .48752 m
.41638 .49012 L
s
% Start of user PostScript
1.2 1.4 1.18653 1.40786 MAarrowhead1
% End of user PostScript
.42083 .55369 m
.41415 .55666 L
s
% Start of user PostScript
1.2 1.6 1.1798 1.60898 MAarrowhead1
% End of user PostScript
.42083 .61986 m
.41192 .62321 L
s
% Start of user PostScript
1.2 1.8 1.17306 1.8101 MAarrowhead1
% End of user PostScript
.42083 .68603 m
.40969 .68975 L
s
% Start of user PostScript
1.2 2. 1.16633 2.01122 MAarrowhead1
% End of user PostScript
.42083 .7522 m
.40746 .75629 L
s
% Start of user PostScript
1.2 2.2 1.15959 2.21235 MAarrowhead1
% End of user PostScript
.42083 .81838 m
.40524 .82283 L
s
% Start of user PostScript
1.2 2.4 1.15286 2.41347 MAarrowhead1
% End of user PostScript
.42083 .88455 m
.40301 .88937 L
s
% Start of user PostScript
1.2 2.6 1.14613 2.61459 MAarrowhead1
% End of user PostScript
.42083 .95072 m
.40078 .95591 L
s
% Start of user PostScript
1.2 2.8 1.13939 2.81571 MAarrowhead1
% End of user PostScript
.487 .02433 m
.5 .02433 L
s
% Start of user PostScript
1.4 0 1.43928 0 MAarrowhead1
% End of user PostScript
.487 .0905 m
.4974 .09124 L
s
% Start of user PostScript
1.4 0.2 1.43143 0.202245 MAarrowhead1
% End of user PostScript
.487 .15667 m
.4948 .15816 L
s
% Start of user PostScript
1.4 0.4 1.42357 0.40449 MAarrowhead1
% End of user PostScript
.487 .22284 m
.4922 .22507 L
s
% Start of user PostScript
1.4 0.6 1.41571 0.606734 MAarrowhead1
% End of user PostScript
.487 .28901 m
.4896 .29198 L
s
% Start of user PostScript
1.4 0.8 1.40786 0.808979 MAarrowhead1
% End of user PostScript
.487 .35518 m
.487 .3589 L
s
% Start of user PostScript
1.4 1. 1.4 1.01122 MAarrowhead1
% End of user PostScript
.487 .42135 m
.4844 .42581 L
s
% Start of user PostScript
1.4 1.2 1.39214 1.21347 MAarrowhead1
% End of user PostScript
.487 .48752 m
.4818 .49272 L
s
% Start of user PostScript
1.4 1.4 1.38429 1.41571 MAarrowhead1
% End of user PostScript
.487 .55369 m
.4792 .55963 L
s
% Start of user PostScript
1.4 1.6 1.37643 1.61796 MAarrowhead1
% End of user PostScript
.487 .61986 m
.47661 .62655 L
s
% Start of user PostScript
1.4 1.8 1.36857 1.8202 MAarrowhead1
% End of user PostScript
.487 .68603 m
.47401 .69346 L
s
% Start of user PostScript
1.4 2. 1.36072 2.02245 MAarrowhead1
% End of user PostScript
.487 .7522 m
.47141 .76037 L
s
% Start of user PostScript
1.4 2.2 1.35286 2.22469 MAarrowhead1
% End of user PostScript
.487 .81838 m
.46881 .82729 L
s
% Start of user PostScript
1.4 2.4 1.345 2.42694 MAarrowhead1
% End of user PostScript
.487 .88455 m
.46621 .8942 L
s
% Start of user PostScript
1.4 2.6 1.33715 2.62918 MAarrowhead1
% End of user PostScript
.487 .95072 m
.46361 .96111 L
s
% Start of user PostScript
1.4 2.8 1.32929 2.83143 MAarrowhead1
% End of user PostScript
.55317 .02433 m
.56803 .02433 L
s
% Start of user PostScript
1.6 0 1.6449 0 MAarrowhead1
% End of user PostScript
.55317 .0905 m
.56506 .09161 L
s
% Start of user PostScript
1.6 0.2 1.63592 0.203367 MAarrowhead1
% End of user PostScript
.55317 .15667 m
.56209 .1589 L
s
% Start of user PostScript
1.6 0.4 1.62694 0.406734 MAarrowhead1
% End of user PostScript
.55317 .22284 m
.55911 .22618 L
s
% Start of user PostScript
1.6 0.6 1.61796 0.610102 MAarrowhead1
% End of user PostScript
.55317 .28901 m
.55614 .29347 L
s
% Start of user PostScript
1.6 0.8 1.60898 0.813469 MAarrowhead1
% End of user PostScript
.55317 .35518 m
.55317 .36075 L
s
% Start of user PostScript
1.6 1. 1.6 1.01684 MAarrowhead1
% End of user PostScript
.55317 .42135 m
.5502 .42804 L
s
% Start of user PostScript
1.6 1.2 1.59102 1.2202 MAarrowhead1
% End of user PostScript
.55317 .48752 m
.54723 .49532 L
s
% Start of user PostScript
1.6 1.4 1.58204 1.42357 MAarrowhead1
% End of user PostScript
.55317 .55369 m
.54426 .56261 L
s
% Start of user PostScript
1.6 1.6 1.57306 1.62694 MAarrowhead1
% End of user PostScript
.55317 .61986 m
.54129 .62989 L
s
% Start of user PostScript
1.6 1.8 1.56408 1.8303 MAarrowhead1
% End of user PostScript
.55317 .68603 m
.53832 .69717 L
s
% Start of user PostScript
1.6 2. 1.5551 2.03367 MAarrowhead1
% End of user PostScript
.55317 .7522 m
.53535 .76446 L
s
% Start of user PostScript
1.6 2.2 1.54613 2.23704 MAarrowhead1
% End of user PostScript
.55317 .81838 m
.53238 .83174 L
s
% Start of user PostScript
1.6 2.4 1.53715 2.44041 MAarrowhead1
% End of user PostScript
.55317 .88455 m
.52941 .89903 L
s
% Start of user PostScript
1.6 2.6 1.52817 2.64377 MAarrowhead1
% End of user PostScript
.55317 .95072 m
.52644 .96631 L
s
% Start of user PostScript
1.6 2.8 1.51919 2.84714 MAarrowhead1
% End of user PostScript
.61934 .02433 m
.63605 .02433 L
s
% Start of user PostScript
1.8 0 1.85051 0 MAarrowhead1
% End of user PostScript
.61934 .0905 m
.63271 .09199 L
s
% Start of user PostScript
1.8 0.2 1.84041 0.20449 MAarrowhead1
% End of user PostScript
.61934 .15667 m
.62937 .15964 L
s
% Start of user PostScript
1.8 0.4 1.8303 0.408979 MAarrowhead1
% End of user PostScript
.61934 .22284 m
.62603 .2273 L
s
% Start of user PostScript
1.8 0.6 1.8202 0.613469 MAarrowhead1
% End of user PostScript
.61934 .28901 m
.62269 .29495 L
s
% Start of user PostScript
1.8 0.8 1.8101 0.817958 MAarrowhead1
% End of user PostScript
.61934 .35518 m
.61934 .36261 L
s
% Start of user PostScript
1.8 1. 1.8 1.02245 MAarrowhead1
% End of user PostScript
.61934 .42135 m
.616 .43026 L
s
% Start of user PostScript
1.8 1.2 1.7899 1.22694 MAarrowhead1
% End of user PostScript
.61934 .48752 m
.61266 .49792 L
s
% Start of user PostScript
1.8 1.4 1.7798 1.43143 MAarrowhead1
% End of user PostScript
.61934 .55369 m
.60932 .56558 L
s
% Start of user PostScript
1.8 1.6 1.7697 1.63592 MAarrowhead1
% End of user PostScript
.61934 .61986 m
.60598 .63323 L
s
% Start of user PostScript
1.8 1.8 1.75959 1.84041 MAarrowhead1
% End of user PostScript
.61934 .68603 m
.60263 .70089 L
s
% Start of user PostScript
1.8 2. 1.74949 2.0449 MAarrowhead1
% End of user PostScript
.61934 .7522 m
.59929 .76854 L
s
% Start of user PostScript
1.8 2.2 1.73939 2.24939 MAarrowhead1
% End of user PostScript
.61934 .81838 m
.59595 .8362 L
s
% Start of user PostScript
1.8 2.4 1.72929 2.45387 MAarrowhead1
% End of user PostScript
.61934 .88455 m
.59261 .90386 L
s
% Start of user PostScript
1.8 2.6 1.71919 2.65836 MAarrowhead1
% End of user PostScript
.61934 .95072 m
.58926 .97151 L
s
% Start of user PostScript
1.8 2.8 1.70909 2.86285 MAarrowhead1
% End of user PostScript
.68551 .02433 m
.70408 .02433 L
s
% Start of user PostScript
2. 0 2.05612 0 MAarrowhead1
% End of user PostScript
.68551 .0905 m
.70037 .09236 L
s
% Start of user PostScript
2. 0.2 2.0449 0.205612 MAarrowhead1
% End of user PostScript
.68551 .15667 m
.69665 .16038 L
s
% Start of user PostScript
2. 0.4 2.03367 0.411224 MAarrowhead1
% End of user PostScript
.68551 .22284 m
.69294 .22841 L
s
% Start of user PostScript
2. 0.6 2.02245 0.616836 MAarrowhead1
% End of user PostScript
.68551 .28901 m
.68923 .29644 L
s
% Start of user PostScript
2. 0.8 2.01122 0.822448 MAarrowhead1
% End of user PostScript
.68551 .35518 m
.68551 .36447 L
s
% Start of user PostScript
2. 1. 2. 1.02806 MAarrowhead1
% End of user PostScript
.68551 .42135 m
.6818 .43249 L
s
% Start of user PostScript
2. 1.2 1.98878 1.23367 MAarrowhead1
% End of user PostScript
.68551 .48752 m
.67809 .50052 L
s
% Start of user PostScript
2. 1.4 1.97755 1.43928 MAarrowhead1
% End of user PostScript
.68551 .55369 m
.67437 .56855 L
s
% Start of user PostScript
2. 1.6 1.96633 1.6449 MAarrowhead1
% End of user PostScript
.68551 .61986 m
.67066 .63657 L
s
% Start of user PostScript
2. 1.8 1.9551 1.85051 MAarrowhead1
% End of user PostScript
.68551 .68603 m
.66695 .7046 L
s
% Start of user PostScript
2. 2. 1.94388 2.05612 MAarrowhead1
% End of user PostScript
.68551 .7522 m
.66323 .77263 L
s
% Start of user PostScript
2. 2.2 1.93266 2.26173 MAarrowhead1
% End of user PostScript
.68551 .81838 m
.65952 .84066 L
s
% Start of user PostScript
2. 2.4 1.92143 2.46734 MAarrowhead1
% End of user PostScript
.68551 .88455 m
.65581 .90868 L
s
% Start of user PostScript
2. 2.6 1.91021 2.67296 MAarrowhead1
% End of user PostScript
.68551 .95072 m
.65209 .97671 L
s
% Start of user PostScript
2. 2.8 1.89898 2.87857 MAarrowhead1
% End of user PostScript
.75168 .02433 m
.77211 .02433 L
s
% Start of user PostScript
2.2 0 2.26173 0 MAarrowhead1
% End of user PostScript
.75168 .0905 m
.76802 .09273 L
s
% Start of user PostScript
2.2 0.2 2.24939 0.206734 MAarrowhead1
% End of user PostScript
.75168 .15667 m
.76394 .16113 L
s
% Start of user PostScript
2.2 0.4 2.23704 0.413469 MAarrowhead1
% End of user PostScript
.75168 .22284 m
.75985 .22953 L
s
% Start of user PostScript
2.2 0.6 2.22469 0.620203 MAarrowhead1
% End of user PostScript
.75168 .28901 m
.75577 .29792 L
s
% Start of user PostScript
2.2 0.8 2.21235 0.826937 MAarrowhead1
% End of user PostScript
.75168 .35518 m
.75168 .36632 L
s
% Start of user PostScript
2.2 1. 2.2 1.03367 MAarrowhead1
% End of user PostScript
.75168 .42135 m
.7476 .43472 L
s
% Start of user PostScript
2.2 1.2 2.18765 1.24041 MAarrowhead1
% End of user PostScript
.75168 .48752 m
.74352 .50312 L
s
% Start of user PostScript
2.2 1.4 2.17531 1.44714 MAarrowhead1
% End of user PostScript
.75168 .55369 m
.73943 .57152 L
s
% Start of user PostScript
2.2 1.6 2.16296 1.65387 MAarrowhead1
% End of user PostScript
.75168 .61986 m
.73535 .63992 L
s
% Start of user PostScript
2.2 1.8 2.15061 1.86061 MAarrowhead1
% End of user PostScript
.75168 .68603 m
.73126 .70831 L
s
% Start of user PostScript
2.2 2. 2.13827 2.06734 MAarrowhead1
% End of user PostScript
.75168 .7522 m
.72718 .77671 L
s
% Start of user PostScript
2.2 2.2 2.12592 2.27408 MAarrowhead1
% End of user PostScript
.75168 .81838 m
.72309 .84511 L
s
% Start of user PostScript
2.2 2.4 2.11358 2.48081 MAarrowhead1
% End of user PostScript
.75168 .88455 m
.71901 .91351 L
s
% Start of user PostScript
2.2 2.6 2.10123 2.68755 MAarrowhead1
% End of user PostScript
.75168 .95072 m
.71492 .98191 L
s
% Start of user PostScript
2.2 2.8 2.08888 2.89428 MAarrowhead1
% End of user PostScript
.81786 .02433 m
.84014 .02433 L
s
% Start of user PostScript
2.4 0 2.46734 0 MAarrowhead1
% End of user PostScript
.81786 .0905 m
.83568 .0931 L
s
% Start of user PostScript
2.4 0.2 2.45387 0.207857 MAarrowhead1
% End of user PostScript
.81786 .15667 m
.83122 .16187 L
s
% Start of user PostScript
2.4 0.4 2.44041 0.415713 MAarrowhead1
% End of user PostScript
.81786 .22284 m
.82677 .23064 L
s
% Start of user PostScript
2.4 0.6 2.42694 0.62357 MAarrowhead1
% End of user PostScript
.81786 .28901 m
.82231 .29941 L
s
% Start of user PostScript
2.4 0.8 2.41347 0.831427 MAarrowhead1
% End of user PostScript
.81786 .35518 m
.81786 .36818 L
s
% Start of user PostScript
2.4 1. 2.4 1.03928 MAarrowhead1
% End of user PostScript
.81786 .42135 m
.8134 .43695 L
s
% Start of user PostScript
2.4 1.2 2.38653 1.24714 MAarrowhead1
% End of user PostScript
.81786 .48752 m
.80894 .50572 L
s
% Start of user PostScript
2.4 1.4 2.37306 1.455 MAarrowhead1
% End of user PostScript
.81786 .55369 m
.80449 .57449 L
s
% Start of user PostScript
2.4 1.6 2.35959 1.66285 MAarrowhead1
% End of user PostScript
.81786 .61986 m
.80003 .64326 L
s
% Start of user PostScript
2.4 1.8 2.34613 1.87071 MAarrowhead1
% End of user PostScript
.81786 .68603 m
.79557 .71203 L
s
% Start of user PostScript
2.4 2. 2.33266 2.07857 MAarrowhead1
% End of user PostScript
.81786 .7522 m
.79112 .7808 L
s
% Start of user PostScript
2.4 2.2 2.31919 2.28642 MAarrowhead1
% End of user PostScript
.81786 .81838 m
.78666 .84957 L
s
% Start of user PostScript
2.4 2.4 2.30572 2.49428 MAarrowhead1
% End of user PostScript
.81786 .88455 m
.78221 .91834 L
s
% Start of user PostScript
2.4 2.6 2.29225 2.70214 MAarrowhead1
% End of user PostScript
.81786 .95072 m
.77775 .98711 L
s
% Start of user PostScript
2.4 2.8 2.27878 2.90999 MAarrowhead1
% End of user PostScript
.88403 .02433 m
.90816 .02433 L
s
% Start of user PostScript
2.6 0 2.67296 0 MAarrowhead1
% End of user PostScript
.88403 .0905 m
.90334 .09347 L
s
% Start of user PostScript
2.6 0.2 2.65836 0.208979 MAarrowhead1
% End of user PostScript
.88403 .15667 m
.89851 .16261 L
s
% Start of user PostScript
2.6 0.4 2.64377 0.417958 MAarrowhead1
% End of user PostScript
.88403 .22284 m
.89368 .23175 L
s
% Start of user PostScript
2.6 0.6 2.62918 0.626937 MAarrowhead1
% End of user PostScript
.88403 .28901 m
.88885 .30089 L
s
% Start of user PostScript
2.6 0.8 2.61459 0.835917 MAarrowhead1
% End of user PostScript
.88403 .35518 m
.88403 .37004 L
s
% Start of user PostScript
2.6 1. 2.6 1.0449 MAarrowhead1
% End of user PostScript
.88403 .42135 m
.8792 .43918 L
s
% Start of user PostScript
2.6 1.2 2.58541 1.25387 MAarrowhead1
% End of user PostScript
.88403 .48752 m
.87437 .50832 L
s
% Start of user PostScript
2.6 1.4 2.57082 1.46285 MAarrowhead1
% End of user PostScript
.88403 .55369 m
.86954 .57746 L
s
% Start of user PostScript
2.6 1.6 2.55623 1.67183 MAarrowhead1
% End of user PostScript
.88403 .61986 m
.86472 .6466 L
s
% Start of user PostScript
2.6 1.8 2.54164 1.88081 MAarrowhead1
% End of user PostScript
.88403 .68603 m
.85989 .71574 L
s
% Start of user PostScript
2.6 2. 2.52704 2.08979 MAarrowhead1
% End of user PostScript
.88403 .7522 m
.85506 .78488 L
s
% Start of user PostScript
2.6 2.2 2.51245 2.29877 MAarrowhead1
% End of user PostScript
.88403 .81838 m
.85023 .85402 L
s
% Start of user PostScript
2.6 2.4 2.49786 2.50775 MAarrowhead1
% End of user PostScript
.88403 .88455 m
.84541 .92317 L
s
% Start of user PostScript
2.6 2.6 2.48327 2.71673 MAarrowhead1
% End of user PostScript
.88403 .95072 m
.84058 .99231 L
s
% Start of user PostScript
2.6 2.8 2.46868 2.92571 MAarrowhead1
% End of user PostScript
.9502 .02433 m
.97619 .02433 L
s
% Start of user PostScript
2.8 0 2.87857 0 MAarrowhead1
% End of user PostScript
.9502 .0905 m
.97099 .09384 L
s
% Start of user PostScript
2.8 0.2 2.86285 0.210102 MAarrowhead1
% End of user PostScript
.9502 .15667 m
.96579 .16335 L
s
% Start of user PostScript
2.8 0.4 2.84714 0.420203 MAarrowhead1
% End of user PostScript
.9502 .22284 m
.96059 .23287 L
s
% Start of user PostScript
2.8 0.6 2.83143 0.630305 MAarrowhead1
% End of user PostScript
.9502 .28901 m
.9554 .30238 L
s
% Start of user PostScript
2.8 0.8 2.81571 0.840406 MAarrowhead1
% End of user PostScript
.9502 .35518 m
.9502 .37189 L
s
% Start of user PostScript
2.8 1. 2.8 1.05051 MAarrowhead1
% End of user PostScript
.9502 .42135 m
.945 .4414 L
s
% Start of user PostScript
2.8 1.2 2.78429 1.26061 MAarrowhead1
% End of user PostScript
.9502 .48752 m
.9398 .51092 L
s
% Start of user PostScript
2.8 1.4 2.76857 1.47071 MAarrowhead1
% End of user PostScript
.9502 .55369 m
.9346 .58043 L
s
% Start of user PostScript
2.8 1.6 2.75286 1.68081 MAarrowhead1
% End of user PostScript
.9502 .61986 m
.9294 .64994 L
s
% Start of user PostScript
2.8 1.8 2.73715 1.89091 MAarrowhead1
% End of user PostScript
.9502 .68603 m
.9242 .71946 L
s
% Start of user PostScript
2.8 2. 2.72143 2.10102 MAarrowhead1
% End of user PostScript
.9502 .7522 m
.919 .78897 L
s
% Start of user PostScript
2.8 2.2 2.70572 2.31112 MAarrowhead1
% End of user PostScript
.9502 .81838 m
.9138 .85848 L
s
% Start of user PostScript
2.8 2.4 2.69001 2.52122 MAarrowhead1
% End of user PostScript
.9502 .88455 m
.90861 .92799 L
s
% Start of user PostScript
2.8 2.6 2.67429 2.73132 MAarrowhead1
% End of user PostScript
.9502 .95072 m
.90341 .99751 L
s
% Start of user PostScript
2.8 2.8 2.65858 2.94142 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1.02184 L
0 1.02184 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{186, 190},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002j0000_R000`400?l00000o`00003o^_ooool0
02[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Booooo`?o00004_ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001;ooooo1Ol0000@ooooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00005Oooool002Wooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000001;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000004_ooool01?l0003oooooooooool0000Aooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Dooooo`00:Oooool01?l0003o
ooooooooool0000;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo000Yooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04_ooool002Wooooo00Co0000oooooooooooo00001oooool4o`00
01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`Co00004_ooool01Ol0
003ooooooooooooooooo0000013ooooo00Go0000ooooooooooooooooo`000007ooooo`Co00005Ooo
ool002Wooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Cooooo`;o00004ooo
ool2o`0000Wooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000013ooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Kooooo000Zooooo`;o0000
2?ooool5o`0001;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`Go0000
4_ooool3o`0001;ooooo0ol00008ooooo`Go00005?ooool001Kooooo00?o0000ooooooooool0XOoo
ool001Kooooo00?o0000ooooooooool0XOooool001Kooooo00?o0000ooooooooool0XOooool001Ko
oooo00?o0000ooooooooool01Oooool3o`0000Sooooo0ol00008ooooo`?o00002?ooool3o`0000So
oooo0ol00009ooooo`?o00002?ooool3o`0000Sooooo0ol00008ooooo`?o00002?ooool3o`0000So
oooo0ol00009ooooo`?o00002?ooool3o`0000Sooooo0ol00008ooooo`004_oooonUo`0000?ooooo
000Fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Iooooo`005_ooool00ol0003oooooooooo`2Qooooo`005_ooool00ol0003oooooooooo`2Qoooo
o`005_ooool00ol0003oooooooooo`2Qooooo`005_ooool00ol0003oooooooooo`2Qooooo`005_oo
ool00ol0003oooooooooo`2Qooooo`005_ooool00ol0003oooooooooo`2Qooooo`005_ooool00ol0
003oooooooooo`2Qooooo`005_ooool00ol0003oooooooooo`1Cooooo`;o0000C?ooool001Kooooo
00?o0000ooooooooool01oooool2o`0000Wooooo0_l00007ooooo`Co00001oooool4o`0000Oooooo
1?l00007ooooo`Go00001_ooool4o`0000Sooooo0ol00008ooooo`?o00002?ooool3o`0000Sooooo
0ol00008ooooo`?o00002?ooool3o`0000Sooooo0ol00009ooooo`005_ooool00ol0003ooooooooo
o`06ooooo`?o00001oooool2o`0000Wooooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo0_l0
0009ooooo`Go00001_ooool5o`0000Oooooo1?l00007ooooo`Co00001oooool4o`0000Oooooo1?l0
0007ooooo`Co00001oooool4o`0000Sooooo000Eooooo`?o00001_ooool3o`0000Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`23ooooo`005Oooool3o`0000Oooooo00?o0000oooo
ooooool0V?ooool001Kooooo00?o0000ooooooooool0XOooool001Kooooo00?o0000ooooooooool0
XOooool001Kooooo00?o0000ooooooooool0XOooool001Kooooo00?o0000ooooooooool0XOooool0
01Kooooo00?o0000ooooooooool0XOooool001Kooooo00?o0000ooooooooool0XOooool001Kooooo
00?o0000ooooooooool0<Oooool3o`0000Sooooo0ol00008ooooo`;o00002Oooool2o`0000Wooooo
0_l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`;o00002Oooool2o`0000[ooooo000Fooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool2o`0000Wooooo0_l00007ooooo`Co00001oooool4o`0000Oooooo1?l0
0007ooooo`?o00002?ooool3o`0000Sooooo0ol00009ooooo`;o00002Oooool2o`0000Wooooo0_l0
0009ooooo`?o00002?ooool3o`0000Wooooo000Fooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01_ooool3o`0000Oooooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo0_l00009
ooooo`Co00001oooool4o`0000Oooooo1?l00007ooooo`Co00001oooool4o`0000Oooooo1?l00007
ooooo`Go00001_ooool5o`0000Sooooo000Eooooo`?o00002?ooool00ol0003oooooooooo`06oooo
o`?o00002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Sooooo0004ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Oooooo0_l00009ooooo`03
o`000?oooooooooo08gooooo0003ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo0:7ooooo0003ooooo`04o`000?ooooooooooo`00
00_ooooo00Go0000ooooooooooooooooo`00002Sooooo`000oooool01?l0003oooooooooool0000;
ooooo`04o`000?ooooooooooooooo`;o0000X_ooool000?ooooo00Co0000oooooooooooo00001ooo
ool4o`0000Cooooo00?o0000ooooooooool0XOooool000?ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:7ooooo0004ooooo`;o00002?ooool5
o`0000?ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0=Oooool001Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Uooooo`?o00002Oooool3o`0000Sooooo0_l00009ooooo`;o00002Oooool2o`00
00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool2o`0000So
oooo0ol00006ooooo`Go00001_ooool5o`0000Kooooo1?l00007ooooo`Co00002?ooool3o`0000So
oooo0ol00008ooooo`?o00002?ooool3o`0000Sooooo0_l00009ooooo`;o00002oooool001Kooooo
00?o0000ooooooooool01oooool2o`0000Wooooo0_l00008ooooo`?o00001_ooool3o`0000Sooooo
0_l0000Gooooo`;o00002Oooool2o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo000Eooooo`?o00002?ooool2o`0000Sooooo0_l0
0008ooooo`?o00002?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool001Gooooo0ol00007ooooo`?o00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo08;ooooo000Fooooo`03o`000?oooooooooo0:7ooooo000Fooooo`03
o`000?oooooooooo0:7ooooo000Fooooo`03o`000?oooooooooo0:7ooooo000Fooooo`03o`000?oo
oooooooo0:7ooooo000Fooooo`03o`000?oooooooooo0:7ooooo000Fooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07oooool001Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01[ooooo0ol00008ooooo`?o00002Oooool2o`0000Wo
oooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo0_l00009ooooo`;o00002Oooool2o`0000[o
oooo00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l00009ooooo`;o00001_ooool4o`0000[ooooo
00?o0000ooooooooool01oooool2o`0000Wooooo0_l00009ooooo`;o00002Oooool2o`0000Sooooo
0_l00009ooooo`;o00002Oooool2o`0000Wooooo0_l0000;ooooo`005Oooool3o`0000Sooooo0_l0
0009ooooo`;o00002Oooool2o`0000Sooooo0ol00006ooooo`;o00005oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`;o00002Oooool2o`0000Wooooo0_l00009ooooo`;o00002_ooool001Gooooo0ol00008
ooooo`;o00002?ooool3o`0000Sooooo0_l00008ooooo`?o0000C?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`005_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1gooooo`005_ooool00ol0003oooooooooo`2Qooooo`00
5_ooool00ol0003oooooooooo`2Qooooo`005_ooool00ol0003oooooooooo`2Qooooo`005_ooool0
0ol0003oooooooooo`2Qooooo`003oooool3o`0000Cooooo00?o0000ooooooooool0?Oooool3o`00
00Sooooo0ol0001Fooooo`004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03go
oooo0ol00008ooooo`?o00002?ooool3o`0000Sooooo0_l00009ooooo`;o00002Oooool2o`0002_o
oooo000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`07ooooo`?o00002?ooool3o`0000Sooooo0_l00009ooooo`;o00002Oooool2o`0000Sooooo
0ol00008ooooo`?o00002?ooool3o`0000[ooooo000@ooooo`03o`000?oooooooooo00?ooooo0_l0
0009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`?o00002?ooool3o`0000Sooooo0ol0
000:ooooo`004?ooool00ol0003oooooooooo`02ooooo`?o00002?ooool3o`0000Sooooo0_l00009
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`?o00002_ooool000oooooo0_l00004ooooo`?o00002?ooool3o`0000Sooooo0_l00009oooo
o`;o00002?ooool3o`0004[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0013ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Mooooo`;o00002?ooool3o`0006_ooooo00?o0000oooooooo
ool02Oooool001Kooooo00?o0000ooooooooool0XOooool001Kooooo00?o0000ooooooooool0XOoo
ool001Kooooo00?o0000ooooooooool0XOooool001Kooooo00?o0000ooooooooool0XOooool001Ko
oooo00?o0000ooooooooool0?oooool2o`0000Sooooo0_l0001Fooooo`005_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03Cooooo0ol00007ooooo`?o00002?ooool2o`0000Sooooo
0ol00008ooooo`;o0000=_ooool001Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0:ooooo`;o00001oooool2o`0000Wooooo0ol00008ooooo`;o00002?ooool3o`0000Sooooo0ol0
0008ooooo`;o00002Oooool2o`0000Sooooo0_l0000Fooooo`005Oooool3o`0000Wooooo00?o0000
ooooooooool01oooool2o`0000Wooooo00?o0000ooooooooool02?ooool2o`0000Wooooo1?l00007
ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o00002Oooool2o`0000Wooooo0ol00008
ooooo`;o00002Oooool2o`0000Sooooo0ol00008ooooo`?o00002_ooool001Gooooo0ol00008oooo
o`?o00002?ooool2o`0000Wooooo0_l00009ooooo`?o00002oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0ol00008oooo
o`?o00002_ooool001Kooooo00?o0000ooooooooool01oooool3o`0000Sooooo0ol00008ooooo`?o
00002Oooool3o`0003gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo0_l00009ooooo`;o00002oooool001Kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool001Kooooo00?o0000ooooooooool0XOooool001Kooooo00?o0000ooooooooool0XOooool0
01Kooooo00?o0000ooooooooool0XOooool001Kooooo00?o0000ooooooooool0XOooool001Kooooo
00?o0000ooooooooool0XOooool001Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02[ooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0oooooo`005_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`;o00002oooool2o`0000Oooooo1?l00008ooooo`;o00002?ooool2o`0000Wooooo0_l00008
ooooo`?o00002?ooool00ol0003oooooooooo`07ooooo`;o00008Oooool001Gooooo0ol00008oooo
o`?o00002?ooool2o`0000Wooooo00?o0000ooooooooool02?ooool3o`0000Sooooo1?l00006oooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0000Wooooo0_l00009oooo
o`;o00002?ooool3o`0000Sooooo0ol00008ooooo`;o00002oooool001Gooooo0ol00008ooooo`?o
00002?ooool3o`0000Wooooo00?o0000ooooooooool02?ooool3o`0000[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool2o`0000Wooooo0_l00009ooooo`?o00002?ooool3o`0000Sooooo0_l0000;ooooo`00
5_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o0000
2Oooool2o`0000Sooooo0_l0000<ooooo`000oooool3o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Cooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02oooool000Cooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0XOooool000Cooooo00?o0000
ooooooooool02oooool01?l0003oooooooooooooool2o`000:;ooooo0004ooooo`03o`000?oooooo
oooo00_ooooo00Go0000ooooooooooooooooo`00002Sooooo`001?ooool00ol0003oooooooooo`07
ooooo`Co00001?ooool00ol0003oooooooooo`2Qooooo`000oooool2o`0000Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2Qooooo`001?ooool00ol0003oooooooooo`07ooooo`Go
00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0:_ooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo043ooooo000Eooooo`?o00002Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool3o`0000Wooooo0ol00007ooooo`?o0000
2Oooool2o`0000Sooooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02[ooooo000Eooooo`?o00002?ooool3o`0000Sooooo0_l00009ooooo`;o00002Ooo
ool4o`0000Kooooo1Ol00006ooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`;o00002?oo
ool4o`0000Sooooo0_l00009ooooo`;o00002?ooool2o`0000Wooooo0_l0000:ooooo`03o`000?oo
oooooooo00Wooooo000Fooooo`03o`000?oooooooooo00Oooooo0ol00008ooooo`?o00002Oooool2
o`0000Wooooo0ol0000Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool2
o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo0ol00008ooooo`;o00002?ooool3
o`0000_ooooo000Fooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool2o`00
00Wooooo0_l00009ooooo`?o00002oooool001Kooooo00?o0000ooooooooool0OOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`005_ooool00ol0003ooooo
ooooo`2Booooo`03o`000?oooooooooo00cooooo000Fooooo`03o`000?oooooooooo0:7ooooo000F
ooooo`03o`000?oooooooooo0:7ooooo000Fooooo`03o`000?oooooooooo0:7ooooo000Fooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0Uoooool001Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`07ooooo`;o00002Oooool00ol0003oooooooooo`1:ooooo`005Ooo
ool3o`0000Sooooo0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`?o00002?oo
ool4o`0000Sooooo0_l00008ooooo`?o00002Oooool00ol0003oooooooooo`07ooooo`;o00002Ooo
ool2o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool001Gooooo0ol00008ooooo`?o00002?ooool2
o`0000Wooooo0_l0000:ooooo`?o00002Oooool00ol0003oooooooooo`05ooooo`Co00001_ooool2
o`0000[ooooo0ol00008ooooo`;o00002Oooool2o`0000Sooooo0_l00009ooooo`;o00002_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool3o`0000Wooooo0_l0000:ooooo`03o`000?oooooooooo
02Gooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`00
00Wooooo0_l00008ooooo`;o00002Oooool2o`0000cooooo000Fooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo0_l00009ooooo`03o`000?oooooooooo00Sooooo0ol00008ooooo`;o00003?ooool001Kooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
0_l00009ooooo`;o00003Oooool001Kooooo00?o0000ooooooooool0Qoooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00cooooo000Fooooo`03o`000?oooooooooo0:7ooooo000Foooo
o`03o`000?oooooooooo0:7ooooo000Fooooo`03o`000?oooooooooo0:7ooooo000>ooooo`Go0000
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
S?ooool000oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`;o0000
2?ooool2o`0000Wooooo00?o0000ooooooooool0EOooool0013ooooo00?o0000ooooooooool00_oo
ool3o`0000Sooooo0_l00009ooooo`;o00002Oooool2o`0000Sooooo1?l00007ooooo`Co00001ooo
ool3o`0000Sooooo0_l00009ooooo`;o00002Oooool2o`0000Sooooo00?o0000ooooool000002Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`004Oooool01?l0003oooooooooooooool3o`0000Sooooo0ol0
0008ooooo`?o00002Oooool2o`0000Wooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo1Ol0
0006ooooo`Co00001oooool3o`0000Wooooo0_l00008ooooo`;o00002Oooool2o`0000[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000>
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`;o00002_oo
ool00ol0003oooooooooo`07ooooo`?o00002Oooool2o`0000Sooooo0_l00009ooooo`;o00002_oo
ool00ol0003oooooooooo`0:ooooo`003_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool2o`0000Wooooo0_l00008ooooo`;o00003Oooool000oooooo0ol00004
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool02?ooool2o`0000Wooooo00?o0000
ooooooooool02?ooool2o`0000gooooo000Fooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`;o00003_ooool001Kooooo00?o0000oooooooo
ool0TOooool00ol0003oooooooooo`0=ooooo`005_ooool00ol0003oooooooooo`2Qooooo`005_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09Oooooo000Fooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2<ooooo`005Oooool3o`00
00Sooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo0_l00009ooooo`?o00002Oooool3o`00
00Sooooo0_l00008ooooo`;o0000Eoooool001Gooooo0ol00008ooooo`;o00002Oooool2o`0000So
oooo0ol00008ooooo`Co00001_ooool5o`0000Oooooo0ol00007ooooo`?o00002Oooool2o`0000So
oooo0ol00009ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003ooooo
ooooo`07ooooo`?o00002?ooool3o`0000Sooooo0ol00008ooooo`?o00002Oooool2o`0000Kooooo
1?l00006ooooo`Go00001oooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo
0_l0000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`005_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`;o00002Oooool00ol0003ooooooooo
o`08ooooo`?o00002?ooool2o`0000Wooooo0_l0000:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool001Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`08
ooooo`;o00002Oooool00ol0003oooooooooo`09ooooo`;o00002?ooool2o`0000Sooooo0ol0000=
ooooo`005_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool2o`0000Sooooo0ol0000=ooooo`005_ooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool2o`0000oooooo000Fooooo`03o`00
0?oooooooooo08Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`005_oo
ool00ol0003oooooooooo`2Qooooo`005_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo09Oooooo000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`2<ooooo`005Oooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo00Oo
oooo0ol00008ooooo`?o00002Oooool2o`0000Wooooo00?o0000ooooooooool01oooool2o`0005Oo
oooo000Eooooo`?o00002?ooool3o`0000Sooooo0_l00008ooooo`Co00002?ooool3o`0000Kooooo
1?l00008ooooo`;o00002?ooool3o`0000Sooooo0ol00008ooooo`?o00002Oooool2o`0000Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool04_ooool3o`0000Sooooo0ol0
0009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool4o`0000Kooooo1?l0
0007ooooo`Co00002?ooool00ol0003oooooooooo`07ooooo`;o00002_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`005_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02oooooo0_l0000:
ooooo`?o00002?ooool2o`0000Wooooo00?o0000ooooooooool01oooool2o`0000_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`000_ooool5o`0000?ooooo00?o0000oooo
ooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0Foooool2o`0000Wooooo00?o0000oooo
ooooool02?ooool3o`0000Sooooo0_l00008ooooo`03o`000?oooooo000000[ooooo00?o0000oooo
ooooool02oooool000?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`;o00002Oooool0
0ol0003oooooooooo`08ooooo`;o00002Oooool2o`0000kooooo0004ooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooooooo0_l0001kooooo`03o`000?oooooooooo00Sooooo0_l0000:
ooooo`;o00003_ooool000Gooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo
000008Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`000_ooool01Ol0
003ooooooooooooooooo000000Oooooo1?l00004ooooo`03o`000?oooooooooo08oooooo00?o0000
ooooooooool03oooool000;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Gooooo`000oooool3o`00
00Sooooo1Ol00002ooooo`?o00002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo0_l00023ooooo`005Oooool3o`0000Sooooo0_l00009ooooo`;o00002?ooool3o`0000Oo
oooo0ol0000:ooooo`;o00002?ooool2o`0000Wooooo00?o0000ooooooooool0E_ooool001Kooooo
00?o0000ooooooooool01oooool3o`0000Sooooo0ol00008ooooo`?o00002?ooool3o`0000Kooooo
1?l00007ooooo`?o00002?ooool3o`0000Sooooo0ol00007ooooo`04o`000?oooooo0000o`0000Wo
oooo0_l00009ooooo`03o`000?oooooooooo00Oooooo0_l0000:ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`04ooooo`Go00001_ooool4o`0000Oooooo0ol00008ooooo`;o00002Oooool2o`0000[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02_ooool001Kooooo00?o0000ooooooooool0D?ooool2o`0000Wooooo0ol0
0009ooooo`;o00002?ooool2o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00_ooooo000Fooooo`03o`000?oooooooooo05[ooooo0_l0000:
ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo00Sooooo0_l0000:
ooooo`03o`000?oooooooooo00cooooo000Fooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`?o00002Oooool00ol0003oooooooooo`07oooo
o`;o00003oooool001Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`;o
00002_ooool3o`0000Sooooo0_l0000?ooooo`005_ooool00ol0003oooooooooo`24ooooo`;o0000
2Oooool00ol0003oooooooooo`0?ooooo`005_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo08Cooooo00?o0000ooooooooool04?ooool001Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo08gooooo000Eooooo`?o00002?ooool2o`00
00Sooooo0_l00009ooooo`;o0000Poooool001Gooooo0ol00008ooooo`;o00002?ooool3o`0000So
oooo0ol00007ooooo`Co00002?ooool3o`0000Sooooo0_l00008ooooo`;o0000F?ooool001Kooooo
00?o0000ooooooooool01oooool2o`0000Wooooo0ol00008ooooo`?o00002?ooool2o`0000Kooooo
1Ol00007ooooo`?o00001oooool4o`0000Oooooo1?l00009ooooo`;o00002Oooool2o`0000Sooooo
0_l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool2o`0000_ooooo
000Fooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`Co00001_ooool4o`0000Oooooo1?l0
0008ooooo`;o00002?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo000F
ooooo`03o`000?oooooooooo04oooooo0_l0000:ooooo`?o00002?ooool2o`0000Sooooo0_l0000;
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<
ooooo`005_ooool00ol0003oooooooooo`1Jooooo`;o00002Oooool3o`0000Sooooo0_l00009oooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Fooooo`03
o`000?oooooooooo06Cooooo0_l00009ooooo`03o`000?oooooooooo00Wooooo0_l00008ooooo`;o
00002Oooool00ol0003oooooooooo`0>ooooo`005_ooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool2o`0000Sooooo00?o0000ooooooooool0
3oooool001Kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo0ol0000@ooooo`005_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo00Oooooo0_l0000Booooo`003oooool3o`0000Cooooo00?o0000ooooooooool0XOooool000ko
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0:7ooooo000Booooo`05
o`000?ooooooooooooooool00000Xoooool0013ooooo0_l00004ooooo`;o0000X_ooool001;ooooo
00?o0000ooooooooool0YOooool000kooooo00Go0000ooooooooooooooooo`00002Wooooo`003ooo
ool3o`000:Sooooo002Aooooo`?o00009_ooool009;ooooo00?o0000ooooooooool09Oooool001_o
oooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol00004ooooo`;o00000oooool3o`0000;o
oooo0ol00009ooooo`Go000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool5o`0000;o
oooo1?l00007ooooo`Go00000_ooool3o`0000;ooooo0ol00009ooooo`Co00000_ooool5o`000003
ooooool0003o000000;o00001?ooool01?l0003oooooooooooooool4o`0000Cooooo0_l00003oooo
o`?o00000_ooool01Ol0003oooooo`000?oooooo000000cooooo000Kooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Sooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000_o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Gooooo
00Go0000ooooool0003oooooo`00000<ooooo`006oooool01?l0003oooooooooooooool5o`000003
ooooool0003ooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
ooooo`Go00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00002oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooo0000
00?ooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo1Ol000001_oooooo0000ooooool0003o
ooooo`0000cooooo000Jooooo`03o`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000?ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00;ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0000:ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000[ooooo00Co0000oooooooo
oooo00000_ooool3o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000002oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool02ol0003ooooooooooooooooo
0000ooooool0003oooooo`000?oooooo000000cooooo000Jooooo`03o`000?oooooo000000?ooooo
0ol00003ooooo`?o00000_ooool4o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
2?ooool4o`000004ooooool0003o0000o`0000Cooooo0ol00004ooooo`03o`000?oooooooooo00;o
oooo0ol00009ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool4o`000004ooooool0003o0000
ooooo`;o00000_ooool4o`000003ooooool0003o000000;o00000oooool3o`0000;ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`006_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0001Cooooo00?o0000ooooooooool06Oooool001Wooooo1Ol0000>ooooo`03o`000?oooooo
oooo01Oooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo0ol00005ooooo`;o00002oooool2
o`0001?ooooo1?l00002ooooo`Go00005?ooool00ol0003oooooooooo`0Iooooo`00^_ooool00;[o
oooo0000\
\>"],
  ImageRangeCache->{{{77.875, 262.875}, {286.875, 97.875}} -> {-1.84345, \
1.59717, 0.0183962, 0.0183962}}]
}, Open  ]],

Cell["\<\
And here is the trajectory, making its way through the vector \
field. The solution is periodic.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ vf,
      ParametricPlot[ Evaluate[{x[t],y[t]}/.soln], {t,0,20}, 
                  PlotStyle->RGBColor[0,1,0] ],
      PlotLabel->\"Field and Flow\" ]\
\>", "Input",
  CellLabel->"In[7]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.02184 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.330852 0.0243294 0.330852 [
[.18924 .01183 -9 -9 ]
[.18924 .01183 9 0 ]
[.35466 .01183 -3 -9 ]
[.35466 .01183 3 0 ]
[.52009 .01183 -9 -9 ]
[.52009 .01183 9 0 ]
[.68551 .01183 -3 -9 ]
[.68551 .01183 3 0 ]
[.85094 .01183 -9 -9 ]
[.85094 .01183 9 0 ]
[.01131 .18976 -18 -4.5 ]
[.01131 .18976 0 4.5 ]
[.01131 .35518 -6 -4.5 ]
[.01131 .35518 0 4.5 ]
[.01131 .52061 -18 -4.5 ]
[.01131 .52061 0 4.5 ]
[.01131 .68603 -6 -4.5 ]
[.01131 .68603 0 4.5 ]
[.01131 .85146 -18 -4.5 ]
[.01131 .85146 0 4.5 ]
[.01131 1.01689 -6 -4.5 ]
[.01131 1.01689 0 4.5 ]
[.5 1.03434 -44 0 ]
[.5 1.03434 44 12 ]
[ 0 0 0 0 ]
[ 1 1.02184 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18924 .02433 m
.18924 .03058 L
s
[(0.5)] .18924 .01183 0 1 Mshowa
.35466 .02433 m
.35466 .03058 L
s
[(1)] .35466 .01183 0 1 Mshowa
.52009 .02433 m
.52009 .03058 L
s
[(1.5)] .52009 .01183 0 1 Mshowa
.68551 .02433 m
.68551 .03058 L
s
[(2)] .68551 .01183 0 1 Mshowa
.85094 .02433 m
.85094 .03058 L
s
[(2.5)] .85094 .01183 0 1 Mshowa
.125 Mabswid
.05689 .02433 m
.05689 .02808 L
s
.08998 .02433 m
.08998 .02808 L
s
.12307 .02433 m
.12307 .02808 L
s
.15615 .02433 m
.15615 .02808 L
s
.22232 .02433 m
.22232 .02808 L
s
.25541 .02433 m
.25541 .02808 L
s
.28849 .02433 m
.28849 .02808 L
s
.32158 .02433 m
.32158 .02808 L
s
.38775 .02433 m
.38775 .02808 L
s
.42083 .02433 m
.42083 .02808 L
s
.45392 .02433 m
.45392 .02808 L
s
.487 .02433 m
.487 .02808 L
s
.55317 .02433 m
.55317 .02808 L
s
.58626 .02433 m
.58626 .02808 L
s
.61934 .02433 m
.61934 .02808 L
s
.65243 .02433 m
.65243 .02808 L
s
.7186 .02433 m
.7186 .02808 L
s
.75168 .02433 m
.75168 .02808 L
s
.78477 .02433 m
.78477 .02808 L
s
.81786 .02433 m
.81786 .02808 L
s
.88403 .02433 m
.88403 .02808 L
s
.91711 .02433 m
.91711 .02808 L
s
.9502 .02433 m
.9502 .02808 L
s
.98328 .02433 m
.98328 .02808 L
s
.25 Mabswid
0 .02433 m
1 .02433 L
s
.02381 .18976 m
.03006 .18976 L
s
[(0.5)] .01131 .18976 1 0 Mshowa
.02381 .35518 m
.03006 .35518 L
s
[(1)] .01131 .35518 1 0 Mshowa
.02381 .52061 m
.03006 .52061 L
s
[(1.5)] .01131 .52061 1 0 Mshowa
.02381 .68603 m
.03006 .68603 L
s
[(2)] .01131 .68603 1 0 Mshowa
.02381 .85146 m
.03006 .85146 L
s
[(2.5)] .01131 .85146 1 0 Mshowa
.02381 1.01689 m
.03006 1.01689 L
s
[(3)] .01131 1.01689 1 0 Mshowa
.125 Mabswid
.02381 .05741 m
.02756 .05741 L
s
.02381 .0905 m
.02756 .0905 L
s
.02381 .12359 m
.02756 .12359 L
s
.02381 .15667 m
.02756 .15667 L
s
.02381 .22284 m
.02756 .22284 L
s
.02381 .25593 m
.02756 .25593 L
s
.02381 .28901 m
.02756 .28901 L
s
.02381 .3221 m
.02756 .3221 L
s
.02381 .38827 m
.02756 .38827 L
s
.02381 .42135 m
.02756 .42135 L
s
.02381 .45444 m
.02756 .45444 L
s
.02381 .48752 m
.02756 .48752 L
s
.02381 .55369 m
.02756 .55369 L
s
.02381 .58678 m
.02756 .58678 L
s
.02381 .61986 m
.02756 .61986 L
s
.02381 .65295 m
.02756 .65295 L
s
.02381 .71912 m
.02756 .71912 L
s
.02381 .7522 m
.02756 .7522 L
s
.02381 .78529 m
.02756 .78529 L
s
.02381 .81838 m
.02756 .81838 L
s
.02381 .88455 m
.02756 .88455 L
s
.02381 .91763 m
.02756 .91763 L
s
.02381 .95072 m
.02756 .95072 L
s
.02381 .9838 m
.02756 .9838 L
s
.25 Mabswid
.02381 0 m
.02381 1.02184 L
s
gsave
.5 1.03434 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Field) show
99.000 13.000 moveto
(and) show
123.000 13.000 moveto
(Flow) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.02381 .02433 m
.02381 .02433 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.02381 .0905 m
.02381 .08864 L
s
% Start of user PostScript
0 0.2 0 0.194388 MAarrowhead1
% End of user PostScript
.02381 .15667 m
.02381 .15296 L
s
% Start of user PostScript
0 0.4 0 0.388776 MAarrowhead1
% End of user PostScript
.02381 .22284 m
.02381 .21727 L
s
% Start of user PostScript
0 0.6 0 0.583164 MAarrowhead1
% End of user PostScript
.02381 .28901 m
.02381 .28158 L
s
% Start of user PostScript
0 0.8 0 0.777552 MAarrowhead1
% End of user PostScript
.02381 .35518 m
.02381 .3459 L
s
% Start of user PostScript
0 1. 0 0.97194 MAarrowhead1
% End of user PostScript
.02381 .42135 m
.02381 .41021 L
s
% Start of user PostScript
0 1.2 0 1.16633 MAarrowhead1
% End of user PostScript
.02381 .48752 m
.02381 .47453 L
s
% Start of user PostScript
0 1.4 0 1.36072 MAarrowhead1
% End of user PostScript
.02381 .55369 m
.02381 .53884 L
s
% Start of user PostScript
0 1.6 0 1.5551 MAarrowhead1
% End of user PostScript
.02381 .61986 m
.02381 .60315 L
s
% Start of user PostScript
0 1.8 0 1.74949 MAarrowhead1
% End of user PostScript
.02381 .68603 m
.02381 .66747 L
s
% Start of user PostScript
0 2. 0 1.94388 MAarrowhead1
% End of user PostScript
.02381 .7522 m
.02381 .73178 L
s
% Start of user PostScript
0 2.2 0 2.13827 MAarrowhead1
% End of user PostScript
.02381 .81838 m
.02381 .79609 L
s
% Start of user PostScript
0 2.4 0 2.33266 MAarrowhead1
% End of user PostScript
.02381 .88455 m
.02381 .86041 L
s
% Start of user PostScript
0 2.6 0 2.52704 MAarrowhead1
% End of user PostScript
.02381 .95072 m
.02381 .92472 L
s
% Start of user PostScript
0 2.8 0 2.72143 MAarrowhead1
% End of user PostScript
.08998 .02433 m
.09184 .02433 L
s
% Start of user PostScript
0.2 0 0.205612 0 MAarrowhead1
% End of user PostScript
.08998 .0905 m
.09147 .08901 L
s
% Start of user PostScript
0.2 0.2 0.20449 0.19551 MAarrowhead1
% End of user PostScript
.08998 .15667 m
.09109 .1537 L
s
% Start of user PostScript
0.2 0.4 0.203367 0.391021 MAarrowhead1
% End of user PostScript
.08998 .22284 m
.09072 .21838 L
s
% Start of user PostScript
0.2 0.6 0.202245 0.586531 MAarrowhead1
% End of user PostScript
.08998 .28901 m
.09035 .28307 L
s
% Start of user PostScript
0.2 0.8 0.201122 0.782042 MAarrowhead1
% End of user PostScript
.08998 .35518 m
.08998 .34775 L
s
% Start of user PostScript
0.2 1. 0.2 0.977552 MAarrowhead1
% End of user PostScript
.08998 .42135 m
.08961 .41244 L
s
% Start of user PostScript
0.2 1.2 0.198878 1.17306 MAarrowhead1
% End of user PostScript
.08998 .48752 m
.08924 .47713 L
s
% Start of user PostScript
0.2 1.4 0.197755 1.36857 MAarrowhead1
% End of user PostScript
.08998 .55369 m
.08887 .54181 L
s
% Start of user PostScript
0.2 1.6 0.196633 1.56408 MAarrowhead1
% End of user PostScript
.08998 .61986 m
.08849 .6065 L
s
% Start of user PostScript
0.2 1.8 0.19551 1.75959 MAarrowhead1
% End of user PostScript
.08998 .68603 m
.08812 .67118 L
s
% Start of user PostScript
0.2 2. 0.194388 1.9551 MAarrowhead1
% End of user PostScript
.08998 .7522 m
.08775 .73587 L
s
% Start of user PostScript
0.2 2.2 0.193266 2.15061 MAarrowhead1
% End of user PostScript
.08998 .81838 m
.08738 .80055 L
s
% Start of user PostScript
0.2 2.4 0.192143 2.34613 MAarrowhead1
% End of user PostScript
.08998 .88455 m
.08701 .86524 L
s
% Start of user PostScript
0.2 2.6 0.191021 2.54164 MAarrowhead1
% End of user PostScript
.08998 .95072 m
.08664 .92992 L
s
% Start of user PostScript
0.2 2.8 0.189898 2.73715 MAarrowhead1
% End of user PostScript
.15615 .02433 m
.15986 .02433 L
s
% Start of user PostScript
0.4 0 0.411224 0 MAarrowhead1
% End of user PostScript
.15615 .0905 m
.15912 .08939 L
s
% Start of user PostScript
0.4 0.2 0.408979 0.196633 MAarrowhead1
% End of user PostScript
.15615 .15667 m
.15838 .15444 L
s
% Start of user PostScript
0.4 0.4 0.406734 0.393266 MAarrowhead1
% End of user PostScript
.15615 .22284 m
.15764 .2195 L
s
% Start of user PostScript
0.4 0.6 0.40449 0.589898 MAarrowhead1
% End of user PostScript
.15615 .28901 m
.15689 .28456 L
s
% Start of user PostScript
0.4 0.8 0.402245 0.786531 MAarrowhead1
% End of user PostScript
.15615 .35518 m
.15615 .34961 L
s
% Start of user PostScript
0.4 1. 0.4 0.983164 MAarrowhead1
% End of user PostScript
.15615 .42135 m
.15541 .41467 L
s
% Start of user PostScript
0.4 1.2 0.397755 1.1798 MAarrowhead1
% End of user PostScript
.15615 .48752 m
.15467 .47972 L
s
% Start of user PostScript
0.4 1.4 0.39551 1.37643 MAarrowhead1
% End of user PostScript
.15615 .55369 m
.15392 .54478 L
s
% Start of user PostScript
0.4 1.6 0.393266 1.57306 MAarrowhead1
% End of user PostScript
.15615 .61986 m
.15318 .60984 L
s
% Start of user PostScript
0.4 1.8 0.391021 1.7697 MAarrowhead1
% End of user PostScript
.15615 .68603 m
.15244 .67489 L
s
% Start of user PostScript
0.4 2. 0.388776 1.96633 MAarrowhead1
% End of user PostScript
.15615 .7522 m
.15169 .73995 L
s
% Start of user PostScript
0.4 2.2 0.386531 2.16296 MAarrowhead1
% End of user PostScript
.15615 .81838 m
.15095 .80501 L
s
% Start of user PostScript
0.4 2.4 0.384287 2.35959 MAarrowhead1
% End of user PostScript
.15615 .88455 m
.15021 .87006 L
s
% Start of user PostScript
0.4 2.6 0.382042 2.55623 MAarrowhead1
% End of user PostScript
.15615 .95072 m
.14947 .93512 L
s
% Start of user PostScript
0.4 2.8 0.379797 2.75286 MAarrowhead1
% End of user PostScript
.22232 .02433 m
.22789 .02433 L
s
% Start of user PostScript
0.6 0 0.616836 0 MAarrowhead1
% End of user PostScript
.22232 .0905 m
.22678 .08976 L
s
% Start of user PostScript
0.6 0.2 0.613469 0.197755 MAarrowhead1
% End of user PostScript
.22232 .15667 m
.22566 .15518 L
s
% Start of user PostScript
0.6 0.4 0.610102 0.39551 MAarrowhead1
% End of user PostScript
.22232 .22284 m
.22455 .22061 L
s
% Start of user PostScript
0.6 0.6 0.606734 0.593266 MAarrowhead1
% End of user PostScript
.22232 .28901 m
.22344 .28604 L
s
% Start of user PostScript
0.6 0.8 0.603367 0.791021 MAarrowhead1
% End of user PostScript
.22232 .35518 m
.22232 .35147 L
s
% Start of user PostScript
0.6 1. 0.6 0.988776 MAarrowhead1
% End of user PostScript
.22232 .42135 m
.22121 .4169 L
s
% Start of user PostScript
0.6 1.2 0.596633 1.18653 MAarrowhead1
% End of user PostScript
.22232 .48752 m
.22009 .48232 L
s
% Start of user PostScript
0.6 1.4 0.593266 1.38429 MAarrowhead1
% End of user PostScript
.22232 .55369 m
.21898 .54775 L
s
% Start of user PostScript
0.6 1.6 0.589898 1.58204 MAarrowhead1
% End of user PostScript
.22232 .61986 m
.21786 .61318 L
s
% Start of user PostScript
0.6 1.8 0.586531 1.7798 MAarrowhead1
% End of user PostScript
.22232 .68603 m
.21675 .67861 L
s
% Start of user PostScript
0.6 2. 0.583164 1.97755 MAarrowhead1
% End of user PostScript
.22232 .7522 m
.21564 .74404 L
s
% Start of user PostScript
0.6 2.2 0.579797 2.17531 MAarrowhead1
% End of user PostScript
.22232 .81838 m
.21452 .80946 L
s
% Start of user PostScript
0.6 2.4 0.57643 2.37306 MAarrowhead1
% End of user PostScript
.22232 .88455 m
.21341 .87489 L
s
% Start of user PostScript
0.6 2.6 0.573063 2.57082 MAarrowhead1
% End of user PostScript
.22232 .95072 m
.21229 .94032 L
s
% Start of user PostScript
0.6 2.8 0.569695 2.76857 MAarrowhead1
% End of user PostScript
.28849 .02433 m
.29592 .02433 L
s
% Start of user PostScript
0.8 0 0.822448 0 MAarrowhead1
% End of user PostScript
.28849 .0905 m
.29443 .09013 L
s
% Start of user PostScript
0.8 0.2 0.817958 0.198878 MAarrowhead1
% End of user PostScript
.28849 .15667 m
.29295 .15593 L
s
% Start of user PostScript
0.8 0.4 0.813469 0.397755 MAarrowhead1
% End of user PostScript
.28849 .22284 m
.29146 .22173 L
s
% Start of user PostScript
0.8 0.6 0.808979 0.596633 MAarrowhead1
% End of user PostScript
.28849 .28901 m
.28998 .28753 L
s
% Start of user PostScript
0.8 0.8 0.80449 0.79551 MAarrowhead1
% End of user PostScript
.28849 .35518 m
.28849 .35333 L
s
% Start of user PostScript
0.8 1. 0.8 0.994388 MAarrowhead1
% End of user PostScript
.28849 .42135 m
.28701 .41912 L
s
% Start of user PostScript
0.8 1.2 0.79551 1.19327 MAarrowhead1
% End of user PostScript
.28849 .48752 m
.28552 .48492 L
s
% Start of user PostScript
0.8 1.4 0.791021 1.39214 MAarrowhead1
% End of user PostScript
.28849 .55369 m
.28404 .55072 L
s
% Start of user PostScript
0.8 1.6 0.786531 1.59102 MAarrowhead1
% End of user PostScript
.28849 .61986 m
.28255 .61652 L
s
% Start of user PostScript
0.8 1.8 0.782042 1.7899 MAarrowhead1
% End of user PostScript
.28849 .68603 m
.28106 .68232 L
s
% Start of user PostScript
0.8 2. 0.777552 1.98878 MAarrowhead1
% End of user PostScript
.28849 .7522 m
.27958 .74812 L
s
% Start of user PostScript
0.8 2.2 0.773063 2.18765 MAarrowhead1
% End of user PostScript
.28849 .81838 m
.27809 .81392 L
s
% Start of user PostScript
0.8 2.4 0.768573 2.38653 MAarrowhead1
% End of user PostScript
.28849 .88455 m
.27661 .87972 L
s
% Start of user PostScript
0.8 2.6 0.764083 2.58541 MAarrowhead1
% End of user PostScript
.28849 .95072 m
.27512 .94552 L
s
% Start of user PostScript
0.8 2.8 0.759594 2.78429 MAarrowhead1
% End of user PostScript
.35466 .02433 m
.36395 .02433 L
s
% Start of user PostScript
1. 0 1.02806 0 MAarrowhead1
% End of user PostScript
.35466 .0905 m
.36209 .0905 L
s
% Start of user PostScript
1. 0.2 1.02245 0.2 MAarrowhead1
% End of user PostScript
.35466 .15667 m
.36023 .15667 L
s
% Start of user PostScript
1. 0.4 1.01684 0.4 MAarrowhead1
% End of user PostScript
.35466 .22284 m
.35838 .22284 L
s
% Start of user PostScript
1. 0.6 1.01122 0.6 MAarrowhead1
% End of user PostScript
.35466 .28901 m
.35652 .28901 L
s
% Start of user PostScript
1. 0.8 1.00561 0.8 MAarrowhead1
% End of user PostScript
.35466 .35518 m
.35466 .35518 L
s
% Start of user PostScript
1. 1. MAarrowzero1
% End of user PostScript
.35466 .42135 m
.35281 .42135 L
s
% Start of user PostScript
1. 1.2 0.994388 1.2 MAarrowhead1
% End of user PostScript
.35466 .48752 m
.35095 .48752 L
s
% Start of user PostScript
1. 1.4 0.988776 1.4 MAarrowhead1
% End of user PostScript
.35466 .55369 m
.34909 .55369 L
s
% Start of user PostScript
1. 1.6 0.983164 1.6 MAarrowhead1
% End of user PostScript
.35466 .61986 m
.34724 .61986 L
s
% Start of user PostScript
1. 1.8 0.977552 1.8 MAarrowhead1
% End of user PostScript
.35466 .68603 m
.34538 .68603 L
s
% Start of user PostScript
1. 2. 0.97194 2. MAarrowhead1
% End of user PostScript
.35466 .7522 m
.34352 .7522 L
s
% Start of user PostScript
1. 2.2 0.966328 2.2 MAarrowhead1
% End of user PostScript
.35466 .81838 m
.34166 .81838 L
s
% Start of user PostScript
1. 2.4 0.960716 2.4 MAarrowhead1
% End of user PostScript
.35466 .88455 m
.33981 .88455 L
s
% Start of user PostScript
1. 2.6 0.955104 2.6 MAarrowhead1
% End of user PostScript
.35466 .95072 m
.33795 .95072 L
s
% Start of user PostScript
1. 2.8 0.949492 2.8 MAarrowhead1
% End of user PostScript
.42083 .02433 m
.43197 .02433 L
s
% Start of user PostScript
1.2 0 1.23367 0 MAarrowhead1
% End of user PostScript
.42083 .0905 m
.42974 .09087 L
s
% Start of user PostScript
1.2 0.2 1.22694 0.201122 MAarrowhead1
% End of user PostScript
.42083 .15667 m
.42752 .15741 L
s
% Start of user PostScript
1.2 0.4 1.2202 0.402245 MAarrowhead1
% End of user PostScript
.42083 .22284 m
.42529 .22395 L
s
% Start of user PostScript
1.2 0.6 1.21347 0.603367 MAarrowhead1
% End of user PostScript
.42083 .28901 m
.42306 .2905 L
s
% Start of user PostScript
1.2 0.8 1.20673 0.80449 MAarrowhead1
% End of user PostScript
.42083 .35518 m
.42083 .35704 L
s
% Start of user PostScript
1.2 1. 1.2 1.00561 MAarrowhead1
% End of user PostScript
.42083 .42135 m
.4186 .42358 L
s
% Start of user PostScript
1.2 1.2 1.19327 1.20673 MAarrowhead1
% End of user PostScript
.42083 .48752 m
.41638 .49012 L
s
% Start of user PostScript
1.2 1.4 1.18653 1.40786 MAarrowhead1
% End of user PostScript
.42083 .55369 m
.41415 .55666 L
s
% Start of user PostScript
1.2 1.6 1.1798 1.60898 MAarrowhead1
% End of user PostScript
.42083 .61986 m
.41192 .62321 L
s
% Start of user PostScript
1.2 1.8 1.17306 1.8101 MAarrowhead1
% End of user PostScript
.42083 .68603 m
.40969 .68975 L
s
% Start of user PostScript
1.2 2. 1.16633 2.01122 MAarrowhead1
% End of user PostScript
.42083 .7522 m
.40746 .75629 L
s
% Start of user PostScript
1.2 2.2 1.15959 2.21235 MAarrowhead1
% End of user PostScript
.42083 .81838 m
.40524 .82283 L
s
% Start of user PostScript
1.2 2.4 1.15286 2.41347 MAarrowhead1
% End of user PostScript
.42083 .88455 m
.40301 .88937 L
s
% Start of user PostScript
1.2 2.6 1.14613 2.61459 MAarrowhead1
% End of user PostScript
.42083 .95072 m
.40078 .95591 L
s
% Start of user PostScript
1.2 2.8 1.13939 2.81571 MAarrowhead1
% End of user PostScript
.487 .02433 m
.5 .02433 L
s
% Start of user PostScript
1.4 0 1.43928 0 MAarrowhead1
% End of user PostScript
.487 .0905 m
.4974 .09124 L
s
% Start of user PostScript
1.4 0.2 1.43143 0.202245 MAarrowhead1
% End of user PostScript
.487 .15667 m
.4948 .15816 L
s
% Start of user PostScript
1.4 0.4 1.42357 0.40449 MAarrowhead1
% End of user PostScript
.487 .22284 m
.4922 .22507 L
s
% Start of user PostScript
1.4 0.6 1.41571 0.606734 MAarrowhead1
% End of user PostScript
.487 .28901 m
.4896 .29198 L
s
% Start of user PostScript
1.4 0.8 1.40786 0.808979 MAarrowhead1
% End of user PostScript
.487 .35518 m
.487 .3589 L
s
% Start of user PostScript
1.4 1. 1.4 1.01122 MAarrowhead1
% End of user PostScript
.487 .42135 m
.4844 .42581 L
s
% Start of user PostScript
1.4 1.2 1.39214 1.21347 MAarrowhead1
% End of user PostScript
.487 .48752 m
.4818 .49272 L
s
% Start of user PostScript
1.4 1.4 1.38429 1.41571 MAarrowhead1
% End of user PostScript
.487 .55369 m
.4792 .55963 L
s
% Start of user PostScript
1.4 1.6 1.37643 1.61796 MAarrowhead1
% End of user PostScript
.487 .61986 m
.47661 .62655 L
s
% Start of user PostScript
1.4 1.8 1.36857 1.8202 MAarrowhead1
% End of user PostScript
.487 .68603 m
.47401 .69346 L
s
% Start of user PostScript
1.4 2. 1.36072 2.02245 MAarrowhead1
% End of user PostScript
.487 .7522 m
.47141 .76037 L
s
% Start of user PostScript
1.4 2.2 1.35286 2.22469 MAarrowhead1
% End of user PostScript
.487 .81838 m
.46881 .82729 L
s
% Start of user PostScript
1.4 2.4 1.345 2.42694 MAarrowhead1
% End of user PostScript
.487 .88455 m
.46621 .8942 L
s
% Start of user PostScript
1.4 2.6 1.33715 2.62918 MAarrowhead1
% End of user PostScript
.487 .95072 m
.46361 .96111 L
s
% Start of user PostScript
1.4 2.8 1.32929 2.83143 MAarrowhead1
% End of user PostScript
.55317 .02433 m
.56803 .02433 L
s
% Start of user PostScript
1.6 0 1.6449 0 MAarrowhead1
% End of user PostScript
.55317 .0905 m
.56506 .09161 L
s
% Start of user PostScript
1.6 0.2 1.63592 0.203367 MAarrowhead1
% End of user PostScript
.55317 .15667 m
.56209 .1589 L
s
% Start of user PostScript
1.6 0.4 1.62694 0.406734 MAarrowhead1
% End of user PostScript
.55317 .22284 m
.55911 .22618 L
s
% Start of user PostScript
1.6 0.6 1.61796 0.610102 MAarrowhead1
% End of user PostScript
.55317 .28901 m
.55614 .29347 L
s
% Start of user PostScript
1.6 0.8 1.60898 0.813469 MAarrowhead1
% End of user PostScript
.55317 .35518 m
.55317 .36075 L
s
% Start of user PostScript
1.6 1. 1.6 1.01684 MAarrowhead1
% End of user PostScript
.55317 .42135 m
.5502 .42804 L
s
% Start of user PostScript
1.6 1.2 1.59102 1.2202 MAarrowhead1
% End of user PostScript
.55317 .48752 m
.54723 .49532 L
s
% Start of user PostScript
1.6 1.4 1.58204 1.42357 MAarrowhead1
% End of user PostScript
.55317 .55369 m
.54426 .56261 L
s
% Start of user PostScript
1.6 1.6 1.57306 1.62694 MAarrowhead1
% End of user PostScript
.55317 .61986 m
.54129 .62989 L
s
% Start of user PostScript
1.6 1.8 1.56408 1.8303 MAarrowhead1
% End of user PostScript
.55317 .68603 m
.53832 .69717 L
s
% Start of user PostScript
1.6 2. 1.5551 2.03367 MAarrowhead1
% End of user PostScript
.55317 .7522 m
.53535 .76446 L
s
% Start of user PostScript
1.6 2.2 1.54613 2.23704 MAarrowhead1
% End of user PostScript
.55317 .81838 m
.53238 .83174 L
s
% Start of user PostScript
1.6 2.4 1.53715 2.44041 MAarrowhead1
% End of user PostScript
.55317 .88455 m
.52941 .89903 L
s
% Start of user PostScript
1.6 2.6 1.52817 2.64377 MAarrowhead1
% End of user PostScript
.55317 .95072 m
.52644 .96631 L
s
% Start of user PostScript
1.6 2.8 1.51919 2.84714 MAarrowhead1
% End of user PostScript
.61934 .02433 m
.63605 .02433 L
s
% Start of user PostScript
1.8 0 1.85051 0 MAarrowhead1
% End of user PostScript
.61934 .0905 m
.63271 .09199 L
s
% Start of user PostScript
1.8 0.2 1.84041 0.20449 MAarrowhead1
% End of user PostScript
.61934 .15667 m
.62937 .15964 L
s
% Start of user PostScript
1.8 0.4 1.8303 0.408979 MAarrowhead1
% End of user PostScript
.61934 .22284 m
.62603 .2273 L
s
% Start of user PostScript
1.8 0.6 1.8202 0.613469 MAarrowhead1
% End of user PostScript
.61934 .28901 m
.62269 .29495 L
s
% Start of user PostScript
1.8 0.8 1.8101 0.817958 MAarrowhead1
% End of user PostScript
.61934 .35518 m
.61934 .36261 L
s
% Start of user PostScript
1.8 1. 1.8 1.02245 MAarrowhead1
% End of user PostScript
.61934 .42135 m
.616 .43026 L
s
% Start of user PostScript
1.8 1.2 1.7899 1.22694 MAarrowhead1
% End of user PostScript
.61934 .48752 m
.61266 .49792 L
s
% Start of user PostScript
1.8 1.4 1.7798 1.43143 MAarrowhead1
% End of user PostScript
.61934 .55369 m
.60932 .56558 L
s
% Start of user PostScript
1.8 1.6 1.7697 1.63592 MAarrowhead1
% End of user PostScript
.61934 .61986 m
.60598 .63323 L
s
% Start of user PostScript
1.8 1.8 1.75959 1.84041 MAarrowhead1
% End of user PostScript
.61934 .68603 m
.60263 .70089 L
s
% Start of user PostScript
1.8 2. 1.74949 2.0449 MAarrowhead1
% End of user PostScript
.61934 .7522 m
.59929 .76854 L
s
% Start of user PostScript
1.8 2.2 1.73939 2.24939 MAarrowhead1
% End of user PostScript
.61934 .81838 m
.59595 .8362 L
s
% Start of user PostScript
1.8 2.4 1.72929 2.45387 MAarrowhead1
% End of user PostScript
.61934 .88455 m
.59261 .90386 L
s
% Start of user PostScript
1.8 2.6 1.71919 2.65836 MAarrowhead1
% End of user PostScript
.61934 .95072 m
.58926 .97151 L
s
% Start of user PostScript
1.8 2.8 1.70909 2.86285 MAarrowhead1
% End of user PostScript
.68551 .02433 m
.70408 .02433 L
s
% Start of user PostScript
2. 0 2.05612 0 MAarrowhead1
% End of user PostScript
.68551 .0905 m
.70037 .09236 L
s
% Start of user PostScript
2. 0.2 2.0449 0.205612 MAarrowhead1
% End of user PostScript
.68551 .15667 m
.69665 .16038 L
s
% Start of user PostScript
2. 0.4 2.03367 0.411224 MAarrowhead1
% End of user PostScript
.68551 .22284 m
.69294 .22841 L
s
% Start of user PostScript
2. 0.6 2.02245 0.616836 MAarrowhead1
% End of user PostScript
.68551 .28901 m
.68923 .29644 L
s
% Start of user PostScript
2. 0.8 2.01122 0.822448 MAarrowhead1
% End of user PostScript
.68551 .35518 m
.68551 .36447 L
s
% Start of user PostScript
2. 1. 2. 1.02806 MAarrowhead1
% End of user PostScript
.68551 .42135 m
.6818 .43249 L
s
% Start of user PostScript
2. 1.2 1.98878 1.23367 MAarrowhead1
% End of user PostScript
.68551 .48752 m
.67809 .50052 L
s
% Start of user PostScript
2. 1.4 1.97755 1.43928 MAarrowhead1
% End of user PostScript
.68551 .55369 m
.67437 .56855 L
s
% Start of user PostScript
2. 1.6 1.96633 1.6449 MAarrowhead1
% End of user PostScript
.68551 .61986 m
.67066 .63657 L
s
% Start of user PostScript
2. 1.8 1.9551 1.85051 MAarrowhead1
% End of user PostScript
.68551 .68603 m
.66695 .7046 L
s
% Start of user PostScript
2. 2. 1.94388 2.05612 MAarrowhead1
% End of user PostScript
.68551 .7522 m
.66323 .77263 L
s
% Start of user PostScript
2. 2.2 1.93266 2.26173 MAarrowhead1
% End of user PostScript
.68551 .81838 m
.65952 .84066 L
s
% Start of user PostScript
2. 2.4 1.92143 2.46734 MAarrowhead1
% End of user PostScript
.68551 .88455 m
.65581 .90868 L
s
% Start of user PostScript
2. 2.6 1.91021 2.67296 MAarrowhead1
% End of user PostScript
.68551 .95072 m
.65209 .97671 L
s
% Start of user PostScript
2. 2.8 1.89898 2.87857 MAarrowhead1
% End of user PostScript
.75168 .02433 m
.77211 .02433 L
s
% Start of user PostScript
2.2 0 2.26173 0 MAarrowhead1
% End of user PostScript
.75168 .0905 m
.76802 .09273 L
s
% Start of user PostScript
2.2 0.2 2.24939 0.206734 MAarrowhead1
% End of user PostScript
.75168 .15667 m
.76394 .16113 L
s
% Start of user PostScript
2.2 0.4 2.23704 0.413469 MAarrowhead1
% End of user PostScript
.75168 .22284 m
.75985 .22953 L
s
% Start of user PostScript
2.2 0.6 2.22469 0.620203 MAarrowhead1
% End of user PostScript
.75168 .28901 m
.75577 .29792 L
s
% Start of user PostScript
2.2 0.8 2.21235 0.826937 MAarrowhead1
% End of user PostScript
.75168 .35518 m
.75168 .36632 L
s
% Start of user PostScript
2.2 1. 2.2 1.03367 MAarrowhead1
% End of user PostScript
.75168 .42135 m
.7476 .43472 L
s
% Start of user PostScript
2.2 1.2 2.18765 1.24041 MAarrowhead1
% End of user PostScript
.75168 .48752 m
.74352 .50312 L
s
% Start of user PostScript
2.2 1.4 2.17531 1.44714 MAarrowhead1
% End of user PostScript
.75168 .55369 m
.73943 .57152 L
s
% Start of user PostScript
2.2 1.6 2.16296 1.65387 MAarrowhead1
% End of user PostScript
.75168 .61986 m
.73535 .63992 L
s
% Start of user PostScript
2.2 1.8 2.15061 1.86061 MAarrowhead1
% End of user PostScript
.75168 .68603 m
.73126 .70831 L
s
% Start of user PostScript
2.2 2. 2.13827 2.06734 MAarrowhead1
% End of user PostScript
.75168 .7522 m
.72718 .77671 L
s
% Start of user PostScript
2.2 2.2 2.12592 2.27408 MAarrowhead1
% End of user PostScript
.75168 .81838 m
.72309 .84511 L
s
% Start of user PostScript
2.2 2.4 2.11358 2.48081 MAarrowhead1
% End of user PostScript
.75168 .88455 m
.71901 .91351 L
s
% Start of user PostScript
2.2 2.6 2.10123 2.68755 MAarrowhead1
% End of user PostScript
.75168 .95072 m
.71492 .98191 L
s
% Start of user PostScript
2.2 2.8 2.08888 2.89428 MAarrowhead1
% End of user PostScript
.81786 .02433 m
.84014 .02433 L
s
% Start of user PostScript
2.4 0 2.46734 0 MAarrowhead1
% End of user PostScript
.81786 .0905 m
.83568 .0931 L
s
% Start of user PostScript
2.4 0.2 2.45387 0.207857 MAarrowhead1
% End of user PostScript
.81786 .15667 m
.83122 .16187 L
s
% Start of user PostScript
2.4 0.4 2.44041 0.415713 MAarrowhead1
% End of user PostScript
.81786 .22284 m
.82677 .23064 L
s
% Start of user PostScript
2.4 0.6 2.42694 0.62357 MAarrowhead1
% End of user PostScript
.81786 .28901 m
.82231 .29941 L
s
% Start of user PostScript
2.4 0.8 2.41347 0.831427 MAarrowhead1
% End of user PostScript
.81786 .35518 m
.81786 .36818 L
s
% Start of user PostScript
2.4 1. 2.4 1.03928 MAarrowhead1
% End of user PostScript
.81786 .42135 m
.8134 .43695 L
s
% Start of user PostScript
2.4 1.2 2.38653 1.24714 MAarrowhead1
% End of user PostScript
.81786 .48752 m
.80894 .50572 L
s
% Start of user PostScript
2.4 1.4 2.37306 1.455 MAarrowhead1
% End of user PostScript
.81786 .55369 m
.80449 .57449 L
s
% Start of user PostScript
2.4 1.6 2.35959 1.66285 MAarrowhead1
% End of user PostScript
.81786 .61986 m
.80003 .64326 L
s
% Start of user PostScript
2.4 1.8 2.34613 1.87071 MAarrowhead1
% End of user PostScript
.81786 .68603 m
.79557 .71203 L
s
% Start of user PostScript
2.4 2. 2.33266 2.07857 MAarrowhead1
% End of user PostScript
.81786 .7522 m
.79112 .7808 L
s
% Start of user PostScript
2.4 2.2 2.31919 2.28642 MAarrowhead1
% End of user PostScript
.81786 .81838 m
.78666 .84957 L
s
% Start of user PostScript
2.4 2.4 2.30572 2.49428 MAarrowhead1
% End of user PostScript
.81786 .88455 m
.78221 .91834 L
s
% Start of user PostScript
2.4 2.6 2.29225 2.70214 MAarrowhead1
% End of user PostScript
.81786 .95072 m
.77775 .98711 L
s
% Start of user PostScript
2.4 2.8 2.27878 2.90999 MAarrowhead1
% End of user PostScript
.88403 .02433 m
.90816 .02433 L
s
% Start of user PostScript
2.6 0 2.67296 0 MAarrowhead1
% End of user PostScript
.88403 .0905 m
.90334 .09347 L
s
% Start of user PostScript
2.6 0.2 2.65836 0.208979 MAarrowhead1
% End of user PostScript
.88403 .15667 m
.89851 .16261 L
s
% Start of user PostScript
2.6 0.4 2.64377 0.417958 MAarrowhead1
% End of user PostScript
.88403 .22284 m
.89368 .23175 L
s
% Start of user PostScript
2.6 0.6 2.62918 0.626937 MAarrowhead1
% End of user PostScript
.88403 .28901 m
.88885 .30089 L
s
% Start of user PostScript
2.6 0.8 2.61459 0.835917 MAarrowhead1
% End of user PostScript
.88403 .35518 m
.88403 .37004 L
s
% Start of user PostScript
2.6 1. 2.6 1.0449 MAarrowhead1
% End of user PostScript
.88403 .42135 m
.8792 .43918 L
s
% Start of user PostScript
2.6 1.2 2.58541 1.25387 MAarrowhead1
% End of user PostScript
.88403 .48752 m
.87437 .50832 L
s
% Start of user PostScript
2.6 1.4 2.57082 1.46285 MAarrowhead1
% End of user PostScript
.88403 .55369 m
.86954 .57746 L
s
% Start of user PostScript
2.6 1.6 2.55623 1.67183 MAarrowhead1
% End of user PostScript
.88403 .61986 m
.86472 .6466 L
s
% Start of user PostScript
2.6 1.8 2.54164 1.88081 MAarrowhead1
% End of user PostScript
.88403 .68603 m
.85989 .71574 L
s
% Start of user PostScript
2.6 2. 2.52704 2.08979 MAarrowhead1
% End of user PostScript
.88403 .7522 m
.85506 .78488 L
s
% Start of user PostScript
2.6 2.2 2.51245 2.29877 MAarrowhead1
% End of user PostScript
.88403 .81838 m
.85023 .85402 L
s
% Start of user PostScript
2.6 2.4 2.49786 2.50775 MAarrowhead1
% End of user PostScript
.88403 .88455 m
.84541 .92317 L
s
% Start of user PostScript
2.6 2.6 2.48327 2.71673 MAarrowhead1
% End of user PostScript
.88403 .95072 m
.84058 .99231 L
s
% Start of user PostScript
2.6 2.8 2.46868 2.92571 MAarrowhead1
% End of user PostScript
.9502 .02433 m
.97619 .02433 L
s
% Start of user PostScript
2.8 0 2.87857 0 MAarrowhead1
% End of user PostScript
.9502 .0905 m
.97099 .09384 L
s
% Start of user PostScript
2.8 0.2 2.86285 0.210102 MAarrowhead1
% End of user PostScript
.9502 .15667 m
.96579 .16335 L
s
% Start of user PostScript
2.8 0.4 2.84714 0.420203 MAarrowhead1
% End of user PostScript
.9502 .22284 m
.96059 .23287 L
s
% Start of user PostScript
2.8 0.6 2.83143 0.630305 MAarrowhead1
% End of user PostScript
.9502 .28901 m
.9554 .30238 L
s
% Start of user PostScript
2.8 0.8 2.81571 0.840406 MAarrowhead1
% End of user PostScript
.9502 .35518 m
.9502 .37189 L
s
% Start of user PostScript
2.8 1. 2.8 1.05051 MAarrowhead1
% End of user PostScript
.9502 .42135 m
.945 .4414 L
s
% Start of user PostScript
2.8 1.2 2.78429 1.26061 MAarrowhead1
% End of user PostScript
.9502 .48752 m
.9398 .51092 L
s
% Start of user PostScript
2.8 1.4 2.76857 1.47071 MAarrowhead1
% End of user PostScript
.9502 .55369 m
.9346 .58043 L
s
% Start of user PostScript
2.8 1.6 2.75286 1.68081 MAarrowhead1
% End of user PostScript
.9502 .61986 m
.9294 .64994 L
s
% Start of user PostScript
2.8 1.8 2.73715 1.89091 MAarrowhead1
% End of user PostScript
.9502 .68603 m
.9242 .71946 L
s
% Start of user PostScript
2.8 2. 2.72143 2.10102 MAarrowhead1
% End of user PostScript
.9502 .7522 m
.919 .78897 L
s
% Start of user PostScript
2.8 2.2 2.70572 2.31112 MAarrowhead1
% End of user PostScript
.9502 .81838 m
.9138 .85848 L
s
% Start of user PostScript
2.8 2.4 2.69001 2.52122 MAarrowhead1
% End of user PostScript
.9502 .88455 m
.90861 .92799 L
s
% Start of user PostScript
2.8 2.6 2.67429 2.73132 MAarrowhead1
% End of user PostScript
.9502 .95072 m
.90341 .99751 L
s
% Start of user PostScript
2.8 2.8 2.65858 2.94142 MAarrowhead1
% End of user PostScript
0 1 0 r
.5 Mabswid
.15615 .15667 m
.16429 .14929 L
.17259 .14306 L
.18345 .13639 L
.19431 .131 L
.20596 .1263 L
.21979 .12182 L
.23584 .11777 L
.25248 .11456 L
.27096 .1119 L
.28223 .11066 L
.29329 .10968 L
.30549 .10883 L
.31717 .10823 L
.32383 .10797 L
.33129 .10774 L
.33476 .10766 L
.3385 .10759 L
.34208 .10754 L
.34536 .1075 L
.35183 .10746 L
.35514 .10745 L
.35881 .10746 L
.3654 .10751 L
.37167 .1076 L
.37553 .10767 L
.37922 .10775 L
.38624 .10793 L
.4025 .10852 L
.41723 .10924 L
.43133 .1101 L
.46488 .11273 L
.49725 .11607 L
.53416 .12087 L
.60562 .13353 L
.64906 .14389 L
.69546 .15794 L
.73466 .17313 L
.77577 .19395 L
.7948 .20612 L
.81411 .22097 L
.82971 .23563 L
.84442 .25291 L
.85579 .27016 L
.861 .27999 L
.8659 .29111 L
.8697 .30182 L
.87257 .31206 L
.87483 .32278 L
.87638 .33337 L
Mistroke
.87745 .34722 L
.87754 .3603 L
.87723 .36779 L
.87658 .37606 L
.87457 .39151 L
.87168 .40659 L
.86755 .42306 L
.85733 .45389 L
.84072 .49187 L
.82075 .52881 L
.76047 .61558 L
.69368 .69029 L
.61262 .76293 L
.5343 .81769 L
.498 .83792 L
.46517 .85314 L
.437 .86367 L
.40817 .87173 L
.39327 .87471 L
.37816 .87683 L
.36571 .87783 L
.35259 .87812 L
.33916 .87752 L
.32747 .8762 L
.31456 .8738 L
.30296 .87073 L
.29267 .86722 L
.2836 .86346 L
.26448 .85322 L
.24674 .84053 L
.23209 .82726 L
.20391 .79285 L
.18286 .75696 L
.16662 .72084 L
.15237 .68064 L
.14033 .63783 L
.13008 .59183 L
.1228 .55081 L
.11783 .51631 L
.1138 .48177 L
.1106 .44616 L
.10953 .43115 L
.10861 .41563 L
.10793 .40142 L
.10748 .38891 L
.10731 .38303 L
.10716 .37674 L
.10706 .37091 L
.10699 .36561 L
.10694 .35955 L
Mistroke
.10693 .35397 L
.10696 .34795 L
.10703 .34161 L
.10715 .33512 L
.1073 .32908 L
.10769 .31806 L
.10796 .31238 L
.10829 .30638 L
.109 .29583 L
.11071 .27724 L
.11191 .26732 L
.11334 .25732 L
.11635 .24058 L
.11965 .22633 L
.1232 .21406 L
.13298 .18952 L
.1391 .17842 L
.1466 .16753 L
.15401 .15887 L
.16274 .15058 L
.17141 .14387 L
.18195 .13723 L
.20323 .12732 L
.21661 .12276 L
.23207 .11863 L
.24646 .11562 L
.26356 .11287 L
.28373 .11051 L
.29584 .10948 L
.30737 .10872 L
.31861 .10817 L
.32515 .10792 L
.33132 .10774 L
.33682 .10762 L
.34299 .10752 L
.34956 .10747 L
.35583 .10745 L
.36244 .10748 L
.36619 .10752 L
.36962 .10756 L
.3764 .10768 L
.38289 .10784 L
.39791 .10833 L
.41479 .10911 L
.44741 .11125 L
.47943 .11414 L
.54573 .12261 L
.58145 .1287 L
.62202 .13717 L
.66605 .14862 L
Mistroke
.70793 .16238 L
.74486 .17774 L
.78304 .19836 L
.8204 .22653 L
.83679 .24342 L
.85231 .26437 L
.86303 .28432 L
.86789 .29643 L
.87155 .3081 L
.87421 .31945 L
.87627 .33241 L
.87736 .34522 L
.87759 .3576 L
.87692 .37211 L
.8762 .37964 L
.8751 .38809 L
.87235 .40347 L
.86884 .41833 L
.85747 .45352 L
.8399 .49354 L
.79359 .57118 L
.73726 .64342 L
.67359 .70992 L
.5987 .77375 L
.52741 .82179 L
.46446 .85344 L
.43167 .86537 L
.41673 .86964 L
.40323 .87281 L
.389 .8754 L
.37397 .87724 L
.35988 .87806 L
.34545 .87792 L
.33323 .87694 L
.32055 .87504 L
.30909 .87247 L
.29897 .86946 L
.28095 .86223 L
.26343 .85257 L
.24587 .83981 L
.22891 .82401 L
.20278 .79119 L
.17812 .74729 L
.16049 .70468 L
.14749 .66447 L
.13651 .62194 L
.12244 .54852 L
.11658 .50643 L
.11256 .46918 L
.10998 .43778 L
Mistroke
.10898 .42218 L
.10814 .40607 L
.1078 .39823 L
.10754 .39095 L
.10733 .38399 L
.10718 .37768 L
.10707 .37179 L
.10699 .36565 L
.10694 .3596 L
.10694 .35305 L
.10695 .34965 L
.10698 .34612 L
.10706 .33991 L
.10712 .33649 L
.10719 .33336 L
.10738 .32636 L
.10783 .31499 L
.10848 .30336 L
.10933 .29173 L
.11045 .27973 L
.11301 .25946 L
.11617 .24148 L
.11965 .22634 L
.1236 .21281 L
.12846 .19954 L
.139 .17858 L
.14662 .1675 L
.15476 .15808 L
.16282 .15052 L
.17267 .143 L
.19393 .13118 L
.20736 .1258 L
.22125 .12141 L
.23439 .11809 L
.2494 .11509 L
.2673 .11236 L
.28516 .11038 L
.2958 .10948 L
.30629 .10878 L
.31608 .10828 L
.3271 .10786 L
.33299 .1077 L
.3396 .10757 L
.34298 .10752 L
.34666 .10749 L
.35342 .10745 L
.36028 .10747 L
.36692 .10753 L
.373 .10762 L
.37975 .10776 L
Mistroke
.38677 .10795 L
.39351 .10817 L
.40642 .1087 L
.43687 .11047 L
.4649 .11273 L
.49697 .11604 L
.56888 .12642 L
.61248 .13502 L
.65442 .14533 L
.6992 .15924 L
.73948 .17527 L
.76109 .18578 L
.78368 .19876 L
.80238 .2116 L
.82107 .22715 L
.83661 .24321 L
.84914 .25953 L
.85934 .27667 L
.8679 .29645 L
.87144 .30772 L
.87307 .31414 L
.87438 .32036 L
.87632 .33286 L
.87733 .34471 L
.87758 .35178 L
.87756 .35943 L
.8768 .37359 L
.87596 .38171 L
.87489 .38946 L
.87145 .40765 L
.86721 .42427 L
.86129 .44302 L
.84695 .4787 L
.80781 .54987 L
.7438 .63581 L
.67133 .71205 L
.59455 .77688 L
.55374 .80549 L
.51149 .8308 L
.47566 .84861 L
.43825 .86325 L
.42253 .86808 L
.40622 .87217 L
.39135 .87503 L
.37825 .87682 L
.36492 .87787 L
.3513 .8781 L
.34011 .87759 L
.32824 .87631 L
.31604 .87413 L
Mistroke
.30943 .87256 L
.30353 .8709 L
.29235 .8671 L
.28245 .86293 L
.26477 .85341 L
.24721 .84091 L
.21952 .81354 L
.20534 .79494 L
.19367 .77671 L
.1716 .73285 L
.15623 .6925 L
.14333 .64946 L
.12721 .57669 L
.12075 .53742 L
.11611 .50247 L
.11239 .46734 L
.11087 .44968 L
.10956 .43158 L
.10865 .41637 L
.10788 .40018 L
.10762 .39329 L
.10739 .386 L
.10722 .37929 L
.10709 .37315 L
.10701 .36724 L
.10695 .36103 L
.10693 .35427 L
.10696 .34824 L
.10702 .34207 L
.10708 .33864 L
.10714 .33551 L
.10728 .32984 L
.10746 .32395 L
.10789 .31387 L
.10839 .30476 L
.10991 .28515 L
.11099 .27478 L
.11212 .2657 L
Mfstroke
0 0 m
1 0 L
1 1.02184 L
0 1.02184 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{188.812, 192.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002l0000`2000`400?l00000o`00003o_?ooool0
02_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Booooo`?o00004oooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`00017ooooo1Ol0000Aooooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00005Oooool002[ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000001;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000004Oooool01?l0003oooooooooool0000Booooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Dooooo`00:_ooool01?l0003o
ooooooooool0000;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo000Zooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04_ooool002[ooooo00Co0000oooooooooooo00001oooool4o`00
01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`Co00004Oooool01Ol0
003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`000007ooooo`Co00005Ooo
ool002[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Cooooo`;o00005?oo
ool2o`0000Wooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo0000017ooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Kooooo000Fooooo`03o`00
0?oooooooooo01;ooooo0_l00008ooooo`Go00004_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Oooooo1Ol0000Aooooo`?o00004oooool3o`0000Sooooo1Ol0000Dooooo`005_oo
ool00ol0003oooooooooo`2Sooooo`005_ooool00ol0003oooooooooo`2Sooooo`005_ooool00ol0
003oooooooooo`05ooooo`?o00002?ooool3o`0000Wooooo0ol00008ooooo`?o00002?ooool3o`00
00Wooooo0ol00008ooooo`?o00002?ooool3o`0000Wooooo0ol00008ooooo`?o00002Oooool3o`00
00Sooooo0ol00008ooooo`?o00002Oooool3o`0000Oooooo000BooooojSo00000_ooool001Kooooo
00?o0000ooooooooool01Oooool2o`0000Wooooo0_l00007ooooo`03o`000?oooooooooo00;o0000
2Oooool2o`0000Wooooo0ol00009ooooo`;o00002Oooool2o`0000Gooooo00Co0000oooooooooooo
oooo0_l0000:ooooo`;o00002Oooool2o`0000[ooooo0_l00009ooooo`;o00000oooool00ol0003o
ooooooooo`03ooooo`;o00002_ooool2o`0000Sooooo000Fooooo`03o`000?oooooooooo0:?ooooo
000Fooooo`03o`000?oooooooooo0:?ooooo000Fooooo`03o`000?oooooooooo0:?ooooo000Foooo
o`;o0000Y?ooool001Kooooo00?o0000ooooooooool0Xoooool001Kooooo00?o0000ooooooooool0
Xoooool001Kooooo00?o0000ooooooooool0Xoooool001Kooooo00?o0000ooooooooool0Xoooool0
01Kooooo00?o0000ooooooooool06oooool3o`0000Wooooo0ol00008ooooo`?o00002?ooool3o`00
00Wooooo0ol00008ooooo`?o00002?ooool3o`0000Wooooo0ol00008ooooo`?o00002?ooool3o`00
00Wooooo0ol00008ooooo`?o00002?ooool001Kooooo0_l00008ooooo`;o00001oooool4o`0000Oo
oooo1Ol00007ooooo`Co00001oooool4o`0000Oooooo1Ol00007ooooo`Co00001oooool4o`0000Oo
oooo1Ol00007ooooo`Co00001oooool4o`0000Oooooo1Ol00007ooooo`Co00001oooool4o`0000Oo
oooo000Fooooo`03o`000?oooooooooo00Gooooo1?l00007ooooo`?o00002Oooool2o`0000Wooooo
0_l00009ooooo`;o00002Oooool2o`0000[ooooo0_l00009ooooo`;o00002Oooool2o`0000[ooooo
0_l00009ooooo`;o00002Oooool2o`0000Wooooo0_l0000:ooooo`;o00002Oooool001Gooooo0ol0
0006ooooo`?o00002Oooool00ol0003oooooooooo`2?ooooo`005Oooool3o`0000Oooooo00?o0000
ooooooooool07?oooolVo`3o05Sooooo000Fooooo`03o`000?oooooooooo01oooooo2?l0o`0Qoooo
o`So0?l0Doooool001Kooooo0_l0000Mooooo`?o0?l0<Oooool8o`3o04_ooooo000Fooooo`03o`00
0?oooooooooo01[ooooo0ol0o`0iooooo`Oo0?l0A_ooool001Kooooo00?o0000ooooooooool06?oo
ool3o`3o047ooooo1_l0o`11ooooo`005_ooool00ol0003oooooooooo`0Gooooo`03o`3o0?oooooo
oooo04Kooooo1_l0o`0mooooo`005_ooool00ol0003oooooooooo`0Eooooo`;o0?l0COooool6o`3o
03Wooooo000Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
0?l0ooooo`0@ooooo`?o00002Oooool3o`0000Sooooo0ol00008ooooo`?o00002Oooool3o`0000So
oooo0ol00006ooooo`Go0?l02Oooool2o`0000Wooooo0_l00009ooooo`;o00002_ooool00ol0003o
ooooooooo`08ooooo`005_ooool2o`0000Wooooo00?o0000ooooooooool02?ooool00ol0o`3ooooo
ooooo`05ooooo`Go00001_ooool5o`0000Oooooo1?l00007ooooo`Co00001oooool5o`0000Kooooo
1Ol00007ooooo`Co00001oooool2o`0000Co0?l01Oooool4o`0000Oooooo1?l00008ooooo`?o0000
2?ooool3o`0000Wooooo000Fooooo`03o`000?oooooooooo00Oooooo0_l00009ooooo`03o`3o0?l0
003ooooo00Kooooo0ol00009ooooo`;o00002Oooool2o`0003_ooooo0ol0o`06ooooo`;o00002Ooo
ool2o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`005Oooool3
o`0000Oooooo0ol00008ooooo`03o`3o0?l0003ooooo00Sooooo00?o0000ooooooooool0Doooool3
o`3o02kooooo0004ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`00
00Wooooo00?o0000ooooooooool01Oooool00ol0o`3oooooo`00001Qooooo`?o0?l0;?ooool000?o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool04?ooool00ol0o`3oooooooooo`1Sooooo`?o0?l0:_ooool000?ooooo00Co0000oooo
oooooooo00002oooool01?l0003oooooooooooooool2o`00013ooooo00?o0?l0ooooooooool0I_oo
ool3o`3o02Sooooo0003ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000oooooooooooooooo
o`00000Aooooo`03o`3o0?oooooooooo06Sooooo0ol0o`0Vooooo`000oooool01?l0003ooooooooo
ool00007ooooo`Co00001?ooool00ol0003oooooooooo`0>ooooo`03o`3o0?oooooooooo06_ooooo
0_l0o`0Uooooo`000oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03_ooool00ol0o`3oooooooooo`1]ooooo`03o`3o0?oooooooooo02;ooooo
0004ooooo`;o00002?ooool5o`0000?ooooo00?o0000ooooooooool03Oooool2o`3o03Wooooo0_l0
000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo00?o0?l0ooooool000008Oooool001Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`;o0?l01?ooool00ol0003oooooooooo`0K
ooooo`?o00002Oooool3o`0000Sooooo0ol00009ooooo`;o00002Oooool2o`0000[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`3o0?l0003ooooo00Wooooo00?o0000
ooooooooool02?ooool2o`0000[ooooo000Fooooo`;o00002Oooool00ol0003oooooooooo`02oooo
o`03o`3o0?oooooooooo00?ooooo00?o0000ooooooooool01oooool2o`0000Oooooo1Ol00006oooo
o`Go00001_ooool5o`0000Oooooo1?l00007ooooo`Co00001oooool4o`0000Sooooo0ol00008oooo
o`?o00002?ooool00ol0003o0?l0o`3o0008ooooo`?o00002?ooool3o`0000[ooooo000Eooooo`?o
00002?ooool2o`0000Cooooo00?o0?l0ooooooooool00_ooool2o`0000Oooooo1?l00007ooooo`?o
00002?ooool2o`0002kooooo0_l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool2o`3o00[ooooo00?o0000ooooooooool01oooool2o`0000Wooooo000Eooooo`?o0000
2?ooool2o`0000?ooooo00?o0?l0ooooooooool00_ooool3o`0000Sooooo0_l00009ooooo`03o`00
0?oooooooooo05[ooooo00?o0?l0ooooooooool04_ooool00ol0003oooooooooo`07ooooo`005_oo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool0o`001_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo06Cooooo0_l0o`0Mooooo`005_ooool00ol0003ooooooooo
o`0<ooooo`03o`3o0?oooooooooo07Kooooo00?o0?l0ooooooooool06oooool001Kooooo0_l0000=
ooooo`03o`3o0?oooooooooo07Oooooo00?o0?l0ooooooooool06_ooool001Kooooo00?o0000oooo
ooooool03?ooool00ol0o`3oooooooooo`1gooooo`;o0?l06oooool001Kooooo00?o0000oooooooo
ool03?ooool00ol0o`3oooooooooo`1hooooo`03o`3o0?oooooooooo01Wooooo000Fooooo`03o`00
0?oooooooooo00_ooooo0_l0o`0looooo`03o`000?oooooooooo03_ooooo0_l0o`0Jooooo`005_oo
ool00ol0003oooooooooo`0;ooooo`03o`3o0?oooooooooo02oooooo0_l0000:ooooo`03o`000?oo
oooooooo00Oooooo0ol00009ooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`;o00002Ooo
ool2o`0000Gooooo0_l0o`0Iooooo`005_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`3o00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`?o00002?oo
ool4o`0000Sooooo0ol00009ooooo`;o00002Oooool2o`0000Wooooo0_l00009ooooo`?o00002?oo
ool3o`0000Kooooo00?o0?l0ooooool000000_l00009ooooo`;o00002_ooool001Kooooo0_l00009
ooooo`04o`000?ooooooooooo`3o00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`;o00001oooool4o`0000[ooooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo0_l0
0009ooooo`;o00002Oooool2o`0000Sooooo0ol00006ooooo`;o0?l00ol00009ooooo`;o00002_oo
ool001Gooooo0ol00008ooooo`?o000000?oooooo`3o0?ooool01Oooool2o`0000Wooooo0_l00008
ooooo`?o00001oooool2o`0002?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool2o`0000Oooooo00Co0?l0
ooooool0003o00002_ooool2o`0000Wooooo000Eooooo`?o00002?ooool3o`000003ooooool0o`3o
oooo00Gooooo0_l00008ooooo`?o00001oooool3o`0005Wooooo00?o0000ooooooooool01Oooool0
1?l0o`3oooooooooool0000;ooooo`03o`000?oooooooooo00Oooooo000Fooooo`03o`000?oooooo
oooo00_ooooo00?o0?l0ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Goooool2o`3o01Oooooo000Fooooo`03o`000?oooooooooo
00_ooooo00?o0?l0ooooooooool0OOooool00ol0o`3oooooooooo`0Eooooo`005_ooool2o`0000co
oooo00?o0?l0ooooooooool0OOooool00ol0o`3oooooooooo`0Eooooo`005_ooool00ol0003ooooo
ooooo`0;ooooo`03o`3o0?oooooooooo07gooooo00?o0?l0ooooooooool05Oooool001Kooooo00?o
0000ooooooooool02oooool00ol0o`3oooooooooo`1mooooo`03o`3o0?oooooooooo01Gooooo000F
ooooo`03o`000?oooooooooo00_ooooo00?o0?l0ooooooooool0<?ooool3o`0000Sooooo0ol0000o
ooooo`03o`3o0?oooooooooo01Gooooo000?ooooo`?o00001?ooool00ol0003oooooooooo`0;oooo
o`03o`3o0?oooooooooo033ooooo0ol00008ooooo`?o00002?ooool3o`0000Wooooo0_l00009oooo
o`;o00007oooool00ol0o`3oooooooooo`0Dooooo`004?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo0?l01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool3o`0000Sooooo0ol00009oooo
o`;o00002Oooool2o`0000Wooooo0_l00009ooooo`;o00002Oooool00ol0o`3o0000ooooo`08oooo
o`?o00002Oooool0013ooooo00?o0000ooooooooool00oooool2o`0000Wooooo00Co0000oooooooo
oooo0?l01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0_l00009oooo
o`;o00002Oooool2o`0000Wooooo00?o0?l0o`000?ooool02?ooool3o`0000Wooooo000@ooooo`03
o`000?oooooooooo00;ooooo0ol00008ooooo`?o000000?oooooo`3o0?ooool01Oooool3o`0000Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`3o0?l0003ooooo00So
oooo0ol00009ooooo`004?ooool00ol0003oooooooooo`02ooooo`?o00002?ooool3o`000003oooo
ool0o`3ooooo00Gooooo0ol00008ooooo`?o00002?ooool3o`00043ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0_l0o`000ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo000?ooooo`;o00001Oooool00ol0003ooooooooo
o`0;ooooo`03o`3o0?oooooooooo00oooooo0ol00008ooooo`?o0000H?ooool00ol0o`3ooooooooo
o`0:ooooo`03o`000?oooooooooo00Sooooo000@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02oooool00ol0o`3oooooooooo`1mooooo`03o`3o0?oooooooooo01Gooooo000Foooo
o`03o`000?oooooooooo00_ooooo00?o0?l0ooooooooool0OOooool00ol0o`3oooooooooo`0Eoooo
o`005_ooool2o`0000cooooo00?o0?l0ooooooooool0OOooool00ol0o`3oooooooooo`0Eooooo`00
5_ooool00ol0003oooooooooo`0;ooooo`03o`3o0?oooooooooo07gooooo00?o0?l0ooooooooool0
5Oooool001Kooooo00?o0000ooooooooool02oooool00ol0o`3oooooooooo`0cooooo`03o`000?oo
oooooooo04Oooooo00?o0?l0ooooooooool05Oooool001Kooooo00?o0000ooooooooool02oooool0
0ol0o`3oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`?o00002?ooool2
o`0002Wooooo00?o0?l0ooooooooool05Oooool001Kooooo00?o0000ooooooooool02?ooool01?l0
003oooooooooool0o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool2
o`0000Sooooo0ol00008ooooo`;o00002?ooool3o`0000Sooooo0ol00008ooooo`?o00002?ooool3
o`0000Sooooo0_l00007ooooo`;o0?l05oooool001Kooooo0_l00009ooooo`04o`000?oooooooooo
o`3o00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o00002Oooool4
o`0000Oooooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo0ol00008ooooo`?o00002?ooool3
o`0000Sooooo0ol00006ooooo`04o`3o0?oooooo0000o`0000Wooooo0_l0000:ooooo`005Oooool3
o`0000Sooooo0ol000000ooooooo0?l0ooooo`05ooooo`?o00002Oooool2o`0000Wooooo0ol0000;
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`;o00002Oooool2o`0000Wooooo0_l00009ooooo`?o00001_ooool01?l0o`3oooooo`000?l0
0009ooooo`;o00002_ooool001Gooooo0ol00008ooooo`?o000000?oooooo`3o0?ooool01Oooool3
o`0000Wooooo0_l0000:ooooo`?o0000<oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool2o`0000Kooooo0_l0o`000ooooooo0000ooooo`09
ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo00_ooooo00?o0?l0oooo
ooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool01Oooool01?l0o`3oooooooooool0000:ooooo`03o`000?oooooooooo00Wooooo000Foooo
o`03o`000?oooooooooo00_ooooo00?o0?l0ooooooooool0Noooool00ol0o`3oooooooooo`0Goooo
o`005_ooool00ol0003oooooooooo`0;ooooo`03o`3o0?oooooooooo07[ooooo0_l0o`0Iooooo`00
5_ooool2o`0000cooooo0_l0o`1kooooo`03o`3o0?oooooooooo01Sooooo000Fooooo`03o`000?oo
oooooooo00_ooooo0_l0o`1jooooo`;o0?l06_ooool001Kooooo00?o0000ooooooooool03?ooool0
0ol0o`3oooooooooo`1hooooo`03o`3o0?oooooooooo01Wooooo000Fooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`3o000dooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0]ooooo`;o0?l06oooool001Kooooo00?o0000oooo
ooooool02?ooool01Ol0003ooooooooooooooooo0?l000Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Eooooo`;o00002?ooool2o`0000Wooooo0_l00009ooooo`;o00002?ooool2
o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0?l0ooooooooool06_ooool0
01Gooooo0ol00009ooooo`05o`000?ooooooooooooooool0o`001_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo0ol00008ooooo`Co00001oooool4o`0000Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`?o00002?ooool3o`0000Sooooo0_l00009
ooooo`;o00000oooool00ol0o`3oooooooooo`03ooooo`;o00002_ooool00ol0003oooooooooo`08
ooooo`005Oooool3o`0000Sooooo0ol00002ooooo`03o`3o0?oooooooooo00Cooooo0_l00009oooo
o`;o00002Oooool4o`0000[ooooo00?o0000ooooooooool01?ooool2o`0000Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`;o00002Oooool2o`0000[ooooo0_l00009oooo
o`;o00000_ooool00ol0o`3oooooooooo`04ooooo`;o00002Oooool2o`0000[ooooo000Fooooo`03
o`000?oooooooooo00Oooooo0ol00002ooooo`03o`3o0?oooooooooo00Cooooo0_l00009ooooo`?o
00002Oooool3o`0003;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o
00002Oooool2o`0000?ooooo00?o0?l0ooooooooool01?ooool2o`0000Wooooo0_l0000:ooooo`00
0oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0
3?ooool2o`3o013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`3o0006ooooo`;o00002Oooool2o`0000_o
oooo0004ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00cooooo0_l0o`1fooooo`03o`3o0?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`001?ooool00ol0003oooooooooo`0;ooooo`05o`00
0?ooooooooooooooool000003_ooool2o`3o07Gooooo00?o0?l0ooooooooool07Oooool000Cooooo
00?o0000ooooooooool02oooool01?l0003oooooooooooooool2o`0000gooooo0_l0o`1eooooo`03
o`3o0?oooooooooo01gooooo0004ooooo`03o`000?oooooooooo00Oooooo1?l00004ooooo`03o`00
0?oooooooooo00gooooo00?o0?l0ooooooooool0L_ooool00ol0o`3oooooooooo`0Nooooo`000ooo
ool2o`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`3o0?oo
oooooooo077ooooo0_l0o`0Pooooo`001?ooool00ol0003oooooooooo`07ooooo`Go00000oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool0>oooool0
0ol0003oooooooooo`0cooooo`03o`3o0?oooooooooo01oooooo000Fooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05?ooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`;o0?l08Oooool001Go
oooo0ol00009ooooo`;o00000oooool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool3o`0000Sooooo1Ol00007ooooo`?o00002?ooool3o`0000So
oooo0ol00008ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`;o00002?ooool00ol0o`3o
0000o`00000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool001Gooooo
0ol00008ooooo`?o00000oooool2o`3o00Cooooo0_l00009ooooo`;o00002_ooool3o`0000Wooooo
0_l00006ooooo`;o00002Oooool2o`0000[ooooo00?o0000ooooooooool01oooool2o`0000[ooooo
0_l00009ooooo`;o00001oooool2o`3o00;o00002?ooool3o`0000Sooooo00?o0000ooooool00000
2_ooool001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o0?l01?oo
ool2o`0000Wooooo0ol0000:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`;o0?l00_l0
0009ooooo`?o00002?ooool2o`0000_ooooo000Fooooo`03o`000?oooooooooo00kooooo00?o0?l0
ooooooooool03Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0o`3o0000o`000009ooooo`;o00002_ooool2o`0000_ooooo000Foooo
o`03o`000?oooooooooo00kooooo00?o0?l0ooooooooool0K?ooool2o`3o0003o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool2o`0000cooooo000Fooooo`03o`000?oooooooooo00ko
oooo00?o0?l0ooooooooool0Joooool2o`3o01Oooooo00?o0000ooooooooool02oooool001Kooooo
0_l0000?ooooo`;o0?l0K?ooool00ol0o`3oooooooooo`0Tooooo`005_ooool00ol0003ooooooooo
o`0?ooooo`03o`3o0?oooooooooo06Wooooo00?o0?l0ooooooooool09Oooool001Kooooo00?o0000
ooooooooool03oooool00ol0o`3oooooooooo`1Xooooo`03o`3o0?oooooooooo02Kooooo000Foooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0o`3oooooooooo`1Woooo
o`;o0?l0:?ooool001Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`05
o`3o0?ooooooooooooooool000002Oooool00ol0003oooooooooo`0Eooooo`;o00002Oooool2o`00
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`3o0?oooooooooo
02Oooooo000Eooooo`?o00002?ooool3o`0000Kooooo00Co0?l0oooooooooooo00002Oooool2o`00
00Wooooo0ol00008ooooo`Co00002?ooool3o`0000Sooooo0ol00008ooooo`;o00002Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000o`3o0?ooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool001Go
oooo0ol00008ooooo`?o00001_ooool00ol0o`3oooooooooo`02o`0000Wooooo0_l0000:ooooo`;o
00002_ooool00ol0003oooooooooo`05ooooo`;o00002Oooool2o`0000Wooooo00?o0000oooooooo
ool02?ooool3o`0000Wooooo0_l00008ooooo`;o00000_l0o`07ooooo`03o`000?oooooo000000[o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003ooooo
ooooo`0@ooooo`03o`3o0?oooooooooo00;o00002Oooool3o`0000[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`08ooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`03o`00
0?l0o`3o0?l000Sooooo0_l00009ooooo`;o00002?ooool3o`0000_ooooo000Fooooo`03o`000?oo
oooooooo013ooooo00?o0?l0ooooooooool0E_ooool00ol0003oooooooooo`08ooooo`03o`000?l0
o`3o0?l000Sooooo0_l0000:ooooo`;o00002?ooool3o`0000_ooooo000Fooooo`03o`000?oooooo
oooo013ooooo0_l0o`1Rooooo`;o0?l02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo0_l0000=ooooo`005_ooool00ol0003oooooooooo`0@ooooo`;o0?l0HOooool2o`3o
01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`005_ooool2o`0001;o
oooo00?o0?l0ooooooooool0G_ooool2o`3o02oooooo000Fooooo`03o`000?oooooooooo017ooooo
0_l0o`1Nooooo`;o0?l0<?ooool001Kooooo00?o0000ooooooooool04Oooool2o`3o05gooooo0_l0
o`0aooooo`003_ooool5o`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`3o0?oooooooooo05[ooooo0_l0o`0booooo`003oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool2o`3o00Wooooo0_l0000F
ooooo`;o00002?ooool2o`0000[ooooo00?o0000ooooooooool08?ooool2o`3o03?ooooo000@oooo
o`03o`000?oooooooooo00;ooooo0ol00008ooooo`?o00002?ooool2o`3o00Wooooo0ol00008oooo
o`?o00002?ooool4o`0000Oooooo0ol00009ooooo`;o00002Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo0_l000000ooooooo0?l0o`3o0008ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo000Aooooo`04o`000?ooooooooooooooo`?o00002?ooool3o`0000Wooooo00?o0?l0o`00
0?ooool02?ooool3o`0000Sooooo0ol0000:ooooo`03o`000?oooooooooo00Cooooo1Ol00007oooo
o`?o00002?ooool3o`0000Wooooo0_l00008ooooo`04o`000?oooooo0?l0o`3o00Oooooo0_l0000;
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`003_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04oooool2
o`3o00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`;o00002Oooool2
o`0000[ooooo00?o0000ooooooooool01oooool2o`0000;o0?l02?ooool2o`0000Sooooo0ol00008
ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool02Oooool000kooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo01Cooooo00?o0?l0ooooooooool0Aoooool0
0ol0003oooooooooo`07ooooo`;o00000_l0o`08ooooo`03o`000?oooooooooo00Sooooo0ol00008
ooooo`;o00002Oooool2o`0000cooooo000?ooooo`?o00001?ooool00ol0003oooooooooo`0Doooo
o`03o`3o0?oooooooooo057ooooo0ol0o`08ooooo`03o`000?oooooooooo00Sooooo0_l00009oooo
o`;o00002_ooool2o`0000cooooo000Fooooo`03o`000?oooooooooo01Cooooo0_l0o`1Aooooo`?o
0?l05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03?ooool001Kooooo0_l0000Fooooo`03o`3o0?oooooooooo04kooooo0_l0o`0[ooooo`03o`00
0?oooooooooo00gooooo000Fooooo`03o`000?oooooooooo01Gooooo00?o0?l0ooooooooool0COoo
ool2o`3o03cooooo000Fooooo`03o`000?oooooooooo01Kooooo00?o0?l0ooooooooool0Boooool2
o`3o03gooooo000Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo0?l004cooooo00?o0?l0ooooooooool0?Oooool001Gooooo0ol00009oooo
o`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0_l0o`05ooooo`;o00008?ooool2
o`0000Wooooo00?o0000ooooooooool05Oooool00ol0o`3oooooooooo`0nooooo`005Oooool3o`00
00Sooooo0ol00008ooooo`;o00000oooool00ol0o`3oooooooooo`03ooooo`?o00002?ooool4o`00
00Kooooo1Ol00007ooooo`?o00002Oooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`00
0003o`3o0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool2o`0000[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Fooooo`03
o`000?oooooooooo00Oooooo0ol00009ooooo`;o00000_ooool2o`3o00Gooooo0ol00008ooooo`?o
00002Oooool2o`0000Kooooo1?l00008ooooo`?o00001oooool4o`0000Sooooo0_l0o`09ooooo`;o
00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003oooooooooo`0Cooooo`04o`00
0?ooooooooooooooo`;o0?l01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_o
oooo0_l00008ooooo`;o00002_ooool2o`3o0003o`000?oooooooooo00Oooooo0_l00008ooooo`03
o`000?oooooooooo00Sooooo0_l0000;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool001Kooooo00?o0000ooooooooool06?ooool00ol0o`3oooooooooo`12ooooo`;o0?l0
2_ooool00ol0003oooooooooo`07ooooo`?o00002Oooool2o`0000Sooooo0ol00008ooooo`;o0000
3Oooool001Kooooo00?o0000ooooooooool06Oooool00ol0o`3oooooooooo`0oooooo`?o0?l02_oo
ool00ol0003oooooooooo`07ooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`?o00002?oo
ool00ol0003oooooooooo`0<ooooo`005_ooool00ol0003oooooooooo`0Iooooo`;o0?l0?oooool2
o`3o027ooooo00?o0000ooooooooool02?ooool2o`0000Wooooo0ol0000=ooooo`005_ooool2o`00
01_ooooo00?o0?l0ooooooooool0>oooool3o`3o02gooooo00?o0000ooooooooool01oooool2o`00
00oooooo000Fooooo`03o`000?oooooooooo01_ooooo00?o0?l0ooooooooool0>Oooool2o`3o04[o
oooo000Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0o`3ooooo
ooooo`0hooooo`;o0?l0Boooool001Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0?l0ooooooooool0=Oooool2o`3o04gooooo000E
ooooo`?o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0?l0
o`000?ooool07oooool2o`00017ooooo0ol0o`1>ooooo`005Oooool3o`0000Sooooo0ol00008oooo
o`;o00002Oooool00ol0003o0?l0o`000007ooooo`Go00001_ooool4o`0000Sooooo0ol00008oooo
o`;o00001_ooool2o`3o0003ooooool0003o000000Wooooo0_l0000:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool001Kooooo00?o0000ooooooooool01oooool3o`0000Wo
oooo0_l00009ooooo`03o`000?l0o`3o000000Sooooo0ol00009ooooo`03o`000?oooooooooo00Go
oooo1?l00007ooooo`Co00000oooool3o`3o00;ooooo00?o0000ooooooooool01oooool2o`0000Wo
oooo0_l0000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000Fooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooo`3o0009ooooo`03o`000?oooooooooo01[ooooo
0_l00004ooooo`?o0?l00oooool3o`0000Oooooo1?l00008ooooo`03o`000?oooooooooo00Sooooo
0_l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`000_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o
0000ooooooooool08Oooool00ol0o`3oooooooooo`0Wooooo`?o0?l01?ooool2o`0000Sooooo0_l0
000:ooooo`?o00002Oooool2o`0000Sooooo0_l00009ooooo`;o00002oooool00ol0003ooooooooo
o`0:ooooo`000oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Rooooo`;o0?l09Oooool4o`3o01[ooooo0_l0000:ooooo`03o`00
0?oooooooooo00Sooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
3Oooool000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000002Kooooo
00?o0?l0ooooooooool08?ooool4o`3o02Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`?o00002?ooool2o`0000kooooo0005ooooo`03o`000?oooooooooo00[ooooo00Co
0000oooooooooooooooo0_l0000Vooooo`;o0?l07_ooool3o`3o03Cooooo00?o0000ooooooooool0
2?ooool2o`0000Wooooo0_l0000?ooooo`000_ooool01Ol0003ooooooooooooooooo000000Oooooo
1?l00004ooooo`03o`000?oooooooooo02Oooooo00?o0?l0ooooooooool06Oooool3o`3o04cooooo
00?o0000ooooooooool03_ooool000;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`?o0?l0
5Oooool3o`3o063ooooo0003ooooo`?o00002?ooool5o`0000?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo1?l0o`0>ooooo`Go0?l0H_oo
ool001Gooooo0ol00008ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00gooooo4Ol0o`1Uooooo`005Oooool3o`0000Sooooo0ol00008ooooo`;o00002Oooool2o`00
00Sooooo1Ol00006ooooo`Co00002?ooool2o`0000Wooooo0_l00009ooooo`;o00002_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0ol00009ooooo`;o00002Oooool3o`0000Wo
oooo00?o0000ooooooooool01?ooool5o`0000Oooooo0ol00008ooooo`;o00002Oooool2o`0000[o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool2o`0000Wooooo
1?l00008ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`;o00002oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool001Kooooo00?o
0000ooooooooool0DOooool2o`0000[ooooo00?o0000ooooooooool02?ooool3o`0000Sooooo00?o
0000ooooooooool01oooool3o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`005_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Sooooo0_l00009
ooooo`?o00002?ooool3o`0000Sooooo0_l0000;ooooo`03o`000?oooooooooo00_ooooo000Foooo
o`03o`000?oooooooooo077ooooo0_l00009ooooo`;o00002_ooool2o`0000Sooooo0ol0000>oooo
o`005_ooool2o`0007gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`?o
00003_ooool001Kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`08ooooo`;o0000
4?ooool001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`27ooooo`03o`000?oo
oooooooo00oooooo000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`2>ooooo`005Oooool3o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo
00Oooooo0_l00025ooooo`005Oooool3o`0000Sooooo0ol00008ooooo`;o00002?ooool3o`0000So
oooo1?l00008ooooo`?o00002?ooool2o`0000Sooooo0_l0001Iooooo`005_ooool2o`0000Wooooo
00?o0000ooooooooool01oooool3o`0000Sooooo0ol00009ooooo`;o00001_ooool5o`0000Kooooo
1?l00007ooooo`Co00002?ooool3o`0000Sooooo0ol00009ooooo`;o00002_ooool2o`0000Wooooo
0_l00009ooooo`;o00002Oooool2o`0000[ooooo000Fooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`Go00001oooool3o`0000Sooooo0_l0
0009ooooo`;o00002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`005_ooool00ol0003oooooooooo`1A
ooooo`;o00002Oooool4o`0000Sooooo0_l00008ooooo`?o00002_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool001Kooooo00?o0000oooo
ooooool0Foooool2o`0000[ooooo00?o0000ooooooooool02?ooool2o`0000Wooooo0_l00009oooo
o`;o00002_ooool00ol0003oooooooooo`0<ooooo`005_ooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool2o`0000Sooooo00?o0000oooooooo
ool02?ooool2o`0000oooooo000Fooooo`;o0000LOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Oooooo0ol00009ooooo`03o`000?oooooooooo00kooooo000Fooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool01oooool2o`0000[ooooo0ol0000?ooooo`005_ooool0
0ol0003oooooooooo`2@ooooo`;o00004Oooool000oooooo0ol00004ooooo`03o`000?oooooooooo
0:?ooooo000>ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`2Soooo
o`004_ooool01Ol0003ooooooooooooooooo00000:Gooooo000@ooooo`;o00001?ooool2o`000:Co
oooo000Booooo`03o`000?oooooooooo0:Oooooo000>ooooo`05o`000?ooooooooooooooool00000
ZOooool000oooooo0ol0002Zooooo`00_?ooool00;cooooo000looooo`?o00000oooool5o`0000;o
oooo0ol00002ooooo`Go00000_ooool4o`0000Sooooo1?l000001Ooooooo0000o`000?l0003ooooo
00;o000000?oooooo`000?l000000_l00007ooooo`?o00000oooool5o`0000;ooooo0ol00003oooo
o`03o`000?oooooo000002kooooo000mooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Ko0000oooooooooooo0000ooooool0000^ooooo`00?Oooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooooooo`Go00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01oooool3o`0000?ooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Oo0000ooooool0003oooooo`000?oooooo000002gooooo000mooooo`?o00001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01_l0003oooooooooool0
003oooooo`0000;ooooo00?o0000ooooooooool01oooool3o`0000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`07o`000?oooooo0000ooooool0003oooooo`00000]ooooo`00?Oooool00ol0
003oooooooooo`02ooooo`?o00001?ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Wooooo0_l00003ooooo`Co00000oooool3o`0000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`?o00000_ooool6o`0002cooooo000mooooo`04o`000?ooooooooooo`00
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0iooooo`00??ooool5o`00
00?ooooo00?o0000ooooooooool01oooool3o`0000Gooooo0_l0000Fooooo`;o00002?ooool5o`00
0004ooooool0003o0000o`0003_ooooo002looooo`00_?ooool00001\
\>"],
  ImageRangeCache->{{{77.875, 265.688}, {573.75, 381.875}} -> {-1.81336, \
6.70629, 0.0180867, 0.0180867}}]
}, Open  ]],

Cell[TextData[StyleBox["Estimating the period: Numeric data",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "We can estimate the period using a table of numeric data generated from \
the NDSolve solution. It appears from the time series plot above that the \
solutions start to repeat at about ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 7. The following Table pins it down to 6.96."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[ {{t,x[t],y[t]}},
      Evaluate[ Table[ {t,x[t],y[t]}, {t,6.9,7,0.01}]]/.soln[[1]] ]
      //MatrixForm\
\>", "Input",
  CellLabel->"In[57]:=",
  FormatType->InputForm],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"t", \(x[t]\), \(y[t]\)},
            {"6.9`", "0.38562319390858335`", "0.41529339232295986`"},
            {"6.91`", "0.38788948834306375`", "0.4127544101408495`"},
            {"6.92`", "0.39017894793476815`", "0.4102402834407916`"},
            {"6.930000000000001`", "0.3924917358037514`", 
              "0.40775084893829455`"},
            {"6.94`", "0.3948280150729648`", "0.4052859433516123`"},
            {"6.95`", "0.39718794886536024`", "0.4028454033989982`"},
            {"6.96`", "0.39957170030388933`", "0.40042906579870574`"},
            {"6.970000000000001`", "0.4019794325115039`", 
              "0.3980367672689883`"},
            {"6.98`", "0.4044113086111553`", "0.3956683445280998`"},
            {"6.99`", "0.4068674917257954`", "0.3933236342942935`"},
            {"7.`", "0.40934814497837574`", "0.39100247328582305`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[57]//MatrixForm="]
}, Open  ]],

Cell[TextData[StyleBox["A more complete flow",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
A more complete picture of the flow is obtained with a family of \
numeric solutions. The following input defines four initial values, creates \
four numeric solutions,and then shows their parametric plots in the vector \
field. The picture is named flow so it can be shown again below.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
inits = {0.4, 0.6, 1.3, 1.8};
solns = Evaluate[
        Table[ NDSolve[ {DEsystem,x[0]==inits[[k]],y[0]==inits[[k]]}, 
               {x,y}, {t,0,20} ], {k,4} ] ];
Show[ vf,
      ParametricPlot[ Evaluate[Table[{x[t],y[t]}/.solns[[k]], {k,4}]], 
                      {t,0,20}, PlotStyle->RGBColor[0,1,0] ],
                      PlotLabel->\"Field and more flow lines\", 
                      AspectRatio->1/1 ]
flow = %;\
\>", "Input",
  CellLabel->"In[8]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.330852 0.0238095 0.323783 [
[.18924 .01131 -9 -9 ]
[.18924 .01131 9 0 ]
[.35466 .01131 -3 -9 ]
[.35466 .01131 3 0 ]
[.52009 .01131 -9 -9 ]
[.52009 .01131 9 0 ]
[.68551 .01131 -3 -9 ]
[.68551 .01131 3 0 ]
[.85094 .01131 -9 -9 ]
[.85094 .01131 9 0 ]
[.01131 .1857 -18 -4.5 ]
[.01131 .1857 0 4.5 ]
[.01131 .34759 -6 -4.5 ]
[.01131 .34759 0 4.5 ]
[.01131 .50948 -18 -4.5 ]
[.01131 .50948 0 4.5 ]
[.01131 .67137 -6 -4.5 ]
[.01131 .67137 0 4.5 ]
[.01131 .83327 -18 -4.5 ]
[.01131 .83327 0 4.5 ]
[.01131 .99516 -6 -4.5 ]
[.01131 .99516 0 4.5 ]
[.5 1.0125 -89 0 ]
[.5 1.0125 89 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18924 .02381 m
.18924 .03006 L
s
[(0.5)] .18924 .01131 0 1 Mshowa
.35466 .02381 m
.35466 .03006 L
s
[(1)] .35466 .01131 0 1 Mshowa
.52009 .02381 m
.52009 .03006 L
s
[(1.5)] .52009 .01131 0 1 Mshowa
.68551 .02381 m
.68551 .03006 L
s
[(2)] .68551 .01131 0 1 Mshowa
.85094 .02381 m
.85094 .03006 L
s
[(2.5)] .85094 .01131 0 1 Mshowa
.125 Mabswid
.05689 .02381 m
.05689 .02756 L
s
.08998 .02381 m
.08998 .02756 L
s
.12307 .02381 m
.12307 .02756 L
s
.15615 .02381 m
.15615 .02756 L
s
.22232 .02381 m
.22232 .02756 L
s
.25541 .02381 m
.25541 .02756 L
s
.28849 .02381 m
.28849 .02756 L
s
.32158 .02381 m
.32158 .02756 L
s
.38775 .02381 m
.38775 .02756 L
s
.42083 .02381 m
.42083 .02756 L
s
.45392 .02381 m
.45392 .02756 L
s
.487 .02381 m
.487 .02756 L
s
.55317 .02381 m
.55317 .02756 L
s
.58626 .02381 m
.58626 .02756 L
s
.61934 .02381 m
.61934 .02756 L
s
.65243 .02381 m
.65243 .02756 L
s
.7186 .02381 m
.7186 .02756 L
s
.75168 .02381 m
.75168 .02756 L
s
.78477 .02381 m
.78477 .02756 L
s
.81786 .02381 m
.81786 .02756 L
s
.88403 .02381 m
.88403 .02756 L
s
.91711 .02381 m
.91711 .02756 L
s
.9502 .02381 m
.9502 .02756 L
s
.98328 .02381 m
.98328 .02756 L
s
.25 Mabswid
0 .02381 m
1 .02381 L
s
.02381 .1857 m
.03006 .1857 L
s
[(0.5)] .01131 .1857 1 0 Mshowa
.02381 .34759 m
.03006 .34759 L
s
[(1)] .01131 .34759 1 0 Mshowa
.02381 .50948 m
.03006 .50948 L
s
[(1.5)] .01131 .50948 1 0 Mshowa
.02381 .67137 m
.03006 .67137 L
s
[(2)] .01131 .67137 1 0 Mshowa
.02381 .83327 m
.03006 .83327 L
s
[(2.5)] .01131 .83327 1 0 Mshowa
.02381 .99516 m
.03006 .99516 L
s
[(3)] .01131 .99516 1 0 Mshowa
.125 Mabswid
.02381 .05619 m
.02756 .05619 L
s
.02381 .08857 m
.02756 .08857 L
s
.02381 .12094 m
.02756 .12094 L
s
.02381 .15332 m
.02756 .15332 L
s
.02381 .21808 m
.02756 .21808 L
s
.02381 .25046 m
.02756 .25046 L
s
.02381 .28284 m
.02756 .28284 L
s
.02381 .31521 m
.02756 .31521 L
s
.02381 .37997 m
.02756 .37997 L
s
.02381 .41235 m
.02756 .41235 L
s
.02381 .44473 m
.02756 .44473 L
s
.02381 .47711 m
.02756 .47711 L
s
.02381 .54186 m
.02756 .54186 L
s
.02381 .57424 m
.02756 .57424 L
s
.02381 .60662 m
.02756 .60662 L
s
.02381 .639 m
.02756 .639 L
s
.02381 .70375 m
.02756 .70375 L
s
.02381 .73613 m
.02756 .73613 L
s
.02381 .76851 m
.02756 .76851 L
s
.02381 .80089 m
.02756 .80089 L
s
.02381 .86564 m
.02756 .86564 L
s
.02381 .89802 m
.02756 .89802 L
s
.02381 .9304 m
.02756 .9304 L
s
.02381 .96278 m
.02756 .96278 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
gsave
.5 1.0125 -150 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Field) show
99.000 13.000 moveto
(and) show
123.000 13.000 moveto
(more) show
153.000 13.000 moveto
(flow) show
183.000 13.000 moveto
(lines) show
237.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.02381 .02381 m
.02381 .02381 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.02381 .08857 m
.02381 .08675 L
s
% Start of user PostScript
0 0.2 0 0.194388 MAarrowhead1
% End of user PostScript
.02381 .15332 m
.02381 .14969 L
s
% Start of user PostScript
0 0.4 0 0.388776 MAarrowhead1
% End of user PostScript
.02381 .21808 m
.02381 .21263 L
s
% Start of user PostScript
0 0.6 0 0.583164 MAarrowhead1
% End of user PostScript
.02381 .28284 m
.02381 .27557 L
s
% Start of user PostScript
0 0.8 0 0.777552 MAarrowhead1
% End of user PostScript
.02381 .34759 m
.02381 .33851 L
s
% Start of user PostScript
0 1. 0 0.97194 MAarrowhead1
% End of user PostScript
.02381 .41235 m
.02381 .40145 L
s
% Start of user PostScript
0 1.2 0 1.16633 MAarrowhead1
% End of user PostScript
.02381 .47711 m
.02381 .46439 L
s
% Start of user PostScript
0 1.4 0 1.36072 MAarrowhead1
% End of user PostScript
.02381 .54186 m
.02381 .52733 L
s
% Start of user PostScript
0 1.6 0 1.5551 MAarrowhead1
% End of user PostScript
.02381 .60662 m
.02381 .59026 L
s
% Start of user PostScript
0 1.8 0 1.74949 MAarrowhead1
% End of user PostScript
.02381 .67137 m
.02381 .6532 L
s
% Start of user PostScript
0 2. 0 1.94388 MAarrowhead1
% End of user PostScript
.02381 .73613 m
.02381 .71614 L
s
% Start of user PostScript
0 2.2 0 2.13827 MAarrowhead1
% End of user PostScript
.02381 .80089 m
.02381 .77908 L
s
% Start of user PostScript
0 2.4 0 2.33266 MAarrowhead1
% End of user PostScript
.02381 .86564 m
.02381 .84202 L
s
% Start of user PostScript
0 2.6 0 2.52704 MAarrowhead1
% End of user PostScript
.02381 .9304 m
.02381 .90496 L
s
% Start of user PostScript
0 2.8 0 2.72143 MAarrowhead1
% End of user PostScript
.08998 .02381 m
.09184 .02381 L
s
% Start of user PostScript
0.2 0 0.205612 0 MAarrowhead1
% End of user PostScript
.08998 .08857 m
.09147 .08711 L
s
% Start of user PostScript
0.2 0.2 0.20449 0.19551 MAarrowhead1
% End of user PostScript
.08998 .15332 m
.09109 .15042 L
s
% Start of user PostScript
0.2 0.4 0.203367 0.391021 MAarrowhead1
% End of user PostScript
.08998 .21808 m
.09072 .21372 L
s
% Start of user PostScript
0.2 0.6 0.202245 0.586531 MAarrowhead1
% End of user PostScript
.08998 .28284 m
.09035 .27702 L
s
% Start of user PostScript
0.2 0.8 0.201122 0.782042 MAarrowhead1
% End of user PostScript
.08998 .34759 m
.08998 .34032 L
s
% Start of user PostScript
0.2 1. 0.2 0.977552 MAarrowhead1
% End of user PostScript
.08998 .41235 m
.08961 .40363 L
s
% Start of user PostScript
0.2 1.2 0.198878 1.17306 MAarrowhead1
% End of user PostScript
.08998 .47711 m
.08924 .46693 L
s
% Start of user PostScript
0.2 1.4 0.197755 1.36857 MAarrowhead1
% End of user PostScript
.08998 .54186 m
.08887 .53023 L
s
% Start of user PostScript
0.2 1.6 0.196633 1.56408 MAarrowhead1
% End of user PostScript
.08998 .60662 m
.08849 .59354 L
s
% Start of user PostScript
0.2 1.8 0.19551 1.75959 MAarrowhead1
% End of user PostScript
.08998 .67137 m
.08812 .65684 L
s
% Start of user PostScript
0.2 2. 0.194388 1.9551 MAarrowhead1
% End of user PostScript
.08998 .73613 m
.08775 .72014 L
s
% Start of user PostScript
0.2 2.2 0.193266 2.15061 MAarrowhead1
% End of user PostScript
.08998 .80089 m
.08738 .78344 L
s
% Start of user PostScript
0.2 2.4 0.192143 2.34613 MAarrowhead1
% End of user PostScript
.08998 .86564 m
.08701 .84675 L
s
% Start of user PostScript
0.2 2.6 0.191021 2.54164 MAarrowhead1
% End of user PostScript
.08998 .9304 m
.08664 .91005 L
s
% Start of user PostScript
0.2 2.8 0.189898 2.73715 MAarrowhead1
% End of user PostScript
.15615 .02381 m
.15986 .02381 L
s
% Start of user PostScript
0.4 0 0.411224 0 MAarrowhead1
% End of user PostScript
.15615 .08857 m
.15912 .08748 L
s
% Start of user PostScript
0.4 0.2 0.408979 0.196633 MAarrowhead1
% End of user PostScript
.15615 .15332 m
.15838 .15114 L
s
% Start of user PostScript
0.4 0.4 0.406734 0.393266 MAarrowhead1
% End of user PostScript
.15615 .21808 m
.15764 .21481 L
s
% Start of user PostScript
0.4 0.6 0.40449 0.589898 MAarrowhead1
% End of user PostScript
.15615 .28284 m
.15689 .27847 L
s
% Start of user PostScript
0.4 0.8 0.402245 0.786531 MAarrowhead1
% End of user PostScript
.15615 .34759 m
.15615 .34214 L
s
% Start of user PostScript
0.4 1. 0.4 0.983164 MAarrowhead1
% End of user PostScript
.15615 .41235 m
.15541 .40581 L
s
% Start of user PostScript
0.4 1.2 0.397755 1.1798 MAarrowhead1
% End of user PostScript
.15615 .47711 m
.15467 .46947 L
s
% Start of user PostScript
0.4 1.4 0.39551 1.37643 MAarrowhead1
% End of user PostScript
.15615 .54186 m
.15392 .53314 L
s
% Start of user PostScript
0.4 1.6 0.393266 1.57306 MAarrowhead1
% End of user PostScript
.15615 .60662 m
.15318 .59681 L
s
% Start of user PostScript
0.4 1.8 0.391021 1.7697 MAarrowhead1
% End of user PostScript
.15615 .67137 m
.15244 .66047 L
s
% Start of user PostScript
0.4 2. 0.388776 1.96633 MAarrowhead1
% End of user PostScript
.15615 .73613 m
.15169 .72414 L
s
% Start of user PostScript
0.4 2.2 0.386531 2.16296 MAarrowhead1
% End of user PostScript
.15615 .80089 m
.15095 .7878 L
s
% Start of user PostScript
0.4 2.4 0.384287 2.35959 MAarrowhead1
% End of user PostScript
.15615 .86564 m
.15021 .85147 L
s
% Start of user PostScript
0.4 2.6 0.382042 2.55623 MAarrowhead1
% End of user PostScript
.15615 .9304 m
.14947 .91514 L
s
% Start of user PostScript
0.4 2.8 0.379797 2.75286 MAarrowhead1
% End of user PostScript
.22232 .02381 m
.22789 .02381 L
s
% Start of user PostScript
0.6 0 0.616836 0 MAarrowhead1
% End of user PostScript
.22232 .08857 m
.22678 .08784 L
s
% Start of user PostScript
0.6 0.2 0.613469 0.197755 MAarrowhead1
% End of user PostScript
.22232 .15332 m
.22566 .15187 L
s
% Start of user PostScript
0.6 0.4 0.610102 0.39551 MAarrowhead1
% End of user PostScript
.22232 .21808 m
.22455 .2159 L
s
% Start of user PostScript
0.6 0.6 0.606734 0.593266 MAarrowhead1
% End of user PostScript
.22232 .28284 m
.22344 .27993 L
s
% Start of user PostScript
0.6 0.8 0.603367 0.791021 MAarrowhead1
% End of user PostScript
.22232 .34759 m
.22232 .34396 L
s
% Start of user PostScript
0.6 1. 0.6 0.988776 MAarrowhead1
% End of user PostScript
.22232 .41235 m
.22121 .40799 L
s
% Start of user PostScript
0.6 1.2 0.596633 1.18653 MAarrowhead1
% End of user PostScript
.22232 .47711 m
.22009 .47202 L
s
% Start of user PostScript
0.6 1.4 0.593266 1.38429 MAarrowhead1
% End of user PostScript
.22232 .54186 m
.21898 .53605 L
s
% Start of user PostScript
0.6 1.6 0.589898 1.58204 MAarrowhead1
% End of user PostScript
.22232 .60662 m
.21786 .60008 L
s
% Start of user PostScript
0.6 1.8 0.586531 1.7798 MAarrowhead1
% End of user PostScript
.22232 .67137 m
.21675 .66411 L
s
% Start of user PostScript
0.6 2. 0.583164 1.97755 MAarrowhead1
% End of user PostScript
.22232 .73613 m
.21564 .72814 L
s
% Start of user PostScript
0.6 2.2 0.579797 2.17531 MAarrowhead1
% End of user PostScript
.22232 .80089 m
.21452 .79217 L
s
% Start of user PostScript
0.6 2.4 0.57643 2.37306 MAarrowhead1
% End of user PostScript
.22232 .86564 m
.21341 .8562 L
s
% Start of user PostScript
0.6 2.6 0.573063 2.57082 MAarrowhead1
% End of user PostScript
.22232 .9304 m
.21229 .92023 L
s
% Start of user PostScript
0.6 2.8 0.569695 2.76857 MAarrowhead1
% End of user PostScript
.28849 .02381 m
.29592 .02381 L
s
% Start of user PostScript
0.8 0 0.822448 0 MAarrowhead1
% End of user PostScript
.28849 .08857 m
.29443 .0882 L
s
% Start of user PostScript
0.8 0.2 0.817958 0.198878 MAarrowhead1
% End of user PostScript
.28849 .15332 m
.29295 .1526 L
s
% Start of user PostScript
0.8 0.4 0.813469 0.397755 MAarrowhead1
% End of user PostScript
.28849 .21808 m
.29146 .21699 L
s
% Start of user PostScript
0.8 0.6 0.808979 0.596633 MAarrowhead1
% End of user PostScript
.28849 .28284 m
.28998 .28138 L
s
% Start of user PostScript
0.8 0.8 0.80449 0.79551 MAarrowhead1
% End of user PostScript
.28849 .34759 m
.28849 .34578 L
s
% Start of user PostScript
0.8 1. 0.8 0.994388 MAarrowhead1
% End of user PostScript
.28849 .41235 m
.28701 .41017 L
s
% Start of user PostScript
0.8 1.2 0.79551 1.19327 MAarrowhead1
% End of user PostScript
.28849 .47711 m
.28552 .47456 L
s
% Start of user PostScript
0.8 1.4 0.791021 1.39214 MAarrowhead1
% End of user PostScript
.28849 .54186 m
.28404 .53895 L
s
% Start of user PostScript
0.8 1.6 0.786531 1.59102 MAarrowhead1
% End of user PostScript
.28849 .60662 m
.28255 .60335 L
s
% Start of user PostScript
0.8 1.8 0.782042 1.7899 MAarrowhead1
% End of user PostScript
.28849 .67137 m
.28106 .66774 L
s
% Start of user PostScript
0.8 2. 0.777552 1.98878 MAarrowhead1
% End of user PostScript
.28849 .73613 m
.27958 .73213 L
s
% Start of user PostScript
0.8 2.2 0.773063 2.18765 MAarrowhead1
% End of user PostScript
.28849 .80089 m
.27809 .79653 L
s
% Start of user PostScript
0.8 2.4 0.768573 2.38653 MAarrowhead1
% End of user PostScript
.28849 .86564 m
.27661 .86092 L
s
% Start of user PostScript
0.8 2.6 0.764083 2.58541 MAarrowhead1
% End of user PostScript
.28849 .9304 m
.27512 .92531 L
s
% Start of user PostScript
0.8 2.8 0.759594 2.78429 MAarrowhead1
% End of user PostScript
.35466 .02381 m
.36395 .02381 L
s
% Start of user PostScript
1. 0 1.02806 0 MAarrowhead1
% End of user PostScript
.35466 .08857 m
.36209 .08857 L
s
% Start of user PostScript
1. 0.2 1.02245 0.2 MAarrowhead1
% End of user PostScript
.35466 .15332 m
.36023 .15332 L
s
% Start of user PostScript
1. 0.4 1.01684 0.4 MAarrowhead1
% End of user PostScript
.35466 .21808 m
.35838 .21808 L
s
% Start of user PostScript
1. 0.6 1.01122 0.6 MAarrowhead1
% End of user PostScript
.35466 .28284 m
.35652 .28284 L
s
% Start of user PostScript
1. 0.8 1.00561 0.8 MAarrowhead1
% End of user PostScript
.35466 .34759 m
.35466 .34759 L
s
% Start of user PostScript
1. 1. MAarrowzero1
% End of user PostScript
.35466 .41235 m
.35281 .41235 L
s
% Start of user PostScript
1. 1.2 0.994388 1.2 MAarrowhead1
% End of user PostScript
.35466 .47711 m
.35095 .47711 L
s
% Start of user PostScript
1. 1.4 0.988776 1.4 MAarrowhead1
% End of user PostScript
.35466 .54186 m
.34909 .54186 L
s
% Start of user PostScript
1. 1.6 0.983164 1.6 MAarrowhead1
% End of user PostScript
.35466 .60662 m
.34724 .60662 L
s
% Start of user PostScript
1. 1.8 0.977552 1.8 MAarrowhead1
% End of user PostScript
.35466 .67137 m
.34538 .67137 L
s
% Start of user PostScript
1. 2. 0.97194 2. MAarrowhead1
% End of user PostScript
.35466 .73613 m
.34352 .73613 L
s
% Start of user PostScript
1. 2.2 0.966328 2.2 MAarrowhead1
% End of user PostScript
.35466 .80089 m
.34166 .80089 L
s
% Start of user PostScript
1. 2.4 0.960716 2.4 MAarrowhead1
% End of user PostScript
.35466 .86564 m
.33981 .86564 L
s
% Start of user PostScript
1. 2.6 0.955104 2.6 MAarrowhead1
% End of user PostScript
.35466 .9304 m
.33795 .9304 L
s
% Start of user PostScript
1. 2.8 0.949492 2.8 MAarrowhead1
% End of user PostScript
.42083 .02381 m
.43197 .02381 L
s
% Start of user PostScript
1.2 0 1.23367 0 MAarrowhead1
% End of user PostScript
.42083 .08857 m
.42974 .08893 L
s
% Start of user PostScript
1.2 0.2 1.22694 0.201122 MAarrowhead1
% End of user PostScript
.42083 .15332 m
.42752 .15405 L
s
% Start of user PostScript
1.2 0.4 1.2202 0.402245 MAarrowhead1
% End of user PostScript
.42083 .21808 m
.42529 .21917 L
s
% Start of user PostScript
1.2 0.6 1.21347 0.603367 MAarrowhead1
% End of user PostScript
.42083 .28284 m
.42306 .28429 L
s
% Start of user PostScript
1.2 0.8 1.20673 0.80449 MAarrowhead1
% End of user PostScript
.42083 .34759 m
.42083 .34941 L
s
% Start of user PostScript
1.2 1. 1.2 1.00561 MAarrowhead1
% End of user PostScript
.42083 .41235 m
.4186 .41453 L
s
% Start of user PostScript
1.2 1.2 1.19327 1.20673 MAarrowhead1
% End of user PostScript
.42083 .47711 m
.41638 .47965 L
s
% Start of user PostScript
1.2 1.4 1.18653 1.40786 MAarrowhead1
% End of user PostScript
.42083 .54186 m
.41415 .54477 L
s
% Start of user PostScript
1.2 1.6 1.1798 1.60898 MAarrowhead1
% End of user PostScript
.42083 .60662 m
.41192 .60989 L
s
% Start of user PostScript
1.2 1.8 1.17306 1.8101 MAarrowhead1
% End of user PostScript
.42083 .67137 m
.40969 .67501 L
s
% Start of user PostScript
1.2 2. 1.16633 2.01122 MAarrowhead1
% End of user PostScript
.42083 .73613 m
.40746 .74013 L
s
% Start of user PostScript
1.2 2.2 1.15959 2.21235 MAarrowhead1
% End of user PostScript
.42083 .80089 m
.40524 .80525 L
s
% Start of user PostScript
1.2 2.4 1.15286 2.41347 MAarrowhead1
% End of user PostScript
.42083 .86564 m
.40301 .87037 L
s
% Start of user PostScript
1.2 2.6 1.14613 2.61459 MAarrowhead1
% End of user PostScript
.42083 .9304 m
.40078 .93549 L
s
% Start of user PostScript
1.2 2.8 1.13939 2.81571 MAarrowhead1
% End of user PostScript
.487 .02381 m
.5 .02381 L
s
% Start of user PostScript
1.4 0 1.43928 0 MAarrowhead1
% End of user PostScript
.487 .08857 m
.4974 .08929 L
s
% Start of user PostScript
1.4 0.2 1.43143 0.202245 MAarrowhead1
% End of user PostScript
.487 .15332 m
.4948 .15478 L
s
% Start of user PostScript
1.4 0.4 1.42357 0.40449 MAarrowhead1
% End of user PostScript
.487 .21808 m
.4922 .22026 L
s
% Start of user PostScript
1.4 0.6 1.41571 0.606734 MAarrowhead1
% End of user PostScript
.487 .28284 m
.4896 .28574 L
s
% Start of user PostScript
1.4 0.8 1.40786 0.808979 MAarrowhead1
% End of user PostScript
.487 .34759 m
.487 .35123 L
s
% Start of user PostScript
1.4 1. 1.4 1.01122 MAarrowhead1
% End of user PostScript
.487 .41235 m
.4844 .41671 L
s
% Start of user PostScript
1.4 1.2 1.39214 1.21347 MAarrowhead1
% End of user PostScript
.487 .47711 m
.4818 .48219 L
s
% Start of user PostScript
1.4 1.4 1.38429 1.41571 MAarrowhead1
% End of user PostScript
.487 .54186 m
.4792 .54768 L
s
% Start of user PostScript
1.4 1.6 1.37643 1.61796 MAarrowhead1
% End of user PostScript
.487 .60662 m
.47661 .61316 L
s
% Start of user PostScript
1.4 1.8 1.36857 1.8202 MAarrowhead1
% End of user PostScript
.487 .67137 m
.47401 .67864 L
s
% Start of user PostScript
1.4 2. 1.36072 2.02245 MAarrowhead1
% End of user PostScript
.487 .73613 m
.47141 .74413 L
s
% Start of user PostScript
1.4 2.2 1.35286 2.22469 MAarrowhead1
% End of user PostScript
.487 .80089 m
.46881 .80961 L
s
% Start of user PostScript
1.4 2.4 1.345 2.42694 MAarrowhead1
% End of user PostScript
.487 .86564 m
.46621 .87509 L
s
% Start of user PostScript
1.4 2.6 1.33715 2.62918 MAarrowhead1
% End of user PostScript
.487 .9304 m
.46361 .94058 L
s
% Start of user PostScript
1.4 2.8 1.32929 2.83143 MAarrowhead1
% End of user PostScript
.55317 .02381 m
.56803 .02381 L
s
% Start of user PostScript
1.6 0 1.6449 0 MAarrowhead1
% End of user PostScript
.55317 .08857 m
.56506 .08966 L
s
% Start of user PostScript
1.6 0.2 1.63592 0.203367 MAarrowhead1
% End of user PostScript
.55317 .15332 m
.56209 .1555 L
s
% Start of user PostScript
1.6 0.4 1.62694 0.406734 MAarrowhead1
% End of user PostScript
.55317 .21808 m
.55911 .22135 L
s
% Start of user PostScript
1.6 0.6 1.61796 0.610102 MAarrowhead1
% End of user PostScript
.55317 .28284 m
.55614 .2872 L
s
% Start of user PostScript
1.6 0.8 1.60898 0.813469 MAarrowhead1
% End of user PostScript
.55317 .34759 m
.55317 .35304 L
s
% Start of user PostScript
1.6 1. 1.6 1.01684 MAarrowhead1
% End of user PostScript
.55317 .41235 m
.5502 .41889 L
s
% Start of user PostScript
1.6 1.2 1.59102 1.2202 MAarrowhead1
% End of user PostScript
.55317 .47711 m
.54723 .48474 L
s
% Start of user PostScript
1.6 1.4 1.58204 1.42357 MAarrowhead1
% End of user PostScript
.55317 .54186 m
.54426 .55058 L
s
% Start of user PostScript
1.6 1.6 1.57306 1.62694 MAarrowhead1
% End of user PostScript
.55317 .60662 m
.54129 .61643 L
s
% Start of user PostScript
1.6 1.8 1.56408 1.8303 MAarrowhead1
% End of user PostScript
.55317 .67137 m
.53832 .68228 L
s
% Start of user PostScript
1.6 2. 1.5551 2.03367 MAarrowhead1
% End of user PostScript
.55317 .73613 m
.53535 .74812 L
s
% Start of user PostScript
1.6 2.2 1.54613 2.23704 MAarrowhead1
% End of user PostScript
.55317 .80089 m
.53238 .81397 L
s
% Start of user PostScript
1.6 2.4 1.53715 2.44041 MAarrowhead1
% End of user PostScript
.55317 .86564 m
.52941 .87982 L
s
% Start of user PostScript
1.6 2.6 1.52817 2.64377 MAarrowhead1
% End of user PostScript
.55317 .9304 m
.52644 .94566 L
s
% Start of user PostScript
1.6 2.8 1.51919 2.84714 MAarrowhead1
% End of user PostScript
.61934 .02381 m
.63605 .02381 L
s
% Start of user PostScript
1.8 0 1.85051 0 MAarrowhead1
% End of user PostScript
.61934 .08857 m
.63271 .09002 L
s
% Start of user PostScript
1.8 0.2 1.84041 0.20449 MAarrowhead1
% End of user PostScript
.61934 .15332 m
.62937 .15623 L
s
% Start of user PostScript
1.8 0.4 1.8303 0.408979 MAarrowhead1
% End of user PostScript
.61934 .21808 m
.62603 .22244 L
s
% Start of user PostScript
1.8 0.6 1.8202 0.613469 MAarrowhead1
% End of user PostScript
.61934 .28284 m
.62269 .28865 L
s
% Start of user PostScript
1.8 0.8 1.8101 0.817958 MAarrowhead1
% End of user PostScript
.61934 .34759 m
.61934 .35486 L
s
% Start of user PostScript
1.8 1. 1.8 1.02245 MAarrowhead1
% End of user PostScript
.61934 .41235 m
.616 .42107 L
s
% Start of user PostScript
1.8 1.2 1.7899 1.22694 MAarrowhead1
% End of user PostScript
.61934 .47711 m
.61266 .48728 L
s
% Start of user PostScript
1.8 1.4 1.7798 1.43143 MAarrowhead1
% End of user PostScript
.61934 .54186 m
.60932 .55349 L
s
% Start of user PostScript
1.8 1.6 1.7697 1.63592 MAarrowhead1
% End of user PostScript
.61934 .60662 m
.60598 .6197 L
s
% Start of user PostScript
1.8 1.8 1.75959 1.84041 MAarrowhead1
% End of user PostScript
.61934 .67137 m
.60263 .68591 L
s
% Start of user PostScript
1.8 2. 1.74949 2.0449 MAarrowhead1
% End of user PostScript
.61934 .73613 m
.59929 .75212 L
s
% Start of user PostScript
1.8 2.2 1.73939 2.24939 MAarrowhead1
% End of user PostScript
.61934 .80089 m
.59595 .81833 L
s
% Start of user PostScript
1.8 2.4 1.72929 2.45387 MAarrowhead1
% End of user PostScript
.61934 .86564 m
.59261 .88454 L
s
% Start of user PostScript
1.8 2.6 1.71919 2.65836 MAarrowhead1
% End of user PostScript
.61934 .9304 m
.58926 .95075 L
s
% Start of user PostScript
1.8 2.8 1.70909 2.86285 MAarrowhead1
% End of user PostScript
.68551 .02381 m
.70408 .02381 L
s
% Start of user PostScript
2. 0 2.05612 0 MAarrowhead1
% End of user PostScript
.68551 .08857 m
.70037 .09038 L
s
% Start of user PostScript
2. 0.2 2.0449 0.205612 MAarrowhead1
% End of user PostScript
.68551 .15332 m
.69665 .15696 L
s
% Start of user PostScript
2. 0.4 2.03367 0.411224 MAarrowhead1
% End of user PostScript
.68551 .21808 m
.69294 .22353 L
s
% Start of user PostScript
2. 0.6 2.02245 0.616836 MAarrowhead1
% End of user PostScript
.68551 .28284 m
.68923 .2901 L
s
% Start of user PostScript
2. 0.8 2.01122 0.822448 MAarrowhead1
% End of user PostScript
.68551 .34759 m
.68551 .35668 L
s
% Start of user PostScript
2. 1. 2. 1.02806 MAarrowhead1
% End of user PostScript
.68551 .41235 m
.6818 .42325 L
s
% Start of user PostScript
2. 1.2 1.98878 1.23367 MAarrowhead1
% End of user PostScript
.68551 .47711 m
.67809 .48982 L
s
% Start of user PostScript
2. 1.4 1.97755 1.43928 MAarrowhead1
% End of user PostScript
.68551 .54186 m
.67437 .5564 L
s
% Start of user PostScript
2. 1.6 1.96633 1.6449 MAarrowhead1
% End of user PostScript
.68551 .60662 m
.67066 .62297 L
s
% Start of user PostScript
2. 1.8 1.9551 1.85051 MAarrowhead1
% End of user PostScript
.68551 .67137 m
.66695 .68955 L
s
% Start of user PostScript
2. 2. 1.94388 2.05612 MAarrowhead1
% End of user PostScript
.68551 .73613 m
.66323 .75612 L
s
% Start of user PostScript
2. 2.2 1.93266 2.26173 MAarrowhead1
% End of user PostScript
.68551 .80089 m
.65952 .82269 L
s
% Start of user PostScript
2. 2.4 1.92143 2.46734 MAarrowhead1
% End of user PostScript
.68551 .86564 m
.65581 .88927 L
s
% Start of user PostScript
2. 2.6 1.91021 2.67296 MAarrowhead1
% End of user PostScript
.68551 .9304 m
.65209 .95584 L
s
% Start of user PostScript
2. 2.8 1.89898 2.87857 MAarrowhead1
% End of user PostScript
.75168 .02381 m
.77211 .02381 L
s
% Start of user PostScript
2.2 0 2.26173 0 MAarrowhead1
% End of user PostScript
.75168 .08857 m
.76802 .09075 L
s
% Start of user PostScript
2.2 0.2 2.24939 0.206734 MAarrowhead1
% End of user PostScript
.75168 .15332 m
.76394 .15768 L
s
% Start of user PostScript
2.2 0.4 2.23704 0.413469 MAarrowhead1
% End of user PostScript
.75168 .21808 m
.75985 .22462 L
s
% Start of user PostScript
2.2 0.6 2.22469 0.620203 MAarrowhead1
% End of user PostScript
.75168 .28284 m
.75577 .29156 L
s
% Start of user PostScript
2.2 0.8 2.21235 0.826937 MAarrowhead1
% End of user PostScript
.75168 .34759 m
.75168 .35849 L
s
% Start of user PostScript
2.2 1. 2.2 1.03367 MAarrowhead1
% End of user PostScript
.75168 .41235 m
.7476 .42543 L
s
% Start of user PostScript
2.2 1.2 2.18765 1.24041 MAarrowhead1
% End of user PostScript
.75168 .47711 m
.74352 .49237 L
s
% Start of user PostScript
2.2 1.4 2.17531 1.44714 MAarrowhead1
% End of user PostScript
.75168 .54186 m
.73943 .55931 L
s
% Start of user PostScript
2.2 1.6 2.16296 1.65387 MAarrowhead1
% End of user PostScript
.75168 .60662 m
.73535 .62624 L
s
% Start of user PostScript
2.2 1.8 2.15061 1.86061 MAarrowhead1
% End of user PostScript
.75168 .67137 m
.73126 .69318 L
s
% Start of user PostScript
2.2 2. 2.13827 2.06734 MAarrowhead1
% End of user PostScript
.75168 .73613 m
.72718 .76012 L
s
% Start of user PostScript
2.2 2.2 2.12592 2.27408 MAarrowhead1
% End of user PostScript
.75168 .80089 m
.72309 .82705 L
s
% Start of user PostScript
2.2 2.4 2.11358 2.48081 MAarrowhead1
% End of user PostScript
.75168 .86564 m
.71901 .89399 L
s
% Start of user PostScript
2.2 2.6 2.10123 2.68755 MAarrowhead1
% End of user PostScript
.75168 .9304 m
.71492 .96093 L
s
% Start of user PostScript
2.2 2.8 2.08888 2.89428 MAarrowhead1
% End of user PostScript
.81786 .02381 m
.84014 .02381 L
s
% Start of user PostScript
2.4 0 2.46734 0 MAarrowhead1
% End of user PostScript
.81786 .08857 m
.83568 .09111 L
s
% Start of user PostScript
2.4 0.2 2.45387 0.207857 MAarrowhead1
% End of user PostScript
.81786 .15332 m
.83122 .15841 L
s
% Start of user PostScript
2.4 0.4 2.44041 0.415713 MAarrowhead1
% End of user PostScript
.81786 .21808 m
.82677 .22571 L
s
% Start of user PostScript
2.4 0.6 2.42694 0.62357 MAarrowhead1
% End of user PostScript
.81786 .28284 m
.82231 .29301 L
s
% Start of user PostScript
2.4 0.8 2.41347 0.831427 MAarrowhead1
% End of user PostScript
.81786 .34759 m
.81786 .36031 L
s
% Start of user PostScript
2.4 1. 2.4 1.03928 MAarrowhead1
% End of user PostScript
.81786 .41235 m
.8134 .42761 L
s
% Start of user PostScript
2.4 1.2 2.38653 1.24714 MAarrowhead1
% End of user PostScript
.81786 .47711 m
.80894 .49491 L
s
% Start of user PostScript
2.4 1.4 2.37306 1.455 MAarrowhead1
% End of user PostScript
.81786 .54186 m
.80449 .56221 L
s
% Start of user PostScript
2.4 1.6 2.35959 1.66285 MAarrowhead1
% End of user PostScript
.81786 .60662 m
.80003 .62951 L
s
% Start of user PostScript
2.4 1.8 2.34613 1.87071 MAarrowhead1
% End of user PostScript
.81786 .67137 m
.79557 .69681 L
s
% Start of user PostScript
2.4 2. 2.33266 2.07857 MAarrowhead1
% End of user PostScript
.81786 .73613 m
.79112 .76411 L
s
% Start of user PostScript
2.4 2.2 2.31919 2.28642 MAarrowhead1
% End of user PostScript
.81786 .80089 m
.78666 .83141 L
s
% Start of user PostScript
2.4 2.4 2.30572 2.49428 MAarrowhead1
% End of user PostScript
.81786 .86564 m
.78221 .89871 L
s
% Start of user PostScript
2.4 2.6 2.29225 2.70214 MAarrowhead1
% End of user PostScript
.81786 .9304 m
.77775 .96601 L
s
% Start of user PostScript
2.4 2.8 2.27878 2.90999 MAarrowhead1
% End of user PostScript
.88403 .02381 m
.90816 .02381 L
s
% Start of user PostScript
2.6 0 2.67296 0 MAarrowhead1
% End of user PostScript
.88403 .08857 m
.90334 .09147 L
s
% Start of user PostScript
2.6 0.2 2.65836 0.208979 MAarrowhead1
% End of user PostScript
.88403 .15332 m
.89851 .15914 L
s
% Start of user PostScript
2.6 0.4 2.64377 0.417958 MAarrowhead1
% End of user PostScript
.88403 .21808 m
.89368 .2268 L
s
% Start of user PostScript
2.6 0.6 2.62918 0.626937 MAarrowhead1
% End of user PostScript
.88403 .28284 m
.88885 .29446 L
s
% Start of user PostScript
2.6 0.8 2.61459 0.835917 MAarrowhead1
% End of user PostScript
.88403 .34759 m
.88403 .36213 L
s
% Start of user PostScript
2.6 1. 2.6 1.0449 MAarrowhead1
% End of user PostScript
.88403 .41235 m
.8792 .42979 L
s
% Start of user PostScript
2.6 1.2 2.58541 1.25387 MAarrowhead1
% End of user PostScript
.88403 .47711 m
.87437 .49746 L
s
% Start of user PostScript
2.6 1.4 2.57082 1.46285 MAarrowhead1
% End of user PostScript
.88403 .54186 m
.86954 .56512 L
s
% Start of user PostScript
2.6 1.6 2.55623 1.67183 MAarrowhead1
% End of user PostScript
.88403 .60662 m
.86472 .63278 L
s
% Start of user PostScript
2.6 1.8 2.54164 1.88081 MAarrowhead1
% End of user PostScript
.88403 .67137 m
.85989 .70045 L
s
% Start of user PostScript
2.6 2. 2.52704 2.08979 MAarrowhead1
% End of user PostScript
.88403 .73613 m
.85506 .76811 L
s
% Start of user PostScript
2.6 2.2 2.51245 2.29877 MAarrowhead1
% End of user PostScript
.88403 .80089 m
.85023 .83578 L
s
% Start of user PostScript
2.6 2.4 2.49786 2.50775 MAarrowhead1
% End of user PostScript
.88403 .86564 m
.84541 .90344 L
s
% Start of user PostScript
2.6 2.6 2.48327 2.71673 MAarrowhead1
% End of user PostScript
.88403 .9304 m
.84058 .9711 L
s
% Start of user PostScript
2.6 2.8 2.46868 2.92571 MAarrowhead1
% End of user PostScript
.9502 .02381 m
.97619 .02381 L
s
% Start of user PostScript
2.8 0 2.87857 0 MAarrowhead1
% End of user PostScript
.9502 .08857 m
.97099 .09184 L
s
% Start of user PostScript
2.8 0.2 2.86285 0.210102 MAarrowhead1
% End of user PostScript
.9502 .15332 m
.96579 .15986 L
s
% Start of user PostScript
2.8 0.4 2.84714 0.420203 MAarrowhead1
% End of user PostScript
.9502 .21808 m
.96059 .22789 L
s
% Start of user PostScript
2.8 0.6 2.83143 0.630305 MAarrowhead1
% End of user PostScript
.9502 .28284 m
.9554 .29592 L
s
% Start of user PostScript
2.8 0.8 2.81571 0.840406 MAarrowhead1
% End of user PostScript
.9502 .34759 m
.9502 .36395 L
s
% Start of user PostScript
2.8 1. 2.8 1.05051 MAarrowhead1
% End of user PostScript
.9502 .41235 m
.945 .43197 L
s
% Start of user PostScript
2.8 1.2 2.78429 1.26061 MAarrowhead1
% End of user PostScript
.9502 .47711 m
.9398 .5 L
s
% Start of user PostScript
2.8 1.4 2.76857 1.47071 MAarrowhead1
% End of user PostScript
.9502 .54186 m
.9346 .56803 L
s
% Start of user PostScript
2.8 1.6 2.75286 1.68081 MAarrowhead1
% End of user PostScript
.9502 .60662 m
.9294 .63605 L
s
% Start of user PostScript
2.8 1.8 2.73715 1.89091 MAarrowhead1
% End of user PostScript
.9502 .67137 m
.9242 .70408 L
s
% Start of user PostScript
2.8 2. 2.72143 2.10102 MAarrowhead1
% End of user PostScript
.9502 .73613 m
.919 .77211 L
s
% Start of user PostScript
2.8 2.2 2.70572 2.31112 MAarrowhead1
% End of user PostScript
.9502 .80089 m
.9138 .84014 L
s
% Start of user PostScript
2.8 2.4 2.69001 2.52122 MAarrowhead1
% End of user PostScript
.9502 .86564 m
.90861 .90816 L
s
% Start of user PostScript
2.8 2.6 2.67429 2.73132 MAarrowhead1
% End of user PostScript
.9502 .9304 m
.90341 .97619 L
s
% Start of user PostScript
2.8 2.8 2.65858 2.94142 MAarrowhead1
% End of user PostScript
0 1 0 r
.5 Mabswid
.15615 .15332 m
.16429 .1461 L
.17259 .14 L
.18345 .13348 L
.19431 .1282 L
.20596 .1236 L
.21979 .11922 L
.23584 .11525 L
.25248 .11211 L
.27096 .10951 L
.28223 .1083 L
.29329 .10733 L
.30549 .10651 L
.31717 .10592 L
.32383 .10566 L
.33129 .10544 L
.33476 .10536 L
.3385 .10529 L
.34208 .10524 L
.34536 .1052 L
.35183 .10516 L
.35514 .10516 L
.35881 .10517 L
.3654 .10521 L
.37167 .1053 L
.37553 .10536 L
.37922 .10544 L
.38624 .10562 L
.4025 .1062 L
.41723 .10691 L
.43133 .10774 L
.46488 .11032 L
.49725 .11359 L
.53416 .11829 L
.60562 .13068 L
.64906 .14081 L
.69546 .15456 L
.73466 .16943 L
.77577 .1898 L
.7948 .20172 L
.81411 .21625 L
.82971 .23059 L
.84442 .2475 L
.85579 .26439 L
.861 .27401 L
.8659 .28489 L
.8697 .29537 L
.87257 .30539 L
.87483 .31588 L
.87638 .32625 L
Mistroke
.87745 .3398 L
.87754 .35261 L
.87723 .35993 L
.87658 .36802 L
.87457 .38315 L
.87168 .3979 L
.86755 .41402 L
.85733 .44419 L
.84072 .48136 L
.82075 .51751 L
.76047 .60242 L
.69368 .67554 L
.61262 .74663 L
.5343 .80022 L
.498 .82001 L
.46517 .83491 L
.437 .84521 L
.40817 .8531 L
.39327 .85602 L
.37816 .85809 L
.36571 .85908 L
.35259 .85935 L
.33916 .85877 L
.32747 .85747 L
.31456 .85513 L
.30296 .85213 L
.29267 .84869 L
.2836 .84501 L
.26448 .83499 L
.24674 .82257 L
.23209 .80959 L
.20391 .77591 L
.18286 .74078 L
.16662 .70544 L
.15237 .6661 L
.14033 .6242 L
.13008 .57918 L
.1228 .53904 L
.11783 .50527 L
.1138 .47147 L
.1106 .43663 L
.10953 .42194 L
.10861 .40675 L
.10793 .39284 L
.10748 .3806 L
.10731 .37484 L
.10716 .36869 L
.10706 .36298 L
.10699 .35779 L
.10694 .35186 L
Mistroke
.10693 .3464 L
.10696 .34052 L
.10703 .33431 L
.10715 .32796 L
.1073 .32205 L
.10769 .31127 L
.10796 .30571 L
.10829 .29983 L
.109 .2895 L
.11071 .27132 L
.11191 .26161 L
.11334 .25182 L
.11635 .23544 L
.11965 .22149 L
.1232 .20948 L
.13298 .18547 L
.1391 .1746 L
.1466 .16395 L
.15401 .15548 L
.16274 .14737 L
.17141 .1408 L
.18195 .1343 L
.20323 .1246 L
.21661 .12014 L
.23207 .11609 L
.24646 .11315 L
.26356 .11045 L
.28373 .10815 L
.29584 .10714 L
.30737 .1064 L
.31861 .10586 L
.32515 .10562 L
.33132 .10544 L
.33682 .10532 L
.34299 .10523 L
.34956 .10517 L
.35583 .10516 L
.36244 .10519 L
.36619 .10522 L
.36962 .10527 L
.3764 .10538 L
.38289 .10553 L
.39791 .10602 L
.41479 .10678 L
.44741 .10888 L
.47943 .1117 L
.54573 .11999 L
.58145 .12595 L
.62202 .13424 L
.66605 .14545 L
Mistroke
.70793 .15891 L
.74486 .17394 L
.78304 .19412 L
.8204 .22169 L
.83679 .23821 L
.85231 .25872 L
.86303 .27824 L
.86789 .29009 L
.87155 .30152 L
.87421 .31262 L
.87627 .32531 L
.87736 .33784 L
.87759 .34996 L
.87692 .36416 L
.8762 .37153 L
.8751 .37979 L
.87235 .39485 L
.86884 .40939 L
.85747 .44383 L
.8399 .48299 L
.79359 .55898 L
.73726 .62967 L
.67359 .69475 L
.5987 .75721 L
.52741 .80423 L
.46446 .8352 L
.43167 .84688 L
.41673 .85106 L
.40323 .85416 L
.389 .8567 L
.37397 .8585 L
.35988 .8593 L
.34545 .85916 L
.33323 .8582 L
.32055 .85634 L
.30909 .85382 L
.29897 .85089 L
.28095 .84381 L
.26343 .83435 L
.24587 .82186 L
.22891 .80641 L
.20278 .77428 L
.17812 .73132 L
.16049 .68962 L
.14749 .65027 L
.13651 .60865 L
.12244 .5368 L
.11658 .49561 L
.11256 .45915 L
.10998 .42843 L
Mistroke
.10898 .41316 L
.10814 .39739 L
.1078 .38972 L
.10754 .38259 L
.10733 .37579 L
.10718 .36961 L
.10707 .36385 L
.10699 .35784 L
.10694 .35192 L
.10694 .3455 L
.10695 .34218 L
.10698 .33873 L
.10706 .33264 L
.10712 .3293 L
.10719 .32623 L
.10738 .31938 L
.10783 .30826 L
.10848 .29688 L
.10933 .2855 L
.11045 .27375 L
.11301 .25391 L
.11617 .23632 L
.11965 .2215 L
.1236 .20826 L
.12846 .19528 L
.139 .17477 L
.14662 .16392 L
.15476 .1547 L
.16282 .1473 L
.17267 .13995 L
.19393 .12837 L
.20736 .12311 L
.22125 .11881 L
.23439 .11557 L
.2494 .11263 L
.2673 .10996 L
.28516 .10802 L
.2958 .10714 L
.30629 .10646 L
.31608 .10596 L
.3271 .10556 L
.33299 .1054 L
.3396 .10527 L
.34298 .10523 L
.34666 .10519 L
.35342 .10516 L
.36028 .10517 L
.36692 .10523 L
.373 .10532 L
.37975 .10546 L
Mistroke
.38677 .10564 L
.39351 .10586 L
.40642 .10637 L
.43687 .10811 L
.4649 .11032 L
.49697 .11356 L
.56888 .12372 L
.61248 .13213 L
.65442 .14223 L
.6992 .15584 L
.73948 .17152 L
.76109 .18181 L
.78368 .19451 L
.80238 .20708 L
.82107 .2223 L
.83661 .23801 L
.84914 .25398 L
.85934 .27076 L
.8679 .29011 L
.87144 .30114 L
.87307 .30743 L
.87438 .31351 L
.87632 .32575 L
.87733 .33735 L
.87758 .34426 L
.87756 .35175 L
.8768 .36561 L
.87596 .37355 L
.87489 .38114 L
.87145 .39893 L
.86721 .41521 L
.86129 .43356 L
.84695 .46848 L
.80781 .53812 L
.7438 .62222 L
.67133 .69684 L
.59455 .76028 L
.55374 .78827 L
.51149 .81305 L
.47566 .83047 L
.43825 .84481 L
.42253 .84953 L
.40622 .85353 L
.39135 .85633 L
.37825 .85808 L
.36492 .85912 L
.3513 .85934 L
.34011 .85884 L
.32824 .85758 L
.31604 .85545 L
Mistroke
.30943 .85391 L
.30353 .85229 L
.29235 .84857 L
.28245 .84449 L
.26477 .83517 L
.24721 .82294 L
.21952 .79615 L
.20534 .77795 L
.19367 .76011 L
.1716 .71719 L
.15623 .6777 L
.14333 .63559 L
.12721 .56437 L
.12075 .52593 L
.11611 .49173 L
.11239 .45736 L
.11087 .44007 L
.10956 .42235 L
.10865 .40747 L
.10788 .39163 L
.10762 .38489 L
.10739 .37775 L
.10722 .37118 L
.10709 .36517 L
.10701 .35939 L
.10695 .35331 L
.10693 .3467 L
.10696 .3408 L
.10702 .33476 L
.10708 .3314 L
.10714 .32834 L
.10728 .32279 L
.10746 .31702 L
.10789 .30716 L
.10839 .29825 L
.10991 .27906 L
.11099 .26891 L
.11212 .26002 L
Mfstroke
.22232 .21808 m
.23045 .21086 L
.23873 .20479 L
.24947 .19836 L
.26012 .19325 L
.2714 .18891 L
.28461 .18495 L
.2923 .18311 L
.29968 .18161 L
.31499 .17927 L
.32281 .17841 L
.32723 .17803 L
.3315 .17771 L
.33551 .17747 L
.33996 .17726 L
.34406 .17711 L
.34792 .17702 L
.35034 .17699 L
.35298 .17696 L
.35782 .17697 L
.36261 .17704 L
.36707 .17716 L
.37196 .17735 L
.37741 .17762 L
.38864 .17841 L
.40011 .17952 L
.41081 .18082 L
.43559 .18482 L
.45926 .19 L
.48206 .19635 L
.52515 .21285 L
.54609 .22374 L
.56784 .23805 L
.58465 .25229 L
.6004 .26996 L
.60664 .27893 L
.61242 .28898 L
.61666 .29809 L
.62045 .30848 L
.62232 .315 L
.62373 .32119 L
.62481 .32725 L
.62564 .33383 L
.62611 .33985 L
.62631 .3456 L
.62625 .35203 L
.62587 .35908 L
.62509 .3667 L
.62447 .37108 L
.62379 .37518 L
Mistroke
.62022 .391 L
.61561 .40576 L
.60927 .42179 L
.59249 .45397 L
.57194 .48405 L
.52357 .53627 L
.49406 .56026 L
.46035 .58206 L
.44322 .59101 L
.42502 .59897 L
.40953 .60446 L
.40148 .60682 L
.39306 .60893 L
.38542 .61051 L
.37714 .61186 L
.36974 .61272 L
.36293 .61322 L
.35609 .61344 L
.34995 .61337 L
.34334 .61301 L
.33654 .61232 L
.33093 .6115 L
.32508 .61038 L
.31489 .60776 L
.30337 .6037 L
.29347 .59919 L
.27337 .58663 L
.2642 .57916 L
.25485 .5702 L
.22815 .53501 L
.21636 .51316 L
.20597 .48893 L
.19861 .4675 L
.19235 .44486 L
.18747 .42225 L
.18416 .40193 L
.18279 .39096 L
.18179 .38087 L
.18099 .37007 L
.18068 .36412 L
.18056 .3613 L
.18048 .35875 L
.18037 .35444 L
.18031 .3499 L
.18031 .34574 L
.18035 .34186 L
.18046 .3374 L
.1806 .33334 L
.18082 .32896 L
.18111 .32438 L
Mistroke
.18182 .31611 L
.18268 .30861 L
.18384 .30065 L
.18533 .2924 L
.18881 .27782 L
.19282 .26527 L
.1981 .25258 L
.20474 .24025 L
.21207 .2296 L
.21988 .22054 L
.23693 .20601 L
.24645 .20002 L
.25785 .19425 L
.27084 .18911 L
.28399 .18512 L
.29724 .18208 L
.3101 .17991 L
.31754 .17896 L
.32589 .17814 L
.32981 .17783 L
.33403 .17755 L
.33802 .17734 L
.34177 .17719 L
.3458 .17707 L
.35027 .17699 L
.35469 .17696 L
.35947 .17699 L
.36399 .17707 L
.3683 .1772 L
.37223 .17736 L
.37652 .17757 L
.38658 .17824 L
.39749 .17924 L
.41765 .18178 L
.43699 .18509 L
.4555 .18909 L
.49841 .20184 L
.52062 .21078 L
.5441 .2226 L
.56503 .23598 L
.58276 .2505 L
.59818 .26709 L
.60976 .2841 L
.61504 .29439 L
.61971 .30618 L
.62146 .31184 L
.62304 .31797 L
.62423 .32382 L
.62511 .32934 L
.62582 .33586 L
Mistroke
.62608 .33935 L
.62625 .3431 L
.62631 .34951 L
.62603 .35671 L
.62549 .36323 L
.62458 .37037 L
.62341 .37722 L
.62208 .38358 L
.61787 .39902 L
.6116 .41628 L
.5958 .44836 L
.57637 .47812 L
.55127 .50877 L
.49782 .55746 L
.46267 .58074 L
.43005 .59694 L
.41325 .60325 L
.39521 .60843 L
.38633 .61034 L
.3815 .6112 L
.37697 .61188 L
.37281 .6124 L
.36833 .61285 L
.3606 .61333 L
.35345 .61344 L
.34688 .61324 L
.33983 .6127 L
.33594 .61225 L
.33242 .61174 L
.32586 .61055 L
.31889 .6089 L
.30547 .60454 L
.29441 .59966 L
.28331 .59345 L
.26515 .57999 L
.24722 .56174 L
.23311 .54285 L
.22005 .52056 L
.20872 .4959 L
.19464 .45379 L
.18903 .43021 L
.18515 .40872 L
.18252 .3885 L
.1815 .37742 L
.18113 .37223 L
.18084 .3674 L
.18063 .36285 L
.18046 .358 L
.18036 .35365 L
.18031 .3497 L
Mistroke
.18031 .34547 L
.18037 .34089 L
.18042 .3386 L
.18049 .33618 L
.18067 .33185 L
.18089 .32766 L
.18115 .32384 L
.18189 .31541 L
.18274 .3082 L
.18382 .30078 L
.18615 .28853 L
.18937 .27584 L
.19356 .26329 L
.1988 .25112 L
.21035 .23189 L
.21803 .22252 L
.226 .21464 L
.23561 .20694 L
.24715 .19963 L
.25949 .19352 L
.27191 .18874 L
.28473 .18492 L
.29934 .18168 L
.306 .18053 L
.31336 .17947 L
.31992 .1787 L
.32726 .17802 L
.33183 .17769 L
.33613 .17744 L
.3403 .17724 L
.34479 .17709 L
.34886 .17701 L
.35273 .17697 L
.35703 .17697 L
.36173 .17703 L
.36644 .17714 L
.37077 .1773 L
.37584 .17753 L
.38069 .17782 L
.38946 .17848 L
.39917 .17941 L
.42191 .18244 L
.44365 .18643 L
.46524 .19153 L
.48932 .19868 L
.51422 .20801 L
.53734 .2189 L
.55757 .23083 L
.57797 .2462 L
.59436 .2625 L
Mistroke
.60716 .27976 L
.61361 .29136 L
.6186 .30303 L
.62209 .31412 L
.62361 .32062 L
.62473 .32676 L
.62561 .33355 L
.62612 .34005 L
.62627 .34385 L
.62632 .34735 L
.62627 .35144 L
.62611 .35535 L
.62586 .35919 L
.62548 .36331 L
.62451 .37081 L
.62306 .37903 L
.62094 .38827 L
.61659 .40291 L
.61036 .41927 L
.5932 .45279 L
.57222 .48368 L
.54893 .51132 L
.51826 .54096 L
.48696 .56532 L
.44963 .58783 L
.43211 .59607 L
.41592 .60234 L
.40159 .60679 L
.38655 .6103 L
.37819 .61171 L
.37039 .61266 L
.36352 .61319 L
.35617 .61344 L
.35219 .61342 L
.34848 .61332 L
.34168 .61288 L
.33793 .61249 L
.33453 .61206 L
.32702 .61078 L
.32114 .60947 L
.31486 .60776 L
.30273 .60344 L
.29188 .59837 L
.28256 .59298 L
.26354 .57857 L
.24817 .56285 L
.2355 .54638 L
.213 .50594 L
.20435 .48458 L
.19663 .4609 L
Mistroke
.1914 .44094 L
.18703 .41987 L
.18397 .40054 L
.18202 .38344 L
.18123 .37372 L
.18073 .36509 L
.18053 .3604 L
.18045 .35778 L
.18039 .35538 L
.18032 .35102 L
.18031 .34647 L
.18034 .34261 L
.18042 .33853 L
.18055 .33473 L
.1807 .3313 L
.18091 .32734 L
.18121 .32309 L
.18188 .31554 L
.1828 .30774 L
.18404 .29941 L
.18732 .2835 L
.19123 .26986 L
.19567 .25801 L
.20704 .23663 L
.21396 .22723 L
.22249 .21792 L
.2306 .21074 L
.24014 .20386 L
.25963 .19347 L
.2662 .19079 L
Mfstroke
.45392 .44473 m
.44076 .4564 L
.42766 .46597 L
.41265 .47479 L
.39621 .48209 L
.3879 .48489 L
.37893 .48723 L
.37484 .48806 L
.37054 .48878 L
.3669 .48926 L
.36291 .48964 L
.3591 .48987 L
.35564 .48996 L
.35169 .48992 L
.34799 .48975 L
.34462 .48947 L
.34154 .48911 L
.3382 .4886 L
.33469 .48794 L
.32679 .48594 L
.31981 .48353 L
.31248 .48031 L
.30514 .47629 L
.29374 .46824 L
.28263 .45783 L
.27395 .44742 L
.26592 .43537 L
.25461 .41211 L
.25007 .399 L
.24684 .38682 L
.24541 .37997 L
.24432 .37357 L
.24345 .36697 L
.24308 .3635 L
.24278 .35978 L
.24258 .35677 L
.24245 .35399 L
.24236 .35097 L
.24234 .34929 L
.24233 .34777 L
.24234 .34617 L
.24235 .34471 L
.24239 .34312 L
.24245 .34144 L
.24258 .33863 L
.24278 .33558 L
.24302 .33283 L
.24328 .33033 L
.24402 .32482 L
.24488 .31984 L
Mistroke
.24586 .31522 L
.24859 .30536 L
.25171 .29695 L
.25605 .28789 L
.26086 .28 L
.27114 .26754 L
.27787 .26144 L
.28465 .25642 L
.29221 .25186 L
.30096 .24765 L
.3098 .24433 L
.31833 .24188 L
.32339 .24073 L
.32891 .2397 L
.33514 .23881 L
.33797 .23849 L
.34105 .23821 L
.34397 .238 L
.34667 .23785 L
.34927 .23774 L
.35203 .23768 L
.3551 .23766 L
.35798 .23769 L
.35965 .23773 L
.36116 .23778 L
.36459 .23794 L
.36751 .23812 L
.37025 .23834 L
.37654 .23899 L
.38273 .23984 L
.38944 .24099 L
.40167 .24372 L
.41286 .24697 L
.42576 .25171 L
.43946 .25808 L
.45175 .26525 L
.46257 .27309 L
.47245 .28198 L
.48051 .29111 L
.4881 .30232 L
.49144 .30865 L
.49441 .31564 L
.49661 .32226 L
.49761 .326 L
.4984 .32961 L
.49901 .33302 L
.49953 .33678 L
.49986 .34025 L
.50006 .34349 L
.50014 .34738 L
Mistroke
.50008 .35107 L
.49998 .3532 L
.49985 .35515 L
.49965 .35743 L
.49942 .3596 L
.4988 .36394 L
.49807 .36799 L
.49581 .37728 L
.49307 .38568 L
.48997 .39342 L
.481 .41071 L
.47098 .42543 L
.45851 .44007 L
.43327 .4621 L
.41757 .47213 L
.40245 .4796 L
.39456 .4827 L
.38618 .48539 L
.38183 .48655 L
.37705 .48763 L
.37268 .48844 L
.36871 .48903 L
.36493 .48947 L
.36099 .48977 L
.35707 .48994 L
.35487 .48997 L
.35284 .48995 L
.34917 .48982 L
.34588 .48958 L
.34212 .48918 L
.33863 .48868 L
.33224 .4874 L
.32568 .4856 L
.31452 .48128 L
.3034 .47521 L
.2923 .46705 L
.28208 .45723 L
.27355 .44687 L
.26054 .4255 L
.2549 .41286 L
.25066 .40093 L
.24706 .38779 L
.24561 .38101 L
.24437 .37391 L
.24352 .36765 L
.24317 .36436 L
.24286 .36087 L
.24264 .35768 L
.24249 .35479 L
.24239 .35192 L
Mistroke
.24234 .34922 L
.24233 .34774 L
.24234 .34611 L
.24236 .34442 L
.2424 .34284 L
.24251 .34004 L
.24259 .33849 L
.24268 .33707 L
.24292 .33392 L
.24326 .33053 L
.24407 .32448 L
.24506 .31895 L
.24613 .31407 L
.24918 .3036 L
.25276 .29453 L
.25679 .28655 L
.26713 .27186 L
.27333 .26541 L
.28091 .25907 L
.28799 .25428 L
.29621 .2498 L
.30392 .24644 L
.31263 .24344 L
.3176 .24207 L
.32326 .24075 L
.32862 .23975 L
.33367 .239 L
.33974 .23832 L
.34299 .23806 L
.34466 .23795 L
.34645 .23786 L
.34805 .23779 L
.34951 .23774 L
.35239 .23767 L
.35401 .23766 L
.35578 .23766 L
.35745 .23768 L
.35901 .23771 L
.36179 .2378 L
.36479 .23795 L
.36765 .23813 L
.37028 .23834 L
.37677 .23902 L
.383 .23988 L
.3955 .24224 L
.40924 .24584 L
.42272 .25049 L
.43516 .25591 L
.45709 .26891 L
.4682 .2779 L
Mistroke
.47735 .28728 L
.48596 .29879 L
.48989 .30557 L
.49308 .31231 L
.49542 .31846 L
.49746 .32541 L
.49819 .32855 L
.49883 .33194 L
.49932 .33516 L
.49967 .33815 L
.49996 .34165 L
.50012 .34547 L
.50014 .34888 L
.50002 .3525 L
.49974 .35653 L
.49933 .3603 L
.49871 .36448 L
.49787 .36898 L
.49604 .37647 L
.49345 .38463 L
.48717 .39944 L
.47919 .41364 L
.47032 .42629 L
.45888 .43968 L
.44508 .45282 L
.43218 .46288 L
.4174 .47223 L
.40818 .47702 L
.39955 .4808 L
.39144 .48377 L
.3825 .48638 L
.37869 .48728 L
.37459 .48811 L
.37107 .4887 L
.36724 .48922 L
.36319 .48962 L
.361 .48977 L
.35896 .48988 L
.35535 .48996 L
.35153 .48992 L
.34784 .48974 L
.34576 .48957 L
.34383 .48938 L
.33998 .48889 L
.33591 .48819 L
.32874 .4865 L
.32241 .4845 L
.31536 .48167 L
.30803 .47797 L
.29571 .46981 L
Mistroke
.28541 .46071 L
.27574 .44976 L
.26168 .42773 L
.25566 .41474 L
.25118 .40254 L
.24736 .38906 L
.24585 .38221 L
.24453 .37492 L
.24363 .36856 L
.24302 .36283 L
.2428 .3601 L
.2426 .35714 L
.24247 .35437 L
.24238 .35182 L
.24233 .3489 L
.24234 .34618 L
.24239 .34323 L
.24244 .34158 L
.24251 .34007 L
.24267 .33724 L
.2429 .33417 L
.24355 .32811 L
.24436 .32273 L
.24545 .31706 L
.24801 .3072 L
.25121 .29816 L
.25476 .29034 L
.26496 .27447 L
.27119 .26749 L
.27887 .26063 L
.28674 .25506 L
.29488 .25046 L
.30282 .24688 L
.31183 .24369 L
.3172 .24217 L
.32222 .24098 L
.32746 .23995 L
.3324 .23917 L
.33834 .23846 L
.34152 .23817 L
.34491 .23794 L
.34791 .23779 L
.35073 .2377 L
.35236 .23767 L
.35385 .23766 L
.35558 .23766 L
.35723 .23768 L
.35996 .23774 L
.36292 .23785 L
.36574 .23801 L
Mistroke
.36834 .23819 L
.37474 .23878 L
.38091 .23957 L
.39328 .24176 L
.40692 .24515 L
.41866 .24896 L
.431 .25397 L
.45219 .26554 L
.46392 .27418 L
.47372 .28328 L
.48308 .29455 L
.4872 .3008 L
.49107 .30789 L
.49395 .31442 L
.49613 .32063 L
.49786 .32709 L
.49849 .33007 L
.49907 .3334 L
.49956 .33704 L
.49976 .33906 L
.49991 .34097 L
.50009 .34441 L
.50014 .34816 L
.50011 .35016 L
.50003 .35237 L
.49989 .35469 L
.49971 .35686 L
.49927 .36078 L
.49863 .365 L
.49692 .37311 L
.49442 .38177 L
.48818 .39736 L
.47903 .41389 L
.46632 .43129 L
.45345 .44519 L
.43804 .45854 L
.42253 .46923 L
.40757 .47731 L
.39672 .4819 L
.38515 .48568 L
.37857 .48731 L
.37243 .48848 L
.36697 .48925 L
.36392 .48956 L
.36114 .48977 L
.35867 .48989 L
.35605 .48996 L
.35359 .48996 L
.35137 .48991 L
.34878 .4898 L
Mistroke
.34599 .48959 L
.34338 .48933 L
.341 .48903 L
.33631 .48827 L
.33126 .48716 L
.32142 .48414 L
Mfstroke
.61934 .60662 m
.57099 .64951 L
.52404 .68358 L
.47272 .71277 L
.44484 .72499 L
.42034 .73343 L
.40824 .73675 L
.39571 .73955 L
.38528 .74137 L
.37408 .74277 L
.36242 .74359 L
.35603 .74374 L
.35029 .74369 L
.33945 .7431 L
.3295 .74195 L
.32061 .74039 L
.31146 .73823 L
.29583 .7331 L
.27864 .72513 L
.26431 .71632 L
.24981 .70508 L
.23591 .69171 L
.21435 .66478 L
.19535 .63277 L
.17871 .59565 L
.16727 .56295 L
.15755 .52811 L
.15085 .4983 L
.14531 .46769 L
.14102 .43727 L
.13823 .41057 L
.13711 .39639 L
.13632 .38348 L
.136 .37676 L
.13573 .3698 L
.13562 .36621 L
.13552 .36233 L
.13545 .35883 L
.1354 .35561 L
.13535 .34985 L
.13535 .34664 L
.13536 .34372 L
.13542 .33841 L
.13553 .33289 L
.13567 .32803 L
.13584 .32356 L
.13635 .31363 L
.1371 .30333 L
.13796 .29426 L
.1405 .27506 L
Mistroke
.14345 .25936 L
.14731 .24395 L
.15163 .2306 L
.15613 .21945 L
.16218 .20736 L
.16966 .19555 L
.1776 .18558 L
.18586 .17719 L
.20467 .16307 L
.21613 .15678 L
.22965 .1509 L
.2453 .14565 L
.2616 .14151 L
.27753 .13849 L
.28638 .13716 L
.29631 .13593 L
.30599 .13497 L
.31521 .13425 L
.32432 .13371 L
.32902 .13349 L
.33423 .13329 L
.33728 .1332 L
.34019 .13313 L
.34569 .13303 L
.34882 .13299 L
.35173 .13297 L
.35495 .13296 L
.35839 .13298 L
.36418 .13303 L
.36968 .13313 L
.37581 .13329 L
.3825 .13352 L
.39619 .13417 L
.41162 .13519 L
.4411 .13793 L
.47144 .14182 L
.50085 .14666 L
.53004 .1526 L
.56233 .16065 L
.62137 .18058 L
.65459 .19604 L
.68739 .2162 L
.7124 .23711 L
.72487 .25067 L
.73512 .2645 L
.74428 .28043 L
.75101 .29639 L
.7538 .30522 L
.75626 .31535 L
.75725 .3206 L
Mistroke
.75811 .32637 L
.75874 .33193 L
.75914 .33711 L
.75947 .34744 L
.7592 .35733 L
.75826 .36851 L
.75744 .37491 L
.7565 .3808 L
.7543 .39184 L
.75122 .40407 L
.74375 .42698 L
.72139 .47529 L
.68759 .52812 L
.60607 .61925 L
.55346 .66306 L
.50423 .69585 L
.47728 .71053 L
.44865 .72348 L
.42254 .73276 L
.41126 .73597 L
.39938 .7388 L
.38866 .74083 L
.37906 .74222 L
.3701 .74312 L
.36089 .74364 L
.35103 .74371 L
.34213 .74331 L
.33266 .74238 L
.32288 .74084 L
.31373 .73882 L
.30418 .73607 L
.28783 .72972 L
.2731 .72198 L
.26052 .71363 L
.23631 .69213 L
.21456 .66508 L
.19755 .63697 L
.18459 .60998 L
.17209 .57761 L
.16123 .54224 L
.15371 .51179 L
.14736 .47986 L
.14248 .44857 L
.13917 .42059 L
.13799 .40786 L
.137 .39481 L
.13634 .38398 L
.13582 .37245 L
.1356 .36567 L
.13552 .36238 L
Mistroke
.13546 .35938 L
.13538 .35382 L
.13535 .3479 L
.13537 .3421 L
.13541 .33885 L
.13546 .33583 L
.13553 .33269 L
.13561 .32985 L
.13584 .32354 L
.13609 .31824 L
.13637 .3134 L
.13715 .30275 L
.13802 .29372 L
.13913 .28445 L
.14207 .26616 L
.14549 .25069 L
.15004 .23513 L
.15579 .22022 L
.1677 .19838 L
.1758 .18766 L
.18429 .17865 L
.19356 .17071 L
.20475 .16302 L
.21563 .15703 L
.2283 .15142 L
.24071 .14704 L
.25562 .14289 L
.27033 .13975 L
.2852 .13733 L
.30257 .13529 L
.31298 .13441 L
.32307 .13377 L
.32871 .1335 L
.33415 .1333 L
.33912 .13315 L
.34461 .13304 L
.34749 .133 L
.35069 .13298 L
.35407 .13296 L
.35727 .13297 L
.36305 .13302 L
.36635 .13307 L
.36938 .13312 L
.37491 .13326 L
.38088 .13346 L
.39187 .13394 L
.40534 .13474 L
.4179 .13569 L
.44372 .13822 L
.46919 .1415 L
Mistroke
.52979 .15254 L
.56166 .16046 L
.59704 .1714 L
.62709 .18297 L
.65831 .19804 L
.68603 .21523 L
.70893 .2338 L
.73107 .25865 L
.74027 .27288 L
.74486 .28162 L
.74858 .28998 L
.75394 .30572 L
.75607 .31442 L
.75777 .32392 L
.75879 .3325 L
.75933 .34071 L
.75945 .34999 L
.75902 .36018 L
.75852 .3661 L
.75778 .37247 L
.75589 .38414 L
.75307 .39706 L
.74899 .41166 L
.73909 .43877 L
.72685 .46502 L
.69654 .51548 L
.65437 .56959 L
.6066 .61876 L
.55111 .6648 L
.52143 .68527 L
.48875 .70457 L
.45927 .719 L
.43302 .72934 L
.40891 .73658 L
.39719 .73925 L
.38468 .74146 L
.37823 .74232 L
.37246 .74292 L
.3659 .74341 L
.35981 .74368 L
.34923 .74367 L
.34342 .7434 L
.33814 .74299 L
.32892 .74186 L
.32056 .74038 L
.31169 .73829 L
.3025 .73552 L
.28488 .72833 L
.27004 .7201 L
.24392 .69975 L
Mistroke
.23115 .68647 L
.22063 .67351 L
.20253 .64596 L
.18863 .61901 L
.17522 .58642 L
.16365 .55087 L
.15562 .52012 L
.14885 .48802 L
.14378 .45776 L
.14033 .43139 L
.13903 .41913 L
.13785 .40615 L
.13697 .39431 L
.13632 .3835 L
.13578 .37135 L
.13558 .36506 L
.1355 .36157 L
.13544 .3584 L
.13537 .35247 L
.13535 .34915 L
.13535 .34609 L
.13537 .34288 L
.1354 .34 L
.13545 .3367 L
.13551 .33362 L
.13565 .32847 L
.13586 .32313 L
.13634 .31378 L
.13704 .30408 L
.13801 .29382 L
.14048 .27523 L
.14354 .25898 L
.14687 .24548 L
.15116 .2319 L
.15659 .21842 L
.16329 .20542 L
.17788 .18527 L
.18712 .17605 L
.19656 .16847 L
.2078 .16121 L
.22149 .15427 L
.23468 .14905 L
.2481 .14485 L
.26351 .1411 L
.27203 .13943 L
.28149 .13787 L
.29051 .13662 L
.30088 .13545 L
.31072 .13458 L
.32029 .13393 L
Mistroke
.32622 .13361 L
.33197 .13337 L
.33724 .1332 L
.34024 .13313 L
.3431 .13307 L
.34648 .13302 L
.34957 .13298 L
.35293 .13297 L
.35662 .13297 L
.35988 .13298 L
.36336 .13302 L
.36636 .13307 L
.36968 .13313 L
.37622 .1333 L
.38254 .13352 L
.39466 .13409 L
.40812 .13493 L
.42325 .13615 L
.4517 .13916 L
.47936 .14302 L
.50784 .14798 L
.53959 .1548 L
.59856 .17193 L
.63252 .18534 L
.66691 .20291 L
.69412 .22122 L
.70724 .23223 L
.72029 .24536 L
.72964 .25672 L
.73735 .26798 L
.74368 .27924 L
.74955 .29244 L
.75374 .305 L
.75667 .31741 L
.75786 .32452 L
.75867 .33119 L
.75925 .33909 L
.75946 .34679 L
.75929 .35539 L
.75877 .36338 L
.75773 .37282 L
.7563 .38191 L
.75268 .39862 L
.74716 .41733 L
.73911 .43873 L
.72839 .46199 L
.70367 .5048 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{223, 223},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003O0000gb000`400?l00000o`00003ogoooool0
037ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Hooooo`?o00006?ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001Sooooo1Ol0000Fooooo`Go00000oooool00ol0
003oooooooooo`02ooooo`?o00006oooool0033ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000001Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000006?ooool01?l0003oooooooooool0000Gooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Jooooo`00<?ooool01?l0003o
ooooooooool0000;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo000`ooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06?ooool0033ooooo00Co0000oooooooooooo00001oooool4o`00
01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`Co00006?ooool01Ol0
003ooooooooooooooooo000001Kooooo00Go0000ooooooooooooooooo`000007ooooo`Co00006ooo
ool0033ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Iooooo`;o00006Ooo
ool2o`0000Wooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000001Kooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01cooooo000Gooooo`03o`00
0?oooooooooo01Oooooo0_l00008ooooo`Go00006?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Oooooo1Ol0000Hooooo`?o00006?ooool3o`0000Sooooo1Ol0000Jooooo`005ooo
ool00ol0003oooooooooo`35ooooo`005oooool00ol0003oooooooooo`35ooooo`005oooool00ol0
003oooooooooo`35ooooo`005oooool00ol0003oooooooooo`06ooooo`?o00002oooool3o`0000_o
oooo0ol0000:ooooo`?o00002oooool3o`0000_ooooo0ol0000:ooooo`?o00002oooool3o`0000_o
oooo0ol0000:ooooo`?o00002oooool3o`0000_ooooo0ol0000:ooooo`?o00002oooool3o`0000[o
oooo000Boooool[o00000oooool001Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02o`000003ooooool0
003ooooo00Gooooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`04ooooo`04o`00
0?ooooooooooooooo`;o000000?oooooo`000?ooool01Oooool01?l0003oooooooooooooool3o`00
00Kooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool00oooool2o`00
00Gooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool01?ooool2o`00
00Gooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool00oooool3o`00
00Cooooo00?o0000ooooooooool01?ooool3o`0000?ooooo00?o0000ooooooooool01Oooool001Oo
oooo00?o0000ooooooooool0aOooool001Oooooo00?o0000ooooooooool0aOooool001Oooooo00?o
0000ooooooooool0aOooool001Oooooo00?o0000ooooooooool0aOooool001Oooooo00?o0000oooo
ooooool0aOooool001Oooooo0_l00036ooooo`005oooool00ol0003oooooooooo`35ooooo`005ooo
ool00ol0003oooooooooo`35ooooo`005oooool00ol0003oooooooooo`35ooooo`005oooool00ol0
003oooooooooo`35ooooo`005oooool00ol0003oooooooooo`0_ooooo`?o00002oooool3o`0000[o
oooo0ol0000;ooooo`?o00002_ooool3o`0000_ooooo0ol0000;ooooo`?o00002_ooool3o`0000_o
oooo0_l0000;ooooo`;o00003?ooool2o`0000cooooo000Gooooo`;o00002_ooool2o`0000_ooooo
0ol00008ooooo`Ko00002?ooool5o`0000Wooooo1Ol00008ooooo`Go00002Oooool5o`0000Sooooo
1Ol00009ooooo`Go00002Oooool5o`0000Sooooo1Ol00009ooooo`Co00002Oooool4o`0000[ooooo
1?l0000:ooooo`005oooool00ol0003oooooooooo`08ooooo`?o00002Oooool3o`0000[ooooo1?l0
000:ooooo`;o00003?ooool2o`0000_ooooo0_l0000<ooooo`;o00002oooool2o`0000cooooo0_l0
000;ooooo`?o00002oooool2o`0000cooooo1Ol00008ooooo`Go00002Oooool5o`0000Wooooo000G
ooooo`03o`000?oooooooooo00Oooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0X?ooool001Kooooo0ol00009ooooo`03o`000?oooooooooo02cooooo4ol0o`1koooo
o`005_ooool3o`0002cooooo3_l0o`0?oooooa;o0?l0Joooool001Oooooo00?o0000ooooooooool0
9_ooool7o`3o02Wooooo2ol0o`1Tooooo`005oooool00ol0003oooooooooo`0Rooooo`Ko0?l0>?oo
ool9o`3o05cooooo000Gooooo`;o00008Oooool3o`3o04Gooooo1ol0o`1Fooooo`005oooool00ol0
003oooooooooo`0Nooooo`?o0?l0Boooool9o`3o053ooooo000Gooooo`03o`000?oooooooooo01co
oooo0_l0o`0Eoooooago0?l08_ooool7o`3o04cooooo000Gooooo`03o`000?oooooooooo01[ooooo
0_l0o`0Aooooo`Oo0?l06Oooool:o`3o01oooooo1ol0o`18ooooo`005oooool00ol0003ooooooooo
o`0Jooooo`03o`3o0?oooooooooo00_ooooo1ol0o`0Vooooo`Oo0?l07_ooool6o`3o04Gooooo000G
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool2o`3o00cooooo1?l0o`0B
ooooo`?o00002oooool3o`0000_ooooo0_l00008o`3o00?ooooo0ol0000;ooooo`;o00002Oooool5
o`3o00_ooooo0_l0000;ooooo`;o00003?ooool2o`0000cooooo0_l0000<ooooo`005oooool2o`00
00_ooooo00?o0000ooooooooool02_ooool00ol0o`3o0000ooooo`07ooooo`?o00000ol0o`08oooo
o`Go00002?ooool5o`0000Wooooo1Ol00009ooooo`Co00001?ooool7o`3o00?o00002Oooool3o`00
00[ooooo00?o0000o`3o0?l0o`000ol0o`08ooooo`?o00002_ooool4o`0000[ooooo0ol0000;oooo
o`?o00002oooool001Oooooo00?o0000ooooooooool02Oooool2o`0000[ooooo00Co0000o`3o0?l0
003o00002?ooool01?l0003o0?l0o`3o0?l0o`0:ooooo`?o00002_ooool2o`0000cooooo0_l0000;
ooooo`;o00003?ooool2o`0000Go0?l01_ooool5o`0000Wooooo1?l00005o`3o00Cooooo1Ol00009
ooooo`Go00002?ooool5o`0000Wooooo1Ol0000:ooooo`005_ooool3o`0000[ooooo0_l00009oooo
o`04o`000?l0o`3o0000o`0000Sooooo0ol0o`0<ooooo`03o`000?oooooooooo03Sooooo1Ol0o`0G
ooooo`Go0?l0>_ooool001Kooooo0ol00009ooooo`?o00002_ooool00ol0o`3o0000ooooo`07oooo
o`;o0?l0C?ooool5o`3o01Oooooo1Ol0o`0gooooo`001?ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`3o0?oooooooooo00Oooooo0_l0o`1@ooooo`Go0?l05oooool4o`3o03Gooooo0003ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
01Cooooo00?o0?l0ooooooooool01_ooool2o`3o01Kooooo5ol0o`0Wooooo`Co0?l05oooool4o`3o
03?ooooo0003ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Cooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool04Oooool6o`3o
01Cooooo2Ol0o`0Sooooo`?o0?l06?ooool3o`3o037ooooo0003ooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooooooool00_ooool2o`0001Cooooo00?o0?l0ooooooooool01Oooool2o`3o
013ooooo0ol0o`0Pooooo`Ko0?l08_ooool3o`3o01Sooooo0ol0o`0_ooooo`000oooool01?l0003o
ooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`0Booooo`03o`3o0?oooooooooo
00Gooooo0_l0o`0?ooooo`?o0?l09_ooool5o`3o027ooooo0_l0o`0Iooooo`;o0?l0;_ooool000?o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01;ooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0<ooooo`;o0?l0;_ooool3o`3o
01oooooo0ol0o`0Iooooo`03o`3o0?oooooooooo02_ooooo0004ooooo`;o00002?ooool5o`0000Co
oooo00?o0000ooooooooool04Oooool2o`3o00Kooooo0_l0o`0=ooooo`;o0?l0<Oooool4o`3o01ko
oooo0ol0o`0Hooooo`03o`3o0?oooooooooo02[ooooo000Gooooo`03o`000?oooooooooo017ooooo
00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0:ooooo`?o0?l08Oooool2o`0000_ooooo
0_l00005ooooo`?o0?l01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo
0ol0o`0<ooooo`03o`000?oooooooooo00Sooooo0_l0o`000ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Wooooo000Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?oo
ool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo00[ooooo0_l0o`0Eooooo`?o00002ooo
ool3o`0000[ooooo1?l00006ooooo`?o0?l000?oooooo`000?l000003?ooool2o`0000_ooooo0ol0
o`0;ooooo`;o00002_ooool2o`3o00gooooo00?o0000ooooooooool02_ooool2o`0000gooooo000G
ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo00Cooooo00?o0?l0
o`000?ooool02_ooool00ol0003o0?l0ooooo`07ooooo`Ko00002?ooool5o`0000Sooooo1Ol00009
ooooo`Go00001oooool3o`3o00;o00002_ooool4o`0000Wooooo0ol00002o`3o00Wooooo1?l00009
ooooo`03o`000?l0o`3o0?l000_ooooo0ol0000:ooooo`?o00003Oooool001Oooooo00?o0000oooo
ooooool02Oooool2o`0000Gooooo00?o0?l0ooooooooool01?ooool00ol0o`3o0000ooooo`08oooo
o`;o000000?o0?l0o`000?ooool01oooool4o`0000[ooooo0_l0000Wooooo`?o0?l000?o0000oooo
ooooool02_ooool2o`0000_ooooo00?o0000o`3o0?l0o`002oooool2o`0000[ooooo00?o0000o`3o
0?ooool02oooool00ol0003oooooooooo`0:ooooo`;o00003?ooool001Kooooo0ol0000:ooooo`;o
00001Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?l0003ooooo00Sooooo0_l000000ol0o`3o
0000ooooo`09ooooo`03o`000?oooooooooo03Gooooo0_l0o`0Looooo`03o`3o0?oooooooooo01Ko
oooo00?o0?l0ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wo
oooo000Fooooo`?o00002Oooool3o`0000Cooooo00?o0?l0ooooooooool00oooool00ol0003o0?l0
o`00000:ooooo`;o0?l0A?ooool2o`3o01cooooo0_l0o`0Gooooo`03o`3o0?oooooooooo02?ooooo
000Gooooo`03o`000?oooooooooo00oooooo00?o0?l0ooooooooool01?ooool00ol0o`3ooooooooo
o`08ooooo`;o0?l05oooool=o`3o02;ooooo0_l0o`0Looooo`;o0?l05oooool00ol0o`3ooooooooo
o`0Rooooo`005oooool00ol0003oooooooooo`0?ooooo`03o`3o0?oooooooooo00?ooooo0_l0o`0:
ooooo`;o0?l04_ooool5o`3o00cooooo1_l0o`0Oooooo`03o`3o0?oooooooooo01[ooooo0_l0o`0F
ooooo`;o0?l08oooool001Oooooo00?o0000ooooooooool03oooool00ol0o`3oooooooooo`03oooo
o`;o0?l02Oooool2o`3o017ooooo0ol0o`0Dooooo`Go0?l07Oooool00ol0o`3oooooooooo`0Joooo
o`03o`3o0?oooooooooo01Gooooo0_l0o`0Rooooo`005oooool2o`00013ooooo00?o0?l0oooooooo
ool00oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00kooooo0ol0o`0Iooooo`Co
0?l07?ooool2o`3o01_ooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Pooooo`00
5oooool00ol0003oooooooooo`0>ooooo`;o0?l01Oooool00ol0o`3oooooooooo`07ooooo`;o0?l0
3oooool2o`3o01gooooo1?l0o`0Kooooo`;o0?l06_ooool2o`3o01Kooooo0_l0o`0Qooooo`005ooo
ool00ol0003oooooooooo`0>ooooo`;o0?l01Oooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oo
oooooooo00gooooo0_l0o`0Pooooo`?o0?l06oooool2o`3o01[ooooo0_l0o`0Fooooo`;o0?l08?oo
ool001Oooooo00?o0000ooooooooool03_ooool00ol0o`3oooooooooo`03ooooo`;o0?l02?ooool2
o`3o00kooooo0_l0o`0Jooooo`03o`000?oooooooooo00Kooooo0_l0o`03ooooo`03o`000?oooooo
oooo00[ooooo0_l00009ooooo`;o0?l000?oooooo`000?l000003?ooool00ol0003oooooooooo`08
ooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool07_ooool001Oooooo00?o0000oooo
ooooool03_ooool00ol0o`3oooooooooo`03ooooo`;o0?l02?ooool00ol0o`3oooooooooo`0<oooo
o`;o0?l06oooool2o`0000Wooooo00Co0?l0ooooool0003o00002oooool3o`0000Wooooo0_l0o`03
o`0000_ooooo0_l0000:ooooo`;o0?l00_l0000;ooooo`;o00001oooool2o`3o00?ooooo0_l0000J
ooooo`005oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool0o`001Oooool0
1?l0o`3oooooooooool00006ooooo`03o`3o0?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool3o`3o00cooooo1?l0000:ooooo`Co00002Oooool01?l0o`3oooooo`000?l0000<ooooo`;o0000
2Oooool2o`3o00;o00002oooool2o`0000_ooooo00?o0?l0o`000?l000002_ooool3o`0000Sooooo
00?o0?l0ooooooooool00ol0000:ooooo`?o00003Oooool001Oooooo0_l0000;ooooo`05o`000?oo
ooooooooooooool0o`001Oooool01?l0o`3oooooooooool00006ooooo`03o`3o0?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool2o`3o00?ooooo0_l00008ooooo`Ko00002oooool2o`0000Wo
oooo00Co0?l0ooooool0003o00003?ooool00ol0003oooooooooo`08ooooo`04o`3o0?oooooo0000
o`0000_ooooo0_l0000:ooooo`;o0?l000?o0000ooooooooool02Oooool2o`0000Sooooo0_l0o`00
1?oooooo0000o`000?l0000:ooooo`?o00003Oooool001Oooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo0?l000Gooooo00Co0?l0oooooooooooo00001Oooool2o`3o00Gooooo
0_l00005ooooo`;o0?l00oooool3o`0000Sooooo0ol0000Iooooo`;o0?l000?oooooo`000?ooool0
3?ooool00ol0003oooooooooo`07ooooo`;o0?l000?oooooo`000?ooool02oooool00ol0003ooooo
ooooo`08ooooo`;o0?l00_l0000;ooooo`;o00002?ooool00ol0o`3oooooooooo`02o`0000_ooooo
0_l0000=ooooo`005_ooool3o`0000[ooooo0ol00002ooooo`03o`3o0?oooooooooo00?ooooo00?o
0?l0ooooool000000_l00004ooooo`03o`3o0?oooooooooo00?ooooo0_l00006ooooo`04o`3o0?oo
ooooooooooooo`?o00009_ooool2o`3o01Wooooo00?o0?l0ooooooooool06?ooool00ol0o`3ooooo
o`00000<ooooo`03o`000?oooooooooo00Kooooo0_l0o`02ooooo`03o`000?oooooooooo00[ooooo
0_l0000<ooooo`005_ooool3o`0000[ooooo0ol00002ooooo`03o`3o0?oooooooooo00?ooooo00?o
0?l0ooooool000000_l00004ooooo`03o`3o0?oooooooooo00;ooooo0ol00005ooooo`;o0?l01?oo
ool00ol0003oooooooooo`0Vooooo`;o0?l06?ooool2o`3o01Wooooo0_l0o`0Gooooo`03o`3o0?oo
oooooooo00kooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool03_ooool0
0ol0o`3oooooooooo`02ooooo`;o0?l02?ooool00ol0o`3oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo0_l0o`0^ooooo`03o`3o0?oooooooooo01Oooooo00?o0?l0ooooooooool06?ooool0
0ol0o`3oooooooooo`0Eooooo`03o`3o0?oooooooooo01_ooooo000Gooooo`03o`000?oooooooooo
00kooooo00?o0?l0ooooooooool00_ooool2o`3o00Sooooo00?o0?l0ooooooooool02_ooool00ol0
o`3oooooooooo`0]ooooo`;o0?l06?ooool2o`3o01Wooooo00?o0?l0ooooooooool05Oooool00ol0
o`3oooooooooo`0Kooooo`005oooool00ol0003oooooooooo`0>ooooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`09ooooo`;o0?l0<?ooool00ol0o`3o
ooooooooo`0Gooooo`03o`3o0?oooooooooo01Oooooo0_l0o`0Fooooo`;o0?l07?ooool001Oooooo
0_l0000?ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool01_ooool2o`3o00_ooooo
00?o0?l0ooooooooool0;oooool00ol0o`3oooooooooo`0Gooooo`03o`3o0?oooooooooo01Sooooo
00?o0?l0ooooooooool05?ooool2o`3o01cooooo000Gooooo`03o`000?oooooooooo00kooooo00?o
0?l0ooooooooool00_ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo00[ooooo00?o
0?l0ooooooooool0;oooool2o`3o01Sooooo00?o0?l0ooooooooool06?ooool00ol0o`3ooooooooo
o`0Eooooo`03o`3o0?oooooooooo01[ooooo000Gooooo`03o`000?oooooooooo00gooooo0_l0o`04
ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool02_ooool00ol0o`3oooooooooo`0O
ooooo`?o00003_ooool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oooooooooo01Sooooo00?o0?l0
ooooooooool05Oooool00ol0o`3oooooooooo`0Jooooo`005oooool00ol0003oooooooooo`0=oooo
o`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0:oooo
o`03o`3o0?oooooooooo01oooooo0ol0000;ooooo`?o000000?o0?l0ooooooooool01oooool3o`00
00[ooooo0_l00002o`3o01Wooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Joooo
o`003oooool3o`0000Gooooo00?o0000ooooooooool03Oooool00ol0o`3oooooooooo`03ooooo`03
o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool02_ooool00ol0o`3oooooooooo`0Oooooo`?o
00002oooool3o`000003o`3o0?oooooooooo00Oooooo0ol0000:ooooo`?o000000?o0?l0oooooooo
ool02?ooool3o`0000[ooooo0_l000000ol0o`3oooooooooo`0Eooooo`03o`3o0?oooooooooo01[o
oooo000@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool01?l0003ooooo
ooooool0o`05ooooo`05o`3o0?ooooooooooooooool000001?ooool00ol0o`3oooooooooo`06oooo
o`05o`000?ooooooooooooooool0o`008_ooool00ol0003oooooooooo`0:ooooo`?o000000?o0?l0
ooooooooool01oooool3o`0000[ooooo0ol000000ol0o`3oooooooooo`08ooooo`?o00002_ooool2
o`000003o`3o0?oooooooooo00Sooooo0ol0000:ooooo`03o`3o0?l0003o000000_ooooo0ol0000<
ooooo`004?ooool00ol0003oooooooooo`04ooooo`;o00002oooool01?l0003oooooooooool0o`05
ooooo`05o`3o0?ooooooooooooooool000001?ooool00ol0o`3oooooooooo`06ooooo`05o`000?oo
ooooooooooooool0o`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooo`3o000:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooool0o`002_ooool3o`0000[ooooo0_l000000ol0o`3oooooooooo`08ooooo`?o0000
2_ooool00ol0o`3o0000o`00000;ooooo`?o00003?ooool0013ooooo00?o0000ooooooooool00ooo
ool3o`0000_ooooo00Co0000oooooooooooo0?l01Oooool01Ol0o`3ooooooooooooooooo000000Co
oooo00?o0?l0ooooooooool01_ooool01Ol0003ooooooooooooooooo0?l000Sooooo00?o0000oooo
ooooool09Oooool00ol0003oooooo`3o000:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ool0o`002oooool00ol0003oooooooooo`0:ooooo`03o`000?l0o`3ooooo00Wooooo0ol0000:oooo
o`03o`3o0?l0003o000000_ooooo0ol0000<ooooo`004?ooool00ol0003oooooooooo`03ooooo`?o
00002_ooool3o`000003ooooool0o`3ooooo00Cooooo00?o0?l0ooooooooool00ol00003ooooo`03
o`3o0?oooooooooo00Gooooo0ol00002ooooo`03o`3o0?oooooooooo00Kooooo00?o0000oooooooo
ool09oooool00ol0o`3oooooooooo`0Gooooo`03o`3o0?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003o0?l0ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0?l0o`000?oo
ool03?ooool00ol0003oooooooooo`0;ooooo`003oooool2o`0000Kooooo00?o0000ooooooooool0
2Oooool3o`000003ooooool0o`3ooooo00Cooooo00?o0?l0ooooooooool00ol00003ooooo`03o`3o
0?oooooooooo00Gooooo0ol00002ooooo`03o`3o0?oooooooooo00Gooooo0ol0000Xooooo`03o`3o
0?oooooooooo01Oooooo00?o0?l0ooooooooool05oooool00ol0o`3oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0?l0o`000?ooool03?ooool00ol0003oooooooooo`0;ooooo`004?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0_l0o`04ooooo`03o`3o0?oo
oooooooo00Kooooo00?o0?l0ooooooooool02_ooool00ol0o`3oooooooooo`05ooooo`?o0000:?oo
ool00ol0o`3oooooooooo`0Fooooo`;o0?l06Oooool00ol0o`3oooooooooo`0Eooooo`03o`3o0?oo
oooooooo01[ooooo000Gooooo`03o`000?oooooooooo00kooooo00?o0?l0ooooooooool00_ooool0
0ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool0<?ooool0
0ol0o`3oooooooooo`0Fooooo`03o`3o0?oooooooooo01Sooooo00?o0?l0ooooooooool05Oooool0
0ol0o`3oooooooooo`0Jooooo`005oooool00ol0003oooooooooo`0>ooooo`03o`3o0?oooooooooo
00;ooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo
033ooooo00?o0?l0ooooooooool05_ooool00ol0o`3oooooooooo`0Hooooo`03o`3o0?oooooooooo
01Gooooo00?o0?l0ooooooooool06_ooool001Oooooo0_l0000?ooooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool01_ooool2o`3o00_ooooo00?o0?l0ooooooooool0;oooool2o`3o01So
oooo00?o0?l0ooooooooool06?ooool00ol0o`3oooooooooo`0Eooooo`03o`3o0?oooooooooo01[o
oooo000Gooooo`03o`000?oooooooooo00kooooo00?o0?l0ooooooooool00_ooool00ol0o`3ooooo
ooooo`06ooooo`;o0?l03?ooool00ol0o`3oooooooooo`0^ooooo`03o`3o0?oooooooooo01Oooooo
00?o0?l0ooooooooool06?ooool00ol0o`3oooooooooo`0Dooooo`;o0?l07?ooool001Oooooo00?o
0000ooooooooool03_ooool00ol0o`3oooooooooo`02ooooo`;o0?l02?ooool00ol0o`3ooooooooo
o`0:ooooo`03o`3o0?oooooooooo02gooooo00?o0?l0ooooooooool05oooool2o`3o01Wooooo00?o
0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Kooooo`005oooool00ol0003oooooooooo`0>
ooooo`03o`3o0?oooooooooo00;ooooo0_l0o`08ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0
ooooooooool08Oooool2o`0000[ooooo00?o0?l0o`000?ooool02_ooool2o`0000_ooooo0_l0o`0I
ooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool06oooool001Oooooo00?o0000oooo
ooooool02_ooool01Ol0003ooooooooooooooooo0?l000Gooooo00?o0?l0ooooooooool01_ooool0
0ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo027ooooo0ol00009ooooo`03o`3o0?l0003o
000000[ooooo0ol0000:ooooo`03o`3o0?l0003o000000[ooooo0_l0000<ooooo`03o`3o0?oooooo
oooo01Cooooo0_l0o`0Mooooo`005oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooo
ooooool0o`001Oooool01?l0o`3oooooooooool00005ooooo`03o`3o0?oooooooooo00Cooooo00?o
0000ooooooooool00oooool2o`3o01Gooooo0ol00009ooooo`;o00002_ooool00ol0o`3o0000o`00
000;ooooo`;o00002oooool00ol0o`3o0000o`00000:ooooo`?o00002_ooool2o`3o0003o`000?oo
oooooooo00Sooooo0_l00009ooooo`;o0?l000?oooooo`000?l000006_ooool001Oooooo0_l0000;
ooooo`05o`000?ooooooooooooooool0o`001Oooool01?l0o`3oooooooooool00005ooooo`03o`3o
0?oooooooooo00Cooooo0_l00005ooooo`03o`3o0?oooooooooo00Cooooo0_l0000;ooooo`Go0000
2?ooool00ol0003oooooooooo`09ooooo`;o0?l000?o0000ooooooooool02Oooool2o`0000_ooooo
0_l0o`000ol0003oooooooooo`09ooooo`?o00002_ooool00ol0o`3o0000o`00000:ooooo`?o0000
2?ooool00ol0o`3oooooooooo`03o`0000[ooooo0ol0000<ooooo`005_ooool3o`0000[ooooo0ol0
0002ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool00_l00004ooooo`;o0?l01Ooo
ool2o`0000Gooooo00?o0?l0ooooooooool01?ooool3o`0000gooooo0_l0000Dooooo`;o0?l03?oo
ool00ol0003oooooooooo`0:ooooo`03o`3o0?l0003o000000_ooooo0_l0000;ooooo`03o`3o0?l0
003ooooo00[ooooo0ol00008ooooo`03o`3o0?oooooooooo00?o00002_ooool3o`0000cooooo000F
ooooo`?o00002_ooool3o`0000;ooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`02
o`0000Gooooo00?o0?l0ooooooooool00oooool2o`0000Kooooo00?o0?l0ooooooooool01?ooool3
o`00027ooooo0_l0o`0Iooooo`;o0?l000?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`;o0?l000?o0000ooooooooool02Oooool2o`0000Sooooo0_l0o`001?oooooo0000o`000?l0
000;ooooo`;o00003Oooool001Oooooo00?o0000ooooooooool03_ooool00ol0o`3oooooooooo`03
ooooo`03o`3o0?oooooooooo00?o00001?ooool00ol0o`3oooooooooo`03ooooo`?o00001Oooool2
o`3o00Gooooo00?o0000ooooooooool08?ooool2o`3o01[ooooo00?o0?l0ooooooooool06?ooool0
0ol0o`3o0000ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0?l0ooooooooool00_l0000<
ooooo`;o00003Oooool001Oooooo00?o0000ooooooooool03_ooool00ol0o`3oooooooooo`03oooo
o`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool02oooool2o`3o02Oooooo0_l0o`0Joooo
o`;o0?l06_ooool00ol0o`3oooooooooo`0Eooooo`04o`3o0?ooooooooooo`0000gooooo00?o0000
ooooooooool03?ooool001Oooooo00?o0000ooooooooool03_ooool00ol0o`3oooooooooo`03oooo
o`;o0?l02?ooool2o`3o00gooooo0_l0o`0Uooooo`;o0?l06oooool00ol0o`3oooooooooo`0Hoooo
o`03o`3o0?oooooooooo01Gooooo0_l0o`0Oooooo`005oooool00ol0003oooooooooo`0>ooooo`03
o`3o0?oooooooooo00?ooooo0_l0o`08ooooo`;o0?l03_ooool00ol0o`3oooooooooo`0Rooooo`;o
0?l06oooool2o`3o01[ooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Nooooo`00
5oooool2o`0000oooooo0_l0o`04ooooo`;o0?l02?ooool2o`3o00kooooo0_l0o`0Rooooo`;o0?l0
7?ooool00ol0o`3oooooooooo`0Hooooo`;o0?l05oooool00ol0o`3oooooooooo`0Nooooo`005ooo
ool00ol0003oooooooooo`0>ooooo`;o0?l01?ooool2o`3o00Sooooo0_l0o`0?ooooo`;o0?l08?oo
ool00ol0o`3oooooooooo`0Kooooo`;o0?l06_ooool00ol0o`3oooooooooo`0Eooooo`03o`3o0?oo
oooooooo01oooooo000Gooooo`03o`000?oooooooooo00oooooo00?o0?l0ooooooooool00oooool0
0ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo00kooooo0_l0o`0Mooooo`;o0?l07_ooool0
0ol0o`3oooooooooo`0Iooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool07oooool0
01Oooooo00?o0000ooooooooool03oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo
00Oooooo0_l0o`0@ooooo`;o0?l06oooool2o`3o01kooooo00?o0?l0ooooooooool06Oooool00ol0
o`3oooooooooo`0Fooooo`03o`3o0?oooooooooo01oooooo000Gooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool00ol0o`3oooooooooo`03ooooo`;o0?l000?o0000oooooooo
ool01Oooool2o`3o017ooooo0_l0o`0Hooooo`?o0?l000?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l0o`05ooooo`;o00005?ooool00ol0o`3o
ooooooooo`0Eooooo`03o`3o0?oooooooooo023ooooo000Gooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00_ooool00ol0o`3oooooooooo`03ooooo`;o0?l000?o0000ooooooooool0
1_ooool01Ol0o`3ooooooooooooooooo000000kooooo0ol0o`0:ooooo`?o00002?ooool2o`3o0004
ooooool0003o0000o`0000[ooooo0_l0000;ooooo`;o00000oooool00ol0o`3oooooooooo`04oooo
o`?o00002_ooool2o`0000Kooooo0_l0o`03ooooo`;o00004_ooool00ol0o`3oooooooooo`0Poooo
o`005_ooool3o`0000_ooooo00?o0000ooooooooool00_ooool00ol0o`3oooooooooo`03ooooo`;o
0?l00_l00007ooooo`;o0?l00_ooool2o`0000_ooooo0ol000000ooooooo0?l0o`3o0007ooooo`Go
00001_ooool3o`3o00?o00002oooool00ol0003oooooooooo`0:ooooo`;o00000oooool00ol0o`3o
ooooooooo`05ooooo`;o00002oooool3o`0000Gooooo00?o0?l0ooooooooool00_ooool3o`0000[o
oooo0ol00003ooooo`;o0?l01Oooool2o`0000gooooo00?o0000ooooooooool02oooool001Kooooo
0ol0000:ooooo`?o00000oooool00ol0o`3oooooooooo`03ooooo`;o0?l00_l00007ooooo`;o0?l0
0_ooool3o`0000_ooooo1?l000001?oooooo0?l0o`3o0?l0o`07ooooo`;o00000oooool4o`3o00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooooooo
o`;o0?l01_ooool2o`0000cooooo0_l00005ooooo`;o0?l01?ooool2o`0000_ooooo0ol00003oooo
o`03o`3o0?oooooooooo00Cooooo0ol0000:ooooo`?o00003Oooool001Kooooo0ol0000:ooooo`?o
00000oooool00ol0o`3oooooooooo`04ooooo`04o`3o0?l0003o0000o`0000Oooooo00Co0?l0oooo
oooooooooooo0ol0000;ooooo`?o00000oooool5o`3o00?ooooo1_l0o`0Oooooo`03o`000?oooooo
oooo00;ooooo00?o0?l0ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o00001Oooool2
o`3o00Cooooo0_l0000<ooooo`;o00000oooool2o`3o00Kooooo0ol0000:ooooo`?o00003Oooool0
01Oooooo00?o0000ooooooooool03oooool2o`3o00Gooooo00?o0?l0o`000?ooool02?ooool2o`3o
00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`Go0?l0:?ooool00ol0
o`3oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0?l0ooooooooool00oooool00ol0
003oooooooooo`0:ooooo`;o00000oooool2o`3o00Oooooo0_l0000;ooooo`;o00003_ooool000?o
oooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00oo
oooo0_l0o`05ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool0A?ooool00ol0o`3o
ooooooooo`0Jooooo`;o0?l04_ooool00ol0003oooooooooo`02ooooo`;o0?l01oooool00ol0003o
ooooooooo`0:ooooo`;o00003_ooool000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool03oooool2o`3o00Gooooo0_l0o`0:ooooo`03
o`3o0?oooooooooo04?ooooo00?o0?l0ooooooooool06oooool00ol0o`3oooooooooo`0Eooooo`;o
0?l05Oooool00ol0003oooooooooo`0=ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03oooool2o`3o00Kooooo00?o0?l0ooooooooool0
2?ooool2o`3o04;ooooo0_l0o`0Mooooo`03o`3o0?oooooooooo01Kooooo00?o0?l0ooooooooool0
9?ooool000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`;o00004Ooo
ool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool0?ooo
ool2o`3o01gooooo0_l0o`0Gooooo`;o0?l09_ooool000Cooooo00?o0000ooooooooool01oooool4
o`0000Gooooo00?o0000ooooooooool04?ooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooo
oooo00Wooooo0_l0o`0oooooo`;o0?l07_ooool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oooooo
oooo02Gooooo0003ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
013ooooo00?o0?l0ooooooooool01?ooool2o`3o00_ooooo00?o0?l0ooooooooool0??ooool2o`3o
01kooooo0_l0o`0Gooooo`;o0?l09oooool000Cooooo00?o0000ooooooooool01oooool5o`0000Co
oooo00?o0000ooooooooool04?ooool2o`3o00Gooooo0_l0o`0;ooooo`;o0?l0??ooool2o`3o01ko
oooo0_l0o`0Gooooo`;o0?l0:?ooool001Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`03ooooo`;o0?l01Oooool00ol0003o0?l0ooooo`0;ooooo`03o`3o0?oooooooooo02Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`;o0?l01?ooool00ol0003ooooo
ooooo`0Hooooo`03o`3o0?oooooooooo01Kooooo00?o0?l0ooooooooool09oooool001Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`;o0?l01Oooool00ol0003o0?l0oooo
o`0:ooooo`03o`000?oooooo0?l000[ooooo0_l0000=ooooo`?o00002_ooool2o`0000_ooooo0_l0
0004ooooo`;o0?l01Oooool2o`0000_ooooo0_l0000;ooooo`03o`3o0?l0003ooooo01Kooooo0_l0
o`0Yooooo`005_ooool3o`0000_ooooo00?o0000ooooooooool01?ooool00ol0o`3oooooooooo`03
ooooo`03o`000?l0o`3o0?l000[ooooo0_l00002o`3o00Wooooo1?l00009ooooo`Go00002Oooool4
o`0000Wooooo1?l00002ooooo`;o0?l01Oooool4o`0000[ooooo0ol00009ooooo`04o`3o0?l0003o
0000o`0000[ooooo0_l00009ooooo`;o0?l00_l0000<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool001Kooooo0ol0000:ooooo`?o00001Oooool00ol0o`3oooooooooo`03
ooooo`03o`000?l0o`3o0?l000[ooooo0ol000000ol0o`3oooooooooo`08ooooo`Co00002oooool2
o`0000Sooooo0_l0000;ooooo`;o00001?ooool00ol0o`3oooooooooo`05ooooo`;o00002oooool2
o`0000[ooooo00?o0?l0o`000?l000003?ooool3o`0000Sooooo00Co0?l0ooooool0003o00002ooo
ool2o`0000_ooooo00?o0000ooooool000003Oooool001Oooooo00?o0000ooooooooool02Oooool3
o`0000Gooooo00?o0?l0ooooooooool00oooool2o`000003o`3o0?oooooooooo00Wooooo0ol00000
0ol0o`3oooooooooo`08ooooo`?o00009oooool00ol0o`3oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool2o`3o0003o`000?oooooooooo00[ooooo0_l00009
ooooo`04o`3o0?oooooo0000o`0000cooooo0ol0000:ooooo`;o00003_ooool001Oooooo00?o0000
ooooooooool04Oooool2o`3o00Kooooo0_l0o`0:ooooo`05o`000?ooooooooooooooool0o`002_oo
ool00ol0003oooooooooo`0Tooooo`;o0?l08?ooool2o`3o0003o`000?oooooooooo00_ooooo00?o
0000ooooooooool01oooool2o`3o0003ooooool0003ooooo00cooooo0_l0000;ooooo`;o00003_oo
ool001Oooooo00?o0000ooooooooool04_ooool00ol0o`3oooooooooo`04ooooo`;o0?l03_ooool2
o`3o02oooooo0_l0o`0Qooooo`03o`3o0?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0o`3oooooo`00000=ooooo`;o00002oooool2o`0000oooooo000Gooooo`03o`000?oooooooooo
01;ooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0=ooooo`;o0?l0;?ooool3o`3o
027ooooo00?o0?l0ooooooooool05oooool00ol0o`3oooooooooo`0>ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool04_ooool00ol0o`3o
ooooooooo`05ooooo`03o`3o0?oooooooooo00kooooo0_l0o`0Zooooo`;o0?l08_ooool00ol0o`3o
ooooooooo`0Gooooo`;o0?l0;_ooool001Oooooo0_l0000Cooooo`03o`3o0?oooooooooo00Gooooo
0_l0o`0@ooooo`?o0?l09_ooool2o`3o02?ooooo00?o0?l0ooooooooool05oooool2o`3o02oooooo
000Gooooo`03o`000?oooooooooo01;ooooo0_l0o`07ooooo`03o`3o0?oooooooooo00oooooo0ol0
o`0Sooooo`?o0?l08oooool00ol0o`3oooooooooo`0Gooooo`;o0?l0<?ooool001Oooooo00?o0000
ooooooooool04_ooool2o`3o00Oooooo00?o0?l0ooooooooool04Oooool2o`3o023ooooo0ol0o`0T
ooooo`03o`3o0?oooooooooo01Sooooo00?o0?l0ooooooooool0;oooool001Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`05ooooo`;o0?l01oooool2o`3o01Cooooo0_l0o`0Loooo
o`?o0?l09Oooool00ol0o`3oooooooooo`0Hooooo`;o0?l0<Oooool001Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`05o`3o0?ooooooooooooooool000001?ooool00ol0
o`3oooooooooo`0Cooooo`?o0?l05oooool4o`3o00_ooooo00?o0000ooooooooool06?ooool2o`3o
01Wooooo0_l0o`0booooo`005oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Ko
oooo00Go0?l0ooooooooooooooooo`000004ooooo`03o`3o0?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool2o`0000Co0?l02Oooool3o`0000Kooooo1?l0o`02o`0000_ooooo0_l0000;oooo
o`03o`000?oooooooooo00[ooooo00?o0000o`3o0?l0o`006Oooool2o`3o03?ooooo000Fooooo`?o
00002_ooool3o`0000Oooooo0_l0o`02ooooo`;o00001?ooool00ol0o`3oooooooooo`04ooooo`;o
00003?ooool3o`0000Co0?l01Oooool5o`0000?ooooo1Ol0o`000ooooooo0000o`000002o`0000Wo
oooo1?l0000:ooooo`;o00002oooool2o`3o00_ooooo0_l0000:ooooo`03o`000?oooooo000000;o
0?l02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool001Kooooo0ol0000:ooooo`?o00001oooool2o`3o00;ooooo0_l00004ooooo`03o`3o
0?oooooooooo00Cooooo0ol0000<ooooo`?o00000_ooool@o`3o00?ooooo0_l0000;ooooo`;o0000
3?ooool00ol0003oooooooooo`0:ooooo`;o0?l000?o0000ooooooooool02Oooool2o`0000[ooooo
0_l00002o`3o00Wooooo0ol0000:ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
2oooool001Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`;o0?l00_oo
ool3o`0000?ooooo0_l0o`06ooooo`?o00003?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00Wooooo0ol0o`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000o`3o0?l0o`002_oo
ool3o`0000[ooooo0_l0000;ooooo`?o00003_ooool001Oooooo00?o0000ooooooooool05?ooool0
0ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo00Cooooo00?o0000ooooooooool0B?ooool3
o`3o00cooooo00?o0000ooooooooool02_ooool00ol0003o0?l0o`3o000;ooooo`;o00002oooool3
o`0000[ooooo0ol0000>ooooo`005oooool00ol0003oooooooooo`0Dooooo`03o`3o0?oooooooooo
00Oooooo0_l0o`1?ooooo`;o0?l06oooool00ol0003o0?l0ooooo`0:ooooo`;o00002oooool2o`00
00cooooo0_l0000?ooooo`005oooool00ol0003oooooooooo`0Dooooo`;o0?l02Oooool00ol0o`3o
ooooooooo`1<ooooo`;o0?l07?ooool00ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool2o`00013ooooo000Gooooo`03o`000?oooooooooo01Gooooo
00?o0?l0ooooooooool01oooool2o`3o04cooooo0_l0o`0Looooo`03o`3o0?oooooooooo02Gooooo
00?o0000ooooooooool03oooool001Oooooo0_l0000Fooooo`03o`3o0?oooooooooo00Sooooo00?o
0?l0ooooooooool0BOooool2o`3o01cooooo00?o0?l0ooooooooool0>?ooool001Oooooo00?o0000
ooooooooool05Oooool2o`3o00Wooooo0_l0o`18ooooo`?o0?l07?ooool00ol0o`3oooooooooo`0i
ooooo`005oooool00ol0003oooooooooo`0Fooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0oooo
ooooool0AOooool3o`3o01cooooo00?o0?l0ooooooooool0>_ooool001Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0oooooooo
ool0@oooool2o`3o01gooooo00?o0?l0ooooooooool0>oooool000kooooo1Ol00004ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0o`3o0000ooooo`09ooooo`;o0?l0
@_ooool3o`3o01gooooo00?o0?l0ooooooooool0??ooool000oooooo00Co0000oooooooooooo0000
0oooool3o`0000_ooooo00?o0000ooooooooool02Oooool2o`3o00_ooooo00?o0?l0o`000?l00000
2_ooool3o`0000cooooo0ol0000;ooooo`;o00002_ooool2o`0000[ooooo0ol0o`0Mooooo`03o`3o
0?oooooooooo03gooooo000@ooooo`03o`000?oooooooooo00?ooooo0ol0000:ooooo`?o00002ooo
ool00ol0o`3o0000ooooo`09ooooo`;o0?l00_l0000;ooooo`?o00002?ooool5o`0000Wooooo1?l0
0009ooooo`Co00001oooool3o`3o00;o00002oooool2o`0000_ooooo00Go0000ooooool0003ooooo
o`3o000:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo000Aooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool3o`0000_ooooo00?o0?l0o`000?l000002_ooool01?l0o`3o0000o`00
0?l0000;ooooo`;o00002oooool2o`0000Sooooo1Ol00008ooooo`;o00002Oooool3o`3o00Co0000
2_ooool3o`0000[ooooo0_l00002o`3o00Wooooo0_l0000;ooooo`03o`000?oooooo000000cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`003_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool05oooool2o`3o00cooooo00?o0?l0ooooooooool0
3?ooool00ol0003oooooooooo`0Yooooo`?o0?l000?oooooo`000?l000003?ooool2o`0000_ooooo
0_l00002o`3o00[ooooo0_l0000;ooooo`;o00002_ooool3o`0000gooooo00?o0000ooooooooool0
3?ooool000kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Sooooo
00?o0?l0ooooooooool02oooool00ol0o`3oooooooooo`0eooooo`Co0?l03oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?l0o`3o0?l000[ooooo00?o0000ooooooooool02_ooool3o`0000[ooooo
0ol0000:ooooo`?o00003oooool000oooooo0ol00005ooooo`03o`000?oooooooooo01Sooooo00?o
0?l0ooooooooool03?ooool2o`3o03Cooooo0ol0o`0Nooooo`03o`000?l0o`3o0?l000[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`;o00002oooool3o`0000oooooo000G
ooooo`03o`000?oooooooooo01Sooooo00?o0?l0ooooooooool03Oooool2o`3o037ooooo0ol0o`0P
ooooo`;o0?l06?ooool00ol0003oooooooooo`0:ooooo`;o00003?ooool2o`00013ooooo000Goooo
o`03o`000?oooooooooo01Wooooo00?o0?l0ooooooooool03Oooool2o`3o02kooooo1?l0o`0Poooo
o`03o`3o0?oooooooooo02Gooooo00?o0000ooooooooool02_ooool2o`00017ooooo000Gooooo`;o
00006_ooool00ol0o`3oooooooooo`0>ooooo`;o0?l0;?ooool3o`3o027ooooo00?o0?l0oooooooo
ool0<oooool00ol0003oooooooooo`0@ooooo`005oooool00ol0003oooooooooo`0Iooooo`;o0?l0
4Oooool2o`3o02Sooooo0ol0o`0Qooooo`;o0?l0BOooool001Oooooo00?o0000ooooooooool06_oo
ool00ol0o`3oooooooooo`0@ooooo`;o0?l09Oooool3o`3o02;ooooo0_l0o`1:ooooo`005oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo0_l0o`0Booooo`?o0?l08?ooool4
o`3o02?ooooo00?o0?l0ooooooooool0B_ooool001Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool01Oooool2o`00
00_ooooo0ol0o`0Kooooo`Go0?l09?ooool00ol0o`3oooooooooo`1;ooooo`005_ooool3o`0000_o
oooo00?o0000ooooooooool02Oooool2o`0000?ooooo0_l0o`06ooooo`?o00002_ooool2o`0000Co
0?l02Oooool3o`0000Wooooo1Ol0o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03Oooool00ol0o`3oooooooooo`1<ooooo`005_ooool3o`0000[ooooo0ol0000:ooooo`?o0000
0oooool00ol0o`3oooooooooo`05ooooo`?o00002_ooool4o`0000?o0?l01Oooool5o`0000Oooooo
1?l0o`000ol0003oooooooooo`09ooooo`;o00002_ooool3o`0000_ooooo00?o0000o`3o0?l0o`00
2oooool2o`0000cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool001Oooooo00?o0000ooooooooool02Ooo
ool3o`0000_ooooo0ol00003ooooo`03o`3o0?oooooooooo00Cooooo1?l0000:ooooo`?o00000_oo
ool7o`3o00;ooooo00?o0000o`3o0?l0o`001ol0o`05o`0000Wooooo1?l00008ooooo`Co00002_oo
ool00ol0003o0?l0o`3o000:ooooo`;o00002oooool00ol0003oooooo`00000=ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`005oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo1?l0o`0Eooooo`;o00002_ooool2
o`0000cooooo00Co0000o`3o0?l0o`3o00002_ooool3o`0000[ooooo0_l0000;ooooo`03o`000?oo
oooo000000cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`005oooool0
0ol0003oooooooooo`0Nooooo`03o`3o0?oooooooooo04oooooo00?o0000o`3o0?ooool02oooool2
o`0000_ooooo1?l0000:ooooo`;o00002oooool2o`0000cooooo00?o0000ooooooooool03_ooool0
01Oooooo00?o0000ooooooooool07_ooool2o`3o04oooooo0_l0o`0<ooooo`03o`000?oooooooooo
00_ooooo0_l0000;ooooo`;o00003?ooool2o`0000[ooooo0_l0000Aooooo`005oooool00ol0003o
ooooooooo`0Oooooo`03o`3o0?oooooooooo04cooooo0_l0o`0Jooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`?o00004?ooool001Oooooo
00?o0000ooooooooool07oooool2o`3o04_ooooo0_l0o`0Yooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool2o`0001;ooooo000Gooooo`;o00008Oooool00ol0o`3ooooooooo
o`18ooooo`;o0?l0@oooool00ol0003oooooooooo`0Booooo`005oooool00ol0003oooooooooo`0Q
ooooo`03o`3o0?oooooooooo04Gooooo0_l0o`1Jooooo`005oooool00ol0003oooooooooo`0Qoooo
o`03o`3o0?oooooooooo04Cooooo0_l0o`1Kooooo`005oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0o`3oooooooooo`11ooooo`;o
0?l0GOooool001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0?l0ooooooooool0?oooool2o`3o05kooooo000Fooooo`?o00002ooo
ool2o`0000[ooooo0_l0000;ooooo`03o`000?l0o`3o0?l000[ooooo0ol0000<ooooo`?o00002_oo
ool2o`0000_ooooo00?o0000ooooooooool01oooool2o`3o063ooooo000Fooooo`?o00002_ooool3
o`0000_ooooo0_l0000;ooooo`03o`000?l0o`3o0?l000[ooooo1?l00008ooooo`Go00002?ooool4
o`0000[ooooo0ol00006ooooo`?o0?l00_ooool2o`0000[ooooo00?o0000ooooool000003?ooool2
o`0000_ooooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`005oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00_ooooo0ol0000:ooooo`;o00000_l0o`0:ooooo`?o00002oooool2o`0000Oooooo1Ol00009oooo
o`Co00001Oooool3o`3o00;ooooo0ol0000:ooooo`;o00002oooool2o`0000cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03?ooool001Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`04
o`000?oooooo0?l0o`3o00[ooooo00?o0000ooooooooool08?ooool2o`0000Kooooo0ol0o`03oooo
o`;o00002oooool3o`0000[ooooo0_l0000;ooooo`;o00003Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool001Oooooo00?o0000oooooooo
ool0:?ooool2o`3o03;ooooo0ol0o`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02Oooool4o`0000[ooooo0ol0000:ooooo`;o00002oooool00ol0003oooooo`00000<ooooo`03
o`000?oooooooooo00kooooo0002ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`0Yooooo`;o0?l0;oooool3o`3o01?ooooo00?o0000ooooooooool0
2Oooool2o`0000cooooo0_l0000<ooooo`;o00002oooool2o`0000[ooooo00?o0000ooooool00000
4Oooool000?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0:oooool00ol0o`3oooooooooo`0Zooooo`?o0?l0;_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0ol0000:ooooo`;o00004_ooool000Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo
00?o0?l0ooooooooool09oooool2o`3o03kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`09ooooo`Co00004Oooool000Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`;o0000;_ooool2o`3o02Cooooo0ol0o`1=ooooo`03o`000?oooooooooo00[ooooo0_l0
000Cooooo`000_ooool01Ol0003ooooooooooooooooo000000Oooooo1?l00005ooooo`03o`000?oo
oooooooo02oooooo0_l0o`0Pooooo`?o0?l0Foooool00ol0003oooooooooo`0Cooooo`000_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02Cooooo0ol0o`0Jooooo`Co0?l0M?ooool000?ooooo0ol00008
ooooo`Go00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool06_ooool4o`3o01;ooooo1_l0o`1fooooo`005_ooool3o`0000[ooooo0_l0000;oooo
o`03o`000?oooooooooo00[ooooo0_l0000Aooooo`Ko0?l01oooool9o`3o07Wooooo000Fooooo`?o
00002_ooool2o`0000_ooooo0_l0000;ooooo`?o00002_ooool3o`0000Sooooo2_l0o`07ooooo`;o
00002oooool00ol0003oooooooooo`1Yooooo`005oooool2o`0000[ooooo0ol0000;ooooo`;o0000
2oooool3o`0000[ooooo1?l00007ooooo`Go00002Oooool4o`0000[ooooo0ol0000:ooooo`?o0000
2oooool2o`0000cooooo0_l0000;ooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool001Oooooo00?o0000ooooooooool05ooo
ool3o`0000[ooooo0ol0000;ooooo`?o00002_ooool2o`0000Sooooo1Ol00009ooooo`Co00002Ooo
ool2o`0000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00cooooo000Gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Pooooo`;o00002oooool4o`0000[ooooo0ol0000:ooooo`;o00002oooool2
o`0000gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00gooooo000Gooooo`03o`000?oooooooooo06;ooooo0_l0000<ooooo`;o00003?ooool2o`00
00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0ol0000:ooooo`;o00002oooool00ol0003o
ooooo`00000<ooooo`03o`000?oooooooooo00oooooo000Gooooo`03o`000?oooooooooo07cooooo
00?o0000ooooooooool02_ooool2o`0000_ooooo1?l0000:ooooo`;o00002_ooool3o`0001;ooooo
000Gooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool02oooool2o`0000_ooooo0ol0
000:ooooo`?o00004_ooool001Oooooo0_l0002Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02Oooool2o`0001Cooooo000Gooooo`03o`000?oooooooooo0:;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Cooooo`005oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo0:;ooooo00?o0000ooooooooool05?ooool001Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:cooooo000Fooooo`?o00002_oo
ool2o`0000_ooooo00?o0000ooooooooool02_ooool2o`000:3ooooo000Fooooo`?o00002_ooool2
o`0000_ooooo0_l0000;ooooo`?o00002Oooool3o`0000cooooo0ol0000:ooooo`;o0000N?ooool0
01Oooooo0_l0000:ooooo`?o00002oooool2o`0000_ooooo0ol0000:ooooo`?o00002?ooool5o`00
00Sooooo1?l0000:ooooo`Co00002_ooool3o`0000_ooooo0_l0000<ooooo`;o00002oooool2o`00
00_ooooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`005oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo0ol0000<ooooo`03o`000?oooooooooo00Wo
oooo0_l00007ooooo`Ko00002?ooool4o`0000[ooooo0_l0000;ooooo`;o00003Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0;Oooool2o`0000cooooo1?l00009ooooo`;o00002oooool3o`0000cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool0H_ooool2o`0000_ooooo1?l0
000:ooooo`?o00002_ooool2o`0000cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00oooooo000Gooooo`03o`000?oooooooooo06kooooo0_l0000<
ooooo`;o00003?ooool2o`0000[ooooo0_l0000=ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04?ooool001Oooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo0ol0000:ooooo`;o00003?ooool00ol0003oooooooooo`0Aoooo
o`005oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`;o
00002_ooool2o`0001Cooooo000Gooooo`;o0000UOooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo0ol0000Cooooo`005oooool00ol0003oooooooooo`2Qooooo`03o`000?oo
oooooooo00[ooooo0_l0000Eooooo`005oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooo
oooo01Gooooo000Gooooo`03o`000?oooooooooo0<Gooooo000?ooooo`?o00001Oooool00ol0003o
ooooooooo`35ooooo`003_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0aOooool001;ooooo00?o0000ooooooooool00_ooool2o`000<Kooooo000@ooooo`;o00001Ooo
ool00ol0003oooooooooo`35ooooo`004_ooool00ol0003oooooooooo`3:ooooo`003_ooool01Ol0
003ooooooooooooooooo00000<cooooo000?ooooo`?o0000cOooool00=oooooo003Oooooo`007ooo
ool3o`0000?ooooo1Ol00002ooooo`?o00000_ooool5o`0000;ooooo1?l00008ooooo`Co000000Go
ooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o00001oooool01Ol0003ooooo
o`000?oooooo000000;ooooo0ol00002ooooo`?o00001?ooool3o`0000Sooooo1Ol000000ooooooo
0000o`000003o`0000;ooooo0ol00003ooooo`03o`000?oooooo000000Sooooo1Ol000000ooooooo
0000o`000003o`000005ooooool0003o0000o`000?ooool00_l000001?oooooo0000o`000?l00002
ooooo`Co0000;?ooool0023ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000oooo
ooooool01_ooool01ol0003oooooo`000?oooooo0000ooooool000000oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Ko0000oooooooooooo0000ooooool0000:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000Wooooo
00?o0000ooooooooool0:Oooool0023ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ooooool5o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Oo
oooo0ol00003ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`06
ooooo`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Co
oooo1Ol00009ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`07o`000?oooooo0000ooooool0003oooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool01Ol0003oooooooooool0003ooooo00Go00000_ooool3o`0002cooooo
000Pooooo`?o00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool01_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000oooo
ooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`07o`000?oooooo0000ooooool0003oooooo`000009ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooool00000;oooool0023ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0ol00004oooo
o`03o`000?oooooooooo00;ooooo0ol00009ooooo`;o00000oooool4o`0000?ooooo0ol00008oooo
o`;o000000?oooooo`000?ooool00_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`?o00002Oooool4o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1_l00008oooo
o`04o`000?ooooooooooooooo`?o00000oooool4o`0000?ooooo0ol00003ooooo`Co0000:oooool0
023ooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0@oooool001oooooo1Ol00003ooooo`03o`000?oooooooooo
00Oooooo0ol00005ooooo`;o00005_ooool2o`0002Wooooo0_l000001?oooooo0000o`000?l0000E
ooooo`?o00001Oooool00ol0003oooooooooo`0mooooo`00goooool00=oooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 299.875}, {419.875, 197.875}} -> {-1.5227, \
2.86704, 0.0150554, 0.0153841}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Nullclines, critical points",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell["\<\
The nullclines for an autonomous system are the curves determined \
by the equations \
\>", "Text"],

Cell[TextData[{
  " ",
  StyleBox["f",
    FontSlant->"Italic"],
  " (",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ") = 0\n ",
  StyleBox["g",
    FontSlant->"Italic"],
  " (",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ") = 0 "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
The points where the nullcllines cross are called the critical \
points or the stationary points of the system. \
\>", "Text"],

Cell["\<\
The ImplicitPlot function is used to draw the nullclines for \
DEsystem. The critical point in the first quadrant is also drawn using the \
ListPlot function. These plots are given names (output is suppressed) and \
shown with the above flow plot. We first load the ImplicitPlot function\
\>", \
"Text"],

Cell["<< Graphics`ImplicitPlot`", "Input",
  CellLabel->"In[12]:="],

Cell[CellGroupData[{

Cell["\<\
nullclines = ImplicitPlot[ {x*(1-y)==0, y*(x-1)==0}, {x,0,3}, \
{y,0,3} ];
stationary = ListPlot[ {{1,1}}, PlotStyle\[Rule]PointSize[0.03] ];
Show[ nullclines, stationary, flow, AspectRatio->1/1 ]\
\>", "Input",
  CellLabel->"In[22]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0238095 0.31746 [
[.18254 .01131 -9 -9 ]
[.18254 .01131 9 0 ]
[.34127 .01131 -3 -9 ]
[.34127 .01131 3 0 ]
[.5 .01131 -9 -9 ]
[.5 .01131 9 0 ]
[.65873 .01131 -3 -9 ]
[.65873 .01131 3 0 ]
[.81746 .01131 -9 -9 ]
[.81746 .01131 9 0 ]
[.97619 .01131 -3 -9 ]
[.97619 .01131 3 0 ]
[.01131 .18254 -18 -4.5 ]
[.01131 .18254 0 4.5 ]
[.01131 .34127 -6 -4.5 ]
[.01131 .34127 0 4.5 ]
[.01131 .5 -18 -4.5 ]
[.01131 .5 0 4.5 ]
[.01131 .65873 -6 -4.5 ]
[.01131 .65873 0 4.5 ]
[.01131 .81746 -18 -4.5 ]
[.01131 .81746 0 4.5 ]
[.01131 .97619 -6 -4.5 ]
[.01131 .97619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .02381 m
.18254 .03006 L
s
[(0.5)] .18254 .01131 0 1 Mshowa
.34127 .02381 m
.34127 .03006 L
s
[(1)] .34127 .01131 0 1 Mshowa
.5 .02381 m
.5 .03006 L
s
[(1.5)] .5 .01131 0 1 Mshowa
.65873 .02381 m
.65873 .03006 L
s
[(2)] .65873 .01131 0 1 Mshowa
.81746 .02381 m
.81746 .03006 L
s
[(2.5)] .81746 .01131 0 1 Mshowa
.97619 .02381 m
.97619 .03006 L
s
[(3)] .97619 .01131 0 1 Mshowa
.125 Mabswid
.05556 .02381 m
.05556 .02756 L
s
.0873 .02381 m
.0873 .02756 L
s
.11905 .02381 m
.11905 .02756 L
s
.15079 .02381 m
.15079 .02756 L
s
.21429 .02381 m
.21429 .02756 L
s
.24603 .02381 m
.24603 .02756 L
s
.27778 .02381 m
.27778 .02756 L
s
.30952 .02381 m
.30952 .02756 L
s
.37302 .02381 m
.37302 .02756 L
s
.40476 .02381 m
.40476 .02756 L
s
.43651 .02381 m
.43651 .02756 L
s
.46825 .02381 m
.46825 .02756 L
s
.53175 .02381 m
.53175 .02756 L
s
.56349 .02381 m
.56349 .02756 L
s
.59524 .02381 m
.59524 .02756 L
s
.62698 .02381 m
.62698 .02756 L
s
.69048 .02381 m
.69048 .02756 L
s
.72222 .02381 m
.72222 .02756 L
s
.75397 .02381 m
.75397 .02756 L
s
.78571 .02381 m
.78571 .02756 L
s
.84921 .02381 m
.84921 .02756 L
s
.88095 .02381 m
.88095 .02756 L
s
.9127 .02381 m
.9127 .02756 L
s
.94444 .02381 m
.94444 .02756 L
s
.25 Mabswid
0 .02381 m
1 .02381 L
s
.02381 .18254 m
.03006 .18254 L
s
[(0.5)] .01131 .18254 1 0 Mshowa
.02381 .34127 m
.03006 .34127 L
s
[(1)] .01131 .34127 1 0 Mshowa
.02381 .5 m
.03006 .5 L
s
[(1.5)] .01131 .5 1 0 Mshowa
.02381 .65873 m
.03006 .65873 L
s
[(2)] .01131 .65873 1 0 Mshowa
.02381 .81746 m
.03006 .81746 L
s
[(2.5)] .01131 .81746 1 0 Mshowa
.02381 .97619 m
.03006 .97619 L
s
[(3)] .01131 .97619 1 0 Mshowa
.125 Mabswid
.02381 .05556 m
.02756 .05556 L
s
.02381 .0873 m
.02756 .0873 L
s
.02381 .11905 m
.02756 .11905 L
s
.02381 .15079 m
.02756 .15079 L
s
.02381 .21429 m
.02756 .21429 L
s
.02381 .24603 m
.02756 .24603 L
s
.02381 .27778 m
.02756 .27778 L
s
.02381 .30952 m
.02756 .30952 L
s
.02381 .37302 m
.02756 .37302 L
s
.02381 .40476 m
.02756 .40476 L
s
.02381 .43651 m
.02756 .43651 L
s
.02381 .46825 m
.02756 .46825 L
s
.02381 .53175 m
.02756 .53175 L
s
.02381 .56349 m
.02756 .56349 L
s
.02381 .59524 m
.02756 .59524 L
s
.02381 .62698 m
.02756 .62698 L
s
.02381 .69048 m
.02756 .69048 L
s
.02381 .72222 m
.02756 .72222 L
s
.02381 .75397 m
.02756 .75397 L
s
.02381 .78571 m
.02756 .78571 L
s
.02381 .84921 m
.02756 .84921 L
s
.02381 .88095 m
.02756 .88095 L
s
.02381 .9127 m
.02756 .9127 L
s
.02381 .94444 m
.02756 .94444 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.5 Mabswid
.02381 .34962 m
.02381 .37469 L
.02381 .39975 L
.02381 .42481 L
.02381 .44987 L
.02381 .47494 L
.02381 .5 L
.02381 .52506 L
.02381 .55013 L
.02381 .57519 L
.02381 .60025 L
.02381 .62531 L
.02381 .65038 L
.02381 .67544 L
.02381 .7005 L
.02381 .72556 L
.02381 .75063 L
.02381 .77569 L
.02381 .80075 L
.02381 .82581 L
.02381 .85088 L
.02381 .87594 L
.02381 .901 L
.02381 .92607 L
.02381 .95113 L
.02381 .97619 L
.02381 .34962 L
s
.97619 .34127 m
.95113 .34127 L
.92607 .34127 L
.901 .34127 L
.87594 .34127 L
.85088 .34127 L
.82581 .34127 L
.80075 .34127 L
.77569 .34127 L
.75063 .34127 L
.72556 .34127 L
.7005 .34127 L
.67544 .34127 L
.65038 .34127 L
.62531 .34127 L
.60025 .34127 L
.57519 .34127 L
.55013 .34127 L
.52506 .34127 L
.5 .34127 L
.47494 .34127 L
.44987 .34127 L
.42481 .34127 L
.39975 .34127 L
.37469 .34127 L
.34962 .34127 L
.32456 .34127 L
.2995 .34127 L
.27444 .34127 L
.24937 .34127 L
.22431 .34127 L
.19925 .34127 L
.17419 .34127 L
.14912 .34127 L
.12406 .34127 L
.099 .34127 L
.07393 .34127 L
.04887 .34127 L
.02381 .32456 L
.02381 .2995 L
.02381 .27444 L
.02381 .24937 L
.02381 .22431 L
.02381 .19925 L
.02381 .17419 L
.02381 .14912 L
.02381 .12406 L
.02381 .099 L
.02381 .07393 L
.02381 .04887 L
Mistroke
.02381 .02381 L
Mfstroke
.34962 .02381 m
.37469 .02381 L
.39975 .02381 L
.42481 .02381 L
.44987 .02381 L
.47494 .02381 L
.5 .02381 L
.52506 .02381 L
.55013 .02381 L
.57519 .02381 L
.60025 .02381 L
.62531 .02381 L
.65038 .02381 L
.67544 .02381 L
.7005 .02381 L
.72556 .02381 L
.75063 .02381 L
.77569 .02381 L
.80075 .02381 L
.82581 .02381 L
.85088 .02381 L
.87594 .02381 L
.901 .02381 L
.92607 .02381 L
.95113 .02381 L
.97619 .02381 L
.34962 .02381 L
s
.02381 .02381 m
.04887 .02381 L
.07393 .02381 L
.099 .02381 L
.12406 .02381 L
.14912 .02381 L
.17419 .02381 L
.19925 .02381 L
.22431 .02381 L
.24937 .02381 L
.27444 .02381 L
.2995 .02381 L
.32456 .02381 L
.34127 .04887 L
.34127 .07393 L
.34127 .099 L
.34127 .12406 L
.34127 .14912 L
.34127 .17419 L
.34127 .19925 L
.34127 .22431 L
.34127 .24937 L
.34127 .27444 L
.34127 .2995 L
.34127 .32456 L
.34127 .34962 L
.34127 .37469 L
.34127 .39975 L
.34127 .42481 L
.34127 .44987 L
.34127 .47494 L
.34127 .5 L
.34127 .52506 L
.34127 .55013 L
.34127 .57519 L
.34127 .60025 L
.34127 .62531 L
.34127 .65038 L
.34127 .67544 L
.34127 .7005 L
.34127 .72556 L
.34127 .75063 L
.34127 .77569 L
.34127 .80075 L
.34127 .82581 L
.34127 .85088 L
.34127 .87594 L
.34127 .901 L
.34127 .92607 L
.34127 .95113 L
Mistroke
.34127 .97619 L
Mfstroke
.03 w
.34127 .34127 Mdot
.0001 w
.02381 .02381 m
.02381 .02381 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.02381 .0873 m
.02381 .08552 L
s
% Start of user PostScript
0 0.2 0 0.194388 MAarrowhead1
% End of user PostScript
.02381 .15079 m
.02381 .14723 L
s
% Start of user PostScript
0 0.4 0 0.388776 MAarrowhead1
% End of user PostScript
.02381 .21429 m
.02381 .20894 L
s
% Start of user PostScript
0 0.6 0 0.583164 MAarrowhead1
% End of user PostScript
.02381 .27778 m
.02381 .27065 L
s
% Start of user PostScript
0 0.8 0 0.777552 MAarrowhead1
% End of user PostScript
.02381 .34127 m
.02381 .33236 L
s
% Start of user PostScript
0 1. 0 0.97194 MAarrowhead1
% End of user PostScript
.02381 .40476 m
.02381 .39407 L
s
% Start of user PostScript
0 1.2 0 1.16633 MAarrowhead1
% End of user PostScript
.02381 .46825 m
.02381 .45578 L
s
% Start of user PostScript
0 1.4 0 1.36072 MAarrowhead1
% End of user PostScript
.02381 .53175 m
.02381 .51749 L
s
% Start of user PostScript
0 1.6 0 1.5551 MAarrowhead1
% End of user PostScript
.02381 .59524 m
.02381 .5792 L
s
% Start of user PostScript
0 1.8 0 1.74949 MAarrowhead1
% End of user PostScript
.02381 .65873 m
.02381 .64091 L
s
% Start of user PostScript
0 2. 0 1.94388 MAarrowhead1
% End of user PostScript
.02381 .72222 m
.02381 .70262 L
s
% Start of user PostScript
0 2.2 0 2.13827 MAarrowhead1
% End of user PostScript
.02381 .78571 m
.02381 .76434 L
s
% Start of user PostScript
0 2.4 0 2.33266 MAarrowhead1
% End of user PostScript
.02381 .84921 m
.02381 .82605 L
s
% Start of user PostScript
0 2.6 0 2.52704 MAarrowhead1
% End of user PostScript
.02381 .9127 m
.02381 .88776 L
s
% Start of user PostScript
0 2.8 0 2.72143 MAarrowhead1
% End of user PostScript
.0873 .02381 m
.08908 .02381 L
s
% Start of user PostScript
0.2 0 0.205612 0 MAarrowhead1
% End of user PostScript
.0873 .0873 m
.08873 .08588 L
s
% Start of user PostScript
0.2 0.2 0.20449 0.19551 MAarrowhead1
% End of user PostScript
.0873 .15079 m
.08837 .14794 L
s
% Start of user PostScript
0.2 0.4 0.203367 0.391021 MAarrowhead1
% End of user PostScript
.0873 .21429 m
.08801 .21001 L
s
% Start of user PostScript
0.2 0.6 0.202245 0.586531 MAarrowhead1
% End of user PostScript
.0873 .27778 m
.08766 .27208 L
s
% Start of user PostScript
0.2 0.8 0.201122 0.782042 MAarrowhead1
% End of user PostScript
.0873 .34127 m
.0873 .33414 L
s
% Start of user PostScript
0.2 1. 0.2 0.977552 MAarrowhead1
% End of user PostScript
.0873 .40476 m
.08695 .39621 L
s
% Start of user PostScript
0.2 1.2 0.198878 1.17306 MAarrowhead1
% End of user PostScript
.0873 .46825 m
.08659 .45828 L
s
% Start of user PostScript
0.2 1.4 0.197755 1.36857 MAarrowhead1
% End of user PostScript
.0873 .53175 m
.08623 .52034 L
s
% Start of user PostScript
0.2 1.6 0.196633 1.56408 MAarrowhead1
% End of user PostScript
.0873 .59524 m
.08588 .58241 L
s
% Start of user PostScript
0.2 1.8 0.19551 1.75959 MAarrowhead1
% End of user PostScript
.0873 .65873 m
.08552 .64448 L
s
% Start of user PostScript
0.2 2. 0.194388 1.9551 MAarrowhead1
% End of user PostScript
.0873 .72222 m
.08516 .70654 L
s
% Start of user PostScript
0.2 2.2 0.193266 2.15061 MAarrowhead1
% End of user PostScript
.0873 .78571 m
.08481 .76861 L
s
% Start of user PostScript
0.2 2.4 0.192143 2.34613 MAarrowhead1
% End of user PostScript
.0873 .84921 m
.08445 .83068 L
s
% Start of user PostScript
0.2 2.6 0.191021 2.54164 MAarrowhead1
% End of user PostScript
.0873 .9127 m
.08409 .89274 L
s
% Start of user PostScript
0.2 2.8 0.189898 2.73715 MAarrowhead1
% End of user PostScript
.15079 .02381 m
.15436 .02381 L
s
% Start of user PostScript
0.4 0 0.411224 0 MAarrowhead1
% End of user PostScript
.15079 .0873 m
.15364 .08623 L
s
% Start of user PostScript
0.4 0.2 0.408979 0.196633 MAarrowhead1
% End of user PostScript
.15079 .15079 m
.15293 .14866 L
s
% Start of user PostScript
0.4 0.4 0.406734 0.393266 MAarrowhead1
% End of user PostScript
.15079 .21429 m
.15222 .21108 L
s
% Start of user PostScript
0.4 0.6 0.40449 0.589898 MAarrowhead1
% End of user PostScript
.15079 .27778 m
.15151 .2735 L
s
% Start of user PostScript
0.4 0.8 0.402245 0.786531 MAarrowhead1
% End of user PostScript
.15079 .34127 m
.15079 .33593 L
s
% Start of user PostScript
0.4 1. 0.4 0.983164 MAarrowhead1
% End of user PostScript
.15079 .40476 m
.15008 .39835 L
s
% Start of user PostScript
0.4 1.2 0.397755 1.1798 MAarrowhead1
% End of user PostScript
.15079 .46825 m
.14937 .46077 L
s
% Start of user PostScript
0.4 1.4 0.39551 1.37643 MAarrowhead1
% End of user PostScript
.15079 .53175 m
.14866 .52319 L
s
% Start of user PostScript
0.4 1.6 0.393266 1.57306 MAarrowhead1
% End of user PostScript
.15079 .59524 m
.14794 .58562 L
s
% Start of user PostScript
0.4 1.8 0.391021 1.7697 MAarrowhead1
% End of user PostScript
.15079 .65873 m
.14723 .64804 L
s
% Start of user PostScript
0.4 2. 0.388776 1.96633 MAarrowhead1
% End of user PostScript
.15079 .72222 m
.14652 .71046 L
s
% Start of user PostScript
0.4 2.2 0.386531 2.16296 MAarrowhead1
% End of user PostScript
.15079 .78571 m
.14581 .77289 L
s
% Start of user PostScript
0.4 2.4 0.384287 2.35959 MAarrowhead1
% End of user PostScript
.15079 .84921 m
.14509 .83531 L
s
% Start of user PostScript
0.4 2.6 0.382042 2.55623 MAarrowhead1
% End of user PostScript
.15079 .9127 m
.14438 .89773 L
s
% Start of user PostScript
0.4 2.8 0.379797 2.75286 MAarrowhead1
% End of user PostScript
.21429 .02381 m
.21963 .02381 L
s
% Start of user PostScript
0.6 0 0.616836 0 MAarrowhead1
% End of user PostScript
.21429 .0873 m
.21856 .08659 L
s
% Start of user PostScript
0.6 0.2 0.613469 0.197755 MAarrowhead1
% End of user PostScript
.21429 .15079 m
.21749 .14937 L
s
% Start of user PostScript
0.6 0.4 0.610102 0.39551 MAarrowhead1
% End of user PostScript
.21429 .21429 m
.21642 .21215 L
s
% Start of user PostScript
0.6 0.6 0.606734 0.593266 MAarrowhead1
% End of user PostScript
.21429 .27778 m
.21535 .27493 L
s
% Start of user PostScript
0.6 0.8 0.603367 0.791021 MAarrowhead1
% End of user PostScript
.21429 .34127 m
.21429 .33771 L
s
% Start of user PostScript
0.6 1. 0.6 0.988776 MAarrowhead1
% End of user PostScript
.21429 .40476 m
.21322 .40049 L
s
% Start of user PostScript
0.6 1.2 0.596633 1.18653 MAarrowhead1
% End of user PostScript
.21429 .46825 m
.21215 .46327 L
s
% Start of user PostScript
0.6 1.4 0.593266 1.38429 MAarrowhead1
% End of user PostScript
.21429 .53175 m
.21108 .52604 L
s
% Start of user PostScript
0.6 1.6 0.589898 1.58204 MAarrowhead1
% End of user PostScript
.21429 .59524 m
.21001 .58882 L
s
% Start of user PostScript
0.6 1.8 0.586531 1.7798 MAarrowhead1
% End of user PostScript
.21429 .65873 m
.20894 .6516 L
s
% Start of user PostScript
0.6 2. 0.583164 1.97755 MAarrowhead1
% End of user PostScript
.21429 .72222 m
.20787 .71438 L
s
% Start of user PostScript
0.6 2.2 0.579797 2.17531 MAarrowhead1
% End of user PostScript
.21429 .78571 m
.2068 .77716 L
s
% Start of user PostScript
0.6 2.4 0.57643 2.37306 MAarrowhead1
% End of user PostScript
.21429 .84921 m
.20573 .83994 L
s
% Start of user PostScript
0.6 2.6 0.573063 2.57082 MAarrowhead1
% End of user PostScript
.21429 .9127 m
.20467 .90272 L
s
% Start of user PostScript
0.6 2.8 0.569695 2.76857 MAarrowhead1
% End of user PostScript
.27778 .02381 m
.2849 .02381 L
s
% Start of user PostScript
0.8 0 0.822448 0 MAarrowhead1
% End of user PostScript
.27778 .0873 m
.28348 .08695 L
s
% Start of user PostScript
0.8 0.2 0.817958 0.198878 MAarrowhead1
% End of user PostScript
.27778 .15079 m
.28205 .15008 L
s
% Start of user PostScript
0.8 0.4 0.813469 0.397755 MAarrowhead1
% End of user PostScript
.27778 .21429 m
.28063 .21322 L
s
% Start of user PostScript
0.8 0.6 0.808979 0.596633 MAarrowhead1
% End of user PostScript
.27778 .27778 m
.2792 .27635 L
s
% Start of user PostScript
0.8 0.8 0.80449 0.79551 MAarrowhead1
% End of user PostScript
.27778 .34127 m
.27778 .33949 L
s
% Start of user PostScript
0.8 1. 0.8 0.994388 MAarrowhead1
% End of user PostScript
.27778 .40476 m
.27635 .40262 L
s
% Start of user PostScript
0.8 1.2 0.79551 1.19327 MAarrowhead1
% End of user PostScript
.27778 .46825 m
.27493 .46576 L
s
% Start of user PostScript
0.8 1.4 0.791021 1.39214 MAarrowhead1
% End of user PostScript
.27778 .53175 m
.2735 .5289 L
s
% Start of user PostScript
0.8 1.6 0.786531 1.59102 MAarrowhead1
% End of user PostScript
.27778 .59524 m
.27208 .59203 L
s
% Start of user PostScript
0.8 1.8 0.782042 1.7899 MAarrowhead1
% End of user PostScript
.27778 .65873 m
.27065 .65517 L
s
% Start of user PostScript
0.8 2. 0.777552 1.98878 MAarrowhead1
% End of user PostScript
.27778 .72222 m
.26923 .7183 L
s
% Start of user PostScript
0.8 2.2 0.773063 2.18765 MAarrowhead1
% End of user PostScript
.27778 .78571 m
.2678 .78144 L
s
% Start of user PostScript
0.8 2.4 0.768573 2.38653 MAarrowhead1
% End of user PostScript
.27778 .84921 m
.26638 .84457 L
s
% Start of user PostScript
0.8 2.6 0.764083 2.58541 MAarrowhead1
% End of user PostScript
.27778 .9127 m
.26495 .90771 L
s
% Start of user PostScript
0.8 2.8 0.759594 2.78429 MAarrowhead1
% End of user PostScript
.34127 .02381 m
.35018 .02381 L
s
% Start of user PostScript
1. 0 1.02806 0 MAarrowhead1
% End of user PostScript
.34127 .0873 m
.3484 .0873 L
s
% Start of user PostScript
1. 0.2 1.02245 0.2 MAarrowhead1
% End of user PostScript
.34127 .15079 m
.34661 .15079 L
s
% Start of user PostScript
1. 0.4 1.01684 0.4 MAarrowhead1
% End of user PostScript
.34127 .21429 m
.34483 .21429 L
s
% Start of user PostScript
1. 0.6 1.01122 0.6 MAarrowhead1
% End of user PostScript
.34127 .27778 m
.34305 .27778 L
s
% Start of user PostScript
1. 0.8 1.00561 0.8 MAarrowhead1
% End of user PostScript
.34127 .34127 m
.34127 .34127 L
s
% Start of user PostScript
1. 1. MAarrowzero1
% End of user PostScript
.34127 .40476 m
.33949 .40476 L
s
% Start of user PostScript
1. 1.2 0.994388 1.2 MAarrowhead1
% End of user PostScript
.34127 .46825 m
.33771 .46825 L
s
% Start of user PostScript
1. 1.4 0.988776 1.4 MAarrowhead1
% End of user PostScript
.34127 .53175 m
.33593 .53175 L
s
% Start of user PostScript
1. 1.6 0.983164 1.6 MAarrowhead1
% End of user PostScript
.34127 .59524 m
.33414 .59524 L
s
% Start of user PostScript
1. 1.8 0.977552 1.8 MAarrowhead1
% End of user PostScript
.34127 .65873 m
.33236 .65873 L
s
% Start of user PostScript
1. 2. 0.97194 2. MAarrowhead1
% End of user PostScript
.34127 .72222 m
.33058 .72222 L
s
% Start of user PostScript
1. 2.2 0.966328 2.2 MAarrowhead1
% End of user PostScript
.34127 .78571 m
.3288 .78571 L
s
% Start of user PostScript
1. 2.4 0.960716 2.4 MAarrowhead1
% End of user PostScript
.34127 .84921 m
.32702 .84921 L
s
% Start of user PostScript
1. 2.6 0.955104 2.6 MAarrowhead1
% End of user PostScript
.34127 .9127 m
.32524 .9127 L
s
% Start of user PostScript
1. 2.8 0.949492 2.8 MAarrowhead1
% End of user PostScript
.40476 .02381 m
.41545 .02381 L
s
% Start of user PostScript
1.2 0 1.23367 0 MAarrowhead1
% End of user PostScript
.40476 .0873 m
.41331 .08766 L
s
% Start of user PostScript
1.2 0.2 1.22694 0.201122 MAarrowhead1
% End of user PostScript
.40476 .15079 m
.41118 .15151 L
s
% Start of user PostScript
1.2 0.4 1.2202 0.402245 MAarrowhead1
% End of user PostScript
.40476 .21429 m
.40904 .21535 L
s
% Start of user PostScript
1.2 0.6 1.21347 0.603367 MAarrowhead1
% End of user PostScript
.40476 .27778 m
.4069 .2792 L
s
% Start of user PostScript
1.2 0.8 1.20673 0.80449 MAarrowhead1
% End of user PostScript
.40476 .34127 m
.40476 .34305 L
s
% Start of user PostScript
1.2 1. 1.2 1.00561 MAarrowhead1
% End of user PostScript
.40476 .40476 m
.40262 .4069 L
s
% Start of user PostScript
1.2 1.2 1.19327 1.20673 MAarrowhead1
% End of user PostScript
.40476 .46825 m
.40049 .47075 L
s
% Start of user PostScript
1.2 1.4 1.18653 1.40786 MAarrowhead1
% End of user PostScript
.40476 .53175 m
.39835 .5346 L
s
% Start of user PostScript
1.2 1.6 1.1798 1.60898 MAarrowhead1
% End of user PostScript
.40476 .59524 m
.39621 .59844 L
s
% Start of user PostScript
1.2 1.8 1.17306 1.8101 MAarrowhead1
% End of user PostScript
.40476 .65873 m
.39407 .66229 L
s
% Start of user PostScript
1.2 2. 1.16633 2.01122 MAarrowhead1
% End of user PostScript
.40476 .72222 m
.39193 .72614 L
s
% Start of user PostScript
1.2 2.2 1.15959 2.21235 MAarrowhead1
% End of user PostScript
.40476 .78571 m
.3898 .78999 L
s
% Start of user PostScript
1.2 2.4 1.15286 2.41347 MAarrowhead1
% End of user PostScript
.40476 .84921 m
.38766 .85384 L
s
% Start of user PostScript
1.2 2.6 1.14613 2.61459 MAarrowhead1
% End of user PostScript
.40476 .9127 m
.38552 .91769 L
s
% Start of user PostScript
1.2 2.8 1.13939 2.81571 MAarrowhead1
% End of user PostScript
.46825 .02381 m
.48072 .02381 L
s
% Start of user PostScript
1.4 0 1.43928 0 MAarrowhead1
% End of user PostScript
.46825 .0873 m
.47823 .08801 L
s
% Start of user PostScript
1.4 0.2 1.43143 0.202245 MAarrowhead1
% End of user PostScript
.46825 .15079 m
.47574 .15222 L
s
% Start of user PostScript
1.4 0.4 1.42357 0.40449 MAarrowhead1
% End of user PostScript
.46825 .21429 m
.47324 .21642 L
s
% Start of user PostScript
1.4 0.6 1.41571 0.606734 MAarrowhead1
% End of user PostScript
.46825 .27778 m
.47075 .28063 L
s
% Start of user PostScript
1.4 0.8 1.40786 0.808979 MAarrowhead1
% End of user PostScript
.46825 .34127 m
.46825 .34483 L
s
% Start of user PostScript
1.4 1. 1.4 1.01122 MAarrowhead1
% End of user PostScript
.46825 .40476 m
.46576 .40904 L
s
% Start of user PostScript
1.4 1.2 1.39214 1.21347 MAarrowhead1
% End of user PostScript
.46825 .46825 m
.46327 .47324 L
s
% Start of user PostScript
1.4 1.4 1.38429 1.41571 MAarrowhead1
% End of user PostScript
.46825 .53175 m
.46077 .53745 L
s
% Start of user PostScript
1.4 1.6 1.37643 1.61796 MAarrowhead1
% End of user PostScript
.46825 .59524 m
.45828 .60165 L
s
% Start of user PostScript
1.4 1.8 1.36857 1.8202 MAarrowhead1
% End of user PostScript
.46825 .65873 m
.45578 .66586 L
s
% Start of user PostScript
1.4 2. 1.36072 2.02245 MAarrowhead1
% End of user PostScript
.46825 .72222 m
.45329 .73006 L
s
% Start of user PostScript
1.4 2.2 1.35286 2.22469 MAarrowhead1
% End of user PostScript
.46825 .78571 m
.45079 .79427 L
s
% Start of user PostScript
1.4 2.4 1.345 2.42694 MAarrowhead1
% End of user PostScript
.46825 .84921 m
.4483 .85847 L
s
% Start of user PostScript
1.4 2.6 1.33715 2.62918 MAarrowhead1
% End of user PostScript
.46825 .9127 m
.44581 .92268 L
s
% Start of user PostScript
1.4 2.8 1.32929 2.83143 MAarrowhead1
% End of user PostScript
.53175 .02381 m
.546 .02381 L
s
% Start of user PostScript
1.6 0 1.6449 0 MAarrowhead1
% End of user PostScript
.53175 .0873 m
.54315 .08837 L
s
% Start of user PostScript
1.6 0.2 1.63592 0.203367 MAarrowhead1
% End of user PostScript
.53175 .15079 m
.5403 .15293 L
s
% Start of user PostScript
1.6 0.4 1.62694 0.406734 MAarrowhead1
% End of user PostScript
.53175 .21429 m
.53745 .21749 L
s
% Start of user PostScript
1.6 0.6 1.61796 0.610102 MAarrowhead1
% End of user PostScript
.53175 .27778 m
.5346 .28205 L
s
% Start of user PostScript
1.6 0.8 1.60898 0.813469 MAarrowhead1
% End of user PostScript
.53175 .34127 m
.53175 .34661 L
s
% Start of user PostScript
1.6 1. 1.6 1.01684 MAarrowhead1
% End of user PostScript
.53175 .40476 m
.5289 .41118 L
s
% Start of user PostScript
1.6 1.2 1.59102 1.2202 MAarrowhead1
% End of user PostScript
.53175 .46825 m
.52604 .47574 L
s
% Start of user PostScript
1.6 1.4 1.58204 1.42357 MAarrowhead1
% End of user PostScript
.53175 .53175 m
.52319 .5403 L
s
% Start of user PostScript
1.6 1.6 1.57306 1.62694 MAarrowhead1
% End of user PostScript
.53175 .59524 m
.52034 .60486 L
s
% Start of user PostScript
1.6 1.8 1.56408 1.8303 MAarrowhead1
% End of user PostScript
.53175 .65873 m
.51749 .66942 L
s
% Start of user PostScript
1.6 2. 1.5551 2.03367 MAarrowhead1
% End of user PostScript
.53175 .72222 m
.51464 .73398 L
s
% Start of user PostScript
1.6 2.2 1.54613 2.23704 MAarrowhead1
% End of user PostScript
.53175 .78571 m
.51179 .79854 L
s
% Start of user PostScript
1.6 2.4 1.53715 2.44041 MAarrowhead1
% End of user PostScript
.53175 .84921 m
.50894 .8631 L
s
% Start of user PostScript
1.6 2.6 1.52817 2.64377 MAarrowhead1
% End of user PostScript
.53175 .9127 m
.50609 .92766 L
s
% Start of user PostScript
1.6 2.8 1.51919 2.84714 MAarrowhead1
% End of user PostScript
.59524 .02381 m
.61127 .02381 L
s
% Start of user PostScript
1.8 0 1.85051 0 MAarrowhead1
% End of user PostScript
.59524 .0873 m
.60807 .08873 L
s
% Start of user PostScript
1.8 0.2 1.84041 0.20449 MAarrowhead1
% End of user PostScript
.59524 .15079 m
.60486 .15364 L
s
% Start of user PostScript
1.8 0.4 1.8303 0.408979 MAarrowhead1
% End of user PostScript
.59524 .21429 m
.60165 .21856 L
s
% Start of user PostScript
1.8 0.6 1.8202 0.613469 MAarrowhead1
% End of user PostScript
.59524 .27778 m
.59844 .28348 L
s
% Start of user PostScript
1.8 0.8 1.8101 0.817958 MAarrowhead1
% End of user PostScript
.59524 .34127 m
.59524 .3484 L
s
% Start of user PostScript
1.8 1. 1.8 1.02245 MAarrowhead1
% End of user PostScript
.59524 .40476 m
.59203 .41331 L
s
% Start of user PostScript
1.8 1.2 1.7899 1.22694 MAarrowhead1
% End of user PostScript
.59524 .46825 m
.58882 .47823 L
s
% Start of user PostScript
1.8 1.4 1.7798 1.43143 MAarrowhead1
% End of user PostScript
.59524 .53175 m
.58562 .54315 L
s
% Start of user PostScript
1.8 1.6 1.7697 1.63592 MAarrowhead1
% End of user PostScript
.59524 .59524 m
.58241 .60807 L
s
% Start of user PostScript
1.8 1.8 1.75959 1.84041 MAarrowhead1
% End of user PostScript
.59524 .65873 m
.5792 .67298 L
s
% Start of user PostScript
1.8 2. 1.74949 2.0449 MAarrowhead1
% End of user PostScript
.59524 .72222 m
.576 .7379 L
s
% Start of user PostScript
1.8 2.2 1.73939 2.24939 MAarrowhead1
% End of user PostScript
.59524 .78571 m
.57279 .80282 L
s
% Start of user PostScript
1.8 2.4 1.72929 2.45387 MAarrowhead1
% End of user PostScript
.59524 .84921 m
.56958 .86773 L
s
% Start of user PostScript
1.8 2.6 1.71919 2.65836 MAarrowhead1
% End of user PostScript
.59524 .9127 m
.56638 .93265 L
s
% Start of user PostScript
1.8 2.8 1.70909 2.86285 MAarrowhead1
% End of user PostScript
.65873 .02381 m
.67655 .02381 L
s
% Start of user PostScript
2. 0 2.05612 0 MAarrowhead1
% End of user PostScript
.65873 .0873 m
.67298 .08908 L
s
% Start of user PostScript
2. 0.2 2.0449 0.205612 MAarrowhead1
% End of user PostScript
.65873 .15079 m
.66942 .15436 L
s
% Start of user PostScript
2. 0.4 2.03367 0.411224 MAarrowhead1
% End of user PostScript
.65873 .21429 m
.66586 .21963 L
s
% Start of user PostScript
2. 0.6 2.02245 0.616836 MAarrowhead1
% End of user PostScript
.65873 .27778 m
.66229 .2849 L
s
% Start of user PostScript
2. 0.8 2.01122 0.822448 MAarrowhead1
% End of user PostScript
.65873 .34127 m
.65873 .35018 L
s
% Start of user PostScript
2. 1. 2. 1.02806 MAarrowhead1
% End of user PostScript
.65873 .40476 m
.65517 .41545 L
s
% Start of user PostScript
2. 1.2 1.98878 1.23367 MAarrowhead1
% End of user PostScript
.65873 .46825 m
.6516 .48072 L
s
% Start of user PostScript
2. 1.4 1.97755 1.43928 MAarrowhead1
% End of user PostScript
.65873 .53175 m
.64804 .546 L
s
% Start of user PostScript
2. 1.6 1.96633 1.6449 MAarrowhead1
% End of user PostScript
.65873 .59524 m
.64448 .61127 L
s
% Start of user PostScript
2. 1.8 1.9551 1.85051 MAarrowhead1
% End of user PostScript
.65873 .65873 m
.64091 .67655 L
s
% Start of user PostScript
2. 2. 1.94388 2.05612 MAarrowhead1
% End of user PostScript
.65873 .72222 m
.63735 .74182 L
s
% Start of user PostScript
2. 2.2 1.93266 2.26173 MAarrowhead1
% End of user PostScript
.65873 .78571 m
.63379 .80709 L
s
% Start of user PostScript
2. 2.4 1.92143 2.46734 MAarrowhead1
% End of user PostScript
.65873 .84921 m
.63022 .87237 L
s
% Start of user PostScript
2. 2.6 1.91021 2.67296 MAarrowhead1
% End of user PostScript
.65873 .9127 m
.62666 .93764 L
s
% Start of user PostScript
2. 2.8 1.89898 2.87857 MAarrowhead1
% End of user PostScript
.72222 .02381 m
.74182 .02381 L
s
% Start of user PostScript
2.2 0 2.26173 0 MAarrowhead1
% End of user PostScript
.72222 .0873 m
.7379 .08944 L
s
% Start of user PostScript
2.2 0.2 2.24939 0.206734 MAarrowhead1
% End of user PostScript
.72222 .15079 m
.73398 .15507 L
s
% Start of user PostScript
2.2 0.4 2.23704 0.413469 MAarrowhead1
% End of user PostScript
.72222 .21429 m
.73006 .2207 L
s
% Start of user PostScript
2.2 0.6 2.22469 0.620203 MAarrowhead1
% End of user PostScript
.72222 .27778 m
.72614 .28633 L
s
% Start of user PostScript
2.2 0.8 2.21235 0.826937 MAarrowhead1
% End of user PostScript
.72222 .34127 m
.72222 .35196 L
s
% Start of user PostScript
2.2 1. 2.2 1.03367 MAarrowhead1
% End of user PostScript
.72222 .40476 m
.7183 .41759 L
s
% Start of user PostScript
2.2 1.2 2.18765 1.24041 MAarrowhead1
% End of user PostScript
.72222 .46825 m
.71438 .48322 L
s
% Start of user PostScript
2.2 1.4 2.17531 1.44714 MAarrowhead1
% End of user PostScript
.72222 .53175 m
.71046 .54885 L
s
% Start of user PostScript
2.2 1.6 2.16296 1.65387 MAarrowhead1
% End of user PostScript
.72222 .59524 m
.70654 .61448 L
s
% Start of user PostScript
2.2 1.8 2.15061 1.86061 MAarrowhead1
% End of user PostScript
.72222 .65873 m
.70262 .68011 L
s
% Start of user PostScript
2.2 2. 2.13827 2.06734 MAarrowhead1
% End of user PostScript
.72222 .72222 m
.69871 .74574 L
s
% Start of user PostScript
2.2 2.2 2.12592 2.27408 MAarrowhead1
% End of user PostScript
.72222 .78571 m
.69479 .81137 L
s
% Start of user PostScript
2.2 2.4 2.11358 2.48081 MAarrowhead1
% End of user PostScript
.72222 .84921 m
.69087 .877 L
s
% Start of user PostScript
2.2 2.6 2.10123 2.68755 MAarrowhead1
% End of user PostScript
.72222 .9127 m
.68695 .94263 L
s
% Start of user PostScript
2.2 2.8 2.08888 2.89428 MAarrowhead1
% End of user PostScript
.78571 .02381 m
.80709 .02381 L
s
% Start of user PostScript
2.4 0 2.46734 0 MAarrowhead1
% End of user PostScript
.78571 .0873 m
.80282 .0898 L
s
% Start of user PostScript
2.4 0.2 2.45387 0.207857 MAarrowhead1
% End of user PostScript
.78571 .15079 m
.79854 .15578 L
s
% Start of user PostScript
2.4 0.4 2.44041 0.415713 MAarrowhead1
% End of user PostScript
.78571 .21429 m
.79427 .22177 L
s
% Start of user PostScript
2.4 0.6 2.42694 0.62357 MAarrowhead1
% End of user PostScript
.78571 .27778 m
.78999 .28775 L
s
% Start of user PostScript
2.4 0.8 2.41347 0.831427 MAarrowhead1
% End of user PostScript
.78571 .34127 m
.78571 .35374 L
s
% Start of user PostScript
2.4 1. 2.4 1.03928 MAarrowhead1
% End of user PostScript
.78571 .40476 m
.78144 .41973 L
s
% Start of user PostScript
2.4 1.2 2.38653 1.24714 MAarrowhead1
% End of user PostScript
.78571 .46825 m
.77716 .48571 L
s
% Start of user PostScript
2.4 1.4 2.37306 1.455 MAarrowhead1
% End of user PostScript
.78571 .53175 m
.77289 .5517 L
s
% Start of user PostScript
2.4 1.6 2.35959 1.66285 MAarrowhead1
% End of user PostScript
.78571 .59524 m
.76861 .61769 L
s
% Start of user PostScript
2.4 1.8 2.34613 1.87071 MAarrowhead1
% End of user PostScript
.78571 .65873 m
.76434 .68367 L
s
% Start of user PostScript
2.4 2. 2.33266 2.07857 MAarrowhead1
% End of user PostScript
.78571 .72222 m
.76006 .74966 L
s
% Start of user PostScript
2.4 2.2 2.31919 2.28642 MAarrowhead1
% End of user PostScript
.78571 .78571 m
.75578 .81564 L
s
% Start of user PostScript
2.4 2.4 2.30572 2.49428 MAarrowhead1
% End of user PostScript
.78571 .84921 m
.75151 .88163 L
s
% Start of user PostScript
2.4 2.6 2.29225 2.70214 MAarrowhead1
% End of user PostScript
.78571 .9127 m
.74723 .94762 L
s
% Start of user PostScript
2.4 2.8 2.27878 2.90999 MAarrowhead1
% End of user PostScript
.84921 .02381 m
.87237 .02381 L
s
% Start of user PostScript
2.6 0 2.67296 0 MAarrowhead1
% End of user PostScript
.84921 .0873 m
.86773 .09015 L
s
% Start of user PostScript
2.6 0.2 2.65836 0.208979 MAarrowhead1
% End of user PostScript
.84921 .15079 m
.8631 .15649 L
s
% Start of user PostScript
2.6 0.4 2.64377 0.417958 MAarrowhead1
% End of user PostScript
.84921 .21429 m
.85847 .22284 L
s
% Start of user PostScript
2.6 0.6 2.62918 0.626937 MAarrowhead1
% End of user PostScript
.84921 .27778 m
.85384 .28918 L
s
% Start of user PostScript
2.6 0.8 2.61459 0.835917 MAarrowhead1
% End of user PostScript
.84921 .34127 m
.84921 .35552 L
s
% Start of user PostScript
2.6 1. 2.6 1.0449 MAarrowhead1
% End of user PostScript
.84921 .40476 m
.84457 .42187 L
s
% Start of user PostScript
2.6 1.2 2.58541 1.25387 MAarrowhead1
% End of user PostScript
.84921 .46825 m
.83994 .48821 L
s
% Start of user PostScript
2.6 1.4 2.57082 1.46285 MAarrowhead1
% End of user PostScript
.84921 .53175 m
.83531 .55455 L
s
% Start of user PostScript
2.6 1.6 2.55623 1.67183 MAarrowhead1
% End of user PostScript
.84921 .59524 m
.83068 .62089 L
s
% Start of user PostScript
2.6 1.8 2.54164 1.88081 MAarrowhead1
% End of user PostScript
.84921 .65873 m
.82605 .68724 L
s
% Start of user PostScript
2.6 2. 2.52704 2.08979 MAarrowhead1
% End of user PostScript
.84921 .72222 m
.82141 .75358 L
s
% Start of user PostScript
2.6 2.2 2.51245 2.29877 MAarrowhead1
% End of user PostScript
.84921 .78571 m
.81678 .81992 L
s
% Start of user PostScript
2.6 2.4 2.49786 2.50775 MAarrowhead1
% End of user PostScript
.84921 .84921 m
.81215 .88626 L
s
% Start of user PostScript
2.6 2.6 2.48327 2.71673 MAarrowhead1
% End of user PostScript
.84921 .9127 m
.80752 .95261 L
s
% Start of user PostScript
2.6 2.8 2.46868 2.92571 MAarrowhead1
% End of user PostScript
.9127 .02381 m
.93764 .02381 L
s
% Start of user PostScript
2.8 0 2.87857 0 MAarrowhead1
% End of user PostScript
.9127 .0873 m
.93265 .09051 L
s
% Start of user PostScript
2.8 0.2 2.86285 0.210102 MAarrowhead1
% End of user PostScript
.9127 .15079 m
.92766 .15721 L
s
% Start of user PostScript
2.8 0.4 2.84714 0.420203 MAarrowhead1
% End of user PostScript
.9127 .21429 m
.92268 .22391 L
s
% Start of user PostScript
2.8 0.6 2.83143 0.630305 MAarrowhead1
% End of user PostScript
.9127 .27778 m
.91769 .29061 L
s
% Start of user PostScript
2.8 0.8 2.81571 0.840406 MAarrowhead1
% End of user PostScript
.9127 .34127 m
.9127 .3573 L
s
% Start of user PostScript
2.8 1. 2.8 1.05051 MAarrowhead1
% End of user PostScript
.9127 .40476 m
.90771 .424 L
s
% Start of user PostScript
2.8 1.2 2.78429 1.26061 MAarrowhead1
% End of user PostScript
.9127 .46825 m
.90272 .4907 L
s
% Start of user PostScript
2.8 1.4 2.76857 1.47071 MAarrowhead1
% End of user PostScript
.9127 .53175 m
.89773 .5574 L
s
% Start of user PostScript
2.8 1.6 2.75286 1.68081 MAarrowhead1
% End of user PostScript
.9127 .59524 m
.89274 .6241 L
s
% Start of user PostScript
2.8 1.8 2.73715 1.89091 MAarrowhead1
% End of user PostScript
.9127 .65873 m
.88776 .6908 L
s
% Start of user PostScript
2.8 2. 2.72143 2.10102 MAarrowhead1
% End of user PostScript
.9127 .72222 m
.88277 .7575 L
s
% Start of user PostScript
2.8 2.2 2.70572 2.31112 MAarrowhead1
% End of user PostScript
.9127 .78571 m
.87778 .8242 L
s
% Start of user PostScript
2.8 2.4 2.69001 2.52122 MAarrowhead1
% End of user PostScript
.9127 .84921 m
.87279 .8909 L
s
% Start of user PostScript
2.8 2.6 2.67429 2.73132 MAarrowhead1
% End of user PostScript
.9127 .9127 m
.8678 .95759 L
s
% Start of user PostScript
2.8 2.8 2.65858 2.94142 MAarrowhead1
% End of user PostScript
0 1 0 r
.5 Mabswid
.15079 .15079 m
.1586 .14371 L
.16657 .13773 L
.17699 .13134 L
.18741 .12616 L
.19859 .12165 L
.21185 .11736 L
.22725 .11347 L
.24322 .11039 L
.26096 .10784 L
.27177 .10665 L
.28238 .1057 L
.29409 .10489 L
.3053 .10431 L
.31169 .10406 L
.31884 .10385 L
.32217 .10377 L
.32577 .1037 L
.3292 .10365 L
.33234 .10361 L
.33855 .10357 L
.34172 .10357 L
.34525 .10358 L
.35157 .10362 L
.35759 .10371 L
.36129 .10377 L
.36483 .10385 L
.37157 .10403 L
.38717 .10459 L
.40131 .10529 L
.41483 .1061 L
.44703 .10863 L
.47809 .11184 L
.5135 .11645 L
.58207 .12859 L
.62376 .13853 L
.66827 .15201 L
.70589 .16658 L
.74533 .18656 L
.76359 .19825 L
.78212 .21249 L
.79709 .22656 L
.8112 .24313 L
.82212 .25969 L
.82711 .26912 L
.83181 .27979 L
.83546 .29007 L
.83821 .29989 L
.84039 .31018 L
.84187 .32034 L
Mistroke
.8429 .33363 L
.84299 .34619 L
.84268 .35337 L
.84206 .3613 L
.84013 .37613 L
.83736 .3906 L
.8334 .4064 L
.82359 .43598 L
.80766 .47242 L
.78849 .50787 L
.73065 .59113 L
.66657 .66282 L
.58879 .73252 L
.51363 .78506 L
.4788 .80446 L
.4473 .81908 L
.42027 .82917 L
.39262 .83691 L
.37832 .83977 L
.36382 .8418 L
.35187 .84277 L
.33928 .84304 L
.3264 .84246 L
.31518 .8412 L
.3028 .8389 L
.29166 .83595 L
.28179 .83258 L
.27309 .82897 L
.25474 .81915 L
.23772 .80697 L
.22366 .79424 L
.19662 .76122 L
.17642 .72678 L
.16084 .69213 L
.14717 .65356 L
.13561 .61248 L
.12578 .56834 L
.11879 .52898 L
.11402 .49587 L
.11016 .46273 L
.10708 .42857 L
.10606 .41417 L
.10518 .39927 L
.10453 .38563 L
.10409 .37364 L
.10393 .36799 L
.10379 .36196 L
.10369 .35636 L
.10362 .35127 L
.10358 .34546 L
Mistroke
.10357 .3401 L
.10359 .33434 L
.10366 .32825 L
.10377 .32202 L
.10392 .31622 L
.1043 .30565 L
.10455 .3002 L
.10487 .29444 L
.10555 .28432 L
.1072 .26649 L
.10834 .25697 L
.10972 .24737 L
.1126 .2313 L
.11577 .21763 L
.11917 .20586 L
.12856 .18231 L
.13443 .17166 L
.14163 .16121 L
.14874 .15291 L
.15712 .14495 L
.16544 .13852 L
.17554 .13214 L
.19597 .12263 L
.20881 .11826 L
.22364 .11429 L
.23745 .1114 L
.25385 .10876 L
.27321 .1065 L
.28483 .10551 L
.29589 .10479 L
.30668 .10426 L
.31296 .10402 L
.31887 .10385 L
.32415 .10373 L
.33007 .10364 L
.33638 .10358 L
.34239 .10357 L
.34874 .1036 L
.35233 .10363 L
.35562 .10367 L
.36213 .10379 L
.36836 .10394 L
.38277 .10441 L
.39896 .10516 L
.43027 .10722 L
.46099 .10998 L
.5246 .11811 L
.55887 .12396 L
.59781 .13208 L
.64005 .14307 L
Mistroke
.68024 .15628 L
.71568 .17101 L
.75231 .1908 L
.78816 .21783 L
.80388 .23403 L
.81877 .25413 L
.82906 .27327 L
.83372 .28489 L
.83723 .2961 L
.83978 .30698 L
.84176 .31942 L
.84281 .33171 L
.84304 .34359 L
.84239 .35751 L
.8417 .36474 L
.84064 .37284 L
.838 .3876 L
.83463 .40186 L
.82373 .43563 L
.80687 .47402 L
.76243 .54853 L
.70838 .61784 L
.64729 .68164 L
.57543 .74289 L
.50702 .78899 L
.44662 .81936 L
.41516 .83081 L
.40083 .8349 L
.38787 .83795 L
.37421 .84044 L
.35979 .8422 L
.34628 .84299 L
.33243 .84284 L
.32071 .84191 L
.30853 .84008 L
.29754 .83762 L
.28784 .83474 L
.27054 .82779 L
.25373 .81852 L
.23688 .80628 L
.22061 .79112 L
.19554 .75963 L
.17187 .71751 L
.15495 .67662 L
.14249 .63804 L
.13195 .59723 L
.11845 .52679 L
.11283 .4864 L
.10897 .45065 L
.10649 .42053 L
Mistroke
.10553 .40556 L
.10472 .39009 L
.1044 .38257 L
.10415 .37559 L
.10395 .36891 L
.1038 .36285 L
.1037 .35721 L
.10362 .35132 L
.10358 .34551 L
.10357 .33922 L
.10358 .33596 L
.10361 .33258 L
.10369 .32661 L
.10375 .32334 L
.10381 .32033 L
.104 .31361 L
.10443 .30271 L
.10505 .29155 L
.10586 .28039 L
.10694 .26887 L
.1094 .24942 L
.11243 .23217 L
.11577 .21764 L
.11956 .20466 L
.12423 .19193 L
.13433 .17182 L
.14165 .16119 L
.14946 .15215 L
.15719 .14489 L
.16665 .13768 L
.18704 .12633 L
.19993 .12117 L
.21326 .11696 L
.22587 .11378 L
.24026 .1109 L
.25744 .10828 L
.27458 .10638 L
.28479 .10552 L
.29486 .10485 L
.30425 .10436 L
.31482 .10396 L
.32047 .10381 L
.32682 .10368 L
.33006 .10364 L
.3336 .1036 L
.34008 .10357 L
.34666 .10358 L
.35304 .10364 L
.35887 .10373 L
.36534 .10386 L
Mistroke
.37208 .10404 L
.37855 .10425 L
.39093 .10476 L
.42015 .10647 L
.44704 .10863 L
.47782 .11181 L
.54681 .12177 L
.58866 .13002 L
.6289 .13992 L
.67186 .15326 L
.71051 .16864 L
.73124 .17873 L
.75292 .19118 L
.77086 .2035 L
.7888 .21842 L
.80371 .23383 L
.81574 .24949 L
.82552 .26594 L
.83373 .28491 L
.83713 .29573 L
.83869 .30189 L
.83996 .30786 L
.84181 .31985 L
.84278 .33122 L
.84302 .338 L
.84301 .34535 L
.84228 .35894 L
.84147 .36672 L
.84044 .37416 L
.83714 .39161 L
.83307 .40756 L
.82739 .42556 L
.81363 .45979 L
.77607 .52808 L
.71465 .61054 L
.64512 .6837 L
.57145 .7459 L
.53229 .77335 L
.49175 .79764 L
.45737 .81472 L
.42147 .82877 L
.40639 .8334 L
.39074 .83733 L
.37647 .84008 L
.36391 .84179 L
.35111 .84281 L
.33805 .84302 L
.32731 .84253 L
.31592 .8413 L
.30422 .83921 L
Mistroke
.29787 .8377 L
.2922 .83612 L
.28148 .83247 L
.27198 .82847 L
.25502 .81933 L
.23817 .80733 L
.2116 .78107 L
.19799 .76323 L
.1868 .74573 L
.16561 .70365 L
.15087 .66493 L
.1385 .62364 L
.12302 .55381 L
.11683 .51613 L
.11237 .48259 L
.1088 .44889 L
.10735 .43194 L
.10609 .41457 L
.10522 .39998 L
.10448 .38445 L
.10423 .37784 L
.10401 .37084 L
.10384 .3644 L
.10372 .35851 L
.10364 .35284 L
.10359 .34688 L
.10357 .34039 L
.10359 .33461 L
.10365 .32869 L
.10371 .32539 L
.10377 .32239 L
.1039 .31695 L
.10408 .3113 L
.10448 .30163 L
.10496 .29289 L
.10642 .27407 L
.10746 .26412 L
.10855 .25541 L
Mfstroke
.21429 .21429 m
.22209 .20721 L
.23003 .20125 L
.24033 .19495 L
.25056 .18994 L
.26138 .18569 L
.27406 .18181 L
.28144 .18 L
.28851 .17853 L
.3032 .17623 L
.31071 .1754 L
.31495 .17501 L
.31904 .17471 L
.32289 .17447 L
.32716 .17426 L
.3311 .17412 L
.3348 .17403 L
.33712 .174 L
.33966 .17397 L
.3443 .17398 L
.34889 .17405 L
.35317 .17417 L
.35787 .17435 L
.3631 .17462 L
.37387 .17539 L
.38488 .17648 L
.39515 .17775 L
.41892 .18168 L
.44163 .18676 L
.46351 .19298 L
.50485 .20916 L
.52495 .21983 L
.54582 .23387 L
.56195 .24783 L
.57706 .26515 L
.58305 .27395 L
.58859 .2838 L
.59266 .29273 L
.5963 .30292 L
.59809 .30932 L
.59945 .31538 L
.60048 .32133 L
.60128 .32778 L
.60173 .33368 L
.60192 .33932 L
.60187 .34562 L
.6015 .35253 L
.60075 .36001 L
.60016 .3643 L
.59951 .36832 L
Mistroke
.59608 .38383 L
.59165 .39831 L
.58557 .41402 L
.56947 .44557 L
.54975 .47506 L
.50334 .52627 L
.47502 .54978 L
.44268 .57116 L
.42625 .57994 L
.40878 .58774 L
.39391 .59312 L
.38619 .59544 L
.37811 .59751 L
.37079 .59906 L
.36284 .60037 L
.35574 .60122 L
.34921 .60171 L
.34264 .60192 L
.33674 .60186 L
.3304 .60151 L
.32388 .60083 L
.3185 .60002 L
.31288 .59893 L
.30311 .59636 L
.29205 .59238 L
.28256 .58795 L
.26327 .57564 L
.25447 .56832 L
.2455 .55953 L
.21988 .52503 L
.20856 .50361 L
.1986 .47985 L
.19153 .45884 L
.18552 .43664 L
.18084 .41447 L
.17767 .39454 L
.17635 .38379 L
.17539 .3739 L
.17463 .36331 L
.17433 .35748 L
.17422 .35471 L
.17414 .35221 L
.17403 .34799 L
.17398 .34353 L
.17398 .33945 L
.17402 .33565 L
.17411 .33128 L
.17426 .3273 L
.17446 .323 L
.17474 .31851 L
Mistroke
.17542 .31041 L
.17625 .30305 L
.17736 .29525 L
.17879 .28716 L
.18213 .27286 L
.18598 .26056 L
.19105 .24811 L
.19742 .23602 L
.20445 .22558 L
.21194 .2167 L
.2283 .20246 L
.23744 .19658 L
.24838 .19092 L
.26084 .18588 L
.27346 .18197 L
.28617 .17899 L
.29851 .17687 L
.30565 .17594 L
.31366 .17512 L
.31742 .17482 L
.32147 .17455 L
.3253 .17434 L
.3289 .17419 L
.33277 .17407 L
.33706 .174 L
.34129 .17397 L
.34588 .174 L
.35022 .17408 L
.35436 .17421 L
.35812 .17436 L
.36224 .17457 L
.3719 .17523 L
.38236 .1762 L
.40171 .1787 L
.42027 .18194 L
.43803 .18586 L
.4792 .19836 L
.50051 .20713 L
.52304 .21872 L
.54312 .23183 L
.56013 .24607 L
.57493 .26234 L
.58605 .27902 L
.59111 .28911 L
.59559 .30067 L
.59727 .30622 L
.59878 .31223 L
.59993 .31796 L
.60077 .32338 L
.60146 .32976 L
Mistroke
.6017 .33319 L
.60186 .33687 L
.60192 .34315 L
.60166 .35021 L
.60113 .3566 L
.60026 .3636 L
.59914 .37032 L
.59786 .37655 L
.59382 .39169 L
.58781 .40862 L
.57265 .44007 L
.55401 .46925 L
.52992 .4993 L
.47864 .54704 L
.4449 .56987 L
.41361 .58574 L
.39749 .59194 L
.38018 .59701 L
.37165 .59889 L
.36702 .59973 L
.36268 .6004 L
.35868 .60091 L
.35438 .60135 L
.34697 .60182 L
.34011 .60193 L
.3338 .60173 L
.32704 .6012 L
.3233 .60076 L
.31992 .60026 L
.31364 .59909 L
.30695 .59747 L
.29407 .5932 L
.28346 .58842 L
.2728 .58233 L
.25538 .56913 L
.23818 .55123 L
.22464 .53271 L
.21211 .51086 L
.20123 .48668 L
.18773 .44539 L
.18235 .42227 L
.17862 .40121 L
.1761 .38138 L
.17512 .37052 L
.17476 .36542 L
.17448 .36069 L
.17428 .35623 L
.17412 .35148 L
.17402 .34721 L
.17398 .34334 L
Mistroke
.17398 .33919 L
.17403 .3347 L
.17408 .33246 L
.17415 .33008 L
.17432 .32584 L
.17454 .32173 L
.17478 .31798 L
.17549 .30971 L
.1763 .30264 L
.17734 .29537 L
.17957 .28336 L
.18267 .27092 L
.18669 .25862 L
.19172 .24668 L
.2028 .22783 L
.21017 .21864 L
.21782 .21091 L
.22704 .20337 L
.23811 .19619 L
.24995 .19021 L
.26186 .18552 L
.27417 .18178 L
.28819 .17859 L
.29457 .17747 L
.30164 .17643 L
.30794 .17568 L
.31498 .17501 L
.31936 .17469 L
.32349 .17444 L
.32749 .17425 L
.3318 .1741 L
.3357 .17402 L
.33942 .17398 L
.34354 .17398 L
.34805 .17403 L
.35257 .17415 L
.35673 .1743 L
.36159 .17453 L
.36624 .17481 L
.37466 .17546 L
.38398 .17638 L
.4058 .17934 L
.42665 .18326 L
.44737 .18825 L
.47048 .19527 L
.49437 .20441 L
.51655 .21509 L
.53596 .22679 L
.55554 .24186 L
.57127 .25784 L
Mistroke
.58355 .27476 L
.58974 .28614 L
.59452 .29758 L
.59787 .30845 L
.59934 .31482 L
.60041 .32084 L
.60125 .32751 L
.60174 .33388 L
.60188 .3376 L
.60193 .34103 L
.60188 .34504 L
.60173 .34888 L
.60149 .35264 L
.60113 .35668 L
.6002 .36403 L
.5988 .37209 L
.59677 .38115 L
.5926 .39551 L
.58661 .41154 L
.57015 .44442 L
.55002 .4747 L
.52767 .50181 L
.49824 .53086 L
.46821 .55475 L
.43239 .57682 L
.41558 .58489 L
.40005 .59105 L
.3863 .59541 L
.37187 .59885 L
.36384 .60023 L
.35636 .60116 L
.34977 .60168 L
.34272 .60192 L
.3389 .60191 L
.33534 .60181 L
.32881 .60137 L
.32521 .601 L
.32195 .60057 L
.31474 .59932 L
.3091 .59804 L
.30308 .59635 L
.29144 .59213 L
.28103 .58715 L
.27209 .58187 L
.25384 .56774 L
.23909 .55232 L
.22693 .53617 L
.20534 .49652 L
.19704 .47558 L
.18963 .45237 L
Mistroke
.18462 .43279 L
.18042 .41213 L
.17749 .39319 L
.17561 .37642 L
.17486 .36688 L
.17437 .35843 L
.17419 .35382 L
.17411 .35125 L
.17405 .34891 L
.17399 .34463 L
.17397 .34017 L
.174 .33639 L
.17408 .33239 L
.1742 .32866 L
.17434 .3253 L
.17455 .32141 L
.17483 .31725 L
.17548 .30984 L
.17636 .30219 L
.17756 .29403 L
.1807 .27843 L
.18445 .26506 L
.18872 .25344 L
.19962 .23248 L
.20626 .22325 L
.21445 .21413 L
.22223 .20709 L
.23138 .20034 L
.25008 .19015 L
.25639 .18753 L
Mfstroke
.43651 .43651 m
.42388 .44796 L
.41131 .45734 L
.39691 .46599 L
.38114 .47314 L
.37317 .47588 L
.36455 .47818 L
.36064 .479 L
.35651 .4797 L
.35301 .48017 L
.34919 .48055 L
.34553 .48077 L
.34221 .48086 L
.33842 .48082 L
.33487 .48065 L
.33164 .48037 L
.32868 .48002 L
.32547 .47953 L
.3221 .47888 L
.31452 .47691 L
.30783 .47456 L
.3008 .4714 L
.29375 .46745 L
.28282 .45956 L
.27215 .44935 L
.26383 .43915 L
.25612 .42733 L
.24526 .40453 L
.24091 .39167 L
.23781 .37974 L
.23644 .37301 L
.2354 .36674 L
.23456 .36027 L
.23421 .35686 L
.23391 .35322 L
.23373 .35027 L
.2336 .34755 L
.23352 .34458 L
.23349 .34293 L
.23348 .34144 L
.23349 .33988 L
.23351 .33845 L
.23354 .33688 L
.2336 .33523 L
.23373 .33249 L
.23392 .3295 L
.23415 .32679 L
.2344 .32435 L
.23511 .31894 L
.23593 .31406 L
Mistroke
.23687 .30953 L
.23949 .29986 L
.24248 .29162 L
.24665 .28273 L
.25127 .275 L
.26113 .26278 L
.26759 .2568 L
.27409 .25188 L
.28135 .2474 L
.28974 .24328 L
.29822 .24003 L
.30641 .23762 L
.31127 .23649 L
.31657 .23548 L
.32254 .23461 L
.32525 .2343 L
.32821 .23402 L
.33101 .23381 L
.3336 .23367 L
.33609 .23357 L
.33875 .2335 L
.34169 .23348 L
.34445 .23351 L
.34605 .23355 L
.34751 .2336 L
.3508 .23376 L
.35359 .23394 L
.35622 .23415 L
.36226 .23479 L
.3682 .23562 L
.37464 .23675 L
.38638 .23943 L
.39711 .24262 L
.40949 .24726 L
.42263 .2535 L
.43442 .26053 L
.44481 .26822 L
.45429 .27694 L
.46202 .28589 L
.46931 .29688 L
.47251 .30309 L
.47537 .30994 L
.47748 .31643 L
.47843 .3201 L
.47919 .32364 L
.47978 .32698 L
.48027 .33067 L
.48059 .33407 L
.48078 .33725 L
.48086 .34106 L
Mistroke
.4808 .34468 L
.48071 .34677 L
.48058 .34868 L
.48039 .35091 L
.48017 .35304 L
.47958 .35729 L
.47887 .36127 L
.4767 .37038 L
.47407 .37862 L
.4711 .3862 L
.46249 .40315 L
.45288 .41759 L
.44091 .43194 L
.4167 .45354 L
.40163 .46338 L
.38713 .4707 L
.37955 .47374 L
.37152 .47638 L
.36734 .47751 L
.36275 .47857 L
.35856 .47937 L
.35475 .47995 L
.35112 .48037 L
.34734 .48068 L
.34358 .48084 L
.34147 .48086 L
.33952 .48085 L
.336 .48072 L
.33284 .48049 L
.32924 .4801 L
.32589 .4796 L
.31975 .47835 L
.31347 .47658 L
.30276 .47235 L
.29209 .4664 L
.28143 .45839 L
.27162 .44877 L
.26344 .43861 L
.25096 .41765 L
.24555 .40526 L
.24148 .39357 L
.23802 .38068 L
.23663 .37403 L
.23545 .36707 L
.23463 .36093 L
.23429 .35771 L
.23399 .35429 L
.23378 .35116 L
.23363 .34833 L
.23354 .34551 L
Mistroke
.23349 .34287 L
.23348 .34141 L
.23349 .33981 L
.23351 .33816 L
.23355 .33661 L
.23365 .33387 L
.23373 .33234 L
.23382 .33095 L
.23405 .32787 L
.23438 .32454 L
.23516 .31861 L
.2361 .31318 L
.23713 .3084 L
.24006 .29814 L
.24349 .28925 L
.24736 .28142 L
.25728 .26702 L
.26323 .26069 L
.2705 .25448 L
.2773 .24978 L
.28519 .24539 L
.29259 .24209 L
.30094 .23916 L
.30571 .2378 L
.31114 .23652 L
.31629 .23553 L
.32113 .23479 L
.32695 .23413 L
.33007 .23388 L
.33167 .23377 L
.33339 .23368 L
.33493 .23361 L
.33633 .23356 L
.33909 .2335 L
.34064 .23349 L
.34234 .23349 L
.34395 .23351 L
.34544 .23354 L
.34811 .23363 L
.35099 .23377 L
.35374 .23395 L
.35626 .23415 L
.36248 .23482 L
.36846 .23566 L
.38046 .23797 L
.39364 .2415 L
.40657 .24606 L
.41851 .25138 L
.43955 .26412 L
.45021 .27294 L
Mistroke
.45899 .28213 L
.46725 .29343 L
.47102 .30006 L
.47409 .30667 L
.47633 .31271 L
.47829 .31952 L
.47898 .3226 L
.4796 .32592 L
.48008 .32908 L
.48041 .33201 L
.48069 .33545 L
.48084 .33919 L
.48086 .34253 L
.48075 .34608 L
.48047 .35003 L
.48008 .35373 L
.47949 .35783 L
.47868 .36224 L
.47692 .36958 L
.47444 .37759 L
.46841 .39211 L
.46075 .40603 L
.45225 .41843 L
.44126 .43156 L
.42803 .44444 L
.41565 .4543 L
.40147 .46348 L
.39262 .46817 L
.38434 .47188 L
.37656 .47479 L
.36798 .47735 L
.36432 .47823 L
.36039 .47904 L
.35701 .47962 L
.35334 .48013 L
.34945 .48052 L
.34735 .48068 L
.3454 .48078 L
.34193 .48086 L
.33826 .48082 L
.33472 .48064 L
.33273 .48048 L
.33087 .48029 L
.32718 .47981 L
.32328 .47912 L
.3164 .47747 L
.31033 .47551 L
.30356 .47273 L
.29653 .46911 L
.2847 .4611 L
Mistroke
.27482 .45218 L
.26554 .44144 L
.25205 .41984 L
.24628 .4071 L
.24198 .39514 L
.23832 .38193 L
.23686 .37521 L
.2356 .36806 L
.23474 .36183 L
.23415 .35621 L
.23393 .35353 L
.23375 .35063 L
.23362 .34791 L
.23354 .34542 L
.23349 .34255 L
.23349 .33989 L
.23354 .33699 L
.23359 .33537 L
.23365 .3339 L
.23381 .33112 L
.23403 .32811 L
.23466 .32217 L
.23543 .3169 L
.23648 .31133 L
.23894 .30166 L
.24201 .2928 L
.24542 .28513 L
.2552 .26957 L
.26118 .26273 L
.26855 .25601 L
.2761 .25055 L
.2839 .24604 L
.29152 .24252 L
.30017 .23939 L
.30533 .2379 L
.31014 .23674 L
.31517 .23573 L
.31991 .23496 L
.32561 .23427 L
.32866 .23399 L
.33192 .23376 L
.33479 .23361 L
.3375 .23353 L
.33906 .2335 L
.34049 .23349 L
.34215 .23349 L
.34373 .2335 L
.34635 .23356 L
.3492 .23367 L
.3519 .23382 L
Mistroke
.35439 .234 L
.36054 .23459 L
.36645 .23535 L
.37833 .2375 L
.39141 .24083 L
.40267 .24457 L
.41452 .24947 L
.43485 .26082 L
.4461 .26929 L
.4555 .27822 L
.46449 .28926 L
.46845 .2954 L
.47215 .30234 L
.47492 .30875 L
.47701 .31483 L
.47867 .32116 L
.47928 .32409 L
.47983 .32736 L
.4803 .33093 L
.4805 .3329 L
.48064 .33477 L
.48081 .33815 L
.48086 .34183 L
.48083 .34379 L
.48075 .34595 L
.48062 .34823 L
.48045 .35036 L
.48002 .3542 L
.47941 .35834 L
.47777 .36629 L
.47537 .37478 L
.46938 .39007 L
.4606 .40628 L
.44841 .42333 L
.43606 .43696 L
.42128 .45005 L
.40639 .46053 L
.39203 .46845 L
.38162 .47296 L
.37052 .47666 L
.36421 .47826 L
.35832 .47941 L
.35308 .48016 L
.35016 .48046 L
.34749 .48067 L
.34512 .48079 L
.3426 .48085 L
.34024 .48086 L
.33811 .48081 L
.33562 .4807 L
Mistroke
.33295 .4805 L
.33045 .48024 L
.32816 .47995 L
.32366 .4792 L
.31881 .47811 L
.30937 .47515 L
Mfstroke
.59524 .59524 m
.54884 .6373 L
.5038 .6707 L
.45455 .69932 L
.4278 .7113 L
.40429 .71957 L
.39268 .72282 L
.38066 .72557 L
.37065 .72736 L
.3599 .72873 L
.34871 .72953 L
.34258 .72968 L
.33708 .72964 L
.32667 .72906 L
.31713 .72793 L
.30859 .7264 L
.29981 .72428 L
.28482 .71925 L
.26833 .71144 L
.25457 .7028 L
.24066 .69177 L
.22733 .67867 L
.20664 .65226 L
.18841 .62088 L
.17244 .58449 L
.16147 .55242 L
.15214 .51826 L
.14571 .48904 L
.14039 .45902 L
.13628 .4292 L
.13359 .40302 L
.13252 .38911 L
.13176 .37646 L
.13145 .36987 L
.1312 .36305 L
.13109 .35953 L
.131 .35572 L
.13093 .35229 L
.13088 .34913 L
.13084 .34348 L
.13083 .34034 L
.13084 .33747 L
.1309 .33227 L
.13101 .32685 L
.13114 .32209 L
.1313 .3177 L
.1318 .30798 L
.13252 .29787 L
.13334 .28898 L
.13578 .27016 L
Mistroke
.13861 .25476 L
.14231 .23965 L
.14646 .22656 L
.15077 .21563 L
.15658 .20378 L
.16376 .1922 L
.17137 .18242 L
.1793 .1742 L
.19735 .16035 L
.20835 .15418 L
.22131 .14842 L
.23634 .14327 L
.25197 .13922 L
.26726 .13625 L
.27575 .13495 L
.28528 .13374 L
.29457 .1328 L
.30341 .13209 L
.31216 .13156 L
.31666 .13135 L
.32167 .13116 L
.32459 .13106 L
.32738 .13099 L
.33266 .13089 L
.33566 .13086 L
.33845 .13084 L
.34154 .13083 L
.34484 .13084 L
.3504 .1309 L
.35568 .13099 L
.36156 .13115 L
.36798 .13138 L
.38111 .13202 L
.39592 .13302 L
.42421 .1357 L
.45332 .13952 L
.48154 .14427 L
.50955 .15008 L
.54053 .15797 L
.59718 .17751 L
.62906 .19268 L
.66053 .21245 L
.68452 .23295 L
.69649 .24624 L
.70633 .2598 L
.71511 .27541 L
.72157 .29106 L
.72425 .29973 L
.72662 .30966 L
.72756 .31481 L
Mistroke
.72839 .32047 L
.72899 .32592 L
.72938 .33099 L
.72969 .34112 L
.72943 .35082 L
.72853 .36178 L
.72774 .36806 L
.72684 .37383 L
.72473 .38465 L
.72178 .39665 L
.71461 .41911 L
.69315 .46648 L
.66072 .51827 L
.58251 .60763 L
.53202 .65058 L
.48479 .68273 L
.45893 .69712 L
.43146 .70982 L
.4064 .71892 L
.39558 .72207 L
.38418 .72484 L
.37389 .72683 L
.36468 .72819 L
.35608 .72908 L
.34724 .72959 L
.33779 .72965 L
.32925 .72926 L
.32016 .72835 L
.31078 .72684 L
.30199 .72486 L
.29283 .72217 L
.27715 .71594 L
.26301 .70834 L
.25094 .70016 L
.2277 .67908 L
.20684 .65256 L
.19052 .625 L
.17808 .59853 L
.16609 .56679 L
.15566 .53212 L
.14846 .50226 L
.14236 .47096 L
.13767 .44027 L
.1345 .41284 L
.13337 .40036 L
.13242 .38756 L
.13179 .37695 L
.13129 .36564 L
.13108 .35899 L
.131 .35577 L
Mistroke
.13094 .35283 L
.13086 .34738 L
.13083 .34157 L
.13086 .33588 L
.13089 .3327 L
.13094 .32974 L
.13101 .32666 L
.13109 .32387 L
.1313 .31769 L
.13154 .31249 L
.13181 .30774 L
.13256 .2973 L
.1334 .28845 L
.13446 .27936 L
.13728 .26143 L
.14056 .24626 L
.14493 .23101 L
.15045 .21638 L
.16188 .19497 L
.16965 .18446 L
.1778 .17563 L
.18669 .16784 L
.19742 .16031 L
.20786 .15443 L
.22002 .14893 L
.23193 .14463 L
.24624 .14057 L
.26035 .13748 L
.27462 .13511 L
.29128 .13311 L
.30128 .13225 L
.31095 .13162 L
.31637 .13136 L
.32159 .13116 L
.32636 .13102 L
.33162 .13091 L
.33439 .13087 L
.33746 .13084 L
.3407 .13083 L
.34377 .13084 L
.34932 .13088 L
.35248 .13093 L
.3554 .13099 L
.3607 .13112 L
.36643 .13132 L
.37697 .13179 L
.38989 .13257 L
.40195 .1335 L
.42672 .13599 L
.45116 .1392 L
Mistroke
.50931 .15003 L
.53989 .15779 L
.57384 .16852 L
.60267 .17986 L
.63263 .19463 L
.65922 .21149 L
.6812 .2297 L
.70244 .25407 L
.71127 .26802 L
.71567 .27659 L
.71924 .28478 L
.72438 .30021 L
.72643 .30875 L
.72807 .31806 L
.72904 .32648 L
.72956 .33453 L
.72967 .34362 L
.72926 .35361 L
.72878 .35942 L
.72807 .36566 L
.72626 .3771 L
.72355 .38977 L
.71963 .40409 L
.71014 .43067 L
.69839 .45641 L
.66931 .50587 L
.62885 .55893 L
.58301 .60715 L
.52977 .65229 L
.50129 .67235 L
.46993 .69128 L
.44164 .70543 L
.41645 .71556 L
.39333 .72266 L
.38208 .72528 L
.37007 .72744 L
.36389 .72829 L
.35834 .72888 L
.35205 .72936 L
.34621 .72962 L
.33606 .72961 L
.33048 .72935 L
.32542 .72894 L
.31657 .72784 L
.30855 .72639 L
.30004 .72434 L
.29122 .72162 L
.27432 .71457 L
.26008 .70651 L
.23501 .68655 L
Mistroke
.22276 .67353 L
.21266 .66082 L
.19529 .63381 L
.18196 .60738 L
.16909 .57544 L
.15799 .54058 L
.15029 .51043 L
.14379 .47896 L
.13892 .44929 L
.13561 .42343 L
.13436 .41141 L
.13323 .39869 L
.13239 .38708 L
.13176 .37647 L
.13125 .36457 L
.13106 .3584 L
.13098 .35498 L
.13092 .35187 L
.13085 .34605 L
.13084 .34279 L
.13084 .3398 L
.13085 .33665 L
.13088 .33382 L
.13093 .33059 L
.13099 .32757 L
.13113 .32253 L
.13132 .31728 L
.13179 .30812 L
.13245 .29861 L
.13339 .28855 L
.13575 .27032 L
.13869 .25438 L
.14189 .24115 L
.14601 .22784 L
.15122 .21462 L
.15764 .20188 L
.17164 .18212 L
.18051 .17308 L
.18956 .16565 L
.20035 .15853 L
.21348 .15173 L
.22615 .1466 L
.23902 .14249 L
.2538 .13881 L
.26199 .13718 L
.27106 .13564 L
.27972 .13442 L
.28967 .13327 L
.2991 .13242 L
.30828 .13178 L
Mistroke
.31397 .13147 L
.3195 .13123 L
.32455 .13107 L
.32744 .13099 L
.33018 .13093 L
.33342 .13088 L
.33638 .13085 L
.33961 .13084 L
.34314 .13084 L
.34627 .13085 L
.34961 .13089 L
.35249 .13093 L
.35568 .13099 L
.36196 .13116 L
.36802 .13138 L
.37965 .13193 L
.39256 .13276 L
.40708 .13395 L
.43438 .13691 L
.46092 .14069 L
.48825 .14555 L
.51872 .15225 L
.5753 .16904 L
.60788 .18218 L
.64088 .19941 L
.66699 .21737 L
.67957 .22816 L
.6921 .24103 L
.70107 .25217 L
.70847 .26321 L
.71454 .27425 L
.72017 .28719 L
.72419 .29951 L
.72701 .31168 L
.72815 .31865 L
.72892 .32519 L
.72949 .33293 L
.72969 .34048 L
.72952 .34892 L
.72902 .35675 L
.72802 .366 L
.72665 .37492 L
.72317 .3913 L
.71788 .40965 L
.71016 .43063 L
.69987 .45344 L
.67615 .49541 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  ImageSize->{218, 218},
  ImageMargins->{{1, 0}, {0, 20}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003J0000fR000`400?l00000o`00003of_ooool0
0=[ooooo003Jooooo`00f_ooool00=[ooooo003Jooooo`00;Oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0001Oooooo0ol0000Gooooo`?o00001?ooool00ol0003oooooooooo`02oooo
o`?o00005_ooool5o`0001Gooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Goooo
o`?o00001Oooool002cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`05o`000?oooooo
ooooooooool000005_ooool01?l0003oooooooooool0000Fooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`00000Eooooo`05o`000?ooooooooooooooool000001?ooool0
02cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00;ooooo000/ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool2
o`0000Gooooo000/ooooo`04o`000?ooooooooooo`0000Oooooo1?l0000Hooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01oooool4o`0001Kooooo00Go0000ooooooooooooooooo`00
000Eooooo`05o`000?ooooooooooooooool000001oooool4o`0001[ooooo00?o0000ooooooooool0
0_ooool002cooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Hooooo`;o0000
6?ooool2o`0000Wooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000001Go
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`005?ooool00ol0003oooooooooo`0Fooooo`;o00002?ooool5o`00
01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`Go00005_ooool3o`00
01Oooooo0ol00008ooooo`Go00005_ooool3o`0000Gooooo000Dooooo`03o`000?oooooooooo0<?o
oooo000Dooooo`03o`000?oooooooooo0<?ooooo000Dooooo`03o`000?oooooooooo0<?ooooo000D
ooooo`03o`000?oooooooooo00Kooooo0ol0000:ooooo`?o00002_ooool3o`0000_ooooo0ol0000:
ooooo`?o00002_ooool3o`0000[ooooo0ol0000:ooooo`?o00002_ooool3o`0000[ooooo0ol0000:
ooooo`Co00002_ooool3o`0000[ooooo0ol0000:ooooo`?o00003oooool000oooooobol0000001Co
oooo00?o0000ooooooooool01_ooool2o`0000_ooooo0_l00008ooooo`03o`000?oooooooooo00;o
00003?ooool2o`0000[ooooo1?l0000:ooooo`;o00002oooool2o`0000Kooooo00?o0000oooooooo
ool00_ooool2o`0000_ooooo0_l0000;ooooo`;o00002oooool3o`0000_ooooo0_l00004ooooo`03
o`000?oooooooooo00Cooooo0_l0000;ooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`00
5?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Gooooo000Dooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0Q?ooool001Cooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`24ooooo`005?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
08?ooooo000Dooooo`;o0000?_ooool00ol0003oooooooooo`23ooooo`005?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo08?ooooo000Dooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0Poooool001Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`23
ooooo`005?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08?ooooo000Dooooo`03
o`000?oooooooooo02gooooo0ol0000:ooooo`Co00002Oooool3o`0000_ooooo0ol0000:ooooo`;o
00002oooool2o`0000_ooooo0_l0000;ooooo`;o00002oooool2o`0000_ooooo0_l0000;ooooo`;o
00004Oooool001Cooooo0_l0000:ooooo`;o00002?ooool5o`0000Sooooo1Ol00008ooooo`Go0000
2?ooool5o`0000Sooooo1Ol00009ooooo`Co00002Oooool4o`0000Wooooo1?l00009ooooo`Co0000
2Oooool4o`0000Wooooo1?l00009ooooo`Co00002Oooool4o`0000oooooo000Dooooo`03o`000?oo
oooooooo00Oooooo1?l00008ooooo`?o00002_ooool3o`0000[ooooo0_l0000;ooooo`;o000000?o
ooooo`000?ooool02?ooool2o`0000_ooooo0_l0000;ooooo`Ko00001oooool6o`0000Sooooo1Ol0
0008ooooo`Go00002?ooool5o`0000Sooooo1Ol00008ooooo`Go00003_ooool001Cooooo00?o0000
ooooooooool01_ooool4o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo08?ooooo000Cooooo`?o00002Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo08?ooooo000Cooooo`?o0000;?oooolXo`3o073ooooo000Dooooo`03o`00
0?oooooooooo02Oooooo1ol0o`0?ooooo`03o`000?oooooooooo013ooooo3Ol0o`1Vooooo`005?oo
ool00ol0003oooooooooo`0Rooooo`Ko0?l05Oooool00ol0003oooooooooo`0Mooooo`So0?l0G_oo
ool001Cooooo0_l0000Pooooo`Go0?l06Oooool00ol0003oooooooooo`0Sooooo`Ko0?l0F_ooool0
01Cooooo00?o0000ooooooooool07Oooool2o`3o01kooooo00?o0000ooooooooool0:?ooool6o`3o
05Gooooo000Dooooo`03o`000?oooooooooo01_ooooo0_l0o`0FoooooaWo0?l08?ooool7o`3o053o
oooo000Dooooo`03o`000?oooooooooo01[ooooo0_l0o`0@ooooo`So0?l02Oooool00ol0003ooooo
ooooo`09ooooo`_o0?l07?ooool6o`3o04gooooo000Dooooo`03o`000?oooooooooo01Wooooo0_l0
o`0<ooooo`Ko0?l04?ooool00ol0003oooooooooo`0Booooo`Oo0?l07?ooool4o`3o04[ooooo000D
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool2o`3o00cooooo1Ol0o`0@
ooooo`Co00002Oooool3o`0000[ooooo0ol00008o`3o00;ooooo0_l0000;ooooo`;o00002Oooool5
o`3o00[ooooo0_l0000<ooooo`;o00002oooool2o`0000_ooooo0_l0000Aooooo`005?ooool2o`00
00_ooooo00?o0000ooooooooool02Oooool2o`3o00[ooooo00?o0000o`3o0?l0o`000_l0o`06oooo
o`Go00002?ooool5o`0000Sooooo1Ol00008ooooo`Go00001?ooool6o`3o00;o00002Oooool4o`00
00Wooooo00?o0000o`3o0?l0o`000ol0o`07ooooo`Co00002_ooool3o`0000[ooooo0ol0000:oooo
o`?o00004?ooool001Cooooo00?o0000ooooooooool02Oooool2o`0000Wooooo0_l000000ol0o`3o
0000ooooo`07ooooo`04o`000?l0o`3o0?l0o`3o00Wooooo0ol0000:ooooo`;o000000?oooooo`00
0?ooool02?ooool2o`0000_ooooo0_l0000;ooooo`03o`000?l0o`3o0?l000?o0?l01oooool5o`00
00Sooooo1?l00005o`3o00Cooooo1Ol00008ooooo`Go00002?ooool5o`0000Sooooo1Ol0000?oooo
o`004oooool3o`0000[ooooo00?o0000ooooooooool01oooool2o`000003o`3o0?l0003ooooo00Oo
oooo0ol0o`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool5o`3o01Oo
oooo1Ol0o`0mooooo`004oooool3o`0000Wooooo0_l0000:ooooo`03o`3o0?l0003ooooo00Oooooo
0_l0o`0Mooooo`03o`000?oooooooooo02Sooooo1?l0o`0Hooooo`Co0?l0>oooool000;ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0o`3oooooooooo`07ooooo`;o0?l07_ooool00ol0003ooooooooo
o`0/ooooo`?o0?l06?ooool3o`3o03Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01?ooooo00?o0?l0ooooooooool0
1_ooool2o`3o01Gooooo6Ol0o`0Sooooo`?o0?l05oooool3o`3o03Oooooo00001Ooooooo0000oooo
oooooooo000000_ooooo00Co0000oooooooooooooooo0_l0000Cooooo`03o`3o0?oooooooooo00Ko
oooo00?o0?l0ooooooooool04?ooool6o`3o00Wooooo00?o0000ooooooooool02?ooool8o`3o02;o
oooo0ol0o`0Fooooo`?o0?l0=Oooool00005ooooool0003oooooooooool000002oooool01Ol0003o
oooooooooooooooo000001Cooooo00?o0?l0ooooooooool01Oooool2o`3o013ooooo0_l0o`0?oooo
o`03o`000?oooooooooo00gooooo1_l0o`0Qooooo`;o0?l05oooool3o`3o03?ooooo00001Ooooooo
0000oooooooooooo000000Oooooo1?l00004ooooo`03o`000?oooooooooo017ooooo00?o0?l0oooo
ooooool01Oooool2o`3o00kooooo0ol0o`0Aooooo`03o`000?oooooooooo017ooooo1Ol0o`0Ooooo
o`?o0?l06?ooool2o`3o037ooooo00001Ooooooo0000oooooooooooo000000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0oooo
ooooool02oooool3o`3o01?ooooo00?o0000ooooooooool05_ooool3o`3o01kooooo0ol0o`0Goooo
o`;o0?l0<?ooool000;ooooo0_l00008ooooo`Go00000oooool00ol0003oooooooooo`0@ooooo`;o
0?l01_ooool2o`3o00cooooo0_l0o`0Eooooo`03o`000?oooooooooo01Sooooo1?l0o`0Mooooo`?o
0?l05_ooool2o`3o02oooooo000Dooooo`03o`000?oooooooooo013ooooo00?o0?l0ooooooooool0
1Oooool00ol0o`3oooooooooo`0:ooooo`;o0?l05_ooool00ol0003oooooooooo`07ooooo`;o0000
2oooool2o`0000Gooooo1?l0o`02ooooo`;o00002oooool2o`0000_ooooo0_l0o`0;ooooo`;o0000
2Oooool3o`3o0003o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0@ooooo`005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o
0?l0ooooooooool01?ooool2o`3o00[ooooo00?o0000o`3o0?ooool05?ooool4o`0000Wooooo1?l0
0009ooooo`?o00001oooool3o`3o00?o00002Oooool3o`0000[ooooo0ol000000ol0o`3ooooooooo
o`07ooooo`?o00002oooool2o`3o00_ooooo0_l0000;ooooo`;o00004_ooool001Cooooo0_l0000;
ooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool01?ooool00ol0o`3oooooooooo`08
ooooo`03o`000?l0o`3o0?l000Sooooo1Ol00008ooooo`Go00001oooool6o`0000Oooooo1Ol00008
ooooo`;o0?l000?oooooo`000?l000002_ooool2o`0000_ooooo0_l000000ol0o`3oooooooooo`08
ooooo`;o00002Oooool2o`0000;o0?l02Oooool4o`0000Wooooo1?l0000Aooooo`005?ooool00ol0
003oooooooooo`09ooooo`;o00001Oooool00ol0o`3oooooooooo`03ooooo`03o`000?l0o`3ooooo
00Sooooo00?o0000o`3o0?l0o`002Oooool3o`0000[ooooo0_l000000ooooooo0000ooooo`0Soooo
o`;o0?l03Oooool00ol0003oooooooooo`0:ooooo`03o`000?l0o`3ooooo00[ooooo00?o0000oooo
ooooool02Oooool2o`3o00[ooooo0_l0000;ooooo`;o00004Oooool001?ooooo0ol0000:ooooo`;o
00001Oooool00ol0o`3oooooooooo`02ooooo`03o`000?l0o`3ooooo00Sooooo00Co0000o`3o0?l0
o`3o00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo0_l0o`0Joooo
o`03o`3o0?oooooooooo01Gooooo0_l0o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03_ooool001?ooooo0ol00009ooooo`?o00001?ooool00ol0o`3oooooooooo`02ooooo`03
o`000?l0o`3o0?l000[ooooo00?o0?l0o`000?ooool06Oooool00ol0003oooooooooo`0Uooooo`;o
0?l06_ooool2o`3o01Kooooo00?o0?l0ooooooooool09oooool001Cooooo00?o0000ooooooooool0
3oooool00ol0o`3oooooooooo`03ooooo`;o0?l02Oooool2o`3o01Gooooo3ol0o`0Pooooo`;o0?l0
6_ooool2o`3o01Kooooo00?o0?l0ooooooooool09_ooool001Cooooo00?o0000ooooooooool03ooo
ool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool04?oo
ool4o`3o00Kooooo00?o0000ooooooooool01?ooool6o`3o01gooooo0_l0o`0Jooooo`;o0?l05Ooo
ool2o`3o02Oooooo000Dooooo`;o00003oooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooo
oooo00Oooooo00?o0?l0ooooooooool03oooool3o`3o00Wooooo00?o0000ooooooooool02?ooool4
o`3o01cooooo0_l0o`0Jooooo`03o`3o0?oooooooooo01Cooooo0_l0o`0Vooooo`005?ooool00ol0
003oooooooooo`0>ooooo`03o`3o0?oooooooooo00?ooooo0_l0o`09ooooo`03o`3o0?oooooooooo
00gooooo0ol0o`0;ooooo`03o`000?oooooooooo00cooooo0_l0o`0Kooooo`03o`3o0?oooooooooo
01Sooooo0_l0o`0Fooooo`03o`3o0?oooooooooo02Cooooo000Dooooo`03o`000?oooooooooo00ko
oooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`07ooooo`;o0?l03_ooool2o`3o00go
oooo00?o0000ooooooooool03Oooool3o`3o01[ooooo00?o0?l0ooooooooool06?ooool2o`3o01Go
oooo0_l0o`0Uooooo`005?ooool00ol0003oooooooooo`0>ooooo`03o`3o0?oooooooooo00?ooooo
00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0<ooooo`;o0?l03_ooool00ol0003ooooo
ooooo`0@ooooo`03o`3o0?oooooooooo01Sooooo00?o0?l0ooooooooool06?ooool00ol0o`3ooooo
ooooo`0Dooooo`;o0?l09?ooool001Cooooo00?o0000ooooooooool03_ooool00ol0o`3ooooooooo
o`03ooooo`03o`3o0?oooooooooo00Kooooo0_l0o`0=ooooo`;o0?l03oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00Go0?l0ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo00Oooooo00?o0?l0ooooooooool00_l0000;ooooo`;o00002?ooool2o`3o0003oooo
ool0003o000001?ooooo00?o0?l0ooooooooool08_ooool001Cooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo0?l000Gooooo00?o0?l0ooooooooool01_ooool00ol0o`3ooooo
ooooo`0<ooooo`03o`3o0?oooooooooo00kooooo00?o0000ooooooooool01oooool2o`0000Wooooo
0_l0o`02o`0000_ooooo0_l00009ooooo`;o0?l00ol0000:ooooo`?o00002Oooool01?l0o`3o0000
o`000?l0000:ooooo`;o00001oooool2o`3o00?ooooo00?o0000ooooooooool02Oooool2o`0001;o
oooo000Dooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`3o0004ooooo`;o
0?l00_ooool00ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool2o`3o00?ooooo00?o0000ooooooooool01_ooool3o`000003ooooool0003ooooo00Oo
oooo1?l00009ooooo`;o0?l000?oooooo`000?ooool02oooool00ol0003oooooooooo`07ooooo`;o
0?l00_l0000;ooooo`;o00002_ooool00ol0o`3o0000o`00000:ooooo`;o00002?ooool00ol0o`3o
ooooooooo`02o`0000[ooooo0ol0000Booooo`005?ooool2o`0000_ooooo00?o0000ooooooooool0
0_l0o`04ooooo`;o0?l00_ooool00ol0003oooooooooo`02ooooo`;o0?l01Oooool2o`0000Gooooo
0_l0o`03ooooo`;o00002?ooool5o`0000_ooooo0_l00009ooooo`04o`3o0?oooooo0000o`0000_o
oooo0_l00009ooooo`04o`3o0?oooooo0000o`0000_ooooo0_l00009ooooo`03o`3o0?l0003o0000
00_ooooo00?o0000ooooooooool01_ooool2o`3o0003ooooool0003o000000_ooooo0_l0000Boooo
o`004oooool3o`0000[ooooo0ol000000ooooooo0?l0o`3o0004ooooo`03o`3o0?oooooooooo00;o
00001?ooool2o`3o00Cooooo0ol00005ooooo`04o`3o0?ooooooooooooooo`?o00002?ooool2o`00
00;ooooo00?o0000ooooooooool05Oooool00ol0o`3oooooooooo`0Fooooo`;o0?l000?oooooo`00
0?ooool02oooool00ol0003oooooooooo`08ooooo`03o`3o0?l0003ooooo00[ooooo0_l00008oooo
o`03o`3o0?oooooooooo00;o00002oooool2o`00017ooooo000Cooooo`?o00002_ooool3o`000003
ooooool0o`3ooooo00Cooooo00?o0?l0ooooooooool00_l00004ooooo`03o`3o0?oooooooooo00;o
oooo0ol00005ooooo`;o0?l00_ooool3o`0000gooooo00?o0000ooooooooool05Oooool2o`3o01So
oooo00?o0?l0ooooooooool05oooool00ol0o`3oooooooooo`0;ooooo`03o`000?oooooooooo00Ko
oooo00Go0?l0ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00oooooo000Dooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooool0o`001Oooool00ol0o`3oooooo`000002o`0000Co
oooo00?o0?l0ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`;o0?l05oooool2o`3o01So
oooo0_l0o`0Eooooo`;o0?l08Oooool001Cooooo00?o0000ooooooooool03Oooool00ol0o`3ooooo
ooooo`03ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool02Oooool2o`3o01?ooooo
00?o0000ooooooooool05oooool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oooooooooo01Oooooo
00?o0?l0ooooooooool05?ooool00ol0o`3oooooooooo`0Oooooo`005?ooool00ol0003ooooooooo
o`0=ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool01_ooool00ol0o`3ooooooooo
o`09ooooo`;o0?l04oooool00ol0003oooooooooo`0Gooooo`;o0?l05oooool00ol0o`3ooooooooo
o`0Gooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0ooooooooool07oooool001Cooooo0_l0000>
ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`09
ooooo`03o`3o0?oooooooooo01;ooooo00?o0000ooooooooool06?ooool00ol0o`3oooooooooo`0E
ooooo`;o0?l06?ooool2o`3o01Gooooo00?o0?l0ooooooooool07oooool001Cooooo00?o0000oooo
ooooool03Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0oooo
ooooool02Oooool00ol0o`3oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0?l0oooo
ooooool05_ooool00ol0o`3oooooooooo`0Fooooo`;o0?l05Oooool00ol0o`3oooooooooo`0Ooooo
o`005?ooool00ol0003oooooooooo`0=ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0oooooooo
ool01Oooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo01;ooooo00?o0000oooooooo
ool06?ooool2o`3o01Oooooo00?o0?l0ooooooooool05oooool00ol0o`3oooooooooo`0Dooooo`03
o`3o0?oooooooooo01kooooo000Dooooo`;o00003_ooool00ol0o`3oooooooooo`03ooooo`03o`3o
0?oooooooooo00Gooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`0Cooooo`03o`00
0?oooooooooo00Wooooo0ol00009ooooo`?o000000?oooooo`3o0?ooool01oooool3o`0000cooooo
00?o0?l0ooooooooool05oooool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooooooo01kooooo
000=ooooo`?o00001?ooool01?l0003oooooo`000?l0000<ooooo`03o`3o0?oooooooooo00?ooooo
00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo017ooooo
1?l0000:ooooo`?o00002Oooool3o`000003ooooool0o`3ooooo00Oooooo0ol0000:ooooo`;o0000
00?o0?l0ooooooooool02?ooool3o`0000cooooo00?o0?l0ooooooooool05?ooool00ol0o`3ooooo
ooooo`0Nooooo`003_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
2?ooool01?l0003oooooooooool0o`05ooooo`05o`3o0?ooooooooooooooool000000oooool00ol0
o`3oooooooooo`09ooooo`03o`3o0?oooooooooo013ooooo1_l00009ooooo`?o00002Oooool3o`00
0003ooooool0o`3ooooo00Oooooo0ol0000:ooooo`;o000000?o0?l0ooooooooool02?ooool3o`00
00[ooooo0_l000000ol0o`3oooooooooo`07ooooo`?o00002_ooool00ol0o`3o0000o`00000Noooo
o`003_ooool00ol0003oooooooooo`03ooooo`;o00000oooool;o`000003o`3o0?l0003o000000?o
000000?o0?l0o`000?l000001Ol000000ol0o`3o0000o`000009o`000003o`3o0?l0003o000002oo
000000?o0?l0o`000?l000005Ol000000ol0o`3o0000o`00000Go`000003o`3o0?l0003o000001Co
000000?o0?l0o`000?l000006Ol00005ooooo`003_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00Co0000oooooooooooo0?l01Oooool01Ol0o`3ooooooooooooooooo0000
00?ooooo00?o0?l0ooooooooool01Oooool01Ol0003ooooooooooooooooo0?l000Sooooo00?o0000
ooooooooool01oooool6o`0000[ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000o`3o0?ooool02_ooool00ol0003ooooooooo
o`09ooooo`;o000000?o0?l0ooooooooool01oooool3o`0000[ooooo00?o0?l0o`000?l000002_oo
ool3o`00017ooooo000>ooooo`03o`000?oooooooooo00;ooooo0ol0000:ooooo`?o000000?ooooo
o`3o0?ooool01?ooool00ol0o`3oooooooooo`03o`0000;ooooo00?o0?l0ooooooooool01Oooool0
1Ol0003ooooooooooooooooo0?l000Sooooo00?o0000ooooooooool01oooool6o`0001Wooooo00?o
0?l0ooooooooool05?ooool00ol0003o0?l0ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000o`3o0?ooool02Oooool00ol0003oooooooooo`09ooooo`03o`3o0?l0003ooooo00[ooooo0ol0
000Aooooo`003Oooool2o`0000Cooooo0ol0000:ooooo`?o000000?oooooo`3o0?ooool01?ooool0
0ol0o`3oooooooooo`03o`0000;ooooo00?o0?l0ooooooooool01?ooool3o`0000;ooooo00?o0?l0
ooooooooool01Oooool3o`0000Wooooo1?l0000Jooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0
ooooooooool05_ooool00ol0003o0?l0ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0?l0
o`000?ooool02oooool00ol0003oooooooooo`0@ooooo`003_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00gooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`05oooo
o`03o`3o0?oooooooooo00Cooooo0ol00002ooooo`03o`3o0?oooooooooo00Gooooo0ol0000;oooo
o`03o`000?oooooooooo01Wooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Goooo
o`03o`3o0?oooooooooo01Cooooo00?o0?l0ooooooooool02oooool00ol0003oooooooooo`0@oooo
o`005?ooool00ol0003oooooooooo`0=ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0oooooooo
ool01Oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo01?ooooo00?o0000oooooooo
ool06?ooool2o`3o01Oooooo00?o0?l0ooooooooool05oooool00ol0o`3oooooooooo`0Dooooo`03
o`3o0?oooooooooo01kooooo000Dooooo`03o`000?oooooooooo00gooooo00?o0?l0ooooooooool0
0oooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool0
4_ooool00ol0003oooooooooo`0Hooooo`03o`3o0?oooooooooo01Kooooo00?o0?l0ooooooooool0
5oooool00ol0o`3oooooooooo`0Cooooo`;o0?l08?ooool001Cooooo0_l0000>ooooo`03o`3o0?oo
oooooooo00?ooooo00?o0?l0ooooooooool01Oooool2o`3o00_ooooo00?o0?l0ooooooooool04_oo
ool00ol0003oooooooooo`0Hooooo`03o`3o0?oooooooooo01Kooooo00?o0?l0ooooooooool05_oo
ool2o`3o01Gooooo00?o0?l0ooooooooool07oooool001Cooooo00?o0000ooooooooool03Oooool0
0ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool02Oooool0
0ol0o`3oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0?l0ooooooooool05Oooool2
o`3o01Sooooo0_l0o`0Eooooo`03o`3o0?oooooooooo01oooooo000Dooooo`03o`000?oooooooooo
00gooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo
00Wooooo00?o0?l0ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`;o0?l05oooool2o`3o
01Sooooo00?o0?l0ooooooooool05?ooool00ol0o`3oooooooooo`0Oooooo`005?ooool00ol0003o
ooooooooo`0=ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool01_ooool00ol0o`3o
ooooooooo`09ooooo`;o0?l04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00So
oooo00?o0?l0o`000?ooool02_ooool00ol0003oooooooooo`09ooooo`03o`3o0?oooooooooo01Oo
oooo00?o0?l0ooooooooool05?ooool00ol0o`3oooooooooo`0Oooooo`005?ooool00ol0003ooooo
ooooo`0:ooooo`04o`000?ooooooooooo`3o00Gooooo00?o0?l0ooooooooool01_ooool00ol0o`3o
ooooooooo`0:ooooo`03o`3o0?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`07ooooo`;o0?l00_l0000:ooooo`;o00002Oooool2o`3o0003o`000?oooooooooo00So
oooo0_l0000<ooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0ooooooooool07oooool001Cooooo
00?o0000ooooooooool02_ooool01?l0003oooooooooool0o`05ooooo`04o`3o0?ooooooooooo`00
00Gooooo00?o0?l0ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo
017ooooo00?o0000ooooool000000_l00009ooooo`?o00002?ooool00ol0o`3o0000o`00000;oooo
o`;o00002Oooool2o`3o00;o00002Oooool3o`0000[ooooo0_l0o`000ol0003oooooooooo`08oooo
o`;o00002?ooool2o`3o027ooooo000Dooooo`;o00002oooool01?l0003oooooooooool0o`05oooo
o`03o`3o0?oooooooooo00;o00001?ooool00ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0?l0ooooooooool00oooool00ol0003oooooooooo`0:ooooo`Go00002?ooool2o`00
00Wooooo00?o0?l0o`000?l000002oooool2o`0000[ooooo00?o0?l0o`000?l000002_ooool3o`00
00[ooooo0_l0o`000ol0003oooooooooo`08ooooo`?o00001oooool00ol0o`3oooooo`000002o`00
00[ooooo0ol0000Aooooo`004oooool3o`0000[ooooo0ol000000ooooooo0?l0o`3o0004ooooo`03
o`3o0?oooooooooo00;o00001?ooool2o`3o00Gooooo0_l00005ooooo`03o`3o0?oooooooooo00?o
oooo0_l0000;ooooo`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`09ooooo`03
o`3o0?l0003ooooo00_ooooo00?o0000ooooooooool02?ooool2o`3o0003o`000?oooooooooo00Wo
oooo0_l0000;ooooo`03o`3o0?l0003ooooo00[ooooo0ol00007ooooo`03o`3o0?oooooo000000;o
00002_ooool3o`00017ooooo000Cooooo`?o00002_ooool3o`0000;ooooo00?o0?l0ooooooooool0
0_ooool00ol0o`3oooooooooo`02o`0000Gooooo00?o0?l0ooooooooool00oooool2o`0000Gooooo
0_l0o`04ooooo`?o00002_ooool00ol0003oooooooooo`0Dooooo`03o`3o0?oooooooooo01Oooooo
0_l0o`0<ooooo`03o`000?oooooooooo00Wooooo0_l0o`000ol0003oooooooooo`09ooooo`;o0000
1oooool2o`3o0003ooooool0003o000000_ooooo0_l0000Booooo`005?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool00_ooool2o`3o0004ooooool0
003o0000o`0000Cooooo00?o0?l0ooooooooool00oooool3o`0000Gooooo00?o0?l0ooooooooool0
0oooool3o`0000Wooooo00?o0000ooooooooool04oooool00ol0o`3oooooooooo`0Hooooo`03o`3o
0?oooooooooo01Oooooo00?o0?l0o`000?ooool02oooool00ol0003oooooooooo`06ooooo`03o`3o
0?oooooooooo00;o00002oooool2o`0001;ooooo000Dooooo`03o`000?oooooooooo00kooooo00?o
0?l0ooooooooool00_ooool2o`3o00Sooooo00?o0?l0ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`3o0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Booooo`;o0?l06Oooool00ol0o`3oooooooooo`0Hooooo`03o`3o0?oooooooooo01Cooooo00Co
0?l0oooooooooooo00003?ooool00ol0003oooooooooo`0Aooooo`005?ooool00ol0003ooooooooo
o`0>ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool01_ooool2o`3o00gooooo00?o
0?l0ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`3o0?oooooooooo01Sooooo00?o
0?l0ooooooooool05oooool00ol0o`3oooooooooo`0Dooooo`;o0?l08oooool001Cooooo00?o0000
ooooooooool03_ooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Kooooo0_l0o`0=
ooooo`;o0?l03oooool00ol0003oooooooooo`0@ooooo`;o0?l06_ooool00ol0o`3oooooooooo`0H
ooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0ooooooooool08_ooool001Cooooo0_l0000?oooo
o`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool01_ooool2o`3o00kooooo00?o0?l0oooo
ooooool03Oooool00ol0003oooooooooo`0?ooooo`;o0?l06_ooool2o`3o01Wooooo0_l0o`0Foooo
o`03o`3o0?oooooooooo02;ooooo000Dooooo`03o`000?oooooooooo00kooooo00?o0?l0oooooooo
ool00oooool00ol0o`3oooooooooo`06ooooo`;o0?l03oooool00ol0o`3oooooooooo`0<ooooo`03
o`000?oooooooooo00kooooo0_l0o`0Kooooo`03o`3o0?oooooooooo01Sooooo00?o0?l0oooooooo
ool05?ooool00ol0o`3oooooooooo`0Sooooo`005?ooool00ol0003oooooooooo`0>ooooo`03o`3o
0?oooooooooo00?ooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0>ooooo`03o`3o
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool3o`3o01_ooooo0_l0o`0Jooooo`03o`3o
0?oooooooooo01Cooooo00?o0?l0ooooooooool08oooool001Cooooo00?o0000ooooooooool03_oo
ool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Oooooo0_l0o`0@ooooo`03o`3o0?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool2o`3o00_ooooo00?o0000ooooooooool03ooo
ool00ol0o`3oooooooooo`0Hooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0ooooooooool08ooo
ool001Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0?l000Gooooo0_l0
o`000ol0003oooooooooo`05ooooo`;o0?l04Oooool00ol0o`3oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo0ol0o`000ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0o`3oooooooooo`04ooooo`;o00002_ooool2o`0000Oooooo00?o
0?l0ooooooooool05?ooool00ol0o`3oooooooooo`0Tooooo`005?ooool00ol0003oooooooooo`0:
ooooo`05o`000?ooooooooooooooool0o`001Oooool2o`3o0003o`000?oooooooooo00Kooooo00Go
0?l0ooooooooooooooooo`00000<ooooo`;o00000_l0o`09ooooo`Co00001oooool2o`3o00Co0000
2Oooool3o`0000[ooooo0_l00003ooooo`03o`3o0?oooooooooo00Cooooo0ol00009ooooo`?o0000
1Oooool2o`3o00?ooooo0_l0000:ooooo`;o00001Oooool00ol0o`3oooooooooo`0Tooooo`004ooo
ool3o`0000_ooooo00Co0000oooooooooooooooo0_l0o`05ooooo`03o`3o0?l0003o000000Oooooo
0_l0o`02ooooo`03o`000?oooooooooo00[ooooo0ol00002o`3o00Oooooo1Ol00005ooooo`?o0?l0
0_l0000;ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo00Gooooo
0_l0000:ooooo`;o00001Oooool2o`3o00Cooooo0ol00009ooooo`?o00000oooool2o`3o00Gooooo
0_l0000;ooooo`;o00004_ooool001?ooooo0ol0000:ooooo`?o00000_ooool2o`3o00Gooooo00?o
0?l0o`000?l000002?ooool00ol0o`3oooooooooo`02o`0000cooooo0ol000001?oooooo0?l0o`3o
0?l0o`05ooooo`04o`000?oooooo0000o`0000;ooooo1?l0o`0>ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool2o`3o00Kooooo0_l0000:ooooo`;o00001_ooool2o`3o00Co
oooo0_l0000:ooooo`?o00000oooool00ol0o`3oooooooooo`04ooooo`?o00002_ooool2o`0001;o
oooo000Cooooo`?o00002_ooool3o`0000;ooooo0_l0o`05ooooo`04o`3o0?l0003o0000o`0000Oo
oooo00Co0?l0oooooooooooooooo0_l0000;ooooo`?o00000oooool6o`3o0003o`000?l0o`3o0?l0
00Co0?l08oooool00ol0o`3oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01?ooool2o`3o00Cooooo0_l0000;ooooo`;o00000oooool2o`3o00Kooooo0_l0000;oooo
o`;o00004_ooool001Cooooo00?o0000ooooooooool03oooool00ol0o`3oooooooooo`03ooooo`;o
0?l02Oooool2o`3o00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03
o`3o0?oooooooooo02Kooooo00?o0?l0ooooooooool06Oooool00ol0o`3oooooooooo`03ooooo`03
o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0_l0o`06ooooo`;o00002oooool2o`00
01?ooooo00001?oooooo0000o`000?l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004oooo
o`03o`000?oooooooooo00oooooo00?o0?l0ooooooooool00oooool2o`3o00[ooooo00?o0?l0oooo
ooooool06Oooool00ol0003oooooooooo`0Uooooo`03o`3o0?oooooooooo01Wooooo0_l0o`0Foooo
o`;o0?l01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo0002ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00oooooo00?o0?l0ooooooooool00oooool2o`3o00[ooooo00?o0?l0ooooooooool06Oooool00ol0
003oooooooooo`0Tooooo`03o`3o0?oooooooooo01Wooooo0_l0o`0Fooooo`;o0?l0:Oooool000;o
oooo00?o0000ooooooooool02oooool01?l0003oooooooooooooool2o`00013ooooo00?o0?l0oooo
ooooool01?ooool00ol0o`3oooooooooo`08ooooo`;o0?l06_ooool00ol0003oooooooooo`0Soooo
o`03o`3o0?oooooooooo01[ooooo00?o0?l0ooooooooool05Oooool00ol0o`3oooooooooo`0Xoooo
o`000_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000004Oooool2o`3o
00Gooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`0Hooooo`03o`000?oooooooooo
02;ooooo00?o0?l0ooooooooool06_ooool2o`3o01Kooooo0_l0o`0Zooooo`000_ooool00ol0003o
ooooooooo`07ooooo`Co00001?ooool00ol0003oooooooooo`0?ooooo`;o0?l01Oooool2o`3o00[o
oooo0_l0o`0Iooooo`03o`000?oooooooooo027ooooo0_l0o`0Looooo`03o`3o0?oooooooooo01Go
oooo00?o0?l0ooooooooool0:Oooool00003ooooool0003o000000Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0?ooooo`;o0?l01Oooool2o`3o00_ooooo00?o0?l0ooooooooool0
5oooool00ol0003oooooooooo`0Pooooo`;o0?l07?ooool2o`3o01Kooooo0_l0o`0[ooooo`000_oo
ool00ol0003oooooooooo`07ooooo`Go00000oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00?ooooo00?o0?l0ooooooooool00oooool2o`3o00_ooooo0_l0o`0Hooooo`03o`000?oo
oooooooo01oooooo0_l0o`0Looooo`;o0?l05_ooool2o`3o02cooooo000Dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool00ol0o`3oooooooooo`03ooooo`03o`000?l0o`3o
oooo00_ooooo00?o0?l0ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`;o00002_ooool2
o`0000Gooooo0_l0o`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0o`3oooooooooo`0Eooooo`03o`3o0?oooooooooo02_ooooo000Dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00oooool00ol0o`3oooooooooo`03ooooo`03o`000?l0o`3o0?l0
00[ooooo00?o0000o`3o0?l0o`002Oooool2o`0000cooooo1?l00008ooooo`Co00002_ooool3o`00
00?ooooo0_l0o`05ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03o`3o0?l0003ooooo
00[ooooo00?o0000ooooooooool02?ooool2o`3o02gooooo000Cooooo`?o00002_ooool3o`0000Co
oooo00?o0?l0ooooooooool00oooool00ol0003o0?l0o`3o000:ooooo`;o000000?o0?l0oooooooo
ool02?ooool3o`0000Wooooo1Ol00007ooooo`Go00002Oooool2o`0000Cooooo0_l0o`05ooooo`03
o`000?oooooooooo00Wooooo0ol00009ooooo`04o`3o0?l0003o0000o`0000[ooooo0_l00009oooo
o`03o`3o0?l0003o000000_ooooo0_l0000<ooooo`03o`000?oooooooooo013ooooo000Cooooo`?o
00002_ooool3o`0000Cooooo0_l0o`04ooooo`;o000000?o0?l0ooooooooool02?ooool2o`0000;o
0?l02_ooool3o`0000Wooooo00Co0000ooooool0003o00005?ooool00ol0003oooooooooo`02oooo
o`;o0?l01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0_l0o`02o`00
00[ooooo0_l00009ooooo`03o`3o0?oooooo000000;o00002_ooool2o`0000[ooooo0ol0000Boooo
o`005?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0?l0oooooooo
ool00_ooool2o`000003o`3o0?oooooooooo00Wooooo0_l00002o`3o00[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Iooooo`;o0?l04oooool00ol0003oooooooooo`08ooooo`;o
0?l00_l0000;ooooo`03o`000?oooooooooo00Oooooo0_l0o`000ooooooo0000o`00000:ooooo`;o
00002oooool3o`0001;ooooo000Dooooo`03o`000?oooooooooo017ooooo00?o0?l0ooooooooool0
1?ooool2o`3o00[ooooo00?o0000ooooooooool00_l0o`0Dooooo`03o`000?oooooooooo01Oooooo
0ol0o`0Nooooo`;o0?l000?oooooo`000?ooool02_ooool00ol0003oooooooooo`08ooooo`04o`3o
0?oooooo0000o`0000_ooooo00?o0000ooooooooool02_ooool2o`0001?ooooo000Dooooo`03o`00
0?oooooooooo017ooooo00?o0?l0ooooooooool01?ooool2o`3o00kooooo0_l0o`0Cooooo`03o`00
0?oooooooooo01Gooooo0ol0o`0Oooooo`;o0?l06?ooool2o`3o0003ooooool0003ooooo00[ooooo
00?o0000ooooooooool02_ooool2o`0001Cooooo000Dooooo`03o`000?oooooooooo017ooooo00?o
0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0=ooooo`;o0?l04_ooool00ol0003ooooooooo
o`0Dooooo`;o0?l08?ooool2o`3o01Sooooo0_l0o`0Kooooo`03o`000?oooooooooo01?ooooo000D
ooooo`;o00004_ooool2o`3o00Kooooo0_l0o`0?ooooo`;o0?l04Oooool00ol0003oooooooooo`0B
ooooo`?o0?l08?ooool00ol0o`3oooooo`3o000Gooooo`;o0?l0<_ooool001Cooooo00?o0000oooo
ooooool04_ooool00ol0o`3oooooooooo`04ooooo`;o0?l04?ooool2o`3o013ooooo00?o0000oooo
ooooool04Oooool2o`3o02;ooooo0_l0o`0Hooooo`03o`3o0?oooooooooo037ooooo000Dooooo`03
o`000?oooooooooo01;ooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0?ooooo`;o
0?l03oooool00ol0003oooooooooo`0?ooooo`?o0?l08_ooool2o`3o01Sooooo00?o0?l0oooooooo
ool0<_ooool001Cooooo00?o0000ooooooooool04_ooool00ol0o`3oooooooooo`05ooooo`;o0?l0
4Oooool2o`3o00kooooo00?o0000ooooooooool03Oooool3o`3o02?ooooo0_l0o`0Hooooo`;o0?l0
=?ooool001Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`;o0?l01_oo
ool2o`3o01?ooooo0_l0o`0<ooooo`03o`000?oooooooooo00_ooooo0ol0o`0Tooooo`;o0?l06Ooo
ool00ol0o`3oooooooooo`0cooooo`005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Gooooo0_l0o`02ooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool01?ooool2
o`0000gooooo0_l0o`0:ooooo`03o`000?oooooooooo00[ooooo0_l0o`0;ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02oooool2o`3o01Wooooo00?o0?l0ooooooooool0=?ooool0
01?ooooo0ol0000;ooooo`03o`000?oooooooooo00Kooooo00Co0?l0oooooooooooo00001?ooool2
o`3o00Gooooo0ol0000:ooooo`?o000000Coooooo`3o0?l0o`3o0?l01oooool3o`0000Oooooo0ol0
o`02o`0000[ooooo0_l0000;ooooo`;o00002oooool2o`3o00[ooooo00?o0000ooooooooool03?oo
ool00ol0o`3oooooooooo`0eooooo`004oooool3o`0000[ooooo0ol00007ooooo`03o`3o0?oooooo
oooo00;o00001?ooool00ol0o`3oooooooooo`04ooooo`?o00002_ooool4o`000003ooooool0o`3o
0?l000;o0?l00_ooool5o`0000;ooooo1_l0o`05o`0000Sooooo1?l00009ooooo`Co00002Oooool2
o`3o0003o`000?oooooooooo00Sooooo0_l0000:ooooo`;o00000_l0o`09ooooo`;o00003?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Dooooo`03o`000?oooooooooo
00Wooooo0ol00007ooooo`03o`3o0?oooooooooo00?o00000oooool00ol0o`3oooooooooo`04oooo
o`Co00002_ooool3o`0000Gooooo2Ol0o`0Booooo`;o00002oooool2o`0000_ooooo0_l0o`0;oooo
o`;o00002oooool2o`000003o`3o0?oooooooooo00Sooooo0_l0000:ooooo`?o00002Oooool01?l0
003oooooooooool0000Booooo`005?ooool00ol0003oooooooooo`0Cooooo`;o0?l000?oooooo`00
0?ooool01Oooool00ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0/ooooo`?o0?l03?ooool00ol0003oooooooooo`09oooo
o`;o000000?o0?l0ooooooooool02?ooool2o`0000_ooooo0ol00009ooooo`?o00004oooool001Co
oooo00?o0000ooooooooool04oooool2o`3o00Sooooo00?o0?l0ooooooooool07Oooool00ol0003o
ooooooooo`0[ooooo`;o0?l03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo0?l000_o
oooo00?o0000ooooooooool02Oooool2o`0000_ooooo0ol0000Cooooo`005?ooool00ol0003ooooo
ooooo`0Dooooo`03o`3o0?oooooooooo00Kooooo0_l0o`0Nooooo`03o`000?oooooooooo02[ooooo
0_l0o`0Kooooo`03o`3o0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`;o00005Oooool001Cooooo00?o0000ooooooooool05?ooool00ol0o`3ooooooooo
o`07ooooo`;o0?l07Oooool00ol0003oooooooooo`0Yooooo`;o0?l06oooool2o`3o01Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`005?ooool2o`0001Gooooo0_l0o`08
ooooo`;o0?l07Oooool00ol0003oooooooooo`0Xooooo`;o0?l06oooool2o`3o03cooooo000Doooo
o`03o`000?oooooooooo01Gooooo00?o0?l0ooooooooool01oooool2o`3o01cooooo00?o0000oooo
ooooool09oooool2o`3o01_ooooo0_l0o`0mooooo`005?ooool00ol0003oooooooooo`0Eooooo`03
o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool06_ooool00ol0003oooooooooo`0Vooooo`;o
0?l06oooool2o`3o03kooooo000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0o`3oooooooooo`08ooooo`;o0?l06oooool00ol0003oooooooooo`0Uooooo`03o`3o
0?oooooooooo01[ooooo0_l0o`0oooooo`003?ooool5o`0000?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`;o0?l02_ooool00ol0o`3oooooooooo`0Iooooo`03o`000?oo
oooooooo02Cooooo00?o0?l0ooooooooool06_ooool2o`3o043ooooo000=ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool02Oooool2o`0000_ooooo00?o0?l0ooooooooool02Ooo
ool00ol0o`3oooooooooo`0Hooooo`?o00002_ooool2o`0000_ooooo00?o0000ooooooooool02?oo
ool2o`3o01cooooo0_l0o`11ooooo`003_ooool00ol0003oooooooooo`02ooooo`?o00002_ooool2
o`0000_ooooo00?o0?l0o`000?ooool02Oooool00ol0o`3o0000ooooo`0:ooooo`Go00001oooool5
o`0000Wooooo0ol0000:ooooo`;o00002Oooool00ol0o`3o0000o`00000;ooooo`;o00002_ooool0
1?l0003oooooo`000?ooool2o`3o00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool000oooooo00Co0000
oooooooooooooooo0ol0000:ooooo`?o00002_ooool2o`3o00_ooooo00?o0?l0o`000?ooool02ooo
ool3o`0000Wooooo0ol00008ooooo`Go00002?ooool4o`0000Kooooo0_l0o`04o`0000[ooooo0_l0
000:ooooo`;o00000ol0o`08ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000<ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo0_l0
o`000ol0003oooooooooo`08ooooo`03o`000?l0o`3o000000cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Dooooo`;o00002?ooool2o`3o00;o00003?ooool00ol0003ooooooooo
o`09ooooo`;o00000ol0o`09ooooo`;o00002_ooool2o`0000[ooooo00?o0000ooooool000003?oo
ool00ol0003oooooooooo`0Aooooo`003?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool05oooool00ol0o`3oooooooooo`0:ooooo`03o`000?l0o`3ooooo01Kooooo00?o
0000ooooooooool07?ooool3o`3o00kooooo00?o0000ooooooooool02_ooool01?l0003o0?l0o`3o
0?l0o`09ooooo`;o00002oooool2o`0000[ooooo0_l0000;ooooo`;o00005?ooool000gooooo0ol0
0004ooooo`03o`000?oooooooooo01Oooooo0_l0o`0=ooooo`03o`3o0?oooooooooo01Cooooo00?o
0000ooooooooool06oooool2o`3o01cooooo00Co0000o`3o0?l0o`3o0?l02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo1?l0000:ooooo`;o00005?ooool001Cooooo00?o
0000ooooooooool05oooool2o`3o00kooooo00?o0?l0ooooooooool04oooool00ol0003ooooooooo
o`0Iooooo`;o0?l07_ooool3o`3o00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`;o00002oooool2o`0001Gooooo000Dooooo`03o`000?oooooooooo01Sooooo0_l0o`0>
ooooo`;o0?l04oooool00ol0003oooooooooo`0Gooooo`;o0?l07oooool2o`3o02Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Dooooo`005?ooool2o`0001Wooooo0_l0o`0?oooo
o`;o0?l04_ooool00ol0003oooooooooo`0Eooooo`?o0?l07oooool2o`3o03;ooooo00?o0000oooo
ooooool05Oooool001Cooooo00?o0000ooooooooool06Oooool00ol0o`3oooooooooo`0>ooooo`;o
0?l04Oooool00ol0003oooooooooo`0Cooooo`?o0?l08?ooool2o`3o04_ooooo000Dooooo`03o`00
0?oooooooooo01Wooooo0_l0o`0@ooooo`;o0?l04?ooool00ol0003oooooooooo`0Aooooo`?o0?l0
8Oooool2o`3o04cooooo000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_oo
ool00ol0o`3oooooooooo`0@ooooo`;o0?l03_ooool00ol0003oooooooooo`0?ooooo`?o0?l08_oo
ool00ol0o`3oooooooooo`1<ooooo`005?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooooooo0_l0o`0Booooo`?o0?l03?ooool00ol0003ooooooooo
o`0=ooooo`?o0?l08_ooool2o`3o04oooooo000Cooooo`?o00002_ooool2o`0000_ooooo00?o0000
ooooooooool00_ooool00ol0o`3oooooooooo`04ooooo`;o00002_ooool00ol0003o0?l0o`3o0003
o`3o00Wooooo0ol00009ooooo`Co0?l02Oooool2o`0000_ooooo00?o0000ooooooooool02oooool2
o`3o053ooooo000Cooooo`?o00002_ooool2o`0000_ooooo0_l00003ooooo`;o0?l01Oooool3o`00
00_ooooo0_l00003o`3o00Kooooo1Ol00006ooooo`Go0?l000?o0000ooooooooool01oooool3o`00
00[ooooo0_l0000;ooooo`03o`000?l0o`3o0?l000_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0@ooooo`005?ooool00ol0003oooooooooo`09ooooo`?o00002_ooool3o`0000?o
oooo00?o0?l0ooooooooool01?ooool3o`0000_ooooo0_l00002ooooo`Oo0?l000?oooooo`000?l0
00002?l0o`05o`0000Sooooo1?l00009ooooo`Co00002Oooool00ol0003o0?l0o`3o000:ooooo`;o
00002_ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0@ooooo`005?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00?ooooo00?o0?l0ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Gooooo1_l0o`0Cooooo`;o00002oooool2o`0000_ooooo00Co0000o`3o0?l0o`3o
00002_ooool2o`0000[ooooo0_l0000:ooooo`?o00003?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo017ooooo000Dooooo`03o`000?oooooooooo01gooooo00?o0?l0ooooooooool0
7Oooool00ol0003oooooooooo`0/ooooo`03o`000?l0o`3ooooo00_ooooo00?o0000ooooooooool0
2Oooool3o`0000[ooooo0ol00009ooooo`?o00003?ooool00ol0003oooooooooo`0Booooo`005?oo
ool00ol0003oooooooooo`0Mooooo`;o0?l07_ooool00ol0003oooooooooo`0[ooooo`;o0?l03?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`?o00002_oo
ool2o`0001Gooooo000Dooooo`03o`000?oooooooooo01kooooo00?o0?l0ooooooooool07?ooool0
0ol0003oooooooooo`0Zooooo`;o0?l06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo0_l0000<ooooo`;o00005Oooool001Cooooo0_l0000Oooooo`;o0?l07Oooool00ol0
003oooooooooo`0Xooooo`;o0?l09oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05Oooool001Cooooo00?o0000ooooooooool07oooool00ol0o`3o
ooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo0_l0o`11ooooo`03o`000?oooooooooo01Ko
oooo000Dooooo`03o`000?oooooooooo023ooooo00?o0?l0ooooooooool06_ooool00ol0003ooooo
ooooo`0Uooooo`;o0?l0G?ooool001Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Dooooo`03o`3o0?oooooooooo01[ooooo00?o0000ooooooooool09?ooool2o`3o05gooooo000D
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`03o`3o0?oooooooooo01Wooooo00?o0000ooooooooool08_ooool3o`3o05kooooo000Doooo
o`03o`000?oooooooooo00Wooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0?l0oooo
ooooool06?ooool00ol0003oooooooooo`0Qooooo`;o0?l0H?ooool001?ooooo0ol0000:ooooo`;o
00002oooool2o`0000[ooooo00?o0000o`3o0?ooool02Oooool3o`0000_ooooo0ol0000:ooooo`;o
00002oooool00ol0003oooooooooo`06ooooo`?o0?l000?o0000ooooooooool0G_ooool001?ooooo
0ol0000:ooooo`?o00002_ooool2o`0000_ooooo0_l0o`0:ooooo`Co00001oooool5o`0000Wooooo
0ol0000:ooooo`;o00001_ooool4o`3o00?o00002_ooool3o`0000_ooooo0_l0000;ooooo`;o0000
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
4?ooool001Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`?o00002_oo
ool00ol0003o0?l0o`3o000:ooooo`?o00002_ooool2o`0000Sooooo1Ol00008ooooo`Co00001?oo
ool3o`3o0003ooooool0003o000000;o00002_ooool00ol0003oooooooooo`09ooooo`;o00003?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`005?ooool00ol0003oooooooooo`0Tooooo`03o`000?l0o`3o
0?l000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`;o00001Oooool3
o`3o00;ooooo0_l0000<ooooo`?o00002_ooool2o`0000[ooooo0_l0000:ooooo`03o`000?oooooo
000000gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`005?ooool00ol0
003oooooooooo`0Wooooo`03o`3o0?oooooooooo01?ooooo00?o0000ooooooooool06?ooool4o`3o
013ooooo0_l0000;ooooo`03o`000?oooooooooo00[ooooo0ol00009ooooo`;o00002oooool00ol0
003oooooo`00000<ooooo`03o`000?oooooooooo01;ooooo0005o`0000?ooooo00?o0000oooooooo
ool00_ooool3o`0000Cooooo00?o0000ooooooooool0:?ooool2o`3o01?ooooo00?o0000oooooooo
ool05oooool3o`3o01kooooo00?o0000ooooooooool02_ooool2o`0000[ooooo1?l0000:ooooo`;o
00002_ooool00ol0003oooooo`00000Eooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Yooooo`;o0?l04_ooool00ol0
003oooooooooo`0Eooooo`?o0?l0;?ooool00ol0003oooooooooo`0:ooooo`;o00002oooool3o`00
00[ooooo0_l0000Fooooo`000_ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooooooo
o`;o0000:oooool3o`3o013ooooo00?o0000ooooooooool04oooool2o`3o03_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`09ooooo`;o00005oooool000?ooooo00?o0000oooooooo
ool02_ooool01Ol0003ooooooooooooooooo000002gooooo1?l0o`0>ooooo`03o`000?oooooooooo
013ooooo0ol0o`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00005
o`000?ooooooooooooooool000001oooool4o`0000Cooooo00?o0000ooooooooool0;Oooool4o`3o
00cooooo00?o0000ooooooooool03_ooool3o`3o05Sooooo00?o0000ooooooooool05oooool00005
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool08oooool4o`3o00[ooooo00?o0000ooooooooool02Oooool5o`3o
07Gooooo00001?oooooo0000o`000?l00008ooooo`Go00000oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool4o`3o00Oooooo00?o0000oooo
ooooool01Oooool6o`3o07Sooooo000Cooooo`?o00002_ooool2o`0000[ooooo0_l0000;ooooo`;o
00004OoooolAo`3o07gooooo000Cooooo`?o00002_ooool2o`0000[ooooo0ol0000:ooooo`?o0000
2Oooool5o`0000Wooooo0ol0000:ooooo`;o00002_ooool2o`0006cooooo000Dooooo`;o00002_oo
ool3o`0000[ooooo0ol0000:ooooo`?o00002_ooool3o`0000Oooooo1Ol00008ooooo`Co00002Ooo
ool3o`0000[ooooo0ol0000:ooooo`?o00002oooool2o`0000_ooooo0_l0000:ooooo`;o00003?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Dooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo0_l00007ooooo`Go00002?ooool5o`0000Sooooo1?l00009ooooo`;o00002oooool2
o`0000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04Oooool001Cooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Booooo`?o00002_ooool2o`0000_ooooo1?l00009ooooo`;o00002oooool2o`00
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01;ooooo000Dooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0:oooool2o`0000_o
oooo1?l00009ooooo`?o00002_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool04oooool001Cooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0gooooo`;o00002oooool2o`0000_ooooo0ol0000:ooooo`;o00002_ooool00ol0003ooooo
o`00000Fooooo`005?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool02_ooool2o`0000cooooo0_l0000:ooooo`;o00005oooool001Cooooo0_l0000n
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09
ooooo`?o00005oooool001Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool001Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06Sooooo00?o0000oooooooo
ool06?ooool001Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0Poooool001?ooooo0ol0000:ooooo`;o00002_oo
ool00ol0003oooooooooo`09ooooo`;o00006_ooool00ol0003oooooooooo`23ooooo`004oooool3
o`0000[ooooo0_l0000:ooooo`;o00002_ooool3o`0000[ooooo0ol0000;ooooo`?o00002Oooool2
o`0007Wooooo000Dooooo`;o00002_ooool3o`0000[ooooo0_l0000:ooooo`?o00002_ooool4o`00
00Oooooo1Ol00008ooooo`Co00002Oooool3o`0000_ooooo0_l0000;ooooo`;o00002oooool2o`00
00_ooooo0_l0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0@ooooo`005?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo0ol00009ooooo`Co00002_ooool3o`0000[ooooo0_l00007ooooo`Go00002?ooool3o`0000[o
oooo0_l0000;ooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017o
oooo000Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool5o`0000Sooooo
1?l00009ooooo`;o00002oooool2o`0000cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool001Cooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0Nooooo`;o00002oooool4o`0000Wooooo0_l0
000;ooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04oooool001Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Z
ooooo`;o00002oooool4o`0000Wooooo0_l0000;ooooo`;o00003?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Cooooo000Dooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0=_ooool2o`0000_ooooo1?l0000:ooooo`03o`000?oooooooooo00Wooooo0_l0000<oooo
o`03o`000?oooooooooo01Gooooo000Dooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool0@_ooool2o`0000cooooo0ol0000:ooooo`;o00002_ooool2o`0001Sooooo000Dooooo`;o0000
?_ooool00ol0003oooooooooo`1?ooooo`;o00002oooool00ol0003oooooooooo`0:ooooo`;o0000
6?ooool001Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06?ooool001Cooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Wooooo000Dooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool0Poooool000gooooo0ol00004ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0Poooool000cooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0Poooool0013ooooo00Co0000oooooooooooo
oooo0_l0000nooooo`03o`000?oooooooooo08?ooooo000>ooooo`;o00001?ooool00ol0003ooooo
ooooo`33ooooo`004?ooool01Ol0003ooooooooooooooooo00000<Gooooo000<ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`33ooooo`003Oooool3o`0000Cooooo00?o
0000ooooooooool0`oooool001Cooooo00?o0000ooooooooool0`oooool00=[ooooo003Jooooo`00
f_ooool00=[ooooo0000\
\>"],
  ImageRangeCache->{{{78.875, 295.875}, {347.375, 130.375}} -> {-1.55551, \
1.78974, 0.0156503, 0.0156503}}]
}, Open  ]],

Cell[TextData[StyleBox["Symbolic solutions, integral curves",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "The Lotka-Volterra system is non-linear. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " cannot obtain a symbolic solution for the trajectories.  However, \
formulas for curves determined by the trajectories can be obtained by \
eliminating the ",
  StyleBox["t",
    FontSlant->"Italic"],
  " variable to  make a first order differential equation for the ",
  StyleBox["y",
    FontSlant->"Italic"],
  " variable as a function of ",
  StyleBox["x",
    FontSlant->"Italic"],
  ". Solutions to this  differential equation are called \"integrals\" of the \
system, their graphs are called integral curves. Integral curves  for \
Lotka-Voltera can easily be found \"by hand\" (Ledder, page 306). ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s computations are shown in the  next few entries. "
}], "Text"],

Cell["Create DE:", "Text"],

Cell[CellGroupData[{

Cell["DE = y'[x] == DEsystem[[2,2]]/DEsystem[[1,2]]", "Input",
  CellLabel->"In[26]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}], 
      "\[Equal]", \(\(\((\(-1\) + x[t])\)\ y[t]\)\/\(x[
              t]\ \((1 - y[t])\)\)\)}]], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["Change y[t] and x[t] into y[x] and x respectively.", "Text"],

Cell[CellGroupData[{

Cell["DE = DE/.{x[t]->x, y[t]->y[x]}", "Input",
  CellLabel->"In[27]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}], 
      "\[Equal]", \(\(\((\(-1\) + x)\)\ y[
              x]\)\/\(x\ \((1 - y[x])\)\)\)}]], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
Solve DE,with the initial condition y(0,4) = 0.4. to see if DSolve \
is up to the job.\
\>", "Text"],

Cell[CellGroupData[{

Cell["soln = DSolve[ {DE, y[0.4]==0.4}, y, x ]", "Input",
  CellLabel->"In[41]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{\(InverseFunction::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse \
functions are being used. Values may be lost for multivalued inverses. \\!\\(\
\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"InverseFunction::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[41]:="],

Cell[BoxData[
    RowBox[{\(Solve::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse functions are \
being used by \\!\\(Solve\\), so some solutions may not be found; use Reduce \
for complete solution information. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[41]:="],

Cell[BoxData[
    RowBox[{\(Solve::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse functions are \
being used by \\!\\(Solve\\), so some solutions may not be found; use Reduce \
for complete solution information. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[41]:="],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{x}, \
\(-ProductLog[\(-\(\[ExponentialE]\^\(\(-2.63258146374831`\) + \
x\)\/x\)\)]\)]}}\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has found an explicit solution in terms of the \"ProductLog\" function."
}], "Text"],

Cell[CellGroupData[{

Cell["?ProductLog", "Input",
  CellLabel->"In[52]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{"\<\"ProductLog[z] gives the principal solution for w in z = w \
e^w. ProductLog[k, z] gives the kth solution.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"ProductLog",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3305920359-3978630"]
}, Open  ]],

Cell["\<\
The plot of the solution shows that DSolve has obtained the formula \
for the bottom half of the integral curve for the system.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ y[x]/.soln, {x,0,3}, PlotRange->{0,2.5}, AspectRatio->1/1 ]\
\
\>", "Input",
  CellLabel->"In[46]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.369111 0 0.4 [
[.20836 -0.0125 -9 -9 ]
[.20836 -0.0125 9 0 ]
[.39292 -0.0125 -3 -9 ]
[.39292 -0.0125 3 0 ]
[.57748 -0.0125 -9 -9 ]
[.57748 -0.0125 9 0 ]
[.76203 -0.0125 -3 -9 ]
[.76203 -0.0125 3 0 ]
[.94659 -0.0125 -9 -9 ]
[.94659 -0.0125 9 0 ]
[.01131 .2 -18 -4.5 ]
[.01131 .2 0 4.5 ]
[.01131 .4 -6 -4.5 ]
[.01131 .4 0 4.5 ]
[.01131 .6 -18 -4.5 ]
[.01131 .6 0 4.5 ]
[.01131 .8 -6 -4.5 ]
[.01131 .8 0 4.5 ]
[.01131 1 -18 -4.5 ]
[.01131 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20836 0 m
.20836 .00625 L
s
[(0.5)] .20836 -0.0125 0 1 Mshowa
.39292 0 m
.39292 .00625 L
s
[(1)] .39292 -0.0125 0 1 Mshowa
.57748 0 m
.57748 .00625 L
s
[(1.5)] .57748 -0.0125 0 1 Mshowa
.76203 0 m
.76203 .00625 L
s
[(2)] .76203 -0.0125 0 1 Mshowa
.94659 0 m
.94659 .00625 L
s
[(2.5)] .94659 -0.0125 0 1 Mshowa
.125 Mabswid
.06072 0 m
.06072 .00375 L
s
.09763 0 m
.09763 .00375 L
s
.13454 0 m
.13454 .00375 L
s
.17145 0 m
.17145 .00375 L
s
.24528 0 m
.24528 .00375 L
s
.28219 0 m
.28219 .00375 L
s
.3191 0 m
.3191 .00375 L
s
.35601 0 m
.35601 .00375 L
s
.42983 0 m
.42983 .00375 L
s
.46674 0 m
.46674 .00375 L
s
.50365 0 m
.50365 .00375 L
s
.54056 0 m
.54056 .00375 L
s
.61439 0 m
.61439 .00375 L
s
.6513 0 m
.6513 .00375 L
s
.68821 0 m
.68821 .00375 L
s
.72512 0 m
.72512 .00375 L
s
.79894 0 m
.79894 .00375 L
s
.83585 0 m
.83585 .00375 L
s
.87276 0 m
.87276 .00375 L
s
.90967 0 m
.90967 .00375 L
s
.9835 0 m
.9835 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .2 m
.03006 .2 L
s
[(0.5)] .01131 .2 1 0 Mshowa
.02381 .4 m
.03006 .4 L
s
[(1)] .01131 .4 1 0 Mshowa
.02381 .6 m
.03006 .6 L
s
[(1.5)] .01131 .6 1 0 Mshowa
.02381 .8 m
.03006 .8 L
s
[(2)] .01131 .8 1 0 Mshowa
.02381 1 m
.03006 1 L
s
[(2.5)] .01131 1 1 0 Mshowa
.125 Mabswid
.02381 .04 m
.02756 .04 L
s
.02381 .08 m
.02756 .08 L
s
.02381 .12 m
.02756 .12 L
s
.02381 .16 m
.02756 .16 L
s
.02381 .24 m
.02756 .24 L
s
.02381 .28 m
.02756 .28 L
s
.02381 .32 m
.02756 .32 L
s
.02381 .36 m
.02756 .36 L
s
.02381 .44 m
.02756 .44 L
s
.02381 .48 m
.02756 .48 L
s
.02381 .52 m
.02756 .52 L
s
.02381 .56 m
.02756 .56 L
s
.02381 .64 m
.02756 .64 L
s
.02381 .68 m
.02756 .68 L
s
.02381 .72 m
.02756 .72 L
s
.02381 .76 m
.02756 .76 L
s
.02381 .84 m
.02756 .84 L
s
.02381 .88 m
.02756 .88 L
s
.02381 .92 m
.02756 .92 L
s
.02381 .96 m
.02756 .96 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.11695 .36851 m
.11772 .3476 L
.1191 .32486 L
.12057 .30767 L
.12325 .28486 L
.12643 .26482 L
.12933 .25031 L
.13564 .22621 L
.14164 .20904 L
.1522 .18669 L
.16373 .16917 L
.17573 .15558 L
.18661 .14598 L
.19931 .13707 L
.21099 .13048 L
.23337 .1209 L
.24514 .11705 L
.25757 .11365 L
.28041 .10882 L
.30172 .10559 L
.31388 .10419 L
.32539 .10311 L
.33564 .10232 L
.34696 .10164 L
.35819 .10113 L
.36434 .10092 L
.37011 .10076 L
.37549 .10065 L
.38042 .10058 L
.383 .10055 L
.38583 .10052 L
.38726 .10051 L
.38878 .10051 L
.39022 .1005 L
.39153 .1005 L
.39292 .1005 L
.39421 .1005 L
.39564 .1005 L
.39717 .10051 L
.39793 .10051 L
.39877 .10051 L
.40029 .10052 L
.40313 .10055 L
.40582 .10058 L
.40869 .10062 L
.41384 .1007 L
.42037 .10085 L
.42653 .10102 L
.43802 .10143 L
.46141 .10258 L
Mistroke
.4829 .10402 L
.52887 .10822 L
.57308 .11373 L
.62014 .12126 L
.66544 .13034 L
.7136 .14234 L
.75998 .1568 L
.80461 .1743 L
.85209 .19853 L
.87568 .21376 L
.8978 .23091 L
.91897 .25114 L
.94176 .27997 L
.95292 .29895 L
.95931 .31251 L
.9651 .32778 L
.96806 .33739 L
.97126 .35034 L
.97302 .3595 L
.97379 .36437 L
.97464 .37073 L
.97544 .37858 L
.97619 .3912 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[46]:=",
  ImageSize->{151, 151},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002G0000Ub000`400?l00000o`00003oUoooool0
09Oooooo002Gooooo`009?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00013ooooo
0ol0000?ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00003_ooool5o`0000kooooo
1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`008oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000>ooooo`04o`000?oooooooooo
o`0000oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000;ooooo
000Sooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo000Sooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00[ooooo0Ol00001ooooo`7ooooo000Sooooo`04o`000?ooooooooooo`0000Oooooo
1?l0000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool4o`0000kooooo
00Go0000ooooooooooooooooo`00000>ooooo`05o`000?ooooooooooooooool000001oooool4o`00
00?ooooo000Sooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool04Oooool2o`00
013ooooo0_l00009ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000>
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`04ooooo`009?ooool2
o`0000Sooooo1Ol0000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool5
o`0000kooooo0ol0000@ooooo`?o00002?ooool5o`0000;ooooo002Gooooo`00Uoooool009Oooooo
000@ooooohGo00000_ooool001?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Oooooo000Cooooo`03o`000?oooooooooo087ooooo000Cooooo`03
o`000?oooooooooo087ooooo000Cooooo`03o`000?oooooooooo087ooooo000Cooooo`;o0000P_oo
ool001?ooooo00?o0000ooooooooool0POooool001?ooooo00?o0000ooooooooool0POooool001?o
oooo00?o0000ooooooooool0POooool001?ooooo00?o0000ooooooooool0POooool001?ooooo0_l0
0022ooooo`004oooool00ol0003oooooooooo`21ooooo`004oooool00ol0003oooooooooo`21oooo
o`004oooool00ol0003oooooooooo`0Toooooa[o0000@oooool001?ooooo00?o0000ooooooooool0
7_ooool6o`0001[ooooo1_l0000mooooo`004oooool00ol0003oooooooooo`0Jooooo`Co00009_oo
ool6o`0003Oooooo000Cooooo`;o00006Oooool2o`00033ooooo1_l0000aooooo`004oooool00ol0
003oooooooooo`0Eooooo`?o0000>?ooool5o`0002cooooo000Cooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0?_ooool3o`0002Wooooo000Cooooo`03o`000?oooooooooo01;ooooo
0_l00014ooooo`Co00009Oooool001?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`18ooooo`Co00008Oooool001?ooooo0_l0000Booooo`03o`000?oooooooooo04cooooo0_l0000O
ooooo`004oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo0_l0000Moooo
o`004oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0_l0000Kooooo`00
0_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1Eooooo`;o00006Oooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1Gooooo`;o00005oooool00005ooooool0003oooooooooool000002oooool00ol0003o
ooooooooo`02o`0000kooooo00?o0000ooooooooool0F_ooool2o`0001Gooooo00001Ooooooo0000
oooooooooooo000000_ooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01;ooooo00001Ooooooo0000oooooooooooo000000Oooooo1?l00003oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0GOooool2o`0001;ooooo00001Ooooooo
0000oooooooooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool03oooool000;ooooo0_l00008ooooo`Go
00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool03_ooool001?ooooo0_l0000=ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
3Oooool001?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00cooooo000Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`0;ooooo`004oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool02oooool001?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo00[ooooo000Cooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`09ooooo`004oooool2o`0000_ooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`08ooooo`004oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool02?ooool001?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Cooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`00
4oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
1_ooool001?ooooo0_l0000;ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01_oo
ool001?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo00Gooooo000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`05ooooo`004oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool01Oooool001?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo00Cooooo000Cooooo`;o00002_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo00Cooooo000Cooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`04ooooo`004oooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo00Cooooo000=ooooo`?o00000oooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo00Cooooo000>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
N_ooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`02ooooo`;o0000P_oo
ool000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`21ooooo`003_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo087ooooo000=ooooo`;o00001?ooool00ol0003o
ooooooooo`21ooooo`003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo087ooooo
000Cooooo`03o`000?oooooooooo087ooooo000Cooooo`;o0000P_ooool001?ooooo00?o0000oooo
ooooool0POooool001?ooooo00?o0000ooooooooool0POooool001?ooooo00?o0000ooooooooool0
POooool001?ooooo00?o0000ooooooooool0POooool001?ooooo0_l00022ooooo`004oooool00ol0
003oooooooooo`21ooooo`004oooool00ol0003oooooooooo`21ooooo`004oooool00ol0003ooooo
ooooo`21ooooo`004oooool00ol0003oooooooooo`21ooooo`004oooool2o`0008;ooooo000Coooo
o`03o`000?oooooooooo087ooooo000Cooooo`03o`000?oooooooooo087ooooo000Cooooo`03o`00
0?oooooooooo087ooooo000Cooooo`03o`000?oooooooooo087ooooo000Cooooo`;o0000P_ooool0
01?ooooo00?o0000ooooooooool0POooool001?ooooo00?o0000ooooooooool0POooool00004oooo
ool0003o0000o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00?o0000oooooooo
ool0POooool000;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool0POooool000;ooooo00?o0000ooooooooool02oooool01?l0003ooooo
ooooool00023ooooo`000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o0000
P_ooool000;ooooo00?o0000ooooooooool01oooool4o`0000?ooooo00?o0000ooooooooool0POoo
ool00003ooooool0003o000000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`21
ooooo`000_ooool00ol0003oooooooooo`07ooooo`Go00000_ooool00ol0003oooooooooo`21oooo
o`004oooool00ol0003oooooooooo`21ooooo`004oooool2o`0008;ooooo000Cooooo`03o`000?oo
oooooooo087ooooo000Cooooo`03o`000?oooooooooo087ooooo000Cooooo`03o`000?oooooooooo
087ooooo000Cooooo`03o`000?oooooooooo087ooooo000Cooooo`;o0000P_ooool001?ooooo00?o
0000ooooooooool0POooool001?ooooo00?o0000ooooooooool0POooool001?ooooo00?o0000oooo
ooooool0POooool001?ooooo00?o0000ooooooooool0POooool001?ooooo00?o0000ooooooooool0
POooool001?ooooo0_l00022ooooo`004oooool00ol0003oooooooooo`21ooooo`004oooool00ol0
003oooooooooo`21ooooo`004oooool00ol0003oooooooooo`21ooooo`004oooool00ol0003ooooo
ooooo`21ooooo`004oooool2o`0008;ooooo000Cooooo`03o`000?oooooooooo087ooooo000Coooo
o`03o`000?oooooooooo087ooooo000<ooooo`Go00000_ooool00ol0003oooooooooo`21ooooo`00
3Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo087ooooo000>ooooo`03o`00
0?oooooooooo00;ooooo0_l00022ooooo`003oooool01Ol0003ooooooooooooooooo000008?ooooo
000<ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`21ooooo`003?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0POooool000gooooo0ol0
0003ooooo`03o`000?oooooooooo087ooooo000Cooooo`;o0000P_ooool001?ooooo00?o0000oooo
ooooool0POooool001?ooooo00?o0000ooooooooool0POooool001?ooooo00?o0000ooooooooool0
POooool001?ooooo00?o0000ooooooooool0POooool001?ooooo00?o0000ooooooooool0POooool0
01?ooooo0_l00022ooooo`004oooool00ol0003oooooooooo`21ooooo`004oooool00ol0003ooooo
ooooo`21ooooo`004oooool00ol0003oooooooooo`21ooooo`004oooool00ol0003oooooooooo`21
ooooo`004oooool2o`0008;ooooo000Cooooo`03o`000?oooooooooo087ooooo000Cooooo`03o`00
0?oooooooooo087ooooo000Cooooo`03o`000?oooooooooo087ooooo000Cooooo`03o`000?oooooo
oooo087ooooo000Cooooo`;o0000P_ooool001?ooooo00?o0000ooooooooool0POooool001?ooooo
00?o0000ooooooooool0POooool000Go00000oooool00ol0003oooooooooo`02ooooo`?o00000ooo
ool00ol0003oooooooooo`21ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`21ooooo`000_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00;o0000P_ooool000?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`24ooooo`0000Go0000ooooooooooooooooo`000007ooooo`Co0000Qoooool0
0005o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`28ooooo`0000Coooooo`00
0?l0003o00002?ooool5o`0008Kooooo002Gooooo`00Uoooool00001\
\>"],
  ImageRangeCache->{{{77.875, 227.875}, {235.375, 85.375}} -> {-2.00898, \
1.38883, 0.0206008, 0.0190099}}]
}, Open  ]],

Cell[TextData[StyleBox["Linear systems, linear flows",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell["Two dimensional linear systems have the form", "Text"],

Cell[TextData[{
  StyleBox["x' = a x",
    FontSlant->"Italic"],
  " +",
  StyleBox[" b y",
    FontSlant->"Italic"],
  " +",
  StyleBox[" f ",
    FontSlant->"Italic"],
  "\n",
  StyleBox["y' = c x",
    FontSlant->"Italic"],
  " + ",
  StyleBox["d y",
    FontSlant->"Italic"],
  " + ",
  StyleBox["g",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "where ",
  StyleBox["x, y, a, b, c, d, f,",
    FontSlant->"Italic"],
  " and ",
  StyleBox["g",
    FontSlant->"Italic"],
  " are all functions of",
  StyleBox[" t",
    FontSlant->"Italic"],
  ". The functions ",
  StyleBox["f",
    FontSlant->"Italic"],
  " and ",
  StyleBox["g",
    FontSlant->"Italic"],
  " are sometimes referred to as the forcing functions. If they are both \
zero, the system is called homogeneous (or unforced). "
}], "Text"],

Cell[TextData[{
  "When ",
  StyleBox["a, b, c",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["d",
    FontSlant->"Italic"],
  " are constants, symbolic solutions can be always be found, provided the \
functions ",
  StyleBox["f",
    FontSlant->"Italic"],
  " and ",
  StyleBox["g",
    FontSlant->"Italic"],
  " are elementary (products of polynomials, sine, cosine, exp, etc.). Such \
systems are important not only  because they arise in many applications, but \
also because they are used to approximate non-linear systems in  regions near \
their critical points.   "
}], "Text"],

Cell[TextData[{
  StyleBox["Example",
    FontVariations->{"Underline"->True}],
  " Consider the autonomous linear system "
}], "Text"],

Cell[TextData[{
  StyleBox["x' = x",
    FontSlant->"Italic"],
  " - 2 ",
  StyleBox["y",
    FontSlant->"Italic"],
  " + 3 \n",
  StyleBox["y' = x",
    FontSlant->"Italic"],
  " +  ",
  StyleBox["y",
    FontSlant->"Italic"],
  "  -  2 "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Sketch the flow, nullclines and stationary point. Find symbolic \
solutions. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
DEsys = { x'[t] == x[t] - 2*y[t] + 3,
          y'[t] == x[t] +   y[t] - 2 }\
\>", "Input",
  CellLabel->"In[53]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(3 + x[t] - 2\ y[t]\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(-2\) + x[t] + y[t]\)}]}], "}"}]], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell["\<\
Let's find the stationary point first. The Solve function can be \
used. Note that the equations and the unknowns must be entered in separate \
lists. The output is a set, or sets, of arrow substitutions.. \
\>", "Text"],

Cell[CellGroupData[{

Cell["stationary = Solve[ {x-2*y+3==0, x+y-2==0}, {x,y} ]", "Input",
  CellLabel->"In[54]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{x \[Rule] 1\/3, y \[Rule] 5\/3}}\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell["\<\
Use the solution to make a \"point\" (i.e, a list for plotting, as \
follows.\
\>", "Text"],

Cell[CellGroupData[{

Cell["statpoint = {x,y}/.stationary", "Input",
  CellLabel->"In[55]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{1\/3, 5\/3}}\)], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell["\<\
The next entries create the plots for vector field, the flowlines \
(using NDSolve), the nullclines, and the stationary point. They are all shown \
together using Show.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
vf = PlotVectorField[{x-2*y+3, x+y-2}, {x,-4,4}, {y,-1,4} ];
solns = Table[ NDSolve[ {DEsys, x[0]==0, y[0]==k}, {x,y}, {t,-2,3} ],
               {k,0,4} ];
flow=ParametricPlot[Evaluate[Table[{x[t],y[t]}/.solns[[k,1]],{k,1,5}] ], 
                   {t,-2,3}, PlotStyle->RGBColor[0,1,0] ];
nullclines = ImplicitPlot[ {x-2*y+3==0,x+y-2==0}, {x,-4,4}, {y,-1,4} ];
stationarypoint = ListPlot[ statpoint, PlotStyle->PointSize[0.03] ];
Show[ {vf, flow, nullclines, stationarypoint}, Axes->True,
       PlotRange->{{-4,4},{-1,4}}, AspectRatio->5/8 ]\
\>", "Input",
  CellLabel->"In[143]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.125 0.125 [
[0 .1125 -6 -9 ]
[0 .1125 6 0 ]
[.125 .1125 -6 -9 ]
[.125 .1125 6 0 ]
[.25 .1125 -6 -9 ]
[.25 .1125 6 0 ]
[.375 .1125 -6 -9 ]
[.375 .1125 6 0 ]
[.625 .1125 -3 -9 ]
[.625 .1125 3 0 ]
[.75 .1125 -3 -9 ]
[.75 .1125 3 0 ]
[.875 .1125 -3 -9 ]
[.875 .1125 3 0 ]
[1 .1125 -3 -9 ]
[1 .1125 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .25 -6 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -6 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .125 m
0 .13125 L
s
[(-4)] 0 .1125 0 1 Mshowa
.125 .125 m
.125 .13125 L
s
[(-3)] .125 .1125 0 1 Mshowa
.25 .125 m
.25 .13125 L
s
[(-2)] .25 .1125 0 1 Mshowa
.375 .125 m
.375 .13125 L
s
[(-1)] .375 .1125 0 1 Mshowa
.625 .125 m
.625 .13125 L
s
[(1)] .625 .1125 0 1 Mshowa
.75 .125 m
.75 .13125 L
s
[(2)] .75 .1125 0 1 Mshowa
.875 .125 m
.875 .13125 L
s
[(3)] .875 .1125 0 1 Mshowa
1 .125 m
1 .13125 L
s
[(4)] 1 .1125 0 1 Mshowa
.125 Mabswid
.025 .125 m
.025 .12875 L
s
.05 .125 m
.05 .12875 L
s
.075 .125 m
.075 .12875 L
s
.1 .125 m
.1 .12875 L
s
.15 .125 m
.15 .12875 L
s
.175 .125 m
.175 .12875 L
s
.2 .125 m
.2 .12875 L
s
.225 .125 m
.225 .12875 L
s
.275 .125 m
.275 .12875 L
s
.3 .125 m
.3 .12875 L
s
.325 .125 m
.325 .12875 L
s
.35 .125 m
.35 .12875 L
s
.4 .125 m
.4 .12875 L
s
.425 .125 m
.425 .12875 L
s
.45 .125 m
.45 .12875 L
s
.475 .125 m
.475 .12875 L
s
.525 .125 m
.525 .12875 L
s
.55 .125 m
.55 .12875 L
s
.575 .125 m
.575 .12875 L
s
.6 .125 m
.6 .12875 L
s
.65 .125 m
.65 .12875 L
s
.675 .125 m
.675 .12875 L
s
.7 .125 m
.7 .12875 L
s
.725 .125 m
.725 .12875 L
s
.775 .125 m
.775 .12875 L
s
.8 .125 m
.8 .12875 L
s
.825 .125 m
.825 .12875 L
s
.85 .125 m
.85 .12875 L
s
.9 .125 m
.9 .12875 L
s
.925 .125 m
.925 .12875 L
s
.95 .125 m
.95 .12875 L
s
.975 .125 m
.975 .12875 L
s
.25 Mabswid
0 .125 m
1 .125 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(2)] .4875 .375 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(4)] .4875 .625 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.25 Mabswid
.5 0 m
.5 .625 L
s
0 0 m
1 0 L
1 .625 L
0 .625 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
0 0 m
0 0 rlineto s
% Start of user PostScript
-4. -1. -3.96126 -1.27116 MAarrowhead1
% End of user PostScript
0 .04464 m
.00138 .01248 L
s
% Start of user PostScript
-4. -0.642857 -3.98893 -0.900185 MAarrowhead1
% End of user PostScript
0 .08929 m
0 0 rlineto s
% Start of user PostScript
-4. -0.285714 -4.0166 -0.529208 MAarrowhead1
% End of user PostScript
0 .13393 m
0 0 rlineto s
% Start of user PostScript
-4. 0.0714286 -4.04427 -0.15823 MAarrowhead1
% End of user PostScript
0 .17857 m
0 0 rlineto s
% Start of user PostScript
-4. 0.428571 -4.07194 0.212748 MAarrowhead1
% End of user PostScript
0 .22321 m
0 0 rlineto s
% Start of user PostScript
-4. 0.785714 -4.09961 0.583725 MAarrowhead1
% End of user PostScript
0 .26786 m
0 0 rlineto s
% Start of user PostScript
-4. 1.14286 -4.12728 0.954703 MAarrowhead1
% End of user PostScript
0 .3125 m
0 0 rlineto s
% Start of user PostScript
-4. 1.5 -4.15495 1.32568 MAarrowhead1
% End of user PostScript
0 .35714 m
0 0 rlineto s
% Start of user PostScript
-4. 1.85714 -4.18262 1.69666 MAarrowhead1
% End of user PostScript
0 .40179 m
0 0 rlineto s
% Start of user PostScript
-4. 2.21429 -4.21029 2.06764 MAarrowhead1
% End of user PostScript
0 .44643 m
0 0 rlineto s
% Start of user PostScript
-4. 2.57143 -4.23796 2.43861 MAarrowhead1
% End of user PostScript
0 .49107 m
0 0 rlineto s
% Start of user PostScript
-4. 2.92857 -4.26563 2.80959 MAarrowhead1
% End of user PostScript
0 .53571 m
0 0 rlineto s
% Start of user PostScript
-4. 3.28571 -4.2933 3.18057 MAarrowhead1
% End of user PostScript
0 .58036 m
0 0 rlineto s
% Start of user PostScript
-4. 3.64286 -4.32097 3.55155 MAarrowhead1
% End of user PostScript
0 .625 m
0 0 rlineto s
% Start of user PostScript
-4. 4. -4.34864 3.92252 MAarrowhead1
% End of user PostScript
.07143 0 m
0 0 rlineto s
% Start of user PostScript
-3.42857 -1. -3.3677 -1.24903 MAarrowhead1
% End of user PostScript
.07143 .04464 m
.07558 .01524 L
s
% Start of user PostScript
-3.42857 -0.642857 -3.39537 -0.87805 MAarrowhead1
% End of user PostScript
.07143 .08929 m
.07212 .06162 L
s
% Start of user PostScript
-3.42857 -0.285714 -3.42304 -0.507072 MAarrowhead1
% End of user PostScript
.07143 .13393 m
.06866 .10799 L
s
% Start of user PostScript
-3.42857 0.0714286 -3.45071 -0.136094 MAarrowhead1
% End of user PostScript
.07143 .17857 m
.0652 .15436 L
s
% Start of user PostScript
-3.42857 0.428571 -3.47838 0.234884 MAarrowhead1
% End of user PostScript
.07143 .22321 m
.06174 .20073 L
s
% Start of user PostScript
-3.42857 0.785714 -3.50605 0.605861 MAarrowhead1
% End of user PostScript
.07143 .26786 m
.05829 .2471 L
s
% Start of user PostScript
-3.42857 1.14286 -3.53372 0.976839 MAarrowhead1
% End of user PostScript
.07143 .3125 m
.05483 .29348 L
s
% Start of user PostScript
-3.42857 1.5 -3.56139 1.34782 MAarrowhead1
% End of user PostScript
.07143 .35714 m
.05137 .33985 L
s
% Start of user PostScript
-3.42857 1.85714 -3.58906 1.71879 MAarrowhead1
% End of user PostScript
.07143 .40179 m
.04791 .38622 L
s
% Start of user PostScript
-3.42857 2.21429 -3.61673 2.08977 MAarrowhead1
% End of user PostScript
.07143 .44643 m
.04445 .43259 L
s
% Start of user PostScript
-3.42857 2.57143 -3.6444 2.46075 MAarrowhead1
% End of user PostScript
.07143 .49107 m
.04099 .47897 L
s
% Start of user PostScript
-3.42857 2.92857 -3.67206 2.83173 MAarrowhead1
% End of user PostScript
.07143 .53571 m
.03753 .52534 L
s
% Start of user PostScript
-3.42857 3.28571 -3.69973 3.20271 MAarrowhead1
% End of user PostScript
.07143 .58036 m
.03407 .57171 L
s
% Start of user PostScript
-3.42857 3.64286 -3.7274 3.57368 MAarrowhead1
% End of user PostScript
.07143 .625 m
.03062 .61808 L
s
% Start of user PostScript
-3.42857 4. -3.75507 3.94466 MAarrowhead1
% End of user PostScript
.14286 0 m
0 0 rlineto s
% Start of user PostScript
-2.85714 -1. -2.77413 -1.22689 MAarrowhead1
% End of user PostScript
.14286 .04464 m
.14977 .01801 L
s
% Start of user PostScript
-2.85714 -0.642857 -2.8018 -0.855914 MAarrowhead1
% End of user PostScript
.14286 .08929 m
.14632 .06438 L
s
% Start of user PostScript
-2.85714 -0.285714 -2.82947 -0.484936 MAarrowhead1
% End of user PostScript
.14286 .13393 m
.14286 .11076 L
s
% Start of user PostScript
-2.85714 0.0714286 -2.85714 -0.113958 MAarrowhead1
% End of user PostScript
.14286 .17857 m
.1394 .15713 L
s
% Start of user PostScript
-2.85714 0.428571 -2.88481 0.257019 MAarrowhead1
% End of user PostScript
.14286 .22321 m
.13594 .2035 L
s
% Start of user PostScript
-2.85714 0.785714 -2.91248 0.627997 MAarrowhead1
% End of user PostScript
.14286 .26786 m
.13248 .24987 L
s
% Start of user PostScript
-2.85714 1.14286 -2.94015 0.998975 MAarrowhead1
% End of user PostScript
.14286 .3125 m
.12902 .29624 L
s
% Start of user PostScript
-2.85714 1.5 -2.96782 1.36995 MAarrowhead1
% End of user PostScript
.14286 .35714 m
.12556 .34262 L
s
% Start of user PostScript
-2.85714 1.85714 -2.99549 1.74093 MAarrowhead1
% End of user PostScript
.14286 .40179 m
.1221 .38899 L
s
% Start of user PostScript
-2.85714 2.21429 -3.02316 2.11191 MAarrowhead1
% End of user PostScript
.14286 .44643 m
.11865 .43536 L
s
% Start of user PostScript
-2.85714 2.57143 -3.05083 2.48289 MAarrowhead1
% End of user PostScript
.14286 .49107 m
.11519 .48173 L
s
% Start of user PostScript
-2.85714 2.92857 -3.0785 2.85386 MAarrowhead1
% End of user PostScript
.14286 .53571 m
.11173 .52811 L
s
% Start of user PostScript
-2.85714 3.28571 -3.10617 3.22484 MAarrowhead1
% End of user PostScript
.14286 .58036 m
.10827 .57448 L
s
% Start of user PostScript
-2.85714 3.64286 -3.13384 3.59582 MAarrowhead1
% End of user PostScript
.14286 .625 m
.10481 .62085 L
s
% Start of user PostScript
-2.85714 4. -3.16151 3.9668 MAarrowhead1
% End of user PostScript
.21429 0 m
0 0 rlineto s
% Start of user PostScript
-2.28571 -1. -2.18057 -1.20476 MAarrowhead1
% End of user PostScript
.21429 .04464 m
.22397 .02078 L
s
% Start of user PostScript
-2.28571 -0.642857 -2.20824 -0.833778 MAarrowhead1
% End of user PostScript
.21429 .08929 m
.22051 .06715 L
s
% Start of user PostScript
-2.28571 -0.285714 -2.23591 -0.4628 MAarrowhead1
% End of user PostScript
.21429 .13393 m
.21705 .11352 L
s
% Start of user PostScript
-2.28571 0.0714286 -2.26358 -0.0918227 MAarrowhead1
% End of user PostScript
.21429 .17857 m
.21359 .15989 L
s
% Start of user PostScript
-2.28571 0.428571 -2.29125 0.279155 MAarrowhead1
% End of user PostScript
.21429 .22321 m
.21014 .20627 L
s
% Start of user PostScript
-2.28571 0.785714 -2.31892 0.650133 MAarrowhead1
% End of user PostScript
.21429 .26786 m
.20668 .25264 L
s
% Start of user PostScript
-2.28571 1.14286 -2.34659 1.02111 MAarrowhead1
% End of user PostScript
.21429 .3125 m
.20322 .29901 L
s
% Start of user PostScript
-2.28571 1.5 -2.37426 1.39209 MAarrowhead1
% End of user PostScript
.21429 .35714 m
.19976 .34538 L
s
% Start of user PostScript
-2.28571 1.85714 -2.40193 1.76307 MAarrowhead1
% End of user PostScript
.21429 .40179 m
.1963 .39176 L
s
% Start of user PostScript
-2.28571 2.21429 -2.4296 2.13404 MAarrowhead1
% End of user PostScript
.21429 .44643 m
.19284 .43813 L
s
% Start of user PostScript
-2.28571 2.57143 -2.45727 2.50502 MAarrowhead1
% End of user PostScript
.21429 .49107 m
.18938 .4845 L
s
% Start of user PostScript
-2.28571 2.92857 -2.48494 2.876 MAarrowhead1
% End of user PostScript
.21429 .53571 m
.18592 .53087 L
s
% Start of user PostScript
-2.28571 3.28571 -2.51261 3.24698 MAarrowhead1
% End of user PostScript
.21429 .58036 m
.18247 .57724 L
s
% Start of user PostScript
-2.28571 3.64286 -2.54028 3.61795 MAarrowhead1
% End of user PostScript
.21429 .625 m
.17901 .62362 L
s
% Start of user PostScript
-2.28571 4. -2.56795 3.98893 MAarrowhead1
% End of user PostScript
.28571 0 m
0 0 rlineto s
% Start of user PostScript
-1.71429 -1. -1.58701 -1.18262 MAarrowhead1
% End of user PostScript
.28571 .04464 m
.29817 .02354 L
s
% Start of user PostScript
-1.71429 -0.642857 -1.61467 -0.811642 MAarrowhead1
% End of user PostScript
.28571 .08929 m
.29471 .06992 L
s
% Start of user PostScript
-1.71429 -0.285714 -1.64234 -0.440665 MAarrowhead1
% End of user PostScript
.28571 .13393 m
.29125 .11629 L
s
% Start of user PostScript
-1.71429 0.0714286 -1.67001 -0.0696869 MAarrowhead1
% End of user PostScript
.28571 .17857 m
.28779 .16266 L
s
% Start of user PostScript
-1.71429 0.428571 -1.69768 0.301291 MAarrowhead1
% End of user PostScript
.28571 .22321 m
.28433 .20903 L
s
% Start of user PostScript
-1.71429 0.785714 -1.72535 0.672269 MAarrowhead1
% End of user PostScript
.28571 .26786 m
.28087 .25541 L
s
% Start of user PostScript
-1.71429 1.14286 -1.75302 1.04325 MAarrowhead1
% End of user PostScript
.28571 .3125 m
.27741 .30178 L
s
% Start of user PostScript
-1.71429 1.5 -1.78069 1.41422 MAarrowhead1
% End of user PostScript
.28571 .35714 m
.27395 .34815 L
s
% Start of user PostScript
-1.71429 1.85714 -1.80836 1.7852 MAarrowhead1
% End of user PostScript
.28571 .40179 m
.2705 .39452 L
s
% Start of user PostScript
-1.71429 2.21429 -1.83603 2.15618 MAarrowhead1
% End of user PostScript
.28571 .44643 m
.26704 .44089 L
s
% Start of user PostScript
-1.71429 2.57143 -1.8637 2.52716 MAarrowhead1
% End of user PostScript
.28571 .49107 m
.26358 .48727 L
s
% Start of user PostScript
-1.71429 2.92857 -1.89137 2.89813 MAarrowhead1
% End of user PostScript
.28571 .53571 m
.26012 .53364 L
s
% Start of user PostScript
-1.71429 3.28571 -1.91904 3.26911 MAarrowhead1
% End of user PostScript
.28571 .58036 m
.25666 .58001 L
s
% Start of user PostScript
-1.71429 3.64286 -1.94671 3.64009 MAarrowhead1
% End of user PostScript
.28571 .625 m
0 0 rlineto s
.28571 .625 m
.28571 .625 L
s
% Start of user PostScript
-1.71429 4. -1.97438 4.01107 MAarrowhead1
% End of user PostScript
.35714 0 m
0 0 rlineto s
% Start of user PostScript
-1.14286 -1. -0.993441 -1.16048 MAarrowhead1
% End of user PostScript
.35714 .04464 m
.37236 .02631 L
s
% Start of user PostScript
-1.14286 -0.642857 -1.02111 -0.789507 MAarrowhead1
% End of user PostScript
.35714 .08929 m
.3689 .07268 L
s
% Start of user PostScript
-1.14286 -0.285714 -1.04878 -0.418529 MAarrowhead1
% End of user PostScript
.35714 .13393 m
.36544 .11906 L
s
% Start of user PostScript
-1.14286 0.0714286 -1.07645 -0.0475511 MAarrowhead1
% End of user PostScript
.35714 .17857 m
.36199 .16543 L
s
% Start of user PostScript
-1.14286 0.428571 -1.10412 0.323427 MAarrowhead1
% End of user PostScript
.35714 .22321 m
.35853 .2118 L
s
% Start of user PostScript
-1.14286 0.785714 -1.13179 0.694404 MAarrowhead1
% End of user PostScript
.35714 .26786 m
.35507 .25817 L
s
% Start of user PostScript
-1.14286 1.14286 -1.15946 1.06538 MAarrowhead1
% End of user PostScript
.35714 .3125 m
.35161 .30454 L
s
% Start of user PostScript
-1.14286 1.5 -1.18713 1.43636 MAarrowhead1
% End of user PostScript
.35714 .35714 m
.34815 .35092 L
s
% Start of user PostScript
-1.14286 1.85714 -1.2148 1.80734 MAarrowhead1
% End of user PostScript
.35714 .40179 m
.34469 .39729 L
s
% Start of user PostScript
-1.14286 2.21429 -1.24247 2.17832 MAarrowhead1
% End of user PostScript
.35714 .44643 m
.34123 .44366 L
s
% Start of user PostScript
-1.14286 2.57143 -1.27014 2.54929 MAarrowhead1
% End of user PostScript
.35714 .49107 m
.33777 .49003 L
s
% Start of user PostScript
-1.14286 2.92857 -1.29781 2.92027 MAarrowhead1
% End of user PostScript
.35714 .53571 m
.33432 .53641 L
s
% Start of user PostScript
-1.14286 3.28571 -1.32548 3.29125 MAarrowhead1
% End of user PostScript
.35714 .58036 m
.33086 .58278 L
s
% Start of user PostScript
-1.14286 3.64286 -1.35315 3.66223 MAarrowhead1
% End of user PostScript
.35714 .625 m
0 0 rlineto s
.35714 .625 m
.35714 .625 L
s
% Start of user PostScript
-1.14286 4. -1.38082 4.0332 MAarrowhead1
% End of user PostScript
.42857 0 m
0 0 rlineto s
% Start of user PostScript
-0.571429 -1. -0.399876 -1.13835 MAarrowhead1
% End of user PostScript
.42857 .04464 m
.44656 .02908 L
s
% Start of user PostScript
-0.571429 -0.642857 -0.427546 -0.767371 MAarrowhead1
% End of user PostScript
.42857 .08929 m
.4431 .07545 L
s
% Start of user PostScript
-0.571429 -0.285714 -0.455216 -0.396393 MAarrowhead1
% End of user PostScript
.42857 .13393 m
.43964 .12182 L
s
% Start of user PostScript
-0.571429 0.0714286 -0.482886 -0.0254154 MAarrowhead1
% End of user PostScript
.42857 .17857 m
.43618 .1682 L
s
% Start of user PostScript
-0.571429 0.428571 -0.510555 0.345562 MAarrowhead1
% End of user PostScript
.42857 .22321 m
.43272 .21457 L
s
% Start of user PostScript
-0.571429 0.785714 -0.538225 0.71654 MAarrowhead1
% End of user PostScript
.42857 .26786 m
.42926 .26094 L
s
% Start of user PostScript
-0.571429 1.14286 -0.565895 1.08752 MAarrowhead1
% End of user PostScript
.42857 .3125 m
.4258 .30731 L
s
% Start of user PostScript
-0.571429 1.5 -0.593564 1.4585 MAarrowhead1
% End of user PostScript
.42857 .35714 m
.42235 .35368 L
s
% Start of user PostScript
-0.571429 1.85714 -0.621234 1.82947 MAarrowhead1
% End of user PostScript
.42857 .40179 m
.41889 .40006 L
s
% Start of user PostScript
-0.571429 2.21429 -0.648904 2.20045 MAarrowhead1
% End of user PostScript
.42857 .44643 m
.41543 .44643 L
s
% Start of user PostScript
-0.571429 2.57143 -0.676573 2.57143 MAarrowhead1
% End of user PostScript
.42857 .49107 m
.41197 .4928 L
s
% Start of user PostScript
-0.571429 2.92857 -0.704243 2.94241 MAarrowhead1
% End of user PostScript
.42857 .53571 m
.40851 .53917 L
s
% Start of user PostScript
-0.571429 3.28571 -0.731913 3.31338 MAarrowhead1
% End of user PostScript
.42857 .58036 m
.40505 .58555 L
s
% Start of user PostScript
-0.571429 3.64286 -0.759583 3.68436 MAarrowhead1
% End of user PostScript
.42857 .625 m
0 0 rlineto s
.42857 .625 m
.42857 .625 L
s
% Start of user PostScript
-0.571429 4. -0.787252 4.05534 MAarrowhead1
% End of user PostScript
.5 0 m
0 0 rlineto s
% Start of user PostScript
0 -1. 0.193688 -1.11621 MAarrowhead1
% End of user PostScript
.5 .04464 m
.52075 .03185 L
s
% Start of user PostScript
0 -0.642857 0.166018 -0.745235 MAarrowhead1
% End of user PostScript
.5 .08929 m
.51729 .07822 L
s
% Start of user PostScript
0 -0.285714 0.138349 -0.374257 MAarrowhead1
% End of user PostScript
.5 .13393 m
.51383 .12459 L
s
% Start of user PostScript
0 0.0714286 0.110679 -0.00327962 MAarrowhead1
% End of user PostScript
.5 .17857 m
.51038 .17096 L
s
% Start of user PostScript
0 0.428571 0.0830091 0.367698 MAarrowhead1
% End of user PostScript
.5 .22321 m
.50692 .21733 L
s
% Start of user PostScript
0 0.785714 0.0553394 0.738676 MAarrowhead1
% End of user PostScript
.5 .26786 m
.50346 .26371 L
s
% Start of user PostScript
0 1.14286 0.0276697 1.10965 MAarrowhead1
% End of user PostScript
.5 .3125 m
.5 .31008 L
s
% Start of user PostScript
0 1.5 0 1.48063 MAarrowhead1
% End of user PostScript
.5 .35714 m
.49654 .35645 L
s
% Start of user PostScript
0 1.85714 -0.0276697 1.85161 MAarrowhead1
% End of user PostScript
.5 .40179 m
.49308 .40282 L
s
% Start of user PostScript
0 2.21429 -0.0553394 2.22259 MAarrowhead1
% End of user PostScript
.5 .44643 m
.48962 .4492 L
s
% Start of user PostScript
0 2.57143 -0.0830091 2.59356 MAarrowhead1
% End of user PostScript
.5 .49107 m
.48617 .49557 L
s
% Start of user PostScript
0 2.92857 -0.110679 2.96454 MAarrowhead1
% End of user PostScript
.5 .53571 m
.48271 .54194 L
s
% Start of user PostScript
0 3.28571 -0.138349 3.33552 MAarrowhead1
% End of user PostScript
.5 .58036 m
.47925 .58831 L
s
% Start of user PostScript
0 3.64286 -0.166018 3.7065 MAarrowhead1
% End of user PostScript
.5 .625 m
0 0 rlineto s
.5 .625 m
.5 .625 L
s
% Start of user PostScript
0 4. -0.193688 4.07748 MAarrowhead1
% End of user PostScript
.57143 0 m
0 0 rlineto s
% Start of user PostScript
0.571429 -1. 0.787252 -1.09408 MAarrowhead1
% End of user PostScript
.57143 .04464 m
.59495 .03461 L
s
% Start of user PostScript
0.571429 -0.642857 0.759583 -0.723099 MAarrowhead1
% End of user PostScript
.57143 .08929 m
.59149 .08098 L
s
% Start of user PostScript
0.571429 -0.285714 0.731913 -0.352122 MAarrowhead1
% End of user PostScript
.57143 .13393 m
.58803 .12736 L
s
% Start of user PostScript
0.571429 0.0714286 0.704243 0.0188561 MAarrowhead1
% End of user PostScript
.57143 .17857 m
.58457 .17373 L
s
% Start of user PostScript
0.571429 0.428571 0.676573 0.389834 MAarrowhead1
% End of user PostScript
.57143 .22321 m
.58111 .2201 L
s
% Start of user PostScript
0.571429 0.785714 0.648904 0.760812 MAarrowhead1
% End of user PostScript
.57143 .26786 m
.57765 .26647 L
s
% Start of user PostScript
0.571429 1.14286 0.621234 1.13179 MAarrowhead1
% End of user PostScript
.57143 .3125 m
.5742 .31285 L
s
% Start of user PostScript
0.571429 1.5 0.593564 1.50277 MAarrowhead1
% End of user PostScript
.57143 .35714 m
.57074 .35922 L
s
% Start of user PostScript
0.571429 1.85714 0.565895 1.87374 MAarrowhead1
% End of user PostScript
.57143 .40179 m
.56728 .40559 L
s
% Start of user PostScript
0.571429 2.21429 0.538225 2.24472 MAarrowhead1
% End of user PostScript
.57143 .44643 m
.56382 .45196 L
s
% Start of user PostScript
0.571429 2.57143 0.510555 2.6157 MAarrowhead1
% End of user PostScript
.57143 .49107 m
.56036 .49833 L
s
% Start of user PostScript
0.571429 2.92857 0.482886 2.98668 MAarrowhead1
% End of user PostScript
.57143 .53571 m
.5569 .54471 L
s
% Start of user PostScript
0.571429 3.28571 0.455216 3.35766 MAarrowhead1
% End of user PostScript
.57143 .58036 m
.55344 .59108 L
s
% Start of user PostScript
0.571429 3.64286 0.427546 3.72863 MAarrowhead1
% End of user PostScript
.57143 .625 m
0 0 rlineto s
.57143 .625 m
.57143 .625 L
s
% Start of user PostScript
0.571429 4. 0.399876 4.09961 MAarrowhead1
% End of user PostScript
.64286 0 m
0 0 rlineto s
% Start of user PostScript
1.14286 -1. 1.38082 -1.07194 MAarrowhead1
% End of user PostScript
.64286 .04464 m
.66914 .03738 L
s
% Start of user PostScript
1.14286 -0.642857 1.35315 -0.700964 MAarrowhead1
% End of user PostScript
.64286 .08929 m
.66568 .08375 L
s
% Start of user PostScript
1.14286 -0.285714 1.32548 -0.329986 MAarrowhead1
% End of user PostScript
.64286 .13393 m
.66223 .13012 L
s
% Start of user PostScript
1.14286 0.0714286 1.29781 0.0409919 MAarrowhead1
% End of user PostScript
.64286 .17857 m
.65877 .1765 L
s
% Start of user PostScript
1.14286 0.428571 1.27014 0.41197 MAarrowhead1
% End of user PostScript
.64286 .22321 m
.65531 .22287 L
s
% Start of user PostScript
1.14286 0.785714 1.24247 0.782947 MAarrowhead1
% End of user PostScript
.64286 .26786 m
.65185 .26924 L
s
% Start of user PostScript
1.14286 1.14286 1.2148 1.15393 MAarrowhead1
% End of user PostScript
.64286 .3125 m
.64839 .31561 L
s
% Start of user PostScript
1.14286 1.5 1.18713 1.5249 MAarrowhead1
% End of user PostScript
.64286 .35714 m
.64493 .36199 L
s
% Start of user PostScript
1.14286 1.85714 1.15946 1.89588 MAarrowhead1
% End of user PostScript
.64286 .40179 m
.64147 .40836 L
s
% Start of user PostScript
1.14286 2.21429 1.13179 2.26686 MAarrowhead1
% End of user PostScript
.64286 .44643 m
.63801 .45473 L
s
% Start of user PostScript
1.14286 2.57143 1.10412 2.63784 MAarrowhead1
% End of user PostScript
.64286 .49107 m
.63456 .5011 L
s
% Start of user PostScript
1.14286 2.92857 1.07645 3.00881 MAarrowhead1
% End of user PostScript
.64286 .53571 m
.6311 .54747 L
s
% Start of user PostScript
1.14286 3.28571 1.04878 3.37979 MAarrowhead1
% End of user PostScript
.64286 .58036 m
.62764 .59385 L
s
% Start of user PostScript
1.14286 3.64286 1.02111 3.75077 MAarrowhead1
% End of user PostScript
.64286 .625 m
0 0 rlineto s
.64286 .625 m
.64286 .625 L
s
% Start of user PostScript
1.14286 4. 0.993441 4.12175 MAarrowhead1
% End of user PostScript
.71429 0 m
0 0 rlineto s
% Start of user PostScript
1.71429 -1. 1.97438 -1.04981 MAarrowhead1
% End of user PostScript
.71429 .04464 m
.74334 .04015 L
s
% Start of user PostScript
1.71429 -0.642857 1.94671 -0.678828 MAarrowhead1
% End of user PostScript
.71429 .08929 m
.73988 .08652 L
s
% Start of user PostScript
1.71429 -0.285714 1.91904 -0.30785 MAarrowhead1
% End of user PostScript
.71429 .13393 m
.73642 .13289 L
s
% Start of user PostScript
1.71429 0.0714286 1.89137 0.0631277 MAarrowhead1
% End of user PostScript
.71429 .17857 m
.73296 .17926 L
s
% Start of user PostScript
1.71429 0.428571 1.8637 0.434105 MAarrowhead1
% End of user PostScript
.71429 .22321 m
.7295 .22564 L
s
% Start of user PostScript
1.71429 0.785714 1.83603 0.805083 MAarrowhead1
% End of user PostScript
.71429 .26786 m
.72605 .27201 L
s
% Start of user PostScript
1.71429 1.14286 1.80836 1.17606 MAarrowhead1
% End of user PostScript
.71429 .3125 m
.72259 .31838 L
s
% Start of user PostScript
1.71429 1.5 1.78069 1.54704 MAarrowhead1
% End of user PostScript
.71429 .35714 m
.71913 .36475 L
s
% Start of user PostScript
1.71429 1.85714 1.75302 1.91802 MAarrowhead1
% End of user PostScript
.71429 .40179 m
.71567 .41112 L
s
% Start of user PostScript
1.71429 2.21429 1.72535 2.28899 MAarrowhead1
% End of user PostScript
.71429 .44643 m
.71221 .4575 L
s
% Start of user PostScript
1.71429 2.57143 1.69768 2.65997 MAarrowhead1
% End of user PostScript
.71429 .49107 m
.70875 .50387 L
s
% Start of user PostScript
1.71429 2.92857 1.67001 3.03095 MAarrowhead1
% End of user PostScript
.71429 .53571 m
.70529 .55024 L
s
% Start of user PostScript
1.71429 3.28571 1.64234 3.40193 MAarrowhead1
% End of user PostScript
.71429 .58036 m
.70183 .59661 L
s
% Start of user PostScript
1.71429 3.64286 1.61467 3.7729 MAarrowhead1
% End of user PostScript
.71429 .625 m
0 0 rlineto s
.71429 .625 m
.71429 .625 L
s
% Start of user PostScript
1.71429 4. 1.58701 4.14388 MAarrowhead1
% End of user PostScript
.78571 0 m
0 0 rlineto s
% Start of user PostScript
2.28571 -1. 2.56795 -1.02767 MAarrowhead1
% End of user PostScript
.78571 .04464 m
.81753 .04291 L
s
% Start of user PostScript
2.28571 -0.642857 2.54028 -0.656692 MAarrowhead1
% End of user PostScript
.78571 .08929 m
.81408 .08929 L
s
% Start of user PostScript
2.28571 -0.285714 2.51261 -0.285714 MAarrowhead1
% End of user PostScript
.78571 .13393 m
.81062 .13566 L
s
% Start of user PostScript
2.28571 0.0714286 2.48494 0.0852634 MAarrowhead1
% End of user PostScript
.78571 .17857 m
.80716 .18203 L
s
% Start of user PostScript
2.28571 0.428571 2.45727 0.456241 MAarrowhead1
% End of user PostScript
.78571 .22321 m
.8037 .2284 L
s
% Start of user PostScript
2.28571 0.785714 2.4296 0.827219 MAarrowhead1
% End of user PostScript
.78571 .26786 m
.80024 .27477 L
s
% Start of user PostScript
2.28571 1.14286 2.40193 1.1982 MAarrowhead1
% End of user PostScript
.78571 .3125 m
.79678 .32115 L
s
% Start of user PostScript
2.28571 1.5 2.37426 1.56917 MAarrowhead1
% End of user PostScript
.78571 .35714 m
.79332 .36752 L
s
% Start of user PostScript
2.28571 1.85714 2.34659 1.94015 MAarrowhead1
% End of user PostScript
.78571 .40179 m
.78986 .41389 L
s
% Start of user PostScript
2.28571 2.21429 2.31892 2.31113 MAarrowhead1
% End of user PostScript
.78571 .44643 m
.78641 .46026 L
s
% Start of user PostScript
2.28571 2.57143 2.29125 2.68211 MAarrowhead1
% End of user PostScript
.78571 .49107 m
.78295 .50664 L
s
% Start of user PostScript
2.28571 2.92857 2.26358 3.05309 MAarrowhead1
% End of user PostScript
.78571 .53571 m
.77949 .55301 L
s
% Start of user PostScript
2.28571 3.28571 2.23591 3.42406 MAarrowhead1
% End of user PostScript
.78571 .58036 m
.77603 .59938 L
s
% Start of user PostScript
2.28571 3.64286 2.20824 3.79504 MAarrowhead1
% End of user PostScript
.78571 .625 m
0 0 rlineto s
.78571 .625 m
.78571 .625 L
s
% Start of user PostScript
2.28571 4. 2.18057 4.16602 MAarrowhead1
% End of user PostScript
.85714 0 m
0 0 rlineto s
% Start of user PostScript
2.85714 -1. 3.16151 -1.00553 MAarrowhead1
% End of user PostScript
.85714 .04464 m
.89173 .04568 L
s
% Start of user PostScript
2.85714 -0.642857 3.13384 -0.634556 MAarrowhead1
% End of user PostScript
.85714 .08929 m
.88827 .09205 L
s
% Start of user PostScript
2.85714 -0.285714 3.10617 -0.263579 MAarrowhead1
% End of user PostScript
.85714 .13393 m
.88481 .13842 L
s
% Start of user PostScript
2.85714 0.0714286 3.0785 0.107399 MAarrowhead1
% End of user PostScript
.85714 .17857 m
.88135 .1848 L
s
% Start of user PostScript
2.85714 0.428571 3.05083 0.478377 MAarrowhead1
% End of user PostScript
.85714 .22321 m
.8779 .23117 L
s
% Start of user PostScript
2.85714 0.785714 3.02316 0.849355 MAarrowhead1
% End of user PostScript
.85714 .26786 m
.87444 .27754 L
s
% Start of user PostScript
2.85714 1.14286 2.99549 1.22033 MAarrowhead1
% End of user PostScript
.85714 .3125 m
.87098 .32391 L
s
% Start of user PostScript
2.85714 1.5 2.96782 1.59131 MAarrowhead1
% End of user PostScript
.85714 .35714 m
.86752 .37029 L
s
% Start of user PostScript
2.85714 1.85714 2.94015 1.96229 MAarrowhead1
% End of user PostScript
.85714 .40179 m
.86406 .41666 L
s
% Start of user PostScript
2.85714 2.21429 2.91248 2.33327 MAarrowhead1
% End of user PostScript
.85714 .44643 m
.8606 .46303 L
s
% Start of user PostScript
2.85714 2.57143 2.88481 2.70424 MAarrowhead1
% End of user PostScript
.85714 .49107 m
.85714 .5094 L
s
% Start of user PostScript
2.85714 2.92857 2.85714 3.07522 MAarrowhead1
% End of user PostScript
.85714 .53571 m
.85368 .55577 L
s
% Start of user PostScript
2.85714 3.28571 2.82947 3.4462 MAarrowhead1
% End of user PostScript
.85714 .58036 m
.85023 .60215 L
s
% Start of user PostScript
2.85714 3.64286 2.8018 3.81718 MAarrowhead1
% End of user PostScript
.85714 .625 m
0 0 rlineto s
.85714 .625 m
.85714 .625 L
s
% Start of user PostScript
2.85714 4. 2.77413 4.18815 MAarrowhead1
% End of user PostScript
.92857 0 m
.96938 .00208 L
s
% Start of user PostScript
3.42857 -1. 3.75507 -0.983398 MAarrowhead1
% End of user PostScript
.92857 .04464 m
.96593 .04845 L
s
% Start of user PostScript
3.42857 -0.642857 3.7274 -0.61242 MAarrowhead1
% End of user PostScript
.92857 .08929 m
.96247 .09482 L
s
% Start of user PostScript
3.42857 -0.285714 3.69973 -0.241443 MAarrowhead1
% End of user PostScript
.92857 .13393 m
.95901 .14119 L
s
% Start of user PostScript
3.42857 0.0714286 3.67206 0.129535 MAarrowhead1
% End of user PostScript
.92857 .17857 m
.95555 .18756 L
s
% Start of user PostScript
3.42857 0.428571 3.6444 0.500513 MAarrowhead1
% End of user PostScript
.92857 .22321 m
.95209 .23394 L
s
% Start of user PostScript
3.42857 0.785714 3.61673 0.87149 MAarrowhead1
% End of user PostScript
.92857 .26786 m
.94863 .28031 L
s
% Start of user PostScript
3.42857 1.14286 3.58906 1.24247 MAarrowhead1
% End of user PostScript
.92857 .3125 m
.94517 .32668 L
s
% Start of user PostScript
3.42857 1.5 3.56139 1.61345 MAarrowhead1
% End of user PostScript
.92857 .35714 m
.94171 .37305 L
s
% Start of user PostScript
3.42857 1.85714 3.53372 1.98442 MAarrowhead1
% End of user PostScript
.92857 .40179 m
.93826 .41943 L
s
% Start of user PostScript
3.42857 2.21429 3.50605 2.3554 MAarrowhead1
% End of user PostScript
.92857 .44643 m
.9348 .4658 L
s
% Start of user PostScript
3.42857 2.57143 3.47838 2.72638 MAarrowhead1
% End of user PostScript
.92857 .49107 m
.93134 .51217 L
s
% Start of user PostScript
3.42857 2.92857 3.45071 3.09736 MAarrowhead1
% End of user PostScript
.92857 .53571 m
.92788 .55854 L
s
% Start of user PostScript
3.42857 3.28571 3.42304 3.46833 MAarrowhead1
% End of user PostScript
.92857 .58036 m
.92442 .60491 L
s
% Start of user PostScript
3.42857 3.64286 3.39537 3.83931 MAarrowhead1
% End of user PostScript
.92857 .625 m
0 0 rlineto s
.92857 .625 m
.92857 .625 L
s
% Start of user PostScript
3.42857 4. 3.3677 4.21029 MAarrowhead1
% End of user PostScript
1 0 m
0 0 rlineto s
% Start of user PostScript
4. -1. 4.34864 -0.961262 MAarrowhead1
% End of user PostScript
1 .04464 m
0 0 rlineto s
1 .04464 m
1 .04464 L
s
% Start of user PostScript
4. -0.642857 4.32097 -0.590285 MAarrowhead1
% End of user PostScript
1 .08929 m
0 0 rlineto s
1 .08929 m
1 .08929 L
s
% Start of user PostScript
4. -0.285714 4.2933 -0.219307 MAarrowhead1
% End of user PostScript
1 .13393 m
0 0 rlineto s
1 .13393 m
1 .13393 L
s
% Start of user PostScript
4. 0.0714286 4.26563 0.151671 MAarrowhead1
% End of user PostScript
1 .17857 m
0 0 rlineto s
1 .17857 m
1 .17857 L
s
% Start of user PostScript
4. 0.428571 4.23796 0.522648 MAarrowhead1
% End of user PostScript
1 .22321 m
0 0 rlineto s
1 .22321 m
1 .22321 L
s
% Start of user PostScript
4. 0.785714 4.21029 0.893626 MAarrowhead1
% End of user PostScript
1 .26786 m
0 0 rlineto s
1 .26786 m
1 .26786 L
s
% Start of user PostScript
4. 1.14286 4.18262 1.2646 MAarrowhead1
% End of user PostScript
1 .3125 m
0 0 rlineto s
1 .3125 m
1 .3125 L
s
% Start of user PostScript
4. 1.5 4.15495 1.63558 MAarrowhead1
% End of user PostScript
1 .35714 m
0 0 rlineto s
1 .35714 m
1 .35714 L
s
% Start of user PostScript
4. 1.85714 4.12728 2.00656 MAarrowhead1
% End of user PostScript
1 .40179 m
0 0 rlineto s
1 .40179 m
1 .40179 L
s
% Start of user PostScript
4. 2.21429 4.09961 2.37754 MAarrowhead1
% End of user PostScript
1 .44643 m
0 0 rlineto s
1 .44643 m
1 .44643 L
s
% Start of user PostScript
4. 2.57143 4.07194 2.74851 MAarrowhead1
% End of user PostScript
1 .49107 m
0 0 rlineto s
1 .49107 m
1 .49107 L
s
% Start of user PostScript
4. 2.92857 4.04427 3.11949 MAarrowhead1
% End of user PostScript
1 .53571 m
0 0 rlineto s
1 .53571 m
1 .53571 L
s
% Start of user PostScript
4. 3.28571 4.0166 3.49047 MAarrowhead1
% End of user PostScript
1 .58036 m
.99862 .60768 L
s
% Start of user PostScript
4. 3.64286 3.98893 3.86145 MAarrowhead1
% End of user PostScript
1 .625 m
0 0 rlineto s
1 .625 m
1 .625 L
s
% Start of user PostScript
4. 4. 3.96126 4.23243 MAarrowhead1
% End of user PostScript
0 1 0 r
.5 Mabswid
.53475 .36139 m
.53166 .36233 L
.52801 .36324 L
.5239 .36403 L
.51979 .36459 L
.51732 .36483 L
.51607 .36492 L
.51491 .365 L
.51383 .36505 L
.51268 .36509 L
.51207 .36511 L
.5115 .36512 L
.51087 .36513 L
.51052 .36513 L
.51019 .36513 L
.50984 .36513 L
.50952 .36513 L
.50915 .36513 L
.5088 .36513 L
.50817 .36512 L
.50782 .36511 L
.50749 .3651 L
.50603 .36506 L
.50528 .36502 L
.50446 .36498 L
.50153 .36478 L
.49872 .3645 L
.49593 .36415 L
.49283 .36367 L
.48704 .36253 L
.48125 .36107 L
.47577 .35937 L
.46407 .35468 L
.4511 .34752 L
.43927 .33873 L
.42747 .32682 L
.41772 .31288 L
.41363 .30492 L
.41162 .30016 L
.40994 .29549 L
.40859 .29102 L
.40735 .28601 L
.40644 .28131 L
.40581 .27685 L
.40554 .2743 L
.40534 .27189 L
.40526 .27049 L
.4052 .2692 L
.40517 .26848 L
.40515 .2677 L
Mistroke
.40513 .26696 L
.40512 .26627 L
.40511 .26554 L
.40511 .26476 L
.40512 .26401 L
.40513 .26332 L
.40516 .26201 L
.40521 .26061 L
.40529 .2591 L
.40538 .25768 L
.40566 .25443 L
.406 .25147 L
.40639 .2487 L
.40756 .24232 L
.40893 .23658 L
.41075 .23037 L
.41483 .21936 L
.42078 .20688 L
.43761 .18121 L
.45025 .16649 L
.46399 .15296 L
.49625 .12753 L
.54134 .10111 L
.59424 .07858 L
.62829 .06755 L
.662 .05881 L
.69851 .05145 L
.73451 .04613 L
.75423 .04396 L
.77659 .04211 L
.78813 .0414 L
.79456 .04107 L
.80071 .0408 L
.80646 .0406 L
.81277 .04041 L
.81855 .04028 L
.82393 .0402 L
.8293 .04015 L
.835 .04013 L
.83989 .04015 L
.84527 .04019 L
.85113 .04028 L
.85442 .04035 L
.85742 .04042 L
.86887 .04078 L
.8796 .04125 L
.89136 .04191 L
.91305 .04352 L
.9393 .04614 L
.96773 .04979 L
Mistroke
Mfstroke
.96773 .04979 m
1 .05531 L
s
.54212 .34529 m
.53956 .34645 L
.53634 .34749 L
.53442 .34794 L
.5325 .34827 L
.53133 .34842 L
.53024 .34854 L
.52962 .34859 L
.52893 .34864 L
.52827 .34867 L
.52795 .34868 L
.52765 .34869 L
.52738 .3487 L
.52708 .34871 L
.5268 .34871 L
.52654 .34871 L
.52624 .34871 L
.52595 .34871 L
.5258 .34871 L
.52563 .34871 L
.52532 .3487 L
.52505 .3487 L
.52475 .34869 L
.52414 .34866 L
.52357 .34863 L
.52303 .3486 L
.52167 .34849 L
.5204 .34835 L
.51747 .34791 L
.51465 .34732 L
.51197 .34661 L
.50573 .34437 L
.50003 .34152 L
.49385 .33735 L
.48839 .33238 L
.48579 .32939 L
.48317 .3258 L
.48108 .32229 L
.47915 .31824 L
.47824 .31586 L
.47751 .3136 L
.47692 .31139 L
.4764 .30897 L
.47604 .3067 L
.47588 .30538 L
.47577 .30413 L
.47573 .30354 L
.47569 .30297 L
.47567 .30245 L
.47564 .30189 L
Mistroke
.47563 .30128 L
.47562 .30071 L
.47562 .30004 L
.47563 .29942 L
.47564 .29873 L
.47566 .29838 L
.47567 .298 L
.47575 .29668 L
.47581 .29593 L
.47589 .29512 L
.47606 .29364 L
.47653 .29069 L
.47711 .28795 L
.47883 .2821 L
.48106 .27652 L
.48427 .27022 L
.48864 .26338 L
.49936 .25065 L
.51295 .23869 L
.53236 .2259 L
.55445 .21505 L
.58158 .20537 L
.59901 .20075 L
.61655 .19717 L
.62595 .19564 L
.6365 .19423 L
.64681 .19315 L
.65184 .19273 L
.6566 .19239 L
.66133 .19211 L
.66569 .1919 L
.6706 .19172 L
.67333 .19164 L
.67594 .19159 L
.67847 .19155 L
.68118 .19153 L
.68351 .19152 L
.6861 .19153 L
.68888 .19155 L
.69046 .19158 L
.69191 .1916 L
.69459 .19166 L
.69744 .19175 L
.70339 .19198 L
.70908 .19228 L
.7199 .19304 L
.73179 .19418 L
.74497 .1958 L
.76937 .1998 L
.79257 .2048 L
Mistroke
.84365 .22004 L
.87342 .23174 L
.9015 .24486 L
.95823 .27846 L
Mfstroke
.95823 .27846 m
1 .31148 L
s
.54949 .3292 m
.55026 .32939 L
.55111 .32966 L
.55288 .33039 L
.55483 .33151 L
.55658 .33289 L
.55818 .33461 L
.55943 .3365 L
.55998 .33764 L
.5604 .33877 L
.5606 .33944 L
.56076 .34009 L
.56089 .34079 L
.56095 .34118 L
.561 .34159 L
.56103 .34196 L
.56105 .34217 L
.56106 .34236 L
.56106 .34254 L
.56107 .34274 L
.56107 .34293 L
.56107 .3431 L
.56107 .3433 L
.56106 .34349 L
.56106 .3436 L
.56106 .3437 L
.56104 .34393 L
.56103 .34415 L
.56101 .34439 L
.56096 .34484 L
.56084 .34566 L
.56066 .34656 L
.56018 .34823 L
.55953 .3499 L
.5586 .35175 L
.55626 .3552 L
.55261 .35906 L
.5474 .36307 L
.54114 .36662 L
.53405 .36959 L
.52941 .37109 L
.52465 .37233 L
.52005 .37327 L
.51734 .37372 L
.51472 .37409 L
.51186 .37442 L
.50916 .37465 L
.5077 .37476 L
.50608 .37485 L
.50518 .37489 L
Mistroke
.50434 .37492 L
.50348 .37495 L
.50267 .37497 L
.50182 .37499 L
.50137 .37499 L
.50089 .375 L
.50008 .375 L
.49962 .375 L
.49919 .375 L
.49838 .37499 L
.49763 .37498 L
.49677 .37496 L
.49595 .37494 L
.49411 .37486 L
.49238 .37477 L
.48841 .37448 L
.48507 .37414 L
.48141 .37367 L
.4746 .37254 L
.46625 .37068 L
.45839 .36845 L
.44288 .36261 L
.42576 .35366 L
.4099 .34242 L
.39412 .32723 L
.3871 .31853 L
.3802 .30814 L
.37494 .29834 L
.37008 .28671 L
.36816 .28092 L
.3664 .27448 L
.36513 .26873 L
.36403 .26229 L
.36354 .25842 L
.36319 .25478 L
.36294 .25125 L
.36285 .24945 L
.36281 .24842 L
.36278 .24744 L
.36275 .24573 L
.36274 .24392 L
.36274 .24236 L
.36278 .24064 L
.36283 .23877 L
.36288 .23772 L
.36292 .23676 L
.36316 .23311 L
.36347 .22972 L
.36391 .22595 L
.36513 .21818 L
Mistroke
.36667 .21084 L
.36849 .20383 L
.37399 .18762 L
.38222 .16962 L
.39231 .15225 L
.40614 .13294 L
.43955 .09729 L
.48356 .06271 L
.54385 .02775 L
.57881 .01184 L
Mfstroke
.57881 .01184 m
.61003 0 L
s
.55686 .3131 m
.55752 .31305 L
.55824 .313 L
.55886 .31296 L
.55955 .31292 L
.55998 .31291 L
.56038 .31289 L
.56076 .31288 L
.56116 .31288 L
.56153 .31287 L
.56187 .31287 L
.56226 .31287 L
.56267 .31287 L
.5631 .31288 L
.5635 .31288 L
.56394 .3129 L
.56442 .31291 L
.56531 .31295 L
.56612 .313 L
.56781 .31312 L
.56943 .31329 L
.57326 .31384 L
.57691 .31456 L
.58104 .31563 L
.58551 .31708 L
.59345 .3205 L
.60087 .3248 L
.60882 .33096 L
.6155 .33793 L
.62144 .34651 L
.62424 .35201 L
.62638 .35752 L
.62721 .36021 L
.62798 .3632 L
.62857 .36612 L
.629 .36888 L
.62919 .37049 L
.62934 .37201 L
.6294 .37288 L
.62945 .37371 L
.62947 .37416 L
.6295 .37466 L
.62953 .37554 L
.62954 .37641 L
.62955 .37691 L
.62955 .37738 L
.62955 .37787 L
.62954 .37832 L
.62953 .37885 L
.62952 .37935 L
Mistroke
.62948 .38024 L
.62944 .38106 L
.62931 .38296 L
.62912 .38488 L
.62889 .38667 L
.6282 .39078 L
.62738 .39449 L
.62627 .39847 L
.62376 .40556 L
.62007 .41356 L
.60945 .43019 L
.60144 .4397 L
.59275 .44841 L
.57212 .46493 L
.54333 .48205 L
.50929 .49676 L
.48958 .5033 L
.46584 .50964 L
.44219 .51449 L
.41899 .51799 L
.40623 .51943 L
.39184 .52066 L
.38439 .52114 L
.37632 .52154 L
.37235 .52169 L
.36858 .52181 L
.36517 .5219 L
.36145 .52197 L
.35782 .52201 L
.35448 .52203 L
.3506 .52202 L
.3469 .522 L
.34347 .52195 L
.34028 .52189 L
.33675 .5218 L
.33298 .52168 L
.32508 .52135 L
.31757 .52094 L
.30014 .51963 L
.28292 .51783 L
.2668 .51572 L
.22939 .50917 L
.19478 .50107 L
.16179 .49149 L
.08503 .46175 L
.00861 .42032 L
Mfstroke
.00861 .42032 m
0 .41407 L
s
.56423 .29701 m
.56659 .2967 L
.56885 .29645 L
.57141 .29624 L
.57287 .29615 L
.57422 .29608 L
.57492 .29605 L
.57566 .29603 L
.57631 .29601 L
.57701 .29599 L
.57776 .29598 L
.57847 .29598 L
.57891 .29598 L
.57933 .29598 L
.5797 .29598 L
.58011 .29598 L
.58087 .29599 L
.58156 .296 L
.58236 .29602 L
.58312 .29605 L
.58448 .29611 L
.58598 .29619 L
.58918 .29642 L
.59278 .29679 L
.59662 .29731 L
.60029 .29791 L
.60702 .2993 L
.61443 .30127 L
.62997 .30697 L
.64488 .31468 L
.65932 .32479 L
.67187 .3365 L
.68321 .35082 L
.68881 .36011 L
.69334 .36958 L
.69701 .37964 L
.69853 .38496 L
.6999 .39098 L
.70082 .39631 L
.70123 .39931 L
.70155 .40217 L
.70178 .40488 L
.70187 .40632 L
.70196 .40786 L
.70201 .40916 L
.70206 .4106 L
.70208 .41192 L
.70209 .41316 L
.70209 .41474 L
.70207 .41563 L
Mistroke
.70206 .41644 L
.70201 .41802 L
.70195 .41952 L
.70185 .42128 L
.70173 .42292 L
.70139 .42663 L
.70103 .4297 L
.70054 .43309 L
.69926 .44006 L
.69772 .44655 L
.69568 .45362 L
.6909 .4667 L
.6836 .48206 L
.67328 .49918 L
.6475 .53101 L
.61236 .56249 L
.5634 .59479 L
.50636 .62241 L
Mfstroke
.50636 .62241 m
.49898 .625 L
s
0 g
0 .0625 m
.00658 .06579 L
.02632 .07566 L
.03947 .08224 L
.05263 .08882 L
.07237 .09868 L
.07895 .10197 L
.10526 .11513 L
.10526 .11513 L
.13158 .12829 L
.13816 .13158 L
.15789 .14145 L
.17105 .14803 L
.18421 .15461 L
.20395 .16447 L
.21053 .16776 L
.23684 .18092 L
.23684 .18092 L
.26316 .19408 L
.26974 .19737 L
.28947 .20724 L
.30263 .21382 L
.31579 .22039 L
.33553 .23026 L
.34211 .23355 L
.36842 .24671 L
.36842 .24671 L
.39474 .25987 L
.40132 .26316 L
.42105 .27303 L
.43421 .27961 L
.44737 .28618 L
.46711 .29605 L
.47368 .29934 L
.5 .3125 L
.5 .3125 L
.52632 .32566 L
.53289 .32895 L
.55263 .33882 L
.56579 .34539 L
.57895 .35197 L
.59868 .36184 L
.60526 .36513 L
.63158 .37829 L
.63158 .37829 L
.65789 .39145 L
.66447 .39474 L
.68421 .40461 L
.69737 .41118 L
.71053 .41776 L
Mistroke
.73026 .42763 L
.73684 .43092 L
.76316 .44408 L
.76316 .44408 L
.78947 .45724 L
.79605 .46053 L
.81579 .47039 L
.82895 .47697 L
.84211 .48355 L
.86184 .49342 L
.86842 .49671 L
.89474 .50987 L
.89474 .50987 L
.92105 .52303 L
.92763 .52632 L
.94737 .53618 L
.96053 .54276 L
.97368 .54934 L
.99342 .55921 L
1 .5625 L
Mfstroke
.25 .625 m
.26316 .61184 L
.26645 .60855 L
.28289 .59211 L
.28947 .58553 L
.29934 .57566 L
.31579 .55921 L
.31579 .55921 L
.33224 .54276 L
.34211 .53289 L
.34868 .52632 L
.36513 .50987 L
.36842 .50658 L
.38158 .49342 L
.39474 .48026 L
.39803 .47697 L
.41447 .46053 L
.42105 .45395 L
.43092 .44408 L
.44737 .42763 L
.44737 .42763 L
.46382 .41118 L
.47368 .40132 L
.48026 .39474 L
.49671 .37829 L
.5 .375 L
.51316 .36184 L
.52632 .34868 L
.52961 .34539 L
.54605 .32895 L
.55263 .32237 L
.5625 .3125 L
.57895 .29605 L
.57895 .29605 L
.59539 .27961 L
.60526 .26974 L
.61184 .26316 L
.62829 .24671 L
.63158 .24342 L
.64474 .23026 L
.65789 .21711 L
.66118 .21382 L
.67763 .19737 L
.68421 .19079 L
.69408 .18092 L
.71053 .16447 L
.71053 .16447 L
.72697 .14803 L
.73684 .13816 L
.74342 .13158 L
Mistroke
.75987 .11513 L
.76316 .11184 L
.77632 .09868 L
.78947 .08553 L
.79276 .08224 L
.80921 .06579 L
.81579 .05921 L
.82566 .04934 L
.84211 .03289 L
.84211 .03289 L
.85855 .01645 L
.86842 .00658 L
.875 0 L
Mfstroke
.03 w
.54167 .33333 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[143]:=",
  ImageSize->{288, 180},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000hB000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oo
oooooooo0;Kooooo002]ooooo`03o`000?oooooooooo0;Sooooo000;ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`05o`000?oooooooooo
o`000?ooool01_l00005ooooo`03o`000?oooooooooo00Gooooo1?l0000Dooooo`05o`000?oooooo
ooooooooool000001oooool2o`3o00_ooooo00Co0000oooooooooooooooo0_l0000Booooo`04o`00
0?ooooooooooooooo`?o00004Oooool00ol0003oooooooooo`03ooooo`Go00003Oooool00ol0003o
ooooooooo`03ooooo`So00002oooool=o`0000_ooooo00?o0000ooooooooool01_ooool00:gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`?o0?l04Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Oooooo0_l0000Eooooo`03o`000?oooooo000000Co0000
5?ooool8o`0001;ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?oo
ool2o`3o05cooooo00?o0000ooooooooool00_l0000Gooooo`Co00005_ooool00:gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`?o0?l0G_ooool00ol0003oooooooooo`0c
ooooo`002oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05oooool2o`3o063ooooo00?o0000ooooooooool0=?ooool000_ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`24ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool05Oooool2o`3o067ooooo00?o0000ooooooooool0=Oooool000_ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0
4oooool2o`3o067ooooo0_l0000hooooo`002oooool2o`0001Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool04Ooo
ool2o`3o06;ooooo00?o0000ooooooooool0>?ooool000_ooooo0_l0000Fooooo`;o00006?ooool2
o`0001Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00oooooo0_l0o`1Sooooo`03o`000?oooooooooo03Wooooo000;ooooo`;o00005_ooool3o`00
01Kooooo0ol0000Gooooo`;o00005oooool2o`0001Oooooo0_l0000[ooooo`;o00003_ooool2o`3o
06Cooooo00?o0000ooooooooool0>_ooool000_ooooo0ol0000Eooooo`?o00005_ooool3o`0001Ko
oooo0ol0000Fooooo`?o00005_ooool3o`0001Sooooo0_l0000Aooooo`03o`000?oooooooooo00_o
oooo0_l0o`1Uooooo`03o`000?oooooooooo03_ooooo000;ooooo`?o00005?ooool4o`0001Gooooo
1?l0000Fooooo`;o00005_ooool3o`0001Kooooo0ol0000Fooooo`Go00004Oooool00ol0003ooooo
ooooo`02ooooo`?o00001?ooool2o`3o06Kooooo0_l0000mooooo`002oooool00ol0003ooooooooo
o`0Dooooo`Co00005?ooool5o`0001Gooooo0ol0000Eooooo`Co00005Oooool4o`0001Cooooo1_l0
000Booooo`03o`000?oooooo000000Co00000oooool2o`3o017ooooo1?l0001Cooooo`03o`000?oo
oooooooo03cooooo000;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool3
o`0001Cooooo1?l0000Dooooo`Go00005?ooool4o`0001Cooooo1_l0000Cooooo`Ko00000_ooool2
o`3o00oooooo1_l0000Cooooo`So00004_ooool5o`0001Cooooo0ol0000;ooooo`03o`000?oooooo
oooo03gooooo000;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Gooooo`;o00005_ooool2o`0001Kooooo0ol0000Eooooo`Go00004oooool5o`00
0003ooooool0o`3o0?l0017ooooo1Ol0000Dooooo`Ko00005?ooool8o`0000Kooooo6?l0o`000ol0
003o0?l0o`3o000Eo`3o00kooooo0_l0000Iooooo`002oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooo000001Gooooo00?o0000ooooool000005_ooool4o`0001Cooooo1?l00002o`3o01;o
oooo00?o0000ooooool000000_l0000Dooooo`Go00004oooool9o`000003ooooool0o`3o0?l000Go
0?l01oooool<o`0000Cooooo00?o0000ooooooooool01Oooool;o`0000Kooooo2?l0o`04o`0000;o
oooo1?l0000>ooooo`03o`000?oooooooooo00Kooooo002Oooooo`03o`000?oooooooooo01?ooooo
00Co0000ooooool0003o0?l05oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Ko
oooo00?o0000o`3o0?l0o`001?l0o`0Booooo`Go00001_ooool00ol0003oooooooooo`0;ooooo`So
00003?ooool9o`3o00?o00005Oooool00;Gooooo00?o0000o`3o0?l0o`00@oooool7o`3o01Sooooo
0_l00007ooooo`;o00003_ooool4o`0001Gooooo1?l00008o`3o013ooooo002dooooo`;o0?l0?ooo
ool6o`3o02Oooooo00?o0000ooooooooool09oooool4o`0000Sooooo1Ol0o`0;ooooo`00/_ooool2
o`3o0003ooooool0003ooooo03Sooooo1_l0o`0/ooooo`03o`000?oooooooooo03Wooooo0ol0o`08
ooooo`00/?ooool2o`3o00?ooooo00?o0000ooooooooool0<_ooool5o`3o037ooooo00?o0000oooo
ooooool0AOooool000_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`28ooooo`;o
0?l01Oooool00ol0003oooooooooo`0^ooooo`Co0?l0=_ooool00ol0003oooooooooo`15ooooo`00
3?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
K_ooool00ol0o`3oooooooooo`05ooooo`03o`000?oooooooooo02_ooooo0ol0o`0iooooo`03o`00
0?oooooooooo04Kooooo000;ooooo`04o`000?oooooo0000o`0001Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05?ooooo00?o0?l0ooooooooool0
1_ooool00ol0003oooooooooo`0Xooooo`?o0?l0>oooool00ol0003oooooooooo`17ooooo`002ooo
ool01?l0003oooooooooooooool3o`00013ooooo0ol0000Gooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0iooooo`03o`3o0?oooooooooo00Oooooo
00?o0000ooooooooool09Oooool3o`3o03gooooo00?o0000ooooooooool0B?ooool000_ooooo00?o
0000ooooooooool01?ooool2o`0000kooooo0ol0000Fooooo`;o00006?ooool2o`0001Sooooo00?o
0000ooooooooool05Oooool2o`00023ooooo0_l0o`0:ooooo`03o`000?oooooooooo02;ooooo0ol0
o`0oooooo`03o`000?oooooooooo04Wooooo000;ooooo`;o00001oooool2o`0000cooooo0ol0000F
ooooo`?o00005_ooool3o`0001Oooooo0_l0000Fooooo`?o00006?ooool2o`0000Gooooo00?o0?l0
ooooooooool02_ooool2o`00023ooooo0ol0o`11ooooo`03o`000?oooooooooo04[ooooo000;oooo
o`;o00002Oooool2o`0000Wooooo1Ol0000Eooooo`?o00005_ooool2o`0001Oooooo0ol0000Eoooo
o`?o00005_ooool5o`0000Cooooo00?o0?l0ooooooooool02oooool01?l0003oooooooooooooool3
o`0001Sooooo0ol0o`13ooooo`03o`000?oooooooooo04_ooooo000Hooooo`;o00001oooool5o`00
01Cooooo1?l0000Eooooo`?o00005_ooool3o`0001Gooooo1?l0000Dooooo`Ko00001?ooool00ol0
o`3oooooooooo`0<ooooo`Ko00005_ooool01?l0003o0?l0o`3o0?l00013ooooo`;o0000C_ooool0
00kooooo0_l000000ol@413oooooooooo`07ooooo`?o00001_ooool00ol0003oooooooooo`0@oooo
o`04oiRHV?l@413o0000oc8b<PCo00005?ooool4o`0000_ooooo1Ol00005ooooo`Co00005?ooool5
o`0000Cooooo1?l000000ol@413oooooooooo`08ooooo`Ko00000oooool2o`3o00kooooo1_l0000C
ooooo`;o00000ol0o`000ol0003oooooooooo`08ooooo`Co000000?o410@ooooooooool00_ooool8
o`0001;ooooo1Ol00002ooooo`Go00002oooool00ol0003oooooo`000002o`0001Kooooo0ol00000
0olb<S;oc<c<ooooo`0Vooooo`;o000000?o410@ooooooooool01Oooool000oooooo00?o0000oooo
ooooool02oooool2o`0000Cooooo00?o0000ooooooooool04?ooool01_l@413o^[ZjoooooomgMgOo
<S8bo`0001Sooooo0_l0000;ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool2o`0001Kooooo
0_l00007ooooo`03o`000?oooooooooo00_ooooo1Ol00002ooooo`03o`3o0?oooooooooo00kooooo
1Ol0000Dooooo`;o0?l00ol0000=ooooo`03o`000?oooooooooo00Cooooo1_l0000Dooooo`So0000
00Co8B4Qonk^k_ooooooA4A42oooool00ol0003oooooo`000005o`0001?ooooo1_l0000Dooooo`?o
00004?ooool00ol0003oooooooooo`06ooooo`001?ooool6o`000003ooooool0003o000000Co0000
3_ooool01Ol0003ooooooooooooooooo000000[ooooo1_l00006ooooo`;o00006?ooool00ol0003o
ooooooooo`02ooooo`Ko00000oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooo000001Co
oooo1_l00005ooooo`03o`000?oooooooooo00cooooo0ol00002ooooo`03o`3o0?oooooooooo013o
oooo0ol0000Cooooo`;o0?l00ol0000?ooooo`03o`000?oooooooooo00Cooooo1?l0000Dooooo`Oo
00000oooool00onHV9So8B4Qonk^kP0;ooooo`_o00003Oooool<o`0000gooooo2ol0000:ooooo`Go
00001oooool000cooooo00CoA4A4omgMgOoooooo00004?ooool2o`0001Oooooo00?oZJVYoa0@4?oo
ool09oooool00onHV9So8B4Qonk^kP0Xooooo`03o`000?oooooooooo00gooooo00Co0000oooooooo
oooo0?l04oooool2o`0001;ooooo0_l0o`03ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Fooooo`;o00001oooool00onHV9So8B4Qonk^kP09oooo
o`04o`000?ooooooooooooooo`Co00005Oooool5o`0001Cooooo2?l00009ooooo`04odA4A?oMgMgo
ooooo`0000Sooooo000<ooooo`04omgMgOmEEEGoooooo`0001;ooooo00?o0000ooooooooool04ooo
ool00ol@413o0000okZj^P0Yooooo`03ogMgMomVIVKooooo02Oooooo00?o0000ooooooooool03ooo
ool00ol0o`3oooooooooo`0Booooo`03o`000?oooooooooo00kooooo0ol0o`0Fooooo`03o`000?oo
oooooooo02Sooooo00?oMgMgofIVI_ooool01oooool00ol0003oooooooooo`0Kooooo`;o000000?o
410@o`000?nj^[X05?ooool4o`0000gooooo00CogMgMoeEEEOoooooo00002?ooool000gooooo00?o
MgMgolc<c?l000004oooool3o`0001?ooooo00?o^[Zjob4Q8Oooool0:Oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00oooooo00?o0?l0ooooooooool04_ooool2o`0000gooooo0_l0
o`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01?ooool2o`00027ooooo00?o
^[Zjob4Q8Oooool09Oooool00omgMgOoc<c<o`000008ooooo`003Oooool00oo^k^koA4A4o`00000F
ooooo`;o00003_ooool01Ol@413oV9RHoooooonj^[[o000002Kooooo00Go0000okZj^_ooooooV9RH
oa0@400Xooooo`03o`000?oooooooooo00kooooo00?o0?l0ooooooooool04oooool00ol0003ooooo
ooooo`0:ooooo`;o0?l06oooool00ol0003oooooooooo`0Uooooo`05o`000?nj^[[ooooooiRHV?l@
41001Oooool00ol0003oooooooooo`0Nooooo`05oa0@4?nHV9SooooookZj^_l000009_ooool00oo^
k^koA4A4o`000008ooooo`003_ooool00omgMgOo0000ooooo`0Gooooo`;o00003?ooool01OnYZJWo
410@o`000?l@413oZJVY02Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Vooooo`03oeEEEOmVIVKo
000000oooooo00?o0?l0ooooooooool05?ooool00ol0003oooooooooo`08ooooo`;o0?l06oooool0
0omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003ooooooooo
o`0Oooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool00omgMgOo0000ooooo`07ooooo`008_oo
ool00ol0003oooooooooo`05ooooo`?o0000L?ooool00ol0o`3oooooooooo`0Eooooo`03o`000?oo
oooooooo00Oooooo00?o0?l0ooooooooool0COooool00ol0003oooooooooo`1Fooooo`008_ooool0
0ol0003oooooooooo`08ooooo`;o00003?ooool00ol0003oooooooooo`1Nooooo`03o`3o0?oooooo
oooo01Kooooo00?o0000ooooooooool01Oooool2o`3o04oooooo00?o0000ooooooooool0Eoooool0
02;ooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`13ooooo`03o`3o0?oooooooooo01Oooooo00?o0000ooooooooool00oooool2o`3o
053ooooo00?o0000ooooooooool0F?ooool000_ooooo00?o0000ooooooooool05?ooool2o`0000go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0:Oooool00ol0o`3oooooooooo`0Hooooo`03o`000?oooooooooo00;o
oooo00?o0?l0ooooooooool0D?ooool00ol0003oooooooooo`1Hooooo`002oooool00ol0003ooooo
ooooo`0Cooooo`?o00003_ooool2o`0000Oooooo0_l0000Gooooo`;o00006?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00oooooo00?o0?l0ooooooooool06Oooool00ol0003ooooo
ooooo`02o`3o05;ooooo00?o0000ooooooooool0FOooool000_ooooo0_l0000Dooooo`?o00004?oo
ool2o`0000Cooooo0ol0000Gooooo`;o00005oooool2o`0001Oooooo0_l0000@ooooo`03o`3o0?oo
oooooooo00Cooooo0_l0000Dooooo`03o`000?l0o`3o0?l005?ooooo00?o0000ooooooooool0F_oo
ool000_oooooS?l000000ol0o`3o0000o`00000Ko`000003o`3o0?l0003o00000:So00002?ooool0
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo1?l00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001ol00007oooo
o`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0ol000000ooooooo0000ooooo`07
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000002o`0000?ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool0o`04ooooo`Go00001?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0o`05o`0000?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo2?l00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool5o`0000Kooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo1?l00008ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`Co00005?oo
ool4o`0000[ooooo00?o0000ooooooooool02?ooool3o`0001Gooooo1?l00003ooooo`03o`000?oo
oooooooo00Sooooo00?o0?l0ooooooooool00oooool5o`0001;ooooo00?o0?l0o`000?l000001?l0
000Cooooo`Go00003_ooool00ol0003oooooooooo`03ooooo`Ko00004oooool8o`000005ooooool0
003o0000ooooool000003Oooool6o`0001?ooooo1Ol0000Eooooo`;o00004_ooool00ol0003ooooo
ooooo`06ooooo`002oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo0ol0
000Fooooo`;o00005?ooool4o`0001Cooooo1?l0000?ooooo`03o`3o0?oooooooooo00;ooooo1Ol0
000Booooo`03o`3o0?oooooo000000Co00005?ooool4o`0001Kooooo0ol0000Eooooo`Ko00000_oo
ool00ol0003oooooooooo`0=ooooo`[o00003_ooool:o`0000oooooo2?l0000@ooooo`03o`000?oo
oooooooo00Kooooo000nooooo`;o0000;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00cooooo00?o0?l0ooooooooool01Oooool3o`00013ooooo0_l0o`03ooooo`?o00005_ooool2
o`0001Oooooo00?o0000ooooooooool05_ooool2o`0000Cooooo00?o0000ooooooooool04?ooool5
o`0001Cooooo2?l0000Aooooo`Oo00005oooool0043ooooo0_l0001Aooooo`03o`3o0?oooooooooo
00Oooooo00?o0000ooooooooool03_ooool00ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`;o00005oooool4o`00
01Gooooo2?l0000Fooooo`00@_ooool2o`0004kooooo00?o0?l0ooooooooool05oooool2o`3o00Oo
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Qooooo`00A?ooool00ol0003ooooo
ooooo`1;ooooo`03o`3o0?oooooooooo01Kooooo00?o0?l0ooooooooool01oooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo06;ooooo0015ooooo`;o0000B_ooool00ol0o`3ooooooooo
o`0Fooooo`03o`3o0?oooooooooo00Sooooo0_l0001;ooooo`03o`000?oooooooooo06?ooooo0017
ooooo`;o0000Aoooool00ol0o`3oooooooooo`0Fooooo`03o`3o0?oooooooooo00Wooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`1Tooooo`008Oooool00ol0003oooooooooo`0Uoooo
o`;o0000AOooool00ol0o`3oooooooooo`0Eooooo`03o`3o0?oooooooooo00[ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00kooooo0ol00011ooooo`03o`3o0?oooooooooo01Gooooo00?o0?l0oooooooo
ool02oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo06Kooooo000Qooooo`;o0000
5oooool00ol0003oooooooooo`0Aooooo`;o00000oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01oooooo00?o0?l0ooooooooool05?ooool00ol0o`3oooooooooo`0<ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0Ioooool0027ooooo0_l0000Gooooo`;o00005?oo
ool2o`000003ooooool0003ooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`05ooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0ooooooooool03Oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo06Sooooo000Qooooo`?o00005_ooool2o`0001Kooooo0ol0000G
ooooo`;o00006?ooool00ol0003oooooooooo`05ooooo`03o`3o0?oooooooooo00kooooo00?o0000
ooooooooool00_ooool00ol0o`3oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool0JOooool000_ooooo00?o0000ooooooooool04oooool3o`0001Gooooo1?l0000Foooo
o`?o00005_ooool2o`0001Oooooo0_l00006ooooo`03o`3o0?oooooooooo00kooooo0_l00004oooo
o`03o`3o0?oooooooooo00kooooo00Co0000ooooool0003o0000@_ooool00ol0003oooooooooo`1Z
ooooo`008Oooool4o`0001Cooooo1?l0000Eooooo`?o000000?oooooo`000?l000004oooool3o`00
01Kooooo0ol00006ooooo`03o`3o0?oooooooooo00gooooo0_l00004ooooo`03o`3o0?oooooooooo
00oooooo1?l0000Fooooo`Co00004Oooool5o`00017ooooo00?o0000ooooooooool00ol0000Goooo
o`;o0000Coooool0027ooooo0ol0000Eooooo`Go00005?ooool4o`0000;ooooo00?o0000oooooooo
ool04?ooool3o`0001Kooooo0_l00006ooooo`03o`3o0?oooooooooo00gooooo0ol00003ooooo`03
o`3o0?oooooooooo00kooooo1Ol0000Cooooo`Ko00004oooool8o`0000gooooo00Co0000oooooooo
oooooooo1_l0000Dooooo`Co00005_ooool2o`0001Oooooo0_l0000Looooo`002oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01?ooooo0ol0000Fooooo`Co00000oooool2o`00013o
oooo0ol0000Eooooo`?o00001_ooool00ol0o`3oooooooooo`0<ooooo`?o00000oooool00ol0o`3o
ooooooooo`0>ooooo`Go00005?ooool5o`0001Cooooo1_l0000>ooooo`03o`000?oooooooooo00;o
oooo2?l0000Aooooo`Oo00004Oooool7o`0001;ooooo1_l0000Booooo`03o`000?oooooooooo00Ko
oooo001Kooooo`;o00003Oooool4o`0001Cooooo1?l00005ooooo`03o`3o0?oooooooooo00cooooo
1?l00002ooooo`03o`3o0?oooooooooo00oooooo1Ol0000Eooooo`;o00005_ooool3o`00013ooooo
00?o0000ooooooooool00oooool5o`0001Cooooo2?l0000Booooo`Oo00004_ooool6o`0001Wooooo
001Mooooo`;o00009_ooool00ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo00gooooo0ol0
0002ooooo`03o`3o0?oooooooooo013ooooo0ol0000Fooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`;o00005oooool4o`0001Kooooo2?l0
000Aooooo`Oo00006?ooool005oooooo0ol0000Xooooo`03o`3o0?oooooooooo00oooooo00Co0000
oooooooooooo0?l05?ooool2o`0003oooooo00?o0000ooooooooool0E_ooool3o`0001Oooooo001R
ooooo`;o00009_ooool00ol0o`3oooooooooo`0Aooooo`03o`3o0?oooooooooo01Cooooo00?o0000
ooooooooool0=Oooool6o`3o00;o00001ol0o`1/ooooo`00I?ooool2o`0002?ooooo00?o0?l0oooo
ooooool04_ooool00ol0o`3oooooooooo`0Dooooo`03o`000?oooooooooo02[ooooo2ol0o`05oooo
o`03o`000?oooooooooo00Oooooo2ol0o`1Qooooo`00I_ooool2o`00027ooooo00?o0?l0oooooooo
ool04Oooool00ol0o`3oooooooooo`0Eooooo`03o`000?oooooooooo02;ooooo2?l0o`0?ooooo`03
o`000?oooooooooo01?ooooo1ol0o`1Jooooo`008?ooool00ol0003oooooooooo`15ooooo`;o0000
7oooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo01Kooooo0_l0000Oooooo`Co0?l0
5oooool00ol0003oooooooooo`0Jooooo`Ko0?l0E?ooool0023ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01_ooooo00?o0?l0ooooooooool04Ooo
ool00ol0o`3oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo0ol0o`0Jooooo`03o`000?oo
oooooooo027ooooo0ol0o`1Aooooo`008?ooool2o`0001Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Fooooo`;o00006oooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooo
oooo01Oooooo00?o0000ooooooooool05oooool4o`3o01cooooo00?o0000ooooooooool09Oooool4
o`3o04gooooo000Pooooo`?o00005_ooool2o`0001Oooooo00?o0000ooooooooool05_ooool01?l0
003oooooo`000?l0000Iooooo`03o`3o0?oooooooooo00oooooo00?o0?l0ooooooooool06?ooool0
0ol0003oooooooooo`0Dooooo`?o0?l07oooool00ol0003oooooooooo`0Zooooo`?o0?l0B_ooool0
027ooooo0_l0000Fooooo`?o00005_ooool2o`0001Oooooo00Co0000oooooooooooooooo0ol0000C
ooooo`03o`000?oooooo0?l001;ooooo00?o0?l0ooooooooool06?ooool00ol0003oooooooooo`0A
ooooo`?o0?l08Oooool00ol0003oooooooooo`0^ooooo`Co0?l0A_ooool000_ooooo00?o0000oooo
ooooool04oooool3o`0001Kooooo0_l0000Fooooo`;o00005oooool2o`0000Gooooo0_l0000Aoooo
o`03o`000?oooooo0?l0017ooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00kooooo0ol0o`0Sooooo`03o`000?oooooooooo03?ooooo1?l0o`12oooo
o`008Oooool4o`0001Gooooo0ol0000Eooooo`?o00005_ooool2o`0000Oooooo0_l0000>ooooo`;o
000000?oooooo`3o0?ooool04?ooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo01Co
oooo0ol0000<ooooo`;o0?l07Oooool3o`0000Gooooo00?o0000ooooooooool03_ooool2o`0001So
oooo0_l0000>ooooo`?o0?l0?oooool0027ooooo0_l0000Gooooo`Co00005?ooool3o`0001Gooooo
1?l00008ooooo`;o00003?ooool2o`000003ooooool0o`3ooooo00oooooo00?o0?l0ooooooooool0
0_ooool2o`0001Gooooo1?l0000;ooooo`03o`3o0?oooooooooo00Oooooo1?l0000Booooo`Ko0000
00?oooooo`000?ooool04?ooool5o`0001Gooooo0ol0000@ooooo`?o0?l01?ooool2o`0001Oooooo
0_l0000Mooooo`002oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo0_l0
000Fooooo`?o00005Oooool4o`0000[ooooo0_l00009ooooo`Co000000?o0?l0ooooooooool03_oo
ool01?l0o`3oooooooooooooool3o`0001?ooooo1Ol0000:ooooo`;o0?l01_ooool6o`0001Cooooo
2?l0000Aooooo`Oo00004oooool5o`00017ooooo0ol0o`04o`0001Cooooo1Ol0000Cooooo`03o`00
0?oooooooooo00Kooooo001Booooo`Co00005?ooool4o`0000cooooo00?o0000ooooooooool01_oo
ool4o`000003o`3o0?oooooooooo00gooooo00?o0?l0ooooooooool00_ooool2o`0001?ooooo1_l0
0008ooooo`;o0?l02?ooool5o`0001Gooooo1_l0000Cooooo`So00004Oooool7o`0001?ooooo0_l0
o`04o`0001Cooooo1?l0000Kooooo`00J_ooool5o`0000cooooo0_l00006ooooo`?o000000?o0?l0
ooooooooool03_ooool01?l0o`3oooooooooooooool3o`0001?ooooo1Ol00007ooooo`;o0?l02ooo
ool2o`0001Oooooo0_l00002ooooo`03o`000?oooooooooo01;ooooo1?l0000Eooooo`So00004_oo
ool2o`0000?o0?l00_l0000Booooo`Ko00006_ooool007gooooo0_l00003ooooo`Co000000?o0?l0
ooooooooool03Oooool01?l0o`3oooooooooooooool4o`0001Cooooo1?l00006ooooo`03o`3o0?oo
oooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1;ooooo`;o0?l000?o
0000ooooooooool03oooool7o`0001Wooooo001oooooo`;o00001Oooool00ol0o`3oooooooooo`0=
ooooo`03o`3o0?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooo`000004
ooooo`;o0?l0:Oooool00ol0003oooooooooo`1>ooooo`?o0?l05?ooool3o`0001Sooooo0021oooo
o`;o00000oooool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo01cooooo00Go0000oooo
ooooooooooooo`3o000Zooooo`03o`000?oooooooooo05;ooooo0_l0o`0]ooooo`00Poooool3o`00
0003o`3o0?oooooooooo00gooooo00?o0?l0ooooooooool07?ooool01?l0003oooooooooool0o`0Z
ooooo`03o`000?oooooooooo05Gooooo0ol0o`0Zooooo`00Q_ooool2o`0000gooooo00?o0?l0oooo
ooooool04oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooool0o`00:_ooool00ol0
003oooooooooo`1Iooooo`;o0?l0:?ooool001oooooo00?o0000ooooooooool0I?ooool01?l0o`3o
ooooo`000?l0000;ooooo`03o`3o0?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0
003o0?l0ooooo`0Yooooo`03o`000?oooooooooo05cooooo00?o0?l0ooooooooool09Oooool001oo
oooo0_l0000Gooooo`03o`000?oooooooooo04_ooooo00Co0?l0oooooooooooooooo0_l00009oooo
o`03o`3o0?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0o`3o0000o`00000Xoooo
o`03o`000?oooooooooo05kooooo0_l0o`0Uooooo`007oooool3o`0001Kooooo0_l0000Gooooo`03
o`000?oooooooooo03;ooooo00?o0?l0ooooooooool00oooool2o`0000Oooooo00?o0?l0oooooooo
ool05Oooool00ol0003oooooooooo`05ooooo`03o`3o0?oooooooooo02Oooooo00?o0000oooooooo
ool0HOooool2o`3o02?ooooo000Pooooo`?o00005Oooool3o`0001Kooooo0_l0000Gooooo`03o`00
0?oooooooooo01Wooooo00?o0?l0ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`3o
0?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0o`3o0000ooooo`0Wooooo`03o`00
0?oooooooooo06Cooooo00?o0?l0ooooooooool08?ooool0023ooooo1?l0000Eooooo`?o00005Ooo
ool3o`0001Kooooo00?o0000ooooooooool05oooool00ol0003oooooo`3o0008ooooo`;o00001?oo
ool00ol0o`3oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooool000009ooo
ool00ol0003oooooooooo`1Vooooo`;o0?l08?ooool0023ooooo1Ol0000Dooooo`Co00005?ooool4
o`0001Gooooo0_l0000Hooooo`04o`000?ooooooooooo`3o00Wooooo0_l00002ooooo`03o`3o0?oo
oooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`04o`3o0?oo
ooooooooo`0002Kooooo00?o0000ooooooooool00oooool2o`0001Sooooo0_l0000Hooooo`03o`00
0?oooooooooo02oooooo00?o0?l0ooooooooool07Oooool0027ooooo0_l0000Fooooo`Go00005?oo
ool4o`0001Cooooo0ol0000Gooooo`;o000000?oooooo`3o0?ooool02_ooool2o`000003o`3o0?oo
oooooooo00Gooooo00?o0000ooooooooool02oooool00omEEEGoIVIVo`000003ooooo`04o`3o0?oo
ooooooooooooo`;o00009?ooool00ol0003oooooooooo`04ooooo`Go00005Oooool3o`0001Oooooo
0_l0000Gooooo`03o`000?oooooooooo01Oooooo0_l0o`0Mooooo`002oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooo000001Kooooo0_l0000Fooooo`Go00005?ooool2o`0001Oooooo0_l0
00000ooooooo0?l0ooooo`0<ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03o`3o0?oo
oooooooo00?o00004Oooool8o`0000[ooooo00?o0000ooooooooool01Oooool7o`0001;ooooo1_l0
000Dooooo`Co00005Oooool3o`0001Kooooo0ol000000ooooooo0?l0ooooo`0Booooo`03o`000?oo
oooooooo00Kooooo000jooooo`03o`000?oooooooooo01Gooooo0ol0000Fooooo`?o00005Oooool4
o`000003o`3o0?oooooooooo00_ooooo00?o0?l0ooooooooool00_l00002ooooo`;o00004_ooool0
0ol0o`3oooooo`000003o`0001;ooooo1_l0000:ooooo`;o00002?ooool8o`00017ooooo1ol0000B
ooooo`Ko00005?ooool4o`0001Kooooo0ol000000ooooooo0?l0o`3o000Jooooo`00D_ooool00ol0
003oooooooooo`0Fooooo`Co00005?ooool4o`000003o`3o0?oooooooooo00_ooooo00?o0?l0oooo
ooooool00_ooool5o`00013ooooo00?o0?l0ooooool000001?l0000Cooooo`?o00002oooool00ol0
003oooooooooo`0Vooooo`?o00005?ooool4o`0001?ooooo1Ol0000Dooooo`Go00000_ooool2o`3o
01Sooooo001[ooooo`;o00005_ooool4o`000003o`3o0?oooooooooo00_ooooo00?o0?l0oooooooo
ool01?ooool3o`0000oooooo00?o0?l0ooooool000001_l0000Booooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0@Oooool2o`0001Gooooo0ol0000Eooooo`Co00000oooool00ol0o`3o
ooooooooo`0Eooooo`00Poooool2o`0000;ooooo00?o0?l0ooooooooool02oooool00ol0o`3ooooo
ooooo`03ooooo`Go00003_ooool01?l0o`3oooooooooooooool4o`0001oooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`0Eooooo`;o00000oooool2o`3o01Gooooo0028ooooo`03o`3o
0?oooooooooo00[ooooo00?o0?l0ooooooooool00oooool4o`000003ooooool0003o000000cooooo
00?o0?l0ooooooooool00_ooool00ol0003oooooo`00000Oooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool00_ooool00ol0o`3oooooooooo`0Booooo`00R?ooool00ol0o`3ooooooooo
o`0:ooooo`03o`3o0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0o`3ooooooooo
o`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0OOooool00ol0o`3ooooooooo
o`0Aooooo`00ROooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00_ooooo0_l00008
ooooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1o
ooooo`03o`3o0?oooooooooo013ooooo0029ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0oooo
ooooool03?ooool3o`0000Gooooo00?o0?l0ooooooooool01Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo087ooooo0_l0o`0@ooooo`007Oooool2o`0006[ooooo00?o0?l0oooooooo
ool02_ooool00ol0o`3oooooooooo`0?ooooo`;o00000oooool00ol0o`3oooooooooo`05ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0Q?ooool00ol0o`3oooooooooo`0=ooooo`00
7Oooool3o`0001Oooooo0_l0001Aooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool0
4Oooool2o`000003ooooool0o`3ooooo00Kooooo00?o0000ooooooooool04oooool4o`3o00;o0000
1_l0o`22ooooo`03o`3o0?oooooooooo00cooooo000Nooooo`Co00005Oooool3o`0001Kooooo0_l0
000hooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool04_ooool2o`0000Oooooo0_l0
000Gooooo`03o`000?oooooooooo00Kooooo1Ol0o`1nooooo`;o0?l03?ooool001oooooo1?l0000E
ooooo`?o00005Oooool3o`0001Kooooo0_l0000Oooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0
ooooooooool04oooool00ol0o`3o0000o`000005ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool2o`3o00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1M
ooooo`03o`3o0?oooooooooo00Wooooo000Oooooo`Go00005?ooool4o`0001Gooooo0ol0000Eoooo
o`?o00005_ooool2o`0000Oooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`0Coooo
o`03o`3o0?oooooooooo00?o00000_ooool00ol0003oooooooooo`0@ooooo`;o00000_ooool00ol0
003oooooooooo`0?ooooo`?o0?l000?oooooo`000?l000006?ooool2o`0001Sooooo00?o0000oooo
ooooool0A?ooool00ol0o`3oooooooooo`08ooooo`008?ooool3o`0001Kooooo1?l0000Dooooo`Co
00005Oooool4o`0001Cooooo0ol00007ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0oooooooo
ool00_ooool00ol0003oooooooooo`0>ooooo`03o`3o0?oooooooooo00?ooooo0ol0000Booooo`Co
00005Oooool2o`3o00;o00005_ooool4o`0001Kooooo0_l0000Hooooo`03o`000?oooooooooo02co
oooo00?o0?l0ooooooooool01oooool000_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
o`00000Eooooo`?o00005_ooool4o`0001Cooooo1Ol0000Dooooo`Co00001Oooool00ol0o`3ooooo
ooooo`09ooooo`04o`3o0?ooooooooooooooo`;o00003oooool00ol0o`3oooooooooo`05ooooo`;o
00004?ooool7o`0001?ooooo0_l00003o`3o0003o`000?oooooooooo017ooooo1_l0000Dooooo`Co
00005_ooool2o`0001Oooooo0_l0000Fooooo`03o`3o0?oooooooooo00Kooooo000jooooo`03o`00
0?oooooooooo01Gooooo0ol0000Fooooo`Go00004oooool5o`0000Gooooo00?o0?l0ooooooooool0
2Oooool00ol0o`3oooooooooo`02o`0000oooooo00?o0?l0ooooooooool01Oooool01?l0003ooooo
o`000?l0000>ooooo`04o`000?l0o`3o0?l0o`0000Go0?l05?ooool2o`0000;o0?l05Oooool4o`00
01;ooooo1_l0000Dooooo`Co00005_ooool2o`0001oooooo001Cooooo`03o`000?oooooooooo01Go
oooo0ol0000Fooooo`Go00001?ooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00?o
00003_ooool2o`3o00Gooooo0ol00002ooooo`;o00003_ooool00ol0003oooooooooo`04ooooo`Go
0?l04_ooool00ol0003o0?l0ooooo`0Fooooo`;o00005?ooool4o`0001Gooooo0ol0000Dooooo`Co
00007_ooool006cooooo00?o0000ooooooooool05Oooool3o`0000Oooooo00?o0?l0ooooooooool0
2Oooool00ol0o`3oooooooooo`03o`0000kooooo00?o0?l0ooooooooool00oooool3o`0000Cooooo
00?o0000ooooooooool00oooool4o`0000?ooooo00?o0000ooooooooool02_ooool00ol0o`3ooooo
ooooo`0Aooooo`03o`3o0?oooooooooo02gooooo0_l0000Fooooo`;o00005Oooool3o`0001Cooooo
00?o0000ooooooooool01_ooool008Gooooo00?o0000ooooooooool01oooool00ol0o`3ooooooooo
o`09ooooo`03o`3o0?oooooo000000?o00003Oooool00ol0o`3oooooooooo`03ooooo`?o00001Ooo
ool2o`000003ooooool0003o000000Oo00003_ooool00ol0o`3oooooooooo`0Aooooo`03o`3o0?oo
oooooooo04Kooooo00?o0000ooooooooool05?ooool2o`0001cooooo002@ooooo`03o`3o0?oooooo
oooo00Wooooo00?o0?l0o`000?l000004?ooool01?l0o`3oooooooooooooool5o`0000Kooooo2Ol0
000@ooooo`;o0?l04_ooool00ol0o`3oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo002A
ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool04?ooool00ol0o`3oooooooooo`05
o`0000Kooooo2_l0000Aooooo`03o`3o0?oooooooooo013ooooo00?o0?l0ooooooooool0NOooool0
09;ooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`0@ooooo`05o`3o0?oooooooooo
ooooool000002?ooool:o`000003o`3o0?oooooooooo00oooooo00?o0?l0ooooooooool04?ooool0
0ol0o`3oooooooooo`1hooooo`00Toooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo
013ooooo00Co0?l0oooooooooooo00002?ooool:o`000003ooooool0o`3ooooo013ooooo00?o0?l0
ooooooooool04?ooool00ol0o`3oooooooooo`1gooooo`00U?ooool00ol0o`3oooooooooo`09oooo
o`;o0?l04Oooool2o`3o0003o`000?oooooooooo00Kooooo2ol000000ol0o`3oooooooooo`02oooo
o`;o00003?ooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo07Kooooo000Looooo`;o
0000Moooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo013ooooo0_l0o`08ooooo`So
00000_ooool00ol0003o0?l0ooooo`02ooooo`?o00002oooool00ol0o`3oooooooooo`05ooooo`;o
00002Oooool00ol0o`3oooooooooo`1fooooo`007?ooool4o`0001Gooooo0_l0001Oooooo`;o0?l0
2oooool00ol0o`3oooooooooo`0?ooooo`04o`000?oooooo0?l0o`3o00Kooooo2?l00003ooooo`04
o`000?ooooooooooooooo`Co00002oooool00ol0o`3oooooooooo`03ooooo`?o00002_ooool00ol0
o`3oooooooooo`1eooooo`007Oooool5o`0001?ooooo1Ol0000Eooooo`;o0000Aoooool00ol0o`3o
ooooooooo`09ooooo`;o0?l03oooool01?l0003oooooooooooooool2o`3o00Cooooo00?o0000oooo
ool000000ol00005ooooo`04o`3o0?l0003o0000ooooo`Co00003?ooool01?l0o`3ooooooooooooo
ool4o`0000_ooooo00?o0?l0ooooooooool02?ooool2o`0006[ooooo000Nooooo`Go00004oooool6
o`0001?ooooo1?l0000Eooooo`?o0000;_ooool2o`3o00_ooooo0_l0o`0=ooooo`;o00001?ooool2
o`3o00;o00000ol0o`07ooooo`04o`3o0?ooooooooooooooo`Co00003Oooool01?l0o`3ooooooooo
ooooool4o`0000cooooo00?o0?l0ooooooooool01Oooool4o`0001Oooooo0_l0001Aooooo`007_oo
ool5o`0001Cooooo1_l0000Cooooo`Go00004oooool6o`0001?ooooo0ol0000Gooooo`03o`3o0?oo
oooooooo00[ooooo00?o0?l0ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00[ooooo00Co0?l0oooooooooooooooo1Ol0000=ooooo`04o`3o0?ooooooooooooooo`Co
00003?ooool00ol0o`3oooooooooo`05ooooo`Co00005Oooool3o`0001Oooooo0_l0000hooooo`00
7oooool4o`0001Gooooo0ol0000Fooooo`Go00004oooool6o`0001?ooooo1Ol0000Cooooo`;o0000
0_l0o`000ol0003oooooooooo`08ooooo`?o0?l02?ooool8o`0000cooooo00?o0?l0ooooooooool0
0_ooool2o`0000?ooooo0_l0000;ooooo`03o`3o0?oooooooooo00;ooooo0ol0000<ooooo`03o`3o
0?oooooooooo00Kooooo0ol0000Dooooo`Go00005Oooool3o`0001Sooooo00?o0000ooooooooool0
7Oooool000_ooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000Eooooo`03o`00
0?oooooo000001Kooooo0ol0000Eooooo`Go00005?ooool6o`0001?ooooo0_l00002o`3o00;o0000
2_ooool2o`3o00Oooooo1ol0000;ooooo`03o`3o0?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool2o`0000[ooooo00?o0?l0ooooooooool00_ooool2o`0000gooooo00?o0?l0ooooooooool0
1_ooool2o`0001Kooooo0ol0000Dooooo`Go00005_ooool2o`0001Kooooo00?o0000ooooooooool0
1_ooool005?ooooo00?o0000ooooooooool05Oooool3o`0001Kooooo1Ol0000Dooooo`?o000000?o
0?l0o`000?ooool02oooool2o`3o00Gooooo00?o0000ooooool000001?l00003ooooo`?o0?l01?oo
ool00ol0o`3oooooooooo`0=ooooo`?o00001oooool00ol0o`3oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0?l0ooooooooool01_ooool2o`0001Kooooo0ol0000Eooooo`?o00005Ooo
ool4o`0001kooooo001/ooooo`03o`000?oooooooooo01Kooooo0ol0000Gooooo`;o00000ol0o`0<
ooooo`Wo0?l000?o0000o`3o0?l0o`000ol0o`05ooooo`;o0?l04oooool2o`0000Gooooo00?o0?l0
ooooooooool04_ooool00ol0o`3oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool05?ooool3o`0001Kooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo0026oooo
o`03o`000?oooooooooo01Oooooo00Co0000oooooooooooooooo0ol0o`03ooooo`Go00001_ooool0
1_l0003oooooooooool0003oooooo`0000Oooooo0_l0o`0Gooooo`;o00001?ooool00ol0o`3ooooo
ooooo`0Booooo`03o`3o0?oooooooooo023ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Eooooo`;o00007Oooool00:Oooooo1Ol0o`000oo^k^koooooodA4A006ooooo`03o`000?oo
oooo000000Kooooo1?l0o`0Kooooo`;o00000_ooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oo
oooooooo03Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`00Zoooool0
0onHV9So0?l0o`3o0003o`3o00Cooooo0_l00003ooooo`Co0?l08Oooool00ol0003oooooo`3o000E
ooooo`03o`3o0?oooooooooo057ooooo00?o0000ooooooooool06_ooool00:cooooo00?oV9RHob4Q
8Oo^k^h00_ooool4o`3o0003o`000?l0o`3o0?l000;o0?l09_ooool2o`0001Kooooo00?o0?l0oooo
ooooool0KOooool00:gooooo00?oMgMgofIVI_ooool00oooool3o`0002_ooooo00?o0?l0o`000?l0
00005?ooool00ol0o`3oooooooooo`1]ooooo`00[_ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool0:Oooool00ol0o`3oooooooooo`02o`0001;ooooo00?o0?l0oooooooo
ool0KOooool00:[ooooo00Go0000okZj^_ooooooV9RHoa0@4002ooooo`05o`000?oooooooooooooo
ool00000:oooool00ol0o`3oooooooooo`02ooooo`?o00003oooool00ol0o`3oooooooooo`1]oooo
o`006oooool3o`0008cooooo00OoV9RHoa0@4?l0003o8B4Qolc<c?oooooo000000Cooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`04o`3o0?ooooooooooooooo`?o000000?o
ooooo`000?l000003Oooool00ol0o`3oooooooooo`1]ooooo`007?ooool5o`0001?ooooo0ol0000F
ooooo`?o0000Goooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool03_ooool01?l0o`3oooooooooooooool4o`0000;ooooo0_l0000<ooooo`03o`3o0?oo
oooooooo00;ooooo0_l0001Xooooo`007Oooool6o`0001;ooooo1Ol0000Eooooo`Co00005?ooool3
o`0004Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`?o00003_ooool0
0ol0o`3oooooooooo`02ooooo`Co00001?ooool2o`0000[ooooo00?o0?l0ooooooooool01?l0000F
ooooo`;o0000D?ooool001kooooo1Ol0000Cooooo`Ko00005?ooool5o`0001?ooooo1Ol0000Coooo
o`Go0000:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o00005?ooool5o`00
00gooooo00?o0?l0ooooooooool00_ooool3o`0000Oooooo0_l00008ooooo`03o`3o0?oooooooooo
00Co00005?ooool4o`0001Kooooo0_l0000hooooo`007oooool4o`0001Cooooo1Ol0000Eooooo`Co
00005?ooool6o`0001?ooooo1_l0000Aooooo`So00003?ooool00ol0003oooooooooo`05ooooo`Go
00005?ooool3o`0000oooooo00?o0?l0ooooooooool00_ooool3o`0000Wooooo00?o0000oooooooo
ool01Oooool01?l0o`3oooooooooooooool3o`0001Cooooo1?l0000Eooooo`?o00005oooool2o`00
01oooooo000;ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo00005?ooool4o`00
01Kooooo0ol0000Eooooo`Go00005?ooool5o`0001?ooooo1_l0000;ooooo`03o`000?oooooooooo
00Cooooo1ol0000Cooooo`;o00004Oooool00ol0o`3oooooooooo`02ooooo`;o00002oooool2o`00
00Gooooo00Co0?l0oooooooooooooooo0_l0000Fooooo`?o00005?ooool4o`0001Kooooo0ol0000F
ooooo`03o`000?oooooooooo00Kooooo000iooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool05Oooool3o`0001Oooooo0_l0000Gooooo`?o00002_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooo000000;o00004_ooool00ol0003oooooooooo`0@ooooo`03o`3o0?oooooooooo
00?ooooo0_l0000=ooooo`;o00001?ooool00ol0o`3oooooooooo`02o`0001Oooooo0ol0000Doooo
o`Co00005?ooool4o`0001Kooooo00?o0000ooooooooool01_ooool006cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Wooooo`03o`3o0?oooooooooo00?ooooo00?o0000oooooooo
ool03_ooool2o`0000;ooooo00Go0?l0ooooooooooooooooo`00000Gooooo`?o00005Oooool3o`00
01Gooooo1?l0000Dooooo`;o00002?ooool00:Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Vooooo`03o`3o0?oooooooooo01Oooooo0_l000001Ol0o`3ooooooooooooooooo0000
01Sooooo0_l0000Fooooo`;o00005_ooool3o`0001Gooooo00?o0000ooooooooool01_ooool000_o
oooo0_l0o`2Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool00ol0o`3o
ooooooooo`0Iooooo`?o00006oooool00ol0003oooooooooo`0Eooooo`;o00005_ooool2o`0001ko
oooo000=ooooo`03o`3o0?oooooooooo09Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Vooooo`03o`3o0?oooooooooo01Wooooo00?o0?l0ooooooooool00_l0000booooo`03o`00
0?oooooooooo01Gooooo0_l0000Mooooo`003_ooool2o`3o09Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Uooooo`03o`3o0?oooooooooo01[ooooo00?o0?l0ooooooooool00_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01_ooooo000@ooooo`;o0?l0Toooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo00?o0?l0ooooooooool06oooool0
0ol0o`3oooooooooo`03ooooo`;o0000I_ooool001;ooooo0_l0o`2@ooooo`03o`000?oooooooooo
00kooooo0_l0000Uooooo`03o`3o0?oooooooooo01[ooooo00?o0?l0ooooooooool01_ooool00ol0
003oooooooooo`1Sooooo`005?ooool2o`3o08cooooo0_l0000Aooooo`03o`000?oooooooooo02?o
oooo00?o0?l0ooooooooool06oooool00ol0o`3oooooooooo`07ooooo`;o0000Hoooool001Kooooo
00Co0?l0oooooooooooooooo0ol00024ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool08_ooool00ol0o`3oooooooooo`0Looooo`03o`3o0?oooooooooo00Wooooo0_l0001Qooooo`00
5oooool2o`3o00;ooooo1Ol0000Cooooo`?o0000J_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo027ooooo00?o0?l0ooooooooool02_ooool2o`00017ooooo00?o0?l0ooooooooool0
2oooool2o`0005oooooo000Iooooo`;o0?l000?oooooo`000?l000001?l0000Cooooo`Co00004ooo
ool5o`0004kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Kooooo00?o0?l0ooooooooool02oooool3o`00013ooooo00Co0?l0oooooooooooooooo
0ol00009ooooo`?o0000G?ooool001_ooooo0_l0o`05o`0001Cooooo1Ol0000Cooooo`Ko00004_oo
ool5o`0003;ooooo0ol0000Eooooo`?o00005oooool2o`0000Kooooo00?o0?l0ooooooooool03?oo
ool4o`0000oooooo00Co0?l0oooooooooooooooo1?l0000;ooooo`;o00001_ooool5o`0004oooooo
000Mooooo`;o0?l01?l0000Dooooo`Co00005?ooool5o`0001Cooooo1_l0000Aooooo`So00004ooo
ool6o`0001Cooooo1?l0000Fooooo`Co00001?ooool00ol0o`3oooooooooo`0<ooooo`Co00004?oo
ool01?l0o`3oooooooooooooool4o`0000gooooo0_l00004ooooo`Go00005?ooool4o`0003Oooooo
000;ooooo`03o`000?oooooooooo017ooooo0_l0o`02ooooo`03o`000?oooooooooo01;ooooo0_l0
00000ooooooo0000ooooo`0Dooooo`;o000000?oooooo`000?ooool04oooool5o`0001?ooooo1_l0
000Aooooo`So00004_ooool7o`0001Cooooo0ol00005ooooo`03o`3o0?oooooooooo00gooooo0ol0
000@ooooo`03o`3o0?oooooooooo00;ooooo0ol0000@ooooo`;o00000_ooool5o`0001Cooooo1?l0
000Fooooo`;o00005_ooool00ol0003oooooooooo`06ooooo`008Oooool2o`3o01Kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`;o00005_ooool3o`0001Gooooo1Ol0000A
ooooo`So00004oooool2o`0000Gooooo0_l0o`0@ooooo`;o00004Oooool00ol0o`3oooooooooo`02
ooooo`?o00004_ooool2o`000004ooooool0003o0000o`0001Kooooo0ol0000Dooooo`Co00007ooo
ool002?ooooo00?o0?l0ooooooooool0A_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool00_l0000Eooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01?ooool00ol0o`3oooooooooo`0?ooooo`;o00004Oooool00ol0o`3oooooooooo`03
ooooo`;o00005Oooool4o`0001Kooooo0ol0000Dooooo`Co00005Oooool2o`0000Sooooo000Toooo
o`;o0?l0M?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo0_l0o`0Boooo
o`03o`000?oooooooooo013ooooo00?o0?l0ooooooooool00oooool2o`0001Kooooo0ol0000Goooo
o`;o00005Oooool3o`0001Gooooo0_l00008ooooo`009_ooool2o`3o077ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Gooooo`03o`3o0?oooooooooo02Gooooo00?o0?l0oooooooo
ool00oooool00ol0003oooooooooo`0Fooooo`Co00005Oooool2o`0001Kooooo0ol0000Eooooo`03
o`000?oooooooooo00Kooooo000Xooooo`;o0?l0KOooool2o`0001cooooo00?o0000ooooooooool0
5_ooool00ol0o`3oooooooooo`0Vooooo`03o`3o0?oooooooooo01cooooo00Co0000oooooooooooo
oooo0_l0000Cooooo`;o00005_ooool3o`0001kooooo000Zooooo`?o0?l0JOooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo0_l0o`0Xooooo`03o`3o0?oooooooooo02?ooooo
0_l0000Booooo`03o`000?oooooooooo01Gooooo0_l0000Nooooo`00;Oooool3o`3o06Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`3o0?oooooooooo02Sooooo00?o
0?l0ooooooooool09Oooool2o`0002Wooooo00?o0000ooooooooool07?ooool0033ooooo0_l0o`1R
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool2o`3o02_ooooo00?o0?l0
ooooooooool09oooool2o`0004Kooooo000booooo`?o0?l0G_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo013ooooo00?o0?l0ooooooooool0:_ooool00ol0o`3oooooooooo`0Zoooo
o`?o0000@oooool003Gooooo0_l0o`1Kooooo`03o`000?oooooooooo023ooooo0_l0000?ooooo`;o
0?l0;?ooool00ol0o`3oooooooooo`0^ooooo`;o0000@Oooool001Wooooo1Ol0000Iooooo`?o0?l0
F?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0?l0ooooooooool0
;?ooool00ol0o`3oooooooooo`0`ooooo`03o`000?oooooooooo03kooooo000Kooooo`Ko00004Ooo
ool5o`0000?ooooo0ol0o`1Dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02ooo
ool2o`3o027ooooo00?o0000ooooooooool02_ooool00ol0o`3oooooooooo`0booooo`03o`000?oo
oooooooo03gooooo000Looooo`Go00004oooool6o`0000?ooooo0_l0o`0<ooooo`So00005Oooool4
o`0002Cooooo00?o0000ooooooooool08_ooool2o`0000Wooooo0ol0o`0;ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02_ooool00ol0o`3oooooooooo`07ooooo`?o0000:Oooool2
o`0003gooooo000Mooooo`Ko00004_ooool6o`0000Cooooo0ol0o`0;ooooo`Ko00004Oooool8o`00
01Kooooo1?l00009ooooo`03o`000?oooooooooo00[ooooo0_l0000Fooooo`?o00001oooool2o`3o
00gooooo0_l0000Fooooo`?o00002_ooool00ol0o`3oooooooooo`08ooooo`Co00005?ooool4o`00
01;ooooo0ol0000jooooo`002oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool2o`0000;ooooo00?o0000ooooooooool01?ooool2o`3o00_o
oooo0ol000000ooooooo0000o`00000Aooooo`Oo00004Oooool8o`0000Sooooo00?o0000oooooooo
ool02?ooool5o`0001Cooooo1_l00004ooooo`;o0?l03_ooool4o`0001Gooooo1?l00009ooooo`03
o`3o0?oooooooooo00Sooooo1?l0000Dooooo`Co00005?ooool4o`0001Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`06ooooo`00>?ooool00ol0003oooooooooo`09ooooo`?o0?l0
2_ooool00ol0003oooooooooo`0Eooooo`?o00005Oooool4o`0000Sooooo00?o0000ooooooooool0
1oooool8o`0000_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c002ooooo`Oo000000Coooooo`3o0?l0
o`3o0?l03oooool6o`0001?ooooo0ol0000:ooooo`03o`3o0?oooooooooo00Wooooo0ol0000Eoooo
o`?o00005Oooool5o`0001?ooooo1?l0000Oooooo`00Aoooool3o`3o027ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo0ol0000;ooooo`06
oa0@4?nj^[[oooooogMgMolb<S;ooooo1?l000000ooooooo0000o`3o0002o`3o017ooooo1?l0000F
ooooo`;o00002oooool00ol0o`3oooooooooo`08ooooo`?o00005_ooool3o`0001Gooooo1?l00000
0ooooooo0000o`00000Aooooo`Co00005Oooool2o`0000Sooooo001:ooooo`?o0?l0?_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo0ol0o`02o`00017ooooo0_l0000Ioooo
o`03o`000?oooooooooo00Wooooo00?o0?l0ooooooooool02Oooool3o`0001Kooooo0_l0000Foooo
o`?o00001?ooool2o`00013ooooo0ol0000Eooooo`;o00002?ooool004gooooo1?l0o`0iooooo`03
o`000?oooooooooo023ooooo00?oZJVYoa0@4?ooool00ol0o`02ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool02_ooool00ol0o`3oooooooooo`09ooooo`;o00005oooool2o`0001Oo
oooo0_l00006ooooo`;o00003_ooool3o`0001Kooooo00?o0000ooooooooool01_ooool0057ooooo
1_l0o`0booooo`03o`000?oooooooooo023ooooo00Co410@o`3o0?l0o`3o0?l01Oooool00ol0003o
ooooooooo`0gooooo`03o`3o0?oooooooooo00[ooooo00?o0000ooooooooool05_ooool2o`0001Oo
oooo0_l00008ooooo`03o`000?oooooooooo00cooooo0_l0000Fooooo`03o`000?oooooooooo00Ko
oooo001Gooooo`Go0?l0;?ooool00ol0003oooooooooo`0Oooooo`?o0?l000?o^[Zjob4Q8Oooool0
1Oooool00ol0003oooooooooo`0fooooo`03o`3o0?oooooooooo02Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`08ooooo`?o00002oooool2o`0001oooooo001Looooo`Co0?l09_oo
ool2o`0001gooooo1Ol0o`001Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0
=Oooool00ol0o`3oooooooooo`0nooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`03o`00
0?oooooooooo01gooooo001Pooooo`Co0?l08Oooool00ol0003oooooooooo`0Eooooo`So0?l01Ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0=?ooool00ol0o`3ooooo
ooooo`1>ooooo`;o0000:Oooool006Cooooo2ol0o`0Eooooo`03o`000?oooooooooo013ooooo1_l0
o`0Hooooo`03o`000?oooooooooo03?ooooo00?o0?l0ooooooooool0DOooool3o`0002Kooooo001_
ooooo`[o0?l02_ooool00ol0003oooooooooo`09ooooo`So0?l07_ooool00ol0003oooooooooo`0c
ooooo`03o`3o0?oooooooooo05Cooooo0_l0000Tooooo`00NOooool9o`3o0003o`000?l0o`3o0?l0
00[o0?l09_ooool00ol0003oooooooooo`0booooo`03o`3o0?oooooooooo05Oooooo0_l0000Roooo
o`005oooool8o`0006;ooooo00?o0000ooooooooool0<Oooool2o`0003;ooooo00?o0?l0oooooooo
ool0F_ooool2o`00023ooooo000Iooooo`Ko00004_ooool8o`0001Gooooo1?l0000_ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0;Oooool01?l0003oooooooooool0o`1Oooooo`;o
00007_ooool001[ooooo2?l0000Aooooo`Oo00004?ooool8o`0001Gooooo1?l0000Eooooo`Co0000
5oooool2o`0001Oooooo0_l0000Gooooo`03o`000?oooooooooo01Gooooo00?o0000o`3o0?l0o`00
5Oooool2o`0001Kooooo0_l0000cooooo`03o`000?oooooooooo01_ooooo000;ooooo`03o`000?oo
oooooooo00kooooo0_l00004ooooo`;o00004Oooool3o`0000;ooooo0_l0000@ooooo`Wo00003_oo
ool:o`00017ooooo1ol0000Dooooo`Go00005Oooool3o`0001Kooooo0ol0000Eooooo`04o`000?l0
o`3o0000o`0001Gooooo0ol0000Eooooo`?o00005Oooool3o`0001Oooooo00Co0000oooooooooooo
oooo0_l0000Booooo`03o`000?oooooooooo00Kooooo000Mooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05?ooool3o`0001Gooooo1Ol0000Aooooo`So00004oooool7o`0001?ooooo
1_l0000Dooooo`Go00005?ooool00ol0o`3o0000o`000002o`0001?ooooo1Ol0000Dooooo`Co0000
5?ooool4o`0001Cooooo1?l00004ooooo`;o00006Oooool0053ooooo00?o0000ooooooooool05_oo
ool2o`0001;ooooo00Co0000oooooooooooooooo0ol0000Booooo`So00004_ooool7o`0001?ooooo
1?l0000Eooooo`04o`3o0?l0003o0000o`0001Gooooo0ol0000Fooooo`Co00005?ooool4o`0001Co
oooo1?l00006ooooo`?o00005_ooool007_ooooo0_l0000booooo`Co00000_ooool00ol0003ooooo
ooooo`0Aooooo`;o00005oooool00ol0o`3o0000o`00000Gooooo`;o00005_ooool4o`0001Gooooo
0ol0000Eooooo`Co00002Oooool2o`0000[ooooo0_l00008ooooo`00N_ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0o`3o0000oooo
o`0Gooooo`;o00005oooool3o`0001Kooooo0ol0000Fooooo`?o00002oooool2o`0000Sooooo0_l0
0008ooooo`00NOooool00ol0003oooooooooo`0iooooo`;o0000:Oooool00ol0o`3oooooooooo`0H
ooooo`03o`000?oooooooooo01Kooooo0_l0000Gooooo`;o00005oooool2o`0000kooooo0_l00007
ooooo`03o`000?oooooooooo00Kooooo001hooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool09oooool00ol0o`3oooooooooo`0booooo`03o`000?oooooooooo01Kooooo0_l0000Goooo
o`;o00004?ooool3o`0000Cooooo00?o0000ooooooooool01_ooool007Oooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Vooooo`03o`3o0?oooooooooo04cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Aooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`00
M_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02Gooooo00?o0?l0ooooooooool0
Ioooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo001fooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool09?ooool00ol0o`3oooooooooo`1oooooo`03o`000?oo
oooooooo00Oooooo001eooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08_ooool2
o`3o08?ooooo00?o0000ooooooooool01_ooool007Cooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0Qooooo`03o`3o0?oooooooooo08cooooo001cooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool07oooool2o`3o08oooooo000Fooooo`So00005Oooool4o`0003_ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`3o0?oooooooooo08oooooo
000Hooooo`Ko00004_ooool7o`0001Kooooo1?l0000Fooooo`?o00001_ooool2o`0000oooooo0_l0
000Gooooo`;o00005oooool4o`0001Gooooo00?o0000ooooooooool01Oooool2o`3o09;ooooo000K
ooooo`Oo00004?ooool7o`00013ooooo2?l0000Cooooo`Ko00001Oooool00ol0003oooooooooo`0<
ooooo`Go00005Oooool4o`0001Kooooo1?l0000Eooooo`;o00001Oooool2o`3o013ooooo0_l0000F
ooooo`;o00005_ooool2o`0005;ooooo000;ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool2o`00013ooooo0ol00002ooooo`?o00004?ooool9o`0000gooooo2ol000000ooo
oooo0000ooooo`0<ooooo`Wo00004Oooool8o`0001;ooooo1_l0000Dooooo`Co00000oooool00ol0
o`3oooooooooo`0@ooooo`?o00005Oooool3o`0001Gooooo0ol0000Fooooo`?o00005oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo000fooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool05Oooool3o`0000?ooooo00?o0000ooooooooool02oooool8o`0001;o
oooo2?l0000Booooo`Oo00004oooool6o`0000;o0?l04_ooool5o`0001?ooooo1Ol0000Dooooo`Co
00005Oooool4o`0001Cooooo0ol0000Gooooo`03o`000?oooooooooo00Kooooo001]ooooo`03o`00
0?oooooooooo013ooooo0ol0000Gooooo`?o00004Oooool8o`0001;ooooo1?l00002ooooo`03o`3o
0?oooooooooo017ooooo1?l0000Eooooo`?o00005_ooool4o`0001Gooooo1?l0000Dooooo`Co0000
5?ooool3o`0000Sooooo001/ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool03ooo
ool2o`0000?ooooo0_l0o`0Cooooo`;o00006?ooool2o`0001Kooooo1?l0000Fooooo`?o00005Ooo
ool4o`0001Cooooo0ol00008ooooo`00J_ooool2o`0004Wooooo00?o0000ooooooooool04oooool0
0ol0o`3oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo0_l0000Gooooo`?o00005_ooool3
o`0001Kooooo0ol0000Eooooo`?o00002?ooool006Wooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0Aooooo`;o0?l0;oooool00ol0003oooooooooo`0Fooooo`;o00005oooool3o`00
01Kooooo0ol0000Fooooo`;o00002?ooool006Sooooo00?o0000ooooooooool0B_ooool2o`00013o
oooo0_l0o`1:ooooo`03o`000?oooooooooo01Kooooo0_l0000Gooooo`;o00005oooool2o`0000So
oooo001Wooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool03Oooool2o`3o06Gooooo
00?o0000ooooooooool05_ooool2o`0001Oooooo0_l00008ooooo`00I_ooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo00_ooooo0_l0o`20ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01_ooool006Gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`08
ooooo`?o0?l0W?ooool00ol0003oooooooooo`06ooooo`00I?ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo00Kooooo0_l0o`2Xooooo`00I?ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo00Cooooo0_l0o`2Zooooo`006Oooool4o`0004Kooooo00?o0000ooooooooool0
A_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`3o0:cooooo
000Eooooo`So00004Oooool8o`0001Gooooo1?l0000Cooooo`04o`000?ooooooooooooooo`?o0000
A?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o0?l0[_ooool001Sooooo2Ol0
000?ooooo`Wo00003oooool7o`0001;ooooo00?o0000ooooool000001Ol0000Fooooo`?o00005ooo
ool2o`0000oooooo1Ol00002ooooo`;o00000_ooool00ol0003o0?l0o`3o000Cooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0P_ooool000_ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`?o00003oooool3o`0000?ooooo0ol0000?ooooo`[o00002oooool9
o`0000?ooooo00?o0000ooooooooool03Oooool6o`0000;ooooo00?o0000ooooooooool03oooool5
o`0000;ooooo00?o0000ooooooooool02_ooool01?m4A4CogMgMooooool00002ooooo`?o00000_oo
ool00ol0o`3o0000o`00000Booooo`;o000000?oooooo`000?ooool05?ooool01?l0003ooooooooo
ool0000Eooooo`03o`000?oooooo000001Gooooo0ol0000Gooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`00Z_ooool01?oMgMgoEEEEoooo
ool0002jooooo`00Zoooool00omgMgOoc<c<o`00002jooooo`00Zoooool00oo^k^koA4A4o`00002j
ooooo`00[?ooool00omgMgOo0000ooooo`2iooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 364.875}, {450.75, 271.75}} -> {-6.55521, \
6.86035, 0.0294121, 0.0294121}}]
}, Open  ]],

Cell["\<\
This kind of outward spiraling autonomous flow is called a \"source\
\". Phase portraits for constant coefficient  autonomous linear systems are \
often referred to as \"linear flows\". 
Symbolic solution formulas for a source are given in terms of sines, cosines, \
and exponential functions.  \
\>", "Text"],

Cell[CellGroupData[{

Cell["solnFormulas = DSolve[ DEsys, {x,y}, t ]", "Input",
  CellLabel->"In[157]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, \[ExponentialE]\^t\ C[
                  1]\ Cos[\@2\ t] - \@2\ \[ExponentialE]\^t\ C[
                  2]\ Sin[\@2\ t] + \(Sin[\@2\ t]\ \((\(-10\)\ Cos[\@2\ t] + \
\@2\ Sin[\@2\ t])\)\)\/\(3\ \@2\) + 
              1\/3\ Cos[\@2\ t]\ \((Cos[\@2\ t] + 5\ \@2\ Sin[\@2\ t])\)], 
        y \[Rule] 
          Function[{t}, \[ExponentialE]\^t\ C[
                  2]\ Cos[\@2\ t] + \(\[ExponentialE]\^t\ C[1]\ Sin[\@2\ t]\)\
\/\@2 - 1\/6\ Cos[\@2\ t]\ \((\(-10\)\ Cos[\@2\ t] + \@2\ Sin[\@2\ t])\) + \
\(Sin[\@2\ t]\ \((Cos[\@2\ t] + 5\ \@2\ Sin[\@2\ t])\)\)\/\(3\ \@2\)]}}\)], \
"Output",
  CellLabel->"Out[157]="]
}, Open  ]],

Cell["\<\
These formulas are easier to understand if displayed in simplified \
form.\
\>", "Text"],

Cell[CellGroupData[{

Cell["x[t]/.solnFormulas//FullSimplify", "Input",
  CellLabel->"In[158]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({1\/3 + \[ExponentialE]\^t\ \((C[1]\ Cos[\@2\ t] - \@2\ C[
                  2]\ Sin[\@2\ t])\)}\)], "Output",
  CellLabel->"Out[158]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["y[t]/.solnFormulas//FullSimplify", "Input",
  CellLabel->"In[159]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({5\/3 + \[ExponentialE]\^t\ C[
            2]\ Cos[\@2\ t] + \(\[ExponentialE]\^t\ C[1]\ Sin[\@2\ t]\)\/\@2}\
\)], "Output",
  CellLabel->"Out[159]="]
}, Open  ]],

Cell["\<\
Observe that the \"stationary solution\" is obtained by setting the \
constants equal to 0. Linear flows are  discussed in more detail in the next \
section. \
\>", "Text"]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{801, 740},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->91,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3305920359-3978630"->{
    Cell[393727, 13874, 362, 9, 42, "Print",
      CellTags->"Info3305920359-3978630"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3305920359-3978630", 508924, 17589}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 210, 6, 66, "Text"],
Cell[1967, 59, 68, 0, 28, "Text"],
Cell[2038, 61, 329, 18, 28, "Text"],
Cell[2370, 81, 106, 3, 28, "Text"],
Cell[2479, 86, 393, 21, 59, "Text"],
Cell[2875, 109, 343, 10, 48, "Text"],
Cell[3221, 121, 489, 27, 59, "Text"],
Cell[3713, 150, 563, 19, 68, "Text"],
Cell[4279, 171, 62, 1, 31, "Input"],
Cell[4344, 174, 986, 43, 68, "Text"],
Cell[5333, 219, 436, 24, 59, "Text"],
Cell[5772, 245, 50, 0, 28, "Text"],
Cell[5825, 247, 70, 0, 28, "Text"],
Cell[5898, 249, 392, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[6315, 260, 124, 4, 51, "Input"],
Cell[6442, 266, 477, 13, 27, "Output"]
}, Open  ]],
Cell[6934, 282, 372, 13, 36, "Text"],

Cell[CellGroupData[{
Cell[7331, 299, 94, 1, 23, "Input"],
Cell[7428, 302, 360, 6, 42, "Message"],
Cell[7791, 310, 397, 7, 42, "Message"],
Cell[8191, 319, 361, 6, 42, "Message"],
Cell[8555, 327, 361, 6, 42, "Message"],
Cell[8919, 335, 66, 2, 27, "Output"]
}, Open  ]],
Cell[9000, 340, 220, 9, 28, "Text"],

Cell[CellGroupData[{
Cell[9245, 353, 117, 4, 31, "Input"],
Cell[9365, 359, 439, 12, 27, "Output"]
}, Open  ]],
Cell[9819, 374, 322, 14, 28, "Text"],

Cell[CellGroupData[{
Cell[10166, 392, 226, 5, 71, "Input"],
Cell[10395, 399, 43657, 1167, 117, 14080, 797, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[54067, 1569, 110, 3, 28, "Text"],
Cell[54180, 1574, 436, 23, 28, "Text"],
Cell[54619, 1599, 103, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[54747, 1606, 168, 4, 51, "Input"],
Cell[54918, 1612, 60272, 2058, 198, 32931, 1715, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[115205, 3673, 120, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[115350, 3680, 206, 6, 91, "Input"],
Cell[115559, 3688, 69085, 2445, 201, 38286, 2060, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[184659, 6136, 116, 2, 28, "Text"],
Cell[184778, 6140, 312, 7, 48, "Text"],

Cell[CellGroupData[{
Cell[185115, 6151, 184, 6, 71, "Input"],
Cell[185302, 6159, 1077, 20, 234, "Output"]
}, Open  ]],
Cell[186394, 6182, 101, 2, 28, "Text"],
Cell[186498, 6186, 310, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[186833, 6195, 472, 12, 231, "Input"],
Cell[187308, 6209, 99866, 3680, 231, 54807, 3119, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[287189, 9892, 125, 5, 28, "Text"],
Cell[287317, 9899, 109, 3, 28, "Text"],
Cell[287429, 9904, 392, 22, 60, "Text"],
Cell[287824, 9928, 136, 3, 28, "Text"],
Cell[287963, 9933, 313, 6, 48, "Text"],
Cell[288279, 9941, 67, 1, 31, "Input"],

Cell[CellGroupData[{
Cell[288371, 9946, 246, 6, 91, "Input"],
Cell[288620, 9954, 101341, 3797, 246, 56003, 3232, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[389976, 13754, 116, 2, 28, "Text"],
Cell[390095, 13758, 847, 21, 108, "Text"],
Cell[390945, 13781, 26, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[390996, 13785, 112, 2, 29, "Input"],
Cell[391111, 13789, 267, 7, 48, "Output"]
}, Open  ]],
Cell[391393, 13799, 66, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[391484, 13803, 97, 2, 29, "Input"],
Cell[391584, 13807, 261, 7, 48, "Output"]
}, Open  ]],
Cell[391860, 13817, 110, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[391995, 13824, 107, 2, 29, "Input"],
Cell[392105, 13828, 361, 6, 42, "Message"],
Cell[392469, 13836, 398, 7, 42, "Message"],
Cell[392870, 13845, 398, 7, 42, "Message"],
Cell[393271, 13854, 179, 5, 48, "Output"]
}, Open  ]],
Cell[393465, 13862, 156, 4, 28, "Text"],

Cell[CellGroupData[{
Cell[393646, 13870, 78, 2, 29, "Input"],
Cell[393727, 13874, 362, 9, 42, "Print",
  CellTags->"Info3305920359-3978630"]
}, Open  ]],
Cell[394104, 13886, 151, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[394280, 13893, 142, 5, 29, "Input"],
Cell[394425, 13900, 13684, 432, 159, 4033, 308, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[408124, 14335, 109, 2, 28, "Text"],
Cell[408236, 14339, 60, 0, 28, "Text"],
Cell[408299, 14341, 390, 20, 59, "Text"],
Cell[408692, 14363, 471, 18, 48, "Text"],
Cell[409166, 14383, 589, 18, 68, "Text"],
Cell[409758, 14403, 135, 4, 28, "Text"],
Cell[409896, 14409, 300, 15, 59, "Text"],
Cell[410199, 14426, 101, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[410325, 14433, 151, 5, 47, "Input"],
Cell[410479, 14440, 471, 13, 27, "Output"]
}, Open  ]],
Cell[410965, 14456, 230, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[411220, 14464, 118, 2, 29, "Input"],
Cell[411341, 14468, 93, 2, 45, "Output"]
}, Open  ]],
Cell[411449, 14473, 101, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[411575, 14480, 96, 2, 29, "Input"],
Cell[411674, 14484, 73, 2, 45, "Output"]
}, Open  ]],
Cell[411762, 14489, 192, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[411979, 14497, 619, 12, 209, "Input"],
Cell[412601, 14511, 92134, 2951, 188, 43356, 2344, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[504750, 17465, 319, 6, 80, "Text"],

Cell[CellGroupData[{
Cell[505094, 17475, 108, 2, 29, "Input"],
Cell[505205, 17479, 671, 13, 229, "Output"]
}, Open  ]],
Cell[505891, 17495, 98, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[506014, 17502, 100, 2, 29, "Input"],
Cell[506117, 17506, 156, 3, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[506310, 17514, 100, 2, 29, "Input"],
Cell[506413, 17518, 170, 4, 56, "Output"]
}, Open  ]],
Cell[506598, 17525, 182, 4, 48, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

