(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     97498,       3126]*)
(*NotebookOutlinePosition[     99676,       3191]*)
(*  CellTagsIndexPosition[     99632,       3187]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part IV. Linear Differential Equations", "Section"],
  "\n",
  StyleBox["Section 4. Matrix Methods", "Subsection"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "In this section, you will learn enough about vectors and matrices in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to use them to obtain vector solutions  to linear systems of the form "
}], "Text"],

Cell[TextData[{
  StyleBox["x' = a x",
    FontSlant->"Italic"],
  " + ",
  StyleBox["b y",
    FontSlant->"Italic"],
  " \n",
  StyleBox["y' = c x",
    FontSlant->"Italic"],
  " + ",
  StyleBox["d y",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "where ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " are functions of ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", ",
  StyleBox["c",
    FontSlant->"Italic"],
  ", ",
  StyleBox["d",
    FontSlant->"Italic"],
  " are constants. Three dimensional systems will also be considered.  \
Vectors and matrices arise naturally by replacing scalar equations with one \
vector equation v' = Av, where v is a  vector valued function having the \
unknown functions as its components and A is a square matrix.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Warning: It is assumed that the reader knows what eigenvectors \
and eigenvalues are and understands the role they play in formulating \
solutions to systems of differential equations. (See Ledder, Chapter 6.) Our \
principal goal is to demonstrate  how to handle vectors, matrices, \
eigenvectors, etc. so that  ", "Program"],
  StyleBox["Mathematica", "Program",
    FontSlant->"Italic"],
  StyleBox[" can be applied successfully to the analysis of such  systems. ", 
    "Program"]
}], "Text"],

Cell[TextData[StyleBox["Matrices and Vectors ", "Subsubsection"]], "Text"],

Cell[TextData[{
  "A vector in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is represented as a list. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
u = {1,2,3}
v = {a,b,c}\
\>", "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({1, 2, 3}\)], "Output",
  CellLabel->"Out[4]="],

Cell[BoxData[
    \({a, b, c}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
The dot product is obtained as u.v (put a period between u and \
v).\
\>", "Text"],

Cell[CellGroupData[{

Cell["u.v", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(a + 2\ b + 3\ c\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["A matrix is a list of lists. Each list is a row.", "Text"],

Cell[CellGroupData[{

Cell["A = {{1,2,3},{4,5,6},{7,8,9}}", "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \({{1, 2, 3}, {4, 5, 6}, {7, 8, 9}}\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell["The function MatrixForm will display A as a matrix.", "Text"],

Cell[CellGroupData[{

Cell["MatrixForm[A]", "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3"},
            {"4", "5", "6"},
            {"7", "8", "9"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[2]//MatrixForm="]
}, Open  ]],

Cell["\<\
The MatrixForm function displays a one-dimensional list (i.e. a \
vector) as a column. The next entry shows an alternate way to apply the \
MatrixForm function.\
\>", "Text"],

Cell[CellGroupData[{

Cell["u//MatrixForm", "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1"},
            {"2"},
            {"3"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {1, 2, 3}]]], "Output",
  CellLabel->"Out[6]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The matrix A and the vector v are multiplied in this order using A.v. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " interprets v as column vector and outputs the product as a vector (i.e. a \
list)."
}], "Text"],

Cell[CellGroupData[{

Cell["A.v", "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({a + 2\ b + 3\ c, 4\ a + 5\ b + 6\ c, 7\ a + 8\ b + 9\ c}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["v.A//MatrixForm", "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(a + 4\ b + 7\ c\)},
            {\(2\ a + 5\ b + 8\ c\)},
            {\(3\ a + 6\ b + 9\ c\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Plus[ a, 
          Times[ 4, b], 
          Times[ 7, c]], 
        Plus[ 
          Times[ 2, a], 
          Times[ 5, b], 
          Times[ 8, c]], 
        Plus[ 
          Times[ 3, a], 
          Times[ 6, b], 
          Times[ 9, c]]}]]], "Output",
  CellLabel->"Out[7]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "Matrix A and vector v can also be multiplied in the opposite order using \
v.A. Now ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " interprets v as a row and still outputs the product as a vector."
}], "Text"],

Cell[CellGroupData[{

Cell["v.A", "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({a + 4\ b + 7\ c, 2\ a + 5\ b + 8\ c, 3\ a + 6\ b + 9\ c}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["\<\
The MatrixForm function displays this product as a column \
also.\
\>", "Text"],

Cell[CellGroupData[{

Cell["v.A//MatrixForm", "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(a + 4\ b + 7\ c\)},
            {\(2\ a + 5\ b + 8\ c\)},
            {\(3\ a + 6\ b + 9\ c\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Plus[ a, 
          Times[ 4, b], 
          Times[ 7, c]], 
        Plus[ 
          Times[ 2, a], 
          Times[ 5, b], 
          Times[ 8, c]], 
        Plus[ 
          Times[ 3, a], 
          Times[ 6, b], 
          Times[ 9, c]]}]]], "Output",
  CellLabel->"Out[9]//MatrixForm="]
}, Open  ]],

Cell["The Table function can be used to make matrices.", "Text"],

Cell[CellGroupData[{

Cell["B = Table[ 1/(m+n^2), {m,1,3}, {n,0,2} ]", "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({{1, 1\/2, 1\/5}, {1\/2, 1\/3, 1\/6}, {1\/3, 1\/4, 1\/7}}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["The determinant of B is obtained with the entry ", "Text"],

Cell["Det[B]", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
MatrixForm[B]
Det[B]\
\>", "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(1\/2\), \(1\/5\)},
            {\(1\/2\), \(1\/3\), \(1\/6\)},
            {\(1\/3\), \(1\/4\), \(1\/7\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[11]//MatrixForm="],

Cell[BoxData[
    \(1\/1260\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["\<\
Since B's determinant is not zero, it has an inverse. It can be \
found using\
\>", "Text"],

Cell["Inverse[B]", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Binverse = Inverse[B]
B.Binverse\
\>", "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({{15\/2, \(-27\), 21}, {\(-20\), 96, \(-84\)}, {35\/2, \(-105\), 
        105}}\)], "Output",
  CellLabel->"Out[13]="],

Cell[BoxData[
    \({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["\<\
Be careful because the entry 1/B or B^(-1) will output the matrix \
whose entries are the reciprocals of the entries in B.\
\>", "Text"],

Cell[CellGroupData[{

Cell["1/B", "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({{1, 2, 5}, {2, 3, 6}, {3, 4, 7}}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "To find B's characteristic polynomial, as a function of ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  "enter"
}], "Text"],

Cell["CharacteristicPolynomial[B,t]", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["CharacteristicPolynomial[B,t]", "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(1\/1260 - \(139\ t\)\/840 + \(31\ t\^2\)\/21 - t\^3\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell["\<\
The Euclidean length of a vector v can be found using \
Norm[v].\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
v
Norm[v]\
\>", "Input",
  CellLabel->"In[31]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({a, b, c}\)], "Output",
  CellLabel->"Out[31]="],

Cell[BoxData[
    \(\@\(Abs[a]\^2 + Abs[b]\^2 + Abs[c]\^2\)\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
The absolute value function is applied to the components a, b, c \
because they might be complex. If  a, b, c are known to be real numbers, then \
the Euclidean norm of v can also be found as follows.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Sqrt[v.v]", "Input",
  CellLabel->"In[33]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\@\(a\^2 + b\^2 + c\^2\)\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell["\<\
The entry Norm[v,\[Infinity]] calculates what is called the \
\"infinity\" or \"max\" norm of v. This is the maximum of the absolute values \
of the entries.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
u
Norm[u,\[Infinity]]\
\>", "Input",
  CellLabel->"In[36]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({1, 2, 3}\)], "Output",
  CellLabel->"Out[36]="],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[StyleBox["Note. The infinity symbol can be entered using the \
symbol palette. Typing the word \"infinity\" will not work.", "Note"]], "Text"],

Cell["\<\
The entry B[[i,j]] outputs the i,j entry of matrix B. The entry \
v[[k]] is the kth component of the vector v.\
\>", "Text"],

Cell[CellGroupData[{

Cell["{B[[2,2]], v[[2]]}", "Input",
  CellLabel->"In[43]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({1\/3, b}\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["j",
    FontSlant->"Italic"],
  "th column of matrix B is obtained using Take[B,All,{j,j}]. The entry \
Take[B,{i,i}] outputs its ",
  StyleBox["i",
    FontSlant->"Italic"],
  "th row. They appear as lists."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Take[B,All,{3,3}]
Take[B,{1,1}]\
\>", "Input",
  CellLabel->"In[51]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{1\/5}, {1\/6}, {1\/7}}\)], "Output",
  CellLabel->"Out[51]="],

Cell[BoxData[
    \({{1, 1\/2, 1\/5}}\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Augmenting and stacking ",
    FontSlant->"Italic"],
  "(",
  StyleBox["not needed later, but kind of neat anyway",
    FontSlant->"Italic"],
  ")"
}], "Text"],

Cell["\<\
If you would like to stack the matrix B with the row vector \
{x,y,z}, on the bottom, do it like this.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Bstacked = Insert[B,{x,y,z},4]", "Input",
  CellLabel->"In[75]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{1, 1\/2, 1\/5}, {1\/2, 1\/3, 1\/6}, {1\/3, 1\/4, 1\/7}, {x, y, 
        z}}\)], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["MatrixForm[Bstacked]", "Input",
  CellLabel->"In[76]:=",
  FormatType->InputForm],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(1\/2\), \(1\/5\)},
            {\(1\/2\), \(1\/3\), \(1\/6\)},
            {\(1\/3\), \(1\/4\), \(1\/7\)},
            {"x", "y", "z"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[76]//MatrixForm="]
}, Open  ]],

Cell["\<\
If you would like to then put {a,b,c,d} into the right column of \
Bstacked, first transpose Bstacked.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Transpose[Bstacked]", "Input",
  CellLabel->"In[79]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{1, 1\/2, 1\/3, x}, {1\/2, 1\/3, 1\/4, y}, {1\/5, 1\/6, 1\/7, 
        z}}\)], "Output",
  CellLabel->"Out[79]="]
}, Open  ]],

Cell["Then insert {a,b,c,d} along the bottom.", "Text"],

Cell[CellGroupData[{

Cell["Insert[%,{a,b,c,d},4]", "Input",
  CellLabel->"In[80]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{1, 1\/2, 1\/3, x}, {1\/2, 1\/3, 1\/4, y}, {1\/5, 1\/6, 1\/7, z}, {a, 
        b, c, d}}\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]],

Cell["And then transpose again.", "Text"],

Cell[CellGroupData[{

Cell["Bstackedaugmented = Transpose[%]", "Input",
  CellLabel->"In[81]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{1, 1\/2, 1\/5, a}, {1\/2, 1\/3, 1\/6, b}, {1\/3, 1\/4, 1\/7, c}, {x, 
        y, z, d}}\)], "Output",
  CellLabel->"Out[81]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["%//MatrixForm", "Input",
  CellLabel->"In[82]:=",
  FormatType->InputForm],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(1\/2\), \(1\/5\), "a"},
            {\(1\/2\), \(1\/3\), \(1\/6\), "b"},
            {\(1\/3\), \(1\/4\), \(1\/7\), "c"},
            {"x", "y", "z", "d"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[82]//MatrixForm="]
}, Open  ]],

Cell["\<\
Finally, if you need to calculate the determinant of the 3 x 3 \
submatrix of Bstackedaugmented that is obtained by deleting its first row and \
first column, do it like this.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Bstackedaugmented[[{2,3,4},{2,3,4}]];
%//MatrixForm
%%//Det\
\>", "Input",
  CellLabel->"In[92]:=",
  FormatType->InputForm],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/3\), \(1\/6\), "b"},
            {\(1\/4\), \(1\/7\), "c"},
            {"y", "z", "d"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[93]//MatrixForm="],

Cell[BoxData[
    \(d\/168 - \(b\ y\)\/7 + \(c\ y\)\/6 + \(b\ z\)\/4 - \(c\ z\)\/3\)], \
"Output",
  CellLabel->"Out[94]="]
}, Open  ]],

Cell[TextData[StyleBox["Eigenvectors and Eigenvalues", "Subsubsection"]], \
"Text"],

Cell["\<\
The matrix A, defined below,  is square. It has eigenvectors and \
eigenvalues. Let's find them.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
A = {{3,2,1},{0,-1,-1},{2,1,1}};
%//MatrixForm\
\>", "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"3", "2", "1"},
            {"0", \(-1\), \(-1\)},
            {"2", "1", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[97]//MatrixForm="]
}, Open  ]],

Cell["First find A's characteristic polynomial.", "Text"],

Cell[CellGroupData[{

Cell["cp = CharacteristicPolynomial[A,t]", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(\(-2\) + 2\ t + 3\ t\^2 - t\^3\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
Then obtain the eigenvalues as its roots. Call the output lambda.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell["Solve[cp==0,t]", "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({{t \[Rule] \(-1\)}, {t \[Rule] 2 - \@2}, {t \[Rule] 
          2 + \@2}}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["And use it to make a list of eigenvalues called lambda.", "Text"],

Cell[CellGroupData[{

Cell["lambda = Table[t/.%[[j]],{j,1,3}]", "Input",
  CellLabel->"In[13]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({\(-1\), 2 - \@2, 2 + \@2}\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[{
  "Now use the ",
  StyleBox["NullSpace",
    FontWeight->"Bold"],
  " function to obtain bases for the three eigenspaces. Recall that the kth \
eigenspace is the null  space of the matrix "
}], "Text"],

Cell[TextData[{
  StyleBox["A - lambda[[k]]*Identity",
    FontWeight->"Bold"],
  " "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "where \"Identity\" is the 3 x 3 identity matrix. This is obtained in ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "with the entry "
}], "Text"],

Cell[TextData[{
  StyleBox["IdentityMatrix[3]",
    FontWeight->"Bold"],
  "."
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
v = Table[ NullSpace[ A - lambda[[k]]*IdentityMatrix[3] ],
      {k,1,3} ]
   \
\>", "Input",
  CellLabel->"In[35]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{{\(-1\), 2, 0}}, {{\(-\(\(3 - 2\ \@2\)\/\(\(-3\) + \@2\)\)\), 
          1\/\(\(-3\) + \@2\), 
          1}}, {{\(-\(\(\(-3\) - 
                  2\ \@2\)\/\(3 + \@2\)\)\), \(-\(1\/\(3 + \@2\)\)\), 
          1}}}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[{
  "The output for ",
  StyleBox["NullSpace",
    FontWeight->"Bold"],
  " is a list containing a basis for the null space, in list form. If further \
 computations are required it would probably be wise to convert the \
eigenvalues and eigenvectors to floating point form. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
N[lambda,3]
N[v,3]\
\>", "Input",
  CellLabel->"In[39]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({\(-1.`2.9999999999999973\), 0.5857864376269049512`3.5851087004280693, 
      3.4142135623730950488`2.9999999999999973}\)], "Output",
  CellLabel->"Out[39]="],

Cell[BoxData[
    \({{{\(-1.`2.9999999999999973\), 2.`2.9999999999999973, 
          0}}, {{0.1081941875543878362`3.350160949407758, \
\(-0.6306019374818707213`2.9999999999999996\), 
          1.`2.9999999999999973}}, {{1.3203772410170407354`3.692292108955943, \
\(-0.2265409196609864216`3.635635413857253\), 
          1.`2.9999999999999973}}}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontVariations->{"Underline"->True}],
  StyleBox["'s direct method",
    FontVariations->{"Underline"->True}],
  "\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has functions that will output eigenvectors and eigenvalues directly. To \
obtain A's eigenvalues apply the ",
  StyleBox["Eigenvalues",
    FontWeight->"Bold"],
  " function."
}], "Text"],

Cell[CellGroupData[{

Cell["Eigenvalues[A]", "Input",
  CellLabel->"In[41]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({2 + \@2, \(-1\), 2 - \@2}\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[TextData[{
  "The output is a list of A's eigenvalues. The function called ",
  StyleBox["Eigenvectors",
    FontWeight->"Bold"],
  " will output a list with each eigenvector appearing in list form. Observe \
that the eigenvectors appear in simplified form and in the order \
corresponding to the appearance of the output for ",
  StyleBox["Eigenvalue",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["Eigenvectors[A]", "Input",
  CellLabel->"In[42]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{\(-\(1\/7\)\) + 3\/7\ \((2 + \@2)\), \(-\(5\/7\)\) + 
          1\/7\ \((2 + \@2)\), 1}, {\(-1\), 2, 
        0}, {\(-\(1\/7\)\) + 3\/7\ \((2 - \@2)\), \(-\(5\/7\)\) + 
          1\/7\ \((2 - \@2)\), 1}}\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[TextData[StyleBox["Eigenvector solutions to v' = Av, the 2 x 2 case", \
"Subsubsection"]], "Text"],

Cell[" Let's begin by solving a simple 2 x 2 system ", "Text"],

Cell[TextData[{
  StyleBox["    x' = x ",
    FontSlant->"Italic"],
  "+ 2 ",
  StyleBox["y",
    FontSlant->"Italic"],
  "\n",
  StyleBox[" y' = x",
    FontSlant->"Italic"],
  "  -  ",
  StyleBox["y",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "using eigenvectors. This is equivalent to v' = A v where v = < ",
  StyleBox["x , y",
    FontSlant->"Italic"],
  " > and  "
}], "Text"],

Cell[TextData[{
  "A = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"1", "2"},
              {"1", \(-1\)}
              }], ")"}], TraditionalForm]],
    TextAlignment->Center,
    TextJustification->0],
  " ."
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["Start with the eigenvectors and eigenvalues of A.", "Text"],

Cell[CellGroupData[{

Cell["\<\
A = {{1,2},{1,-1}};
%//MatrixForm
lambda = Eigenvalues[A]
v = Eigenvectors[A]\
\>", "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2"},
            {"1", \(-1\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[109]//MatrixForm="],

Cell[BoxData[
    \({\(-\@3\), \@3}\)], "Output",
  CellLabel->"Out[110]="],

Cell[BoxData[
    \({{1 - \@3, 1}, {1 + \@3, 1}}\)], "Output",
  CellLabel->"Out[111]="]
}, Open  ]],

Cell["\<\
Let v1 and v2 be the eigenvector solutions. They are straight line \
trajectories. Recall that vk is defined using the formula\
\>", "Text"],

Cell[TextData[{
  "vk = ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\^\(\(\[Lambda]\_k\) t\)\) E\_k\)],
    TextAlignment->Center,
    TextJustification->0]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`E\_k\ is\ an\ eigenvector\ for\ the\ eigenvalue\ \
\[Lambda]\_k\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
v1 = Exp[lambda[[1]]*t]*v[[1]]
v2 = Exp[lambda[[2]]*t]*v[[2]]\
\>", "Input",
  CellLabel->"In[51]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({\((1 - \@3)\)\ \[ExponentialE]\^\(\(-\@3\)\ t\), \
\[ExponentialE]\^\(\(-\@3\)\ t\)}\)], "Output",
  CellLabel->"Out[51]="],

Cell[BoxData[
    \({\((1 + \@3)\)\ \[ExponentialE]\^\(\@3\ t\), \[ExponentialE]\^\(\@3\ \
t\)}\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell["\<\
Now that we have v1 and v2, the easiest way to obtain solutions to \
the IVP   \
\>", "Text"],

Cell["v' = Av, v(0) = v0", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["is to use the formula  ", "Text"],

Cell[TextData[{
  "v(t) = X(t) ",
  Cell[BoxData[
      \(TraditionalForm\`\(X(0)\)\^\(-1\)\ \(v(0)\)\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
where X(t) is the fundamental matrix having v1 and v2 as its \
columns. See Ledder, Section A.5. \
\>", "Text"],

Cell[CellGroupData[{

Cell["X = Transpose[{v1,v2}]", "Input",
  CellLabel->"In[65]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{\((1 - \@3)\)\ \[ExponentialE]\^\(\(-\@3\)\ t\), \((1 + \@3)\)\ \
\[ExponentialE]\^\(\@3\ t\)}, {\[ExponentialE]\^\(\(-\@3\)\ t\), \
\[ExponentialE]\^\(\@3\ t\)}}\)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell["\<\
For example, the following entries define the vector v as the \
solution to  v' = A v ,  v(0) = < 1 , 1 > ,  then show the trajectory and the \
initial point. The formula for the solution is suppressed because it is a \
mess.\
\>", "Text"],

Cell["v = X.Inverse[X/.t->0].{1,1};", "Input",
  CellLabel->"In[89]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Pt = ListPlot[{{1,1}}, PlotStyle->PointSize[0.03]];
Traj = ParametricPlot[ v, {t,-1,1}, PlotStyle->RGBColor[0,1,0] ];
SolnTraj = Show[ Pt, Traj, PlotRange->{{-2,4},{-2,4}}, AspectRatio->1/1 \
]\
\>", "Input",
  CellLabel->"In[86]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.333333 0.166667 0.333333 0.166667 [
[0 .32083 -6 -9 ]
[0 .32083 6 0 ]
[.16667 .32083 -6 -9 ]
[.16667 .32083 6 0 ]
[.5 .32083 -3 -9 ]
[.5 .32083 3 0 ]
[.66667 .32083 -3 -9 ]
[.66667 .32083 3 0 ]
[.83333 .32083 -3 -9 ]
[.83333 .32083 3 0 ]
[1 .32083 -3 -9 ]
[1 .32083 3 0 ]
[.32083 0 -12 -4.5 ]
[.32083 0 0 4.5 ]
[.32083 .16667 -12 -4.5 ]
[.32083 .16667 0 4.5 ]
[.32083 .5 -6 -4.5 ]
[.32083 .5 0 4.5 ]
[.32083 .66667 -6 -4.5 ]
[.32083 .66667 0 4.5 ]
[.32083 .83333 -6 -4.5 ]
[.32083 .83333 0 4.5 ]
[.32083 1 -6 -4.5 ]
[.32083 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .33333 m
0 .33958 L
s
[(-2)] 0 .32083 0 1 Mshowa
.16667 .33333 m
.16667 .33958 L
s
[(-1)] .16667 .32083 0 1 Mshowa
.5 .33333 m
.5 .33958 L
s
[(1)] .5 .32083 0 1 Mshowa
.66667 .33333 m
.66667 .33958 L
s
[(2)] .66667 .32083 0 1 Mshowa
.83333 .33333 m
.83333 .33958 L
s
[(3)] .83333 .32083 0 1 Mshowa
1 .33333 m
1 .33958 L
s
[(4)] 1 .32083 0 1 Mshowa
.125 Mabswid
.03333 .33333 m
.03333 .33708 L
s
.06667 .33333 m
.06667 .33708 L
s
.1 .33333 m
.1 .33708 L
s
.13333 .33333 m
.13333 .33708 L
s
.2 .33333 m
.2 .33708 L
s
.23333 .33333 m
.23333 .33708 L
s
.26667 .33333 m
.26667 .33708 L
s
.3 .33333 m
.3 .33708 L
s
.36667 .33333 m
.36667 .33708 L
s
.4 .33333 m
.4 .33708 L
s
.43333 .33333 m
.43333 .33708 L
s
.46667 .33333 m
.46667 .33708 L
s
.53333 .33333 m
.53333 .33708 L
s
.56667 .33333 m
.56667 .33708 L
s
.6 .33333 m
.6 .33708 L
s
.63333 .33333 m
.63333 .33708 L
s
.7 .33333 m
.7 .33708 L
s
.73333 .33333 m
.73333 .33708 L
s
.76667 .33333 m
.76667 .33708 L
s
.8 .33333 m
.8 .33708 L
s
.86667 .33333 m
.86667 .33708 L
s
.9 .33333 m
.9 .33708 L
s
.93333 .33333 m
.93333 .33708 L
s
.96667 .33333 m
.96667 .33708 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.33333 0 m
.33958 0 L
s
[(-2)] .32083 0 1 0 Mshowa
.33333 .16667 m
.33958 .16667 L
s
[(-1)] .32083 .16667 1 0 Mshowa
.33333 .5 m
.33958 .5 L
s
[(1)] .32083 .5 1 0 Mshowa
.33333 .66667 m
.33958 .66667 L
s
[(2)] .32083 .66667 1 0 Mshowa
.33333 .83333 m
.33958 .83333 L
s
[(3)] .32083 .83333 1 0 Mshowa
.33333 1 m
.33958 1 L
s
[(4)] .32083 1 1 0 Mshowa
.125 Mabswid
.33333 .03333 m
.33708 .03333 L
s
.33333 .06667 m
.33708 .06667 L
s
.33333 .1 m
.33708 .1 L
s
.33333 .13333 m
.33708 .13333 L
s
.33333 .2 m
.33708 .2 L
s
.33333 .23333 m
.33708 .23333 L
s
.33333 .26667 m
.33708 .26667 L
s
.33333 .3 m
.33708 .3 L
s
.33333 .36667 m
.33708 .36667 L
s
.33333 .4 m
.33708 .4 L
s
.33333 .43333 m
.33708 .43333 L
s
.33333 .46667 m
.33708 .46667 L
s
.33333 .53333 m
.33708 .53333 L
s
.33333 .56667 m
.33708 .56667 L
s
.33333 .6 m
.33708 .6 L
s
.33333 .63333 m
.33708 .63333 L
s
.33333 .7 m
.33708 .7 L
s
.33333 .73333 m
.33708 .73333 L
s
.33333 .76667 m
.33708 .76667 L
s
.33333 .8 m
.33708 .8 L
s
.33333 .86667 m
.33708 .86667 L
s
.33333 .9 m
.33708 .9 L
s
.33333 .93333 m
.33708 .93333 L
s
.33333 .96667 m
.33708 .96667 L
s
.25 Mabswid
.33333 0 m
.33333 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.03 w
.5 .5 Mdot
0 1 0 r
.5 Mabswid
.0288 .8191 m
.08009 .75957 L
.13033 .70423 L
.17316 .66022 L
.21119 .62431 L
.24912 .5922 L
.28389 .56662 L
.31977 .54458 L
.35404 .52789 L
.38741 .51572 L
.40501 .51085 L
.42409 .50669 L
.43279 .50516 L
.44228 .50374 L
.45131 .50261 L
.45981 .50175 L
.46973 .50097 L
.47505 .50065 L
.48077 .50038 L
.48341 .50028 L
.48629 .50019 L
.48883 .50013 L
.49154 .50007 L
.49399 .50004 L
.49539 .50002 L
.4967 .50001 L
.49791 .5 L
.49901 .5 L
.50029 .5 L
.5015 .5 L
.5027 .50001 L
.504 .50002 L
.50523 .50003 L
.50635 .50004 L
.50899 .50008 L
.51177 .50014 L
.51707 .50028 L
.52293 .5005 L
.53354 .50105 L
.54363 .50175 L
.56774 .50401 L
.59077 .50689 L
.64444 .5158 L
.70227 .52801 L
.77177 .5452 L
.84787 .56619 L
.931 .59089 L
s
.931 .59089 m
1 .61253 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[86]:=",
  ImageSize->{209, 209},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003A0000dB000`400?l00000o`00003odOooool0
0=7ooooo000oooooo`Go0000SOooool0043ooooo00Co0000oooooooooooo0000SOooool003Wooooo
1Ol00003ooooo`03o`000?oooooooooo08gooooo0012ooooo`03o`000?oooooooooo00?ooooo0_l0
0027ooooo`00?oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Q_oo
ool003oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08Kooooo0010
ooooo`?o00001Oooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26oooo
o`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?oo
ool2o`0008Oooooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oooooooooo
08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo
0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`;o0000Qoooool004Sooooo00?o0000oooo
ooooool0Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o0000ooooooooool0
Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool0
04Sooooo00?o0000ooooooooool0Q_ooool004Sooooo0_l00027ooooo`00B?ooool00ol0003ooooo
ooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26
ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00
B?ooool00ol0003oooooooooo`26ooooo`00B?ooool2o`0008Oooooo0018ooooo`03o`000?oooooo
oooo08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oooooooooo08Ko
oooo0010ooooo`?o00001Oooool00ol0003oooooooooo`26ooooo`00@Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo08Kooooo000iooooo`Go00000oooool00ol0003oooooooooo`04
ooooo`;o0000Qoooool0047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`26oooo
o`00@Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Kooooo0010ooooo`;o0000
1_ooool00ol0003oooooooooo`26ooooo`00@Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oooooooooo
08Kooooo0018ooooo`;o0000Qoooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o
0000ooooooooool0Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o0000oooo
ooooool0Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo0_l00027ooooo`00B?oo
ool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0
003oooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003ooooo
ooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool2o`0008Oooooo0018oooo
o`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo0006ooooo`Go0000
7Oooool3o`0001gooooo00?o0000ooooooooool07?ooool3o`0001gooooo1Ol0000Mooooo`?o0000
8?ooool3o`0000;ooooo0007ooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo
00007?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool00Oooool000Go
00000oooool00ol0003oooooooooo`0Fooooo`Go00000oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01_ooooo1Ol00002ooooo`002Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01gooooo0_l0000Nooooo`04o`000?ooooooooooo`0000?ooooo0006ooooo`05o`00
0?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Looooo`;o00007_ooool00ol0003o
ooooooooo`0Looooo`05o`000?ooooooooooooooool000008?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooo000000?ooooo0006ooooo`05o`000?ooooooooooooooool000007Oooool2o`00
01kooooo00?o0000ooooooooool07?ooool2o`0001kooooo00Go0000ooooooooooooooooo`00000L
ooooo`05o`000?ooooooooooooooool000007oooool2o`0000?ooooo0007ooooo`?o00007oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool3
o`0001kooooo0ol0000Qooooo`03o`000?oooooooooo007ooooo0018ooooo`03o`000?oooooooooo
08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo
0006ooooolSo00000oooool000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool000Kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool00Oooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o0000ooooooooool0
Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool0
04Sooooo0_l00027ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003ooooo
ooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26
ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00
B?ooool2o`0008Oooooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oooooo
oooo08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oooooooooo08Ko
oooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`;o0000Qoooool004Sooooo00?o0000
ooooooooool0Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o0000oooooooo
ool0Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o0000ooooooooool0Q_oo
ool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo0_l00027ooooo`00B?ooool00ol0003o
ooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003ooooooooo
o`26ooooo`00@?ooool3o`0000Gooooo00?o0000ooooooooool0Q_ooool0047ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Mooooo`?o0000I_ooool0047ooooo00?o0000oooooooo
ool01?ooool2o`0001gooooo0_l000000ol0o`3o0000o`00001Uooooo`00@Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo3?l0o`000ol0003o0?l0o`3o000>o`3o05Oooooo
0011ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool5o`3o00[ooooo1Ol0
000>ooooo`Go0?l0D_ooool0043ooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo0ol0o`0@
ooooo`?o00005?ooool5o`3o04gooooo0011ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool4o`3o02oooooo1_l0o`17ooooo`00B?ooool00ol0003oooooooooo`03ooooo`?o
0?l0>Oooool5o`3o04;ooooo0018ooooo`03o`000?oooooooooo00?o0?l0@Oooool5o`3o03gooooo
0018ooooo`?o0?l0BOooool5o`3o03Sooooo0016ooooo`;o0?l000?o0000ooooooooool0C_ooool5
o`3o03?ooooo0014ooooo`;o0?l00_ooool00ol0003oooooooooo`1Cooooo`Co0?l0;oooool004?o
oooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`1Gooooo`?o0?l0;?ooool0047ooooo
0_l0o`05ooooo`03o`000?oooooooooo05[ooooo0ol0o`0Yooooo`00@?ooool00ol0o`3ooooooooo
o`05ooooo`03o`000?oooooooooo05gooooo0ol0o`0Vooooo`00?oooool00ol0o`3oooooooooo`06
ooooo`03o`000?oooooooooo063ooooo0ol0o`0Sooooo`00?Oooool2o`3o00Wooooo0_l0001Toooo
o`?o0?l08?ooool003cooooo00?o0?l0ooooooooool02Oooool00ol0003oooooooooo`1Vooooo`?o
0?l07Oooool003[ooooo0_l0o`0<ooooo`03o`000?oooooooooo06Wooooo1?l0o`0Iooooo`00>Ooo
ool00ol0o`3oooooooooo`0<ooooo`03o`000?oooooooooo06gooooo0ol0o`0Fooooo`00>?ooool0
0ol0o`3oooooooooo`0=ooooo`03o`000?oooooooooo073ooooo0ol0o`0Cooooo`00=_ooool2o`3o
013ooooo00?o0000ooooooooool0Loooool4o`3o00oooooo000eooooo`03o`3o0?oooooooooo013o
oooo0_l0001hooooo`?o0?l03?ooool003Cooooo00?o0?l0ooooooooool04Oooool00ol0003ooooo
ooooo`1jooooo`Co0?l02?ooool003?ooooo00?o0?l0ooooooooool04_ooool00ol0003ooooooooo
o`1nooooo`?o0?l01Oooool003;ooooo00?o0?l0ooooooooool04oooool00ol0003oooooooooo`21
ooooo`;o0?l00oooool0037ooooo00?o0?l0ooooooooool05?ooool00ol0003oooooooooo`26oooo
o`00;oooool2o`3o01Oooooo00?o0000ooooooooool0Q_ooool002kooooo00?o0?l0ooooooooool0
5oooool00ol0003oooooooooo`26ooooo`00;Oooool00ol0o`3oooooooooo`0Hooooo`;o0000Qooo
ool002cooooo00?o0?l0ooooooooool06Oooool00ol0003oooooooooo`26ooooo`00:oooool00ol0
o`3oooooooooo`0Jooooo`03o`000?oooooooooo08Kooooo000Zooooo`03o`3o0?oooooooooo01_o
oooo00?o0000ooooooooool0Q_ooool002Wooooo00?o0?l0ooooooooool04oooool5o`0000Cooooo
00?o0000ooooooooool0Q_ooool002Sooooo00?o0?l0ooooooooool05Oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo08Kooooo000Wooooo`03o`3o0?oooooooooo01Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`26ooooo`009_ooool00ol0o`3oooooooooo`0I
ooooo`03o`000?oooooooooo00?ooooo0_l00027ooooo`009Oooool00ol0o`3oooooooooo`0Goooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`26ooooo`009?ooool00ol0
o`3oooooooooo`0Hooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`26
ooooo`008oooool00ol0o`3oooooooooo`0Jooooo`?o00001Oooool00ol0003oooooooooo`26oooo
o`008_ooool00ol0o`3oooooooooo`0Sooooo`03o`000?oooooooooo08Kooooo000Qooooo`03o`3o
0?oooooooooo02Cooooo00?o0000ooooooooool0Q_ooool0023ooooo00?o0?l0ooooooooool09Ooo
ool2o`0008Oooooo000Oooooo`03o`3o0?oooooooooo02Kooooo00?o0000ooooooooool0Q_ooool0
01oooooo00?o0?l0ooooooooool09_ooool00ol0003oooooooooo`26ooooo`007_ooool00ol0o`3o
ooooooooo`0Wooooo`03o`000?oooooooooo08Kooooo000Mooooo`03o`3o0?oooooooooo02Sooooo
00?o0000ooooooooool0Q_ooool001cooooo00?o0?l0ooooooooool0:Oooool00ol0003ooooooooo
o`26ooooo`006oooool00ol0o`3oooooooooo`0Zooooo`03o`000?oooooooooo08Kooooo000Joooo
o`03o`3o0?oooooooooo02_ooooo0_l00027ooooo`006Oooool00ol0o`3oooooooooo`0/ooooo`03
o`000?oooooooooo08Kooooo000Hooooo`03o`3o0?oooooooooo02gooooo00?o0000ooooooooool0
Q_ooool001Oooooo00?o0?l0ooooooooool0;_ooool00ol0003oooooooooo`26ooooo`005_ooool0
0ol0o`3oooooooooo`0_ooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`3o0?oooooooooo
033ooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0?l0ooooooooool0<?ooool00ol0003o
ooooooooo`26ooooo`005?ooool00ol0o`3oooooooooo`0aooooo`;o0000Qoooool001?ooooo00?o
0?l0ooooooooool0<_ooool00ol0003oooooooooo`26ooooo`004_ooool00ol0o`3oooooooooo`0c
ooooo`03o`000?oooooooooo08Kooooo000Aooooo`03o`3o0?oooooooooo03Cooooo00?o0000oooo
ooooool0Q_ooool0013ooooo00?o0?l0ooooooooool0=Oooool00ol0003oooooooooo`26ooooo`00
4?ooool00ol0o`3oooooooooo`0eooooo`03o`000?oooooooooo08Kooooo000?ooooo`03o`3o0?oo
oooooooo03Kooooo0_l00027ooooo`003_ooool00ol0o`3oooooooooo`0gooooo`03o`000?oooooo
oooo08Kooooo000=ooooo`03o`3o0?oooooooooo03Sooooo00?o0000ooooooooool0Q_ooool000co
oooo00?o0?l0ooooooooool0>Oooool00ol0003oooooooooo`26ooooo`002oooool00ol0o`3ooooo
ooooo`0booooo`?o00001Oooool00ol0003oooooooooo`26ooooo`00?oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0Q_ooool004?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`26ooooo`00@Oooool2o`0000Gooooo0_l00027ooooo`00@oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo000oooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`26ooooo`00@?ooool3o`0000Gooooo00?o0000oooooooo
ool0Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o0000ooooooooool0Q_oo
ool004Sooooo0_l00027ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003o
ooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003ooooooooo
o`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26oooo
o`00B?ooool2o`0008Oooooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oo
oooooooo08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oooooooooo
08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo0018ooooo`03o`000?oooooooooo08Kooooo
0018ooooo`;o0000Qoooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o0000oooo
ooooool0Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo00?o0000ooooooooool0
Q_ooool004Sooooo00?o0000ooooooooool0Q_ooool004Sooooo0_l00027ooooo`00B?ooool00ol0
003oooooooooo`26ooooo`00B?ooool00ol0003oooooooooo`26ooooo`00B?ooool00ol0003ooooo
ooooo`26ooooo`00@Oooool3o`0000Cooooo00?o0000ooooooooool0Q_ooool004;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`26ooooo`00?oooool5o`0000Cooooo00?o0000oooo
ooooool0Q_ooool003oooooo00Co0000oooooooooooo00001Oooool2o`0008Oooooo0010ooooo`03
o`000?oooooo000008kooooo0011ooooo`;o0000S_ooool004;ooooo00?o0000ooooooooool0S?oo
ool00=7ooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 285.875}, {424.125, 216.125}} -> {-4.52894, \
4.38068, 0.030151, 0.030151}}]
}, Open  ]],

Cell["Here is the solution vector, simplified.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Simplify[v];
%//MatrixForm\
\>", "Input",
  CellLabel->"In[90]:=",
  FormatType->InputForm],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/2\ \[ExponentialE]\^\(\(-\@3\)\ t\)\ \((1 - \@3 + \((1 + \
\@3)\)\ \[ExponentialE]\^\(2\ \@3\ t\))\)\)},
            {\(1\/2\ \[ExponentialE]\^\(\(-\@3\)\ t\)\ \((1 + \[ExponentialE]\
\^\(2\ \@3\ t\))\)\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Times[ 
          Rational[ 1, 2], 
          Power[ E, 
            Times[ -1, 
              Power[ 3, 
                Rational[ 1, 2]], t]], 
          Plus[ 1, 
            Times[ -1, 
              Power[ 3, 
                Rational[ 1, 2]]], 
            Times[ 
              Plus[ 1, 
                Power[ 3, 
                  Rational[ 1, 2]]], 
              Power[ E, 
                Times[ 2, 
                  Power[ 3, 
                    Rational[ 1, 2]], t]]]]], 
        Times[ 
          Rational[ 1, 2], 
          Power[ E, 
            Times[ -1, 
              Power[ 3, 
                Rational[ 1, 2]], t]], 
          Plus[ 1, 
            Power[ E, 
              Times[ 2, 
                Power[ 3, 
                  Rational[ 1, 2]], t]]]]}]]], "Output",
  CellLabel->"Out[91]//MatrixForm="]
}, Open  ]],

Cell["\<\
And here is a picture of the solution trajectory and two \
eigenvector trajectories, one blue, one red. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ ParametricPlot[ v1, {t,-5,1}, PlotStyle->RGBColor[0,0,1] ], 
      ParametricPlot[ v2, {t,-5,1}, PlotStyle->RGBColor[1,0,0] ],
      SolnTraj, PlotRange->{{-2,4},{-2,4}}, AspectRatio->1/1]\
\>", "Input",
  CellLabel->"In[93]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.333333 0.166667 0.333333 0.166667 [
[0 .32083 -6 -9 ]
[0 .32083 6 0 ]
[.16667 .32083 -6 -9 ]
[.16667 .32083 6 0 ]
[.5 .32083 -3 -9 ]
[.5 .32083 3 0 ]
[.66667 .32083 -3 -9 ]
[.66667 .32083 3 0 ]
[.83333 .32083 -3 -9 ]
[.83333 .32083 3 0 ]
[1 .32083 -3 -9 ]
[1 .32083 3 0 ]
[.32083 0 -12 -4.5 ]
[.32083 0 0 4.5 ]
[.32083 .16667 -12 -4.5 ]
[.32083 .16667 0 4.5 ]
[.32083 .5 -6 -4.5 ]
[.32083 .5 0 4.5 ]
[.32083 .66667 -6 -4.5 ]
[.32083 .66667 0 4.5 ]
[.32083 .83333 -6 -4.5 ]
[.32083 .83333 0 4.5 ]
[.32083 1 -6 -4.5 ]
[.32083 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .33333 m
0 .33958 L
s
[(-2)] 0 .32083 0 1 Mshowa
.16667 .33333 m
.16667 .33958 L
s
[(-1)] .16667 .32083 0 1 Mshowa
.5 .33333 m
.5 .33958 L
s
[(1)] .5 .32083 0 1 Mshowa
.66667 .33333 m
.66667 .33958 L
s
[(2)] .66667 .32083 0 1 Mshowa
.83333 .33333 m
.83333 .33958 L
s
[(3)] .83333 .32083 0 1 Mshowa
1 .33333 m
1 .33958 L
s
[(4)] 1 .32083 0 1 Mshowa
.125 Mabswid
.03333 .33333 m
.03333 .33708 L
s
.06667 .33333 m
.06667 .33708 L
s
.1 .33333 m
.1 .33708 L
s
.13333 .33333 m
.13333 .33708 L
s
.2 .33333 m
.2 .33708 L
s
.23333 .33333 m
.23333 .33708 L
s
.26667 .33333 m
.26667 .33708 L
s
.3 .33333 m
.3 .33708 L
s
.36667 .33333 m
.36667 .33708 L
s
.4 .33333 m
.4 .33708 L
s
.43333 .33333 m
.43333 .33708 L
s
.46667 .33333 m
.46667 .33708 L
s
.53333 .33333 m
.53333 .33708 L
s
.56667 .33333 m
.56667 .33708 L
s
.6 .33333 m
.6 .33708 L
s
.63333 .33333 m
.63333 .33708 L
s
.7 .33333 m
.7 .33708 L
s
.73333 .33333 m
.73333 .33708 L
s
.76667 .33333 m
.76667 .33708 L
s
.8 .33333 m
.8 .33708 L
s
.86667 .33333 m
.86667 .33708 L
s
.9 .33333 m
.9 .33708 L
s
.93333 .33333 m
.93333 .33708 L
s
.96667 .33333 m
.96667 .33708 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.33333 0 m
.33958 0 L
s
[(-2)] .32083 0 1 0 Mshowa
.33333 .16667 m
.33958 .16667 L
s
[(-1)] .32083 .16667 1 0 Mshowa
.33333 .5 m
.33958 .5 L
s
[(1)] .32083 .5 1 0 Mshowa
.33333 .66667 m
.33958 .66667 L
s
[(2)] .32083 .66667 1 0 Mshowa
.33333 .83333 m
.33958 .83333 L
s
[(3)] .32083 .83333 1 0 Mshowa
.33333 1 m
.33958 1 L
s
[(4)] .32083 1 1 0 Mshowa
.125 Mabswid
.33333 .03333 m
.33708 .03333 L
s
.33333 .06667 m
.33708 .06667 L
s
.33333 .1 m
.33708 .1 L
s
.33333 .13333 m
.33708 .13333 L
s
.33333 .2 m
.33708 .2 L
s
.33333 .23333 m
.33708 .23333 L
s
.33333 .26667 m
.33708 .26667 L
s
.33333 .3 m
.33708 .3 L
s
.33333 .36667 m
.33708 .36667 L
s
.33333 .4 m
.33708 .4 L
s
.33333 .43333 m
.33708 .43333 L
s
.33333 .46667 m
.33708 .46667 L
s
.33333 .53333 m
.33708 .53333 L
s
.33333 .56667 m
.33708 .56667 L
s
.33333 .6 m
.33708 .6 L
s
.33333 .63333 m
.33708 .63333 L
s
.33333 .7 m
.33708 .7 L
s
.33333 .73333 m
.33708 .73333 L
s
.33333 .76667 m
.33708 .76667 L
s
.33333 .8 m
.33708 .8 L
s
.33333 .86667 m
.33708 .86667 L
s
.33333 .9 m
.33708 .9 L
s
.33333 .93333 m
.33708 .93333 L
s
.33333 .96667 m
.33708 .96667 L
s
.25 Mabswid
.33333 0 m
.33333 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
0 .78868 m
.04417 .72833 L
.14466 .59106 L
.21348 .49705 L
.25593 .43907 L
.28251 .40276 L
.30084 .37772 L
.31175 .36282 L
s
1 0 0 r
.33341 .33336 m
.33345 .33338 L
.33352 .3334 L
.33363 .33344 L
.33378 .3335 L
.33402 .33359 L
.33439 .33372 L
.335 .33394 L
.33591 .33427 L
.33724 .33476 L
.33944 .33557 L
.34272 .33677 L
.34752 .33852 L
.35535 .34139 L
.36694 .34563 L
.38603 .35262 L
.41461 .36308 L
.45664 .37847 L
.52546 .40366 L
.62779 .44111 L
.79687 .503 L
s
.79687 .503 m
1 .57735 L
s
0 g
.03 w
.5 .5 Mdot
0 1 0 r
.5 Mabswid
.0288 .8191 m
.08009 .75957 L
.13033 .70423 L
.17316 .66022 L
.21119 .62431 L
.24912 .5922 L
.28389 .56662 L
.31977 .54458 L
.35404 .52789 L
.38741 .51572 L
.40501 .51085 L
.42409 .50669 L
.43279 .50516 L
.44228 .50374 L
.45131 .50261 L
.45981 .50175 L
.46973 .50097 L
.47505 .50065 L
.48077 .50038 L
.48341 .50028 L
.48629 .50019 L
.48883 .50013 L
.49154 .50007 L
.49399 .50004 L
.49539 .50002 L
.4967 .50001 L
.49791 .5 L
.49901 .5 L
.50029 .5 L
.5015 .5 L
.5027 .50001 L
.504 .50002 L
.50523 .50003 L
.50635 .50004 L
.50899 .50008 L
.51177 .50014 L
.51707 .50028 L
.52293 .5005 L
.53354 .50105 L
.54363 .50175 L
.56774 .50401 L
.59077 .50689 L
.64444 .5158 L
.70227 .52801 L
.77177 .5452 L
.84787 .56619 L
.931 .59089 L
s
.931 .59089 m
1 .61253 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{218, 218},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003J0000fR000`400?l00000o`00003of_ooool0
0=[ooooo0012ooooo`Go0000Toooool004?ooooo00Co0000oooooooooooo0000Toooool003cooooo
1Ol00003ooooo`03o`000?oooooooooo09?ooooo0015ooooo`03o`000?oooooooooo00?ooooo0_l0
002=ooooo`00@_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0S?oo
ool004;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08cooooo0013
ooooo`?o00001Oooool00ol0003oooooooooo`2<ooooo`00Boooool00ol0003oooooooooo`2<oooo
o`00Boooool00ol0003oooooooooo`2<ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00Booo
ool2o`0008gooooo001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo
08cooooo001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo08cooooo
001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo08cooooo001;oooo
o`;o0000SOooool004_ooooo00?o0000ooooooooool0S?ooool004_ooooo00?o0000ooooooooool0
S?ooool004_ooooo00?o0000ooooooooool0S?ooool004_ooooo00?o0000ooooooooool0S?ooool0
04_ooooo00?o0000ooooooooool0S?ooool004_ooooo00?o0000ooooooooool0S?ooool004_ooooo
0_l0002=ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00Boooool00ol0003oooooooooo`2<
ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00
Boooool00ol0003oooooooooo`2<ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00Boooool2
o`0008gooooo001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo08co
oooo001;ooooo`03o`000?oooooooooo08cooooo0013ooooo`?o00001Oooool00ol0003ooooooooo
o`2<ooooo`00A?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08cooooo000loooo
o`Go00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08cooooo0014ooooo`03
o`000?oooooooooo00Cooooo0_l0002=ooooo`00A?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo08cooooo0013ooooo`;o00001_ooool00ol0003oooooooooo`2<ooooo`00A?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo
08cooooo001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo08cooooo
001;ooooo`;o0000SOooool004_ooooo00?o0000ooooooooool0S?ooool004_ooooo00?o0000oooo
ooooool0S?ooool004_ooooo00?o0000ooooooooool0S?ooool004_ooooo00?o0000ooooooooool0
S?ooool004_ooooo00?o0000ooooooooool0S?ooool004_ooooo00?o0000ooooooooool0S?ooool0
04_ooooo0_l0002=ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00Boooool00ol0003ooooo
ooooo`2<ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00Boooool00ol0003oooooooooo`2<
ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00Boooool2o`0008gooooo001;ooooo`03o`00
0?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooo
oooo08cooooo0006ooooo`Go00007_ooool3o`0001oooooo00?o0000ooooooooool07_ooool3o`00
01kooooo1Ol0000Oooooo`?o00008Oooool3o`0000;ooooo0007ooooo`04o`000?ooooooooooo`00
01oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01kooooo00Co0000oooooooooooo00007_ooool01Ol0003ooooooooooooooooo0000027ooooo00?o
0000ooooooooool00Oooool000Go00000oooool00ol0003oooooooooo`0Gooooo`Go00000oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01cooooo1Ol00002ooooo`002Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo0_l0000Pooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool07oooool2o`0001oooooo00Co0000oooooooooooo00000oooool0
00Kooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000008_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000?ooooo0006ooooo`05o`000?oooooo
ooooooooool000007_ooool2o`00023ooooo00?o0000ooooooooool07_ooool2o`0001oooooo00Go
0000ooooooooooooooooo`00000Nooooo`05o`000?ooooooooooooooool000008?ooool2o`0000?o
oooo0007ooooo`?o00008?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool07_ooool3o`00023ooooo0ol0000Rooooo`03o`000?oooooooooo007ooooo
001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo08cooooo001;oooo
o`03o`000?oooooooooo08cooooo0006ooooodGo000000?oo`00o`000?l00000ROl00003ooooo`00
1_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`Coo`000oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo007ooooo0006ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?oo
ool01?l0003oooooooooooooool3ool001cooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00Oooool004_ooooo00?o
0000ooooooooool01?ooool3ool008Gooooo001;ooooo`03o`000?oooooooooo00Oooooo0ooo0022
ooooo`00Boooool00ol0003oooooooooo`0:ooooo`;oo`00P?ooool004Kooooo00?o003ooooooooo
ool00_ooool00ol0003oooooooooo`0<ooooo`;oo`00O_ooool004Kooooo00?o003oooooooooool0
0_ooool2o`0000oooooo0_oo001looooo`00AOooool00ol00?ooooooooooo`03ooooo`03o`000?oo
oooooooo013ooooo0ooo001iooooo`00AOooool00ol00?ooooooooooo`03ooooo`03o`000?oooooo
oooo01?ooooo0ooo001fooooo`00A?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
01Kooooo0ooo001cooooo`00A?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo01Wo
oooo0ooo001`ooooo`00@oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo01cooooo
0ooo001]ooooo`00@_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo01oooooo0ooo
001Zooooo`00@Oooool00ol00?ooooooooooo`07ooooo`;o00008oooool3ool006Oooooo0010oooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool09Oooool2ool006Gooooo0010ooooo`03
o`00oooooooooooo00Sooooo00?o0000ooooooooool09oooool3ool006;ooooo000oooooo`03o`00
oooooooooooo00Wooooo00?o0000ooooooooool0:_ooool3ool005oooooo000nooooo`03o`00oooo
oooooooo00[ooooo00?o0000ooooooooool0;Oooool2ool005gooooo000mooooo`03o`00oooooooo
oooo00_ooooo00?o0000ooooooooool0;oooool3ool005[ooooo000mooooo`03o`00oooooooooooo
00_ooooo00?o0000ooooooooool0<_ooool2ool005Sooooo000looooo`03o`00oooooooooooo00co
oooo0_l0000eooooo`?oo`00EOooool003_ooooo00?o003oooooooooool03Oooool00ol0003ooooo
ooooo`0gooooo`?oo`00D_ooool003_ooooo00?o003oooooooooool03Oooool00ol0003ooooooooo
o`0jooooo`;oo`00D?ooool003[ooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0l
ooooo`?oo`00COooool003Wooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0ooooo
o`?oo`00B_ooool003Sooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`12ooooo`;o
o`00B?ooool003Sooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`14ooooo`?oo`00
AOooool003Oooooo00?o003oooooooooool04Oooool2o`0004Sooooo0ooo0012ooooo`00=_ooool0
0ol00?ooooooooooo`0Booooo`03o`000?oooooooooo04[ooooo0ooo000oooooo`00=Oooool00ol0
0?ooooooooooo`0Cooooo`03o`000?oooooooooo04gooooo0_oo000mooooo`00=Oooool00ol00?oo
ooooooooo`0Cooooo`03o`000?oooooooooo04oooooo0ooo000jooooo`00=?ooool00ol00?oooooo
ooooo`0<ooooo`?o00001Oooool00ol0003oooooooooo`1Booooo`?oo`00=oooool003?ooooo00?o
003oooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo1?l0
000cooooo`;oo`00=Oooool003;ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01gooooo1_l0000dooooo`?oo`00<_ooool003;ooooo00?o003ooooo
ooooool03oooool00ol0003oooooooooo`04ooooo`;o00005ooooolGo`3o02gooooo0ooo000_oooo
o`00<Oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03_ooool8o`3o00Oooooo1_l0000:ooooo`Wo0?l09oooool2ool002gooooo000`ooooo`03o`00
oooooooooooo013ooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo1?l0o`0?ooooo`Ko0000
4oooool6o`3o02?ooooo0ooo000Zooooo`00<?ooool00ol00?ooooooooooo`0Aooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool3o`3o01Cooooo1?l0000Jooooo`Go0?l08Ooo
ool3ool002Oooooo000_ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool01?ooool3
o`3o03[ooooo1?l0o`0Pooooo`?oo`009?ooool002kooooo00?o003oooooooooool06_ooool00ol0
003oooooooooo`02ooooo`;o0?l0@Oooool4o`3o01oooooo0ooo000Qooooo`00;Oooool00ol00?oo
ooooooooo`0Kooooo`03o`000?oooooooooo00;o0?l0Aoooool4o`3o01kooooo0ooo000Nooooo`00
;Oooool00ol00?ooooooooooo`0Kooooo`?o0?l0COooool5o`3o01cooooo0ooo000Kooooo`00;?oo
ool00ol00?ooooooooooo`0Jooooo`;o0?l000?o0000ooooooooool0D_ooool5o`3o01[ooooo0ooo
000Hooooo`00:oooool00ol00?ooooooooooo`0Iooooo`;o0?l00_ooool00ol0003oooooooooo`1G
ooooo`Co0?l06Oooool2ool001Kooooo000[ooooo`03o`00oooooooooooo01Sooooo00?o0?l0oooo
ooooool00_ooool00ol0003oooooooooo`1Kooooo`?o0?l06?ooool3ool001?ooooo000Zooooo`03
o`00oooooooooooo01Oooooo0_l0o`05ooooo`03o`000?oooooooooo05kooooo0ol0o`0Hooooo`?o
o`004?ooool002Wooooo00?o003oooooooooool05oooool00ol0o`3oooooooooo`05ooooo`03o`00
0?oooooooooo067ooooo0ol0o`0Hooooo`?oo`003Oooool002Wooooo00?o003oooooooooool05_oo
ool00ol0o`3oooooooooo`06ooooo`03o`000?oooooooooo06Cooooo0ol0o`0Hooooo`?oo`002_oo
ool002Sooooo00?o003oooooooooool05Oooool2o`3o00Wooooo0_l0001Xooooo`Co0?l05oooool3
ool000Oooooo000Wooooo`03o`00oooooooooooo01Gooooo00?o0?l0ooooooooool02Oooool00ol0
003oooooooooo`1[ooooo`?o0?l05oooool3ool000Cooooo000Vooooo`03o`00oooooooooooo01Co
oooo0_l0o`0<ooooo`03o`000?oooooooooo06kooooo1?l0o`0Fooooo`03ool00?oooooooooo007o
oooo000Vooooo`03o`00oooooooooooo01;ooooo0_l0o`0>ooooo`03o`000?oooooooooo07;ooooo
0ol0o`0Gooooo`009Oooool00ol00?ooooooooooo`0Booooo`03o`3o0?oooooooooo00kooooo00?o
0000ooooooooool0MOooool3o`3o01Cooooo000Tooooo`03o`00oooooooooooo017ooooo0_l0o`0A
ooooo`03o`000?oooooooooo07Sooooo1?l0o`0@ooooo`009?ooool00ol00?ooooooooooo`0@oooo
o`03o`3o0?oooooooooo017ooooo00?o0000ooooooooool0O?ooool4o`3o00cooooo000Sooooo`03
o`00oooooooooooo013ooooo00?o0?l0ooooooooool04_ooool2o`00087ooooo0ol0o`09ooooo`00
8_ooool00ol00?ooooooooooo`0@ooooo`03o`3o0?oooooooooo01?ooooo00?o0000ooooooooool0
Poooool4o`3o00Gooooo000Qooooo`03o`00oooooooooooo013ooooo00?o0?l0ooooooooool05?oo
ool00ol0003oooooooooo`27ooooo`;o0?l00oooool0027ooooo00?o003oooooooooool03oooool0
0ol0o`3oooooooooo`0Eooooo`03o`000?oooooooooo08cooooo000Pooooo`03o`00oooooooooooo
00oooooo00?o0?l0ooooooooool05_ooool00ol0003oooooooooo`2<ooooo`007oooool00ol00?oo
ooooooooo`0?ooooo`03o`3o0?oooooooooo01Oooooo00?o0000ooooooooool0S?ooool001kooooo
00?o003oooooooooool03oooool00ol0o`3oooooooooo`0Hooooo`03o`000?oooooooooo08cooooo
000Nooooo`03o`00oooooooooooo00kooooo00?o0?l0ooooooooool06Oooool2o`0008gooooo000M
ooooo`03o`00oooooooooooo00kooooo00?o0?l0ooooooooool06_ooool00ol0003oooooooooo`2<
ooooo`007?ooool00ol00?ooooooooooo`0>ooooo`03o`3o0?oooooooooo01_ooooo00?o0000oooo
ooooool0S?ooool001_ooooo00?o003oooooooooool03_ooool00ol0o`3oooooooooo`0Looooo`03
o`000?oooooooooo08cooooo000Kooooo`03o`00oooooooooooo00gooooo00?o0?l0ooooooooool0
5?ooool5o`0000Cooooo00?o0000ooooooooool0S?ooool001[ooooo00?o003oooooooooool03Ooo
ool00ol0o`3oooooooooo`0Fooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
S?ooool001Wooooo00?o003oooooooooool03Oooool00ol0o`3oooooooooo`0Hooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0S?ooool001Sooooo00?o003oooooooooool03Oooool0
0ol0o`3oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo0_l0002=ooooo`006?ooool00ol0
0?ooooooooooo`0<ooooo`03o`3o0?oooooooooo01Sooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo08cooooo000Gooooo`03o`00oooooooooooo00cooooo00?o0?l0oooo
ooooool06Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0S?ooool0
01Kooooo00?o003oooooooooool03?ooool00ol0o`3oooooooooo`0Kooooo`?o00001Oooool00ol0
003oooooooooo`2<ooooo`005Oooool00ol00?ooooooooooo`0<ooooo`03o`3o0?oooooooooo02Co
oooo00?o0000ooooooooool0S?ooool001Gooooo00?o003oooooooooool02oooool00ol0o`3ooooo
ooooo`0Uooooo`03o`000?oooooooooo08cooooo000Dooooo`03o`00oooooooooooo00_ooooo00?o
0?l0ooooooooool09_ooool00ol0003oooooooooo`2<ooooo`004oooool00ol00?ooooooooooo`0;
ooooo`03o`3o0?oooooooooo02Oooooo0_l0002=ooooo`004_ooool00ol00?ooooooooooo`0<oooo
o`03o`3o0?oooooooooo02Oooooo00?o0000ooooooooool0S?ooool001;ooooo00?o003ooooooooo
ool02oooool00ol0o`3oooooooooo`0Xooooo`03o`000?oooooooooo08cooooo000Aooooo`03o`00
oooooooooooo00_ooooo00?o0?l0ooooooooool0:Oooool00ol0003oooooooooo`2<ooooo`004?oo
ool00ol00?ooooooooooo`0;ooooo`03o`3o0?oooooooooo02[ooooo00?o0000ooooooooool0S?oo
ool000oooooo00?o003oooooooooool02oooool00ol0o`3oooooooooo`0[ooooo`03o`000?oooooo
oooo08cooooo000?ooooo`03o`00oooooooooooo00[ooooo00?o0?l0ooooooooool0;?ooool00ol0
003oooooooooo`2<ooooo`003_ooool00ol00?ooooooooooo`0:ooooo`03o`3o0?oooooooooo02go
oooo0_l0002=ooooo`003Oooool00ol00?ooooooooooo`0:ooooo`03o`3o0?oooooooooo02kooooo
00?o0000ooooooooool0S?ooool000gooooo00?o003oooooooooool02Oooool00ol0o`3ooooooooo
o`0_ooooo`03o`000?oooooooooo08cooooo000<ooooo`03o`00oooooooooooo00Wooooo00?o0?l0
ooooooooool0<?ooool00ol0003oooooooooo`2<ooooo`002oooool00ol00?ooooooooooo`09oooo
o`03o`3o0?oooooooooo037ooooo00?o0000ooooooooool0S?ooool000[ooooo00?o003ooooooooo
ool02Oooool00ol0o`3oooooooooo`0booooo`03o`000?oooooooooo08cooooo000:ooooo`03o`00
oooooooooooo00Wooooo00?o0?l0ooooooooool0<_ooool2o`0008gooooo0009ooooo`03o`00oooo
oooooooo00Wooooo00?o0?l0ooooooooool0<oooool00ol0003oooooooooo`2<ooooo`002?ooool0
0ol00?ooooooooooo`09ooooo`03o`3o0?oooooooooo03Cooooo00?o0000ooooooooool0S?ooool0
00Sooooo00?o003oooooooooool02?ooool00ol0o`3oooooooooo`0eooooo`03o`000?oooooooooo
08cooooo0007ooooo`03o`00oooooooooooo00Sooooo00?o0?l0ooooooooool0=_ooool00ol0003o
ooooooooo`2<ooooo`001_ooool00ol00?ooooooooooo`08ooooo`03o`3o0?oooooooooo03Oooooo
00?o0000ooooooooool0S?ooool0013ooooo00?o0?l0ooooooooool0>?ooool00ol0003ooooooooo
o`2<ooooo`003oooool00ol0o`3oooooooooo`0iooooo`;o0000SOooool000kooooo00?o0?l0oooo
ooooool0>_ooool00ol0003oooooooooo`2<ooooo`003Oooool00ol0o`3oooooooooo`0kooooo`03
o`000?oooooooooo08cooooo000<ooooo`03o`3o0?oooooooooo03cooooo00?o0000ooooooooool0
S?ooool000_ooooo00?o0?l0ooooooooool0?Oooool00ol0003oooooooooo`2<ooooo`00@oooool3
o`0000Gooooo00?o0000ooooooooool0S?ooool004;ooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo08cooooo0016ooooo`03o`000?oooooooooo00;ooooo0_l0002=oooo
o`00A?ooool2o`0000Gooooo00?o0000ooooooooool0S?ooool004Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2<ooooo`00@_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0S?ooool004?ooooo0ol00005ooooo`03o`000?oooooooooo08cooooo001;
ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`;o
0000SOooool004_ooooo00?o0000ooooooooool0S?ooool004_ooooo00?o0000ooooooooool0S?oo
ool004_ooooo00?o0000ooooooooool0S?ooool004_ooooo00?o0000ooooooooool0S?ooool004_o
oooo00?o0000ooooooooool0S?ooool004_ooooo00?o0000ooooooooool0S?ooool004_ooooo0_l0
002=ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00Boooool00ol0003oooooooooo`2<oooo
o`00Boooool00ol0003oooooooooo`2<ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00Booo
ool00ol0003oooooooooo`2<ooooo`00Boooool00ol0003oooooooooo`2<ooooo`00Boooool2o`00
08gooooo001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo08cooooo
001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo08cooooo001;oooo
o`03o`000?oooooooooo08cooooo001;ooooo`03o`000?oooooooooo08cooooo001;ooooo`;o0000
SOooool004_ooooo00?o0000ooooooooool0S?ooool004_ooooo00?o0000ooooooooool0S?ooool0
04_ooooo00?o0000ooooooooool0S?ooool004Cooooo0ol00004ooooo`03o`000?oooooooooo08co
oooo0015ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0S?ooool004;ooooo1Ol0
0004ooooo`03o`000?oooooooooo08cooooo0012ooooo`04o`000?ooooooooooo`0000Gooooo0_l0
002=ooooo`00@oooool00ol0003oooooo`00002Dooooo`00A?ooool2o`0009Cooooo0015ooooo`03
o`000?oooooooooo09;ooooo003Jooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 294.875}, {327.375, 110.375}} -> {-4.41951, \
1.05409, 0.0288464, 0.0288464}}]
}, Open  ]],

Cell[TextData[StyleBox["The matrix exponential", "Subsubsection"]], "Text"],

Cell[TextData[{
  " The function called ",
  StyleBox["MatrixExp",
    FontWeight->"Bold"],
  ", when applied to square matrix A as "
}], "Text"],

Cell[TextData[StyleBox["MatrixExp[t*A]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "outputs the matrix X(t)",
  Cell[BoxData[
      \(TraditionalForm\`\(X(0)\)\^\(-1\)\)]],
  " that was found above using the eigenvector solutions. We compute it \
below, applied  the 2 x 2 matrix A defined above. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Mexp = MatrixExp[t*A];
Simplify[%]//MatrixForm\
\>", "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/6\ \[ExponentialE]\^\(\(-\@3\)\ t\)\ \((3 - \@3 + \((3 + \
\@3)\)\ \[ExponentialE]\^\(2\ \@3\ t\))\)\), \(\(\[ExponentialE]\^\(\(-\@3\)\ \
t\)\ \((\(-1\) + \[ExponentialE]\^\(2\ \@3\ t\))\)\)\/\@3\)},
            {\(\(\[ExponentialE]\^\(\(-\@3\)\ t\)\ \((\(-1\) + \
\[ExponentialE]\^\(2\ \@3\ t\))\)\)\/\(2\ \@3\)\), \(1\/6\ \
\[ExponentialE]\^\(\(-\@3\)\ t\)\ \((3 + \@3 - \((\(-3\) + \@3)\)\ \
\[ExponentialE]\^\(2\ \@3\ t\))\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[113]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "Compare the matrix Mexp to X(t)",
  Cell[BoxData[
      \(TraditionalForm\`\(X(0)\)\^\(-1\)\)]],
  ", simplified and in matrix form. "
}], "Text"],

Cell[CellGroupData[{

Cell["X.Inverse[X/.t->0]//Simplify//MatrixForm", "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/6\ \[ExponentialE]\^\(\(-\@3\)\ t\)\ \((3 - \@3 + \((3 + \
\@3)\)\ \[ExponentialE]\^\(2\ \@3\ t\))\)\), \(\(\[ExponentialE]\^\(\(-\@3\)\ \
t\)\ \((\(-1\) + \[ExponentialE]\^\(2\ \@3\ t\))\)\)\/\@3\)},
            {\(\(\[ExponentialE]\^\(\(-\@3\)\ t\)\ \((\(-1\) + \
\[ExponentialE]\^\(2\ \@3\ t\))\)\)\/\(2\ \@3\)\), \(1\/6\ \
\[ExponentialE]\^\(\(-\@3\)\ t\)\ \((3 + \@3 - \((\(-3\) + \@3)\)\ \
\[ExponentialE]\^\(2\ \@3\ t\))\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[105]//MatrixForm="]
}, Open  ]],

Cell[TextData[StyleBox["A 3 dimensional example, approximate solutions ", \
"Subsubsection"]], "Text"],

Cell["\<\
We will now compute three linearly independent eigenvector \
solutions to v' = A v for the 3 x 3 matrix A defined  several pages ago and \
redefined below. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
A = {{3,2,1},{0,-1,-1},{2,1,1}};
%//MatrixForm\
\>", "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"3", "2", "1"},
            {"0", \(-1\), \(-1\)},
            {"2", "1", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[107]//MatrixForm="]
}, Open  ]],

Cell["\<\
Because this is a small system, exact formulas can be obtained. \
However we will make our calculations in  floating point form. We do this for \
three reasons.   \
\>", "Text"],

Cell[TextData[StyleBox["1. Floating point calculations are easier to make, \
and are more relevant for real world applications.   \n2. It will give us \
some experience with error analysis.   \n3. If exact solution formulas are \
required, it is easier to get them directly from the matrix exponential or by \
 simply applying DSolve. ", "ItemizedText"]], "Text"],

Cell[TextData[StyleBox["Here, once more, are A's eigenvalues and \
eigenvectors, but in approximate decimal form. ", "ItemizedText"]], "Text"],

Cell[CellGroupData[{

Cell["\<\
lambda = N[Eigenvalues[A]]
EV = N[Eigenvectors[A]]\
\>", "Input",
  CellLabel->"In[108]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({3.414213562373095`, \(-1.`\), 0.5857864376269049`}\)], "Output",
  CellLabel->"Out[108]="],

Cell[BoxData[
    \({{1.3203772410170407`, \(-0.2265409196609865`\), 1.`}, {\(-1.`\), 2.`, 
        0.`}, {0.10819418755438781`, \(-0.6306019374818708`\), 
        1.`}}\)], "Output",
  CellLabel->"Out[109]="]
}, Open  ]],

Cell["The following Table constructs three eigenvector solutions.", "Text"],

Cell[CellGroupData[{

Cell["v = Table[ Exp[lambda[[k]]*t]*EV[[k]], {k,1,3}]", "Input",
  CellLabel->"In[110]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{1.3203772410170407`\ \[ExponentialE]\^\(3.414213562373095`\ t\), \
\(-0.2265409196609865`\)\ \[ExponentialE]\^\(3.414213562373095`\ t\), 
        1.`\ \[ExponentialE]\^\(3.414213562373095`\ t\)}, {\(-1.`\)\ \
\[ExponentialE]\^\(\(-1.`\)\ t\), 2.`\ \[ExponentialE]\^\(\(-1.`\)\ t\), 
        0.`\ \[ExponentialE]\^\(\(-1.`\)\ t\)}, {0.10819418755438781`\ \
\[ExponentialE]\^\(0.5857864376269049`\ t\), \(-0.6306019374818708`\)\ \
\[ExponentialE]\^\(0.5857864376269049`\ t\), 
        1.`\ \[ExponentialE]\^\(0.5857864376269049`\ t\)}}\)], "Output",
  CellLabel->"Out[110]="]
}, Open  ]],

Cell["\<\
The fundamental matrix with these vectors in its columns is called \
X.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
X = Transpose[v];
%//MatrixForm\
\>", "Input",
  CellLabel->"In[111]:=",
  FormatType->InputForm],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1.3203772410170407`\ \[ExponentialE]\^\(3.414213562373095`\ \
t\)\), \(\(-1.`\)\ \[ExponentialE]\^\(\(-1.`\)\ t\)\), \(0.10819418755438781`\
\ \[ExponentialE]\^\(0.5857864376269049`\ t\)\)},
            {\(\(-0.2265409196609865`\)\ \
\[ExponentialE]\^\(3.414213562373095`\ t\)\), \(2.`\ \
\[ExponentialE]\^\(\(-1.`\)\ t\)\), \(\(-0.6306019374818708`\)\ \
\[ExponentialE]\^\(0.5857864376269049`\ t\)\)},
            {\(1.`\ \[ExponentialE]\^\(3.414213562373095`\ t\)\), \(0.`\ \
\[ExponentialE]\^\(\(-1.`\)\ t\)\), \(1.`\ \
\[ExponentialE]\^\(0.5857864376269049`\ t\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[112]//MatrixForm="]
}, Open  ]],

Cell["\<\
And here is the solution to v' = Av satisfying v(0) = \
<2,4,1>.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
v = X.Inverse[X/.t->0].{2,4,1};
Simplify[%]//MatrixForm\
\>", "Input",
  CellLabel->"In[116]:=",
  FormatType->InputForm],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\[ExponentialE]\^\(\(-1.`\)\ t\)\ \((\(-1.7142857142857144`\) \
- 0.21366985918917486`\ \[ExponentialE]\^\(1.5857864376269049`\ t\) + 
                    3.9279555734748888`\ \
\[ExponentialE]\^\(4.414213562373095`\ t\))\)\)},
            {\(\[ExponentialE]\^\(\(-1.`\)\ t\)\ \((\(\(3.4285714285714284`\)\
\(\[InvisibleSpace]\)\) + 
                    1.245359203038886`\ \
\[ExponentialE]\^\(1.5857864376269049`\ t\) - 
                    0.6739306316103146`\ \
\[ExponentialE]\^\(4.414213562373095`\ t\))\)\)},
            {\(0.`\ \[ExponentialE]\^\(\(-1.`\)\ t\) - 
                1.9748737341529163`\ \[ExponentialE]\^\(0.5857864376269049`\ \
t\) + 2.9748737341529163`\ \[ExponentialE]\^\(3.414213562373095`\ t\)\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Times[ 
          Power[ E, 
            Times[ -1.0, t]], 
          Plus[ -1.7142857142857144, 
            Times[ -0.21366985918917486, 
              Power[ E, 
                Times[ 1.5857864376269049, t]]], 
            Times[ 3.9279555734748888, 
              Power[ E, 
                Times[ 4.4142135623730949, t]]]]], 
        Times[ 
          Power[ E, 
            Times[ -1.0, t]], 
          Plus[ 3.4285714285714284, 
            Times[ 1.245359203038886, 
              Power[ E, 
                Times[ 1.5857864376269049, t]]], 
            Times[ -0.67393063161031463, 
              Power[ E, 
                Times[ 4.4142135623730949, t]]]]], 
        Plus[ 
          Times[ 0.0, 
            Power[ E, 
              Times[ -1.0, t]]], 
          Times[ -1.9748737341529163, 
            Power[ E, 
              Times[ 0.58578643762690485, t]]], 
          Times[ 2.9748737341529163, 
            Power[ E, 
              Times[ 3.4142135623730949, t]]]]}]]], "Output",
  CellLabel->"Out[117]//MatrixForm="]
}, Open  ]],

Cell["The next entry checks the initial value.", "Text"],

Cell[CellGroupData[{

Cell["v/.t->0", "Input",
  CellLabel->"In[118]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({1.9999999999999998`, 4.`, 1.`}\)], "Output",
  CellLabel->"Out[118]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Error analysis over the interval t = ",
    FontSlant->"Italic"],
  "0",
  StyleBox[" to t = ",
    FontSlant->"Italic"],
  "8",
  " "
}], "Text"],

Cell["\<\
The vector function v does not satisfy the differential equation \
exactly. Let's see how large the  error is over the time interval from 0 to \
8. The error can be analyzed as follows. First calculate the \"error vector\" \
v' - A v. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
D[v,t] - A.v;
ErrorVector = Simplify[%];
%//MatrixForm\
\>", "Input",
  CellLabel->"In[128]:=",
  FormatType->InputForm],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(4.440892098500626`*^-16\ \[ExponentialE]\^\(\(-1.`\)\ t\) - 
                2.220446049250313`*^-16\ \
\[ExponentialE]\^\(0.5857864376269049`\ t\) + 
                0.`\ \[ExponentialE]\^\(3.414213562373095`\ t\)\)},
            {\(\(-4.440892098500626`*^-16\)\ \[ExponentialE]\^\(\(-1.`\)\ t\) \
+ 0.`\ \[ExponentialE]\^\(0.5857864376269049`\ t\) - 
                8.881784197001252`*^-16\ \
\[ExponentialE]\^\(3.414213562373095`\ t\)\)},
            {\(4.440892098500626`*^-16\ \[ExponentialE]\^\(\(-1.`\)\ t\) + 
                0.`\ \[ExponentialE]\^\(0.5857864376269049`\ t\) + 
                1.7763568394002505`*^-15\ \
\[ExponentialE]\^\(3.414213562373095`\ t\)\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Plus[ 
          Times[ 4.4408920985006262*^-16, 
            Power[ E, 
              Times[ -1.0, t]]], 
          Times[ -2.2204460492503131*^-16, 
            Power[ E, 
              Times[ 0.58578643762690485, t]]], 
          Times[ 0.0, 
            Power[ E, 
              Times[ 3.4142135623730949, t]]]], 
        Plus[ 
          Times[ -4.4408920985006262*^-16, 
            Power[ E, 
              Times[ -1.0, t]]], 
          Times[ 0.0, 
            Power[ E, 
              Times[ 0.58578643762690485, t]]], 
          Times[ -8.8817841970012523*^-16, 
            Power[ E, 
              Times[ 3.4142135623730949, t]]]], 
        Plus[ 
          Times[ 4.4408920985006262*^-16, 
            Power[ E, 
              Times[ -1.0, t]]], 
          Times[ 0.0, 
            Power[ E, 
              Times[ 0.58578643762690485, t]]], 
          Times[ 1.7763568394002505*^-15, 
            Power[ E, 
              Times[ 3.4142135623730949, t]]]]}]]], "Output",
  CellLabel->"Out[130]//MatrixForm="]
}, Open  ]],

Cell["\<\
Then define Error as a function whose value at t is the largest of \
the absolute errors in the three components of  ErrorVector. This requires \
the \"infinity\" norm. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Error = Norm[ErrorVector,\[Infinity]]", "Input",
  CellLabel->"In[131]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(Max[
      Abs[\(-4.440892098500626`*^-16\)\ \[ExponentialE]\^\(\(-1.`\)\ t\) + 
          0.`\ \[ExponentialE]\^\(0.5857864376269049`\ t\) - 
          8.881784197001252`*^-16\ \[ExponentialE]\^\(3.414213562373095`\ \
t\)], Abs[
        4.440892098500626`*^-16\ \[ExponentialE]\^\(\(-1.`\)\ t\) - 
          2.220446049250313`*^-16\ \[ExponentialE]\^\(0.5857864376269049`\ \
t\) + 0.`\ \[ExponentialE]\^\(3.414213562373095`\ t\)], 
      Abs[4.440892098500626`*^-16\ \[ExponentialE]\^\(\(-1.`\)\ t\) + 
          0.`\ \[ExponentialE]\^\(0.5857864376269049`\ t\) + 
          1.7763568394002505`*^-15\ \[ExponentialE]\^\(3.414213562373095`\ \
t\)]]\)], "Output",
  CellLabel->"Out[131]="]
}, Open  ]],

Cell["Now graph Error over the interval from 0 to 8.", "Text"],

Cell[CellGroupData[{

Cell["Plot[Error, {t,0,8}, PlotRange->{0,0.002}]", "Input",
  CellLabel->"In[164]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0 309.017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -42 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -36 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -42 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -30 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -42 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -36 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -42 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -30 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(6)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(8)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.00025)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.0005)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.00075)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.001)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.00125)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.0015)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.00175)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.002)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.03279 0 L
.04262 0 L
.05288 0 L
.06244 0 L
.0731 0 L
.0828 0 L
.094 0 L
.10458 0 L
.11428 0 L
.12455 0 L
.13333 0 L
.14299 0 L
.15313 0 L
.1624 0 L
.17311 0 L
.18328 0 L
.19287 0 L
.20309 0 L
.21273 0 L
.22147 0 L
.2315 0 L
.24072 0 L
.25085 0 L
.26154 0 L
.27102 0 L
.28118 0 L
.29077 0 L
.29951 0 L
.30943 0 L
.3186 0 L
.32866 0 L
.33936 0 L
.34873 0 L
.35883 0 L
.36837 0 L
.37711 0 L
.38691 0 L
.39603 0 L
.40604 0 L
.41673 0 L
.42698 0 L
.43808 0 L
.44856 0 L
.45823 0 L
.46792 0 L
.47699 0 L
.48694 0 L
.49763 0 L
.50776 0 L
Mistroke
.51881 0 L
.52924 0 L
.53891 0 L
.5495 0 L
.55947 0 L
.56842 0 L
.57809 0 L
.58762 1e-05 L
.59807 1e-05 L
.60898 1e-05 L
.61915 1e-05 L
.62963 2e-05 L
.63954 3e-05 L
.64844 3e-05 L
.65811 4e-05 L
.66753 6e-05 L
.67792 8e-05 L
.68877 .00011 L
.69894 .00014 L
.7088 .00019 L
.71916 .00025 L
.72801 .00032 L
.73768 .00043 L
.74798 .00057 L
.75733 .00075 L
.76812 .00102 L
.7783 .00137 L
.78804 .00181 L
.79835 .00244 L
.80715 .00313 L
.81681 .00414 L
.827 .00554 L
.8363 .00723 L
.84703 .00984 L
.85721 .01317 L
.86684 .01737 L
.87709 .0233 L
.88584 .02995 L
.8955 .03951 L
.90558 .05275 L
.91483 .06877 L
.92498 .09201 L
.93567 .12504 L
.9452 .16434 L
.95539 .22011 L
.96501 .29 L
.97375 .37266 L
.97619 .39967 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[164]:=",
  ImageSize->{247, 152.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003g0000V2000`400?l00000o`00003omoooool0
0?Oooooo003gooooo`00moooool00?Oooooo001Jooooo`Go0000;_ooool3o`0002gooooo0ol0000_
ooooo`?o00001Oooool005_ooooo00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`0[
ooooo`05o`000?ooooooooooooooool00000;Oooool01Ol0003ooooooooooooooooo000000Cooooo
001Looooo`03o`000?oooooooooo02cooooo1Ol0000/ooooo`05o`000?ooooooooooooooool00000
;Oooool01Ol0003ooooooooooooooooo000000Cooooo001Mooooo`03o`000?oooooooooo02_ooooo
00Co0000oooooooooooo0000;Oooool4o`0002oooooo0ol00005ooooo`00F_ooool01Ol0003ooooo
oooooooooooo000002gooooo00?o0000ooooool00000;Oooool00ol0003oooooooooo`0_ooooo`05
o`000?ooooooooooooooool000001?ooool005[ooooo00Go0000ooooooooooooooooo`00000^oooo
o`;o0000;_ooool00ol0003oooooooooo`0^ooooo`05o`000?ooooooooooooooool000001?ooool0
05_ooooo0ol0000`ooooo`03o`000?oooooooooo02gooooo0_l0000_ooooo`?o00001Oooool00?Oo
oooo003gooooo`00moooool002Ooooood?l0000002cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooo`00000Xo`0000Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo013ooooo1?l0000Kooooo`03
o`000?oooooooooo00?ooooo000/ooooo`03o`000?oooooooooo0:Oooooo1?l0000Mooooo`00;?oo
ool2o`000:cooooo0_l0000Kooooo`00;?ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooo
oooo01Sooooo000/ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool05oooool002co
oooo0_l0002`ooooo`03o`000?oooooooooo01Kooooo000/ooooo`03o`000?oooooooooo0;3ooooo
00?o0000ooooooooool05Oooool002cooooo00?o0000ooooooooool0/Oooool00ol0003ooooooooo
o`0Dooooo`00;?ooool2o`000;?ooooo00?o0000ooooooooool04oooool002cooooo00?o0000oooo
ooooool0/oooool00ol0003oooooooooo`0Booooo`00;?ooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo01;ooooo000/ooooo`;o0000]Oooool00ol0003oooooooooo`0Aooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00000_oo
ool5o`0000;ooooo0ol00004ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool04Ooo
ool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00Go0000ooooooooooooooooo`00002gooooo`03o`000?oooooooooo013ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooooooool2o`000;Kooooo00?o0000ooooooooool04?ooool00005ooooool0003o
ooooooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000^?ooool00ol0003oooooooooo`0?ooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol00004ooooo`03o`000?oooooooooo
0;Kooooo00?o0000ooooooooool03oooool00005ooooool0003oooooooooool000002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0]oooool00ol0003o
ooooooooo`0>ooooo`000_ooool2o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo
0ol00002ooooo`Go00000oooool2o`000;Sooooo00?o0000ooooooooool03_ooool002cooooo00?o
0000ooooooooool0]oooool00ol0003oooooooooo`0>ooooo`00;?ooool00ol0003oooooooooo`2h
ooooo`03o`000?oooooooooo00gooooo000/ooooo`;o0000^Oooool00ol0003oooooooooo`0=oooo
o`00;?ooool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo00gooooo000/ooooo`03o`00
0?oooooooooo0;Wooooo00?o0000ooooooooool03?ooool002cooooo0_l0002jooooo`03o`000?oo
oooooooo00cooooo000/ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool03?ooool0
02cooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`0<ooooo`00;?ooool2o`000;_o
oooo00?o0000ooooooooool02oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0_l00004ooooo`;o00001?ooool2o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool02oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`05o`000?ooooooooooooooool00000_?ooool00ol0003oooooooooo`0;ooooo`001ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooooooo`;o0000^ooo
ool00ol0003oooooooooo`0;ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005oooo
o`05o`000?ooooooooooooooool00000_Oooool00ol0003oooooooooo`0:ooooo`001oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01Ol0003oooooooooool0003ooooo00Co00001?ooool00ol0003oooooooooo`2kooooo`03
o`000?oooooooooo00[ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
1oooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00[ooooo0008ooooo`;o00002_oo
ool2o`0000Cooooo0_l00004ooooo`;o00000_ooool5o`0000?ooooo0_l0002looooo`03o`000?oo
oooooooo00[ooooo000/ooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooooooool02_ooool0
02cooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`09ooooo`00;?ooool2o`000;go
oooo00?o0000ooooooooool02Oooool002cooooo00?o0000ooooooooool0_?ooool00ol0003ooooo
ooooo`09ooooo`00;?ooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo00Wooooo000/
ooooo`;o0000_Oooool00ol0003oooooooooo`09ooooo`00;?ooool00ol0003oooooooooo`2loooo
o`03o`000?oooooooooo00Wooooo000/ooooo`03o`000?oooooooooo0;gooooo00?o0000oooooooo
ool02?ooool002cooooo0_l0002nooooo`03o`000?oooooooooo00Sooooo0002ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool02?oo
ool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00002oooooo`03o`000?oooooooooo00Sooooo0000
1Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooooooool2o`000;kooooo00?o0000ooooooooool02?ooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool00000_oooool00ol0003oooooooooo`08ooooo`0000Goooooo`000?ooooooooooo`000008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooo000000?o00001?ooool00ol0003oooooooooo`2nooooo`03o`00
0?oooooooooo00Oooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool01ooo
ool000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`Go000000?ooooo
o`000?l000000ol00003ooooo`;o0000_oooool00ol0003oooooooooo`07ooooo`00;?ooool00ol0
003oooooooooo`2nooooo`03o`000?oooooooooo00Oooooo000/ooooo`03o`000?oooooooooo0;ko
oooo00?o0000ooooooooool01oooool002cooooo0_l0002oooooo`03o`000?oooooooooo00Oooooo
000/ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool01oooool002cooooo00?o0000
ooooooooool0_oooool00ol0003oooooooooo`06ooooo`00;?ooool2o`000<3ooooo00?o0000oooo
ooooool01_ooool002cooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`06ooooo`00
;?ooool00ol0003oooooooooo`2oooooo`03o`000?oooooooooo00Kooooo000/ooooo`;o0000`?oo
ool00ol0003oooooooooo`06ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000Cooooo0_l00003ooooo`?o00001?ooool00ol0003oooooooooo`2oooooo`03o`000?oooooo
oooo00Kooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
_oooool00ol0003oooooooooo`06ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03oooo
o`;o0000`?ooool00ol0003oooooooooo`06ooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool01Oooool000gooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00Go
oooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`;o00001Oooool2o`000<7ooooo00?o0000ooooooooool01Oooool0
00kooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`30ooooo`03o`000?oooooooooo00Gooooo000/ooooo`03o`000?oooooooooo0<3o
oooo00?o0000ooooooooool01Oooool002cooooo00?o0000ooooooooool0`?ooool00ol0003ooooo
ooooo`05ooooo`00;?ooool2o`000<7ooooo00?o0000ooooooooool01Oooool002cooooo00?o0000
ooooooooool0`?ooool00ol0003oooooooooo`05ooooo`00;?ooool00ol0003oooooooooo`30oooo
o`03o`000?oooooooooo00Gooooo000/ooooo`;o0000`_ooool00ol0003oooooooooo`04ooooo`00
;?ooool00ol0003oooooooooo`31ooooo`03o`000?oooooooooo00Cooooo000/ooooo`03o`000?oo
oooooooo0<7ooooo00?o0000ooooooooool01?ooool002cooooo0_l00032ooooo`03o`000?oooooo
oooo00Cooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`00
00?ooooo0ol00002ooooo`Go00000_ooool3o`0000Cooooo00?o0000ooooooooool0`Oooool00ol0
003oooooooooo`04ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo00000<?ooooo00?o0000oooo
ooooool01?ooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooooooo`;o0000`_ooool00ol0003oooooooooo`04ooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000034ooooo`03o`000?oooooooooo00?ooooo00001Ooooooo0000oooooooooooo
000000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooo`000003o`0000Cooooo00?o0000oooooooo
ool0`_ooool00ol0003oooooooooo`03ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000Oooooo0_l00033ooooo`03o`000?oooooooooo00?ooooo
0002ooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
0002ooooo`Go00000oooool00ol0003oooooooooo`38ooooo`00;?ooool00ol0003oooooooooo`38
ooooo`00;?ooool00ol0003oooooooooo`38ooooo`00;?ooool2o`000<Wooooo000/ooooo`03o`00
0?oooooooooo0<Sooooo000/ooooo`03o`000?oooooooooo0<Sooooo000/ooooo`;o0000bOooool0
02cooooo00?o0000ooooooooool0b?ooool002cooooo00?o0000ooooooooool0b?ooool002cooooo
0_l00039ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0
0003ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool0b?ooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000b_ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2o`000<Wo
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
003:ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooooooool4o`0000Cooooo00?o0000oooo
ooooool0b?ooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo0_l0
0039ooooo`002?ooool2o`0000[ooooo0_l00004ooooo`;o00001?ooool01?l0003ooooooooooooo
ool5o`0000?ooooo00?o0000ooooooooool0b?ooool002cooooo00?o0000ooooooooool0b?ooool0
02cooooo00?o0000ooooooooool0b?ooool002cooooo0_l00039ooooo`00;?ooool00ol0003ooooo
ooooo`38ooooo`00;?ooool00ol0003oooooooooo`38ooooo`00;?ooool2o`000<Wooooo000/oooo
o`03o`000?oooooooooo0<Sooooo000/ooooo`03o`000?oooooooooo0<Sooooo000/ooooo`;o0000
bOooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00000ooo
ool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0b?oo
ool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00003:ooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo0_l00039ooooo`00
00Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00003:ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000?o00001?ooool00ol0003oooooooooo`38ooooo`0000Goooooo`000?oooooo
ooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool2
o`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo0_l00039ooooo`000_oo
ool2o`0000[ooooo0_l00004ooooo`;o00001?ooool01?l0003oooooooooooooool5o`000003oooo
ool0003o000000?o00000oooool00ol0003oooooooooo`38ooooo`00;?ooool00ol0003ooooooooo
o`38ooooo`00;?ooool2o`000<Wooooo000/ooooo`03o`000?oooooooooo0<Sooooo000/ooooo`03
o`000?oooooooooo0<Sooooo000/ooooo`03o`000?oooooooooo0<Sooooo000/ooooo`;o0000bOoo
ool002cooooo00?o0000ooooooooool0b?ooool002cooooo00?o0000ooooooooool0b?ooool002co
oooo0_l00039ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo
0_l00002ooooo`Go00000oooool00ol0003oooooooooo`38ooooo`003Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo0<Sooooo000=ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00?ooooo0_l00039ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3=oooo
o`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo0<cooooo000=ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool0c?ooool000kooooo0_l0000:ooooo`;o00001?ooool2o`00
00?ooooo0ol0003?ooooo`00moooool00?Oooooo003gooooo`00moooool00001\
\>"],
  ImageRangeCache->{{{77.875, 323.875}, {562.25, 410.688}} -> {-4.98527, \
0.00619709, 0.040711, 1.56838*^-5}}]
}, Open  ]],

Cell[TextData[{
  "This looks very good. Although the error clearly grows exponentially, it \
less than 0.0015 at ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 8 (years, maybe?).  We say years because at ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 8 the approximate solution vector is over 3.6 x ",
  Cell[BoxData[
      \(TraditionalForm\`10\^12\)]],
  " units long. (The length calculation uses the Euclidean norm.) "
}], "Text"],

Cell[CellGroupData[{

Cell["Norm[v/.t->8]", "Input",
  CellLabel->"In[166]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(3.6210150099802925`*^12\)], "Output",
  CellLabel->"Out[166]="]
}, Open  ]],

Cell[TextData[{
  "Thus the maximum relative error over this interval could be as small as 4 \
parts in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(10\^16\)\(.\)\)\)]]
}], "Text"]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{659, 745},
WindowMargins->{{1, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingStartingPageNumber->101,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 201, 6, 66, "Text"],
Cell[1958, 59, 230, 5, 48, "Text"],
Cell[2191, 66, 288, 14, 59, "Text"],
Cell[2482, 82, 694, 26, 68, "Text"],
Cell[3179, 110, 524, 10, 116, "Text"],
Cell[3706, 122, 74, 0, 28, "Text"],
Cell[3783, 124, 129, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[3937, 133, 72, 4, 51, "Input"],
Cell[4012, 139, 67, 2, 27, "Output"],
Cell[4082, 143, 67, 2, 27, "Output"]
}, Open  ]],
Cell[4164, 148, 92, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[4281, 155, 44, 1, 31, "Input"],
Cell[4328, 158, 73, 2, 27, "Output"]
}, Open  ]],
Cell[4416, 163, 64, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[4505, 167, 70, 1, 31, "Input"],
Cell[4578, 170, 91, 2, 27, "Output"]
}, Open  ]],
Cell[4684, 175, 67, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[4776, 179, 54, 1, 31, "Input"],
Cell[4833, 182, 302, 9, 44, "Output"]
}, Open  ]],
Cell[5150, 194, 184, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[5359, 202, 54, 1, 31, "Input"],
Cell[5416, 205, 250, 8, 64, "Output"]
}, Open  ]],
Cell[5681, 216, 243, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[5949, 226, 44, 1, 31, "Input"],
Cell[5996, 229, 115, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6148, 236, 56, 1, 31, "Input"],
Cell[6207, 239, 546, 19, 64, "Output"]
}, Open  ]],
Cell[6768, 261, 239, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[7032, 271, 44, 1, 31, "Input"],
Cell[7079, 274, 115, 2, 27, "Output"]
}, Open  ]],
Cell[7209, 279, 89, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[7323, 286, 56, 1, 31, "Input"],
Cell[7382, 289, 546, 19, 64, "Output"]
}, Open  ]],
Cell[7943, 311, 64, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[8032, 315, 82, 1, 31, "Input"],
Cell[8117, 318, 116, 2, 45, "Output"]
}, Open  ]],
Cell[8248, 323, 64, 0, 28, "Text"],
Cell[8315, 325, 71, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[8411, 331, 70, 4, 51, "Input"],
Cell[8484, 337, 343, 9, 90, "Output"],
Cell[8830, 348, 66, 2, 45, "Output"]
}, Open  ]],
Cell[8911, 353, 101, 3, 28, "Text"],
Cell[9015, 358, 75, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[9115, 364, 82, 4, 51, "Input"],
Cell[9200, 370, 138, 3, 45, "Output"],
Cell[9341, 375, 92, 2, 27, "Output"]
}, Open  ]],
Cell[9448, 380, 146, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[9619, 387, 45, 1, 31, "Input"],
Cell[9667, 390, 92, 2, 27, "Output"]
}, Open  ]],
Cell[9774, 395, 149, 6, 28, "Text"],
Cell[9926, 403, 94, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[10045, 409, 71, 1, 31, "Input"],
Cell[10119, 412, 110, 2, 48, "Output"]
}, Open  ]],
Cell[10244, 417, 88, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[10357, 424, 84, 5, 51, "Input"],
Cell[10444, 431, 68, 2, 27, "Output"],
Cell[10515, 435, 98, 2, 38, "Output"]
}, Open  ]],
Cell[10628, 440, 224, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[10877, 448, 76, 2, 31, "Input"],
Cell[10956, 452, 83, 2, 38, "Output"]
}, Open  ]],
Cell[11054, 457, 181, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[11260, 465, 96, 5, 51, "Input"],
Cell[11359, 472, 68, 2, 27, "Output"],
Cell[11430, 476, 60, 2, 27, "Output"]
}, Open  ]],
Cell[11505, 481, 156, 1, 23, "Text"],
Cell[11664, 484, 134, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[11823, 491, 85, 2, 31, "Input"],
Cell[11911, 495, 68, 2, 45, "Output"]
}, Open  ]],
Cell[11994, 500, 258, 9, 48, "Text"],

Cell[CellGroupData[{
Cell[12277, 513, 106, 5, 51, "Input"],
Cell[12386, 520, 83, 2, 45, "Output"],
Cell[12472, 524, 76, 2, 45, "Output"]
}, Open  ]],
Cell[12563, 529, 187, 7, 28, "Text"],
Cell[12753, 538, 126, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[12904, 545, 97, 2, 31, "Input"],
Cell[13004, 549, 136, 3, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13177, 557, 87, 2, 31, "Input"],
Cell[13267, 561, 372, 10, 110, "Output"]
}, Open  ]],
Cell[13654, 574, 126, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[13805, 581, 86, 2, 31, "Input"],
Cell[13894, 585, 134, 3, 45, "Output"]
}, Open  ]],
Cell[14043, 591, 55, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[14123, 595, 88, 2, 31, "Input"],
Cell[14214, 599, 148, 3, 45, "Output"]
}, Open  ]],
Cell[14377, 605, 41, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[14443, 609, 99, 2, 31, "Input"],
Cell[14545, 613, 148, 3, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14730, 621, 80, 2, 31, "Input"],
Cell[14813, 625, 392, 10, 110, "Output"]
}, Open  ]],
Cell[15220, 638, 199, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[15444, 646, 134, 6, 71, "Input"],
Cell[15581, 654, 323, 9, 82, "Output"],
Cell[15907, 665, 123, 3, 45, "Output"]
}, Open  ]],
Cell[16045, 671, 83, 1, 28, "Text"],
Cell[16131, 674, 120, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[16276, 681, 96, 4, 51, "Input"],
Cell[16375, 687, 309, 9, 64, "Output"]
}, Open  ]],
Cell[16699, 699, 57, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[16781, 703, 75, 1, 31, "Input"],
Cell[16859, 706, 88, 2, 30, "Output"]
}, Open  ]],
Cell[16962, 711, 91, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[17078, 718, 56, 1, 31, "Input"],
Cell[17137, 721, 132, 3, 33, "Output"]
}, Open  ]],
Cell[17284, 727, 71, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[17380, 731, 100, 2, 31, "Input"],
Cell[17483, 735, 85, 2, 33, "Output"]
}, Open  ]],
Cell[17583, 740, 218, 6, 48, "Text"],
Cell[17804, 748, 146, 6, 28, "Text"],
Cell[17953, 756, 175, 5, 28, "Text"],
Cell[18131, 763, 139, 6, 28, "Text"],

Cell[CellGroupData[{
Cell[18295, 773, 153, 6, 71, "Input"],
Cell[18451, 781, 275, 6, 54, "Output"]
}, Open  ]],
Cell[18741, 790, 302, 7, 28, "Text"],

Cell[CellGroupData[{
Cell[19068, 801, 93, 5, 51, "Input"],
Cell[19164, 808, 178, 3, 27, "Output"],
Cell[19345, 813, 383, 7, 27, "Output"]
}, Open  ]],
Cell[19743, 823, 434, 14, 59, "Text"],

Cell[CellGroupData[{
Cell[20202, 841, 81, 2, 31, "Input"],
Cell[20286, 845, 85, 2, 33, "Output"]
}, Open  ]],
Cell[20386, 850, 401, 10, 48, "Text"],

Cell[CellGroupData[{
Cell[20812, 864, 82, 2, 31, "Input"],
Cell[20897, 868, 264, 5, 45, "Output"]
}, Open  ]],
Cell[21176, 876, 103, 1, 28, "Text"],
Cell[21282, 879, 62, 0, 28, "Text"],
Cell[21347, 881, 288, 14, 59, "Text"],
Cell[21638, 897, 155, 5, 28, "Text"],
Cell[21796, 904, 307, 13, 41, "Text"],
Cell[22106, 919, 65, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[22196, 923, 128, 6, 91, "Input"],
Cell[22327, 931, 268, 8, 44, "Output"],
Cell[22598, 941, 75, 2, 33, "Output"],
Cell[22676, 945, 88, 2, 33, "Output"]
}, Open  ]],
Cell[22779, 950, 150, 3, 28, "Text"],
Cell[22932, 955, 220, 8, 28, "Text"],
Cell[23155, 965, 155, 6, 28, "Text"],

Cell[CellGroupData[{
Cell[23335, 975, 136, 5, 51, "Input"],
Cell[23474, 982, 144, 3, 39, "Output"],
Cell[23621, 987, 134, 3, 39, "Output"]
}, Open  ]],
Cell[23770, 993, 103, 3, 28, "Text"],
Cell[23876, 998, 83, 2, 28, "Text"],
Cell[23962, 1002, 39, 0, 28, "Text"],
Cell[24004, 1004, 166, 6, 28, "Text"],
Cell[24173, 1012, 121, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[24319, 1019, 89, 2, 31, "Input"],
Cell[24411, 1023, 223, 4, 39, "Output"]
}, Open  ]],
Cell[24649, 1030, 249, 5, 28, "Text"],
Cell[24901, 1037, 96, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[25022, 1043, 268, 7, 71, "Input"],
Cell[25293, 1052, 16477, 477, 217, 4194, 320, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[41785, 1532, 56, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[41866, 1536, 101, 5, 51, "Input"],
Cell[41970, 1543, 1199, 38, 70, "Output"]
}, Open  ]],
Cell[43184, 1584, 128, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[43337, 1591, 269, 6, 131, "Input"],
Cell[43609, 1599, 20497, 558, 226, 4709, 358, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[64121, 2160, 75, 0, 28, "Text"],
Cell[64199, 2162, 145, 5, 28, "Text"],
Cell[64347, 2169, 121, 3, 28, "Text"],
Cell[64471, 2174, 245, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[64741, 2184, 97, 4, 51, "Input"],
Cell[64841, 2190, 669, 13, 112, "Output"]
}, Open  ]],
Cell[65525, 2206, 165, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[65715, 2215, 83, 1, 31, "Input"],
Cell[65801, 2218, 669, 13, 112, "Output"]
}, Open  ]],
Cell[66485, 2234, 102, 1, 28, "Text"],
Cell[66590, 2237, 180, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[66795, 2245, 97, 4, 51, "Input"],
Cell[66895, 2251, 310, 9, 64, "Output"]
}, Open  ]],
Cell[67220, 2263, 187, 4, 48, "Text"],
Cell[67410, 2269, 363, 4, 77, "Text"],
Cell[67776, 2275, 142, 1, 28, "Text"],

Cell[CellGroupData[{
Cell[67943, 2280, 126, 5, 51, "Input"],
Cell[68072, 2287, 111, 2, 27, "Output"],
Cell[68186, 2291, 209, 4, 27, "Output"]
}, Open  ]],
Cell[68410, 2298, 75, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[68510, 2302, 115, 2, 31, "Input"],
Cell[68628, 2306, 595, 9, 32, "Output"]
}, Open  ]],
Cell[69238, 2318, 95, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[69358, 2325, 107, 5, 51, "Input"],
Cell[69468, 2332, 803, 16, 76, "Output"]
}, Open  ]],
Cell[70286, 2351, 88, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[70399, 2358, 131, 5, 51, "Input"],
Cell[70533, 2365, 1920, 48, 80, "Output"]
}, Open  ]],
Cell[72468, 2416, 56, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[72549, 2420, 75, 2, 29, "Input"],
Cell[72627, 2424, 91, 2, 27, "Output"]
}, Open  ]],
Cell[72733, 2429, 174, 8, 28, "Text"],
Cell[72910, 2439, 259, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[73194, 2448, 130, 6, 71, "Input"],
Cell[73327, 2456, 1857, 47, 76, "Output"]
}, Open  ]],
Cell[75199, 2506, 193, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[75417, 2514, 105, 2, 31, "Input"],
Cell[75525, 2518, 708, 13, 78, "Output"]
}, Open  ]],
Cell[76248, 2534, 62, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[76335, 2538, 110, 2, 31, "Input"],
Cell[76448, 2542, 20198, 549, 161, 4779, 354, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[96661, 3094, 443, 12, 68, "Text"],

Cell[CellGroupData[{
Cell[97129, 3110, 81, 2, 31, "Input"],
Cell[97213, 3114, 83, 2, 30, "Output"]
}, Open  ]],
Cell[97311, 3119, 183, 5, 28, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

