(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    201821,       7106]*)
(*NotebookOutlinePosition[    203999,       7171]*)
(*  CellTagsIndexPosition[    203955,       7167]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Part IV. Linear Differential Equations", "Section"],
  "\n",
  StyleBox["Section 5. The Laplace Transform", "Subsection"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "In this section, examples show how to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to obtain Laplace transforms and their  inverses. The transform method \
for solving an ode and a linear system is illustrated. Applications to \
problems with discontinuous forcing functions are featured. See Ledder, \
Chapter 7."
}], "Text"],

Cell[TextData[StyleBox["Laplace Transforms and the Inverse Laplace \
Transform", "Subsubsection"]], "Text"],

Cell[TextData[{
  "We are interested in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions named ",
  StyleBox["LaplaceTransform",
    FontWeight->"Bold"],
  " and ",
  StyleBox["InverseLaplaceTransform",
    FontWeight->"Bold"],
  ". The syntax to generate the Laplace transform  of an expression f(t) as \
an expression F(s) is "
}], "Text"],

Cell[TextData[StyleBox["LaplaceTransform[ f(t),  t,  s  ]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
The inverse Laplace transform of F(s) to f(t) is accomplished \
with\
\>", "Text"],

Cell[TextData[{
  " ",
  StyleBox["InverseLaplaceTransform[  F(s),  s,  t ]",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  " Four textbook examples:   \n1. The Laplace transform of  ",
  StyleBox["t",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(e\^\(2  t\)\), " ", 
          RowBox[{"cos", "(", 
            RowBox[{"3", 
              StyleBox["t",
                FontSlant->"Italic"]}], 
            StyleBox[")",
              FontSlant->"Plain"]}]}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell["LaplaceTransform[t*Exp[2*t]*Cos[3*t],t,s]", "Input",
  CellLabel->"In[175]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\(\((\(-5\) + s)\)\ \((1 + s)\)\)\/\((13 + \((\(-4\) + s)\)\ \
s)\)\^2\)], "Output",
  CellLabel->"Out[175]="]
}, Open  ]],

Cell[TextData[{
  "2. The inverse Laplace transform of ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\^2 - 1\)\/\(s\^3 + 8\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["InverseLaplaceTransform[ (s^2-1)/(s^3+8),s,t]", "Input",
  CellLabel->"In[177]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(1\/12\ \((3\ \[ExponentialE]\^\(\(-2\)\ t\) + 
          9\ \[ExponentialE]\^t\ Cos[\@3\ t] - \@3\ \[ExponentialE]\^t\ \
Sin[\@3\ t])\)\)], "Output",
  CellLabel->"Out[177]="]
}, Open  ]],

Cell[TextData[{
  "3. Add this to your Laplace transform table: The transform of ",
  StyleBox["t",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(a\ t\)\ \(sin(k\ t)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["LaplaceTransform[ t*Exp[a*t]*Sin[k*t],t,s]", "Input",
  CellLabel->"In[181]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\(-\(\(2\ \@k\^2\ \((a - s)\)\ Sign[
              k]\)\/\((k\^2 + \((a - s)\)\^2)\)\^2\)\)\)], "Output",
  CellLabel->"Out[181]="]
}, Open  ]],

Cell[TextData[{
  "4. The transform of a discontinuous time function: cos(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") - ",
  Cell[BoxData[
      \(TraditionalForm\`t\  - \ UnitStep(t - 3)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell["LaplaceTransform[ Cos[t] - t - UnitStep[t-3],t,s]", "Input",
  CellLabel->"In[194]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\(-\(1\/s\^2\)\) - \[ExponentialE]\^\(\(-3\)\ s\)\/s + 
      s\/\(1 + s\^2\)\)], "Output",
  CellLabel->"Out[194]="]
}, Open  ]],

Cell["\<\
\"UnitStep\"? What is that all about.
Answer: The UnitStep function has its values defined as follows: \
\>", "Text"],

Cell["\<\
UnitStep[t] = 0 when t is negative
UnitStep[t] = 1 when t is positive.\
\>", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["See its graph below.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ UnitStep[t], {t,-2,2}, PlotRange->{-0.5,1.5},
      PlotStyle->Thickness[0.015], AspectRatio->2/4 ]\
\>", "Input",
  CellLabel->"In[191]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.125 0.25 [
[.02381 .1125 -6 -9 ]
[.02381 .1125 6 0 ]
[.2619 .1125 -6 -9 ]
[.2619 .1125 6 0 ]
[.7381 .1125 -3 -9 ]
[.7381 .1125 3 0 ]
[.97619 .1125 -3 -9 ]
[.97619 .1125 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .0625 -30 -4.5 ]
[.4875 .0625 0 4.5 ]
[.4875 .1875 -24 -4.5 ]
[.4875 .1875 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .3125 -24 -4.5 ]
[.4875 .3125 0 4.5 ]
[.4875 .375 -6 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .4375 -24 -4.5 ]
[.4875 .4375 0 4.5 ]
[.4875 .5 -18 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .125 m
.02381 .13125 L
s
[(-2)] .02381 .1125 0 1 Mshowa
.2619 .125 m
.2619 .13125 L
s
[(-1)] .2619 .1125 0 1 Mshowa
.7381 .125 m
.7381 .13125 L
s
[(1)] .7381 .1125 0 1 Mshowa
.97619 .125 m
.97619 .13125 L
s
[(2)] .97619 .1125 0 1 Mshowa
.125 Mabswid
.07143 .125 m
.07143 .12875 L
s
.11905 .125 m
.11905 .12875 L
s
.16667 .125 m
.16667 .12875 L
s
.21429 .125 m
.21429 .12875 L
s
.30952 .125 m
.30952 .12875 L
s
.35714 .125 m
.35714 .12875 L
s
.40476 .125 m
.40476 .12875 L
s
.45238 .125 m
.45238 .12875 L
s
.54762 .125 m
.54762 .12875 L
s
.59524 .125 m
.59524 .12875 L
s
.64286 .125 m
.64286 .12875 L
s
.69048 .125 m
.69048 .12875 L
s
.78571 .125 m
.78571 .12875 L
s
.83333 .125 m
.83333 .12875 L
s
.88095 .125 m
.88095 .12875 L
s
.92857 .125 m
.92857 .12875 L
s
.25 Mabswid
0 .125 m
1 .125 L
s
.5 0 m
.50625 0 L
s
[(-0.5)] .4875 0 1 0 Mshowa
.5 .0625 m
.50625 .0625 L
s
[(-0.25)] .4875 .0625 1 0 Mshowa
.5 .1875 m
.50625 .1875 L
s
[(0.25)] .4875 .1875 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .3125 m
.50625 .3125 L
s
[(0.75)] .4875 .3125 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(1)] .4875 .375 1 0 Mshowa
.5 .4375 m
.50625 .4375 L
s
[(1.25)] .4875 .4375 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1.5)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .0125 m
.50375 .0125 L
s
.5 .025 m
.50375 .025 L
s
.5 .0375 m
.50375 .0375 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .0875 m
.50375 .0875 L
s
.5 .1 m
.50375 .1 L
s
.5 .1125 m
.50375 .1125 L
s
.5 .1375 m
.50375 .1375 L
s
.5 .15 m
.50375 .15 L
s
.5 .1625 m
.50375 .1625 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .2125 m
.50375 .2125 L
s
.5 .225 m
.50375 .225 L
s
.5 .2375 m
.50375 .2375 L
s
.5 .2625 m
.50375 .2625 L
s
.5 .275 m
.50375 .275 L
s
.5 .2875 m
.50375 .2875 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .3375 m
.50375 .3375 L
s
.5 .35 m
.50375 .35 L
s
.5 .3625 m
.50375 .3625 L
s
.5 .3875 m
.50375 .3875 L
s
.5 .4 m
.50375 .4 L
s
.5 .4125 m
.50375 .4125 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .4625 m
.50375 .4625 L
s
.5 .475 m
.50375 .475 L
s
.5 .4875 m
.50375 .4875 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.015 w
.02381 .125 m
.02499 .125 L
.02605 .125 L
.02729 .125 L
.02846 .125 L
.02954 .125 L
.03053 .125 L
.03163 .125 L
.03279 .125 L
.03395 .125 L
.0352 .125 L
.03638 .125 L
.03746 .125 L
.03873 .125 L
.03944 .125 L
.04011 .125 L
.04132 .125 L
.04262 .125 L
.04327 .125 L
.04396 .125 L
.04519 .125 L
.04588 .125 L
.04652 .125 L
.04722 .125 L
.04797 .125 L
.04862 .125 L
.04933 .125 L
.05061 .125 L
.05186 .125 L
.05302 .125 L
.05414 .125 L
.05519 .125 L
.05634 .125 L
.05759 .125 L
.05882 .125 L
.06012 .125 L
.06123 .125 L
.06244 .125 L
.06315 .125 L
.06381 .125 L
.06453 .125 L
.06529 .125 L
.06657 .125 L
.06729 .125 L
.06797 .125 L
.06924 .125 L
.0704 .125 L
.07103 .125 L
.07173 .125 L
.073 .125 L
Mistroke
.07376 .125 L
.07448 .125 L
.07513 .125 L
.07583 .125 L
.0766 .125 L
.0774 .125 L
.07809 .125 L
.07885 .125 L
.07956 .125 L
.0802 .125 L
.08095 .125 L
.08166 .125 L
.08291 .125 L
.08362 .125 L
.08427 .125 L
.08544 .125 L
.08669 .125 L
.08787 .125 L
.08896 .125 L
.09016 .125 L
.09148 .125 L
.09214 .125 L
.09285 .125 L
.09413 .125 L
.09483 .125 L
.09548 .125 L
.09619 .125 L
.09695 .125 L
.09821 .125 L
.09893 .125 L
.09961 .125 L
.10086 .125 L
.10201 .125 L
.10333 .125 L
.10458 .125 L
.10572 .125 L
.10694 .125 L
.1081 .125 L
.10916 .125 L
.11033 .125 L
.11162 .125 L
.11227 .125 L
.11297 .125 L
.11422 .125 L
.11491 .125 L
.11554 .125 L
.11624 .125 L
.11698 .125 L
.11822 .125 L
.11892 .125 L
Mistroke
.11958 .125 L
.12081 .125 L
.12194 .125 L
.12323 .125 L
.12446 .125 L
.12562 .125 L
.12668 .125 L
.12789 .125 L
.12903 .125 L
.13009 .125 L
.13107 .125 L
.13214 .125 L
.13327 .125 L
.13441 .125 L
.13564 .125 L
.1368 .125 L
.13785 .125 L
.13909 .125 L
.13979 .125 L
.14043 .125 L
.14162 .125 L
.14288 .125 L
.14402 .125 L
.14526 .125 L
.14656 .125 L
.14777 .125 L
.14891 .125 L
.14994 .125 L
.15113 .125 L
.15226 .125 L
.15348 .125 L
.15478 .125 L
.15589 .125 L
.15711 .125 L
.15842 .125 L
.15915 .125 L
.15982 .125 L
.16113 .125 L
.16236 .125 L
.16352 .125 L
.16456 .125 L
.16577 .125 L
.1669 .125 L
.16796 .125 L
.16893 .125 L
.16999 .125 L
.17111 .125 L
.17225 .125 L
.17347 .125 L
.17462 .125 L
Mistroke
.17566 .125 L
.17689 .125 L
.17758 .125 L
.17823 .125 L
.1794 .125 L
.18065 .125 L
.18185 .125 L
.18316 .125 L
.18441 .125 L
.18556 .125 L
.1867 .125 L
.18773 .125 L
.18893 .125 L
.19005 .125 L
.19128 .125 L
.19258 .125 L
.19369 .125 L
.19491 .125 L
.19623 .125 L
.19696 .125 L
.19763 .125 L
.19894 .125 L
.20017 .125 L
.20122 .125 L
.20238 .125 L
.20359 .125 L
.20472 .125 L
.20578 .125 L
.20675 .125 L
.20781 .125 L
.20894 .125 L
.21008 .125 L
.21129 .125 L
.21244 .125 L
.21349 .125 L
.21472 .125 L
.21541 .125 L
.21605 .125 L
.21723 .125 L
.21847 .125 L
.21968 .125 L
.221 .125 L
.22224 .125 L
.2234 .125 L
.22454 .125 L
.22558 .125 L
.22677 .125 L
.2279 .125 L
.22914 .125 L
.23044 .125 L
Mistroke
.23155 .125 L
.23277 .125 L
.23409 .125 L
.23482 .125 L
.2355 .125 L
.2368 .125 L
.23804 .125 L
.23909 .125 L
.24025 .125 L
.24146 .125 L
.2426 .125 L
.24365 .125 L
.24462 .125 L
.24569 .125 L
.24681 .125 L
.24795 .125 L
.24917 .125 L
.25032 .125 L
.25137 .125 L
.2526 .125 L
.25329 .125 L
.25393 .125 L
.2551 .125 L
.25635 .125 L
.25756 .125 L
.25888 .125 L
.26013 .125 L
.26129 .125 L
.26233 .125 L
.26348 .125 L
.26467 .125 L
.2658 .125 L
.26704 .125 L
.26835 .125 L
.26946 .125 L
.27068 .125 L
.272 .125 L
.27274 .125 L
.27341 .125 L
.27472 .125 L
.27595 .125 L
.27701 .125 L
.27817 .125 L
.27938 .125 L
.28052 .125 L
.28158 .125 L
.28255 .125 L
.28367 .125 L
.28474 .125 L
.28588 .125 L
Mistroke
.2871 .125 L
.28825 .125 L
.2893 .125 L
.29053 .125 L
.29122 .125 L
.29186 .125 L
.29303 .125 L
.29427 .125 L
.29549 .125 L
.29618 .125 L
.29682 .125 L
.29799 .125 L
.29923 .125 L
.30034 .125 L
.30138 .125 L
.30252 .125 L
.30375 .125 L
.30499 .125 L
.30569 .125 L
.30634 .125 L
.30765 .125 L
.30839 .125 L
.30906 .125 L
.31026 .125 L
.31156 .125 L
.31278 .125 L
.31392 .125 L
.31497 .125 L
.31611 .125 L
.31718 .125 L
.31816 .125 L
.3193 .125 L
.32055 .125 L
.32173 .125 L
.32282 .125 L
.32406 .125 L
.32522 .125 L
.32626 .125 L
.32739 .125 L
.32862 .125 L
.32992 .125 L
.33103 .125 L
.33225 .125 L
.33356 .125 L
.33477 .125 L
.33541 .125 L
.3361 .125 L
.33683 .125 L
.33751 .125 L
.33876 .125 L
Mistroke
.33991 .125 L
.34123 .125 L
.34249 .125 L
.3436 .125 L
.3448 .125 L
.34592 .125 L
.34694 .125 L
.34814 .125 L
.34945 .125 L
.35067 .125 L
.35181 .125 L
.35302 .125 L
.35431 .125 L
.35554 .125 L
.35665 .125 L
.35796 .125 L
.3587 .125 L
.35939 .125 L
.36064 .125 L
.36128 .125 L
.36198 .125 L
.36266 .125 L
.36337 .125 L
.36465 .125 L
.36536 .125 L
.36602 .125 L
.36675 .125 L
.36753 .125 L
.3682 .125 L
.36893 .125 L
.36962 .125 L
.37026 .125 L
.37146 .125 L
.37274 .125 L
.37394 .125 L
.37526 .125 L
.37651 .125 L
.37766 .125 L
.3788 .125 L
.37984 .125 L
.38103 .125 L
.38216 .125 L
.38339 .125 L
.3847 .125 L
.38581 .125 L
.38703 .125 L
.38834 .125 L
.38908 .125 L
.38975 .125 L
.39106 .125 L
Mistroke
.39229 .125 L
.39334 .125 L
.3945 .125 L
.39571 .125 L
.39685 .125 L
.39791 .125 L
.39888 .125 L
.39994 .125 L
.40106 .125 L
.40221 .125 L
.40342 .125 L
.40457 .125 L
.40562 .125 L
.40685 .125 L
.40754 .125 L
.40818 .125 L
.40936 .125 L
.4106 .125 L
.41181 .125 L
.41313 .125 L
.41438 .125 L
.41554 .125 L
.41669 .125 L
.41772 .125 L
.41892 .125 L
.42005 .125 L
.42129 .125 L
.42259 .125 L
.42371 .125 L
.42493 .125 L
.42624 .125 L
.42698 .125 L
.42765 .125 L
.42896 .125 L
.43019 .125 L
.43125 .125 L
.43241 .125 L
.43362 .125 L
.43476 .125 L
.43582 .125 L
.43679 .125 L
.43791 .125 L
.43898 .125 L
.44012 .125 L
.44134 .125 L
.44249 .125 L
.44354 .125 L
.44477 .125 L
.44546 .125 L
.4461 .125 L
Mistroke
.44727 .125 L
.44851 .125 L
.44973 .125 L
.45042 .125 L
.45106 .125 L
.45223 .125 L
.45347 .125 L
.45458 .125 L
.45562 .125 L
.45676 .125 L
.45799 .125 L
.45922 .125 L
.45992 .125 L
.46057 .125 L
.46188 .125 L
.46262 .125 L
.46329 .125 L
.46449 .125 L
.46579 .125 L
.46702 .125 L
.46815 .125 L
.4692 .125 L
.47034 .125 L
.47141 .125 L
.47239 .125 L
.47353 .125 L
.47478 .125 L
.47596 .125 L
.47705 .125 L
.47829 .125 L
.47945 .125 L
.48049 .125 L
.48162 .125 L
.48285 .125 L
.48415 .125 L
.48526 .125 L
.48648 .125 L
.48779 .125 L
.489 .125 L
.48963 .125 L
.49033 .125 L
.49105 .125 L
.49174 .125 L
.49299 .125 L
.49413 .125 L
.49539 .125 L
.49671 .125 L
.49783 .125 L
.49902 .125 L
.50014 .375 L
Mistroke
.50116 .375 L
.50603 .375 L
.52695 .375 L
.56698 .375 L
.6055 .375 L
.64646 .375 L
.68591 .375 L
.72385 .375 L
.76423 .375 L
.80311 .375 L
.84443 .375 L
.88424 .375 L
.92253 .375 L
.96328 .375 L
.97619 .375 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[191]:=",
  ImageSize->{253, 126.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003m0000OR000`400?l00000o`00003ooOooool0
0?gooooo001[ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000Q?ooool006[ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000008?ooooo001Sooooo`Go
00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l0001moooo
o`00J_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0O?ooool006[ooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000oooo
ooooool0O?ooool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06oooo
o`;o0000OOooool006_ooooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`1looooo`00
O_ooool00ol0003oooooooooo`1looooo`00O_ooool2o`0007gooooo001nooooo`03o`000?oooooo
oooo07cooooo001nooooo`03o`000?oooooooooo07cooooo001nooooo`;o0000OOooool007kooooo
00?o0000ooooooooool0O?ooool007kooooo00?o0000ooooooooool0O?ooool007kooooo0_l0001m
ooooo`00IOooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00001Oooool0
0ol0003oooooooooo`1looooo`00I?ooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07cooooo
001Mooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool2o`0007gooooo001Tooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07cooooo
001Tooooo`04o`000?ooooooooooo`0000Oooooo00Ko0000ooooooooooooooooo`000?ooool4o`00
00Gooooo00?o0000ooooooooool0O?ooool006Cooooo00Co0000oooooooooooo00001oooool01ol0
003ooooooooooooooooo0000ooooool000002?ooool2o`0007gooooo000?ooooo`Go0000<oooool3
o`0001_ooooo0_l00009ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0<_ooool3
o`0003Cooooo1Ol0000>ooooo`004?ooool01?l0003oooooooooool0000dooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`04o`000?oooooo
ooooo`0000kooooo0009ooooo`Go00000oooool00ol0003oooooooooo`0/ooooo`Go00000oooool0
0ol0003oooooooooo`0cooooo`;o0000=?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00kooooo000Booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool000oo
oooo00Go0000ooooooooooooooooo`00000dooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0cooooo`05o`000?ooooooooooooooool000003_ooool0
00oooooo00Go0000ooooooooooooooooo`00000cooooo`;o0000=Oooool2o`0003?ooooo0_l0000e
ooooo`05o`000?ooooooooooooooool000003_ooool0013ooooo0ol0000eooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`?o00003oooool0
07kooooo00?o0000ooooooooool0O?ooool007kooooo0_l0001mooooo`00O_ooool00ol0003ooooo
ooooo`1looooo`003_oooomao`0007kooooo0009ooooon[o00002_ooool000koooooLOl0000foooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool007cooooo0ol0001nooooo`00
O?ooool4o`0007gooooo001looooo`?o0000O_ooool007cooooo1?l0001mooooo`00O?ooool3o`00
07kooooo001looooo`?o0000O_ooool007cooooo1?l0001mooooo`00O?ooool3o`0007kooooo001l
ooooo`?o0000O_ooool007cooooo1?l0001mooooo`00IOooool2o`0000Cooooo00Co0000oooooooo
oooooooo1Ol00002ooooo`?o00000oooool3o`0007kooooo001Tooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00?o0000O_oo
ool006Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Co0000OOooool006Cooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?o0000O_ooool006Cooooo00Co0000oooooooooooo00001ooo
ool01_l0003ooooooooooooooooo0000ooooo`Co00000oooool3o`0007kooooo001Tooooo`04o`00
0?ooooooooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo1?l0001m
ooooo`00IOooool2o`0000Wooooo0ol00002ooooo`Go00000_ooool3o`0007kooooo001looooo`?o
0000O_ooool007cooooo1?l0001mooooo`00O?ooool3o`0007kooooo001looooo`?o0000O_ooool0
07cooooo1?l0001mooooo`00O?ooool3o`0007kooooo001looooo`?o0000O_ooool006_ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Co0000OOooool006[ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000;ooooo0ol0001nooooo`00J_oo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?o0000O_ooool006[ooooo00Co
0000oooooooooooo00002oooool00ol0003oooooooooo`04o`0007gooooo001Zooooo`04o`000?oo
ooooooooo`0000Oooooo1?l00003ooooo`Co0000OOooool006[ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`05ooooo`?o0000OOooool006_ooooo0_l00008ooooo`Go00000ooo
ool3o`0007gooooo001mooooo`?o0000OOooool007gooooo0ol0001mooooo`00OOooool3o`0007go
oooo001mooooo`?o0000OOooool007gooooo0ol0001mooooo`00OOooool3o`0007gooooo001moooo
o`?o0000OOooool007gooooo0ol0001mooooo`00IOooool2o`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`?o00001?ooool3o`0007gooooo001Tooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooooooo
o`?o0000OOooool006Cooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooooooo`?o0000OOooool006Cooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`?o0000OOooool006Cooooo00Co0000
oooooooooooo00002oooool00ol0003oooooo`000003o`0000Cooooo0ol0001mooooo`00I?ooool0
1?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000007ooooo`?o
0000OOooool006Gooooo0_l00008ooooo`Go000000?oooooo`000?l000000ol00003ooooo`?o0000
OOooool007gooooo0ol0001mooooo`00OOooool3o`0007gooooo001mooooo`?o0000OOooool007go
oooo0ol0001mooooo`00OOooool3o`0007gooooo001mooooo`?o0000OOooool007gooooo0ol0001m
ooooo`00M_ooool3o`0000Cooooo0ol0001mooooo`00Moooool00ol0003oooooooooo`03ooooo`?o
0000OOooool007Oooooo00?o0000ooooooooool00ooooombo`0000kooooo001gooooo`03o`000?oo
oooooooo00?oooooL_l0000>ooooo`00Moooool00ol0003oooooooooo`03ooooog;o00003_ooool0
07Kooooo0_l00006ooooo`03o`000?oooooooooo07cooooo001gooooo`03o`000?oooooooooo00Co
oooo0_l0001mooooo`00O_ooool00ol0003oooooooooo`1looooo`00O_ooool00ol0003ooooooooo
o`1looooo`00O_ooool2o`0007gooooo001nooooo`03o`000?oooooooooo07cooooo001nooooo`03
o`000?oooooooooo07cooooo001nooooo`;o0000OOooool007kooooo00?o0000ooooooooool0O?oo
ool007kooooo00?o0000ooooooooool0O?ooool006Cooooo0ol00004ooooo`04o`000?oooooooooo
ooooo`Go00000_ooool3o`0000Gooooo0_l0001mooooo`00IOooool00ol0003oooooooooo`08oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo07cooooo001Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`;o0000OOooool006Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0O?ooool006Go
oooo00?o0000ooooooooool01oooool01_l0003ooooooooooooooooo0000ooooo`Co00001Oooool0
0ol0003oooooooooo`1looooo`00I?ooool2o`0000Wooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000Sooooo0_l0001mooooo`00IOooool00ol0003oooooooooo`08ooooo`?o00000_ooool5
o`0000Cooooo00?o0000ooooooooool0O?ooool007kooooo00?o0000ooooooooool0O?ooool007ko
oooo0_l0001mooooo`00O_ooool00ol0003oooooooooo`1looooo`00O_ooool00ol0003ooooooooo
o`1looooo`00O_ooool2o`0007gooooo001nooooo`03o`000?oooooooooo07cooooo001nooooo`03
o`000?oooooooooo07cooooo001Zooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool2o`0007gooooo001[ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo07cooooo001[ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1looooo`00Joooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo0_l0001mooooo`00Joooool00ol0003oooooooooo`07oooo
o`Co0000Q?ooool006[ooooo0_l00009ooooo`03o`000?oooooooooo08Gooooo001[ooooo`03o`00
0?oooooooooo00Oooooo1Ol00023ooooo`00oOooool00001\
\>"],
  ImageRangeCache->{{{77.875, 329.875}, {393.188, 267.688}} -> {-3.67912, \
4.01828, 0.0180259, 0.0171676}}]
}, Open  ]],

Cell["\<\
Consequently, UnitStep[t-3] is zero for t < 3 and 1 for t > 3. The \
UnitStep function and functions defined using it (like the one whose Laplace \
transform was found in 4) are called \"piecewise continuous\". The time \
function in Example 4 has a jump discontinuity at t = 3. Its graph looks like \
this.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ Cos[t] + t - UnitStep[t-3], {t,-1,5}, PlotRange->{-1,3} \
]\
\>", "Input",
  CellLabel->"In[199]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.15873 0.154508 0.154508 [
[.02381 .14201 -6 -9 ]
[.02381 .14201 6 0 ]
[.34127 .14201 -3 -9 ]
[.34127 .14201 3 0 ]
[.5 .14201 -3 -9 ]
[.5 .14201 3 0 ]
[.65873 .14201 -3 -9 ]
[.65873 .14201 3 0 ]
[.81746 .14201 -3 -9 ]
[.81746 .14201 3 0 ]
[.97619 .14201 -3 -9 ]
[.97619 .14201 3 0 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -24 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .23176 -18 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .30902 -6 -4.5 ]
[.17004 .30902 0 4.5 ]
[.17004 .38627 -18 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -6 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -18 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .15451 m
.02381 .16076 L
s
[(-1)] .02381 .14201 0 1 Mshowa
.34127 .15451 m
.34127 .16076 L
s
[(1)] .34127 .14201 0 1 Mshowa
.5 .15451 m
.5 .16076 L
s
[(2)] .5 .14201 0 1 Mshowa
.65873 .15451 m
.65873 .16076 L
s
[(3)] .65873 .14201 0 1 Mshowa
.81746 .15451 m
.81746 .16076 L
s
[(4)] .81746 .14201 0 1 Mshowa
.97619 .15451 m
.97619 .16076 L
s
[(5)] .97619 .14201 0 1 Mshowa
.125 Mabswid
.05556 .15451 m
.05556 .15826 L
s
.0873 .15451 m
.0873 .15826 L
s
.11905 .15451 m
.11905 .15826 L
s
.15079 .15451 m
.15079 .15826 L
s
.21429 .15451 m
.21429 .15826 L
s
.24603 .15451 m
.24603 .15826 L
s
.27778 .15451 m
.27778 .15826 L
s
.30952 .15451 m
.30952 .15826 L
s
.37302 .15451 m
.37302 .15826 L
s
.40476 .15451 m
.40476 .15826 L
s
.43651 .15451 m
.43651 .15826 L
s
.46825 .15451 m
.46825 .15826 L
s
.53175 .15451 m
.53175 .15826 L
s
.56349 .15451 m
.56349 .15826 L
s
.59524 .15451 m
.59524 .15826 L
s
.62698 .15451 m
.62698 .15826 L
s
.69048 .15451 m
.69048 .15826 L
s
.72222 .15451 m
.72222 .15826 L
s
.75397 .15451 m
.75397 .15826 L
s
.78571 .15451 m
.78571 .15826 L
s
.84921 .15451 m
.84921 .15826 L
s
.88095 .15451 m
.88095 .15826 L
s
.9127 .15451 m
.9127 .15826 L
s
.94444 .15451 m
.94444 .15826 L
s
.25 Mabswid
0 .15451 m
1 .15451 L
s
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.5)] .17004 .07725 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(0.5)] .17004 .23176 1 0 Mshowa
.18254 .30902 m
.18879 .30902 L
s
[(1)] .17004 .30902 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(1.5)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(2)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(2.5)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(3)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08348 m
.06244 .14996 L
.10458 .21487 L
.14415 .26715 L
.18221 .30869 L
.22272 .3432 L
.26171 .36726 L
.28302 .37689 L
.30316 .38392 L
.32313 .38912 L
.34157 .39254 L
.35124 .39388 L
.36029 .39487 L
.37023 .39571 L
.37577 .39608 L
.38092 .39636 L
.38622 .3966 L
.39102 .39677 L
.39636 .39692 L
.39933 .39699 L
.40205 .39704 L
.40702 .39711 L
.40964 .39714 L
.4124 .39716 L
.4148 .39718 L
.41705 .39719 L
.41951 .3972 L
.42089 .3972 L
.42214 .3972 L
.42332 .39721 L
.42443 .39721 L
.42564 .39721 L
.42695 .39721 L
.42825 .39721 L
.4289 .39721 L
.42962 .39721 L
.43088 .39721 L
.43206 .39721 L
.43325 .39721 L
.43438 .39721 L
.43539 .39721 L
.43649 .39721 L
.43769 .39721 L
.43896 .39721 L
.44004 .39721 L
.44123 .39722 L
.44262 .39722 L
.44393 .39722 L
.4464 .39723 L
.44778 .39724 L
Mistroke
.44906 .39724 L
.45196 .39726 L
.45451 .39728 L
.45682 .39731 L
.46199 .39739 L
.46688 .39749 L
.47204 .39763 L
.48127 .39798 L
.48642 .39825 L
.49121 .39855 L
.50211 .39942 L
.51259 .40055 L
.5225 .40193 L
.54107 .4054 L
.56102 .41063 L
.57945 .41703 L
.59974 .42601 L
.61877 .43643 L
.6372 .44847 L
.64724 .45587 L
.65213 .45969 L
.65426 .4614 L
.65657 .46328 L
.65783 .46432 L
.65898 .31077 L
.66008 .3117 L
.66125 .31269 L
.66624 .31701 L
.67679 .32666 L
.69531 .34524 L
.73325 .38979 L
.77364 .44634 L
.81252 .50864 L
.85385 .58168 L
Mfstroke
.85385 .58168 m
.87316 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[199]:=",
  ImageSize->{188.938, 116.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002l0000M2000`400?l00000o`00003o_?ooool0
0;cooooo000Pooooo`?o0000VOooool0027ooooo00?o0000ooooooooool0V?ooool001Wooooo1Ol0
0003ooooo`03o`000?oooooooooo00Cooooo0_l0002Booooo`008Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo097ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0TOooool0023ooooo0_l00006ooooo`03o`000?oooooooooo097ooooo000Qooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0TOooool002Sooooo00?o0000ooooooooool0TOoo
ool002Sooooo00?o0000ooooooooool0TOooool002Sooooo00?o0000ooooooooool0TOooool002So
oooo00?o0000ooooooooool0TOooool002Sooooo00?o0000ooooooooool0TOooool002Sooooo00?o
0000ooooooooool0TOooool001Gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005
ooooo`03o`000?oooooooooo097ooooo000Dooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo097ooooo000=ooooo`Go00000_ooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0TOoo
ool001Cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o0000T_oo
ool000cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007ooooo`Co00001Ooo
ool00ol0003oooooooooo`2Aooooo`003?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Aooooo`003Oooool3
o`0000Gooooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`0Fooooo`?o00005oooool5
o`0001Sooooo0ol0000Iooooo`?o00006?ooool3o`0000[ooooo000>ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`04o`000?oooooooooo
o`0001Oooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo01Kooooo00Go
0000ooooooooooooooooo`000009ooooo`001_ooool5o`0000?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Dooooo`Go00006oooool00ol0003oooooooooo`07ooooo`003_ooool2
o`0001Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Sooooo0_l0000Gooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool01ooo
ool000kooooo00?o0000ooooool000005oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Kooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooool000006?ooool4o`0000[ooooo000=ooooo`;o000000?oooooo`000?ooool05_ooool0
0ol0003oooooooooo`0Fooooo`;o00006?ooool01Ol0003ooooooooooooooooo000001Oooooo00Go
0000ooooooooooooooooo`00000Hooooo`;o00006?ooool00ol0003oooooooooo`0;ooooo`003_oo
ool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool3o`0001Wooooo0ol0000Jooooo`03o`000?oooooooooo01Kooooo1Ol00009ooooo`004Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo097ooooo000Booooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0TOooool001?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`2Aooooo`002?oooon^o`0000Kooooo000<ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
000Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0TOooool001Gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`2Aooooo`005_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo097ooooo000Gooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0TOooool001Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Aooooo`006?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo097ooooo000Hooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0TOooool001Wooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`2Aooooo`006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo097o
oooo000Eooooo`;o00000oooool2o`0000Cooooo0ol00005ooooo`03o`000?oooooooooo097ooooo
000Dooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0TOooool001Cooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0002Booooo`00
5?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2Aooooo`005?ooool01?l0003oooooooooool00006ooooo`Go
00001Oooool00ol0003oooooooooo`2Aooooo`005?ooool01?l0003oooooooooool00006ooooo`;o
00002?ooool00ol0003oooooooooo`2Aooooo`005Oooool2o`0000Sooooo1Ol00004ooooo`03o`00
0?oooooooooo097ooooo000Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0TOoo
ool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Aooooo`008Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo097ooooo000Rooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0TOooool002?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`2Aooooo`009?ooool01Ol0003ooooooooooooooooo000009?ooooo000Pooooo`?o00000_oo
ool01?l0003oooooooooool0002Cooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo000009?ooooo000Qooooo`03o`000?oooooooooo00?ooooo0_l0002Cooooo`008Oooool00ol0
003oooooooooo`04ooooo`;o0000D?ooool00ol0003oooooooooo`0oooooo`008Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooo000004oooooo0_l00010ooooo`008?ooool2o`0000Kooooo
00Co0000oooooooooooo0000C_ooool00ol0003oooooo`00000oooooo`008Oooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000COooool01?l0003oooooooooool0000noooo
o`00:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04[ooooo00Go0000oooooooo
ooooooooo`00000mooooo`00:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0jooooo`00:?ooool00ol0003ooooo
ooooo`04ooooo`;o0000BOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo
000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Wooooo000Xooooo`03o`000?oooooooooo00Oooooo0_l00016
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool002Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0=oooool001Cooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo00[ooooo0ol00012ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0=_ooool001Gooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool03Oooool3o`0003oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0eooooo`005Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0=?ooool001Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`;o00004_ooool7o`0003Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0cooooo`005Oooool00ol0003oooooooooo`07ooooo`Co00001Oooool00ol0003oooooooooo`0H
ooooo`Go0000<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03;ooooo000Doooo
o`;o00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo6_l0000Hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<_ooool001Gooooo00?o0000oooooooo
ool01oooool5o`0000Cooooo00?o0000ooooooooool0=oooool7o`00017ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0aooooo`00:?ooool00ol0003oooooooooo`0nooooo`?o0000
3_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo033ooooo000Xooooo`03o`000?oo
oooooooo047ooooo0_l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;ooo
ool002Sooooo00?o0000ooooooooool0@oooool2o`0000[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0^ooooo`00:?ooool00ol0003oooooooooo`15ooooo`;o00002?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02kooooo000Xooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02go
oooo000Xooooo`03o`000?oooooooooo04Sooooo0_l00005ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0;?ooool002Sooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:oooool001oooooo1Ol00004
ooooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0:oooool0023ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool0:_ooool0027ooooo00?o0000oooo
ooooool01?ooool2o`0004oooooo0_l0000Dooooo`03o`000?oooooooooo02[ooooo000Rooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Yooooo`00
7oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`0Yooooo`007oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0I_ooool00ol0003oooooooooo`0Xooooo`008?ooool3o`0000Gooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0Wooooo`00:?ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo02Oooooo000Xooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool09_ooool0
02Sooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Vooooo`00:?ooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo02Gooooo000Xooooo`03o`000?oooooooooo06Wooooo
00?o0000ooooooooool09Oooool002Sooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`0Tooooo`004oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`0Tooooo`005?ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo02?ooooo000Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo02?ooooo000Fooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool2o`0006gooooo00?o0000ooooooooool08_ooool001?o
oooo00Go0000ooooooooooooooooo`000007ooooo`Co00001Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo027ooooo000Cooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08Oooool001Co
oooo0ol00008ooooo`Go00001?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo023o
oooo000Xooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08?ooool002Sooooo00?o
0000ooooooooool0Koooool00ol0003oooooooooo`0Oooooo`00:?ooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo01oooooo000Xooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool07_ooool002Sooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Nooooo`00
:?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01gooooo000Pooooo`?o00001Ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01cooooo000Oooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01cooooo000S
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0K
ooooo`008Oooool2o`0000Gooooo0_l0001eooooo`03o`000?oooooooooo01[ooooo000Sooooo`03
o`000?oooooooooo09Kooooo000Oooooo`05o`000?ooooooooooooooool00000V?ooool0023ooooo
0ol0002Iooooo`00_?ooool00001\
\>"],
  ImageRangeCache->{{{77.875, 265.812}, {594.375, 478.688}} -> {-4.30604, \
16.7787, 0.0364957, 0.0374929}}]
}, Open  ]],

Cell[TextData[{
  "Be on the lookout for UnitStep when inverting an s-domain function \
containing expressions of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(e\^\(\(-a\)\ s\)\), ",", " ", 
          RowBox[{
            StyleBox["a",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Plain"], 
            StyleBox[\(\(positive\)\(.\)\),
              FontSlant->"Plain"]}]}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
InverseLaplaceTransform[ s/(s^2+1) - 1/s^2 - Exp[-3*s]/s, s, \
t]\
\>", "Input",
  CellLabel->"In[202]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\(-t\) + Cos[t] - UnitStep[\(-3\) + t]\)], "Output",
  CellLabel->"Out[202]="]
}, Open  ]],

Cell["\<\
And, be prepared to use UnitStep to deal with piecewise continuous \
functions. It happens all the time in  engineering and science applications. \
\
\>", "Text"],

Cell[TextData[StyleBox["Typical driver: Off, then on, then off again ",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "Suppose, for example, that an undamped mass spring system is set into \
motion from equilibrium with velocity 3  meters per second, then driven with \
a sinusoid for the 10 second interval between ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 10 and ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 20. See the  graph below. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
f[t_] := 20*(UnitStep[t-10] - UnitStep[t-20])*Sin[Pi*t/4]
Plot[ f[t], {t,0,40}, PlotRange->{-22,22}, AspectRatio->1/6, 
      PlotStyle->Thickness[0.005]]\
\>", "Input",
  CellLabel->"In[45]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.0833333 0.00378788 [
[.2619 .07083 -6 -9 ]
[.2619 .07083 6 0 ]
[.5 .07083 -6 -9 ]
[.5 .07083 6 0 ]
[.7381 .07083 -6 -9 ]
[.7381 .07083 6 0 ]
[.97619 .07083 -6 -9 ]
[.97619 .07083 6 0 ]
[.01131 .00758 -18 -4.5 ]
[.01131 .00758 0 4.5 ]
[.01131 .04545 -18 -4.5 ]
[.01131 .04545 0 4.5 ]
[.01131 .12121 -12 -4.5 ]
[.01131 .12121 0 4.5 ]
[.01131 .15909 -12 -4.5 ]
[.01131 .15909 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .08333 m
.2619 .08958 L
s
[(10)] .2619 .07083 0 1 Mshowa
.5 .08333 m
.5 .08958 L
s
[(20)] .5 .07083 0 1 Mshowa
.7381 .08333 m
.7381 .08958 L
s
[(30)] .7381 .07083 0 1 Mshowa
.97619 .08333 m
.97619 .08958 L
s
[(40)] .97619 .07083 0 1 Mshowa
.125 Mabswid
.07143 .08333 m
.07143 .08708 L
s
.11905 .08333 m
.11905 .08708 L
s
.16667 .08333 m
.16667 .08708 L
s
.21429 .08333 m
.21429 .08708 L
s
.30952 .08333 m
.30952 .08708 L
s
.35714 .08333 m
.35714 .08708 L
s
.40476 .08333 m
.40476 .08708 L
s
.45238 .08333 m
.45238 .08708 L
s
.54762 .08333 m
.54762 .08708 L
s
.59524 .08333 m
.59524 .08708 L
s
.64286 .08333 m
.64286 .08708 L
s
.69048 .08333 m
.69048 .08708 L
s
.78571 .08333 m
.78571 .08708 L
s
.83333 .08333 m
.83333 .08708 L
s
.88095 .08333 m
.88095 .08708 L
s
.92857 .08333 m
.92857 .08708 L
s
.25 Mabswid
0 .08333 m
1 .08333 L
s
.02381 .00758 m
.03006 .00758 L
s
[(-20)] .01131 .00758 1 0 Mshowa
.02381 .04545 m
.03006 .04545 L
s
[(-10)] .01131 .04545 1 0 Mshowa
.02381 .12121 m
.03006 .12121 L
s
[(10)] .01131 .12121 1 0 Mshowa
.02381 .15909 m
.03006 .15909 L
s
[(20)] .01131 .15909 1 0 Mshowa
.125 Mabswid
.02381 .01515 m
.02756 .01515 L
s
.02381 .02273 m
.02756 .02273 L
s
.02381 .0303 m
.02756 .0303 L
s
.02381 .03788 m
.02756 .03788 L
s
.02381 .05303 m
.02756 .05303 L
s
.02381 .06061 m
.02756 .06061 L
s
.02381 .06818 m
.02756 .06818 L
s
.02381 .07576 m
.02756 .07576 L
s
.02381 .09091 m
.02756 .09091 L
s
.02381 .09848 m
.02756 .09848 L
s
.02381 .10606 m
.02756 .10606 L
s
.02381 .11364 m
.02756 .11364 L
s
.02381 .12879 m
.02756 .12879 L
s
.02381 .13636 m
.02756 .13636 L
s
.02381 .14394 m
.02756 .14394 L
s
.02381 .15152 m
.02756 .15152 L
s
.25 Mabswid
.02381 0 m
.02381 .16667 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
.005 w
.02381 .08333 m
.02499 .08333 L
.02605 .08333 L
.02729 .08333 L
.02846 .08333 L
.02954 .08333 L
.03053 .08333 L
.03163 .08333 L
.03279 .08333 L
.03395 .08333 L
.0352 .08333 L
.03638 .08333 L
.03746 .08333 L
.03873 .08333 L
.03944 .08333 L
.04011 .08333 L
.04132 .08333 L
.04262 .08333 L
.04327 .08333 L
.04396 .08333 L
.04519 .08333 L
.04588 .08333 L
.04652 .08333 L
.04722 .08333 L
.04797 .08333 L
.04862 .08333 L
.04933 .08333 L
.05061 .08333 L
.05186 .08333 L
.05302 .08333 L
.05414 .08333 L
.05519 .08333 L
.05634 .08333 L
.05759 .08333 L
.05882 .08333 L
.06012 .08333 L
.06123 .08333 L
.06244 .08333 L
.06315 .08333 L
.06381 .08333 L
.06453 .08333 L
.06529 .08333 L
.06657 .08333 L
.06729 .08333 L
.06797 .08333 L
.06924 .08333 L
.0704 .08333 L
.07103 .08333 L
.07173 .08333 L
.073 .08333 L
Mistroke
.07376 .08333 L
.07448 .08333 L
.07513 .08333 L
.07583 .08333 L
.0766 .08333 L
.0774 .08333 L
.07809 .08333 L
.07885 .08333 L
.07956 .08333 L
.0802 .08333 L
.08095 .08333 L
.08166 .08333 L
.08291 .08333 L
.08362 .08333 L
.08427 .08333 L
.08544 .08333 L
.08669 .08333 L
.08787 .08333 L
.08896 .08333 L
.09016 .08333 L
.09148 .08333 L
.09214 .08333 L
.09285 .08333 L
.09413 .08333 L
.09483 .08333 L
.09548 .08333 L
.09619 .08333 L
.09695 .08333 L
.09821 .08333 L
.09893 .08333 L
.09961 .08333 L
.10086 .08333 L
.10201 .08333 L
.10333 .08333 L
.10458 .08333 L
.10572 .08333 L
.10694 .08333 L
.1081 .08333 L
.10916 .08333 L
.11033 .08333 L
.11162 .08333 L
.11227 .08333 L
.11297 .08333 L
.11422 .08333 L
.11491 .08333 L
.11554 .08333 L
.11624 .08333 L
.11698 .08333 L
.11822 .08333 L
.11892 .08333 L
Mistroke
.11958 .08333 L
.12081 .08333 L
.12194 .08333 L
.12323 .08333 L
.12446 .08333 L
.12562 .08333 L
.12668 .08333 L
.12789 .08333 L
.12903 .08333 L
.13009 .08333 L
.13107 .08333 L
.13214 .08333 L
.13327 .08333 L
.13441 .08333 L
.13564 .08333 L
.1368 .08333 L
.13785 .08333 L
.13909 .08333 L
.13979 .08333 L
.14043 .08333 L
.14162 .08333 L
.14288 .08333 L
.14402 .08333 L
.14526 .08333 L
.14656 .08333 L
.14777 .08333 L
.14891 .08333 L
.14994 .08333 L
.15113 .08333 L
.15226 .08333 L
.15348 .08333 L
.15478 .08333 L
.15589 .08333 L
.15711 .08333 L
.15842 .08333 L
.15915 .08333 L
.15982 .08333 L
.16113 .08333 L
.16236 .08333 L
.16352 .08333 L
.16456 .08333 L
.16577 .08333 L
.1669 .08333 L
.16796 .08333 L
.16893 .08333 L
.16999 .08333 L
.17111 .08333 L
.17225 .08333 L
.17347 .08333 L
.17462 .08333 L
Mistroke
.17566 .08333 L
.17689 .08333 L
.17758 .08333 L
.17823 .08333 L
.1794 .08333 L
.18065 .08333 L
.18185 .08333 L
.18316 .08333 L
.18441 .08333 L
.18556 .08333 L
.1867 .08333 L
.18773 .08333 L
.18893 .08333 L
.19005 .08333 L
.19128 .08333 L
.19258 .08333 L
.19369 .08333 L
.19491 .08333 L
.19623 .08333 L
.19696 .08333 L
.19763 .08333 L
.19894 .08333 L
.20017 .08333 L
.20122 .08333 L
.20238 .08333 L
.20359 .08333 L
.20472 .08333 L
.20578 .08333 L
.20675 .08333 L
.20781 .08333 L
.20894 .08333 L
.21008 .08333 L
.21129 .08333 L
.21244 .08333 L
.21349 .08333 L
.21472 .08333 L
.21541 .08333 L
.21605 .08333 L
.21723 .08333 L
.21847 .08333 L
.21968 .08333 L
.221 .08333 L
.22224 .08333 L
.2234 .08333 L
.22454 .08333 L
.22558 .08333 L
.22677 .08333 L
.2279 .08333 L
.22914 .08333 L
.23044 .08333 L
Mistroke
.23155 .08333 L
.23277 .08333 L
.23409 .08333 L
.23482 .08333 L
.2355 .08333 L
.2368 .08333 L
.23804 .08333 L
.23909 .08333 L
.24025 .08333 L
.24146 .08333 L
.2426 .08333 L
.24365 .08333 L
.24462 .08333 L
.24569 .08333 L
.24681 .08333 L
.24795 .08333 L
.24917 .08333 L
.25032 .08333 L
.25137 .08333 L
.2526 .08333 L
.25329 .08333 L
.25393 .08333 L
.2551 .08333 L
.25635 .08333 L
.25756 .08333 L
.25888 .08333 L
.26013 .08333 L
.26129 .08333 L
.26233 .15908 L
.26348 .15899 L
.26467 .15877 L
.2658 .15847 L
.26704 .15801 L
.26835 .15739 L
.27068 .15594 L
.2732 .1539 L
.27595 .1511 L
.28053 .14523 L
.28544 .13739 L
.29427 .11986 L
.31415 .07181 L
.32463 .04714 L
.33036 .03527 L
.33573 .02571 L
.34089 .01821 L
.34561 .01299 L
.3483 .01078 L
.35085 .0092 L
.35225 .00856 L
.35355 .00811 L
Mistroke
.3543 .00791 L
.35497 .00777 L
.35576 .00765 L
.35649 .00759 L
.35761 .00758 L
.35883 .00769 L
.3601 .00794 L
.36129 .00828 L
.3624 .00871 L
.36342 .00919 L
.3657 .01058 L
.36815 .01252 L
.37082 .01515 L
.37566 .02128 L
.38507 .0375 L
.39544 .06041 L
.41645 .11183 L
.42588 .13194 L
.43102 .14105 L
.43581 .14805 L
.441 .15382 L
.44375 .15604 L
.44516 .15695 L
.44669 .15776 L
.44809 .15833 L
.44938 .15872 L
.45061 .15896 L
.45191 .15908 L
.45308 .15907 L
.45418 .15896 L
.45538 .15872 L
.45666 .15834 L
.458 .15779 L
.45921 .15718 L
.46192 .15537 L
.46444 .15318 L
.4668 .15068 L
.47211 .14361 L
.47784 .1339 L
.48744 .11384 L
.49251 .10185 L
.49531 .09502 L
.49795 .08846 L
.49921 .08531 L
.49984 .08373 L
.50054 .08333 L
.5013 .08333 L
.50201 .08333 L
.50266 .08333 L
.50336 .08333 L
Mistroke
.50468 .08333 L
.50593 .08333 L
.50706 .08333 L
.50829 .08333 L
.50956 .08333 L
.51071 .08333 L
.51135 .08333 L
.51204 .08333 L
.51329 .08333 L
.51446 .08333 L
.51571 .08333 L
.51677 .08333 L
.51793 .08333 L
.51861 .08333 L
.51934 .08333 L
.52004 .08333 L
.52068 .08333 L
.5219 .08333 L
.52319 .08333 L
.52385 .08333 L
.52457 .08333 L
.52587 .08333 L
.52662 .08333 L
.52741 .08333 L
.52809 .08333 L
.52883 .08333 L
.52952 .08333 L
.53016 .08333 L
.53138 .08333 L
.53268 .08333 L
.53342 .08333 L
.5341 .08333 L
.53524 .08333 L
.53649 .08333 L
.53779 .08333 L
.53901 .08333 L
.54026 .08333 L
.54096 .08333 L
.54159 .08333 L
.54282 .08333 L
.54398 .08333 L
.54464 .08333 L
.54534 .08333 L
.54659 .08333 L
.54728 .08333 L
.54793 .08333 L
.54864 .08333 L
.54941 .08333 L
.55068 .08333 L
.5514 .08333 L
Mistroke
.55206 .08333 L
.55328 .08333 L
.55457 .08333 L
.55573 .08333 L
.55681 .08333 L
.558 .08333 L
.55928 .08333 L
.56045 .08333 L
.56153 .08333 L
.56272 .08333 L
.56399 .08333 L
.56463 .08333 L
.56533 .08333 L
.56659 .08333 L
.56782 .08333 L
.56895 .08333 L
.57001 .08333 L
.571 .08333 L
.57209 .08333 L
.57326 .08333 L
.57448 .08333 L
.57564 .08333 L
.57668 .08333 L
.57781 .08333 L
.57846 .08333 L
.57915 .08333 L
.58038 .08333 L
.5817 .08333 L
.58245 .08333 L
.58315 .08333 L
.58442 .08333 L
.58557 .08333 L
.58621 .08333 L
.58691 .08333 L
.58817 .08333 L
.58929 .08333 L
.59053 .08333 L
.59183 .08333 L
.59304 .08333 L
.59417 .08333 L
.59521 .08333 L
.59641 .08333 L
.59754 .08333 L
.59886 .08333 L
.60006 .08333 L
.60073 .08333 L
.60144 .08333 L
.60275 .08333 L
.60397 .08333 L
.60526 .08333 L
Mistroke
.60637 .08333 L
.60758 .08333 L
.60831 .08333 L
.60901 .08333 L
.61031 .08333 L
.61104 .08333 L
.61172 .08333 L
.61246 .08333 L
.61325 .08333 L
.61454 .08333 L
.61576 .08333 L
.61646 .08333 L
.6171 .08333 L
.6178 .08333 L
.61854 .08333 L
.61977 .08333 L
.62047 .08333 L
.62111 .08333 L
.62229 .08333 L
.62353 .08333 L
.62465 .08333 L
.6257 .08333 L
.62685 .08333 L
.62808 .08333 L
.62939 .08333 L
.63012 .08333 L
.63081 .08333 L
.63207 .08333 L
.63277 .08333 L
.63341 .08333 L
.63461 .08333 L
.63591 .08333 L
.63714 .08333 L
.63827 .08333 L
.63934 .08333 L
.64048 .08333 L
.64156 .08333 L
.64254 .08333 L
.64369 .08333 L
.64494 .08333 L
.64612 .08333 L
.64721 .08333 L
.64833 .08333 L
.64939 .08333 L
.65054 .08333 L
.65178 .08333 L
.65302 .08333 L
.65432 .08333 L
.65543 .08333 L
.65664 .08333 L
Mistroke
.65728 .08333 L
.65796 .08333 L
.65918 .08333 L
.6605 .08333 L
.66124 .08333 L
.66194 .08333 L
.6632 .08333 L
.66435 .08333 L
.66499 .08333 L
.66568 .08333 L
.66694 .08333 L
.66806 .08333 L
.66929 .08333 L
.67058 .08333 L
.67179 .08333 L
.67292 .08333 L
.67395 .08333 L
.67509 .08333 L
.67628 .08333 L
.6776 .08333 L
.67879 .08333 L
.67945 .08333 L
.68017 .08333 L
.68147 .08333 L
.68268 .08333 L
.68398 .08333 L
.68508 .08333 L
.68629 .08333 L
.68702 .08333 L
.68772 .08333 L
.68902 .08333 L
.68974 .08333 L
.69042 .08333 L
.69116 .08333 L
.69195 .08333 L
.69264 .08333 L
.69338 .08333 L
.69408 .08333 L
.69473 .08333 L
.69595 .08333 L
.69725 .08333 L
.69847 .08333 L
.69916 .08333 L
.6998 .08333 L
.70097 .08333 L
.70221 .08333 L
.70332 .08333 L
.70436 .08333 L
.7055 .08333 L
.70673 .08333 L
Mistroke
.70797 .08333 L
.70867 .08333 L
.70932 .08333 L
.71063 .08333 L
.71137 .08333 L
.71204 .08333 L
.71324 .08333 L
.71454 .08333 L
.71577 .08333 L
.7169 .08333 L
.71795 .08333 L
.71909 .08333 L
.72016 .08333 L
.72114 .08333 L
.72229 .08333 L
.72353 .08333 L
.72471 .08333 L
.72581 .08333 L
.72704 .08333 L
.7282 .08333 L
.72925 .08333 L
.73037 .08333 L
.73161 .08333 L
.73291 .08333 L
.73402 .08333 L
.73523 .08333 L
.73655 .08333 L
.73776 .08333 L
.73839 .08333 L
.73909 .08333 L
.73981 .08333 L
.7405 .08333 L
.74175 .08333 L
.74289 .08333 L
.74422 .08333 L
.74547 .08333 L
.74659 .08333 L
.74778 .08333 L
.74891 .08333 L
.74993 .08333 L
.75113 .08333 L
.75243 .08333 L
.75366 .08333 L
.75479 .08333 L
.756 .08333 L
.7573 .08333 L
.75853 .08333 L
.75964 .08333 L
.76095 .08333 L
.76169 .08333 L
Mistroke
.76238 .08333 L
.76364 .08333 L
.76427 .08333 L
.76497 .08333 L
.76565 .08333 L
.76636 .08333 L
.76764 .08333 L
.76835 .08333 L
.76901 .08333 L
.76974 .08333 L
.77052 .08333 L
.77119 .08333 L
.77192 .08333 L
.77261 .08333 L
.77325 .08333 L
.77445 .08333 L
.77573 .08333 L
.77693 .08333 L
.77825 .08333 L
.7795 .08333 L
.78065 .08333 L
.7818 .08333 L
.78283 .08333 L
.78403 .08333 L
.78515 .08333 L
.78639 .08333 L
.78769 .08333 L
.7888 .08333 L
.79002 .08333 L
.79134 .08333 L
.79208 .08333 L
.79275 .08333 L
.79405 .08333 L
.79529 .08333 L
.79634 .08333 L
.7975 .08333 L
.79871 .08333 L
.79985 .08333 L
.80091 .08333 L
.80188 .08333 L
.80294 .08333 L
.80406 .08333 L
.8052 .08333 L
.80642 .08333 L
.80757 .08333 L
.80862 .08333 L
.80985 .08333 L
.81054 .08333 L
.81118 .08333 L
.81235 .08333 L
Mistroke
.8136 .08333 L
.81481 .08333 L
.81613 .08333 L
.81738 .08333 L
.81854 .08333 L
.81958 .08333 L
.82072 .08333 L
.82192 .08333 L
.82305 .08333 L
.82429 .08333 L
.82559 .08333 L
.82671 .08333 L
.82793 .08333 L
.82925 .08333 L
.82999 .08333 L
.83066 .08333 L
.83196 .08333 L
.8332 .08333 L
.83425 .08333 L
.83541 .08333 L
.83663 .08333 L
.83777 .08333 L
.83883 .08333 L
.8398 .08333 L
.84092 .08333 L
.84198 .08333 L
.84313 .08333 L
.84435 .08333 L
.8455 .08333 L
.84654 .08333 L
.84777 .08333 L
.84847 .08333 L
.84911 .08333 L
.85028 .08333 L
.85152 .08333 L
.85274 .08333 L
.85343 .08333 L
.85407 .08333 L
.85524 .08333 L
.85648 .08333 L
.85759 .08333 L
.85863 .08333 L
.85977 .08333 L
.861 .08333 L
.86223 .08333 L
.86293 .08333 L
.86358 .08333 L
.8649 .08333 L
.86563 .08333 L
.8663 .08333 L
Mistroke
.8675 .08333 L
.8688 .08333 L
.87003 .08333 L
.87116 .08333 L
.87222 .08333 L
.87335 .08333 L
.87442 .08333 L
.8754 .08333 L
.87655 .08333 L
.87779 .08333 L
.87897 .08333 L
.88007 .08333 L
.8813 .08333 L
.88246 .08333 L
.88351 .08333 L
.88463 .08333 L
.88587 .08333 L
.88717 .08333 L
.88828 .08333 L
.88949 .08333 L
.8908 .08333 L
.89201 .08333 L
.89265 .08333 L
.89334 .08333 L
.89407 .08333 L
.89475 .08333 L
.896 .08333 L
.89715 .08333 L
.89841 .08333 L
.89973 .08333 L
.90084 .08333 L
.90204 .08333 L
.90316 .08333 L
.90418 .08333 L
.90538 .08333 L
.90668 .08333 L
.90791 .08333 L
.90904 .08333 L
.91025 .08333 L
.91155 .08333 L
.91277 .08333 L
.91389 .08333 L
.9152 .08333 L
.91594 .08333 L
.91663 .08333 L
.91788 .08333 L
.91852 .08333 L
.91922 .08333 L
.91989 .08333 L
.92061 .08333 L
Mistroke
.92189 .08333 L
.9226 .08333 L
.92326 .08333 L
.92399 .08333 L
.92476 .08333 L
.92544 .08333 L
.92617 .08333 L
.92686 .08333 L
.92749 .08333 L
.9287 .08333 L
.92997 .08333 L
.93118 .08333 L
.9325 .08333 L
.93374 .08333 L
.93489 .08333 L
.93604 .08333 L
.93707 .08333 L
.93827 .08333 L
.9394 .08333 L
.94063 .08333 L
.94193 .08333 L
.94304 .08333 L
.94426 .08333 L
.94558 .08333 L
.94631 .08333 L
.94699 .08333 L
.94829 .08333 L
.94953 .08333 L
.95058 .08333 L
.95174 .08333 L
.95295 .08333 L
.95408 .08333 L
.95514 .08333 L
.95611 .08333 L
.95718 .08333 L
.9583 .08333 L
.95944 .08333 L
.96066 .08333 L
.96181 .08333 L
.96285 .08333 L
.96408 .08333 L
.96477 .08333 L
.96541 .08333 L
.96659 .08333 L
.96783 .08333 L
.96892 .08333 L
.96991 .08333 L
.97106 .08333 L
.97215 .08333 L
.97315 .08333 L
Mistroke
.97408 .08333 L
.9751 .08333 L
.97619 .08333 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{425.938, 70.9375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Y0000AR000`400?l00000o`00003ooooooonZ
ooooo`006oooool00ol0003oooooooooo`3oooooohcooooo000:ooooo`Go00000oooool2o`0000Oo
oooo00?o0000ooooooooool0oooooon<ooooo`002oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooon<ooooo`001?ooool5o`0000?o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`Co0000Ooooool6o`00
0?oooooo1_ooool000gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Ooooool9o`000?oooooo1?ooool000[ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0O_ooool4
o`0000;ooooo1Ol0003oooooo`?ooooo000:ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00006ooooo`?o0000OOooool3o`0000Oooooo0ol0003oooooo`;ooooo000;
ooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool0O?ooool3o`0000Wooooo0_l0003o
ooooo`;ooooo000Kooooo`03o`000?oooooooooo07cooooo0_l0000:ooooo`?o0000ooooool1oooo
o`006oooool3o`0007_ooooo0ol0000;ooooo`?o0000ooooool001_ooooo00?o0000ooooooooool0
N_ooool3o`0000gooooo0_l0003oooooo`006oooool00ol0003oooooooooo`1jooooo`;o00003_oo
ool3o`000?kooooo000Kooooo`?o0000NOooool3o`0000oooooo0_l0003nooooo`006oooool00ol0
003oooooooooo`1hooooo`?o00004?ooool3o`000?gooooo000Kooooo`03o`000?oooooooooo07Oo
oooo0ol0000Booooo`;o0000oOooool001_ooooo0ol0001gooooo`;o00004oooool3o`000?cooooo
000;ooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool0M_ooool3o`0001Cooooo0_l0
003looooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool0M_ooool2o`0001Gooooo0ol0003kooooo`001?ooool5o`0000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00006ooooo`Co0000MOooool2o`0001Kooooo0_l0
003kooooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool0MOooool3o`0001Kooooo0ol0003jooooo`003?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0F?ooool3o`0000Cooooo0_l0
000Dooooo`;o00006?ooool3o`0002Gooooo1Ol00003ooooo`;o0000E_ooool3o`0000Cooooo0_l0
001Hooooo`?o00000oooool2o`0000_ooooo000;ooooo`;o00001?ooool01?l0003oooooooooool0
0006ooooo`?o0000FOooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo
0ol0000Iooooo`;o00009_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
05Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0005Sooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oo
oooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Booooo`;o00006_ooool3o`0002Kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0001Hooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0Doooool5o`0000;ooooo00Co0000oooooooooooo00002_ooool001_ooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo0_l0000K
ooooo`;o00009oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0E?oo
ool2o`0000?ooooo00Co0000oooooooooooo0000EOooool01?l0003oooooooooool00003ooooo`04
o`000?ooooooooooo`0000[ooooo000Kooooo`?o0000FOooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`00017ooooo0ol0000Kooooo`?o00008oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo0000F?ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000:ooooo`00
6oooool00ol0003oooooooooo`1Hooooo`;o00001?ooool01?l0003oooooooooool0000Aooooo`;o
00007Oooool2o`0002?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0005Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0005Oooooo
0_l00003ooooo`04o`000?ooooooooooo`0000[ooooo000Kooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool00oooool2o`00017ooooo0ol0000Mooooo`?o00008oooool3o`0000Cooooo
0_l0001Fooooo`?o00001?ooool2o`0005Wooooo00?o0000ooooooooool00_ooool2o`0000_ooooo
000Kooooo`?o0000L_ooool2o`0001oooooo0_l0003fooooo`006oooool00ol0003oooooooooo`1b
ooooo`;o00007oooool2o`000?Kooooo000Kooooo`03o`000?oooooooooo077ooooo0ol0000Ooooo
o`?o0000mOooool001_ooooo0ol0001aooooo`;o00008Oooool2o`000?Gooooo000Kooooo`03o`00
0?oooooooooo073ooooo0ol0000Qooooo`;o0000mOooool001_ooooo00?o0000ooooooooool0L?oo
ool2o`0002;ooooo0ol0003dooooo`006oooool00ol0003oooooooooo`1`ooooo`;o00008oooool2
o`000?Cooooo000Boooooooo0000U?l00004ooooo`006_oooomRo`00017ooooo0_l0000Booooo`03
o`000?oooooooooo013ooooo0_l0000Booooo`03o`000?oooooooooo00kooooo`_l0000>ooooo`00
6oooool00ol0003oooooooooo`1Looooo`;o00004?ooool3o`0002Gooooo0_l0000Sooooo`?o0000
G_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00cooooo000Kooooo`?o0000G?oo
ool2o`00013ooooo0_l0000Vooooo`?o00008_ooool2o`000<kooooo000Kooooo`03o`000?oooooo
oooo05cooooo0_l0000?ooooo`?o00009oooool2o`00027ooooo0ol0003>ooooo`006oooool00ol0
003oooooooooo`1Looooo`;o00003oooool2o`0002Sooooo0ol0000Pooooo`;o0000coooool001_o
oooo0ol0001Looooo`;o00003oooool2o`0002Wooooo0_l0000Oooooo`?o0000coooool001_ooooo
00?o0000ooooooooool0G?ooool2o`0000kooooo0ol0000Yooooo`;o00007oooool2o`000=3ooooo
000Kooooo`03o`000?oooooooooo05cooooo0_l0000>ooooo`;o0000:_ooool3o`0001kooooo0_l0
003@ooooo`006oooool3o`0005cooooo0_l0000=ooooo`?o0000:oooool2o`0001gooooo0ol0003@
ooooo`006oooool00ol0003oooooooooo`1Looooo`;o00003Oooool2o`0002cooooo0_l0000Moooo
o`;o0000dOooool001_ooooo00?o0000ooooooooool0G?ooool2o`0000cooooo0ol0000/ooooo`?o
00007?ooool2o`000=7ooooo000;ooooo`?o00001?ooool2o`0000Oooooo0ol0001Looooo`;o0000
3?ooool2o`0002kooooo0_l0000Kooooo`?o0000dOooool000cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo05cooooo0_l0000<ooooo`;o0000
;_ooool3o`0001[ooooo0_l0003Booooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool0G?ooool2o`0000_ooooo0ol0000_ooooo`;o0000
6Oooool3o`000=;ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1_ooool4o`0005_ooooo0_l0000;ooooo`;o0000<?ooool3o`0001Sooooo0_l0003Cooooo`003?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
G?ooool2o`0000[ooooo0ol0000aooooo`;o00005oooool3o`000=?ooooo000;ooooo`;o00001?oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo05cooooo0_l0000:ooooo`;o0000
<_ooool3o`0001Kooooo0_l0003Dooooo`003?ooool00ol0003oooooooooo`03ooooo`;o00001ooo
ool3o`0005cooooo0_l00009ooooo`?o0000<oooool2o`0001Gooooo0ol0003Dooooo`006oooool0
0ol0003oooooooooo`1Looooo`;o00002?ooool3o`0003Cooooo0ol0000Dooooo`;o0000eOooool0
01_ooooo00?o0000ooooooooool0G?ooool2o`0000Sooooo0_l0000fooooo`;o00004oooool3o`00
0=Gooooo000Kooooo`?o0000G?ooool2o`0000Oooooo0ol0000fooooo`?o00004_ooool2o`000=Ko
oooo000Kooooo`03o`000?oooooooooo05cooooo0_l00007ooooo`;o0000>?ooool2o`00017ooooo
0ol0003Fooooo`006oooool00ol0003oooooooooo`1Looooo`;o00001_ooool3o`0003Sooooo0ol0
000?ooooo`?o0000eoooool001_ooooo0ol0001Looooo`;o00001Oooool3o`0003[ooooo0_l0000>
ooooo`?o0000f?ooool001_ooooo00?o0000ooooooooool0G?ooool2o`0000Gooooo0_l0000koooo
o`?o00003Oooool2o`000=Wooooo000Kooooo`03o`000?oooooooooo05cooooo0_l00004ooooo`?o
0000??ooool3o`0000_ooooo0ol0003Iooooo`002_ooool5o`0000?ooooo0_l00007ooooo`?o0000
G?ooool2o`0000?ooooo0ol0000nooooo`?o00002Oooool3o`000=[ooooo000;ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`1Looooo`;o
00000_ooool4o`0003oooooo0ol00007ooooo`?o0000foooool000cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo05cooooo0_l000001?oooooo
0000o`000?l00012ooooo`Co00000oooool4o`000=cooooo000=ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`04ooooo`Co0000Foooool5o`0004Cooooo2Ol0003Moooo
o`002_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`1Looooo`Co0000Aoooool5o`000=oooooo000:ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?ooooooS?oo
ool000_ooooo0ol00004ooooo`;o00001oooool00ol0003oooooooooo`3oooooohcooooo003ooooo
oj[ooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 502.812}, {329.812, 259.875}} -> {-11.0219, \
147.628, 0.104427, 0.656394}}]
}, Open  ]],

Cell["Here is the Laplace transform of the driver.", "Text"],

Cell[CellGroupData[{

Cell["LaplaceTransform[f[t],t,s]", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(20\ \((\(4\ \[ExponentialE]\^\(\(-20\)\ s\)\ \[Pi]\)\/\(\[Pi]\^2 + 16\ \
s\^2\) + \(16\ \[ExponentialE]\^\(\(-10\)\ s\)\ s\)\/\(\[Pi]\^2 + 16\ s\^2\))\
\)\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[TextData[{
  "For the forced differential equation we will use ",
  StyleBox["m",
    FontSlant->"Italic"],
  " = 40 (kilograms), ",
  StyleBox["b",
    FontSlant->"Italic"],
  " = 0, ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 10. "
}], "Text"],

Cell[CellGroupData[{

Cell["DE = 40*y''[t] + 10*y[t] == f[t]", "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(10\ y[t]\), "+", 
        RowBox[{"40", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], 
      "\[Equal]", \(f[t]\)}]], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell["The DSolve solution is messy.", "Text"],

Cell[CellGroupData[{

Cell["soln = DSolve[ {DE, y[0]==0, y'[0]==3}, y[t], t ]", "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({{y[
            t] \[Rule] \(\(1\/\(\(-4\) + \[Pi]\^2\)\)\((2\ \((\(-12\)\ Sin[
                      t\/2] + 3\ \[Pi]\^2\ Sin[t\/2] - 
                  2\ \[Pi]\ Cos[t\/2]\ Sin[10]\ UnitStep[\(-20\) + t] + 
                  2\ \[Pi]\ Cos[10]\ Sin[t\/2]\ UnitStep[\(-20\) + t] + 
                  4\ Cos[t\/2]\^2\ Sin[\(\[Pi]\ t\)\/4]\ UnitStep[\(-20\) + 
                        t] + 4\ Sin[t\/2]\^2\ Sin[\(\[Pi]\ t\)\/4]\ UnitStep[\
\(-20\) + t] + 4\ Cos[5]\ Cos[t\/2]\ UnitStep[\(-10\) + t] + 
                  4\ Sin[5]\ Sin[t\/2]\ UnitStep[\(-10\) + t] - 
                  4\ Cos[t\/2]\^2\ Sin[\(\[Pi]\ t\)\/4]\ UnitStep[\(-10\) + 
                        t] - 4\ Sin[t\/2]\^2\ Sin[\(\[Pi]\ t\)\/4]\ UnitStep[\
\(-10\) + t])\))\)\)}}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["But it simplifies considerably.", "Text"],

Cell[CellGroupData[{

Cell["soln = Simplify[soln]", "Input",
  CellLabel->"In[22]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{y[
            t] \[Rule] \(\(1\/\(\(-4\) + \[Pi]\^2\)\)\((6\ \((\(-4\) + \
\[Pi]\^2)\)\ Sin[t\/2] + \((\(-4\)\ \[Pi]\ Sin[10 - t\/2] + 
                    8\ Sin[\(\[Pi]\ t\)\/4])\)\ UnitStep[\(-20\) + t] + 
              8\ \((Cos[5 - t\/2] - 
                    Sin[\(\[Pi]\ t\)\/4])\)\ UnitStep[\(-10\) + 
                    t])\)\)}}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[{
  "The Laplace transform solution is much nicer looking. We can obtain it as \
follows.\n",
  StyleBox["Transform DE to the s-domain",
    FontVariations->{"Underline"->True}]
}], "Text"],

Cell[CellGroupData[{

Cell["LaplaceTransform[DE,t,s]", "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(10\ LaplaceTransform[y[t], t, s]\), "+", 
        RowBox[{"40", " ", 
          RowBox[{"(", 
            
            RowBox[{\(s\^2\ LaplaceTransform[y[t], t, s]\), "-", \(s\ y[0]\), 
              "-", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}]}], ")"}]}]}], 
      "\[Equal]", \(20\ \((\(4\ \[ExponentialE]\^\(\(-20\)\ s\)\ \[Pi]\)\/\(\
\[Pi]\^2 + 16\ s\^2\) + \(16\ \[ExponentialE]\^\(\(-10\)\ s\)\ \
s\)\/\(\[Pi]\^2 + 16\ s\^2\))\)\)}]], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[TextData[{
  " ",
  StyleBox["Substitute the initial values, and let Y replace \
LaplaceTransform[y[t],t,s]",
    FontVariations->{"Underline"->True}]
}], "Text"],

Cell[CellGroupData[{

Cell["%/.{y[0]->0,y'[0]->3,LaplaceTransform[y[t],t,s]->Y}", "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(10\ Y + 40\ \((\(-3\) + s\^2\ Y)\) \[Equal] 
      20\ \((\(4\ \[ExponentialE]\^\(\(-20\)\ s\)\ \[Pi]\)\/\(\[Pi]\^2 + 16\ \
s\^2\) + \(16\ \[ExponentialE]\^\(\(-10\)\ s\)\ s\)\/\(\[Pi]\^2 + 16\ s\^2\))\
\)\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[TextData[StyleBox["Solve for Y",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[CellGroupData[{

Cell["Solve[%,Y]", "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \({{Y \[Rule] \(4\ \[ExponentialE]\^\(\(-20\)\ s\)\ \((2\ \[Pi] + 3\ \
\[ExponentialE]\^\(20\ s\)\ \[Pi]\^2 + 8\ \[ExponentialE]\^\(10\ s\)\ s + 48\ \
\[ExponentialE]\^\(20\ s\)\ s\^2)\)\)\/\(\((1 + 4\ s\^2)\)\ \((\[Pi]\^2 + 16\ \
s\^2)\)\)}}\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Invert to get the solution formula",
    FontVariations->{"Underline"->True}],
  " (Compare to the simplified solution formula displayed above.)"
}], "Text"],

Cell[CellGroupData[{

Cell["InverseLaplaceTransform[Y/.%,s,t]", "Input",
  CellLabel->"In[35]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({\(1\/\(\(-4\) + \[Pi]\^2\)\)\((2\ \((3\ \((\(-4\) + \[Pi]\^2)\)\ Sin[
                  t\/2] + \((\(-2\)\ \[Pi]\ Sin[10 - t\/2] + 
                    4\ Sin[\(\[Pi]\ t\)\/4])\)\ UnitStep[\(-20\) + t] + 
              4\ \((Cos[5 - t\/2] - 
                    Sin[\(\[Pi]\ t\)\/4])\)\ UnitStep[\(-10\) + 
                    t])\))\)}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell["\<\
Here is a plot of the solution and the driver (between 10 and 20). \
The input graph has been scaled down to fit nicely into the plot. The driver \
causes  the amplitude of the oscillations to decrease from 6 to 4 meters \
(approximately). The phase of the oscillations has also been affected, but \
not the period. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Plot[ {y[t]/.soln,f[t]/7}, {t,0,40}, AspectRatio\[Rule]1/3]\
\>", \
"Input",
  CellLabel->"In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.166661 0.0264562 [
[.2619 .15416 -6 -9 ]
[.2619 .15416 6 0 ]
[.5 .15416 -6 -9 ]
[.5 .15416 6 0 ]
[.7381 .15416 -6 -9 ]
[.7381 .15416 6 0 ]
[.97619 .15416 -6 -9 ]
[.97619 .15416 6 0 ]
[.01131 .00792 -12 -4.5 ]
[.01131 .00792 0 4.5 ]
[.01131 .06084 -12 -4.5 ]
[.01131 .06084 0 4.5 ]
[.01131 .11375 -12 -4.5 ]
[.01131 .11375 0 4.5 ]
[.01131 .21957 -6 -4.5 ]
[.01131 .21957 0 4.5 ]
[.01131 .27249 -6 -4.5 ]
[.01131 .27249 0 4.5 ]
[.01131 .3254 -6 -4.5 ]
[.01131 .3254 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .16666 m
.2619 .17291 L
s
[(10)] .2619 .15416 0 1 Mshowa
.5 .16666 m
.5 .17291 L
s
[(20)] .5 .15416 0 1 Mshowa
.7381 .16666 m
.7381 .17291 L
s
[(30)] .7381 .15416 0 1 Mshowa
.97619 .16666 m
.97619 .17291 L
s
[(40)] .97619 .15416 0 1 Mshowa
.125 Mabswid
.07143 .16666 m
.07143 .17041 L
s
.11905 .16666 m
.11905 .17041 L
s
.16667 .16666 m
.16667 .17041 L
s
.21429 .16666 m
.21429 .17041 L
s
.30952 .16666 m
.30952 .17041 L
s
.35714 .16666 m
.35714 .17041 L
s
.40476 .16666 m
.40476 .17041 L
s
.45238 .16666 m
.45238 .17041 L
s
.54762 .16666 m
.54762 .17041 L
s
.59524 .16666 m
.59524 .17041 L
s
.64286 .16666 m
.64286 .17041 L
s
.69048 .16666 m
.69048 .17041 L
s
.78571 .16666 m
.78571 .17041 L
s
.83333 .16666 m
.83333 .17041 L
s
.88095 .16666 m
.88095 .17041 L
s
.92857 .16666 m
.92857 .17041 L
s
.25 Mabswid
0 .16666 m
1 .16666 L
s
.02381 .00792 m
.03006 .00792 L
s
[(-6)] .01131 .00792 1 0 Mshowa
.02381 .06084 m
.03006 .06084 L
s
[(-4)] .01131 .06084 1 0 Mshowa
.02381 .11375 m
.03006 .11375 L
s
[(-2)] .01131 .11375 1 0 Mshowa
.02381 .21957 m
.03006 .21957 L
s
[(2)] .01131 .21957 1 0 Mshowa
.02381 .27249 m
.03006 .27249 L
s
[(4)] .01131 .27249 1 0 Mshowa
.02381 .3254 m
.03006 .3254 L
s
[(6)] .01131 .3254 1 0 Mshowa
.125 Mabswid
.02381 .02115 m
.02756 .02115 L
s
.02381 .03438 m
.02756 .03438 L
s
.02381 .04761 m
.02756 .04761 L
s
.02381 .07406 m
.02756 .07406 L
s
.02381 .08729 m
.02756 .08729 L
s
.02381 .10052 m
.02756 .10052 L
s
.02381 .12698 m
.02756 .12698 L
s
.02381 .1402 m
.02756 .1402 L
s
.02381 .15343 m
.02756 .15343 L
s
.02381 .17989 m
.02756 .17989 L
s
.02381 .19312 m
.02756 .19312 L
s
.02381 .20634 m
.02756 .20634 L
s
.02381 .2328 m
.02756 .2328 L
s
.02381 .24603 m
.02756 .24603 L
s
.02381 .25926 m
.02756 .25926 L
s
.02381 .28571 m
.02756 .28571 L
s
.02381 .29894 m
.02756 .29894 L
s
.02381 .31217 m
.02756 .31217 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.02381 .16666 m
.04262 .22774 L
.06244 .28178 L
.06747 .29266 L
.07286 .30274 L
.07751 .31006 L
.08255 .31646 L
.08564 .31954 L
.08848 .32182 L
.0912 .32348 L
.09258 .32412 L
.09409 .32468 L
.09479 .32489 L
.09545 .32505 L
.0967 .32527 L
.09739 .32535 L
.09804 .32539 L
.09875 .3254 L
.0995 .32537 L
.10016 .32531 L
.10088 .32522 L
.10217 .32495 L
.10342 .32459 L
.10458 .32415 L
.10704 .32292 L
.10928 .32143 L
.11432 .31684 L
.11898 .31109 L
.1234 .30436 L
.1333 .2851 L
.14407 .2584 L
.18485 .12889 L
.2051 .06864 L
.21502 .04494 L
.22412 .02781 L
.2287 .02106 L
.23297 .01599 L
.23742 .01198 L
.23977 .01041 L
.24228 .00915 L
.2436 .00867 L
.24482 .00833 L
.24545 .00819 L
.24615 .00807 L
.24688 .00799 L
.24756 .00794 L
.24882 .00794 L
.24996 .00803 L
.2506 .00812 L
.25129 .00825 L
Mistroke
.25254 .00858 L
.25377 .00901 L
.25489 .00948 L
.25738 .01086 L
.25969 .01252 L
.26187 .01441 L
.26654 .01979 L
.27166 .02788 L
.28198 .05067 L
.30047 .10856 L
.32165 .1874 L
.34095 .25287 L
.35054 .27829 L
.3556 .28909 L
.36097 .2984 L
.36565 .30461 L
.36831 .30733 L
.37081 .30934 L
.37193 .31007 L
.3731 .31073 L
.37411 .3112 L
.37519 .31161 L
.37636 .31194 L
.37744 .31215 L
.37874 .31227 L
.37991 .31227 L
.3811 .31214 L
.38222 .31192 L
.38345 .31157 L
.38477 .31105 L
.38746 .30959 L
.38991 .30777 L
.39464 .30304 L
.39913 .29715 L
.40909 .27981 L
.41994 .25576 L
.4393 .20601 L
.46069 .15279 L
.47042 .13228 L
.48092 .1138 L
.49083 .10007 L
.49992 .0906 L
.50465 .0868 L
.50971 .08361 L
.51217 .0824 L
.51448 .08146 L
.51657 .08078 L
.51883 .08024 L
.52011 .08002 L
.52131 .07987 L
Mistroke
.52263 .07976 L
.52337 .07974 L
.52405 .07973 L
.52475 .07974 L
.52541 .07977 L
.52612 .07982 L
.52689 .07989 L
.52762 .07998 L
.5283 .08008 L
.52959 .08033 L
.53207 .08098 L
.53436 .08178 L
.53952 .08431 L
.54422 .08745 L
.54926 .09168 L
.55836 .1014 L
.57902 .1316 L
.59885 .16676 L
.62041 .20477 L
.63045 .22029 L
.64112 .23415 L
.65022 .24333 L
.65541 .24733 L
.65793 .24893 L
.66027 .25021 L
.66273 .25134 L
.66497 .25217 L
.66746 .25287 L
.66882 .25316 L
.67011 .25336 L
.67137 .2535 L
.672 .25354 L
.6727 .25358 L
.67393 .25359 L
.67508 .25355 L
.67578 .2535 L
.67644 .25344 L
.67768 .25327 L
.67901 .25303 L
.68047 .25269 L
.68291 .25193 L
.68512 .25106 L
.69007 .24844 L
.69466 .24522 L
.69898 .24153 L
.70878 .23093 L
.71911 .21681 L
.7376 .1862 L
.77564 .11958 L
.7857 .10531 L
Mistroke
.79521 .09431 L
.80046 .08945 L
.80617 .08523 L
.80868 .08373 L
.81135 .0824 L
.81364 .08147 L
.81614 .08068 L
.81745 .08036 L
.81866 .08012 L
.81982 .07995 L
.82105 .07982 L
.82226 .07974 L
.82341 .07973 L
.82443 .07976 L
.82555 .07983 L
.82677 .07997 L
.82746 .08008 L
.82811 .08019 L
.83082 .08084 L
.83316 .08162 L
.83567 .08269 L
.84058 .08546 L
.84524 .08888 L
.85396 .09725 L
.86361 .10921 L
.87386 .12447 L
.89228 .15626 L
.91197 .1918 L
.93002 .22082 L
.93925 .23291 L
.94936 .24328 L
.95462 .24734 L
.95951 .25023 L
.96222 .25146 L
.96468 .25234 L
.96605 .25272 L
.96753 .25306 L
.96892 .25331 L
.97021 .25346 L
.97092 .25353 L
.97168 .25357 L
.9724 .25359 L
.97306 .25359 L
.97383 .25357 L
.97466 .25353 L
.97546 .25346 L
.97619 .25337 L
Mfstroke
.02381 .16666 m
.02499 .16666 L
.02605 .16666 L
.02729 .16666 L
.02846 .16666 L
.02954 .16666 L
.03053 .16666 L
.03163 .16666 L
.03279 .16666 L
.03395 .16666 L
.0352 .16666 L
.03638 .16666 L
.03746 .16666 L
.03873 .16666 L
.03944 .16666 L
.04011 .16666 L
.04132 .16666 L
.04262 .16666 L
.04327 .16666 L
.04396 .16666 L
.04519 .16666 L
.04588 .16666 L
.04652 .16666 L
.04722 .16666 L
.04797 .16666 L
.04862 .16666 L
.04933 .16666 L
.05061 .16666 L
.05186 .16666 L
.05302 .16666 L
.05414 .16666 L
.05519 .16666 L
.05634 .16666 L
.05759 .16666 L
.05882 .16666 L
.06012 .16666 L
.06123 .16666 L
.06244 .16666 L
.06315 .16666 L
.06381 .16666 L
.06453 .16666 L
.06529 .16666 L
.06657 .16666 L
.06729 .16666 L
.06797 .16666 L
.06924 .16666 L
.0704 .16666 L
.07103 .16666 L
.07173 .16666 L
.073 .16666 L
Mistroke
.07376 .16666 L
.07448 .16666 L
.07513 .16666 L
.07583 .16666 L
.0766 .16666 L
.0774 .16666 L
.07809 .16666 L
.07885 .16666 L
.07956 .16666 L
.0802 .16666 L
.08095 .16666 L
.08166 .16666 L
.08291 .16666 L
.08362 .16666 L
.08427 .16666 L
.08544 .16666 L
.08669 .16666 L
.08787 .16666 L
.08896 .16666 L
.09016 .16666 L
.09148 .16666 L
.09214 .16666 L
.09285 .16666 L
.09413 .16666 L
.09483 .16666 L
.09548 .16666 L
.09619 .16666 L
.09695 .16666 L
.09821 .16666 L
.09893 .16666 L
.09961 .16666 L
.10086 .16666 L
.10201 .16666 L
.10333 .16666 L
.10458 .16666 L
.10572 .16666 L
.10694 .16666 L
.1081 .16666 L
.10916 .16666 L
.11033 .16666 L
.11162 .16666 L
.11227 .16666 L
.11297 .16666 L
.11422 .16666 L
.11491 .16666 L
.11554 .16666 L
.11624 .16666 L
.11698 .16666 L
.11822 .16666 L
.11892 .16666 L
Mistroke
.11958 .16666 L
.12081 .16666 L
.12194 .16666 L
.12323 .16666 L
.12446 .16666 L
.12562 .16666 L
.12668 .16666 L
.12789 .16666 L
.12903 .16666 L
.13009 .16666 L
.13107 .16666 L
.13214 .16666 L
.13327 .16666 L
.13441 .16666 L
.13564 .16666 L
.1368 .16666 L
.13785 .16666 L
.13909 .16666 L
.13979 .16666 L
.14043 .16666 L
.14162 .16666 L
.14288 .16666 L
.14402 .16666 L
.14526 .16666 L
.14656 .16666 L
.14777 .16666 L
.14891 .16666 L
.14994 .16666 L
.15113 .16666 L
.15226 .16666 L
.15348 .16666 L
.15478 .16666 L
.15589 .16666 L
.15711 .16666 L
.15842 .16666 L
.15915 .16666 L
.15982 .16666 L
.16113 .16666 L
.16236 .16666 L
.16352 .16666 L
.16456 .16666 L
.16577 .16666 L
.1669 .16666 L
.16796 .16666 L
.16893 .16666 L
.16999 .16666 L
.17111 .16666 L
.17225 .16666 L
.17347 .16666 L
.17462 .16666 L
Mistroke
.17566 .16666 L
.17689 .16666 L
.17758 .16666 L
.17823 .16666 L
.1794 .16666 L
.18065 .16666 L
.18185 .16666 L
.18316 .16666 L
.18441 .16666 L
.18556 .16666 L
.1867 .16666 L
.18773 .16666 L
.18893 .16666 L
.19005 .16666 L
.19128 .16666 L
.19258 .16666 L
.19369 .16666 L
.19491 .16666 L
.19623 .16666 L
.19696 .16666 L
.19763 .16666 L
.19894 .16666 L
.20017 .16666 L
.20122 .16666 L
.20238 .16666 L
.20359 .16666 L
.20472 .16666 L
.20578 .16666 L
.20675 .16666 L
.20781 .16666 L
.20894 .16666 L
.21008 .16666 L
.21129 .16666 L
.21244 .16666 L
.21349 .16666 L
.21472 .16666 L
.21541 .16666 L
.21605 .16666 L
.21723 .16666 L
.21847 .16666 L
.21968 .16666 L
.221 .16666 L
.22224 .16666 L
.2234 .16666 L
.22454 .16666 L
.22558 .16666 L
.22677 .16666 L
.2279 .16666 L
.22914 .16666 L
.23044 .16666 L
Mistroke
.23155 .16666 L
.23277 .16666 L
.23409 .16666 L
.23482 .16666 L
.2355 .16666 L
.2368 .16666 L
.23804 .16666 L
.23909 .16666 L
.24025 .16666 L
.24146 .16666 L
.2426 .16666 L
.24365 .16666 L
.24462 .16666 L
.24569 .16666 L
.24681 .16666 L
.24795 .16666 L
.24917 .16666 L
.25032 .16666 L
.25137 .16666 L
.2526 .16666 L
.25329 .16666 L
.25393 .16666 L
.2551 .16666 L
.25635 .16666 L
.25756 .16666 L
.25888 .16666 L
.26013 .16666 L
.26129 .16666 L
.26233 .24224 L
.26348 .24215 L
.26467 .24193 L
.2658 .24163 L
.26704 .24117 L
.26835 .24055 L
.27068 .2391 L
.2732 .23707 L
.27595 .23428 L
.28053 .22842 L
.28544 .2206 L
.29427 .2031 L
.31415 .15517 L
.32463 .13054 L
.33036 .11871 L
.33573 .10916 L
.34089 .10168 L
.34561 .09648 L
.3483 .09427 L
.35085 .09269 L
.35225 .09205 L
.35355 .0916 L
Mistroke
.3543 .0914 L
.35497 .09126 L
.35576 .09115 L
.35649 .09109 L
.35761 .09108 L
.35883 .09119 L
.3601 .09143 L
.36129 .09178 L
.3624 .09221 L
.36342 .09269 L
.3657 .09406 L
.36815 .096 L
.37082 .09863 L
.37566 .10474 L
.38507 .12093 L
.39544 .14379 L
.41645 .19509 L
.42588 .21516 L
.43102 .22425 L
.43581 .23123 L
.441 .23699 L
.44375 .23921 L
.44516 .24012 L
.44669 .24092 L
.44809 .24149 L
.44938 .24188 L
.45061 .24212 L
.45191 .24224 L
.45308 .24223 L
.45418 .24212 L
.45538 .24188 L
.45666 .2415 L
.458 .24095 L
.45921 .24034 L
.46192 .23854 L
.46444 .23635 L
.4668 .23386 L
.47211 .2268 L
.47784 .21712 L
.48744 .1971 L
.49251 .18514 L
.49531 .17832 L
.49795 .17177 L
.49921 .16864 L
.49984 .16705 L
.50054 .16666 L
.5013 .16666 L
.50201 .16666 L
.50266 .16666 L
.50336 .16666 L
Mistroke
.50468 .16666 L
.50593 .16666 L
.50706 .16666 L
.50829 .16666 L
.50956 .16666 L
.51071 .16666 L
.51135 .16666 L
.51204 .16666 L
.51329 .16666 L
.51446 .16666 L
.51571 .16666 L
.51677 .16666 L
.51793 .16666 L
.51861 .16666 L
.51934 .16666 L
.52004 .16666 L
.52068 .16666 L
.5219 .16666 L
.52319 .16666 L
.52385 .16666 L
.52457 .16666 L
.52587 .16666 L
.52662 .16666 L
.52741 .16666 L
.52809 .16666 L
.52883 .16666 L
.52952 .16666 L
.53016 .16666 L
.53138 .16666 L
.53268 .16666 L
.53342 .16666 L
.5341 .16666 L
.53524 .16666 L
.53649 .16666 L
.53779 .16666 L
.53901 .16666 L
.54026 .16666 L
.54096 .16666 L
.54159 .16666 L
.54282 .16666 L
.54398 .16666 L
.54464 .16666 L
.54534 .16666 L
.54659 .16666 L
.54728 .16666 L
.54793 .16666 L
.54864 .16666 L
.54941 .16666 L
.55068 .16666 L
.5514 .16666 L
Mistroke
.55206 .16666 L
.55328 .16666 L
.55457 .16666 L
.55573 .16666 L
.55681 .16666 L
.558 .16666 L
.55928 .16666 L
.56045 .16666 L
.56153 .16666 L
.56272 .16666 L
.56399 .16666 L
.56463 .16666 L
.56533 .16666 L
.56659 .16666 L
.56782 .16666 L
.56895 .16666 L
.57001 .16666 L
.571 .16666 L
.57209 .16666 L
.57326 .16666 L
.57448 .16666 L
.57564 .16666 L
.57668 .16666 L
.57781 .16666 L
.57846 .16666 L
.57915 .16666 L
.58038 .16666 L
.5817 .16666 L
.58245 .16666 L
.58315 .16666 L
.58442 .16666 L
.58557 .16666 L
.58621 .16666 L
.58691 .16666 L
.58817 .16666 L
.58929 .16666 L
.59053 .16666 L
.59183 .16666 L
.59304 .16666 L
.59417 .16666 L
.59521 .16666 L
.59641 .16666 L
.59754 .16666 L
.59886 .16666 L
.60006 .16666 L
.60073 .16666 L
.60144 .16666 L
.60275 .16666 L
.60397 .16666 L
.60526 .16666 L
Mistroke
.60637 .16666 L
.60758 .16666 L
.60831 .16666 L
.60901 .16666 L
.61031 .16666 L
.61104 .16666 L
.61172 .16666 L
.61246 .16666 L
.61325 .16666 L
.61454 .16666 L
.61576 .16666 L
.61646 .16666 L
.6171 .16666 L
.6178 .16666 L
.61854 .16666 L
.61977 .16666 L
.62047 .16666 L
.62111 .16666 L
.62229 .16666 L
.62353 .16666 L
.62465 .16666 L
.6257 .16666 L
.62685 .16666 L
.62808 .16666 L
.62939 .16666 L
.63012 .16666 L
.63081 .16666 L
.63207 .16666 L
.63277 .16666 L
.63341 .16666 L
.63461 .16666 L
.63591 .16666 L
.63714 .16666 L
.63827 .16666 L
.63934 .16666 L
.64048 .16666 L
.64156 .16666 L
.64254 .16666 L
.64369 .16666 L
.64494 .16666 L
.64612 .16666 L
.64721 .16666 L
.64833 .16666 L
.64939 .16666 L
.65054 .16666 L
.65178 .16666 L
.65302 .16666 L
.65432 .16666 L
.65543 .16666 L
.65664 .16666 L
Mistroke
.65728 .16666 L
.65796 .16666 L
.65918 .16666 L
.6605 .16666 L
.66124 .16666 L
.66194 .16666 L
.6632 .16666 L
.66435 .16666 L
.66499 .16666 L
.66568 .16666 L
.66694 .16666 L
.66806 .16666 L
.66929 .16666 L
.67058 .16666 L
.67179 .16666 L
.67292 .16666 L
.67395 .16666 L
.67509 .16666 L
.67628 .16666 L
.6776 .16666 L
.67879 .16666 L
.67945 .16666 L
.68017 .16666 L
.68147 .16666 L
.68268 .16666 L
.68398 .16666 L
.68508 .16666 L
.68629 .16666 L
.68702 .16666 L
.68772 .16666 L
.68902 .16666 L
.68974 .16666 L
.69042 .16666 L
.69116 .16666 L
.69195 .16666 L
.69264 .16666 L
.69338 .16666 L
.69408 .16666 L
.69473 .16666 L
.69595 .16666 L
.69725 .16666 L
.69847 .16666 L
.69916 .16666 L
.6998 .16666 L
.70097 .16666 L
.70221 .16666 L
.70332 .16666 L
.70436 .16666 L
.7055 .16666 L
.70673 .16666 L
Mistroke
.70797 .16666 L
.70867 .16666 L
.70932 .16666 L
.71063 .16666 L
.71137 .16666 L
.71204 .16666 L
.71324 .16666 L
.71454 .16666 L
.71577 .16666 L
.7169 .16666 L
.71795 .16666 L
.71909 .16666 L
.72016 .16666 L
.72114 .16666 L
.72229 .16666 L
.72353 .16666 L
.72471 .16666 L
.72581 .16666 L
.72704 .16666 L
.7282 .16666 L
.72925 .16666 L
.73037 .16666 L
.73161 .16666 L
.73291 .16666 L
.73402 .16666 L
.73523 .16666 L
.73655 .16666 L
.73776 .16666 L
.73839 .16666 L
.73909 .16666 L
.73981 .16666 L
.7405 .16666 L
.74175 .16666 L
.74289 .16666 L
.74422 .16666 L
.74547 .16666 L
.74659 .16666 L
.74778 .16666 L
.74891 .16666 L
.74993 .16666 L
.75113 .16666 L
.75243 .16666 L
.75366 .16666 L
.75479 .16666 L
.756 .16666 L
.7573 .16666 L
.75853 .16666 L
.75964 .16666 L
.76095 .16666 L
.76169 .16666 L
Mistroke
.76238 .16666 L
.76364 .16666 L
.76427 .16666 L
.76497 .16666 L
.76565 .16666 L
.76636 .16666 L
.76764 .16666 L
.76835 .16666 L
.76901 .16666 L
.76974 .16666 L
.77052 .16666 L
.77119 .16666 L
.77192 .16666 L
.77261 .16666 L
.77325 .16666 L
.77445 .16666 L
.77573 .16666 L
.77693 .16666 L
.77825 .16666 L
.7795 .16666 L
.78065 .16666 L
.7818 .16666 L
.78283 .16666 L
.78403 .16666 L
.78515 .16666 L
.78639 .16666 L
.78769 .16666 L
.7888 .16666 L
.79002 .16666 L
.79134 .16666 L
.79208 .16666 L
.79275 .16666 L
.79405 .16666 L
.79529 .16666 L
.79634 .16666 L
.7975 .16666 L
.79871 .16666 L
.79985 .16666 L
.80091 .16666 L
.80188 .16666 L
.80294 .16666 L
.80406 .16666 L
.8052 .16666 L
.80642 .16666 L
.80757 .16666 L
.80862 .16666 L
.80985 .16666 L
.81054 .16666 L
.81118 .16666 L
.81235 .16666 L
Mistroke
.8136 .16666 L
.81481 .16666 L
.81613 .16666 L
.81738 .16666 L
.81854 .16666 L
.81958 .16666 L
.82072 .16666 L
.82192 .16666 L
.82305 .16666 L
.82429 .16666 L
.82559 .16666 L
.82671 .16666 L
.82793 .16666 L
.82925 .16666 L
.82999 .16666 L
.83066 .16666 L
.83196 .16666 L
.8332 .16666 L
.83425 .16666 L
.83541 .16666 L
.83663 .16666 L
.83777 .16666 L
.83883 .16666 L
.8398 .16666 L
.84092 .16666 L
.84198 .16666 L
.84313 .16666 L
.84435 .16666 L
.8455 .16666 L
.84654 .16666 L
.84777 .16666 L
.84847 .16666 L
.84911 .16666 L
.85028 .16666 L
.85152 .16666 L
.85274 .16666 L
.85343 .16666 L
.85407 .16666 L
.85524 .16666 L
.85648 .16666 L
.85759 .16666 L
.85863 .16666 L
.85977 .16666 L
.861 .16666 L
.86223 .16666 L
.86293 .16666 L
.86358 .16666 L
.8649 .16666 L
.86563 .16666 L
.8663 .16666 L
Mistroke
.8675 .16666 L
.8688 .16666 L
.87003 .16666 L
.87116 .16666 L
.87222 .16666 L
.87335 .16666 L
.87442 .16666 L
.8754 .16666 L
.87655 .16666 L
.87779 .16666 L
.87897 .16666 L
.88007 .16666 L
.8813 .16666 L
.88246 .16666 L
.88351 .16666 L
.88463 .16666 L
.88587 .16666 L
.88717 .16666 L
.88828 .16666 L
.88949 .16666 L
.8908 .16666 L
.89201 .16666 L
.89265 .16666 L
.89334 .16666 L
.89407 .16666 L
.89475 .16666 L
.896 .16666 L
.89715 .16666 L
.89841 .16666 L
.89973 .16666 L
.90084 .16666 L
.90204 .16666 L
.90316 .16666 L
.90418 .16666 L
.90538 .16666 L
.90668 .16666 L
.90791 .16666 L
.90904 .16666 L
.91025 .16666 L
.91155 .16666 L
.91277 .16666 L
.91389 .16666 L
.9152 .16666 L
.91594 .16666 L
.91663 .16666 L
.91788 .16666 L
.91852 .16666 L
.91922 .16666 L
.91989 .16666 L
.92061 .16666 L
Mistroke
.92189 .16666 L
.9226 .16666 L
.92326 .16666 L
.92399 .16666 L
.92476 .16666 L
.92544 .16666 L
.92617 .16666 L
.92686 .16666 L
.92749 .16666 L
.9287 .16666 L
.92997 .16666 L
.93118 .16666 L
.9325 .16666 L
.93374 .16666 L
.93489 .16666 L
.93604 .16666 L
.93707 .16666 L
.93827 .16666 L
.9394 .16666 L
.94063 .16666 L
.94193 .16666 L
.94304 .16666 L
.94426 .16666 L
.94558 .16666 L
.94631 .16666 L
.94699 .16666 L
.94829 .16666 L
.94953 .16666 L
.95058 .16666 L
.95174 .16666 L
.95295 .16666 L
.95408 .16666 L
.95514 .16666 L
.95611 .16666 L
.95718 .16666 L
.9583 .16666 L
.95944 .16666 L
.96066 .16666 L
.96181 .16666 L
.96285 .16666 L
.96408 .16666 L
.96477 .16666 L
.96541 .16666 L
.96659 .16666 L
.96783 .16666 L
.96892 .16666 L
.96991 .16666 L
.97106 .16666 L
.97215 .16666 L
.97315 .16666 L
Mistroke
.97408 .16666 L
.9751 .16666 L
.97619 .16666 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{336.375, 112.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005@0000L2000`400?l00000o`00003ooooooomA
ooooo`00oooooomAooooo`002Oooool3o`0000Kooooo00?o0000ooooooooool0oooooollooooo`00
2?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0oooooollooooo`00
0_ooool5o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3ooooooccooooo0008ooooo`Co00001_ooool3o`0004?ooooo1_l0003booooo`002?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo047ooooo0ol00004ooooo`;o0000lOooool0
00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0k_ooool000[ooooo0_l00006ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3^ooooo`004_ooool2o`00043ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`3]ooooo`004_ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0k?ooool001;ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0>_ooooo000Boooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3[oooo
o`004_ooool2o`0003kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3Zooooo`00
4_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
j_ooool001;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0>[ooooo000Booooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`3Yooooo`004_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0jOooool001;ooooo0_l0000looooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0jOooool000[ooooo0ol00005ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`3Xooooo`002oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`3Xooooo`000_ooool5o`000003ooooool0003o000000?o00001Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0ioooool000Sooooo00Co0000oooo
oooooooo00001_ooool3o`0003Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3W
ooooo`002Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`3Wooooo`002_ooool2o`0000Kooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0>Kooooo000;ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo0>Kooooo000Booooo`;o0000>?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo0>Kooooo000Booooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`3Uooooo`004_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0A_ooool6o`0005[ooooo1_l0000iooooo`004_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool3o`0000Go
oooo1?l0001Eooooo`;o00001_ooool2o`0003Oooooo000Booooo`;o0000=oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo043ooooo0_l0000<ooooo`03o`000?oooooooooo053ooooo
0_l0000:ooooo`03o`000?oooooooooo03Cooooo000Booooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03?ooooo000B
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?
ooooo`Go0000:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0booooo`004_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool2o`0000Cooooo0_l0000Xoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo037ooooo000Booooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0`ooooo`004_ooool2o`0003Gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0_ooooo`002?ooool5o`0000Gooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo0009ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02gooooo0002ooooo`Go00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0]ooooo`002oooool00ol0
003oooooooooo`04ooooo`?o0000<oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
02cooooo0008ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:oooool000Sooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Zooooo`002Oooool3o`0000Kooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Wooooo000Booooo`;o0000<oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Wooooo000Booooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool3o`0000Cooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo000000Co00000ooo
ool2o`0001Gooooo00?o0000ooooooooool0;?ooool3o`0000Cooooo0_l00007ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool06Oooool3o`0000?ooooo0_l00007ooooo`004_ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Cooooo000Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0
;_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Fooooo`Go00000_ooool01?l0003oooooooooool00006oooo
o`004_ooool2o`00037ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000[ooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0[ooooo`;o00000oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05_ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000Kooooo000Booooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00[ooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo01Gooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooo
ooooooooo`00000Vooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000000oooool01?l0
003oooooooooool00006ooooo`004_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01;ooooo0_l00004ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooooooo00006?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool0:?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01Kooooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo000B
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03
ooooo`;o00002oooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00oooool3o`0000Cooooo0_l0000Hooooo`03o`000?oooooooooo02Wooooo0ol0
0004ooooo`;o00000oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool00_ooool2o`0000Oooooo000Booooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0:?ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool09?ooool001;ooooo0_l0000`ooooo`03o`000?oooooooooo02Sooooo0_l0000Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09?ooool001;ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Yooooo`;o00006_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo02?ooooo000Booooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
8oooool001;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Yooooo`;o00006ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02;ooooo000;oooooooo0000@ol00003
ooooo`004_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool2o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`;o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02?ooool001;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Y
ooooo`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`08ooooo`004_ooool2o`0002gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;
ooooo`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool08?ooool001;ooooo0_l0000]ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01oooooo000B
ooooo`;o0000;Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Oooooo`004_ooool00ol0003oooooo`00000[oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo01kooooo000Booooo`03o`000?oooooo000002_ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool07_ooool001;ooooo0ol0000[ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01gooooo000Booooo`04o`000?oo
ooooooooo`0002Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool07Oooool001;ooooo00Co0000oooooooooooo0000
:Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Looooo`004_ooool01?l0003oooooooooool0000Yooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo01_ooooo000Booooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
6oooool001;ooooo0_l00002ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool06_oo
ool000Sooooo1Ol00005ooooo`05o`000?ooooooooooooooool000009oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0Iooooo`002Oooool01?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool00000
9oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Iooooo`002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000co
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool06?ooool000_ooooo00?o0000ooooooooool01?ooool3o`0000;ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`04o`000?ooooooooooo`0000co
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool05oooool000Sooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`;o
00003?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0Gooooo`002?ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01go
oooo0_l0000;ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo01Kooooo0009ooooo`?o00001_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo01Gooooo000Booooo`;o00001?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo01?ooooo0_l00019ooooo`03o`000?oooooooooo01Cooooo000B
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Q
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooo000000Sooooo0_l0000gooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Dooooo`004_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool0000Cooooo`03o`000?oo
oooooooo01_ooooo00Co0000oooooooooooooooo0_l00005ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01?ooooo
000Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Qooooo`?o00005Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo1Ol0
000looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`0Booooo`004_ooool2o`0000Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo04oooooo0_l0000Booooo`004_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo04Oooooo0_l00009ooooo`;o0000E?ooool00ol0003oooooooooo`0?oooo
o`004_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Wooooo0_l00005ooooo`;o
0000Eoooool3o`0000kooooo000Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
Boooool5o`0005_ooooo1Ol0000:ooooo`004_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo0;_ooooo000Booooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2kooooo`002_ooool3o`00
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2looooo`002oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0_?ooool000Sooooo
1Ol00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0_Oooool000Sooooo00Co
0000oooooooooooo00001_ooool3o`0000Wooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0__ooool000Wooooo00?o
0000ooooool000001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;kooooo000:
ooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;oooooo000;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2ooooo
o`004_ooool2o`0000_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0`?ooool001;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`30ooooo`004_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0<7ooooo000Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0`Oooool0
01;ooooo0_l0000=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo0<;ooooo000Booooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0`oooool001;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`34ooooo`004_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<Gooooo000B
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1>
ooooo`;o00000_ooool2o`000<Sooooo000Booooo`;o00004?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo053ooooo1?l00039ooooo`002Oooool3o`0000Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo7oooool000Sooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaoooooo0008ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0Booooo`;o00001?ooool2o`000?oooooo8_ooool000Sooooo
1?l00006ooooo`?o00004oooool5o`000?oooooo9?ooool000Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3ooooooccooooo0009ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0oooooollooooo`002_ooool2o`0000Kooooo00?o0000ooooooooool0oooooolloooo
o`00oooooomAooooo`00\
\>"],
  ImageRangeCache->{{{77.875, 413.25}, {196.5, 85.375}} -> {-12.6086, \
3.50312, 0.130568, 0.117506}}]
}, Open  ]],

Cell[TextData[StyleBox["The Dirac delta: DiracDelta",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  " The Dirac delta function is written as ",
  StyleBox["DiracDelta",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell["LaplaceTransform[DiracDelta[t-3], t, s]", "Input",
  CellLabel->"In[47]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-3\)\ s\)\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["InverseLaplaceTransform[1, s, t]", "Input",
  CellLabel->"In[48]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(DiracDelta[t]\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[TextData[{
  "Lets drive the mass spring system introduced above with a blow of \
magnitude 200 in the positive direction at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 12. Note that DE[[1]] can be used to refer to the left side the DE \
equation."
}], "Text"],

Cell[CellGroupData[{

Cell["DE2 = DE[[1]] == 200*DiracDelta[t-12]", "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(10\ y[t]\), "+", 
        RowBox[{"40", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], 
      "\[Equal]", \(200\ DiracDelta[\(-12\) + t]\)}]], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
The solution formula, using the same initial conditions, looks like \
this. \
\>", "Text"],

Cell[CellGroupData[{

Cell["soln = DSolve[ {DE2, y[0]==0, y'[0]==3}, y[t], t]", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({{y[t] \[Rule] 
          2\ \((3\ Sin[t\/2] - 5\ Cos[t\/2]\ Sin[6]\ UnitStep[\(-12\) + t] + 
                5\ Cos[6]\ Sin[t\/2]\ UnitStep[\(-12\) + t])\)}}\)], "Output",\

  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
The following plot displays the solution curve (output) and \
vertical line placed at the time of the application of  the blow (input). \
\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ Plot[ y[t]/.soln, {t,0,40} ], 
      ListPlot[ {{12,0},{12,5}}, PlotJoined->True,
      PlotStyle->Thickness[0.015] ], AspectRatio\[Rule]1/3 ]\
\>", "Input",
  CellLabel->"In[6]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.166667 0.0100146 [
[.2619 .15417 -6 -9 ]
[.2619 .15417 6 0 ]
[.5 .15417 -6 -9 ]
[.5 .15417 6 0 ]
[.7381 .15417 -6 -9 ]
[.7381 .15417 6 0 ]
[.97619 .15417 -6 -9 ]
[.97619 .15417 6 0 ]
[.01131 .01645 -18 -4.5 ]
[.01131 .01645 0 4.5 ]
[.01131 .06652 -18 -4.5 ]
[.01131 .06652 0 4.5 ]
[.01131 .11659 -12 -4.5 ]
[.01131 .11659 0 4.5 ]
[.01131 .21674 -6 -4.5 ]
[.01131 .21674 0 4.5 ]
[.01131 .26681 -12 -4.5 ]
[.01131 .26681 0 4.5 ]
[.01131 .31689 -12 -4.5 ]
[.01131 .31689 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .16667 m
.2619 .17292 L
s
[(10)] .2619 .15417 0 1 Mshowa
.5 .16667 m
.5 .17292 L
s
[(20)] .5 .15417 0 1 Mshowa
.7381 .16667 m
.7381 .17292 L
s
[(30)] .7381 .15417 0 1 Mshowa
.97619 .16667 m
.97619 .17292 L
s
[(40)] .97619 .15417 0 1 Mshowa
.125 Mabswid
.07143 .16667 m
.07143 .17042 L
s
.11905 .16667 m
.11905 .17042 L
s
.16667 .16667 m
.16667 .17042 L
s
.21429 .16667 m
.21429 .17042 L
s
.30952 .16667 m
.30952 .17042 L
s
.35714 .16667 m
.35714 .17042 L
s
.40476 .16667 m
.40476 .17042 L
s
.45238 .16667 m
.45238 .17042 L
s
.54762 .16667 m
.54762 .17042 L
s
.59524 .16667 m
.59524 .17042 L
s
.64286 .16667 m
.64286 .17042 L
s
.69048 .16667 m
.69048 .17042 L
s
.78571 .16667 m
.78571 .17042 L
s
.83333 .16667 m
.83333 .17042 L
s
.88095 .16667 m
.88095 .17042 L
s
.92857 .16667 m
.92857 .17042 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.02381 .01645 m
.03006 .01645 L
s
[(-15)] .01131 .01645 1 0 Mshowa
.02381 .06652 m
.03006 .06652 L
s
[(-10)] .01131 .06652 1 0 Mshowa
.02381 .11659 m
.03006 .11659 L
s
[(-5)] .01131 .11659 1 0 Mshowa
.02381 .21674 m
.03006 .21674 L
s
[(5)] .01131 .21674 1 0 Mshowa
.02381 .26681 m
.03006 .26681 L
s
[(10)] .01131 .26681 1 0 Mshowa
.02381 .31689 m
.03006 .31689 L
s
[(15)] .01131 .31689 1 0 Mshowa
.125 Mabswid
.02381 .02646 m
.02756 .02646 L
s
.02381 .03648 m
.02756 .03648 L
s
.02381 .04649 m
.02756 .04649 L
s
.02381 .05651 m
.02756 .05651 L
s
.02381 .07654 m
.02756 .07654 L
s
.02381 .08655 m
.02756 .08655 L
s
.02381 .09656 m
.02756 .09656 L
s
.02381 .10658 m
.02756 .10658 L
s
.02381 .12661 m
.02756 .12661 L
s
.02381 .13662 m
.02756 .13662 L
s
.02381 .14664 m
.02756 .14664 L
s
.02381 .15665 m
.02756 .15665 L
s
.02381 .17668 m
.02756 .17668 L
s
.02381 .1867 m
.02756 .1867 L
s
.02381 .19671 m
.02756 .19671 L
s
.02381 .20673 m
.02756 .20673 L
s
.02381 .22675 m
.02756 .22675 L
s
.02381 .23677 m
.02756 .23677 L
s
.02381 .24678 m
.02756 .24678 L
s
.02381 .2568 m
.02756 .2568 L
s
.02381 .27683 m
.02756 .27683 L
s
.02381 .28684 m
.02756 .28684 L
s
.02381 .29686 m
.02756 .29686 L
s
.02381 .30687 m
.02756 .30687 L
s
.02381 .00643 m
.02756 .00643 L
s
.02381 .3269 m
.02756 .3269 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.02381 .16667 m
.04262 .18979 L
.06244 .21024 L
.06747 .21436 L
.07286 .21818 L
.07751 .22095 L
.08255 .22337 L
.08564 .22454 L
.08848 .2254 L
.0912 .22603 L
.09258 .22627 L
.09409 .22648 L
.09479 .22656 L
.09545 .22662 L
.0967 .22671 L
.09739 .22674 L
.09804 .22675 L
.09875 .22675 L
.0995 .22674 L
.10016 .22672 L
.10088 .22669 L
.10217 .22659 L
.10342 .22645 L
.10458 .22628 L
.10704 .22582 L
.10928 .22525 L
.11432 .22352 L
.11898 .22134 L
.1234 .21879 L
.1333 .2115 L
.14407 .20139 L
.18485 .15237 L
.2051 .12956 L
.21502 .12059 L
.22412 .11411 L
.2287 .11155 L
.23297 .10963 L
.23742 .10812 L
.23977 .10752 L
.24228 .10704 L
.2436 .10686 L
.24482 .10673 L
.24545 .10668 L
.24615 .10664 L
.24688 .1066 L
.24756 .10659 L
.24882 .10658 L
.24996 .10662 L
.2506 .10665 L
.25129 .1067 L
Mistroke
.25254 .10683 L
.25377 .10699 L
.25489 .10717 L
.25738 .10769 L
.25969 .10832 L
.26187 .10903 L
.26654 .11098 L
.27166 .11372 L
.28198 .12107 L
.29148 .12973 L
.30047 .13928 L
.30537 .14492 L
.30672 .14651 L
.30814 .14821 L
.30936 .14968 L
.31005 .15163 L
.3107 .15378 L
.32002 .18479 L
.34095 .25016 L
.3508 .27612 L
.36117 .29837 L
.37002 .31247 L
.37503 .31825 L
.37729 .32032 L
.37969 .32213 L
.38094 .32292 L
.38232 .32366 L
.38359 .32423 L
.38475 .32465 L
.38612 .32503 L
.38687 .32518 L
.38759 .32529 L
.38885 .32539 L
.38957 .3254 L
.39024 .32537 L
.39142 .32525 L
.39253 .32505 L
.39374 .32473 L
.39506 .32427 L
.39773 .32296 L
.40018 .32132 L
.40451 .31745 L
.40924 .31178 L
.41878 .29607 L
.42904 .27343 L
.43837 .24852 L
.45931 .18283 L
.48009 .11459 L
.48921 .08698 L
.49926 .06 L
Mistroke
.50825 .03983 L
.51792 .02319 L
.52326 .0165 L
.52813 .01203 L
.53048 .01045 L
.53172 .00977 L
.53304 .00917 L
.5343 .0087 L
.53545 .00837 L
.53661 .00813 L
.5377 .00799 L
.53886 .00794 L
.54011 .00798 L
.54128 .00812 L
.54236 .00834 L
.54361 .00869 L
.54498 .0092 L
.54747 .01046 L
.55007 .01223 L
.55283 .01461 L
.55779 .02017 L
.56657 .03387 L
.57627 .05418 L
.59563 .10765 L
.61649 .17573 L
.63615 .23856 L
.64655 .2675 L
.65765 .29309 L
.66319 .30338 L
.66841 .31139 L
.67311 .3171 L
.67553 .31948 L
.67819 .32164 L
.68069 .32323 L
.68302 .32432 L
.68431 .32476 L
.68549 .32507 L
.68614 .32519 L
.68684 .32529 L
.68813 .32539 L
.68934 .32538 L
.69044 .32528 L
.6917 .32506 L
.69289 .32475 L
.69399 .32437 L
.69501 .32395 L
.69729 .32274 L
.69976 .32103 L
.70201 .31911 L
.70706 .31358 L
Mistroke
.71617 .29947 L
.7268 .27693 L
.73685 .25056 L
.77525 .12746 L
.79469 .06962 L
.80501 .04489 L
.8107 .03362 L
.81611 .02467 L
.82118 .01793 L
.82386 .01505 L
.82671 .01251 L
.82935 .01065 L
.83174 .00938 L
.8329 .00891 L
.83415 .0085 L
.83533 .00822 L
.83642 .00804 L
.83752 .00795 L
.8387 .00795 L
.83981 .00803 L
.84083 .00818 L
.84202 .00845 L
.84331 .00886 L
.84567 .0099 L
.84813 .0114 L
.85075 .01344 L
.85545 .01827 L
.86033 .02482 L
.86481 .03214 L
.87491 .05288 L
.89319 .1026 L
.9137 .16911 L
.9328 .23087 L
.95121 .28088 L
.96152 .30189 L
.96602 .30913 L
.97089 .31554 L
.97619 .32073 L
Mfstroke
.015 w
.30952 .16667 m
.30952 .21674 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{279, 92.9375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004G0000G2000`400?l00000o`00003ooooooolH
ooooo`00oooooolHooooo`005Oooool00ol0003oooooooooo`3oooooo`005Oooool2o`000?oooooo
0Oooool000Oooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`22ooooo`Go0000B_oo
ool5o`0002Wooooo0008ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`16ooooo`;o00001?ooool00ol0003oooooooooo`0Vooooo`001Ol00003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool2o`00087ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`13ooooo`;o00001_ooool00ol0003oooooooooo`0Vooooo`002?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0P?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01_ooool2o`00
02Kooooo0008ooooo`04o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02?ooooo0007ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`;o
0000P?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Sooooo`002?ooool01?l0003oooooooooooooool5o`0000Co
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Rooooo`005Oooool2o`0007kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08_ooool001Gooooo00?o0000ooooooooool0O?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Qooooo`005Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027ooooo000Eoooo
o`;o0000O?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Pooooo`005Oooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo023ooooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
7oooool000Oooooo0ol00004ooooo`;o00001Oooool2o`0007_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07ooo
ool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool07oooool000Go00000oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001jooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01kooooo0008
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01kooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01kooooo0007
ooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`;o0000NOooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Mooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`1h
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01gooooo000Eooooo`;o0000NOooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Moooo
o`005Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01cooooo000Eooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool07?ooool001Gooooo0_l0001hooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01cooooo000Eooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool0
01Gooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`003Oooool3o`0000Go
oooo0_l0000fooooo`So0000>Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`003?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0<_ooool3o`0000Sooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Jooooo`001_ooool5o`0000Gooooo00?o0000ooooooooool0
0_ooool2o`00037ooooo0_l0000<ooooo`;o0000=Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Jooooo`004?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01[ooooo000<ooooo`Co00001Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo0ol00004ooooo`;o00000_ooool0
0ol0003oooooooooo`0`ooooo`Go00000oooool2o`0001Kooooo00?o0000ooooooooool07Oooool3
o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool3
o`0000?ooooo0_l00004ooooo`003?ooool00ol0003oooooooooo`06ooooo`;o0000;_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0_ooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00ko
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo007ooooo000<ooooo`Go
00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00003ooooo`;o0000;oooool00ol0003oooooo`000004oooo
o`04o`000?ooooooooooo`0001Kooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0;ooooo`Go00000_ooool01?l0003oooooooooool00003ooooo`005Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo02_ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0001Kooooo00?o0000ooooooooool07Oooool2o`0000?ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`005Oooool2o`0002cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooooooool0:_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000002;ooooo00?o0000ooooooooool02oooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo000Eooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool02Oooool2o`0000Cooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`0Zooooo`;o00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo0_l00003oooo
o`04o`000?ooooooooooo`0000?ooooo000Eooooo`;o0000:_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool00ol00004ooooo`;o00006?ooool00ol0003oooooooooo`0Kooooo`?o00001?ooool2o`00
00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo0_l00004ooooo`005Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Gooooo`005Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Gooooo`005Oooool2o`0002Sooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01Kooooo000Eooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo000Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07oooool3o`0002Oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool05_ooool000ooooooool00009o`0000005Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool2o`0000_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`Co00002Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo
00Gooooo000Eooooo`;o00008oooool00ol0003oooooooooo`0Rooooo`Co00009Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Eooooo`005Oooool00ol0003oooooo`00000Qooooo`03o`000?oooooooooo02?ooooo
1?l0000Tooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01Cooooo000Eooooo`04o`000?ooooooooooo`00023ooooo
00?o0000ooooooooool08oooool3o`000003ooooool0003ooooo02;ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
5?ooool001Gooooo0_l00002ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09?oo
ool3o`000003ooooool0003ooooo02;ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool001Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Gooooo0ol00000
0ooooooo0000ooooo`0Rooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01?ooooo000Eooooo`;o00001?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo02Kooooo0ol00002ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool04oooool001Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02Oooooo0ol00002ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool04oooool001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02Sooooo0ol00002ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool04_ooool000gooooo0ol00005ooooo`;o00001oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02Wooooo0ol00003ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool04_ooool000cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03oooool2o`0002cooooo0ol00003ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool04_ooool0013ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`;o00003_ooool00ol0003oooooooooo`0/ooooo`?o00000oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo017ooooo000@ooooo`03o`000?oooooooooo
00;ooooo0_l0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;Oooool3o`00
00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Aooooo`003?ooool4o`0000Go
oooo00?o0000ooooooooool02oooool2o`0000Oooooo0ol0000`ooooo`?o00001?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo017ooooo000<ooooo`03o`000?oooooooooo00Kooooo
0_l0000>ooooo`Oo0000>_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo
000<ooooo`Go00001?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool04?ooool001Gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo013ooooo000Eooooo`;o0000D?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00oooooo000Eooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0?ooooo`005Oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool03oooool001Gooooo0_l0001Aooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03_ooool001Gooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo0007ooooo`?o00001?ooool2o`00
00Gooooo0_l0001Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03_ooool000So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0008ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool2o`0005?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0=ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00cooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`;o0000E?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo0008ooooo`03o`000?oooooooooo00?o
oooo0_l00005ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool02oooool001Gooooo0_l0001Eooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool02oooool001Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00[ooooo000Eooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0:ooooo`005Oooool2o`0005Oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0:ooooo`005Oooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool02Oooool001Gooooo0_l0001Hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool02?ooool000Oooooo0ol00003ooooo`?o00001Oooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01oooool0
00Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo047ooooo0_l00008
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000F_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0AOooool2o`0000Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`00
2?ooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool0Foooool5o`0004[o
oooo1Ol0001@ooooo`001oooool2o`0000?ooooo00?o0000ooooooooool01_ooool2o`000?oooooo
0Oooool000Sooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo0?oooooo
003ooooooaSooooo003ooooooaSooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 355.875}, {202.312, 110.375}} -> {-15.8377, \
24.4563, 0.159713, 0.379715}}]
}, Open  ]],

Cell["\<\
The effect of the blow is to cause a kink in the curve for position \
as a function of time. There will also be a jump  discontinuity on the curve \
for velocity.  
The phase plane plot below shows the discontinuity in velocity as a vertical \
line joining the initial elliptical trajectory to  the elliptical trajectory \
describing the motion of the system after the blow. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Trajectory = {y[t]/.soln[[1]],D[y[t]/.soln[[1]],t]};
ParametricPlot[ Trajectory, {t,0,22}, AxesOrigin->{-20,-10}, 
                PlotRange->{{-20,20},{-10,10}}, 
                AxesLabel->{\"POSITION\",\"VELOCITY\"}]\
\>", "Input",
  CellLabel->"In[113]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.309017 0.0309017 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -6 -9 ]
[.875 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 52 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -12 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -6 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-15)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-10)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(10)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(15)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(20)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(POSITION) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(-7.5)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-2.5)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(2.5)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(7.5)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(VELOCITY) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.5 .40172 m
.50204 .40171 L
.50389 .40169 L
.50603 .40165 L
.50805 .40159 L
.51164 .40144 L
.51552 .40122 L
.51979 .40091 L
.5243 .4005 L
.53233 .39954 L
.54051 .39828 L
.54807 .39683 L
.56474 .39264 L
.58078 .38713 L
.5944 .38106 L
.60864 .37294 L
.6205 .36422 L
.62963 .35566 L
.63762 .3459 L
.64081 .34096 L
.6434 .33621 L
.6455 .33155 L
.64711 .32714 L
.64847 .32223 L
.64902 .31961 L
.64947 .3168 L
.64965 .31538 L
.6498 .31384 L
.64985 .31313 L
.6499 .31238 L
.64996 .31103 L
.65 .30974 L
.65 .30852 L
.64997 .30719 L
.64994 .30645 L
.64991 .30576 L
.64983 .30461 L
.64972 .30338 L
.64946 .30117 L
.64904 .29854 L
.64855 .29617 L
.64715 .29102 L
.64539 .28622 L
.64034 .27629 L
.63712 .27144 L
.63307 .26624 L
.61542 .24981 L
.60341 .24186 L
.59118 .23541 L
.57578 .22901 L
Mistroke
.56008 .22407 L
.54448 .22048 L
.53552 .21895 L
.52728 .21786 L
.51948 .2171 L
.51507 .21678 L
.511 .21656 L
.50927 .21649 L
.50742 .21643 L
.50538 .21637 L
.50349 .21634 L
.50135 .21632 L
.49934 .21631 L
.49752 .21632 L
.49556 .21635 L
.49344 .2164 L
.4915 .21646 L
.48714 .21665 L
.48331 .21689 L
.47929 .2172 L
.47081 .21808 L
.46166 .21939 L
.45291 .221 L
.44376 .22307 L
.42792 .22772 L
.41286 .23356 L
.39794 .24108 L
.3854 .2492 L
.37533 .25747 L
.36677 .26642 L
.36029 .27528 L
.35731 .28044 L
.35494 .28542 L
.35278 .29125 L
.35198 .29402 L
.35134 .29664 L
.35085 .29918 L
.35049 .30151 L
.35034 .30275 L
.35021 .30411 L
.35011 .30548 L
.35007 .30623 L
.35004 .30692 L
.35002 .30761 L
.35 .30835 L
.35 .3097 L
.35003 .31101 L
.35009 .31222 L
.35018 .31353 L
.35031 .31497 L
Mistroke
.35069 .31788 L
.35114 .32043 L
.35165 .32275 L
.35316 .32794 L
.35498 .3327 L
.35708 .33716 L
.36299 .34676 L
.37114 .35647 L
.38048 .36503 L
.39022 .37219 L
.40191 .37915 L
.41548 .38561 L
.43163 .39153 L
.4398 .39393 L
.44744 .39584 L
.45124 .39669 L
.45327 .39711 L
.45542 .39753 L
.45731 .39789 L
.46169 .55276 L
.4669 .55306 L
.4718 .55329 L
.47748 .55352 L
.48347 .5537 L
.48858 .55381 L
.49417 .55389 L
.50022 .55391 L
.5036 .5539 L
.50667 .55388 L
.51265 .55379 L
.51829 .55365 L
.52314 .55349 L
.52846 .55328 L
.5392 .55271 L
.54912 .55202 L
.55837 .55124 L
.5791 .54898 L
.6011 .54581 L
.64518 .53688 L
.66926 .53044 L
.69092 .52361 L
.72843 .50913 L
.76571 .49069 L
.79964 .46927 L
.82745 .44692 L
.85036 .42341 L
.86753 .40055 L
.87506 .38803 L
.88187 .37438 L
.88672 .3624 L
Mistroke
.89087 .34925 L
.89282 .34115 L
.89424 .33364 L
.89524 .32645 L
.89562 .32281 L
.89579 .32075 L
.89593 .3188 L
.89612 .31518 L
.89622 .31187 L
.89625 .3083 L
.89622 .30629 L
.89618 .30441 L
.89604 .30099 L
.89584 .29789 L
.89553 .29431 L
.89517 .29094 L
.8942 .28417 L
.89303 .27786 L
.88937 .26359 L
.88451 .24985 L
.87788 .23532 L
.86226 .20978 L
.84407 .18755 L
.81938 .16406 L
.7928 .14401 L
.75764 .12295 L
.72103 .10576 L
.68581 .09272 L
.6456 .08125 L
.62307 .07623 L
.59887 .07187 L
.57788 .0689 L
.55465 .06646 L
.54314 .06558 L
.53707 .0652 L
.53062 .06485 L
.52498 .06461 L
.51877 .0644 L
.51312 .06426 L
.50783 .06417 L
.50231 .06413 L
.49707 .06413 L
.49237 .06417 L
.48724 .06425 L
.48169 .06438 L
.47577 .06458 L
.46516 .06507 L
.45277 .06587 L
.43944 .067 L
.41546 .06976 L
Mistroke
.39243 .07332 L
.3716 .07733 L
.33027 .08773 L
.29365 .09995 L
.2561 .11601 L
.21949 .13605 L
.18856 .15761 L
.15985 .1834 L
.13783 .20966 L
.12971 .22183 L
.12217 .23522 L
.11587 .24892 L
.11124 .26164 L
.10784 .27393 L
.10651 .28015 L
.10536 .28696 L
.10484 .29089 L
.10444 .2946 L
.10416 .29794 L
.10394 .30155 L
.10385 .30343 L
.10379 .3055 L
.10376 .30765 L
.10375 .30967 L
.10381 .31328 L
.10388 .3153 L
.10397 .31715 L
.1042 .32073 L
.1045 .32404 L
.10543 .33153 L
.10656 .33812 L
.10808 .3451 L
.11027 .35326 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[113]:=",
  ImageSize->{270, 166.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>0000YR000`400?l00000o`00003oooooool?
ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?
ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?
ooooo`00ooooool?ooooo`00;oooool3o`0000?ooooo0ol0000>ooooo`?o00001?ooool2o`0001;o
oooo0ol0000Booooo`;o00005?ooool3o`00017ooooo0ol00004ooooo`;o00003oooool3o`0000?o
oooo0ol0000=ooooo`Go00000oooool2o`0003Kooooo000`ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00004?ooool01Ol0003ooooooooooooooooo0000013ooooo00Co0000oooooooooooo00004_oo
ool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000?ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0;oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000=Oooool002Sooooo1Ol00003
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool5o`0000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000:ooooo`Go00001Oooool00ol0003ooooooooo
o`0>ooooo`04o`000?ooooooooooo`0001Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=Oooool0033o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0>ooooo`04o`000?oooooooooo
o`0001Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`0cooooo`00<?ooool01?l0003ooooooooo
ooooool4o`0000oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000@ooooo`Co
00004Oooool01?l0003oooooooooool0000Booooo`Co00004_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000oooooo00Co0000oooooooooooooooo1?l0000=ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0000eooooo`00;oooool2o`0000?ooooo
00?o0000ooooooooool03oooool2o`0000Cooooo00Co0000oooooooooooo00004?ooool00ol0003o
ooooooooo`0Booooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool04_ooool2o`00
00Cooooo00Co0000oooooooooooo00003_ooool2o`0000?ooooo00?o0000ooooooooool03_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000=Oooool0033ooooo00Co
0000oooooooooooooooo1Ol0000>ooooo`03o`000?oooooooooo00?ooooo0_l0000Aooooo`Go0000
4Oooool2o`0001?ooooo1Ol0000Aooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`04o`00
0?ooooooooooooooo`Go00003Oooool3o`0000Cooooo0_l0000fooooo`00ooooool?ooooo`00fooo
ool3o`0000Cooooo0ol00003ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`Go00000_oo
ool3o`0000;ooooo0ol000000ooooooo0000ooooo`03ooooo`00g?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`006_oooonko`0000Oo
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooo`000?ooool00_l00004ooooo`006_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo0ol00002ooooo`05o`000?oooooo
ooooooooool000000oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oooooooooool0003ooooo00;o
00001?ooool001[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Gooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000Kooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`03oooo
o`006_ooool2o`000<3ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo0000ooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l000000ooo
oooo0000ooooo`03ooooo`006_ooool00ol0003oooooooooo`2nooooo`Co00000oooool3o`0000Co
oooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o000000?oooooo`000?l0
00000ol00002ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo000Jooooo`03
o`000?oooooooooo0?7ooooo000Jooooo`;o0000l_ooool001[ooooo00?o0000ooooooooool0lOoo
ool001[ooooo00?o0000ooooooooool0lOooool001[ooooo0_l0003booooo`006_ooool00ol0003o
ooooooooo`3aooooo`006_ooool00ol0003oooooooooo`3aooooo`002?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o0000EOooool<o`00097ooooo0008
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo04Sooooo3?l0000<ooooo`_o0000Q_ooool000Go00001?ooool00ol0003oooooooooo`0:
ooooo`05o`000?ooooooooooooooool00000A_ooool4o`0002?ooooo1Ol00021ooooo`002Oooool0
0ol0003oooooooooo`0:ooooo`04o`000?ooooooooooooooo`;o0000@Oooool4o`0002cooooo1?l0
001mooooo`002_ooool00ol0003oooooooooo`05ooooo`Co00001?ooool00ol0003oooooooooo`0l
ooooo`Co0000=?ooool4o`0007Wooooo0006ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo1?l0000looooo`?o0000M_ooool0
00Kooooo1Ol00007ooooo`Go00000oooool2o`0003Kooooo0ol00013ooooo`Co0000L_ooool001[o
oooo00?o0000ooooooooool0<_ooool3o`0004[ooooo0ol0001_ooooo`006_ooool00ol0003ooooo
ooooo`0_ooooo`?o0000D?ooool3o`0006cooooo000Jooooo`;o0000;_ooool2o`0005Kooooo0ol0
001Yooooo`006_ooool00ol0003oooooooooo`0[ooooo`;o0000Foooool2o`0006Oooooo000Joooo
o`;o0000:oooool00ol0003oooooooooo`1Mooooo`;o0000IOooool001[ooooo00?o0000oooooooo
ool0:?ooool2o`0006;ooooo00?o0000ooooooooool0H_ooool001[ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`1Sooooo`;o0000H_ooool001[ooooo0_l0000Vooooo`;o0000J?oo
ool00ol0003oooooooooo`1Oooooo`004oooool3o`0000Cooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1Yooooo`;o0000Goooool001;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo02;ooooo0_l0001^ooooo`03o`000?oooooooooo05cooooo000<oooo
o`Go00001Oooool01?l0003oooooooooooooool2o`0002;ooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`1Kooooo`005_ooool01Ol0003ooooooooooooooooo000002;ooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1Jooooo`004_ooool4o`0000Cooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1cooooo`;o0000F_ooool001;ooooo00?o0000oooooooo
ool01Oooool2o`0001oooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`1Gooooo`00
4_ooool5o`0000?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo05Kooooo000Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`1Eooooo`006_ooool2o`0001_ooooo0_l0001nooooo`03o`000?oooooo
oooo05Cooooo000Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`1Dooooo`006_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo083o
oooo00?o0000ooooooooool0Doooool001[ooooo0_l0000Hooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0D_ooool001[ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`24ooooo`03o`000?oooooooooo057ooooo000Jooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Q?ooool00ol0003oooooooooo`1Aooooo`001_ooool5o`0000?ooooo00?o0000oooo
ooooool00_ooool3o`0000Cooooo0_l0000Fooooo`03o`000?oooooooooo03[ooooo4ol0000ioooo
o`03o`000?oooooooooo053ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=_ooool4
o`0001?ooooo0ol0000gooooo`03o`000?oooooooooo04oooooo0005o`0000?ooooo00?o0000oooo
ooooool02oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool0<oooool3
o`0001[ooooo0ol0000dooooo`03o`000?oooooooooo04oooooo0009ooooo`03o`000?oooooooooo
00[ooooo00Co0000oooooooooooooooo0_l0000Eooooo`03o`000?oooooooooo03;ooooo0_l0000P
ooooo`;o0000<oooool00ol0003oooooooooo`1>ooooo`001_ooool01Ol0003ooooooooooooooooo
000000Oooooo1?l00004ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<?ooool2
o`0002Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1>ooooo`001_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01Oooool2o`0001Cooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0COooool000Oooooo0ol00008ooooo`Go00000oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02oooooo0_l0000Yooooo`;o0000<?ooool00ol0003oooooooooo`1=oooo
o`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04gooooo000Jooooo`;o0000
4oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`1<ooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo04cooooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Boooool0
01[ooooo0_l0000Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo04_ooooo000Jooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0Boooool001[ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`1;ooooo`005?ooool2o`0000Cooooo0_l0000Aooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04_ooooo000C
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo03Cooooo0_l0000/ooooo`;o0000C?ooool001?ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[ooooo000C
ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Aooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[ooooo000C
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1:ooooo`004oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0dooooo`;o0000;?ooool00ol0003ooooooooo
o`1;ooooo`005?ooool2o`0000Cooooo0_l0000Aooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04_ooooo000Joooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool001[ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`1;ooooo`006_ooool2o`0001;ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
Boooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1;ooooo`006_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04_ooooo000Jooooo`;o0000@oooool2o`00
02gooooo0_l0000_ooooo`03o`000?oooooooooo04cooooo000Jooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04co
oooo000Jooooo`;o0000AOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0C?ooool000Kooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`03o`000?oooooooooo04Gooooo0ol0000Uooooo`;o0000<_ooool00ol0003ooooooooo
o`1=ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`18ooooo`;o00008?ooool3o`0003Cooooo00?o0000ooooooooool0
COooool000Sooooo00?o0000ooooooooool02oooool01?l0003oooooooooooooool2o`0004_ooooo
0ol0000Kooooo`;o0000=_ooool00ol0003oooooooooo`1>ooooo`002Oooool00ol0003ooooooooo
o`0:ooooo`05o`000?ooooooooooooooool00000Coooool2o`0001Kooooo0ol0000hooooo`03o`00
0?oooooooooo04kooooo0006ooooo`05o`000?ooooooooooooooool000001oooool4o`0000Cooooo
00?o0000ooooooooool0Coooool4o`0000oooooo0ol0000jooooo`03o`000?oooooooooo04oooooo
0006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`05ooooo`;o0000
Doooool00ol0003oooooooooo`05ooooo`So0000??ooool00ol0003oooooooooo`1@ooooo`001ooo
ool3o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`1@ooooo`006_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0DOooool001[ooooo0_l0001Cooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0D_ooool001[ooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo05?ooooo000Jooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Cooooo`006_ooool2o`0005?ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`1Dooooo`006_ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0EOooool001[ooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo05Kooooo000Cooooo`?o
00001?ooool2o`0005?ooooo00?o0000ooooooooool0@Oooool2o`0005Wooooo000Booooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool0FOooool001Kooooo00Go0000ooooooooooooooooo`00001Dooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0F_ooool001Kooooo00Co0000oooooooooooo
oooo0_l0001Cooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Foooool001;ooooo
1?l00004ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0??ooool2o`0005kooooo
000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Doooool00ol0003ooooooooo
o`0iooooo`;o0000H?ooool001;ooooo1Ol00003ooooo`;o0000E?ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo063ooooo000Jooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool0=_ooool2o`0006?ooooo000Jooooo`;o0000E?ooool00ol0003oooooooooo`0dooooo`;o
0000IOooool001[ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0aooooo`?o0000
Ioooool001[ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0_ooooo`;o0000J_oo
ool001[ooooo0_l0001Dooooo`03o`000?oooooooooo02gooooo0_l0001/ooooo`006_ooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo02[ooooo0ol0001^ooooo`006_ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo02Sooooo0_l0001aooooo`006_ooool2o`0005Cooooo
00?o0000ooooooooool09Oooool3o`0007?ooooo0008ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0Doooool00ol0003ooooooooo
o`0Qooooo`Co0000M_ooool000Sooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Mooooo`Co0000N_oo
ool000Wooooo00?o0000ooooooooool02_ooool01?l0003oooooooooooooool2o`0005Cooooo00?o
0000ooooooooool06Oooool4o`0007kooooo0009ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`00001Eooooo`03o`000?oooooooooo01Gooooo1?l00022ooooo`002_ooool0
0ol0003oooooooooo`05ooooo`Co00001?ooool00ol0003oooooooooo`1CoooooaSo0000Q_ooool0
00Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Gooooo0_l0003b
ooooo`001_ooool5o`0000Oooooo1Ol00003ooooo`03o`000?oooooooooo0?7ooooo000Jooooo`03
o`000?oooooooooo0?7ooooo000Jooooo`;o0000l_ooool001[ooooo00?o0000ooooooooool0lOoo
ool001[ooooo00?o0000ooooooooool0lOooool001[ooooo0_l0003booooo`006_ooool00ol0003o
ooooooooo`3aooooo`006_ooool00ol0003oooooooooo`3aooooo`003Oooool3o`0000Cooooo0_l0
0004ooooo`;o0000l_ooool000kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo0?7ooooo000>ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000oooool2o`000?;ooooo000>ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000moooool000kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
003gooooo`003Oooool2o`0000Cooooo00Co0000oooooooooooo0000moooool000kooooo00?o0000
ooooooooool00oooool2o`000?Sooooo003oooooo`oooooo003oooooo`oooooo003oooooo`oooooo
003oooooo`oooooo0004ooooo`04o`000?ooooooooooooooo`Go000000?oooooo`000?l000000ol0
0002ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool3o`000=kooooo0004
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Mooooo`001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01ol0
003ooooooooooooooooo0000ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0gOooool000?ooooo00?o0000ooooool000000oooool3
o`0000?ooooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool00000
1oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
gOooool000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo00Wo0000oooooooo
ooooooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooo`00003Nooooo`000oooool0
0ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool02Ol0003o
oooooooooooooooo0000ooooool0003oooooo`000002ooooo`03o`000?oooooo00000=kooooo0002
ooooo`Go000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00004ooooo`?o00001?oo
ool3o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol000001?oooooo0000o`00
0?ooool2o`000=gooooo003oooooo`oooooo003oooooo`oooooo003oooooo`oooooo003oooooo`oo
oooo003oooooo`oooooo003oooooo`oooooo003oooooo`oooooo003oooooo`oooooo003oooooo`oo
oooo003oooooo`oooooo003oooooo`oooooo003oooooo`oooooo003oooooo`oooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 346.875}, {517.125, 351.312}} -> {-42.4062, \
47.1554, 0.215028, 0.173961}}]
}, Open  ]],

Cell[TextData[StyleBox["Applying the Laplace transform method to a linear \
system ", "Subsubsection"]], "Text"],

Cell["\<\
The Laplace transform method can also be applied to a system of \
linear equations  (constant coefficients), driven or undriven. However, if \
the system is driven by discontinuous forcing functions,  the Laplace \
transform solution formulas may contain complex exponentials. Consider the \
following IVP\
\>", "Text"],

Cell[TextData[{
  StyleBox["x' = x",
    FontSlant->"Italic"],
  " - ",
  StyleBox["y",
    FontSlant->"Italic"],
  " + 10 UnitStep(",
  StyleBox["t",
    FontSlant->"Italic"],
  " - 2) \n",
  StyleBox["y'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["x",
    FontSlant->"Italic"],
  " + ",
  StyleBox["y",
    FontSlant->"Italic"],
  "                                    \n",
  StyleBox["x",
    FontSlant->"Italic"],
  "(0) = 1, ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 1                      "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
DEsystem = {x'[t] == x[t] - y[t] + 10*UnitStep[t-2],
            y'[t] == x[t] + y[t] }\
\>", "Input",
  CellLabel->"In[23]:=",
  FormatType->InputForm],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(10\ UnitStep[\(-2\) + t] + x[t] - y[t]\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(x[t] + y[t]\)}]}], "}"}]], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell["\<\
Here is the DSolve solution for the initial conditions x(0) = 1 and \
y(0) = 1.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
DSsoln = DSolve[ Join[DEsystem,{x[0]==1, y[0]==1}], {x[t],y[t]}, t]\
\
\>", "Input",
  CellLabel->"In[24]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{x[
            t] \[Rule] \(\(1\/\[ExponentialE]\^2\)\((\[ExponentialE]\^\(2 + t\
\)\ Cos[t] - \[ExponentialE]\^\(2 + t\)\ Sin[t] + 
              5\ \[ExponentialE]\^t\ Cos[2]\ Cos[t]\ UnitStep[\(-2\) + t] - 
              5\ \[ExponentialE]\^2\ Cos[t]\^2\ UnitStep[\(-2\) + t] - 
              5\ \[ExponentialE]\^t\ Cos[t]\ Sin[2]\ UnitStep[\(-2\) + t] + 
              5\ \[ExponentialE]\^t\ Cos[2]\ Sin[t]\ UnitStep[\(-2\) + t] + 
              5\ \[ExponentialE]\^t\ Sin[2]\ Sin[t]\ UnitStep[\(-2\) + t] - 
              5\ \[ExponentialE]\^2\ Sin[t]\^2\ UnitStep[\(-2\) + t])\)\), 
        y[t] \[Rule] \(\(1\/\[ExponentialE]\^2\)\((\[ExponentialE]\^\(2 + t\)\
\ Cos[t] + \[ExponentialE]\^\(2 + t\)\ Sin[t] - 
              5\ \[ExponentialE]\^t\ Cos[2]\ Cos[t]\ UnitStep[\(-2\) + t] + 
              5\ \[ExponentialE]\^2\ Cos[t]\^2\ UnitStep[\(-2\) + t] - 
              5\ \[ExponentialE]\^t\ Cos[t]\ Sin[2]\ UnitStep[\(-2\) + t] + 
              5\ \[ExponentialE]\^t\ Cos[2]\ Sin[t]\ UnitStep[\(-2\) + t] - 
              5\ \[ExponentialE]\^t\ Sin[2]\ Sin[t]\ UnitStep[\(-2\) + t] + 
              5\ \[ExponentialE]\^2\ Sin[t]\^2\ UnitStep[\(-2\) + 
                    t])\)\)}}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["Is simplifies as follows.", "Text"],

Cell[CellGroupData[{

Cell["DSsoln = Simplify[{x[t],y[t]}/.DSsoln]", "Input",
  CellLabel->"In[25]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{\(\[ExponentialE]\^\(2 + t\)\ \((Cos[t] - Sin[t])\) - 5\ \((\
\[ExponentialE]\^2 - \[ExponentialE]\^t\ Cos[2 - t] + \[ExponentialE]\^t\ \
Sin[2 - t])\)\ UnitStep[\(-2\) + t]\)\/\[ExponentialE]\^2, \
\(\[ExponentialE]\^\(2 + t\)\ \((Cos[t] + Sin[t])\) - 5\ \
\((\(-\[ExponentialE]\^2\) + \[ExponentialE]\^t\ Cos[2 - t] + \[ExponentialE]\
\^t\ Sin[2 - t])\)\ UnitStep[\(-2\) + t]\)\/\[ExponentialE]\^2}}\)], "Output",\

  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "The Laplace transform solution will arrive in complex form. See below.\n",
  StyleBox["Transform the system",
    FontVariations->{"Underline"->True}]
}], "Text"],

Cell[CellGroupData[{

Cell["LaplaceTransform[DEsystem, t, s ]", "Input",
  CellLabel->"In[40]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({s\ LaplaceTransform[x[t], t, s] - 
          x[0] \[Equal] \(10\ \[ExponentialE]\^\(\(-2\)\ s\)\)\/s + 
          LaplaceTransform[x[t], t, s] - LaplaceTransform[y[t], t, s], 
      s\ LaplaceTransform[y[t], t, s] - y[0] \[Equal] 
        LaplaceTransform[x[t], t, s] + 
          LaplaceTransform[y[t], t, s]}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[TextData[StyleBox["Substitute the initial values and X and Y for the \
transforms of the solution",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[CellGroupData[{

Cell["\<\
%/.{x[0]->1,y[0]->1,LaplaceTransform[x[t],t,s]->X,LaplaceTransform[\
y[t],t,s]->Y}\
\>", "Input",
  CellLabel->"In[41]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({\(-1\) + s\ X \[Equal] \(10\ \[ExponentialE]\^\(\(-2\)\ s\)\)\/s + X - 
          Y, \(-1\) + s\ Y \[Equal] X + Y}\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[TextData[StyleBox["Solve for X and Y",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[CellGroupData[{

Cell["Tsoln = Solve[%,{X,Y}]", "Input",
  CellLabel->"In[42]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{X \[Rule] \(-1\) + \(\((1 - s)\)\ \((\(10\ \[ExponentialE]\^\(\(-2\)\ \
s\)\)\/s + s)\)\)\/\(\(-1\) - \((\(-1\) + s)\)\^2\), 
        Y \[Rule] \(-\(\(\(10\ \[ExponentialE]\^\(\(-2\)\ s\)\)\/s + 
                  s\)\/\(\(-1\) - \((\(-1\) + s)\)\^2\)\)\)}}\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Invert to obtain the solution trajectory",
    FontVariations->{"Underline"->True}],
  " (Note that the solution is in terms of complex exponentials)"
}], "Text"],

Cell[CellGroupData[{

Cell["Lsoln = InverseLaplaceTransform[{X,Y}/.%, s, t]", "Input",
  CellLabel->"In[43]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{\((1\/2 + \[ImaginaryI]\/2)\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\((\((2 - 2\ \[ImaginaryI])\) + t)\)\)\ \((\[ExponentialE]\^\(\((2 + 2\ \
\[ImaginaryI])\) + t\)\ \((\(-\[ImaginaryI]\) + \[ExponentialE]\^\(2\ \
\[ImaginaryI]\ t\))\) + 
              5\ \((\((\(-1\) + \[ImaginaryI])\)\ \[ExponentialE]\^\(\((2 + 2\
\ \[ImaginaryI])\) + \[ImaginaryI]\ t\) - \[ImaginaryI]\ \
\[ExponentialE]\^\(\((1 + 2\ \[ImaginaryI])\)\ t\) + \[ExponentialE]\^\(4\ \
\[ImaginaryI] + t\))\)\ UnitStep[\(-2\) + 
                    t])\), \((1\/2 - \[ImaginaryI]\/2)\)\ \[ExponentialE]\^\(\
\((1 - \[ImaginaryI])\)\ t\)\ \((\[ImaginaryI] + \[ExponentialE]\^\(2\ \
\[ImaginaryI]\ t\))\) - \((5\/2 + \(5\ \[ImaginaryI]\)\/2)\)\ \((\((\(-1\) + \
\[ImaginaryI])\) - \[ImaginaryI]\ \[ExponentialE]\^\(\((1 - \[ImaginaryI])\)\ \
\((\(-2\) + t)\)\) + \[ExponentialE]\^\(\((1 + \[ImaginaryI])\)\ \((\(-2\) + \
t)\)\))\)\ UnitStep[\(-2\) + t]}}\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[TextData[{
  "The function called ",
  StyleBox["ComplexExpand",
    FontWeight->"Bold"],
  " will change the complex exponentials to Cartesian form, but the output is \
very long. We suppress it, then ",
  StyleBox["Simplify",
    FontWeight->"Bold"],
  ". Compare the output to the simplified DSolve solution shown above."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
ComplexExpand[Lsoln];
Simplify[%]\
\>", "Input",
  CellLabel->"In[44]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({{\(\[ExponentialE]\^\(2 + t\)\ \((Cos[t] - Sin[t])\) - 5\ \((\
\[ExponentialE]\^2 - \[ExponentialE]\^t\ Cos[2 - t] + \[ExponentialE]\^t\ \
Sin[2 - t])\)\ UnitStep[\(-2\) + t]\)\/\[ExponentialE]\^2, \
\(\[ExponentialE]\^\(2 + t\)\ \((Cos[t] + Sin[t])\) - 5\ \
\((\(-\[ExponentialE]\^2\) + \[ExponentialE]\^t\ Cos[2 - t] + \[ExponentialE]\
\^t\ Sin[2 - t])\)\ UnitStep[\(-2\) + t]\)\/\[ExponentialE]\^2}}\)], "Output",\

  CellLabel->"Out[45]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Plot of the solution trajectory",
    FontSlant->"Italic"],
  "\nThe solution trajectory is plotted below along with a point plotted for \
every quarter unit of time. See if you can identify  the point where the \
UnitStep driver starts to have an effect on the output.  "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[ \
ListPlot[Table[DSsoln[[1]],{t,0,4,1/4}],PlotStyle->PointSize[0.02]],
      ParametricPlot[ DSsoln, {t,0,4}, PlotStyle->RGBColor[0,1,0]],
   AspectRatio->1/1, PlotRange->{{-15,25},{-25,5}}, 
   AxesOrigin->{-15,-25}, AxesLabel->{\"x\",\"y\"} ]\
\>", "Input",
  CellLabel->"In[68]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.375 0.025 0.833333 0.0333333 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -3 -9 ]
[.375 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -6 -9 ]
[.625 -0.0125 6 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -6 -9 ]
[.875 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .16667 -18 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -18 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -18 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -12 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -6 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[0 1.025 -5 0 ]
[0 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-10)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(10)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(15)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(20)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(25)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .16667 m
.00625 .16667 L
s
[(-20)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(-15)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(-10)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(-5)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(0)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
0 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.4 .86667 Mdot
.39816 .88539 Mdot
.39141 .90791 Mdot
.37765 .93307 Mdot
.35453 .95853 Mdot
.31971 .98043 Mdot
.27116 .99292 Mdot
.2078 .98789 Mdot
.13016 .9548 Mdot
.11167 .893 Mdot
.1034 .80829 Mdot
.11328 .6994 Mdot
.15153 .56811 Mdot
.23039 .42097 Mdot
.36356 .27132 Mdot
.5649 .14155 Mdot
.8463 .06537 Mdot
0 1 0 r
.5 Mabswid
.4 .86667 m
.4 .867 L
.4 .8673 L
.39999 .86765 L
.39999 .86798 L
.39998 .86858 L
.39996 .86923 L
.39994 .86995 L
.39991 .87073 L
.39984 .87214 L
.39974 .87363 L
.39962 .87504 L
.39927 .87836 L
.39878 .88187 L
.3982 .88519 L
.39642 .89303 L
.39426 .90025 L
.39117 .90849 L
.38254 .92553 L
.37044 .94248 L
.3626 .95105 L
.35271 .96007 L
.33016 .97529 L
.31674 .98171 L
.30929 .98458 L
.30085 .9873 L
.29246 .98948 L
.28442 .99112 L
.28042 .99178 L
.27597 .99239 L
.272 .99284 L
.26763 .99321 L
.2652 .99337 L
.26295 .99349 L
.26078 .99358 L
.25968 .99361 L
.25847 .99364 L
.25777 .99366 L
.25711 .99367 L
.25587 .99368 L
.25517 .99368 L
.25453 .99368 L
.25382 .99368 L
.25306 .99367 L
.25181 .99366 L
.25063 .99364 L
.24933 .9936 L
.24792 .99356 L
.24511 .99343 L
.24201 .99324 L
Mistroke
.23627 .99276 L
.23057 .99211 L
.22518 .99135 L
.213 .98908 L
.20113 .98617 L
.17787 .97851 L
.16511 .97322 L
.15126 .96661 L
.14446 .96304 L
.13794 .9594 L
.13508 .95775 L
.13203 .95593 L
.13044 .95497 L
.12978 .95389 L
.12937 .9529 L
.12899 .95197 L
.12566 .94335 L
.12224 .93354 L
.11656 .91426 L
.11119 .89057 L
.10731 .86653 L
.10573 .85284 L
.1046 .83954 L
.1041 .83162 L
.10376 .82428 L
.10362 .82014 L
.10356 .81794 L
.1035 .81561 L
.10346 .81355 L
.10343 .81127 L
.1034 .80919 L
.10339 .80724 L
.10338 .80518 L
.10338 .80414 L
.10338 .80298 L
.10339 .80094 L
.10341 .79901 L
.10342 .7979 L
.10344 .79673 L
.10347 .79463 L
.10359 .78985 L
.10372 .78566 L
.10387 .78173 L
.10433 .77267 L
.10489 .76428 L
.10551 .75652 L
.10735 .73865 L
.10994 .71942 L
.11297 .7011 L
.12237 .65768 L
Mistroke
.13419 .61632 L
.15134 .56859 L
.19938 .47006 L
.26709 .37167 L
.31086 .32179 L
.3666 .26868 L
.4935 .17839 L
.56887 .13974 L
.61085 .12212 L
.65889 .10501 L
.70582 .09122 L
.75113 .08045 L
.7964 .07205 L
.8463 .06537 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{211, 211},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003C0000db000`400?l00000o`00003odoooool0
0=?ooooo003Cooooo`00doooool00=?ooooo000Xooooo`?o00001?ooool2o`00013ooooo0ol0000@
ooooo`;o00004oooool3o`00013ooooo0ol00004ooooo`;o00003Oooool3o`0000?ooooo0ol0000<
ooooo`Go00000oooool2o`0000cooooo1Ol00002ooooo`?o00003?ooool002Wooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000>ooooo`05o`000?ooooooooooooooool000003_oo
ool01?l0003oooooooooool0000Aooooo`05o`000?ooooooooooooooool000004?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000<ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`09oooo
o`008Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008oooo
o`Go00001Oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
000Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool002Wooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000>ooooo`Co00003oooool01?l0003oooooooooool0
000Aooooo`Co00004Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000gooooo
00Co0000oooooooooooooooo1?l0000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000;ooooo`06o`000?ooooooooooooooool0003ooooo1?l0000<ooooo`00:?oo
ool2o`0000Cooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0@ooooo`04o`00
0?ooooooooooo`00017ooooo00?o0000ooooooooool04Oooool2o`0000Cooooo00Co0000oooooooo
oooo00003?ooool2o`0000?ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00002oooool01ol0003ooooooooooooooooo0000ooooool0
00003oooool002Wooooo00?o0000ooooooooool00oooool2o`0000oooooo1Ol0000?ooooo`;o0000
4_ooool5o`00013ooooo00?o0000ooooooooool00oooool2o`0000kooooo00Co0000oooooooooooo
oooo1Ol0000<ooooo`?o00001?ooool2o`0000gooooo0ol00002ooooo`Go00002oooool00=?ooooo
003:ooooo`;o000000?oooooo`000?l000001?ooool00<_ooooo00?o0000ooooool000001Oooool0
01Cooooo/?l00008ooooo`03o`000?oooooooooo00Cooooo000Dooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`000005ooooo`005?ooool00ol0003oooooooooo`2cooooo`;o
000000?oooooo`000?l000001?ooool001Cooooo00?o0000ooooooooool0_?ooool001Cooooo00?o
0000ooooooooool0_?ooool001Cooooo00?o0000ooooooooool0_?ooool001Cooooo00?o0000oooo
ooooool0_?ooool001Cooooo00?o0000ooooooooool0_?ooool001Cooooo00?o0000ooooooooool0
_?ooool001Cooooo00?o0000ooooooooool0_?ooool001Cooooo00?o0000ooooooooool0_?ooool0
01Cooooo00?o0000ooooooooool0T?ooool3o`0002Wooooo000Dooooo`03o`000?oooooooooo08go
oooo1Ol0o`000ol0003oooooooooo`0Wooooo`005?ooool00ol0003oooooooooo`24ooooo`Wo0?l0
0oooool3o`0002Wooooo000Dooooo`03o`000?oooooooooo07kooooo1_l0o`0hooooo`005?ooool0
0ol0003oooooooooo`1kooooo`?o0?l0?_ooool001Cooooo00?o0000ooooooooool0N?ooool3o`3o
047ooooo000Dooooo`03o`000?oooooooooo07Gooooo0ol0o`14ooooo`005?ooool00ol0003ooooo
ooooo`1booooo`?o0?l0Aoooool001Cooooo00?o0000ooooooooool0Koooool3o`3o04[ooooo000D
ooooo`03o`000?oooooooooo06cooooo0ol0o`1=ooooo`005?ooool00ol0003oooooooooo`1Yoooo
o`?o0?l0D?ooool001Cooooo00?o0000ooooooooool0Ioooool2o`3o05?ooooo000Dooooo`03o`00
0?oooooooooo06Cooooo0ol0o`1Eooooo`005?ooool00ol0003oooooooooo`1Oooooo`;o00000ol0
o`1Hooooo`005?ooool00ol0003oooooooooo`1Oooooo`;o0?l000?o0000ooooooooool0F?ooool0
01Cooooo00?o0000ooooooooool0GOooool2o`3o00?o0000F_ooool000Kooooo1Ol00003ooooo`;o
00001?ooool00ol0003oooooooooo`1Kooooo`;o0?l0Goooool000Oooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo05Sooooo0ol0o`1Qoooo
o`001Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool2o`00
05Oooooo0_l0o`1Tooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`00001Fooooo`;o0?l0I_ooool000Kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0D_ooool2o`3o06Sooooo0006
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo057ooooo00?o0?l0ooooooooool0J?ooool000Oooooo0ol00004ooooo`;o00001?oo
ool00ol0003oooooooooo`1@ooooo`03o`3o0?oooooooooo06Wooooo000Dooooo`03o`000?oooooo
oooo04kooooo0_l0o`1/ooooo`005?ooool00ol0003oooooooooo`1=ooooo`03o`3o0?oooooooooo
06cooooo000Dooooo`03o`000?oooooooooo04_ooooo0_l0o`1_ooooo`005?ooool00ol0003ooooo
ooooo`1:ooooo`03o`3o0?oooooooooo06oooooo000Dooooo`03o`000?oooooooooo04Wooooo00?o
0?l0ooooooooool0L?ooool001Cooooo00?o0000ooooooooool0Aoooool2o`3o07?ooooo000Doooo
o`03o`000?oooooooooo04Kooooo00?o0?l0ooooooooool0Loooool001Cooooo00?o0000oooooooo
ool0AOooool00ol0o`3oooooooooo`1dooooo`005?ooool00ol0003oooooooooo`13ooooo`;o0?l0
Moooool001Cooooo00?o0000ooooooooool0@_ooool00ol0o`3oooooooooo`1gooooo`005?ooool0
0ol0003oooooooooo`10ooooo`;o0?l0N_ooool001Cooooo00?o0000ooooooooool0?oooool00ol0
o`3oooooooooo`1jooooo`005?ooool00ol0003oooooooooo`0nooooo`03o`3o0?oooooooooo07_o
oooo000Dooooo`03o`000?oooooooooo03_ooooo0_l000000ol0o`3oooooooooo`1looooo`005?oo
ool00ol0003oooooooooo`0kooooo`03o`000?l0o`3o000007kooooo000Dooooo`03o`000?oooooo
oooo03_ooooo00?o0?l0o`000?l00000O_ooool001Cooooo00?o0000ooooooooool0>_ooool00ol0
o`3oooooooooo`1oooooo`005?ooool00ol0003oooooooooo`0iooooo`03o`3o0?oooooooooo083o
oooo000Dooooo`03o`000?oooooooooo03Sooooo00?o0?l0ooooooooool0POooool001Cooooo00?o
0000ooooooooool0=oooool00ol0o`3oooooooooo`22ooooo`005?ooool00ol0003oooooooooo`0f
ooooo`03o`3o0?oooooooooo08?ooooo000Dooooo`03o`000?oooooooooo03Gooooo00?o0?l0oooo
ooooool0Q?ooool000Oooooo0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`0dooooo`03
o`3o0?oooooooooo08Gooooo0008ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000003Gooooo00?o0?l0ooooooooool0Q_ooool000Go00000oooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool00000=Oooool00ol0o`3oooooooooo`26oooo
o`002?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o0000<oooool00ol0
o`3oooooooooo`27ooooo`002?ooool01?l0003oooooooooooooool4o`0000Cooooo00?o0000oooo
ooooool0<Oooool00ol0o`3oooooooooo`28ooooo`001oooool2o`0000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0`ooooo`03o`3o0?oooooooooo08Wooooo0008ooooo`04o`00
0?ooooooooooooooo`Go00000oooool00ol0003oooooooooo`0_ooooo`03o`3o0?oooooooooo08[o
oooo000Dooooo`03o`000?oooooooooo02kooooo00?o0?l0ooooooooool0Roooool001Cooooo00?o
0000ooooooooool0;Oooool00ol0o`3oooooooooo`2<ooooo`005?ooool00ol0003oooooooooo`0/
ooooo`03o`3o0?oooooooooo08gooooo000Dooooo`03o`000?oooooooooo02cooooo00?o0?l0oooo
ooooool0SOooool001Cooooo00?o0000ooooooooool0:oooool00ol0o`3oooooooooo`2>ooooo`00
5?ooool00ol0003oooooooooo`0Zooooo`03o`3o0?oooooooooo08oooooo000Dooooo`03o`000?oo
oooooooo02[ooooo00?o0?l0ooooooooool0Soooool001Cooooo00?o0000ooooooooool0:Oooool0
0ol0o`3oooooooooo`2@ooooo`005?ooool00ol0003oooooooooo`0Xooooo`03o`3o0?oooooooooo
097ooooo000Dooooo`03o`000?oooooooooo02Sooooo00?o0?l0ooooooooool0TOooool001Cooooo
00?o0000ooooooooool09?ooool3o`000003o`3o0?oooooooooo09;ooooo000Dooooo`03o`000?oo
oooooooo02Cooooo0_l000000ol0o`3oooooooooo`2Cooooo`005?ooool00ol0003oooooooooo`0T
ooooo`;o000000?o0?l0ooooooooool0Toooool001Cooooo00?o0000ooooooooool09Oooool00ol0
o`3oooooooooo`2Dooooo`005?ooool00ol0003oooooooooo`0Tooooo`03o`3o0?oooooooooo09Go
oooo000Dooooo`03o`000?oooooooooo02Cooooo00?o0?l0ooooooooool0UOooool001Cooooo00?o
0000ooooooooool08oooool00ol0o`3oooooooooo`2Fooooo`005?ooool00ol0003oooooooooo`0R
ooooo`03o`3o0?oooooooooo09Oooooo000Dooooo`03o`000?oooooooooo02;ooooo00?o0?l0oooo
ooooool0Uoooool001Cooooo00?o0000ooooooooool08Oooool00ol0o`3oooooooooo`2Hooooo`00
5?ooool00ol0003oooooooooo`0Pooooo`03o`3o0?oooooooooo09Wooooo000Dooooo`03o`000?oo
oooooooo023ooooo00?o0?l0ooooooooool0VOooool000Oooooo0ol00004ooooo`;o00001?ooool0
0ol0003oooooooooo`0Oooooo`03o`3o0?oooooooooo09[ooooo0008ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Oooooo`03o`3o0?oooooo
oooo09[ooooo0005o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo01kooooo00?o0?l0ooooooooool0Voooool000Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`;o00007oooool00ol0o`3oooooooooo`2K
ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool07Oooool00ol0o`3oooooooooo`2Looooo`001oooool2o`0000Cooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`0Mooooo`03o`3o0?oooooooooo09cooooo0008oooo
o`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo01cooooo00?o0?l0oooo
ooooool0WOooool001Cooooo00?o0000ooooooooool06oooool00ol0o`3oooooooooo`2Nooooo`00
5?ooool00ol0003oooooooooo`0Kooooo`03o`3o0?oooooooooo09kooooo000Dooooo`03o`000?oo
oooooooo01[ooooo00?o0?l0ooooooooool0Woooool001Cooooo00?o0000ooooooooool06_ooool0
0ol0o`3oooooooooo`2Oooooo`005?ooool00ol0003oooooooooo`0Iooooo`03o`3o0?oooooooooo
0:3ooooo000Dooooo`03o`000?oooooooooo01Wooooo00?o0?l0ooooooooool0X?ooool001Cooooo
00?o0000ooooooooool06?ooool00ol0o`3oooooooooo`2Qooooo`005?ooool00ol0003ooooooooo
o`0Fooooo`;o000000?o0?l0ooooooooool0XOooool001Cooooo00?o0000ooooooooool05_ooool0
0ol0003o0?l0o`00002Sooooo`005?ooool00ol0003oooooooooo`0Fooooo`03o`000?l0o`3o0000
0:?ooooo000Dooooo`03o`000?oooooooooo01Kooooo00?o0?l0ooooooooool0Xoooool001Cooooo
00?o0000ooooooooool05_ooool00ol0o`3oooooooooo`2Sooooo`005?ooool00ol0003ooooooooo
o`0Fooooo`03o`3o0?oooooooooo0:?ooooo000Dooooo`03o`000?oooooooooo01Gooooo00?o0?l0
ooooooooool0Y?ooool001Cooooo00?o0000ooooooooool05Oooool00ol0o`3oooooooooo`2Toooo
o`005?ooool00ol0003oooooooooo`0Eooooo`03o`3o0?oooooooooo0:Cooooo000Dooooo`03o`00
0?oooooooooo01Cooooo00?o0?l0ooooooooool0YOooool001Cooooo00?o0000ooooooooool05?oo
ool00ol0o`3oooooooooo`2Uooooo`005?ooool00ol0003oooooooooo`0Dooooo`03o`3o0?oooooo
oooo0:Gooooo000Dooooo`03o`000?oooooooooo01?ooooo00?o0?l0ooooooooool0Y_ooool001Co
oooo00?o0000ooooooooool04oooool00ol0o`3oooooooooo`2Vooooo`005?ooool00ol0003ooooo
ooooo`0Cooooo`03o`3o0?oooooooooo0:Kooooo000Dooooo`03o`000?oooooooooo01?ooooo00?o
0?l0ooooooooool0Y_ooool000gooooo0ol00004ooooo`03o`000?oooooooooo01;ooooo00?o0?l0
ooooooooool0Yoooool000cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo01;ooooo00?o0?l0ooooooooool0Yoooool000Kooooo1Ol00005ooooo`04o`000?oooooooooo
ooooo`;o00004oooool00ol0o`3oooooooooo`2Wooooo`004?ooool01Ol0003ooooooooooooooooo
000001Cooooo00?o0?l0ooooooooool0Yoooool000cooooo1?l00004ooooo`03o`000?oooooooooo
01;ooooo00?o0?l0ooooooooool0Yoooool000cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`03o`3o0?oooooooooo0:Sooooo000<ooooo`Go00000oooool00ol0003ooooo
ooooo`0Aooooo`03o`3o0?oooooooooo0:Sooooo000Dooooo`03o`000?oooooooooo00oooooo0_l0
00000ol0o`3oooooooooo`2Xooooo`005?ooool00ol0003oooooooooo`0?ooooo`;o000000?o0?l0
ooooooooool0Z?ooool001Cooooo00?o0000ooooooooool03oooool2o`000003o`3o0?oooooooooo
0:Sooooo000Dooooo`03o`000?oooooooooo013ooooo00?o0?l0ooooooooool0ZOooool001Cooooo
00?o0000ooooooooool04?ooool00ol0o`3oooooooooo`2Yooooo`005?ooool00ol0003ooooooooo
o`0@ooooo`03o`3o0?oooooooooo0:Wooooo000Dooooo`03o`000?oooooooooo013ooooo00?o0?l0
ooooooooool0ZOooool001Cooooo00?o0000ooooooooool04?ooool00ol0o`3oooooooooo`2Yoooo
o`005?ooool00ol0003oooooooooo`0@ooooo`03o`3o0?oooooooooo0:Wooooo000Dooooo`03o`00
0?oooooooooo013ooooo00?o0?l0ooooooooool0ZOooool001Cooooo00?o0000ooooooooool03ooo
ool00ol0o`3oooooooooo`2Zooooo`005?ooool00ol0003oooooooooo`0?ooooo`03o`3o0?oooooo
oooo0:[ooooo000Dooooo`03o`000?oooooooooo00oooooo00?o0?l0ooooooooool0Z_ooool001Co
oooo00?o0000ooooooooool03oooool00ol0o`3oooooooooo`2Zooooo`005?ooool00ol0003ooooo
ooooo`0?ooooo`03o`3o0?oooooooooo0:[ooooo000Dooooo`03o`000?oooooooooo00oooooo00?o
0?l0ooooooooool0Z_ooool001Cooooo00?o0000ooooooooool03oooool00ol0o`3oooooooooo`2Z
ooooo`005?ooool00ol0003oooooooooo`0?ooooo`03o`3o0?oooooooooo0:[ooooo000Dooooo`03
o`000?oooooooooo00oooooo00?o0?l0ooooooooool0Z_ooool001Cooooo00?o0000ooooooooool0
3_ooool00ol0003o0?l0o`00002[ooooo`005?ooool00ol0003oooooooooo`0>ooooo`03o`000?l0
o`3o00000:_ooooo000Dooooo`03o`000?oooooooooo00kooooo00?o0000o`3o0?l00000Zoooool0
00kooooo0_l00004ooooo`03o`000?oooooooooo00oooooo00?o0?l0ooooooooool0Z_ooool000go
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0?ooooo`03o`3o0?oooooooooo
0:[ooooo000=ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000@ooooo`03o`3o0?oooooooooo
0:[ooooo000=ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03oooool00ol0
o`3oooooooooo`2Zooooo`003Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00oooooo00?o0?l0ooooooooool0Z_ooool000gooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0?ooooo`03o`3o0?oooooooooo0:[ooooo000>ooooo`;o00001?ooool00ol0003o
ooooooooo`0?ooooo`03o`3o0?oooooooooo0:[ooooo000Dooooo`03o`000?oooooooooo00oooooo
00?o0?l0ooooooooool0<?ooool3o`0007Oooooo000Dooooo`03o`000?oooooooooo013ooooo00?o
0?l0ooooooooool0;oooool00ol0003o0?l0o`00001gooooo`005?ooool00ol0003oooooooooo`0@
ooooo`03o`3o0?oooooooooo02oooooo00?o0000o`3o0?l00000Moooool001Cooooo00?o0000oooo
ooooool04?ooool00ol0o`3oooooooooo`0`ooooo`03o`3o0?oooooooooo07Kooooo000Dooooo`03
o`000?oooooooooo013ooooo00?o0?l0ooooooooool0;_ooool2o`000003o`3o0?oooooooooo07Ko
oooo000Dooooo`03o`000?oooooooooo00oooooo00?o0000o`3o0?l00000;oooool2o`000003o`3o
0?oooooooooo07Kooooo000Dooooo`03o`000?oooooooooo00oooooo00?o0000o`3o0?l00000;ooo
ool00ol0003o0?l0o`00001hooooo`005?ooool00ol0003oooooooooo`0?ooooo`03o`000?l0o`3o
0000033ooooo00?o0?l0ooooooooool0Moooool001Cooooo00?o0000ooooooooool04Oooool00ol0
o`3oooooooooo`0/ooooo`;o000000?o0?l0ooooooooool0Moooool001Cooooo00?o0000oooooooo
ool04Oooool00ol0o`3oooooooooo`0/ooooo`03o`000?l0o`3o000007Wooooo000Dooooo`03o`00
0?oooooooooo017ooooo00?o0?l0ooooooooool0;?ooool00ol0003o0?l0o`00001iooooo`005?oo
ool00ol0003oooooooooo`0Aooooo`03o`3o0?oooooooooo02cooooo00?o0?l0ooooooooool0NOoo
ool001Cooooo00?o0000ooooooooool04_ooool00ol0o`3oooooooooo`0Yooooo`;o000000?o0?l0
ooooooooool0NOooool001Cooooo00?o0000ooooooooool04_ooool00ol0o`3oooooooooo`0Yoooo
o`;o000000?o0?l0ooooooooool0NOooool001Cooooo00?o0000ooooooooool04_ooool00ol0o`3o
ooooooooo`0Yooooo`03o`000?l0o`3o000007_ooooo000Dooooo`03o`000?oooooooooo01?ooooo
00?o0?l0ooooooooool09oooool2o`3o07gooooo000Dooooo`03o`000?oooooooooo01;ooooo00?o
0000o`3o0?l000009oooool00ol0o`3oooooooooo`1mooooo`005?ooool00ol0003oooooooooo`0B
ooooo`04o`000?l0o`3o0?l0o`3o02Cooooo0_l000000ol0o`3oooooooooo`1mooooo`005?ooool0
0ol0003oooooooooo`0Booooo`?o000000?oooooo`3o0?ooool08_ooool2o`3o0003o`000?oooooo
oooo07gooooo000Dooooo`03o`000?oooooooooo01Oooooo0ol0o`0Nooooo`;o0?l00ol0001ooooo
o`005?ooool00ol0003oooooooooo`0Jooooo`;o0?l06?ooool2o`0000;o0?l0Q?ooool001Cooooo
00?o0000ooooooooool07?ooool3o`3o01Gooooo0_l0o`000ol0003oooooooooo`23ooooo`003Ooo
ool3o`0000Cooooo00?o0000ooooooooool07oooool3o`3o0003o`000?oooooooooo00cooooo0ol0
o`03o`0008Gooooo000<ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Pooooo`;o00003ol0o`2;ooooo`004?ooool01Ol0003ooooooooooooooooo000002;ooooo0ol0
0006ooooo`;o0?l00ol0002>ooooo`004?ooool01?l0003oooooooooooooool2o`0002cooooo0ol0
002>ooooo`003?ooool4o`000<?ooooo000<ooooo`03o`000?oooooooooo0<Cooooo000<ooooo`Go
0000`_ooool00=?ooooo003Cooooo`004Oooool3o`000;oooooo000Booooo`03o`000?oooooooooo
0;kooooo000Cooooo`03o`000?oooooooooo0;gooooo000Cooooo`03o`000?oooooooooo0;gooooo
000Booooo`03o`000?oooooo00000;kooooo000Booooo`03o`000?oooooo00000;kooooo000Aoooo
o`;o000000?oooooo`000?l00000_Oooool00=?ooooo003Cooooo`00doooool00=?ooooo003Coooo
o`00doooool00=?ooooo0000\
\>"],
  ImageRangeCache->{{{77.875, 287.875}, {332.875, 122.875}} -> {-37.362, \
-6.49902, 0.228024, 0.171018}}]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1235}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{707, 794},
WindowMargins->{{4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->112,
PrintingPageRange->{1, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], "     Page ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{Automatic, Automatic},
"PageSize"->{Automatic, Automatic},
"PageHeaderMargins"->{Automatic, Automatic},
"PageFooterMargins"->{Automatic, Automatic},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->False,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
CellFrame->False,
ShowCellBracket->True,
ShowGroupOpenCloseIcon->False,
ShowClosedCellArea->False,
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 208, 6, 66, "Text"],
Cell[1965, 59, 363, 8, 68, "Text"],
Cell[2331, 69, 107, 1, 28, "Text"],
Cell[2441, 72, 365, 12, 48, "Text"],
Cell[2809, 86, 140, 3, 28, "Text"],
Cell[2952, 91, 92, 3, 28, "Text"],
Cell[3047, 96, 162, 6, 28, "Text"],
Cell[3212, 104, 420, 14, 60, "Text"],

Cell[CellGroupData[{
Cell[3657, 122, 109, 2, 31, "Input"],
Cell[3769, 126, 130, 3, 48, "Output"]
}, Open  ]],
Cell[3914, 132, 148, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[4087, 141, 113, 2, 31, "Input"],
Cell[4203, 145, 195, 4, 45, "Output"]
}, Open  ]],
Cell[4413, 152, 223, 8, 28, "Text"],

Cell[CellGroupData[{
Cell[4661, 164, 110, 2, 31, "Input"],
Cell[4774, 168, 151, 3, 54, "Output"]
}, Open  ]],
Cell[4940, 174, 209, 7, 28, "Text"],

Cell[CellGroupData[{
Cell[5174, 185, 117, 2, 31, "Input"],
Cell[5294, 189, 137, 3, 49, "Output"]
}, Open  ]],
Cell[5446, 195, 127, 3, 60, "Text"],
Cell[5576, 200, 143, 5, 48, "Text"],
Cell[5722, 207, 36, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[5783, 211, 156, 4, 51, "Input"],
Cell[5942, 217, 17580, 842, 135, 9796, 741, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[23537, 1062, 331, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[23893, 1072, 141, 5, 51, "Input"],
Cell[24037, 1079, 16798, 535, 125, 5545, 391, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[40850, 1617, 463, 13, 28, "Text"],

Cell[CellGroupData[{
Cell[41338, 1634, 141, 5, 51, "Input"],
Cell[41482, 1641, 98, 2, 27, "Output"]
}, Open  ]],
Cell[41595, 1646, 172, 4, 48, "Text"],
Cell[41770, 1652, 126, 2, 28, "Text"],
Cell[41899, 1656, 364, 10, 48, "Text"],

Cell[CellGroupData[{
Cell[42288, 1670, 204, 5, 91, "Input"],
Cell[42495, 1677, 22878, 1068, 79, 14803, 963, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[65388, 2748, 60, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[65473, 2752, 67, 1, 31, "Input"],
Cell[65543, 2755, 212, 4, 49, "Output"]
}, Open  ]],
Cell[65770, 2762, 257, 11, 28, "Text"],

Cell[CellGroupData[{
Cell[66052, 2777, 73, 1, 31, "Input"],
Cell[66128, 2780, 286, 8, 27, "Output"]
}, Open  ]],
Cell[66429, 2791, 45, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[66499, 2795, 91, 1, 31, "Input"],
Cell[66593, 2798, 803, 13, 273, "Output"]
}, Open  ]],
Cell[67411, 2814, 47, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[67483, 2818, 88, 2, 31, "Input"],
Cell[67574, 2822, 402, 8, 113, "Output"]
}, Open  ]],
Cell[67991, 2833, 203, 5, 60, "Text"],

Cell[CellGroupData[{
Cell[68219, 2842, 66, 1, 31, "Input"],
Cell[68288, 2845, 610, 14, 91, "Output"]
}, Open  ]],
Cell[68913, 2862, 167, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[69105, 2871, 93, 1, 31, "Input"],
Cell[69201, 2874, 264, 5, 49, "Output"]
}, Open  ]],
Cell[69480, 2882, 86, 1, 28, "Text"],

Cell[CellGroupData[{
Cell[69591, 2887, 52, 1, 31, "Input"],
Cell[69646, 2890, 299, 5, 53, "Output"]
}, Open  ]],
Cell[69960, 2898, 185, 4, 28, "Text"],

Cell[CellGroupData[{
Cell[70170, 2906, 100, 2, 31, "Input"],
Cell[70273, 2910, 396, 7, 122, "Output"]
}, Open  ]],
Cell[70684, 2920, 340, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[71049, 2930, 111, 4, 31, "Input"],
Cell[71163, 2936, 40731, 1465, 121, 18234, 1182, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[111909, 4404, 108, 2, 28, "Text"],
Cell[112020, 4408, 192, 8, 28, "Text"],

Cell[CellGroupData[{
Cell[112237, 4420, 106, 2, 31, "Input"],
Cell[112346, 4424, 89, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112472, 4431, 99, 2, 31, "Input"],
Cell[112574, 4435, 72, 2, 27, "Output"]
}, Open  ]],
Cell[112661, 4440, 277, 7, 48, "Text"],

Cell[CellGroupData[{
Cell[112963, 4451, 78, 1, 31, "Input"],
Cell[113044, 4454, 310, 8, 27, "Output"]
}, Open  ]],
Cell[113369, 4465, 100, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[113494, 4472, 90, 1, 31, "Input"],
Cell[113587, 4475, 218, 5, 83, "Output"]
}, Open  ]],
Cell[113820, 4483, 162, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[114007, 4491, 197, 5, 71, "Input"],
Cell[114207, 4498, 24127, 657, 101, 6313, 432, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[138349, 5158, 399, 7, 100, "Text"],

Cell[CellGroupData[{
Cell[138773, 5169, 295, 7, 111, "Input"],
Cell[139071, 5178, 29070, 911, 175, 10408, 676, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[168156, 6092, 112, 1, 28, "Text"],
Cell[168271, 6095, 329, 6, 68, "Text"],
Cell[168603, 6103, 573, 27, 90, "Text"],

Cell[CellGroupData[{
Cell[169201, 6134, 162, 5, 47, "Input"],
Cell[169366, 6141, 482, 13, 27, "Output"]
}, Open  ]],
Cell[169863, 6157, 103, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[169991, 6164, 144, 5, 47, "Input"],
Cell[170138, 6171, 1254, 19, 215, "Output"]
}, Open  ]],
Cell[171407, 6193, 41, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[171473, 6197, 105, 2, 29, "Input"],
Cell[171581, 6201, 464, 8, 95, "Output"]
}, Open  ]],
Cell[172060, 6212, 181, 4, 60, "Text"],

Cell[CellGroupData[{
Cell[172266, 6220, 100, 2, 29, "Input"],
Cell[172369, 6224, 370, 7, 125, "Output"]
}, Open  ]],
Cell[172754, 6234, 153, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[172932, 6240, 157, 5, 47, "Input"],
Cell[173092, 6247, 174, 3, 48, "Output"]
}, Open  ]],
Cell[173281, 6253, 92, 1, 28, "Text"],

Cell[CellGroupData[{
Cell[173398, 6258, 89, 2, 29, "Input"],
Cell[173490, 6262, 318, 5, 59, "Output"]
}, Open  ]],
Cell[173823, 6270, 190, 4, 28, "Text"],

Cell[CellGroupData[{
Cell[174038, 6278, 114, 2, 29, "Input"],
Cell[174155, 6282, 985, 15, 135, "Output"]
}, Open  ]],
Cell[175155, 6300, 341, 9, 48, "Text"],

Cell[CellGroupData[{
Cell[175521, 6313, 108, 5, 47, "Input"],
Cell[175632, 6320, 464, 8, 95, "Output"]
}, Open  ]],
Cell[176111, 6331, 312, 6, 79, "Text"],

Cell[CellGroupData[{
Cell[176448, 6341, 325, 8, 137, "Input"],
Cell[176776, 6351, 25029, 752, 219, 8231, 538, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

